/**
 * epfl-safety - Calculate hazard for a reaction
 * @version v0.0.1
 * @link https://github.com/cheminfo/epfl-safety#readme
 * @license MIT
 */
(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
  typeof define === 'function' && define.amd ? define(['exports'], factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.EPFLSafety = {}));
})(this, (function (exports) { 'use strict';

  const redAcuteToxicitiesHazards = ["H300", "H310", "H330"];
  const rules$3 = [{
    description: 'Extreme acute toxicity',
    info: {
      highOrExtreme: true
    },
    matcher: {
      hazards: ['H300', 'H310', 'H330']
    },
    masses: [{
      lessThan: 0.001,
      score: 3
    }, {
      lessThan: 0.003,
      score: 6
    }, {
      lessThan: +Infinity,
      score: 12
    }]
  }, {
    description: 'High acute toxicity',
    info: {
      highOrExtreme: true
    },
    matcher: {
      hazards: ['H311', 'H318', 'H331']
    },
    masses: [{
      lessThan: 0.001,
      score: 2
    }, {
      lessThan: 0.003,
      score: 3
    }, {
      lessThan: +Infinity,
      score: 4
    }]
  }, {
    description: 'Medium acute toxicity',
    info: {
      highOrExtreme: false
    },
    matcher: {
      hazards: ['H302', 'H303', 'H305', 'H312', 'H313', 'H330', 'H332', 'H333', 'H334']
    },
    masses: [{
      lessThan: 0.001,
      score: 1
    }, {
      lessThan: 0.003,
      score: 2
    }, {
      lessThan: +Infinity,
      score: 3
    }]
  }, {
    description: 'Low acute toxicity',
    info: {
      highOrExtreme: false
    },
    matcher: {
      hazards: ['H301', 'H304', 'H315', 'H316', 'H317', 'H319,H320', 'H334', 'H335', 'H336']
    },
    masses: [{
      lessThan: 0.001,
      score: 0.5
    }, {
      lessThan: 0.003,
      score: 1
    }, {
      lessThan: +Infinity,
      score: 2
    }]
  }, {
    description: 'No known acute toxicity',
    info: {
      highOrExtreme: false
    },
    matcher: {},
    masses: [{
      lessThan: +Infinity,
      score: 0
    }]
  }];
  function appendAcuteToxicity(reagents, report, options) {
    const {
      logger
    } = options;
    let redAcuteToxicities = new Set();
    // what is the worse hazard ?
    for (const rule of rules$3) {
      for (const reagent of reagents) {
        if (reagent.safety.acuteToxicity) continue;
        appendRed$1(reagent, redAcuteToxicities);
        const matching = isMatching$3(reagent, rule);
        if (!matching) continue;
        reagent.safety.acuteToxicity = {
          description: rule.description,
          matchingHazards: matching.matchingHazards || [],
          info: rule.info,
          score: rule.masses.find(mass => reagent.mass.value <= mass.lessThan).score
        };
      }
    }

    /*
    If high or extreme are present only take sum of high and extreme values.
    If no high or extreme, simply take the score for the one reagent that leads to the highest score.
    */
    const highOrExtremes = reagents.filter(reagent => reagent.safety.acuteToxicity.info.highOrExtreme);
    if (highOrExtremes.length === 0) {
      logger?.info('AcuteToxicity: No high or extreme acute toxicity. Taking the highest score of the other.');
      report.scores.acuteToxicity = Math.max(...reagents.map(reagent => reagent.safety.acuteToxicity.score));
    } else {
      logger?.info('AcuteToxicity: High or extreme acute toxicity. Taking the sum of them.');
      report.scores.acuteToxicity = highOrExtremes.reduce((sum, reagent) => sum + reagent.safety.acuteToxicity.score, 0);
    }
    report.redAcuteToxicity = [...redAcuteToxicities];
  }
  function isMatching$3(reagent, rule) {
    if (!rule.matcher.hazards) return true;
    const matchingHazards = rule.matcher.hazards.filter(hazard => reagent.hazards.includes(hazard));
    if (matchingHazards.length === 0) return false;
    return {
      matchingHazards
    };
  }
  function appendRed$1(reagent, redAcuteToxicities) {
    reagent.hazards.forEach(hazard => {
      if (redAcuteToxicitiesHazards.includes(hazard)) {
        redAcuteToxicities.add(hazard);
      }
    });
  }

  const rules$2 = [{
    description: 'Extreme long-term toxicity',
    matcher: {
      hazards: ['H340', 'H350', 'H360', 'H370']
    },
    volumes: [{
      lessThan: 0.05,
      score: 2
    }, {
      lessThan: 0.5,
      score: 3
    }, {
      lessThan: 1,
      score: 6
    }, {
      lessThan: +Infinity,
      score: 10
    }]
  }, {
    description: 'High long-term toxicity',
    matcher: {
      hazards: ['H341', 'H351', 'H361', 'H371', 'H372', 'H373']
    },
    volumes: [{
      lessThan: 0.05,
      score: 1
    }, {
      lessThan: 0.5,
      score: 2
    }, {
      lessThan: 1,
      score: 4
    }, {
      lessThan: +Infinity,
      score: 8
    }]
  }, {
    description: 'No known long-term toxicity',
    matcher: {},
    volumes: [{
      lessThan: +Infinity,
      score: 0
    }]
  }];
  function appendLongTermToxicity(reagents, report, options = {}) {
    const {
      logger
    } = options;
    // what is the worse hazard ?
    for (const rule of rules$2) {
      for (const reagent of reagents) {
        if (reagent.safety.longTermToxicity) continue;
        const matching = isMatching$2(reagent, rule);
        if (!matching) continue;
        reagent.safety.longTermToxicity = {
          description: rule.description,
          matchingHazards: matching.matchingHazards || [],
          score: rule.volumes.find(volume => reagent.volume.value <= volume.lessThan).score
        };
      }
    }
    logger?.info('LongTermToxicity: Taking the highest score.');
    report.scores.longTermToxicity = Math.max(...reagents.map(reagent => reagent.safety.longTermToxicity.score));
  }
  function isMatching$2(reagent, rule) {
    if (!rule.matcher.hazards) return true;
    const matchingHazards = rule.matcher.hazards.filter(hazard => reagent.hazards.includes(hazard));
    if (matchingHazards.length === 0) return false;
    return {
      matchingHazards
    };
  }

  function appendMiscellaneous(reagents, report, options = {}) {
    const {
      miscellaneous = {}
    } = options;
    const {
      highVoltage,
      dustRisk,
      reactionTime,
      temperature,
      gasLines,
      pressure,
      overheadStirring
    } = miscellaneous;
    const results = [];
    results.push(getDustRisk(dustRisk, options));
    results.push(getReactionTime(reactionTime, options));
    results.push(getTemperature(temperature, options));
    results.push(getGasLines(gasLines, options));
    results.push(getPressure(pressure, options));
    results.push(getOverheadStirring(overheadStirring, options));
    results.push(getHighVoltage(highVoltage, options));
    report.miscellaneous = results;
  }
  function getDustRisk(dustRisk, options) {
    const {
      logger
    } = options;
    const entry = {
      label: 'Dust risk',
      info: '(for more than 5g of solids)',
      scores: []
    };
    switch (dustRisk) {
      case 'yes':
        entry.scores.push({
          remarks: 'Mask still required for all quantities of fine particles!',
          label: 'Fine powders, fibers air suspended',
          score: 4
        });
        break;
      case 'none':
        entry.scores.push({
          label: 'None',
          score: 0
        });
        break;
      default:
        logger.error(`Unknown dustRisk: ${dustRisk}`);
    }
    entry.score = entry.scores.reduce((acc, cur) => acc + cur.score, 0);
    return entry;
  }
  function getReactionTime(reactionTime, options) {
    const {
      logger
    } = options;
    const entry = {
      label: 'Reaction time',
      info: '',
      scores: []
    };
    switch (reactionTime) {
      case 'daytime':
        entry.scores.push({
          label: 'Daytime',
          score: 0
        });
        break;
      case 'overnight':
        entry.scores.push({
          label: 'Overnight',
          score: 2
        });
        break;
      default:
        logger.error(`Unknown reactionTime: ${reactionTime}`);
    }
    entry.score = entry.scores.reduce((acc, cur) => acc + cur.score, 0);
    return entry;
  }
  function getTemperature(temperature, options) {
    const {
      logger
    } = options;
    const entry = {
      label: 'Temperature',
      info: '',
      scores: []
    };
    switch (temperature) {
      case '<100':
        entry.scores.push({
          label: '< 100°C',
          score: 0
        });
        break;
      case '100-200':
        entry.scores.push({
          label: '100-200°C',
          score: 1
        });
        break;
      case 'extreme':
        entry.scores.push({
          label: '> 200°C or < -30°C',
          score: 2
        });
        break;
      default:
        logger.error(`Unknown temperature: ${temperature}`);
    }
    entry.score = entry.scores.reduce((acc, cur) => acc + cur.score, 0);
    return entry;
  }
  function getGasLines(gasLines, options) {
    const {
      logger
    } = options;
    const entry = {
      label: 'Handling High Pressure Gas Lines',
      info: '(Gas line pressure)',
      scores: []
    };
    const inertDescription = 'Inert (e.g., N2, He, Ar, CO2)';
    switch (gasLines.inert) {
      case 'none':
        entry.scores.push({
          description: inertDescription,
          label: 'None',
          score: 0
        });
        break;
      case '<20':
        entry.scores.push({
          description: inertDescription,
          label: '<20 barg',
          score: 0
        });
        break;
      case '20-40':
        entry.scores.push({
          description: inertDescription,
          label: '20-40 barg',
          score: 1
        });
        break;
      case '>40':
        entry.scores.push({
          description: inertDescription,
          label: '>40 barg',
          score: 2
        });
        break;
      default:
        logger.error(`Unknown gasLines.inert: ${gasLines.inert}`);
    }
    const reactiveDescription = 'Reactive/Hazardous (e.g., CO, NH3, H2, hydrocarbons)';
    switch (gasLines.reactive) {
      case 'none':
        entry.scores.push({
          description: reactiveDescription,
          label: 'None',
          score: 0
        });
        break;
      case '<20':
        entry.scores.push({
          description: reactiveDescription,
          label: '<20 barg',
          score: 2
        });
        break;
      case '20-40':
        entry.scores.push({
          description: reactiveDescription,
          label: '20-40 barg',
          score: 3
        });
        break;
      case '>40':
        entry.scores.push({
          description: reactiveDescription,
          label: '>40 barg',
          score: 4
        });
        break;
      default:
        logger.error(`Unknown gasLines.inert: ${gasLines.reactive}`);
    }
    entry.score = entry.scores.reduce((acc, cur) => acc + cur.score, 0);
    return entry;
  }
  function getPressure(pressure, options) {
    const {
      logger
    } = options;
    const entry = {
      label: 'For pressurized reactions in Parr/flow',
      info: 'Did you pass the PARR / Flow reactor exam and sign the pressurized SOP and PHA?',
      scores: []
    };
    const parrLowDescription = 'Parr < 50 mL or flow reactor(1 / 4';
    switch (pressure.parrLow) {
      case 'none':
        entry.scores.push({
          description: parrLowDescription,
          label: 'None',
          score: 0
        });
        break;
      case '1-20':
        entry.scores.push({
          description: parrLowDescription,
          label: '1-20 barg',
          score: 1
        });
        break;
      case '20-100':
        entry.scores.push({
          description: parrLowDescription,
          label: '20-100 barg',
          score: 2
        });
        break;
      case '>100':
        entry.scores.push({
          description: parrLowDescription,
          label: '>100 barg',
          score: 3
        });
        break;
      default:
        logger.error(`Unknown pressure.parrLow: ${pressure.parrLow}`);
    }
    const parrHighDescription = 'Parr > 50 mL or flow reactor(1 / 2';
    switch (pressure.parrHigh) {
      case 'none':
        entry.scores.push({
          description: parrHighDescription,
          label: 'None',
          score: 0
        });
        break;
      case '1-2':
        entry.scores.push({
          description: parrHighDescription,
          label: '1-2 barg',
          score: 1
        });
        break;
      case '2-5':
        entry.scores.push({
          description: parrHighDescription,
          label: '2-5 barg',
          score: 2
        });
        break;
      case '>10':
        entry.scores.push({
          description: parrHighDescription,
          label: '>10 barg',
          score: 3
        });
        break;
      default:
        logger.error(`Unknown pressure.parrHigh: ${pressure.parrHigh}`);
    }
    const pRatedDescription = 'Glass (P-Rated)';
    switch (pressure.pRated) {
      case 'none':
        entry.scores.push({
          description: pRatedDescription,
          label: 'None',
          score: 0
        });
        break;
      case '1-2':
        entry.scores.push({
          description: pRatedDescription,
          label: '1-2 barg',
          score: 1
        });
        break;
      case '2-5':
        entry.scores.push({
          description: pRatedDescription,
          label: '2-5 barg',
          score: 2
        });
        break;
      case '>5':
        entry.scores.push({
          description: pRatedDescription,
          label: '>5 barg',
          score: 3
        });
        break;
      default:
        logger.error(`Unknown pressure.pRated: ${pressure.pRated}`);
    }
    const nonRatedDescription = 'Glass (Not rated)';
    switch (pressure.nonRated) {
      case 'none':
        entry.scores.push({
          description: nonRatedDescription,
          label: 'None',
          score: 0
        });
        break;
      case 'yes':
        entry.scores.push({
          description: nonRatedDescription,
          label: 'Yes',
          score: 100
        });
        break;
      default:
        logger.error(`Unknown pressure.nonRated: ${pressure.nonRated}`);
    }
    entry.score = entry.scores.reduce((acc, cur) => acc + cur.score, 0);
    return entry;
  }
  function getOverheadStirring(overheadStirring, options) {
    const {
      logger
    } = options;
    const entry = {
      label: 'Overheads stirring ?',
      info: '',
      scores: []
    };
    switch (overheadStirring) {
      case 'none':
        entry.scores.push({
          label: 'None',
          score: 0
        });
        break;
      case 'yes':
        entry.scores.push({
          label: 'Yes',
          score: 2
        });
        break;
      default:
        logger.error(`Unknown overheadStirring: ${overheadStirring}`);
    }
    entry.score = entry.scores.reduce((acc, cur) => acc + cur.score, 0);
    return entry;
  }
  function getHighVoltage(highVoltage, options) {
    const {
      logger
    } = options;
    const entry = {
      label: 'High voltage ?',
      info: '',
      scores: []
    };
    switch (highVoltage) {
      case 'none':
        entry.scores.push({
          label: 'None',
          score: 0
        });
        break;
      case 'yes':
        entry.scores.push({
          label: 'Yes',
          score: 100
        });
        break;
      default:
        logger.error(`Unknown highVoltage: ${highVoltage}`);
    }
    entry.score = entry.scores.reduce((acc, cur) => acc + cur.score, 0);
    return entry;
  }

  const redReactivityAndInstabilityHazards = ["H260", "H261", "H250", "H271", "H272", "H200", "H201", "H202", "H203", "H240", "H241", "H242", "H251", "H252"];
  const rules$1 = [{
    description: 'Flammable gas generation',
    matcher: {
      hazards: ['H260', 'H261']
    },
    masses: [{
      lessThan: 0.001,
      score: 3
    }, {
      lessThan: 0.003,
      score: 5
    }, {
      lessThan: +Infinity,
      score: 10
    }]
  }, {
    description: 'Pyrophoric',
    matcher: {
      hazards: ['H250']
    },
    masses: [{
      lessThan: 0.001,
      score: 3
    }, {
      lessThan: 0.003,
      score: 6
    }, {
      lessThan: +Infinity,
      score: 10
    }]
  }, {
    description: 'Oxidizer',
    matcher: {
      hazards: ['H270', 'H271', 'H272']
    },
    masses: [{
      lessThan: 0.001,
      score: 1
    }, {
      lessThan: 0.003,
      score: 3
    }, {
      lessThan: +Infinity,
      score: 6
    }]
  }, {
    description: 'Explosive / Self-heating',
    matcher: {
      hazards: ['H200', 'H201', 'H202', 'H203', 'H240', 'H241', 'H242', 'H251', 'H252']
    },
    masses: [{
      lessThan: 0.001,
      score: 3
    }, {
      lessThan: 0.003,
      score: 5
    }, {
      lessThan: +Infinity,
      score: 10
    }]
  }, {
    description: 'Corrosive',
    matcher: {
      hazards: ['H314']
    },
    masses: [{
      lessThan: 0.001,
      score: 0.5
    }, {
      lessThan: 0.003,
      score: 1
    }, {
      lessThan: +Infinity,
      score: 2
    }]
  }, {
    description: 'No reactivity or instability hazards known',
    matcher: {},
    masses: [{
      lessThan: +Infinity,
      score: 0
    }]
  }];
  function appendReactivityAndInstability(reagents, report, options = {}) {
    // what is the worse hazard ?
    let sum = 0;
    let redReactivityAndInstabilities = new Set();
    for (const rule of rules$1) {
      for (const reagent of reagents) {
        if (!reagent.safety.reactivityAndInstabilities) {
          reagent.safety.reactivityAndInstabilities = [];
        }
        const matching = isMatching$1(reagent, rule);
        appendRed(reagent, redReactivityAndInstabilities);
        if (!matching) continue;
        const score = rule.masses.find(mass => reagent.mass.value <= mass.lessThan).score;
        if (score > 0 || reagent.safety.reactivityAndInstabilities.length === 0) {
          reagent.safety.reactivityAndInstabilities.push({
            description: rule.description,
            matchingHazards: matching.matchingHazards || [],
            score
          });
          sum += score;
        }
      }
    }
    report.redReactivityAndInstabilities = redReactivityAndInstabilities;
    report.scores.reactivityAndInstability = sum;
  }
  function appendRed(reagent, reactivityAndInstabilities) {
    reagent.hazards.forEach(hazard => {
      if (redReactivityAndInstabilityHazards.includes(hazard)) {
        reactivityAndInstabilities.add(hazard);
      }
    });
  }
  function isMatching$1(reagent, rule) {
    if (!rule.matcher.hazards) return true;
    const matchingHazards = rule.matcher.hazards.filter(hazard => reagent.hazards.includes(hazard));
    if (matchingHazards.length === 0) return false;
    return {
      matchingHazards
    };
  }

  const rules = [{
    description: 'Very flammable, low bp',
    matcher: {
      hazards: ['H222', 'H224', 'H225'],
      bpLessThan: 35
    },
    volumes: [{
      lessThan: 0.01,
      score: 1.5
    }, {
      lessThan: 0.05,
      score: 3
    }, {
      lessThan: 0.5,
      score: 4
    }, {
      lessThan: 1,
      score: 5
    }, {
      lessThan: +Infinity,
      score: 10
    }]
  }, {
    description: 'Very flammable, high bp',
    matcher: {
      hazards: ['H222', 'H224', 'H225']
    },
    volumes: [{
      lessThan: 0.01,
      score: 1
    }, {
      lessThan: 0.05,
      score: 2
    }, {
      lessThan: 0.5,
      score: 3
    }, {
      lessThan: 1,
      score: 4
    }, {
      lessThan: +Infinity,
      score: 8
    }]
  }, {
    description: 'Flammable, low bp',
    matcher: {
      hazards: ['H223', 'H226', 'H227', 'H228'],
      bpLessThan: 35
    },
    volumes: [{
      lessThan: 0.01,
      score: 0.5
    }, {
      lessThan: 0.05,
      score: 1
    }, {
      lessThan: 0.5,
      score: 2
    }, {
      lessThan: 1,
      score: 3
    }, {
      lessThan: +Infinity,
      score: 6
    }]
  }, {
    description: 'Flammable, high bp',
    matcher: {
      hazards: ['H223', 'H226', 'H227', 'H228']
    },
    volumes: [{
      lessThan: 0.01,
      score: 0
    }, {
      lessThan: 0.05,
      score: 0.5
    }, {
      lessThan: 0.5,
      score: 1
    }, {
      lessThan: 1,
      score: 2
    }, {
      lessThan: +Infinity,
      score: 4
    }]
  }, {
    description: 'Not flammable',
    matcher: {},
    volumes: [{
      lessThan: 0.5,
      score: 0
    }, {
      lessThan: 1,
      score: 1
    }, {
      lessThan: +Infinity,
      score: 3
    }]
  }];
  function appendVolumeAndFlammability(reagents, report, options) {
    const totalVolume = getTotalVolume(reagents, options);
    // what is the worse hazard ?
    let bestScore = 0;
    for (const rule of rules) {
      for (const reagent of reagents) {
        if (reagent.safety.volumeAndFlammability) continue;
        const matching = isMatching(reagent, rule);
        if (!matching) continue;
        const score = rule.volumes.find(volume => totalVolume <= volume.lessThan).score;
        if (score > bestScore) {
          bestScore = score;
        }
        reagent.safety.volumeAndFlammability = {
          description: rule.description,
          matchingHazards: matching.matchingHazards || [],
          score
        };
      }
    }
    report.scores.volumeAndFlammability = bestScore;
  }
  function isMatching(reagent, rule) {
    if (!rule.matcher.hazards) return true;
    if (!rule.matcher.bpLessThan && reagent.bp > rule.matcher.bpLessThan) {
      return false;
    }
    const matchingHazards = rule.matcher.hazards.filter(hazard => reagent.hazards.includes(hazard));
    if (matchingHazards.length === 0) return false;
    return {
      matchingHazards
    };
  }
  function getTotalVolume(reagents, options) {
    const {
      logger
    } = options;
    let totalVolume = 0;
    for (const reagent of reagents) {
      if (reagent.volume) {
        totalVolume += reagent.volume.value;
      } else {
        logger.warn(`reagent ${reagent.smiles} has no volume`);
        totalVolume += reagent.mass.value;
      }
    }
    return totalVolume;
  }

  var commonjsGlobal = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

  function getDefaultExportFromCjs (x) {
  	return x && x.__esModule && Object.prototype.hasOwnProperty.call(x, 'default') ? x['default'] : x;
  }

  function commonjsRequire (path) {
  	throw new Error('Could not dynamically require "' + path + '". Please configure the dynamicRequireTargets or/and ignoreDynamicRequires option of @rollup/plugin-commonjs appropriately for this require call to work.');
  }

  var browserPonyfill = {exports: {}};

  (function (module, exports) {
    var global = typeof self !== 'undefined' ? self : commonjsGlobal;
    var __self__ = function () {
      function F() {
        this.fetch = false;
        this.DOMException = global.DOMException;
      }
      F.prototype = global;
      return new F();
    }();
    (function (self) {
      (function (exports) {
        var support = {
          searchParams: 'URLSearchParams' in self,
          iterable: 'Symbol' in self && 'iterator' in Symbol,
          blob: 'FileReader' in self && 'Blob' in self && function () {
            try {
              new Blob();
              return true;
            } catch (e) {
              return false;
            }
          }(),
          formData: 'FormData' in self,
          arrayBuffer: 'ArrayBuffer' in self
        };
        function isDataView(obj) {
          return obj && DataView.prototype.isPrototypeOf(obj);
        }
        if (support.arrayBuffer) {
          var viewClasses = ['[object Int8Array]', '[object Uint8Array]', '[object Uint8ClampedArray]', '[object Int16Array]', '[object Uint16Array]', '[object Int32Array]', '[object Uint32Array]', '[object Float32Array]', '[object Float64Array]'];
          var isArrayBufferView = ArrayBuffer.isView || function (obj) {
            return obj && viewClasses.indexOf(Object.prototype.toString.call(obj)) > -1;
          };
        }
        function normalizeName(name) {
          if (typeof name !== 'string') {
            name = String(name);
          }
          if (/[^a-z0-9\-#$%&'*+.^_`|~]/i.test(name)) {
            throw new TypeError('Invalid character in header field name');
          }
          return name.toLowerCase();
        }
        function normalizeValue(value) {
          if (typeof value !== 'string') {
            value = String(value);
          }
          return value;
        }

        // Build a destructive iterator for the value list
        function iteratorFor(items) {
          var iterator = {
            next: function () {
              var value = items.shift();
              return {
                done: value === undefined,
                value: value
              };
            }
          };
          if (support.iterable) {
            iterator[Symbol.iterator] = function () {
              return iterator;
            };
          }
          return iterator;
        }
        function Headers(headers) {
          this.map = {};
          if (headers instanceof Headers) {
            headers.forEach(function (value, name) {
              this.append(name, value);
            }, this);
          } else if (Array.isArray(headers)) {
            headers.forEach(function (header) {
              this.append(header[0], header[1]);
            }, this);
          } else if (headers) {
            Object.getOwnPropertyNames(headers).forEach(function (name) {
              this.append(name, headers[name]);
            }, this);
          }
        }
        Headers.prototype.append = function (name, value) {
          name = normalizeName(name);
          value = normalizeValue(value);
          var oldValue = this.map[name];
          this.map[name] = oldValue ? oldValue + ', ' + value : value;
        };
        Headers.prototype['delete'] = function (name) {
          delete this.map[normalizeName(name)];
        };
        Headers.prototype.get = function (name) {
          name = normalizeName(name);
          return this.has(name) ? this.map[name] : null;
        };
        Headers.prototype.has = function (name) {
          return this.map.hasOwnProperty(normalizeName(name));
        };
        Headers.prototype.set = function (name, value) {
          this.map[normalizeName(name)] = normalizeValue(value);
        };
        Headers.prototype.forEach = function (callback, thisArg) {
          for (var name in this.map) {
            if (this.map.hasOwnProperty(name)) {
              callback.call(thisArg, this.map[name], name, this);
            }
          }
        };
        Headers.prototype.keys = function () {
          var items = [];
          this.forEach(function (value, name) {
            items.push(name);
          });
          return iteratorFor(items);
        };
        Headers.prototype.values = function () {
          var items = [];
          this.forEach(function (value) {
            items.push(value);
          });
          return iteratorFor(items);
        };
        Headers.prototype.entries = function () {
          var items = [];
          this.forEach(function (value, name) {
            items.push([name, value]);
          });
          return iteratorFor(items);
        };
        if (support.iterable) {
          Headers.prototype[Symbol.iterator] = Headers.prototype.entries;
        }
        function consumed(body) {
          if (body.bodyUsed) {
            return Promise.reject(new TypeError('Already read'));
          }
          body.bodyUsed = true;
        }
        function fileReaderReady(reader) {
          return new Promise(function (resolve, reject) {
            reader.onload = function () {
              resolve(reader.result);
            };
            reader.onerror = function () {
              reject(reader.error);
            };
          });
        }
        function readBlobAsArrayBuffer(blob) {
          var reader = new FileReader();
          var promise = fileReaderReady(reader);
          reader.readAsArrayBuffer(blob);
          return promise;
        }
        function readBlobAsText(blob) {
          var reader = new FileReader();
          var promise = fileReaderReady(reader);
          reader.readAsText(blob);
          return promise;
        }
        function readArrayBufferAsText(buf) {
          var view = new Uint8Array(buf);
          var chars = new Array(view.length);
          for (var i = 0; i < view.length; i++) {
            chars[i] = String.fromCharCode(view[i]);
          }
          return chars.join('');
        }
        function bufferClone(buf) {
          if (buf.slice) {
            return buf.slice(0);
          } else {
            var view = new Uint8Array(buf.byteLength);
            view.set(new Uint8Array(buf));
            return view.buffer;
          }
        }
        function Body() {
          this.bodyUsed = false;
          this._initBody = function (body) {
            this._bodyInit = body;
            if (!body) {
              this._bodyText = '';
            } else if (typeof body === 'string') {
              this._bodyText = body;
            } else if (support.blob && Blob.prototype.isPrototypeOf(body)) {
              this._bodyBlob = body;
            } else if (support.formData && FormData.prototype.isPrototypeOf(body)) {
              this._bodyFormData = body;
            } else if (support.searchParams && URLSearchParams.prototype.isPrototypeOf(body)) {
              this._bodyText = body.toString();
            } else if (support.arrayBuffer && support.blob && isDataView(body)) {
              this._bodyArrayBuffer = bufferClone(body.buffer);
              // IE 10-11 can't handle a DataView body.
              this._bodyInit = new Blob([this._bodyArrayBuffer]);
            } else if (support.arrayBuffer && (ArrayBuffer.prototype.isPrototypeOf(body) || isArrayBufferView(body))) {
              this._bodyArrayBuffer = bufferClone(body);
            } else {
              this._bodyText = body = Object.prototype.toString.call(body);
            }
            if (!this.headers.get('content-type')) {
              if (typeof body === 'string') {
                this.headers.set('content-type', 'text/plain;charset=UTF-8');
              } else if (this._bodyBlob && this._bodyBlob.type) {
                this.headers.set('content-type', this._bodyBlob.type);
              } else if (support.searchParams && URLSearchParams.prototype.isPrototypeOf(body)) {
                this.headers.set('content-type', 'application/x-www-form-urlencoded;charset=UTF-8');
              }
            }
          };
          if (support.blob) {
            this.blob = function () {
              var rejected = consumed(this);
              if (rejected) {
                return rejected;
              }
              if (this._bodyBlob) {
                return Promise.resolve(this._bodyBlob);
              } else if (this._bodyArrayBuffer) {
                return Promise.resolve(new Blob([this._bodyArrayBuffer]));
              } else if (this._bodyFormData) {
                throw new Error('could not read FormData body as blob');
              } else {
                return Promise.resolve(new Blob([this._bodyText]));
              }
            };
            this.arrayBuffer = function () {
              if (this._bodyArrayBuffer) {
                return consumed(this) || Promise.resolve(this._bodyArrayBuffer);
              } else {
                return this.blob().then(readBlobAsArrayBuffer);
              }
            };
          }
          this.text = function () {
            var rejected = consumed(this);
            if (rejected) {
              return rejected;
            }
            if (this._bodyBlob) {
              return readBlobAsText(this._bodyBlob);
            } else if (this._bodyArrayBuffer) {
              return Promise.resolve(readArrayBufferAsText(this._bodyArrayBuffer));
            } else if (this._bodyFormData) {
              throw new Error('could not read FormData body as text');
            } else {
              return Promise.resolve(this._bodyText);
            }
          };
          if (support.formData) {
            this.formData = function () {
              return this.text().then(decode);
            };
          }
          this.json = function () {
            return this.text().then(JSON.parse);
          };
          return this;
        }

        // HTTP methods whose capitalization should be normalized
        var methods = ['DELETE', 'GET', 'HEAD', 'OPTIONS', 'POST', 'PUT'];
        function normalizeMethod(method) {
          var upcased = method.toUpperCase();
          return methods.indexOf(upcased) > -1 ? upcased : method;
        }
        function Request(input, options) {
          options = options || {};
          var body = options.body;
          if (input instanceof Request) {
            if (input.bodyUsed) {
              throw new TypeError('Already read');
            }
            this.url = input.url;
            this.credentials = input.credentials;
            if (!options.headers) {
              this.headers = new Headers(input.headers);
            }
            this.method = input.method;
            this.mode = input.mode;
            this.signal = input.signal;
            if (!body && input._bodyInit != null) {
              body = input._bodyInit;
              input.bodyUsed = true;
            }
          } else {
            this.url = String(input);
          }
          this.credentials = options.credentials || this.credentials || 'same-origin';
          if (options.headers || !this.headers) {
            this.headers = new Headers(options.headers);
          }
          this.method = normalizeMethod(options.method || this.method || 'GET');
          this.mode = options.mode || this.mode || null;
          this.signal = options.signal || this.signal;
          this.referrer = null;
          if ((this.method === 'GET' || this.method === 'HEAD') && body) {
            throw new TypeError('Body not allowed for GET or HEAD requests');
          }
          this._initBody(body);
        }
        Request.prototype.clone = function () {
          return new Request(this, {
            body: this._bodyInit
          });
        };
        function decode(body) {
          var form = new FormData();
          body.trim().split('&').forEach(function (bytes) {
            if (bytes) {
              var split = bytes.split('=');
              var name = split.shift().replace(/\+/g, ' ');
              var value = split.join('=').replace(/\+/g, ' ');
              form.append(decodeURIComponent(name), decodeURIComponent(value));
            }
          });
          return form;
        }
        function parseHeaders(rawHeaders) {
          var headers = new Headers();
          // Replace instances of \r\n and \n followed by at least one space or horizontal tab with a space
          // https://tools.ietf.org/html/rfc7230#section-3.2
          var preProcessedHeaders = rawHeaders.replace(/\r?\n[\t ]+/g, ' ');
          preProcessedHeaders.split(/\r?\n/).forEach(function (line) {
            var parts = line.split(':');
            var key = parts.shift().trim();
            if (key) {
              var value = parts.join(':').trim();
              headers.append(key, value);
            }
          });
          return headers;
        }
        Body.call(Request.prototype);
        function Response(bodyInit, options) {
          if (!options) {
            options = {};
          }
          this.type = 'default';
          this.status = options.status === undefined ? 200 : options.status;
          this.ok = this.status >= 200 && this.status < 300;
          this.statusText = 'statusText' in options ? options.statusText : 'OK';
          this.headers = new Headers(options.headers);
          this.url = options.url || '';
          this._initBody(bodyInit);
        }
        Body.call(Response.prototype);
        Response.prototype.clone = function () {
          return new Response(this._bodyInit, {
            status: this.status,
            statusText: this.statusText,
            headers: new Headers(this.headers),
            url: this.url
          });
        };
        Response.error = function () {
          var response = new Response(null, {
            status: 0,
            statusText: ''
          });
          response.type = 'error';
          return response;
        };
        var redirectStatuses = [301, 302, 303, 307, 308];
        Response.redirect = function (url, status) {
          if (redirectStatuses.indexOf(status) === -1) {
            throw new RangeError('Invalid status code');
          }
          return new Response(null, {
            status: status,
            headers: {
              location: url
            }
          });
        };
        exports.DOMException = self.DOMException;
        try {
          new exports.DOMException();
        } catch (err) {
          exports.DOMException = function (message, name) {
            this.message = message;
            this.name = name;
            var error = Error(message);
            this.stack = error.stack;
          };
          exports.DOMException.prototype = Object.create(Error.prototype);
          exports.DOMException.prototype.constructor = exports.DOMException;
        }
        function fetch(input, init) {
          return new Promise(function (resolve, reject) {
            var request = new Request(input, init);
            if (request.signal && request.signal.aborted) {
              return reject(new exports.DOMException('Aborted', 'AbortError'));
            }
            var xhr = new XMLHttpRequest();
            function abortXhr() {
              xhr.abort();
            }
            xhr.onload = function () {
              var options = {
                status: xhr.status,
                statusText: xhr.statusText,
                headers: parseHeaders(xhr.getAllResponseHeaders() || '')
              };
              options.url = 'responseURL' in xhr ? xhr.responseURL : options.headers.get('X-Request-URL');
              var body = 'response' in xhr ? xhr.response : xhr.responseText;
              resolve(new Response(body, options));
            };
            xhr.onerror = function () {
              reject(new TypeError('Network request failed'));
            };
            xhr.ontimeout = function () {
              reject(new TypeError('Network request failed'));
            };
            xhr.onabort = function () {
              reject(new exports.DOMException('Aborted', 'AbortError'));
            };
            xhr.open(request.method, request.url, true);
            if (request.credentials === 'include') {
              xhr.withCredentials = true;
            } else if (request.credentials === 'omit') {
              xhr.withCredentials = false;
            }
            if ('responseType' in xhr && support.blob) {
              xhr.responseType = 'blob';
            }
            request.headers.forEach(function (value, name) {
              xhr.setRequestHeader(name, value);
            });
            if (request.signal) {
              request.signal.addEventListener('abort', abortXhr);
              xhr.onreadystatechange = function () {
                // DONE (success or failure)
                if (xhr.readyState === 4) {
                  request.signal.removeEventListener('abort', abortXhr);
                }
              };
            }
            xhr.send(typeof request._bodyInit === 'undefined' ? null : request._bodyInit);
          });
        }
        fetch.polyfill = true;
        if (!self.fetch) {
          self.fetch = fetch;
          self.Headers = Headers;
          self.Request = Request;
          self.Response = Response;
        }
        exports.Headers = Headers;
        exports.Request = Request;
        exports.Response = Response;
        exports.fetch = fetch;
        Object.defineProperty(exports, '__esModule', {
          value: true
        });
        return exports;
      })({});
    })(__self__);
    __self__.fetch.ponyfill = true;
    // Remove "polyfill" property added by whatwg-fetch
    delete __self__.fetch.polyfill;
    // Choose between native implementation (global) or custom implementation (__self__)
    // var ctx = global.fetch ? global : __self__;
    var ctx = __self__; // this line disable service worker support temporarily
    exports = ctx.fetch; // To enable: import fetch from 'cross-fetch'
    exports.default = ctx.fetch; // For TypeScript consumers without esModuleInterop.
    exports.fetch = ctx.fetch; // To enable: import {fetch} from 'cross-fetch'
    exports.Headers = ctx.Headers;
    exports.Request = ctx.Request;
    exports.Response = ctx.Response;
    module.exports = exports;
  })(browserPonyfill, browserPonyfill.exports);
  var fetch = /*@__PURE__*/getDefaultExportFromCjs(browserPonyfill.exports);

  var jsonpath = {exports: {}};

  /*! jsonpath 1.1.1 */
  (function (module, exports) {
    (function (f) {
      {
        module.exports = f();
      }
    })(function () {
      return function e(t, n, r) {
        function s(o, u) {
          if (!n[o]) {
            if (!t[o]) {
              var a = typeof commonjsRequire == "function" && commonjsRequire;
              if (!u && a) return a(o, !0);
              if (i) return i(o, !0);
              var f = new Error("Cannot find module '" + o + "'");
              throw f.code = "MODULE_NOT_FOUND", f;
            }
            var l = n[o] = {
              exports: {}
            };
            t[o][0].call(l.exports, function (e) {
              var n = t[o][1][e];
              return s(n ? n : e);
            }, l, l.exports, e, t, n, r);
          }
          return n[o].exports;
        }
        var i = typeof commonjsRequire == "function" && commonjsRequire;
        for (var o = 0; o < r.length; o++) s(r[o]);
        return s;
      }({
        "./aesprim": [function (require, module, exports) {
          /*
            Copyright (C) 2013 Ariya Hidayat <ariya.hidayat@gmail.com>
            Copyright (C) 2013 Thaddee Tyl <thaddee.tyl@gmail.com>
            Copyright (C) 2013 Mathias Bynens <mathias@qiwi.be>
            Copyright (C) 2012 Ariya Hidayat <ariya.hidayat@gmail.com>
            Copyright (C) 2012 Mathias Bynens <mathias@qiwi.be>
            Copyright (C) 2012 Joost-Wim Boekesteijn <joost-wim@boekesteijn.nl>
            Copyright (C) 2012 Kris Kowal <kris.kowal@cixar.com>
            Copyright (C) 2012 Yusuke Suzuki <utatane.tea@gmail.com>
            Copyright (C) 2012 Arpad Borsos <arpad.borsos@googlemail.com>
            Copyright (C) 2011 Ariya Hidayat <ariya.hidayat@gmail.com>
          
            Redistribution and use in source and binary forms, with or without
            modification, are permitted provided that the following conditions are met:
          
              * Redistributions of source code must retain the above copyright
                notice, this list of conditions and the following disclaimer.
              * Redistributions in binary form must reproduce the above copyright
                notice, this list of conditions and the following disclaimer in the
                documentation and/or other materials provided with the distribution.
          
            THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
            AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
            IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
            ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
            DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
            (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
            LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
            ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
            (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
            THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
          */

          /*jslint bitwise:true plusplus:true */
          /*global esprima:true, define:true, exports:true, window: true,
          throwErrorTolerant: true,
          throwError: true, generateStatement: true, peek: true,
          parseAssignmentExpression: true, parseBlock: true, parseExpression: true,
          parseFunctionDeclaration: true, parseFunctionExpression: true,
          parseFunctionSourceElements: true, parseVariableIdentifier: true,
          parseLeftHandSideExpression: true,
          parseUnaryExpression: true,
          parseStatement: true, parseSourceElement: true */

          (function (root, factory) {

            // Universal Module Definition (UMD) to support AMD, CommonJS/Node.js,
            // Rhino, and plain browser loading.

            /* istanbul ignore next */
            if (typeof exports !== 'undefined') {
              factory(exports);
            } else {
              factory(root.esprima = {});
            }
          })(this, function (exports) {

            var Token, TokenName, FnExprTokens, Syntax, PropertyKind, Messages, Regex, SyntaxTreeDelegate, source, strict, index, lineNumber, lineStart, length, delegate, lookahead, state, extra;
            Token = {
              BooleanLiteral: 1,
              EOF: 2,
              Identifier: 3,
              Keyword: 4,
              NullLiteral: 5,
              NumericLiteral: 6,
              Punctuator: 7,
              StringLiteral: 8,
              RegularExpression: 9
            };
            TokenName = {};
            TokenName[Token.BooleanLiteral] = 'Boolean';
            TokenName[Token.EOF] = '<end>';
            TokenName[Token.Identifier] = 'Identifier';
            TokenName[Token.Keyword] = 'Keyword';
            TokenName[Token.NullLiteral] = 'Null';
            TokenName[Token.NumericLiteral] = 'Numeric';
            TokenName[Token.Punctuator] = 'Punctuator';
            TokenName[Token.StringLiteral] = 'String';
            TokenName[Token.RegularExpression] = 'RegularExpression';

            // A function following one of those tokens is an expression.
            FnExprTokens = ['(', '{', '[', 'in', 'typeof', 'instanceof', 'new', 'return', 'case', 'delete', 'throw', 'void',
            // assignment operators
            '=', '+=', '-=', '*=', '/=', '%=', '<<=', '>>=', '>>>=', '&=', '|=', '^=', ',',
            // binary/unary operators
            '+', '-', '*', '/', '%', '++', '--', '<<', '>>', '>>>', '&', '|', '^', '!', '~', '&&', '||', '?', ':', '===', '==', '>=', '<=', '<', '>', '!=', '!=='];
            Syntax = {
              AssignmentExpression: 'AssignmentExpression',
              ArrayExpression: 'ArrayExpression',
              BlockStatement: 'BlockStatement',
              BinaryExpression: 'BinaryExpression',
              BreakStatement: 'BreakStatement',
              CallExpression: 'CallExpression',
              CatchClause: 'CatchClause',
              ConditionalExpression: 'ConditionalExpression',
              ContinueStatement: 'ContinueStatement',
              DoWhileStatement: 'DoWhileStatement',
              DebuggerStatement: 'DebuggerStatement',
              EmptyStatement: 'EmptyStatement',
              ExpressionStatement: 'ExpressionStatement',
              ForStatement: 'ForStatement',
              ForInStatement: 'ForInStatement',
              FunctionDeclaration: 'FunctionDeclaration',
              FunctionExpression: 'FunctionExpression',
              Identifier: 'Identifier',
              IfStatement: 'IfStatement',
              Literal: 'Literal',
              LabeledStatement: 'LabeledStatement',
              LogicalExpression: 'LogicalExpression',
              MemberExpression: 'MemberExpression',
              NewExpression: 'NewExpression',
              ObjectExpression: 'ObjectExpression',
              Program: 'Program',
              Property: 'Property',
              ReturnStatement: 'ReturnStatement',
              SequenceExpression: 'SequenceExpression',
              SwitchStatement: 'SwitchStatement',
              SwitchCase: 'SwitchCase',
              ThisExpression: 'ThisExpression',
              ThrowStatement: 'ThrowStatement',
              TryStatement: 'TryStatement',
              UnaryExpression: 'UnaryExpression',
              UpdateExpression: 'UpdateExpression',
              VariableDeclaration: 'VariableDeclaration',
              VariableDeclarator: 'VariableDeclarator',
              WhileStatement: 'WhileStatement',
              WithStatement: 'WithStatement'
            };
            PropertyKind = {
              Data: 1,
              Get: 2,
              Set: 4
            };

            // Error messages should be identical to V8.
            Messages = {
              UnexpectedToken: 'Unexpected token %0',
              UnexpectedNumber: 'Unexpected number',
              UnexpectedString: 'Unexpected string',
              UnexpectedIdentifier: 'Unexpected identifier',
              UnexpectedReserved: 'Unexpected reserved word',
              UnexpectedEOS: 'Unexpected end of input',
              NewlineAfterThrow: 'Illegal newline after throw',
              InvalidRegExp: 'Invalid regular expression',
              UnterminatedRegExp: 'Invalid regular expression: missing /',
              InvalidLHSInAssignment: 'Invalid left-hand side in assignment',
              InvalidLHSInForIn: 'Invalid left-hand side in for-in',
              MultipleDefaultsInSwitch: 'More than one default clause in switch statement',
              NoCatchOrFinally: 'Missing catch or finally after try',
              UnknownLabel: 'Undefined label \'%0\'',
              Redeclaration: '%0 \'%1\' has already been declared',
              IllegalContinue: 'Illegal continue statement',
              IllegalBreak: 'Illegal break statement',
              IllegalReturn: 'Illegal return statement',
              StrictModeWith: 'Strict mode code may not include a with statement',
              StrictCatchVariable: 'Catch variable may not be eval or arguments in strict mode',
              StrictVarName: 'Variable name may not be eval or arguments in strict mode',
              StrictParamName: 'Parameter name eval or arguments is not allowed in strict mode',
              StrictParamDupe: 'Strict mode function may not have duplicate parameter names',
              StrictFunctionName: 'Function name may not be eval or arguments in strict mode',
              StrictOctalLiteral: 'Octal literals are not allowed in strict mode.',
              StrictDelete: 'Delete of an unqualified identifier in strict mode.',
              StrictDuplicateProperty: 'Duplicate data property in object literal not allowed in strict mode',
              AccessorDataProperty: 'Object literal may not have data and accessor property with the same name',
              AccessorGetSet: 'Object literal may not have multiple get/set accessors with the same name',
              StrictLHSAssignment: 'Assignment to eval or arguments is not allowed in strict mode',
              StrictLHSPostfix: 'Postfix increment/decrement may not have eval or arguments operand in strict mode',
              StrictLHSPrefix: 'Prefix increment/decrement may not have eval or arguments operand in strict mode',
              StrictReservedWord: 'Use of future reserved word in strict mode'
            };

            // See also tools/generate-unicode-regex.py.
            Regex = {
              NonAsciiIdentifierStart: new RegExp('[\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u0527\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u08A0\u08A2-\u08AC\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0977\u0979-\u097F\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C33\u0C35-\u0C39\u0C3D\u0C58\u0C59\u0C60\u0C61\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D60\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F4\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F0\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191C\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19C1-\u19C7\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FCC\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA697\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA78E\uA790-\uA793\uA7A0-\uA7AA\uA7F8-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA80-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uABC0-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]'),
              NonAsciiIdentifierPart: new RegExp('[\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0300-\u0374\u0376\u0377\u037A-\u037D\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u0483-\u0487\u048A-\u0527\u0531-\u0556\u0559\u0561-\u0587\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u05D0-\u05EA\u05F0-\u05F2\u0610-\u061A\u0620-\u0669\u066E-\u06D3\u06D5-\u06DC\u06DF-\u06E8\u06EA-\u06FC\u06FF\u0710-\u074A\u074D-\u07B1\u07C0-\u07F5\u07FA\u0800-\u082D\u0840-\u085B\u08A0\u08A2-\u08AC\u08E4-\u08FE\u0900-\u0963\u0966-\u096F\u0971-\u0977\u0979-\u097F\u0981-\u0983\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BC-\u09C4\u09C7\u09C8\u09CB-\u09CE\u09D7\u09DC\u09DD\u09DF-\u09E3\u09E6-\u09F1\u0A01-\u0A03\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A59-\u0A5C\u0A5E\u0A66-\u0A75\u0A81-\u0A83\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABC-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AD0\u0AE0-\u0AE3\u0AE6-\u0AEF\u0B01-\u0B03\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3C-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B56\u0B57\u0B5C\u0B5D\u0B5F-\u0B63\u0B66-\u0B6F\u0B71\u0B82\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD0\u0BD7\u0BE6-\u0BEF\u0C01-\u0C03\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C33\u0C35-\u0C39\u0C3D-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C58\u0C59\u0C60-\u0C63\u0C66-\u0C6F\u0C82\u0C83\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBC-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CDE\u0CE0-\u0CE3\u0CE6-\u0CEF\u0CF1\u0CF2\u0D02\u0D03\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D-\u0D44\u0D46-\u0D48\u0D4A-\u0D4E\u0D57\u0D60-\u0D63\u0D66-\u0D6F\u0D7A-\u0D7F\u0D82\u0D83\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DF2\u0DF3\u0E01-\u0E3A\u0E40-\u0E4E\u0E50-\u0E59\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB9\u0EBB-\u0EBD\u0EC0-\u0EC4\u0EC6\u0EC8-\u0ECD\u0ED0-\u0ED9\u0EDC-\u0EDF\u0F00\u0F18\u0F19\u0F20-\u0F29\u0F35\u0F37\u0F39\u0F3E-\u0F47\u0F49-\u0F6C\u0F71-\u0F84\u0F86-\u0F97\u0F99-\u0FBC\u0FC6\u1000-\u1049\u1050-\u109D\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u135D-\u135F\u1380-\u138F\u13A0-\u13F4\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F0\u1700-\u170C\u170E-\u1714\u1720-\u1734\u1740-\u1753\u1760-\u176C\u176E-\u1770\u1772\u1773\u1780-\u17D3\u17D7\u17DC\u17DD\u17E0-\u17E9\u180B-\u180D\u1810-\u1819\u1820-\u1877\u1880-\u18AA\u18B0-\u18F5\u1900-\u191C\u1920-\u192B\u1930-\u193B\u1946-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u19D0-\u19D9\u1A00-\u1A1B\u1A20-\u1A5E\u1A60-\u1A7C\u1A7F-\u1A89\u1A90-\u1A99\u1AA7\u1B00-\u1B4B\u1B50-\u1B59\u1B6B-\u1B73\u1B80-\u1BF3\u1C00-\u1C37\u1C40-\u1C49\u1C4D-\u1C7D\u1CD0-\u1CD2\u1CD4-\u1CF6\u1D00-\u1DE6\u1DFC-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u200C\u200D\u203F\u2040\u2054\u2071\u207F\u2090-\u209C\u20D0-\u20DC\u20E1\u20E5-\u20F0\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D7F-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2DE0-\u2DFF\u2E2F\u3005-\u3007\u3021-\u302F\u3031-\u3035\u3038-\u303C\u3041-\u3096\u3099\u309A\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FCC\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA62B\uA640-\uA66F\uA674-\uA67D\uA67F-\uA697\uA69F-\uA6F1\uA717-\uA71F\uA722-\uA788\uA78B-\uA78E\uA790-\uA793\uA7A0-\uA7AA\uA7F8-\uA827\uA840-\uA873\uA880-\uA8C4\uA8D0-\uA8D9\uA8E0-\uA8F7\uA8FB\uA900-\uA92D\uA930-\uA953\uA960-\uA97C\uA980-\uA9C0\uA9CF-\uA9D9\uAA00-\uAA36\uAA40-\uAA4D\uAA50-\uAA59\uAA60-\uAA76\uAA7A\uAA7B\uAA80-\uAAC2\uAADB-\uAADD\uAAE0-\uAAEF\uAAF2-\uAAF6\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uABC0-\uABEA\uABEC\uABED\uABF0-\uABF9\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE00-\uFE0F\uFE20-\uFE26\uFE33\uFE34\uFE4D-\uFE4F\uFE70-\uFE74\uFE76-\uFEFC\uFF10-\uFF19\uFF21-\uFF3A\uFF3F\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]')
            };

            // Ensure the condition is true, otherwise throw an error.
            // This is only to have a better contract semantic, i.e. another safety net
            // to catch a logic error. The condition shall be fulfilled in normal case.
            // Do NOT use this to enforce a certain condition on any user input.

            function assert(condition, message) {
              /* istanbul ignore if */
              if (!condition) {
                throw new Error('ASSERT: ' + message);
              }
            }
            function isDecimalDigit(ch) {
              return ch >= 48 && ch <= 57; // 0..9
            }
            function isHexDigit(ch) {
              return '0123456789abcdefABCDEF'.indexOf(ch) >= 0;
            }
            function isOctalDigit(ch) {
              return '01234567'.indexOf(ch) >= 0;
            }

            // 7.2 White Space

            function isWhiteSpace(ch) {
              return ch === 0x20 || ch === 0x09 || ch === 0x0B || ch === 0x0C || ch === 0xA0 || ch >= 0x1680 && [0x1680, 0x180E, 0x2000, 0x2001, 0x2002, 0x2003, 0x2004, 0x2005, 0x2006, 0x2007, 0x2008, 0x2009, 0x200A, 0x202F, 0x205F, 0x3000, 0xFEFF].indexOf(ch) >= 0;
            }

            // 7.3 Line Terminators

            function isLineTerminator(ch) {
              return ch === 0x0A || ch === 0x0D || ch === 0x2028 || ch === 0x2029;
            }

            // 7.6 Identifier Names and Identifiers

            function isIdentifierStart(ch) {
              return ch == 0x40 || ch === 0x24 || ch === 0x5F ||
              // $ (dollar) and _ (underscore)
              ch >= 0x41 && ch <= 0x5A ||
              // A..Z
              ch >= 0x61 && ch <= 0x7A ||
              // a..z
              ch === 0x5C ||
              // \ (backslash)
              ch >= 0x80 && Regex.NonAsciiIdentifierStart.test(String.fromCharCode(ch));
            }
            function isIdentifierPart(ch) {
              return ch === 0x24 || ch === 0x5F ||
              // $ (dollar) and _ (underscore)
              ch >= 0x41 && ch <= 0x5A ||
              // A..Z
              ch >= 0x61 && ch <= 0x7A ||
              // a..z
              ch >= 0x30 && ch <= 0x39 ||
              // 0..9
              ch === 0x5C ||
              // \ (backslash)
              ch >= 0x80 && Regex.NonAsciiIdentifierPart.test(String.fromCharCode(ch));
            }

            // 7.6.1.2 Future Reserved Words

            function isFutureReservedWord(id) {
              switch (id) {
                case 'class':
                case 'enum':
                case 'export':
                case 'extends':
                case 'import':
                case 'super':
                  return true;
                default:
                  return false;
              }
            }
            function isStrictModeReservedWord(id) {
              switch (id) {
                case 'implements':
                case 'interface':
                case 'package':
                case 'private':
                case 'protected':
                case 'public':
                case 'static':
                case 'yield':
                case 'let':
                  return true;
                default:
                  return false;
              }
            }
            function isRestrictedWord(id) {
              return id === 'eval' || id === 'arguments';
            }

            // 7.6.1.1 Keywords

            function isKeyword(id) {
              if (strict && isStrictModeReservedWord(id)) {
                return true;
              }

              // 'const' is specialized as Keyword in V8.
              // 'yield' and 'let' are for compatiblity with SpiderMonkey and ES.next.
              // Some others are from future reserved words.

              switch (id.length) {
                case 2:
                  return id === 'if' || id === 'in' || id === 'do';
                case 3:
                  return id === 'var' || id === 'for' || id === 'new' || id === 'try' || id === 'let';
                case 4:
                  return id === 'this' || id === 'else' || id === 'case' || id === 'void' || id === 'with' || id === 'enum';
                case 5:
                  return id === 'while' || id === 'break' || id === 'catch' || id === 'throw' || id === 'const' || id === 'yield' || id === 'class' || id === 'super';
                case 6:
                  return id === 'return' || id === 'typeof' || id === 'delete' || id === 'switch' || id === 'export' || id === 'import';
                case 7:
                  return id === 'default' || id === 'finally' || id === 'extends';
                case 8:
                  return id === 'function' || id === 'continue' || id === 'debugger';
                case 10:
                  return id === 'instanceof';
                default:
                  return false;
              }
            }

            // 7.4 Comments

            function addComment(type, value, start, end, loc) {
              var comment;
              assert(typeof start === 'number', 'Comment must have valid position');

              // Because the way the actual token is scanned, often the comments
              // (if any) are skipped twice during the lexical analysis.
              // Thus, we need to skip adding a comment if the comment array already
              // handled it.
              if (state.lastCommentStart >= start) {
                return;
              }
              state.lastCommentStart = start;
              comment = {
                type: type,
                value: value
              };
              if (extra.range) {
                comment.range = [start, end];
              }
              if (extra.loc) {
                comment.loc = loc;
              }
              extra.comments.push(comment);
              if (extra.attachComment) {
                extra.leadingComments.push(comment);
                extra.trailingComments.push(comment);
              }
            }
            function skipSingleLineComment(offset) {
              var start, loc, ch, comment;
              start = index - offset;
              loc = {
                start: {
                  line: lineNumber,
                  column: index - lineStart - offset
                }
              };
              while (index < length) {
                ch = source.charCodeAt(index);
                ++index;
                if (isLineTerminator(ch)) {
                  if (extra.comments) {
                    comment = source.slice(start + offset, index - 1);
                    loc.end = {
                      line: lineNumber,
                      column: index - lineStart - 1
                    };
                    addComment('Line', comment, start, index - 1, loc);
                  }
                  if (ch === 13 && source.charCodeAt(index) === 10) {
                    ++index;
                  }
                  ++lineNumber;
                  lineStart = index;
                  return;
                }
              }
              if (extra.comments) {
                comment = source.slice(start + offset, index);
                loc.end = {
                  line: lineNumber,
                  column: index - lineStart
                };
                addComment('Line', comment, start, index, loc);
              }
            }
            function skipMultiLineComment() {
              var start, loc, ch, comment;
              if (extra.comments) {
                start = index - 2;
                loc = {
                  start: {
                    line: lineNumber,
                    column: index - lineStart - 2
                  }
                };
              }
              while (index < length) {
                ch = source.charCodeAt(index);
                if (isLineTerminator(ch)) {
                  if (ch === 0x0D && source.charCodeAt(index + 1) === 0x0A) {
                    ++index;
                  }
                  ++lineNumber;
                  ++index;
                  lineStart = index;
                  if (index >= length) {
                    throwError({}, Messages.UnexpectedToken, 'ILLEGAL');
                  }
                } else if (ch === 0x2A) {
                  // Block comment ends with '*/'.
                  if (source.charCodeAt(index + 1) === 0x2F) {
                    ++index;
                    ++index;
                    if (extra.comments) {
                      comment = source.slice(start + 2, index - 2);
                      loc.end = {
                        line: lineNumber,
                        column: index - lineStart
                      };
                      addComment('Block', comment, start, index, loc);
                    }
                    return;
                  }
                  ++index;
                } else {
                  ++index;
                }
              }
              throwError({}, Messages.UnexpectedToken, 'ILLEGAL');
            }
            function skipComment() {
              var ch, start;
              start = index === 0;
              while (index < length) {
                ch = source.charCodeAt(index);
                if (isWhiteSpace(ch)) {
                  ++index;
                } else if (isLineTerminator(ch)) {
                  ++index;
                  if (ch === 0x0D && source.charCodeAt(index) === 0x0A) {
                    ++index;
                  }
                  ++lineNumber;
                  lineStart = index;
                  start = true;
                } else if (ch === 0x2F) {
                  // U+002F is '/'
                  ch = source.charCodeAt(index + 1);
                  if (ch === 0x2F) {
                    ++index;
                    ++index;
                    skipSingleLineComment(2);
                    start = true;
                  } else if (ch === 0x2A) {
                    // U+002A is '*'
                    ++index;
                    ++index;
                    skipMultiLineComment();
                  } else {
                    break;
                  }
                } else if (start && ch === 0x2D) {
                  // U+002D is '-'
                  // U+003E is '>'
                  if (source.charCodeAt(index + 1) === 0x2D && source.charCodeAt(index + 2) === 0x3E) {
                    // '-->' is a single-line comment
                    index += 3;
                    skipSingleLineComment(3);
                  } else {
                    break;
                  }
                } else if (ch === 0x3C) {
                  // U+003C is '<'
                  if (source.slice(index + 1, index + 4) === '!--') {
                    ++index; // `<`
                    ++index; // `!`
                    ++index; // `-`
                    ++index; // `-`
                    skipSingleLineComment(4);
                  } else {
                    break;
                  }
                } else {
                  break;
                }
              }
            }
            function scanHexEscape(prefix) {
              var i,
                len,
                ch,
                code = 0;
              len = prefix === 'u' ? 4 : 2;
              for (i = 0; i < len; ++i) {
                if (index < length && isHexDigit(source[index])) {
                  ch = source[index++];
                  code = code * 16 + '0123456789abcdef'.indexOf(ch.toLowerCase());
                } else {
                  return '';
                }
              }
              return String.fromCharCode(code);
            }
            function getEscapedIdentifier() {
              var ch, id;
              ch = source.charCodeAt(index++);
              id = String.fromCharCode(ch);

              // '\u' (U+005C, U+0075) denotes an escaped character.
              if (ch === 0x5C) {
                if (source.charCodeAt(index) !== 0x75) {
                  throwError({}, Messages.UnexpectedToken, 'ILLEGAL');
                }
                ++index;
                ch = scanHexEscape('u');
                if (!ch || ch === '\\' || !isIdentifierStart(ch.charCodeAt(0))) {
                  throwError({}, Messages.UnexpectedToken, 'ILLEGAL');
                }
                id = ch;
              }
              while (index < length) {
                ch = source.charCodeAt(index);
                if (!isIdentifierPart(ch)) {
                  break;
                }
                ++index;
                id += String.fromCharCode(ch);

                // '\u' (U+005C, U+0075) denotes an escaped character.
                if (ch === 0x5C) {
                  id = id.substr(0, id.length - 1);
                  if (source.charCodeAt(index) !== 0x75) {
                    throwError({}, Messages.UnexpectedToken, 'ILLEGAL');
                  }
                  ++index;
                  ch = scanHexEscape('u');
                  if (!ch || ch === '\\' || !isIdentifierPart(ch.charCodeAt(0))) {
                    throwError({}, Messages.UnexpectedToken, 'ILLEGAL');
                  }
                  id += ch;
                }
              }
              return id;
            }
            function getIdentifier() {
              var start, ch;
              start = index++;
              while (index < length) {
                ch = source.charCodeAt(index);
                if (ch === 0x5C) {
                  // Blackslash (U+005C) marks Unicode escape sequence.
                  index = start;
                  return getEscapedIdentifier();
                }
                if (isIdentifierPart(ch)) {
                  ++index;
                } else {
                  break;
                }
              }
              return source.slice(start, index);
            }
            function scanIdentifier() {
              var start, id, type;
              start = index;

              // Backslash (U+005C) starts an escaped character.
              id = source.charCodeAt(index) === 0x5C ? getEscapedIdentifier() : getIdentifier();

              // There is no keyword or literal with only one character.
              // Thus, it must be an identifier.
              if (id.length === 1) {
                type = Token.Identifier;
              } else if (isKeyword(id)) {
                type = Token.Keyword;
              } else if (id === 'null') {
                type = Token.NullLiteral;
              } else if (id === 'true' || id === 'false') {
                type = Token.BooleanLiteral;
              } else {
                type = Token.Identifier;
              }
              return {
                type: type,
                value: id,
                lineNumber: lineNumber,
                lineStart: lineStart,
                start: start,
                end: index
              };
            }

            // 7.7 Punctuators

            function scanPunctuator() {
              var start = index,
                code = source.charCodeAt(index),
                code2,
                ch1 = source[index],
                ch2,
                ch3,
                ch4;
              switch (code) {
                // Check for most common single-character punctuators.
                case 0x2E: // . dot
                case 0x28: // ( open bracket
                case 0x29: // ) close bracket
                case 0x3B: // ; semicolon
                case 0x2C: // , comma
                case 0x7B: // { open curly brace
                case 0x7D: // } close curly brace
                case 0x5B: // [
                case 0x5D: // ]
                case 0x3A: // :
                case 0x3F: // ?
                case 0x7E:
                  // ~
                  ++index;
                  if (extra.tokenize) {
                    if (code === 0x28) {
                      extra.openParenToken = extra.tokens.length;
                    } else if (code === 0x7B) {
                      extra.openCurlyToken = extra.tokens.length;
                    }
                  }
                  return {
                    type: Token.Punctuator,
                    value: String.fromCharCode(code),
                    lineNumber: lineNumber,
                    lineStart: lineStart,
                    start: start,
                    end: index
                  };
                default:
                  code2 = source.charCodeAt(index + 1);

                  // '=' (U+003D) marks an assignment or comparison operator.
                  if (code2 === 0x3D) {
                    switch (code) {
                      case 0x2B: // +
                      case 0x2D: // -
                      case 0x2F: // /
                      case 0x3C: // <
                      case 0x3E: // >
                      case 0x5E: // ^
                      case 0x7C: // |
                      case 0x25: // %
                      case 0x26: // &
                      case 0x2A:
                        // *
                        index += 2;
                        return {
                          type: Token.Punctuator,
                          value: String.fromCharCode(code) + String.fromCharCode(code2),
                          lineNumber: lineNumber,
                          lineStart: lineStart,
                          start: start,
                          end: index
                        };
                      case 0x21: // !
                      case 0x3D:
                        // =
                        index += 2;

                        // !== and ===
                        if (source.charCodeAt(index) === 0x3D) {
                          ++index;
                        }
                        return {
                          type: Token.Punctuator,
                          value: source.slice(start, index),
                          lineNumber: lineNumber,
                          lineStart: lineStart,
                          start: start,
                          end: index
                        };
                    }
                  }
              }

              // 4-character punctuator: >>>=

              ch4 = source.substr(index, 4);
              if (ch4 === '>>>=') {
                index += 4;
                return {
                  type: Token.Punctuator,
                  value: ch4,
                  lineNumber: lineNumber,
                  lineStart: lineStart,
                  start: start,
                  end: index
                };
              }

              // 3-character punctuators: === !== >>> <<= >>=

              ch3 = ch4.substr(0, 3);
              if (ch3 === '>>>' || ch3 === '<<=' || ch3 === '>>=') {
                index += 3;
                return {
                  type: Token.Punctuator,
                  value: ch3,
                  lineNumber: lineNumber,
                  lineStart: lineStart,
                  start: start,
                  end: index
                };
              }

              // Other 2-character punctuators: ++ -- << >> && ||
              ch2 = ch3.substr(0, 2);
              if (ch1 === ch2[1] && '+-<>&|'.indexOf(ch1) >= 0 || ch2 === '=>') {
                index += 2;
                return {
                  type: Token.Punctuator,
                  value: ch2,
                  lineNumber: lineNumber,
                  lineStart: lineStart,
                  start: start,
                  end: index
                };
              }

              // 1-character punctuators: < > = ! + - * % & | ^ /
              if ('<>=!+-*%&|^/'.indexOf(ch1) >= 0) {
                ++index;
                return {
                  type: Token.Punctuator,
                  value: ch1,
                  lineNumber: lineNumber,
                  lineStart: lineStart,
                  start: start,
                  end: index
                };
              }
              throwError({}, Messages.UnexpectedToken, 'ILLEGAL');
            }

            // 7.8.3 Numeric Literals

            function scanHexLiteral(start) {
              var number = '';
              while (index < length) {
                if (!isHexDigit(source[index])) {
                  break;
                }
                number += source[index++];
              }
              if (number.length === 0) {
                throwError({}, Messages.UnexpectedToken, 'ILLEGAL');
              }
              if (isIdentifierStart(source.charCodeAt(index))) {
                throwError({}, Messages.UnexpectedToken, 'ILLEGAL');
              }
              return {
                type: Token.NumericLiteral,
                value: parseInt('0x' + number, 16),
                lineNumber: lineNumber,
                lineStart: lineStart,
                start: start,
                end: index
              };
            }
            function scanOctalLiteral(start) {
              var number = '0' + source[index++];
              while (index < length) {
                if (!isOctalDigit(source[index])) {
                  break;
                }
                number += source[index++];
              }
              if (isIdentifierStart(source.charCodeAt(index)) || isDecimalDigit(source.charCodeAt(index))) {
                throwError({}, Messages.UnexpectedToken, 'ILLEGAL');
              }
              return {
                type: Token.NumericLiteral,
                value: parseInt(number, 8),
                octal: true,
                lineNumber: lineNumber,
                lineStart: lineStart,
                start: start,
                end: index
              };
            }
            function scanNumericLiteral() {
              var number, start, ch;
              ch = source[index];
              assert(isDecimalDigit(ch.charCodeAt(0)) || ch === '.', 'Numeric literal must start with a decimal digit or a decimal point');
              start = index;
              number = '';
              if (ch !== '.') {
                number = source[index++];
                ch = source[index];

                // Hex number starts with '0x'.
                // Octal number starts with '0'.
                if (number === '0') {
                  if (ch === 'x' || ch === 'X') {
                    ++index;
                    return scanHexLiteral(start);
                  }
                  if (isOctalDigit(ch)) {
                    return scanOctalLiteral(start);
                  }

                  // decimal number starts with '0' such as '09' is illegal.
                  if (ch && isDecimalDigit(ch.charCodeAt(0))) {
                    throwError({}, Messages.UnexpectedToken, 'ILLEGAL');
                  }
                }
                while (isDecimalDigit(source.charCodeAt(index))) {
                  number += source[index++];
                }
                ch = source[index];
              }
              if (ch === '.') {
                number += source[index++];
                while (isDecimalDigit(source.charCodeAt(index))) {
                  number += source[index++];
                }
                ch = source[index];
              }
              if (ch === 'e' || ch === 'E') {
                number += source[index++];
                ch = source[index];
                if (ch === '+' || ch === '-') {
                  number += source[index++];
                }
                if (isDecimalDigit(source.charCodeAt(index))) {
                  while (isDecimalDigit(source.charCodeAt(index))) {
                    number += source[index++];
                  }
                } else {
                  throwError({}, Messages.UnexpectedToken, 'ILLEGAL');
                }
              }
              if (isIdentifierStart(source.charCodeAt(index))) {
                throwError({}, Messages.UnexpectedToken, 'ILLEGAL');
              }
              return {
                type: Token.NumericLiteral,
                value: parseFloat(number),
                lineNumber: lineNumber,
                lineStart: lineStart,
                start: start,
                end: index
              };
            }

            // 7.8.4 String Literals

            function scanStringLiteral() {
              var str = '',
                quote,
                start,
                ch,
                code,
                unescaped,
                restore,
                octal = false,
                startLineNumber,
                startLineStart;
              startLineNumber = lineNumber;
              startLineStart = lineStart;
              quote = source[index];
              assert(quote === '\'' || quote === '"', 'String literal must starts with a quote');
              start = index;
              ++index;
              while (index < length) {
                ch = source[index++];
                if (ch === quote) {
                  quote = '';
                  break;
                } else if (ch === '\\') {
                  ch = source[index++];
                  if (!ch || !isLineTerminator(ch.charCodeAt(0))) {
                    switch (ch) {
                      case 'u':
                      case 'x':
                        restore = index;
                        unescaped = scanHexEscape(ch);
                        if (unescaped) {
                          str += unescaped;
                        } else {
                          index = restore;
                          str += ch;
                        }
                        break;
                      case 'n':
                        str += '\n';
                        break;
                      case 'r':
                        str += '\r';
                        break;
                      case 't':
                        str += '\t';
                        break;
                      case 'b':
                        str += '\b';
                        break;
                      case 'f':
                        str += '\f';
                        break;
                      case 'v':
                        str += '\x0B';
                        break;
                      default:
                        if (isOctalDigit(ch)) {
                          code = '01234567'.indexOf(ch);

                          // \0 is not octal escape sequence
                          if (code !== 0) {
                            octal = true;
                          }
                          if (index < length && isOctalDigit(source[index])) {
                            octal = true;
                            code = code * 8 + '01234567'.indexOf(source[index++]);

                            // 3 digits are only allowed when string starts
                            // with 0, 1, 2, 3
                            if ('0123'.indexOf(ch) >= 0 && index < length && isOctalDigit(source[index])) {
                              code = code * 8 + '01234567'.indexOf(source[index++]);
                            }
                          }
                          str += String.fromCharCode(code);
                        } else {
                          str += ch;
                        }
                        break;
                    }
                  } else {
                    ++lineNumber;
                    if (ch === '\r' && source[index] === '\n') {
                      ++index;
                    }
                    lineStart = index;
                  }
                } else if (isLineTerminator(ch.charCodeAt(0))) {
                  break;
                } else {
                  str += ch;
                }
              }
              if (quote !== '') {
                throwError({}, Messages.UnexpectedToken, 'ILLEGAL');
              }
              return {
                type: Token.StringLiteral,
                value: str,
                octal: octal,
                startLineNumber: startLineNumber,
                startLineStart: startLineStart,
                lineNumber: lineNumber,
                lineStart: lineStart,
                start: start,
                end: index
              };
            }
            function testRegExp(pattern, flags) {
              var value;
              try {
                value = new RegExp(pattern, flags);
              } catch (e) {
                throwError({}, Messages.InvalidRegExp);
              }
              return value;
            }
            function scanRegExpBody() {
              var ch, str, classMarker, terminated, body;
              ch = source[index];
              assert(ch === '/', 'Regular expression literal must start with a slash');
              str = source[index++];
              classMarker = false;
              terminated = false;
              while (index < length) {
                ch = source[index++];
                str += ch;
                if (ch === '\\') {
                  ch = source[index++];
                  // ECMA-262 7.8.5
                  if (isLineTerminator(ch.charCodeAt(0))) {
                    throwError({}, Messages.UnterminatedRegExp);
                  }
                  str += ch;
                } else if (isLineTerminator(ch.charCodeAt(0))) {
                  throwError({}, Messages.UnterminatedRegExp);
                } else if (classMarker) {
                  if (ch === ']') {
                    classMarker = false;
                  }
                } else {
                  if (ch === '/') {
                    terminated = true;
                    break;
                  } else if (ch === '[') {
                    classMarker = true;
                  }
                }
              }
              if (!terminated) {
                throwError({}, Messages.UnterminatedRegExp);
              }

              // Exclude leading and trailing slash.
              body = str.substr(1, str.length - 2);
              return {
                value: body,
                literal: str
              };
            }
            function scanRegExpFlags() {
              var ch, str, flags, restore;
              str = '';
              flags = '';
              while (index < length) {
                ch = source[index];
                if (!isIdentifierPart(ch.charCodeAt(0))) {
                  break;
                }
                ++index;
                if (ch === '\\' && index < length) {
                  ch = source[index];
                  if (ch === 'u') {
                    ++index;
                    restore = index;
                    ch = scanHexEscape('u');
                    if (ch) {
                      flags += ch;
                      for (str += '\\u'; restore < index; ++restore) {
                        str += source[restore];
                      }
                    } else {
                      index = restore;
                      flags += 'u';
                      str += '\\u';
                    }
                    throwErrorTolerant({}, Messages.UnexpectedToken, 'ILLEGAL');
                  } else {
                    str += '\\';
                    throwErrorTolerant({}, Messages.UnexpectedToken, 'ILLEGAL');
                  }
                } else {
                  flags += ch;
                  str += ch;
                }
              }
              return {
                value: flags,
                literal: str
              };
            }
            function scanRegExp() {
              var start, body, flags, value;
              lookahead = null;
              skipComment();
              start = index;
              body = scanRegExpBody();
              flags = scanRegExpFlags();
              value = testRegExp(body.value, flags.value);
              if (extra.tokenize) {
                return {
                  type: Token.RegularExpression,
                  value: value,
                  lineNumber: lineNumber,
                  lineStart: lineStart,
                  start: start,
                  end: index
                };
              }
              return {
                literal: body.literal + flags.literal,
                value: value,
                start: start,
                end: index
              };
            }
            function collectRegex() {
              var pos, loc, regex, token;
              skipComment();
              pos = index;
              loc = {
                start: {
                  line: lineNumber,
                  column: index - lineStart
                }
              };
              regex = scanRegExp();
              loc.end = {
                line: lineNumber,
                column: index - lineStart
              };

              /* istanbul ignore next */
              if (!extra.tokenize) {
                // Pop the previous token, which is likely '/' or '/='
                if (extra.tokens.length > 0) {
                  token = extra.tokens[extra.tokens.length - 1];
                  if (token.range[0] === pos && token.type === 'Punctuator') {
                    if (token.value === '/' || token.value === '/=') {
                      extra.tokens.pop();
                    }
                  }
                }
                extra.tokens.push({
                  type: 'RegularExpression',
                  value: regex.literal,
                  range: [pos, index],
                  loc: loc
                });
              }
              return regex;
            }
            function isIdentifierName(token) {
              return token.type === Token.Identifier || token.type === Token.Keyword || token.type === Token.BooleanLiteral || token.type === Token.NullLiteral;
            }
            function advanceSlash() {
              var prevToken, checkToken;
              // Using the following algorithm:
              // https://github.com/mozilla/sweet.js/wiki/design
              prevToken = extra.tokens[extra.tokens.length - 1];
              if (!prevToken) {
                // Nothing before that: it cannot be a division.
                return collectRegex();
              }
              if (prevToken.type === 'Punctuator') {
                if (prevToken.value === ']') {
                  return scanPunctuator();
                }
                if (prevToken.value === ')') {
                  checkToken = extra.tokens[extra.openParenToken - 1];
                  if (checkToken && checkToken.type === 'Keyword' && (checkToken.value === 'if' || checkToken.value === 'while' || checkToken.value === 'for' || checkToken.value === 'with')) {
                    return collectRegex();
                  }
                  return scanPunctuator();
                }
                if (prevToken.value === '}') {
                  // Dividing a function by anything makes little sense,
                  // but we have to check for that.
                  if (extra.tokens[extra.openCurlyToken - 3] && extra.tokens[extra.openCurlyToken - 3].type === 'Keyword') {
                    // Anonymous function.
                    checkToken = extra.tokens[extra.openCurlyToken - 4];
                    if (!checkToken) {
                      return scanPunctuator();
                    }
                  } else if (extra.tokens[extra.openCurlyToken - 4] && extra.tokens[extra.openCurlyToken - 4].type === 'Keyword') {
                    // Named function.
                    checkToken = extra.tokens[extra.openCurlyToken - 5];
                    if (!checkToken) {
                      return collectRegex();
                    }
                  } else {
                    return scanPunctuator();
                  }
                  // checkToken determines whether the function is
                  // a declaration or an expression.
                  if (FnExprTokens.indexOf(checkToken.value) >= 0) {
                    // It is an expression.
                    return scanPunctuator();
                  }
                  // It is a declaration.
                  return collectRegex();
                }
                return collectRegex();
              }
              if (prevToken.type === 'Keyword') {
                return collectRegex();
              }
              return scanPunctuator();
            }
            function advance() {
              var ch;
              skipComment();
              if (index >= length) {
                return {
                  type: Token.EOF,
                  lineNumber: lineNumber,
                  lineStart: lineStart,
                  start: index,
                  end: index
                };
              }
              ch = source.charCodeAt(index);
              if (isIdentifierStart(ch)) {
                return scanIdentifier();
              }

              // Very common: ( and ) and ;
              if (ch === 0x28 || ch === 0x29 || ch === 0x3B) {
                return scanPunctuator();
              }

              // String literal starts with single quote (U+0027) or double quote (U+0022).
              if (ch === 0x27 || ch === 0x22) {
                return scanStringLiteral();
              }

              // Dot (.) U+002E can also start a floating-point number, hence the need
              // to check the next character.
              if (ch === 0x2E) {
                if (isDecimalDigit(source.charCodeAt(index + 1))) {
                  return scanNumericLiteral();
                }
                return scanPunctuator();
              }
              if (isDecimalDigit(ch)) {
                return scanNumericLiteral();
              }

              // Slash (/) U+002F can also start a regex.
              if (extra.tokenize && ch === 0x2F) {
                return advanceSlash();
              }
              return scanPunctuator();
            }
            function collectToken() {
              var loc, token, value;
              skipComment();
              loc = {
                start: {
                  line: lineNumber,
                  column: index - lineStart
                }
              };
              token = advance();
              loc.end = {
                line: lineNumber,
                column: index - lineStart
              };
              if (token.type !== Token.EOF) {
                value = source.slice(token.start, token.end);
                extra.tokens.push({
                  type: TokenName[token.type],
                  value: value,
                  range: [token.start, token.end],
                  loc: loc
                });
              }
              return token;
            }
            function lex() {
              var token;
              token = lookahead;
              index = token.end;
              lineNumber = token.lineNumber;
              lineStart = token.lineStart;
              lookahead = typeof extra.tokens !== 'undefined' ? collectToken() : advance();
              index = token.end;
              lineNumber = token.lineNumber;
              lineStart = token.lineStart;
              return token;
            }
            function peek() {
              var pos, line, start;
              pos = index;
              line = lineNumber;
              start = lineStart;
              lookahead = typeof extra.tokens !== 'undefined' ? collectToken() : advance();
              index = pos;
              lineNumber = line;
              lineStart = start;
            }
            function Position(line, column) {
              this.line = line;
              this.column = column;
            }
            function SourceLocation(startLine, startColumn, line, column) {
              this.start = new Position(startLine, startColumn);
              this.end = new Position(line, column);
            }
            SyntaxTreeDelegate = {
              name: 'SyntaxTree',
              processComment: function (node) {
                var lastChild, trailingComments;
                if (node.type === Syntax.Program) {
                  if (node.body.length > 0) {
                    return;
                  }
                }
                if (extra.trailingComments.length > 0) {
                  if (extra.trailingComments[0].range[0] >= node.range[1]) {
                    trailingComments = extra.trailingComments;
                    extra.trailingComments = [];
                  } else {
                    extra.trailingComments.length = 0;
                  }
                } else {
                  if (extra.bottomRightStack.length > 0 && extra.bottomRightStack[extra.bottomRightStack.length - 1].trailingComments && extra.bottomRightStack[extra.bottomRightStack.length - 1].trailingComments[0].range[0] >= node.range[1]) {
                    trailingComments = extra.bottomRightStack[extra.bottomRightStack.length - 1].trailingComments;
                    delete extra.bottomRightStack[extra.bottomRightStack.length - 1].trailingComments;
                  }
                }

                // Eating the stack.
                while (extra.bottomRightStack.length > 0 && extra.bottomRightStack[extra.bottomRightStack.length - 1].range[0] >= node.range[0]) {
                  lastChild = extra.bottomRightStack.pop();
                }
                if (lastChild) {
                  if (lastChild.leadingComments && lastChild.leadingComments[lastChild.leadingComments.length - 1].range[1] <= node.range[0]) {
                    node.leadingComments = lastChild.leadingComments;
                    delete lastChild.leadingComments;
                  }
                } else if (extra.leadingComments.length > 0 && extra.leadingComments[extra.leadingComments.length - 1].range[1] <= node.range[0]) {
                  node.leadingComments = extra.leadingComments;
                  extra.leadingComments = [];
                }
                if (trailingComments) {
                  node.trailingComments = trailingComments;
                }
                extra.bottomRightStack.push(node);
              },
              markEnd: function (node, startToken) {
                if (extra.range) {
                  node.range = [startToken.start, index];
                }
                if (extra.loc) {
                  node.loc = new SourceLocation(startToken.startLineNumber === undefined ? startToken.lineNumber : startToken.startLineNumber, startToken.start - (startToken.startLineStart === undefined ? startToken.lineStart : startToken.startLineStart), lineNumber, index - lineStart);
                  this.postProcess(node);
                }
                if (extra.attachComment) {
                  this.processComment(node);
                }
                return node;
              },
              postProcess: function (node) {
                if (extra.source) {
                  node.loc.source = extra.source;
                }
                return node;
              },
              createArrayExpression: function (elements) {
                return {
                  type: Syntax.ArrayExpression,
                  elements: elements
                };
              },
              createAssignmentExpression: function (operator, left, right) {
                return {
                  type: Syntax.AssignmentExpression,
                  operator: operator,
                  left: left,
                  right: right
                };
              },
              createBinaryExpression: function (operator, left, right) {
                var type = operator === '||' || operator === '&&' ? Syntax.LogicalExpression : Syntax.BinaryExpression;
                return {
                  type: type,
                  operator: operator,
                  left: left,
                  right: right
                };
              },
              createBlockStatement: function (body) {
                return {
                  type: Syntax.BlockStatement,
                  body: body
                };
              },
              createBreakStatement: function (label) {
                return {
                  type: Syntax.BreakStatement,
                  label: label
                };
              },
              createCallExpression: function (callee, args) {
                return {
                  type: Syntax.CallExpression,
                  callee: callee,
                  'arguments': args
                };
              },
              createCatchClause: function (param, body) {
                return {
                  type: Syntax.CatchClause,
                  param: param,
                  body: body
                };
              },
              createConditionalExpression: function (test, consequent, alternate) {
                return {
                  type: Syntax.ConditionalExpression,
                  test: test,
                  consequent: consequent,
                  alternate: alternate
                };
              },
              createContinueStatement: function (label) {
                return {
                  type: Syntax.ContinueStatement,
                  label: label
                };
              },
              createDebuggerStatement: function () {
                return {
                  type: Syntax.DebuggerStatement
                };
              },
              createDoWhileStatement: function (body, test) {
                return {
                  type: Syntax.DoWhileStatement,
                  body: body,
                  test: test
                };
              },
              createEmptyStatement: function () {
                return {
                  type: Syntax.EmptyStatement
                };
              },
              createExpressionStatement: function (expression) {
                return {
                  type: Syntax.ExpressionStatement,
                  expression: expression
                };
              },
              createForStatement: function (init, test, update, body) {
                return {
                  type: Syntax.ForStatement,
                  init: init,
                  test: test,
                  update: update,
                  body: body
                };
              },
              createForInStatement: function (left, right, body) {
                return {
                  type: Syntax.ForInStatement,
                  left: left,
                  right: right,
                  body: body,
                  each: false
                };
              },
              createFunctionDeclaration: function (id, params, defaults, body) {
                return {
                  type: Syntax.FunctionDeclaration,
                  id: id,
                  params: params,
                  defaults: defaults,
                  body: body,
                  rest: null,
                  generator: false,
                  expression: false
                };
              },
              createFunctionExpression: function (id, params, defaults, body) {
                return {
                  type: Syntax.FunctionExpression,
                  id: id,
                  params: params,
                  defaults: defaults,
                  body: body,
                  rest: null,
                  generator: false,
                  expression: false
                };
              },
              createIdentifier: function (name) {
                return {
                  type: Syntax.Identifier,
                  name: name
                };
              },
              createIfStatement: function (test, consequent, alternate) {
                return {
                  type: Syntax.IfStatement,
                  test: test,
                  consequent: consequent,
                  alternate: alternate
                };
              },
              createLabeledStatement: function (label, body) {
                return {
                  type: Syntax.LabeledStatement,
                  label: label,
                  body: body
                };
              },
              createLiteral: function (token) {
                return {
                  type: Syntax.Literal,
                  value: token.value,
                  raw: source.slice(token.start, token.end)
                };
              },
              createMemberExpression: function (accessor, object, property) {
                return {
                  type: Syntax.MemberExpression,
                  computed: accessor === '[',
                  object: object,
                  property: property
                };
              },
              createNewExpression: function (callee, args) {
                return {
                  type: Syntax.NewExpression,
                  callee: callee,
                  'arguments': args
                };
              },
              createObjectExpression: function (properties) {
                return {
                  type: Syntax.ObjectExpression,
                  properties: properties
                };
              },
              createPostfixExpression: function (operator, argument) {
                return {
                  type: Syntax.UpdateExpression,
                  operator: operator,
                  argument: argument,
                  prefix: false
                };
              },
              createProgram: function (body) {
                return {
                  type: Syntax.Program,
                  body: body
                };
              },
              createProperty: function (kind, key, value) {
                return {
                  type: Syntax.Property,
                  key: key,
                  value: value,
                  kind: kind
                };
              },
              createReturnStatement: function (argument) {
                return {
                  type: Syntax.ReturnStatement,
                  argument: argument
                };
              },
              createSequenceExpression: function (expressions) {
                return {
                  type: Syntax.SequenceExpression,
                  expressions: expressions
                };
              },
              createSwitchCase: function (test, consequent) {
                return {
                  type: Syntax.SwitchCase,
                  test: test,
                  consequent: consequent
                };
              },
              createSwitchStatement: function (discriminant, cases) {
                return {
                  type: Syntax.SwitchStatement,
                  discriminant: discriminant,
                  cases: cases
                };
              },
              createThisExpression: function () {
                return {
                  type: Syntax.ThisExpression
                };
              },
              createThrowStatement: function (argument) {
                return {
                  type: Syntax.ThrowStatement,
                  argument: argument
                };
              },
              createTryStatement: function (block, guardedHandlers, handlers, finalizer) {
                return {
                  type: Syntax.TryStatement,
                  block: block,
                  guardedHandlers: guardedHandlers,
                  handlers: handlers,
                  finalizer: finalizer
                };
              },
              createUnaryExpression: function (operator, argument) {
                if (operator === '++' || operator === '--') {
                  return {
                    type: Syntax.UpdateExpression,
                    operator: operator,
                    argument: argument,
                    prefix: true
                  };
                }
                return {
                  type: Syntax.UnaryExpression,
                  operator: operator,
                  argument: argument,
                  prefix: true
                };
              },
              createVariableDeclaration: function (declarations, kind) {
                return {
                  type: Syntax.VariableDeclaration,
                  declarations: declarations,
                  kind: kind
                };
              },
              createVariableDeclarator: function (id, init) {
                return {
                  type: Syntax.VariableDeclarator,
                  id: id,
                  init: init
                };
              },
              createWhileStatement: function (test, body) {
                return {
                  type: Syntax.WhileStatement,
                  test: test,
                  body: body
                };
              },
              createWithStatement: function (object, body) {
                return {
                  type: Syntax.WithStatement,
                  object: object,
                  body: body
                };
              }
            };

            // Return true if there is a line terminator before the next token.

            function peekLineTerminator() {
              var pos, line, start, found;
              pos = index;
              line = lineNumber;
              start = lineStart;
              skipComment();
              found = lineNumber !== line;
              index = pos;
              lineNumber = line;
              lineStart = start;
              return found;
            }

            // Throw an exception

            function throwError(token, messageFormat) {
              var error,
                args = Array.prototype.slice.call(arguments, 2),
                msg = messageFormat.replace(/%(\d)/g, function (whole, index) {
                  assert(index < args.length, 'Message reference must be in range');
                  return args[index];
                });
              if (typeof token.lineNumber === 'number') {
                error = new Error('Line ' + token.lineNumber + ': ' + msg);
                error.index = token.start;
                error.lineNumber = token.lineNumber;
                error.column = token.start - lineStart + 1;
              } else {
                error = new Error('Line ' + lineNumber + ': ' + msg);
                error.index = index;
                error.lineNumber = lineNumber;
                error.column = index - lineStart + 1;
              }
              error.description = msg;
              throw error;
            }
            function throwErrorTolerant() {
              try {
                throwError.apply(null, arguments);
              } catch (e) {
                if (extra.errors) {
                  extra.errors.push(e);
                } else {
                  throw e;
                }
              }
            }

            // Throw an exception because of the token.

            function throwUnexpected(token) {
              if (token.type === Token.EOF) {
                throwError(token, Messages.UnexpectedEOS);
              }
              if (token.type === Token.NumericLiteral) {
                throwError(token, Messages.UnexpectedNumber);
              }
              if (token.type === Token.StringLiteral) {
                throwError(token, Messages.UnexpectedString);
              }
              if (token.type === Token.Identifier) {
                throwError(token, Messages.UnexpectedIdentifier);
              }
              if (token.type === Token.Keyword) {
                if (isFutureReservedWord(token.value)) {
                  throwError(token, Messages.UnexpectedReserved);
                } else if (strict && isStrictModeReservedWord(token.value)) {
                  throwErrorTolerant(token, Messages.StrictReservedWord);
                  return;
                }
                throwError(token, Messages.UnexpectedToken, token.value);
              }

              // BooleanLiteral, NullLiteral, or Punctuator.
              throwError(token, Messages.UnexpectedToken, token.value);
            }

            // Expect the next token to match the specified punctuator.
            // If not, an exception will be thrown.

            function expect(value) {
              var token = lex();
              if (token.type !== Token.Punctuator || token.value !== value) {
                throwUnexpected(token);
              }
            }

            // Expect the next token to match the specified keyword.
            // If not, an exception will be thrown.

            function expectKeyword(keyword) {
              var token = lex();
              if (token.type !== Token.Keyword || token.value !== keyword) {
                throwUnexpected(token);
              }
            }

            // Return true if the next token matches the specified punctuator.

            function match(value) {
              return lookahead.type === Token.Punctuator && lookahead.value === value;
            }

            // Return true if the next token matches the specified keyword

            function matchKeyword(keyword) {
              return lookahead.type === Token.Keyword && lookahead.value === keyword;
            }

            // Return true if the next token is an assignment operator

            function matchAssign() {
              var op;
              if (lookahead.type !== Token.Punctuator) {
                return false;
              }
              op = lookahead.value;
              return op === '=' || op === '*=' || op === '/=' || op === '%=' || op === '+=' || op === '-=' || op === '<<=' || op === '>>=' || op === '>>>=' || op === '&=' || op === '^=' || op === '|=';
            }
            function consumeSemicolon() {
              var line;

              // Catch the very common case first: immediately a semicolon (U+003B).
              if (source.charCodeAt(index) === 0x3B || match(';')) {
                lex();
                return;
              }
              line = lineNumber;
              skipComment();
              if (lineNumber !== line) {
                return;
              }
              if (lookahead.type !== Token.EOF && !match('}')) {
                throwUnexpected(lookahead);
              }
            }

            // Return true if provided expression is LeftHandSideExpression

            function isLeftHandSide(expr) {
              return expr.type === Syntax.Identifier || expr.type === Syntax.MemberExpression;
            }

            // 11.1.4 Array Initialiser

            function parseArrayInitialiser() {
              var elements = [],
                startToken;
              startToken = lookahead;
              expect('[');
              while (!match(']')) {
                if (match(',')) {
                  lex();
                  elements.push(null);
                } else {
                  elements.push(parseAssignmentExpression());
                  if (!match(']')) {
                    expect(',');
                  }
                }
              }
              lex();
              return delegate.markEnd(delegate.createArrayExpression(elements), startToken);
            }

            // 11.1.5 Object Initialiser

            function parsePropertyFunction(param, first) {
              var previousStrict, body, startToken;
              previousStrict = strict;
              startToken = lookahead;
              body = parseFunctionSourceElements();
              if (first && strict && isRestrictedWord(param[0].name)) {
                throwErrorTolerant(first, Messages.StrictParamName);
              }
              strict = previousStrict;
              return delegate.markEnd(delegate.createFunctionExpression(null, param, [], body), startToken);
            }
            function parseObjectPropertyKey() {
              var token, startToken;
              startToken = lookahead;
              token = lex();

              // Note: This function is called only from parseObjectProperty(), where
              // EOF and Punctuator tokens are already filtered out.

              if (token.type === Token.StringLiteral || token.type === Token.NumericLiteral) {
                if (strict && token.octal) {
                  throwErrorTolerant(token, Messages.StrictOctalLiteral);
                }
                return delegate.markEnd(delegate.createLiteral(token), startToken);
              }
              return delegate.markEnd(delegate.createIdentifier(token.value), startToken);
            }
            function parseObjectProperty() {
              var token, key, id, value, param, startToken;
              token = lookahead;
              startToken = lookahead;
              if (token.type === Token.Identifier) {
                id = parseObjectPropertyKey();

                // Property Assignment: Getter and Setter.

                if (token.value === 'get' && !match(':')) {
                  key = parseObjectPropertyKey();
                  expect('(');
                  expect(')');
                  value = parsePropertyFunction([]);
                  return delegate.markEnd(delegate.createProperty('get', key, value), startToken);
                }
                if (token.value === 'set' && !match(':')) {
                  key = parseObjectPropertyKey();
                  expect('(');
                  token = lookahead;
                  if (token.type !== Token.Identifier) {
                    expect(')');
                    throwErrorTolerant(token, Messages.UnexpectedToken, token.value);
                    value = parsePropertyFunction([]);
                  } else {
                    param = [parseVariableIdentifier()];
                    expect(')');
                    value = parsePropertyFunction(param, token);
                  }
                  return delegate.markEnd(delegate.createProperty('set', key, value), startToken);
                }
                expect(':');
                value = parseAssignmentExpression();
                return delegate.markEnd(delegate.createProperty('init', id, value), startToken);
              }
              if (token.type === Token.EOF || token.type === Token.Punctuator) {
                throwUnexpected(token);
              } else {
                key = parseObjectPropertyKey();
                expect(':');
                value = parseAssignmentExpression();
                return delegate.markEnd(delegate.createProperty('init', key, value), startToken);
              }
            }
            function parseObjectInitialiser() {
              var properties = [],
                property,
                name,
                key,
                kind,
                map = {},
                toString = String,
                startToken;
              startToken = lookahead;
              expect('{');
              while (!match('}')) {
                property = parseObjectProperty();
                if (property.key.type === Syntax.Identifier) {
                  name = property.key.name;
                } else {
                  name = toString(property.key.value);
                }
                kind = property.kind === 'init' ? PropertyKind.Data : property.kind === 'get' ? PropertyKind.Get : PropertyKind.Set;
                key = '$' + name;
                if (Object.prototype.hasOwnProperty.call(map, key)) {
                  if (map[key] === PropertyKind.Data) {
                    if (strict && kind === PropertyKind.Data) {
                      throwErrorTolerant({}, Messages.StrictDuplicateProperty);
                    } else if (kind !== PropertyKind.Data) {
                      throwErrorTolerant({}, Messages.AccessorDataProperty);
                    }
                  } else {
                    if (kind === PropertyKind.Data) {
                      throwErrorTolerant({}, Messages.AccessorDataProperty);
                    } else if (map[key] & kind) {
                      throwErrorTolerant({}, Messages.AccessorGetSet);
                    }
                  }
                  map[key] |= kind;
                } else {
                  map[key] = kind;
                }
                properties.push(property);
                if (!match('}')) {
                  expect(',');
                }
              }
              expect('}');
              return delegate.markEnd(delegate.createObjectExpression(properties), startToken);
            }

            // 11.1.6 The Grouping Operator

            function parseGroupExpression() {
              var expr;
              expect('(');
              expr = parseExpression();
              expect(')');
              return expr;
            }

            // 11.1 Primary Expressions

            function parsePrimaryExpression() {
              var type, token, expr, startToken;
              if (match('(')) {
                return parseGroupExpression();
              }
              if (match('[')) {
                return parseArrayInitialiser();
              }
              if (match('{')) {
                return parseObjectInitialiser();
              }
              type = lookahead.type;
              startToken = lookahead;
              if (type === Token.Identifier) {
                expr = delegate.createIdentifier(lex().value);
              } else if (type === Token.StringLiteral || type === Token.NumericLiteral) {
                if (strict && lookahead.octal) {
                  throwErrorTolerant(lookahead, Messages.StrictOctalLiteral);
                }
                expr = delegate.createLiteral(lex());
              } else if (type === Token.Keyword) {
                if (matchKeyword('function')) {
                  return parseFunctionExpression();
                }
                if (matchKeyword('this')) {
                  lex();
                  expr = delegate.createThisExpression();
                } else {
                  throwUnexpected(lex());
                }
              } else if (type === Token.BooleanLiteral) {
                token = lex();
                token.value = token.value === 'true';
                expr = delegate.createLiteral(token);
              } else if (type === Token.NullLiteral) {
                token = lex();
                token.value = null;
                expr = delegate.createLiteral(token);
              } else if (match('/') || match('/=')) {
                if (typeof extra.tokens !== 'undefined') {
                  expr = delegate.createLiteral(collectRegex());
                } else {
                  expr = delegate.createLiteral(scanRegExp());
                }
                peek();
              } else {
                throwUnexpected(lex());
              }
              return delegate.markEnd(expr, startToken);
            }

            // 11.2 Left-Hand-Side Expressions

            function parseArguments() {
              var args = [];
              expect('(');
              if (!match(')')) {
                while (index < length) {
                  args.push(parseAssignmentExpression());
                  if (match(')')) {
                    break;
                  }
                  expect(',');
                }
              }
              expect(')');
              return args;
            }
            function parseNonComputedProperty() {
              var token, startToken;
              startToken = lookahead;
              token = lex();
              if (!isIdentifierName(token)) {
                throwUnexpected(token);
              }
              return delegate.markEnd(delegate.createIdentifier(token.value), startToken);
            }
            function parseNonComputedMember() {
              expect('.');
              return parseNonComputedProperty();
            }
            function parseComputedMember() {
              var expr;
              expect('[');
              expr = parseExpression();
              expect(']');
              return expr;
            }
            function parseNewExpression() {
              var callee, args, startToken;
              startToken = lookahead;
              expectKeyword('new');
              callee = parseLeftHandSideExpression();
              args = match('(') ? parseArguments() : [];
              return delegate.markEnd(delegate.createNewExpression(callee, args), startToken);
            }
            function parseLeftHandSideExpressionAllowCall() {
              var previousAllowIn, expr, args, property, startToken;
              startToken = lookahead;
              previousAllowIn = state.allowIn;
              state.allowIn = true;
              expr = matchKeyword('new') ? parseNewExpression() : parsePrimaryExpression();
              state.allowIn = previousAllowIn;
              for (;;) {
                if (match('.')) {
                  property = parseNonComputedMember();
                  expr = delegate.createMemberExpression('.', expr, property);
                } else if (match('(')) {
                  args = parseArguments();
                  expr = delegate.createCallExpression(expr, args);
                } else if (match('[')) {
                  property = parseComputedMember();
                  expr = delegate.createMemberExpression('[', expr, property);
                } else {
                  break;
                }
                delegate.markEnd(expr, startToken);
              }
              return expr;
            }
            function parseLeftHandSideExpression() {
              var previousAllowIn, expr, property, startToken;
              startToken = lookahead;
              previousAllowIn = state.allowIn;
              expr = matchKeyword('new') ? parseNewExpression() : parsePrimaryExpression();
              state.allowIn = previousAllowIn;
              while (match('.') || match('[')) {
                if (match('[')) {
                  property = parseComputedMember();
                  expr = delegate.createMemberExpression('[', expr, property);
                } else {
                  property = parseNonComputedMember();
                  expr = delegate.createMemberExpression('.', expr, property);
                }
                delegate.markEnd(expr, startToken);
              }
              return expr;
            }

            // 11.3 Postfix Expressions

            function parsePostfixExpression() {
              var expr,
                token,
                startToken = lookahead;
              expr = parseLeftHandSideExpressionAllowCall();
              if (lookahead.type === Token.Punctuator) {
                if ((match('++') || match('--')) && !peekLineTerminator()) {
                  // 11.3.1, 11.3.2
                  if (strict && expr.type === Syntax.Identifier && isRestrictedWord(expr.name)) {
                    throwErrorTolerant({}, Messages.StrictLHSPostfix);
                  }
                  if (!isLeftHandSide(expr)) {
                    throwErrorTolerant({}, Messages.InvalidLHSInAssignment);
                  }
                  token = lex();
                  expr = delegate.markEnd(delegate.createPostfixExpression(token.value, expr), startToken);
                }
              }
              return expr;
            }

            // 11.4 Unary Operators

            function parseUnaryExpression() {
              var token, expr, startToken;
              if (lookahead.type !== Token.Punctuator && lookahead.type !== Token.Keyword) {
                expr = parsePostfixExpression();
              } else if (match('++') || match('--')) {
                startToken = lookahead;
                token = lex();
                expr = parseUnaryExpression();
                // 11.4.4, 11.4.5
                if (strict && expr.type === Syntax.Identifier && isRestrictedWord(expr.name)) {
                  throwErrorTolerant({}, Messages.StrictLHSPrefix);
                }
                if (!isLeftHandSide(expr)) {
                  throwErrorTolerant({}, Messages.InvalidLHSInAssignment);
                }
                expr = delegate.createUnaryExpression(token.value, expr);
                expr = delegate.markEnd(expr, startToken);
              } else if (match('+') || match('-') || match('~') || match('!')) {
                startToken = lookahead;
                token = lex();
                expr = parseUnaryExpression();
                expr = delegate.createUnaryExpression(token.value, expr);
                expr = delegate.markEnd(expr, startToken);
              } else if (matchKeyword('delete') || matchKeyword('void') || matchKeyword('typeof')) {
                startToken = lookahead;
                token = lex();
                expr = parseUnaryExpression();
                expr = delegate.createUnaryExpression(token.value, expr);
                expr = delegate.markEnd(expr, startToken);
                if (strict && expr.operator === 'delete' && expr.argument.type === Syntax.Identifier) {
                  throwErrorTolerant({}, Messages.StrictDelete);
                }
              } else {
                expr = parsePostfixExpression();
              }
              return expr;
            }
            function binaryPrecedence(token, allowIn) {
              var prec = 0;
              if (token.type !== Token.Punctuator && token.type !== Token.Keyword) {
                return 0;
              }
              switch (token.value) {
                case '||':
                  prec = 1;
                  break;
                case '&&':
                  prec = 2;
                  break;
                case '|':
                  prec = 3;
                  break;
                case '^':
                  prec = 4;
                  break;
                case '&':
                  prec = 5;
                  break;
                case '==':
                case '!=':
                case '===':
                case '!==':
                  prec = 6;
                  break;
                case '<':
                case '>':
                case '<=':
                case '>=':
                case 'instanceof':
                  prec = 7;
                  break;
                case 'in':
                  prec = allowIn ? 7 : 0;
                  break;
                case '<<':
                case '>>':
                case '>>>':
                  prec = 8;
                  break;
                case '+':
                case '-':
                  prec = 9;
                  break;
                case '*':
                case '/':
                case '%':
                  prec = 11;
                  break;
              }
              return prec;
            }

            // 11.5 Multiplicative Operators
            // 11.6 Additive Operators
            // 11.7 Bitwise Shift Operators
            // 11.8 Relational Operators
            // 11.9 Equality Operators
            // 11.10 Binary Bitwise Operators
            // 11.11 Binary Logical Operators

            function parseBinaryExpression() {
              var marker, markers, expr, token, prec, stack, right, operator, left, i;
              marker = lookahead;
              left = parseUnaryExpression();
              token = lookahead;
              prec = binaryPrecedence(token, state.allowIn);
              if (prec === 0) {
                return left;
              }
              token.prec = prec;
              lex();
              markers = [marker, lookahead];
              right = parseUnaryExpression();
              stack = [left, token, right];
              while ((prec = binaryPrecedence(lookahead, state.allowIn)) > 0) {
                // Reduce: make a binary expression from the three topmost entries.
                while (stack.length > 2 && prec <= stack[stack.length - 2].prec) {
                  right = stack.pop();
                  operator = stack.pop().value;
                  left = stack.pop();
                  expr = delegate.createBinaryExpression(operator, left, right);
                  markers.pop();
                  marker = markers[markers.length - 1];
                  delegate.markEnd(expr, marker);
                  stack.push(expr);
                }

                // Shift.
                token = lex();
                token.prec = prec;
                stack.push(token);
                markers.push(lookahead);
                expr = parseUnaryExpression();
                stack.push(expr);
              }

              // Final reduce to clean-up the stack.
              i = stack.length - 1;
              expr = stack[i];
              markers.pop();
              while (i > 1) {
                expr = delegate.createBinaryExpression(stack[i - 1].value, stack[i - 2], expr);
                i -= 2;
                marker = markers.pop();
                delegate.markEnd(expr, marker);
              }
              return expr;
            }

            // 11.12 Conditional Operator

            function parseConditionalExpression() {
              var expr, previousAllowIn, consequent, alternate, startToken;
              startToken = lookahead;
              expr = parseBinaryExpression();
              if (match('?')) {
                lex();
                previousAllowIn = state.allowIn;
                state.allowIn = true;
                consequent = parseAssignmentExpression();
                state.allowIn = previousAllowIn;
                expect(':');
                alternate = parseAssignmentExpression();
                expr = delegate.createConditionalExpression(expr, consequent, alternate);
                delegate.markEnd(expr, startToken);
              }
              return expr;
            }

            // 11.13 Assignment Operators

            function parseAssignmentExpression() {
              var token, left, right, node, startToken;
              token = lookahead;
              startToken = lookahead;
              node = left = parseConditionalExpression();
              if (matchAssign()) {
                // LeftHandSideExpression
                if (!isLeftHandSide(left)) {
                  throwErrorTolerant({}, Messages.InvalidLHSInAssignment);
                }

                // 11.13.1
                if (strict && left.type === Syntax.Identifier && isRestrictedWord(left.name)) {
                  throwErrorTolerant(token, Messages.StrictLHSAssignment);
                }
                token = lex();
                right = parseAssignmentExpression();
                node = delegate.markEnd(delegate.createAssignmentExpression(token.value, left, right), startToken);
              }
              return node;
            }

            // 11.14 Comma Operator

            function parseExpression() {
              var expr,
                startToken = lookahead;
              expr = parseAssignmentExpression();
              if (match(',')) {
                expr = delegate.createSequenceExpression([expr]);
                while (index < length) {
                  if (!match(',')) {
                    break;
                  }
                  lex();
                  expr.expressions.push(parseAssignmentExpression());
                }
                delegate.markEnd(expr, startToken);
              }
              return expr;
            }

            // 12.1 Block

            function parseStatementList() {
              var list = [],
                statement;
              while (index < length) {
                if (match('}')) {
                  break;
                }
                statement = parseSourceElement();
                if (typeof statement === 'undefined') {
                  break;
                }
                list.push(statement);
              }
              return list;
            }
            function parseBlock() {
              var block, startToken;
              startToken = lookahead;
              expect('{');
              block = parseStatementList();
              expect('}');
              return delegate.markEnd(delegate.createBlockStatement(block), startToken);
            }

            // 12.2 Variable Statement

            function parseVariableIdentifier() {
              var token, startToken;
              startToken = lookahead;
              token = lex();
              if (token.type !== Token.Identifier) {
                throwUnexpected(token);
              }
              return delegate.markEnd(delegate.createIdentifier(token.value), startToken);
            }
            function parseVariableDeclaration(kind) {
              var init = null,
                id,
                startToken;
              startToken = lookahead;
              id = parseVariableIdentifier();

              // 12.2.1
              if (strict && isRestrictedWord(id.name)) {
                throwErrorTolerant({}, Messages.StrictVarName);
              }
              if (kind === 'const') {
                expect('=');
                init = parseAssignmentExpression();
              } else if (match('=')) {
                lex();
                init = parseAssignmentExpression();
              }
              return delegate.markEnd(delegate.createVariableDeclarator(id, init), startToken);
            }
            function parseVariableDeclarationList(kind) {
              var list = [];
              do {
                list.push(parseVariableDeclaration(kind));
                if (!match(',')) {
                  break;
                }
                lex();
              } while (index < length);
              return list;
            }
            function parseVariableStatement() {
              var declarations;
              expectKeyword('var');
              declarations = parseVariableDeclarationList();
              consumeSemicolon();
              return delegate.createVariableDeclaration(declarations, 'var');
            }

            // kind may be `const` or `let`
            // Both are experimental and not in the specification yet.
            // see http://wiki.ecmascript.org/doku.php?id=harmony:const
            // and http://wiki.ecmascript.org/doku.php?id=harmony:let
            function parseConstLetDeclaration(kind) {
              var declarations, startToken;
              startToken = lookahead;
              expectKeyword(kind);
              declarations = parseVariableDeclarationList(kind);
              consumeSemicolon();
              return delegate.markEnd(delegate.createVariableDeclaration(declarations, kind), startToken);
            }

            // 12.3 Empty Statement

            function parseEmptyStatement() {
              expect(';');
              return delegate.createEmptyStatement();
            }

            // 12.4 Expression Statement

            function parseExpressionStatement() {
              var expr = parseExpression();
              consumeSemicolon();
              return delegate.createExpressionStatement(expr);
            }

            // 12.5 If statement

            function parseIfStatement() {
              var test, consequent, alternate;
              expectKeyword('if');
              expect('(');
              test = parseExpression();
              expect(')');
              consequent = parseStatement();
              if (matchKeyword('else')) {
                lex();
                alternate = parseStatement();
              } else {
                alternate = null;
              }
              return delegate.createIfStatement(test, consequent, alternate);
            }

            // 12.6 Iteration Statements

            function parseDoWhileStatement() {
              var body, test, oldInIteration;
              expectKeyword('do');
              oldInIteration = state.inIteration;
              state.inIteration = true;
              body = parseStatement();
              state.inIteration = oldInIteration;
              expectKeyword('while');
              expect('(');
              test = parseExpression();
              expect(')');
              if (match(';')) {
                lex();
              }
              return delegate.createDoWhileStatement(body, test);
            }
            function parseWhileStatement() {
              var test, body, oldInIteration;
              expectKeyword('while');
              expect('(');
              test = parseExpression();
              expect(')');
              oldInIteration = state.inIteration;
              state.inIteration = true;
              body = parseStatement();
              state.inIteration = oldInIteration;
              return delegate.createWhileStatement(test, body);
            }
            function parseForVariableDeclaration() {
              var token, declarations, startToken;
              startToken = lookahead;
              token = lex();
              declarations = parseVariableDeclarationList();
              return delegate.markEnd(delegate.createVariableDeclaration(declarations, token.value), startToken);
            }
            function parseForStatement() {
              var init, test, update, left, right, body, oldInIteration;
              init = test = update = null;
              expectKeyword('for');
              expect('(');
              if (match(';')) {
                lex();
              } else {
                if (matchKeyword('var') || matchKeyword('let')) {
                  state.allowIn = false;
                  init = parseForVariableDeclaration();
                  state.allowIn = true;
                  if (init.declarations.length === 1 && matchKeyword('in')) {
                    lex();
                    left = init;
                    right = parseExpression();
                    init = null;
                  }
                } else {
                  state.allowIn = false;
                  init = parseExpression();
                  state.allowIn = true;
                  if (matchKeyword('in')) {
                    // LeftHandSideExpression
                    if (!isLeftHandSide(init)) {
                      throwErrorTolerant({}, Messages.InvalidLHSInForIn);
                    }
                    lex();
                    left = init;
                    right = parseExpression();
                    init = null;
                  }
                }
                if (typeof left === 'undefined') {
                  expect(';');
                }
              }
              if (typeof left === 'undefined') {
                if (!match(';')) {
                  test = parseExpression();
                }
                expect(';');
                if (!match(')')) {
                  update = parseExpression();
                }
              }
              expect(')');
              oldInIteration = state.inIteration;
              state.inIteration = true;
              body = parseStatement();
              state.inIteration = oldInIteration;
              return typeof left === 'undefined' ? delegate.createForStatement(init, test, update, body) : delegate.createForInStatement(left, right, body);
            }

            // 12.7 The continue statement

            function parseContinueStatement() {
              var label = null,
                key;
              expectKeyword('continue');

              // Optimize the most common form: 'continue;'.
              if (source.charCodeAt(index) === 0x3B) {
                lex();
                if (!state.inIteration) {
                  throwError({}, Messages.IllegalContinue);
                }
                return delegate.createContinueStatement(null);
              }
              if (peekLineTerminator()) {
                if (!state.inIteration) {
                  throwError({}, Messages.IllegalContinue);
                }
                return delegate.createContinueStatement(null);
              }
              if (lookahead.type === Token.Identifier) {
                label = parseVariableIdentifier();
                key = '$' + label.name;
                if (!Object.prototype.hasOwnProperty.call(state.labelSet, key)) {
                  throwError({}, Messages.UnknownLabel, label.name);
                }
              }
              consumeSemicolon();
              if (label === null && !state.inIteration) {
                throwError({}, Messages.IllegalContinue);
              }
              return delegate.createContinueStatement(label);
            }

            // 12.8 The break statement

            function parseBreakStatement() {
              var label = null,
                key;
              expectKeyword('break');

              // Catch the very common case first: immediately a semicolon (U+003B).
              if (source.charCodeAt(index) === 0x3B) {
                lex();
                if (!(state.inIteration || state.inSwitch)) {
                  throwError({}, Messages.IllegalBreak);
                }
                return delegate.createBreakStatement(null);
              }
              if (peekLineTerminator()) {
                if (!(state.inIteration || state.inSwitch)) {
                  throwError({}, Messages.IllegalBreak);
                }
                return delegate.createBreakStatement(null);
              }
              if (lookahead.type === Token.Identifier) {
                label = parseVariableIdentifier();
                key = '$' + label.name;
                if (!Object.prototype.hasOwnProperty.call(state.labelSet, key)) {
                  throwError({}, Messages.UnknownLabel, label.name);
                }
              }
              consumeSemicolon();
              if (label === null && !(state.inIteration || state.inSwitch)) {
                throwError({}, Messages.IllegalBreak);
              }
              return delegate.createBreakStatement(label);
            }

            // 12.9 The return statement

            function parseReturnStatement() {
              var argument = null;
              expectKeyword('return');
              if (!state.inFunctionBody) {
                throwErrorTolerant({}, Messages.IllegalReturn);
              }

              // 'return' followed by a space and an identifier is very common.
              if (source.charCodeAt(index) === 0x20) {
                if (isIdentifierStart(source.charCodeAt(index + 1))) {
                  argument = parseExpression();
                  consumeSemicolon();
                  return delegate.createReturnStatement(argument);
                }
              }
              if (peekLineTerminator()) {
                return delegate.createReturnStatement(null);
              }
              if (!match(';')) {
                if (!match('}') && lookahead.type !== Token.EOF) {
                  argument = parseExpression();
                }
              }
              consumeSemicolon();
              return delegate.createReturnStatement(argument);
            }

            // 12.10 The with statement

            function parseWithStatement() {
              var object, body;
              if (strict) {
                // TODO(ikarienator): Should we update the test cases instead?
                skipComment();
                throwErrorTolerant({}, Messages.StrictModeWith);
              }
              expectKeyword('with');
              expect('(');
              object = parseExpression();
              expect(')');
              body = parseStatement();
              return delegate.createWithStatement(object, body);
            }

            // 12.10 The swith statement

            function parseSwitchCase() {
              var test,
                consequent = [],
                statement,
                startToken;
              startToken = lookahead;
              if (matchKeyword('default')) {
                lex();
                test = null;
              } else {
                expectKeyword('case');
                test = parseExpression();
              }
              expect(':');
              while (index < length) {
                if (match('}') || matchKeyword('default') || matchKeyword('case')) {
                  break;
                }
                statement = parseStatement();
                consequent.push(statement);
              }
              return delegate.markEnd(delegate.createSwitchCase(test, consequent), startToken);
            }
            function parseSwitchStatement() {
              var discriminant, cases, clause, oldInSwitch, defaultFound;
              expectKeyword('switch');
              expect('(');
              discriminant = parseExpression();
              expect(')');
              expect('{');
              cases = [];
              if (match('}')) {
                lex();
                return delegate.createSwitchStatement(discriminant, cases);
              }
              oldInSwitch = state.inSwitch;
              state.inSwitch = true;
              defaultFound = false;
              while (index < length) {
                if (match('}')) {
                  break;
                }
                clause = parseSwitchCase();
                if (clause.test === null) {
                  if (defaultFound) {
                    throwError({}, Messages.MultipleDefaultsInSwitch);
                  }
                  defaultFound = true;
                }
                cases.push(clause);
              }
              state.inSwitch = oldInSwitch;
              expect('}');
              return delegate.createSwitchStatement(discriminant, cases);
            }

            // 12.13 The throw statement

            function parseThrowStatement() {
              var argument;
              expectKeyword('throw');
              if (peekLineTerminator()) {
                throwError({}, Messages.NewlineAfterThrow);
              }
              argument = parseExpression();
              consumeSemicolon();
              return delegate.createThrowStatement(argument);
            }

            // 12.14 The try statement

            function parseCatchClause() {
              var param, body, startToken;
              startToken = lookahead;
              expectKeyword('catch');
              expect('(');
              if (match(')')) {
                throwUnexpected(lookahead);
              }
              param = parseVariableIdentifier();
              // 12.14.1
              if (strict && isRestrictedWord(param.name)) {
                throwErrorTolerant({}, Messages.StrictCatchVariable);
              }
              expect(')');
              body = parseBlock();
              return delegate.markEnd(delegate.createCatchClause(param, body), startToken);
            }
            function parseTryStatement() {
              var block,
                handlers = [],
                finalizer = null;
              expectKeyword('try');
              block = parseBlock();
              if (matchKeyword('catch')) {
                handlers.push(parseCatchClause());
              }
              if (matchKeyword('finally')) {
                lex();
                finalizer = parseBlock();
              }
              if (handlers.length === 0 && !finalizer) {
                throwError({}, Messages.NoCatchOrFinally);
              }
              return delegate.createTryStatement(block, [], handlers, finalizer);
            }

            // 12.15 The debugger statement

            function parseDebuggerStatement() {
              expectKeyword('debugger');
              consumeSemicolon();
              return delegate.createDebuggerStatement();
            }

            // 12 Statements

            function parseStatement() {
              var type = lookahead.type,
                expr,
                labeledBody,
                key,
                startToken;
              if (type === Token.EOF) {
                throwUnexpected(lookahead);
              }
              if (type === Token.Punctuator && lookahead.value === '{') {
                return parseBlock();
              }
              startToken = lookahead;
              if (type === Token.Punctuator) {
                switch (lookahead.value) {
                  case ';':
                    return delegate.markEnd(parseEmptyStatement(), startToken);
                  case '(':
                    return delegate.markEnd(parseExpressionStatement(), startToken);
                }
              }
              if (type === Token.Keyword) {
                switch (lookahead.value) {
                  case 'break':
                    return delegate.markEnd(parseBreakStatement(), startToken);
                  case 'continue':
                    return delegate.markEnd(parseContinueStatement(), startToken);
                  case 'debugger':
                    return delegate.markEnd(parseDebuggerStatement(), startToken);
                  case 'do':
                    return delegate.markEnd(parseDoWhileStatement(), startToken);
                  case 'for':
                    return delegate.markEnd(parseForStatement(), startToken);
                  case 'function':
                    return delegate.markEnd(parseFunctionDeclaration(), startToken);
                  case 'if':
                    return delegate.markEnd(parseIfStatement(), startToken);
                  case 'return':
                    return delegate.markEnd(parseReturnStatement(), startToken);
                  case 'switch':
                    return delegate.markEnd(parseSwitchStatement(), startToken);
                  case 'throw':
                    return delegate.markEnd(parseThrowStatement(), startToken);
                  case 'try':
                    return delegate.markEnd(parseTryStatement(), startToken);
                  case 'var':
                    return delegate.markEnd(parseVariableStatement(), startToken);
                  case 'while':
                    return delegate.markEnd(parseWhileStatement(), startToken);
                  case 'with':
                    return delegate.markEnd(parseWithStatement(), startToken);
                }
              }
              expr = parseExpression();

              // 12.12 Labelled Statements
              if (expr.type === Syntax.Identifier && match(':')) {
                lex();
                key = '$' + expr.name;
                if (Object.prototype.hasOwnProperty.call(state.labelSet, key)) {
                  throwError({}, Messages.Redeclaration, 'Label', expr.name);
                }
                state.labelSet[key] = true;
                labeledBody = parseStatement();
                delete state.labelSet[key];
                return delegate.markEnd(delegate.createLabeledStatement(expr, labeledBody), startToken);
              }
              consumeSemicolon();
              return delegate.markEnd(delegate.createExpressionStatement(expr), startToken);
            }

            // 13 Function Definition

            function parseFunctionSourceElements() {
              var sourceElement,
                sourceElements = [],
                token,
                directive,
                firstRestricted,
                oldLabelSet,
                oldInIteration,
                oldInSwitch,
                oldInFunctionBody,
                startToken;
              startToken = lookahead;
              expect('{');
              while (index < length) {
                if (lookahead.type !== Token.StringLiteral) {
                  break;
                }
                token = lookahead;
                sourceElement = parseSourceElement();
                sourceElements.push(sourceElement);
                if (sourceElement.expression.type !== Syntax.Literal) {
                  // this is not directive
                  break;
                }
                directive = source.slice(token.start + 1, token.end - 1);
                if (directive === 'use strict') {
                  strict = true;
                  if (firstRestricted) {
                    throwErrorTolerant(firstRestricted, Messages.StrictOctalLiteral);
                  }
                } else {
                  if (!firstRestricted && token.octal) {
                    firstRestricted = token;
                  }
                }
              }
              oldLabelSet = state.labelSet;
              oldInIteration = state.inIteration;
              oldInSwitch = state.inSwitch;
              oldInFunctionBody = state.inFunctionBody;
              state.labelSet = {};
              state.inIteration = false;
              state.inSwitch = false;
              state.inFunctionBody = true;
              while (index < length) {
                if (match('}')) {
                  break;
                }
                sourceElement = parseSourceElement();
                if (typeof sourceElement === 'undefined') {
                  break;
                }
                sourceElements.push(sourceElement);
              }
              expect('}');
              state.labelSet = oldLabelSet;
              state.inIteration = oldInIteration;
              state.inSwitch = oldInSwitch;
              state.inFunctionBody = oldInFunctionBody;
              return delegate.markEnd(delegate.createBlockStatement(sourceElements), startToken);
            }
            function parseParams(firstRestricted) {
              var param,
                params = [],
                token,
                stricted,
                paramSet,
                key,
                message;
              expect('(');
              if (!match(')')) {
                paramSet = {};
                while (index < length) {
                  token = lookahead;
                  param = parseVariableIdentifier();
                  key = '$' + token.value;
                  if (strict) {
                    if (isRestrictedWord(token.value)) {
                      stricted = token;
                      message = Messages.StrictParamName;
                    }
                    if (Object.prototype.hasOwnProperty.call(paramSet, key)) {
                      stricted = token;
                      message = Messages.StrictParamDupe;
                    }
                  } else if (!firstRestricted) {
                    if (isRestrictedWord(token.value)) {
                      firstRestricted = token;
                      message = Messages.StrictParamName;
                    } else if (isStrictModeReservedWord(token.value)) {
                      firstRestricted = token;
                      message = Messages.StrictReservedWord;
                    } else if (Object.prototype.hasOwnProperty.call(paramSet, key)) {
                      firstRestricted = token;
                      message = Messages.StrictParamDupe;
                    }
                  }
                  params.push(param);
                  paramSet[key] = true;
                  if (match(')')) {
                    break;
                  }
                  expect(',');
                }
              }
              expect(')');
              return {
                params: params,
                stricted: stricted,
                firstRestricted: firstRestricted,
                message: message
              };
            }
            function parseFunctionDeclaration() {
              var id,
                params = [],
                body,
                token,
                stricted,
                tmp,
                firstRestricted,
                message,
                previousStrict,
                startToken;
              startToken = lookahead;
              expectKeyword('function');
              token = lookahead;
              id = parseVariableIdentifier();
              if (strict) {
                if (isRestrictedWord(token.value)) {
                  throwErrorTolerant(token, Messages.StrictFunctionName);
                }
              } else {
                if (isRestrictedWord(token.value)) {
                  firstRestricted = token;
                  message = Messages.StrictFunctionName;
                } else if (isStrictModeReservedWord(token.value)) {
                  firstRestricted = token;
                  message = Messages.StrictReservedWord;
                }
              }
              tmp = parseParams(firstRestricted);
              params = tmp.params;
              stricted = tmp.stricted;
              firstRestricted = tmp.firstRestricted;
              if (tmp.message) {
                message = tmp.message;
              }
              previousStrict = strict;
              body = parseFunctionSourceElements();
              if (strict && firstRestricted) {
                throwError(firstRestricted, message);
              }
              if (strict && stricted) {
                throwErrorTolerant(stricted, message);
              }
              strict = previousStrict;
              return delegate.markEnd(delegate.createFunctionDeclaration(id, params, [], body), startToken);
            }
            function parseFunctionExpression() {
              var token,
                id = null,
                stricted,
                firstRestricted,
                message,
                tmp,
                params = [],
                body,
                previousStrict,
                startToken;
              startToken = lookahead;
              expectKeyword('function');
              if (!match('(')) {
                token = lookahead;
                id = parseVariableIdentifier();
                if (strict) {
                  if (isRestrictedWord(token.value)) {
                    throwErrorTolerant(token, Messages.StrictFunctionName);
                  }
                } else {
                  if (isRestrictedWord(token.value)) {
                    firstRestricted = token;
                    message = Messages.StrictFunctionName;
                  } else if (isStrictModeReservedWord(token.value)) {
                    firstRestricted = token;
                    message = Messages.StrictReservedWord;
                  }
                }
              }
              tmp = parseParams(firstRestricted);
              params = tmp.params;
              stricted = tmp.stricted;
              firstRestricted = tmp.firstRestricted;
              if (tmp.message) {
                message = tmp.message;
              }
              previousStrict = strict;
              body = parseFunctionSourceElements();
              if (strict && firstRestricted) {
                throwError(firstRestricted, message);
              }
              if (strict && stricted) {
                throwErrorTolerant(stricted, message);
              }
              strict = previousStrict;
              return delegate.markEnd(delegate.createFunctionExpression(id, params, [], body), startToken);
            }

            // 14 Program

            function parseSourceElement() {
              if (lookahead.type === Token.Keyword) {
                switch (lookahead.value) {
                  case 'const':
                  case 'let':
                    return parseConstLetDeclaration(lookahead.value);
                  case 'function':
                    return parseFunctionDeclaration();
                  default:
                    return parseStatement();
                }
              }
              if (lookahead.type !== Token.EOF) {
                return parseStatement();
              }
            }
            function parseSourceElements() {
              var sourceElement,
                sourceElements = [],
                token,
                directive,
                firstRestricted;
              while (index < length) {
                token = lookahead;
                if (token.type !== Token.StringLiteral) {
                  break;
                }
                sourceElement = parseSourceElement();
                sourceElements.push(sourceElement);
                if (sourceElement.expression.type !== Syntax.Literal) {
                  // this is not directive
                  break;
                }
                directive = source.slice(token.start + 1, token.end - 1);
                if (directive === 'use strict') {
                  strict = true;
                  if (firstRestricted) {
                    throwErrorTolerant(firstRestricted, Messages.StrictOctalLiteral);
                  }
                } else {
                  if (!firstRestricted && token.octal) {
                    firstRestricted = token;
                  }
                }
              }
              while (index < length) {
                sourceElement = parseSourceElement();
                /* istanbul ignore if */
                if (typeof sourceElement === 'undefined') {
                  break;
                }
                sourceElements.push(sourceElement);
              }
              return sourceElements;
            }
            function parseProgram() {
              var body, startToken;
              skipComment();
              peek();
              startToken = lookahead;
              strict = false;
              body = parseSourceElements();
              return delegate.markEnd(delegate.createProgram(body), startToken);
            }
            function filterTokenLocation() {
              var i,
                entry,
                token,
                tokens = [];
              for (i = 0; i < extra.tokens.length; ++i) {
                entry = extra.tokens[i];
                token = {
                  type: entry.type,
                  value: entry.value
                };
                if (extra.range) {
                  token.range = entry.range;
                }
                if (extra.loc) {
                  token.loc = entry.loc;
                }
                tokens.push(token);
              }
              extra.tokens = tokens;
            }
            function tokenize(code, options) {
              var toString, token, tokens;
              toString = String;
              if (typeof code !== 'string' && !(code instanceof String)) {
                code = toString(code);
              }
              delegate = SyntaxTreeDelegate;
              source = code;
              index = 0;
              lineNumber = source.length > 0 ? 1 : 0;
              lineStart = 0;
              length = source.length;
              lookahead = null;
              state = {
                allowIn: true,
                labelSet: {},
                inFunctionBody: false,
                inIteration: false,
                inSwitch: false,
                lastCommentStart: -1
              };
              extra = {};

              // Options matching.
              options = options || {};

              // Of course we collect tokens here.
              options.tokens = true;
              extra.tokens = [];
              extra.tokenize = true;
              // The following two fields are necessary to compute the Regex tokens.
              extra.openParenToken = -1;
              extra.openCurlyToken = -1;
              extra.range = typeof options.range === 'boolean' && options.range;
              extra.loc = typeof options.loc === 'boolean' && options.loc;
              if (typeof options.comment === 'boolean' && options.comment) {
                extra.comments = [];
              }
              if (typeof options.tolerant === 'boolean' && options.tolerant) {
                extra.errors = [];
              }
              try {
                peek();
                if (lookahead.type === Token.EOF) {
                  return extra.tokens;
                }
                token = lex();
                while (lookahead.type !== Token.EOF) {
                  try {
                    token = lex();
                  } catch (lexError) {
                    token = lookahead;
                    if (extra.errors) {
                      extra.errors.push(lexError);
                      // We have to break on the first error
                      // to avoid infinite loops.
                      break;
                    } else {
                      throw lexError;
                    }
                  }
                }
                filterTokenLocation();
                tokens = extra.tokens;
                if (typeof extra.comments !== 'undefined') {
                  tokens.comments = extra.comments;
                }
                if (typeof extra.errors !== 'undefined') {
                  tokens.errors = extra.errors;
                }
              } catch (e) {
                throw e;
              } finally {
                extra = {};
              }
              return tokens;
            }
            function parse(code, options) {
              var program, toString;
              toString = String;
              if (typeof code !== 'string' && !(code instanceof String)) {
                code = toString(code);
              }
              delegate = SyntaxTreeDelegate;
              source = code;
              index = 0;
              lineNumber = source.length > 0 ? 1 : 0;
              lineStart = 0;
              length = source.length;
              lookahead = null;
              state = {
                allowIn: true,
                labelSet: {},
                inFunctionBody: false,
                inIteration: false,
                inSwitch: false,
                lastCommentStart: -1
              };
              extra = {};
              if (typeof options !== 'undefined') {
                extra.range = typeof options.range === 'boolean' && options.range;
                extra.loc = typeof options.loc === 'boolean' && options.loc;
                extra.attachComment = typeof options.attachComment === 'boolean' && options.attachComment;
                if (extra.loc && options.source !== null && options.source !== undefined) {
                  extra.source = toString(options.source);
                }
                if (typeof options.tokens === 'boolean' && options.tokens) {
                  extra.tokens = [];
                }
                if (typeof options.comment === 'boolean' && options.comment) {
                  extra.comments = [];
                }
                if (typeof options.tolerant === 'boolean' && options.tolerant) {
                  extra.errors = [];
                }
                if (extra.attachComment) {
                  extra.range = true;
                  extra.comments = [];
                  extra.bottomRightStack = [];
                  extra.trailingComments = [];
                  extra.leadingComments = [];
                }
              }
              try {
                program = parseProgram();
                if (typeof extra.comments !== 'undefined') {
                  program.comments = extra.comments;
                }
                if (typeof extra.tokens !== 'undefined') {
                  filterTokenLocation();
                  program.tokens = extra.tokens;
                }
                if (typeof extra.errors !== 'undefined') {
                  program.errors = extra.errors;
                }
              } catch (e) {
                throw e;
              } finally {
                extra = {};
              }
              return program;
            }

            // Sync with *.json manifests.
            exports.version = '1.2.2';
            exports.tokenize = tokenize;
            exports.parse = parse;

            // Deep copy.
            /* istanbul ignore next */
            exports.Syntax = function () {
              var name,
                types = {};
              if (typeof Object.create === 'function') {
                types = Object.create(null);
              }
              for (name in Syntax) {
                if (Syntax.hasOwnProperty(name)) {
                  types[name] = Syntax[name];
                }
              }
              if (typeof Object.freeze === 'function') {
                Object.freeze(types);
              }
              return types;
            }();
          });
          /* vim: set sw=4 ts=4 et tw=80 : */
        }, {}],
        1: [function (require, module, exports) {
          (function (process) {
            /* parser generated by jison 0.4.13 */
            /*
              Returns a Parser object of the following structure:
            
              Parser: {
                yy: {}
              }
            
              Parser.prototype: {
                yy: {},
                trace: function(),
                symbols_: {associative list: name ==> number},
                terminals_: {associative list: number ==> name},
                productions_: [...],
                performAction: function anonymous(yytext, yyleng, yylineno, yy, yystate, $$, _$),
                table: [...],
                defaultActions: {...},
                parseError: function(str, hash),
                parse: function(input),
            
                lexer: {
                    EOF: 1,
                    parseError: function(str, hash),
                    setInput: function(input),
                    input: function(),
                    unput: function(str),
                    more: function(),
                    less: function(n),
                    pastInput: function(),
                    upcomingInput: function(),
                    showPosition: function(),
                    test_match: function(regex_match_array, rule_index),
                    next: function(),
                    lex: function(),
                    begin: function(condition),
                    popState: function(),
                    _currentRules: function(),
                    topState: function(),
                    pushState: function(condition),
            
                    options: {
                        ranges: boolean           (optional: true ==> token location info will include a .range[] member)
                        flex: boolean             (optional: true ==> flex-like lexing behaviour where the rules are tested exhaustively to find the longest match)
                        backtrack_lexer: boolean  (optional: true ==> lexer regexes are tested in order and for each matching regex the action code is invoked; the lexer terminates the scan when a token is returned by the action code)
                    },
            
                    performAction: function(yy, yy_, $avoiding_name_collisions, YY_START),
                    rules: [...],
                    conditions: {associative list: name ==> set},
                }
              }
            
            
              token location info (@$, _$, etc.): {
                first_line: n,
                last_line: n,
                first_column: n,
                last_column: n,
                range: [start_number, end_number]       (where the numbers are indexes into the input string, regular zero-based)
              }
            
            
              the parseError function receives a 'hash' object with these members for lexer and parser errors: {
                text:        (matched text)
                token:       (the produced terminal token, if any)
                line:        (yylineno)
              }
              while parser (grammar) errors will also provide these members, i.e. parser errors deliver a superset of attributes: {
                loc:         (yylloc)
                expected:    (string describing the set of expected tokens)
                recoverable: (boolean: TRUE when the parser has a error recovery rule available for this particular error)
              }
            */
            var parser = function () {
              var parser = {
                trace: function trace() {},
                yy: {},
                symbols_: {
                  "error": 2,
                  "JSON_PATH": 3,
                  "DOLLAR": 4,
                  "PATH_COMPONENTS": 5,
                  "LEADING_CHILD_MEMBER_EXPRESSION": 6,
                  "PATH_COMPONENT": 7,
                  "MEMBER_COMPONENT": 8,
                  "SUBSCRIPT_COMPONENT": 9,
                  "CHILD_MEMBER_COMPONENT": 10,
                  "DESCENDANT_MEMBER_COMPONENT": 11,
                  "DOT": 12,
                  "MEMBER_EXPRESSION": 13,
                  "DOT_DOT": 14,
                  "STAR": 15,
                  "IDENTIFIER": 16,
                  "SCRIPT_EXPRESSION": 17,
                  "INTEGER": 18,
                  "END": 19,
                  "CHILD_SUBSCRIPT_COMPONENT": 20,
                  "DESCENDANT_SUBSCRIPT_COMPONENT": 21,
                  "[": 22,
                  "SUBSCRIPT": 23,
                  "]": 24,
                  "SUBSCRIPT_EXPRESSION": 25,
                  "SUBSCRIPT_EXPRESSION_LIST": 26,
                  "SUBSCRIPT_EXPRESSION_LISTABLE": 27,
                  ",": 28,
                  "STRING_LITERAL": 29,
                  "ARRAY_SLICE": 30,
                  "FILTER_EXPRESSION": 31,
                  "QQ_STRING": 32,
                  "Q_STRING": 33,
                  "$accept": 0,
                  "$end": 1
                },
                terminals_: {
                  2: "error",
                  4: "DOLLAR",
                  12: "DOT",
                  14: "DOT_DOT",
                  15: "STAR",
                  16: "IDENTIFIER",
                  17: "SCRIPT_EXPRESSION",
                  18: "INTEGER",
                  19: "END",
                  22: "[",
                  24: "]",
                  28: ",",
                  30: "ARRAY_SLICE",
                  31: "FILTER_EXPRESSION",
                  32: "QQ_STRING",
                  33: "Q_STRING"
                },
                productions_: [0, [3, 1], [3, 2], [3, 1], [3, 2], [5, 1], [5, 2], [7, 1], [7, 1], [8, 1], [8, 1], [10, 2], [6, 1], [11, 2], [13, 1], [13, 1], [13, 1], [13, 1], [13, 1], [9, 1], [9, 1], [20, 3], [21, 4], [23, 1], [23, 1], [26, 1], [26, 3], [27, 1], [27, 1], [27, 1], [25, 1], [25, 1], [25, 1], [29, 1], [29, 1]],
                performAction: function anonymous(yytext, yyleng, yylineno, yy, yystate /* action[1] */, $$ /* vstack */, _$ /* lstack */
                /**/) {
                  /* this == yyval */
                  if (!yy.ast) {
                    yy.ast = _ast;
                    _ast.initialize();
                  }
                  var $0 = $$.length - 1;
                  switch (yystate) {
                    case 1:
                      yy.ast.set({
                        expression: {
                          type: "root",
                          value: $$[$0]
                        }
                      });
                      yy.ast.unshift();
                      return yy.ast.yield();
                    case 2:
                      yy.ast.set({
                        expression: {
                          type: "root",
                          value: $$[$0 - 1]
                        }
                      });
                      yy.ast.unshift();
                      return yy.ast.yield();
                    case 3:
                      yy.ast.unshift();
                      return yy.ast.yield();
                    case 4:
                      yy.ast.set({
                        operation: "member",
                        scope: "child",
                        expression: {
                          type: "identifier",
                          value: $$[$0 - 1]
                        }
                      });
                      yy.ast.unshift();
                      return yy.ast.yield();
                    case 5:
                      break;
                    case 6:
                      break;
                    case 7:
                      yy.ast.set({
                        operation: "member"
                      });
                      yy.ast.push();
                      break;
                    case 8:
                      yy.ast.set({
                        operation: "subscript"
                      });
                      yy.ast.push();
                      break;
                    case 9:
                      yy.ast.set({
                        scope: "child"
                      });
                      break;
                    case 10:
                      yy.ast.set({
                        scope: "descendant"
                      });
                      break;
                    case 11:
                      break;
                    case 12:
                      yy.ast.set({
                        scope: "child",
                        operation: "member"
                      });
                      break;
                    case 13:
                      break;
                    case 14:
                      yy.ast.set({
                        expression: {
                          type: "wildcard",
                          value: $$[$0]
                        }
                      });
                      break;
                    case 15:
                      yy.ast.set({
                        expression: {
                          type: "identifier",
                          value: $$[$0]
                        }
                      });
                      break;
                    case 16:
                      yy.ast.set({
                        expression: {
                          type: "script_expression",
                          value: $$[$0]
                        }
                      });
                      break;
                    case 17:
                      yy.ast.set({
                        expression: {
                          type: "numeric_literal",
                          value: parseInt($$[$0])
                        }
                      });
                      break;
                    case 18:
                      break;
                    case 19:
                      yy.ast.set({
                        scope: "child"
                      });
                      break;
                    case 20:
                      yy.ast.set({
                        scope: "descendant"
                      });
                      break;
                    case 21:
                      break;
                    case 22:
                      break;
                    case 23:
                      break;
                    case 24:
                      $$[$0].length > 1 ? yy.ast.set({
                        expression: {
                          type: "union",
                          value: $$[$0]
                        }
                      }) : this.$ = $$[$0];
                      break;
                    case 25:
                      this.$ = [$$[$0]];
                      break;
                    case 26:
                      this.$ = $$[$0 - 2].concat($$[$0]);
                      break;
                    case 27:
                      this.$ = {
                        expression: {
                          type: "numeric_literal",
                          value: parseInt($$[$0])
                        }
                      };
                      yy.ast.set(this.$);
                      break;
                    case 28:
                      this.$ = {
                        expression: {
                          type: "string_literal",
                          value: $$[$0]
                        }
                      };
                      yy.ast.set(this.$);
                      break;
                    case 29:
                      this.$ = {
                        expression: {
                          type: "slice",
                          value: $$[$0]
                        }
                      };
                      yy.ast.set(this.$);
                      break;
                    case 30:
                      this.$ = {
                        expression: {
                          type: "wildcard",
                          value: $$[$0]
                        }
                      };
                      yy.ast.set(this.$);
                      break;
                    case 31:
                      this.$ = {
                        expression: {
                          type: "script_expression",
                          value: $$[$0]
                        }
                      };
                      yy.ast.set(this.$);
                      break;
                    case 32:
                      this.$ = {
                        expression: {
                          type: "filter_expression",
                          value: $$[$0]
                        }
                      };
                      yy.ast.set(this.$);
                      break;
                    case 33:
                      this.$ = $$[$0];
                      break;
                    case 34:
                      this.$ = $$[$0];
                      break;
                  }
                },
                table: [{
                  3: 1,
                  4: [1, 2],
                  6: 3,
                  13: 4,
                  15: [1, 5],
                  16: [1, 6],
                  17: [1, 7],
                  18: [1, 8],
                  19: [1, 9]
                }, {
                  1: [3]
                }, {
                  1: [2, 1],
                  5: 10,
                  7: 11,
                  8: 12,
                  9: 13,
                  10: 14,
                  11: 15,
                  12: [1, 18],
                  14: [1, 19],
                  20: 16,
                  21: 17,
                  22: [1, 20]
                }, {
                  1: [2, 3],
                  5: 21,
                  7: 11,
                  8: 12,
                  9: 13,
                  10: 14,
                  11: 15,
                  12: [1, 18],
                  14: [1, 19],
                  20: 16,
                  21: 17,
                  22: [1, 20]
                }, {
                  1: [2, 12],
                  12: [2, 12],
                  14: [2, 12],
                  22: [2, 12]
                }, {
                  1: [2, 14],
                  12: [2, 14],
                  14: [2, 14],
                  22: [2, 14]
                }, {
                  1: [2, 15],
                  12: [2, 15],
                  14: [2, 15],
                  22: [2, 15]
                }, {
                  1: [2, 16],
                  12: [2, 16],
                  14: [2, 16],
                  22: [2, 16]
                }, {
                  1: [2, 17],
                  12: [2, 17],
                  14: [2, 17],
                  22: [2, 17]
                }, {
                  1: [2, 18],
                  12: [2, 18],
                  14: [2, 18],
                  22: [2, 18]
                }, {
                  1: [2, 2],
                  7: 22,
                  8: 12,
                  9: 13,
                  10: 14,
                  11: 15,
                  12: [1, 18],
                  14: [1, 19],
                  20: 16,
                  21: 17,
                  22: [1, 20]
                }, {
                  1: [2, 5],
                  12: [2, 5],
                  14: [2, 5],
                  22: [2, 5]
                }, {
                  1: [2, 7],
                  12: [2, 7],
                  14: [2, 7],
                  22: [2, 7]
                }, {
                  1: [2, 8],
                  12: [2, 8],
                  14: [2, 8],
                  22: [2, 8]
                }, {
                  1: [2, 9],
                  12: [2, 9],
                  14: [2, 9],
                  22: [2, 9]
                }, {
                  1: [2, 10],
                  12: [2, 10],
                  14: [2, 10],
                  22: [2, 10]
                }, {
                  1: [2, 19],
                  12: [2, 19],
                  14: [2, 19],
                  22: [2, 19]
                }, {
                  1: [2, 20],
                  12: [2, 20],
                  14: [2, 20],
                  22: [2, 20]
                }, {
                  13: 23,
                  15: [1, 5],
                  16: [1, 6],
                  17: [1, 7],
                  18: [1, 8],
                  19: [1, 9]
                }, {
                  13: 24,
                  15: [1, 5],
                  16: [1, 6],
                  17: [1, 7],
                  18: [1, 8],
                  19: [1, 9],
                  22: [1, 25]
                }, {
                  15: [1, 29],
                  17: [1, 30],
                  18: [1, 33],
                  23: 26,
                  25: 27,
                  26: 28,
                  27: 32,
                  29: 34,
                  30: [1, 35],
                  31: [1, 31],
                  32: [1, 36],
                  33: [1, 37]
                }, {
                  1: [2, 4],
                  7: 22,
                  8: 12,
                  9: 13,
                  10: 14,
                  11: 15,
                  12: [1, 18],
                  14: [1, 19],
                  20: 16,
                  21: 17,
                  22: [1, 20]
                }, {
                  1: [2, 6],
                  12: [2, 6],
                  14: [2, 6],
                  22: [2, 6]
                }, {
                  1: [2, 11],
                  12: [2, 11],
                  14: [2, 11],
                  22: [2, 11]
                }, {
                  1: [2, 13],
                  12: [2, 13],
                  14: [2, 13],
                  22: [2, 13]
                }, {
                  15: [1, 29],
                  17: [1, 30],
                  18: [1, 33],
                  23: 38,
                  25: 27,
                  26: 28,
                  27: 32,
                  29: 34,
                  30: [1, 35],
                  31: [1, 31],
                  32: [1, 36],
                  33: [1, 37]
                }, {
                  24: [1, 39]
                }, {
                  24: [2, 23]
                }, {
                  24: [2, 24],
                  28: [1, 40]
                }, {
                  24: [2, 30]
                }, {
                  24: [2, 31]
                }, {
                  24: [2, 32]
                }, {
                  24: [2, 25],
                  28: [2, 25]
                }, {
                  24: [2, 27],
                  28: [2, 27]
                }, {
                  24: [2, 28],
                  28: [2, 28]
                }, {
                  24: [2, 29],
                  28: [2, 29]
                }, {
                  24: [2, 33],
                  28: [2, 33]
                }, {
                  24: [2, 34],
                  28: [2, 34]
                }, {
                  24: [1, 41]
                }, {
                  1: [2, 21],
                  12: [2, 21],
                  14: [2, 21],
                  22: [2, 21]
                }, {
                  18: [1, 33],
                  27: 42,
                  29: 34,
                  30: [1, 35],
                  32: [1, 36],
                  33: [1, 37]
                }, {
                  1: [2, 22],
                  12: [2, 22],
                  14: [2, 22],
                  22: [2, 22]
                }, {
                  24: [2, 26],
                  28: [2, 26]
                }],
                defaultActions: {
                  27: [2, 23],
                  29: [2, 30],
                  30: [2, 31],
                  31: [2, 32]
                },
                parseError: function parseError(str, hash) {
                  if (hash.recoverable) {
                    this.trace(str);
                  } else {
                    throw new Error(str);
                  }
                },
                parse: function parse(input) {
                  var self = this,
                    stack = [0],
                    vstack = [null],
                    lstack = [],
                    table = this.table,
                    yytext = '',
                    yylineno = 0,
                    yyleng = 0,
                    TERROR = 2,
                    EOF = 1;
                  var args = lstack.slice.call(arguments, 1);
                  this.lexer.setInput(input);
                  this.lexer.yy = this.yy;
                  this.yy.lexer = this.lexer;
                  this.yy.parser = this;
                  if (typeof this.lexer.yylloc == 'undefined') {
                    this.lexer.yylloc = {};
                  }
                  var yyloc = this.lexer.yylloc;
                  lstack.push(yyloc);
                  var ranges = this.lexer.options && this.lexer.options.ranges;
                  if (typeof this.yy.parseError === 'function') {
                    this.parseError = this.yy.parseError;
                  } else {
                    this.parseError = Object.getPrototypeOf(this).parseError;
                  }
                  function lex() {
                    var token;
                    token = self.lexer.lex() || EOF;
                    if (typeof token !== 'number') {
                      token = self.symbols_[token] || token;
                    }
                    return token;
                  }
                  var symbol,
                    state,
                    action,
                    r,
                    yyval = {},
                    p,
                    len,
                    newState,
                    expected;
                  while (true) {
                    state = stack[stack.length - 1];
                    if (this.defaultActions[state]) {
                      action = this.defaultActions[state];
                    } else {
                      if (symbol === null || typeof symbol == 'undefined') {
                        symbol = lex();
                      }
                      action = table[state] && table[state][symbol];
                    }
                    if (typeof action === 'undefined' || !action.length || !action[0]) {
                      var errStr = '';
                      expected = [];
                      for (p in table[state]) {
                        if (this.terminals_[p] && p > TERROR) {
                          expected.push('\'' + this.terminals_[p] + '\'');
                        }
                      }
                      if (this.lexer.showPosition) {
                        errStr = 'Parse error on line ' + (yylineno + 1) + ':\n' + this.lexer.showPosition() + '\nExpecting ' + expected.join(', ') + ', got \'' + (this.terminals_[symbol] || symbol) + '\'';
                      } else {
                        errStr = 'Parse error on line ' + (yylineno + 1) + ': Unexpected ' + (symbol == EOF ? 'end of input' : '\'' + (this.terminals_[symbol] || symbol) + '\'');
                      }
                      this.parseError(errStr, {
                        text: this.lexer.match,
                        token: this.terminals_[symbol] || symbol,
                        line: this.lexer.yylineno,
                        loc: yyloc,
                        expected: expected
                      });
                    }
                    if (action[0] instanceof Array && action.length > 1) {
                      throw new Error('Parse Error: multiple actions possible at state: ' + state + ', token: ' + symbol);
                    }
                    switch (action[0]) {
                      case 1:
                        stack.push(symbol);
                        vstack.push(this.lexer.yytext);
                        lstack.push(this.lexer.yylloc);
                        stack.push(action[1]);
                        symbol = null;
                        {
                          yyleng = this.lexer.yyleng;
                          yytext = this.lexer.yytext;
                          yylineno = this.lexer.yylineno;
                          yyloc = this.lexer.yylloc;
                        }
                        break;
                      case 2:
                        len = this.productions_[action[1]][1];
                        yyval.$ = vstack[vstack.length - len];
                        yyval._$ = {
                          first_line: lstack[lstack.length - (len || 1)].first_line,
                          last_line: lstack[lstack.length - 1].last_line,
                          first_column: lstack[lstack.length - (len || 1)].first_column,
                          last_column: lstack[lstack.length - 1].last_column
                        };
                        if (ranges) {
                          yyval._$.range = [lstack[lstack.length - (len || 1)].range[0], lstack[lstack.length - 1].range[1]];
                        }
                        r = this.performAction.apply(yyval, [yytext, yyleng, yylineno, this.yy, action[1], vstack, lstack].concat(args));
                        if (typeof r !== 'undefined') {
                          return r;
                        }
                        if (len) {
                          stack = stack.slice(0, -1 * len * 2);
                          vstack = vstack.slice(0, -1 * len);
                          lstack = lstack.slice(0, -1 * len);
                        }
                        stack.push(this.productions_[action[1]][0]);
                        vstack.push(yyval.$);
                        lstack.push(yyval._$);
                        newState = table[stack[stack.length - 2]][stack[stack.length - 1]];
                        stack.push(newState);
                        break;
                      case 3:
                        return true;
                    }
                  }
                  return true;
                }
              };
              var _ast = {
                initialize: function () {
                  this._nodes = [];
                  this._node = {};
                  this._stash = [];
                },
                set: function (props) {
                  for (var k in props) this._node[k] = props[k];
                  return this._node;
                },
                node: function (obj) {
                  if (arguments.length) this._node = obj;
                  return this._node;
                },
                push: function () {
                  this._nodes.push(this._node);
                  this._node = {};
                },
                unshift: function () {
                  this._nodes.unshift(this._node);
                  this._node = {};
                },
                yield: function () {
                  var _nodes = this._nodes;
                  this.initialize();
                  return _nodes;
                }
              };
              /* generated by jison-lex 0.2.1 */
              var lexer = function () {
                var lexer = {
                  EOF: 1,
                  parseError: function parseError(str, hash) {
                    if (this.yy.parser) {
                      this.yy.parser.parseError(str, hash);
                    } else {
                      throw new Error(str);
                    }
                  },
                  // resets the lexer, sets new input
                  setInput: function (input) {
                    this._input = input;
                    this._more = this._backtrack = this.done = false;
                    this.yylineno = this.yyleng = 0;
                    this.yytext = this.matched = this.match = '';
                    this.conditionStack = ['INITIAL'];
                    this.yylloc = {
                      first_line: 1,
                      first_column: 0,
                      last_line: 1,
                      last_column: 0
                    };
                    if (this.options.ranges) {
                      this.yylloc.range = [0, 0];
                    }
                    this.offset = 0;
                    return this;
                  },
                  // consumes and returns one char from the input
                  input: function () {
                    var ch = this._input[0];
                    this.yytext += ch;
                    this.yyleng++;
                    this.offset++;
                    this.match += ch;
                    this.matched += ch;
                    var lines = ch.match(/(?:\r\n?|\n).*/g);
                    if (lines) {
                      this.yylineno++;
                      this.yylloc.last_line++;
                    } else {
                      this.yylloc.last_column++;
                    }
                    if (this.options.ranges) {
                      this.yylloc.range[1]++;
                    }
                    this._input = this._input.slice(1);
                    return ch;
                  },
                  // unshifts one char (or a string) into the input
                  unput: function (ch) {
                    var len = ch.length;
                    var lines = ch.split(/(?:\r\n?|\n)/g);
                    this._input = ch + this._input;
                    this.yytext = this.yytext.substr(0, this.yytext.length - len - 1);
                    //this.yyleng -= len;
                    this.offset -= len;
                    var oldLines = this.match.split(/(?:\r\n?|\n)/g);
                    this.match = this.match.substr(0, this.match.length - 1);
                    this.matched = this.matched.substr(0, this.matched.length - 1);
                    if (lines.length - 1) {
                      this.yylineno -= lines.length - 1;
                    }
                    var r = this.yylloc.range;
                    this.yylloc = {
                      first_line: this.yylloc.first_line,
                      last_line: this.yylineno + 1,
                      first_column: this.yylloc.first_column,
                      last_column: lines ? (lines.length === oldLines.length ? this.yylloc.first_column : 0) + oldLines[oldLines.length - lines.length].length - lines[0].length : this.yylloc.first_column - len
                    };
                    if (this.options.ranges) {
                      this.yylloc.range = [r[0], r[0] + this.yyleng - len];
                    }
                    this.yyleng = this.yytext.length;
                    return this;
                  },
                  // When called from action, caches matched text and appends it on next action
                  more: function () {
                    this._more = true;
                    return this;
                  },
                  // When called from action, signals the lexer that this rule fails to match the input, so the next matching rule (regex) should be tested instead.
                  reject: function () {
                    if (this.options.backtrack_lexer) {
                      this._backtrack = true;
                    } else {
                      return this.parseError('Lexical error on line ' + (this.yylineno + 1) + '. You can only invoke reject() in the lexer when the lexer is of the backtracking persuasion (options.backtrack_lexer = true).\n' + this.showPosition(), {
                        text: "",
                        token: null,
                        line: this.yylineno
                      });
                    }
                    return this;
                  },
                  // retain first n characters of the match
                  less: function (n) {
                    this.unput(this.match.slice(n));
                  },
                  // displays already matched input, i.e. for error messages
                  pastInput: function () {
                    var past = this.matched.substr(0, this.matched.length - this.match.length);
                    return (past.length > 20 ? '...' : '') + past.substr(-20).replace(/\n/g, "");
                  },
                  // displays upcoming input, i.e. for error messages
                  upcomingInput: function () {
                    var next = this.match;
                    if (next.length < 20) {
                      next += this._input.substr(0, 20 - next.length);
                    }
                    return (next.substr(0, 20) + (next.length > 20 ? '...' : '')).replace(/\n/g, "");
                  },
                  // displays the character position where the lexing error occurred, i.e. for error messages
                  showPosition: function () {
                    var pre = this.pastInput();
                    var c = new Array(pre.length + 1).join("-");
                    return pre + this.upcomingInput() + "\n" + c + "^";
                  },
                  // test the lexed token: return FALSE when not a match, otherwise return token
                  test_match: function (match, indexed_rule) {
                    var token, lines, backup;
                    if (this.options.backtrack_lexer) {
                      // save context
                      backup = {
                        yylineno: this.yylineno,
                        yylloc: {
                          first_line: this.yylloc.first_line,
                          last_line: this.last_line,
                          first_column: this.yylloc.first_column,
                          last_column: this.yylloc.last_column
                        },
                        yytext: this.yytext,
                        match: this.match,
                        matches: this.matches,
                        matched: this.matched,
                        yyleng: this.yyleng,
                        offset: this.offset,
                        _more: this._more,
                        _input: this._input,
                        yy: this.yy,
                        conditionStack: this.conditionStack.slice(0),
                        done: this.done
                      };
                      if (this.options.ranges) {
                        backup.yylloc.range = this.yylloc.range.slice(0);
                      }
                    }
                    lines = match[0].match(/(?:\r\n?|\n).*/g);
                    if (lines) {
                      this.yylineno += lines.length;
                    }
                    this.yylloc = {
                      first_line: this.yylloc.last_line,
                      last_line: this.yylineno + 1,
                      first_column: this.yylloc.last_column,
                      last_column: lines ? lines[lines.length - 1].length - lines[lines.length - 1].match(/\r?\n?/)[0].length : this.yylloc.last_column + match[0].length
                    };
                    this.yytext += match[0];
                    this.match += match[0];
                    this.matches = match;
                    this.yyleng = this.yytext.length;
                    if (this.options.ranges) {
                      this.yylloc.range = [this.offset, this.offset += this.yyleng];
                    }
                    this._more = false;
                    this._backtrack = false;
                    this._input = this._input.slice(match[0].length);
                    this.matched += match[0];
                    token = this.performAction.call(this, this.yy, this, indexed_rule, this.conditionStack[this.conditionStack.length - 1]);
                    if (this.done && this._input) {
                      this.done = false;
                    }
                    if (token) {
                      return token;
                    } else if (this._backtrack) {
                      // recover context
                      for (var k in backup) {
                        this[k] = backup[k];
                      }
                      return false; // rule action called reject() implying the next rule should be tested instead.
                    }
                    return false;
                  },
                  // return next match in input
                  next: function () {
                    if (this.done) {
                      return this.EOF;
                    }
                    if (!this._input) {
                      this.done = true;
                    }
                    var token, match, tempMatch, index;
                    if (!this._more) {
                      this.yytext = '';
                      this.match = '';
                    }
                    var rules = this._currentRules();
                    for (var i = 0; i < rules.length; i++) {
                      tempMatch = this._input.match(this.rules[rules[i]]);
                      if (tempMatch && (!match || tempMatch[0].length > match[0].length)) {
                        match = tempMatch;
                        index = i;
                        if (this.options.backtrack_lexer) {
                          token = this.test_match(tempMatch, rules[i]);
                          if (token !== false) {
                            return token;
                          } else if (this._backtrack) {
                            match = false;
                            continue; // rule action called reject() implying a rule MISmatch.
                          } else {
                            // else: this is a lexer rule which consumes input without producing a token (e.g. whitespace)
                            return false;
                          }
                        } else if (!this.options.flex) {
                          break;
                        }
                      }
                    }
                    if (match) {
                      token = this.test_match(match, rules[index]);
                      if (token !== false) {
                        return token;
                      }
                      // else: this is a lexer rule which consumes input without producing a token (e.g. whitespace)
                      return false;
                    }
                    if (this._input === "") {
                      return this.EOF;
                    } else {
                      return this.parseError('Lexical error on line ' + (this.yylineno + 1) + '. Unrecognized text.\n' + this.showPosition(), {
                        text: "",
                        token: null,
                        line: this.yylineno
                      });
                    }
                  },
                  // return next match that has a token
                  lex: function lex() {
                    var r = this.next();
                    if (r) {
                      return r;
                    } else {
                      return this.lex();
                    }
                  },
                  // activates a new lexer condition state (pushes the new lexer condition state onto the condition stack)
                  begin: function begin(condition) {
                    this.conditionStack.push(condition);
                  },
                  // pop the previously active lexer condition state off the condition stack
                  popState: function popState() {
                    var n = this.conditionStack.length - 1;
                    if (n > 0) {
                      return this.conditionStack.pop();
                    } else {
                      return this.conditionStack[0];
                    }
                  },
                  // produce the lexer rule set which is active for the currently active lexer condition state
                  _currentRules: function _currentRules() {
                    if (this.conditionStack.length && this.conditionStack[this.conditionStack.length - 1]) {
                      return this.conditions[this.conditionStack[this.conditionStack.length - 1]].rules;
                    } else {
                      return this.conditions["INITIAL"].rules;
                    }
                  },
                  // return the currently active lexer condition state; when an index argument is provided it produces the N-th previous condition state, if available
                  topState: function topState(n) {
                    n = this.conditionStack.length - 1 - Math.abs(n || 0);
                    if (n >= 0) {
                      return this.conditionStack[n];
                    } else {
                      return "INITIAL";
                    }
                  },
                  // alias for begin(condition)
                  pushState: function pushState(condition) {
                    this.begin(condition);
                  },
                  // return the number of states currently on the stack
                  stateStackSize: function stateStackSize() {
                    return this.conditionStack.length;
                  },
                  options: {},
                  performAction: function anonymous(yy, yy_, $avoiding_name_collisions, YY_START
                  /**/) {
                    switch ($avoiding_name_collisions) {
                      case 0:
                        return 4;
                      case 1:
                        return 14;
                      case 2:
                        return 12;
                      case 3:
                        return 15;
                      case 4:
                        return 16;
                      case 5:
                        return 22;
                      case 6:
                        return 24;
                      case 7:
                        return 28;
                      case 8:
                        return 30;
                      case 9:
                        return 18;
                      case 10:
                        yy_.yytext = yy_.yytext.substr(1, yy_.yyleng - 2);
                        return 32;
                      case 11:
                        yy_.yytext = yy_.yytext.substr(1, yy_.yyleng - 2);
                        return 33;
                      case 12:
                        return 17;
                      case 13:
                        return 31;
                    }
                  },
                  rules: [/^(?:\$)/, /^(?:\.\.)/, /^(?:\.)/, /^(?:\*)/, /^(?:[a-zA-Z_]+[a-zA-Z0-9_]*)/, /^(?:\[)/, /^(?:\])/, /^(?:,)/, /^(?:((-?(?:0|[1-9][0-9]*)))?\:((-?(?:0|[1-9][0-9]*)))?(\:((-?(?:0|[1-9][0-9]*)))?)?)/, /^(?:(-?(?:0|[1-9][0-9]*)))/, /^(?:"(?:\\["bfnrt/\\]|\\u[a-fA-F0-9]{4}|[^"\\])*")/, /^(?:'(?:\\['bfnrt/\\]|\\u[a-fA-F0-9]{4}|[^'\\])*')/, /^(?:\(.+?\)(?=\]))/, /^(?:\?\(.+?\)(?=\]))/],
                  conditions: {
                    "INITIAL": {
                      "rules": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13],
                      "inclusive": true
                    }
                  }
                };
                return lexer;
              }();
              parser.lexer = lexer;
              function Parser() {
                this.yy = {};
              }
              Parser.prototype = parser;
              parser.Parser = Parser;
              return new Parser();
            }();
            if (typeof require !== 'undefined' && typeof exports !== 'undefined') {
              exports.parser = parser;
              exports.Parser = parser.Parser;
              exports.parse = function () {
                return parser.parse.apply(parser, arguments);
              };
              exports.main = function commonjsMain(args) {
                if (!args[1]) {
                  console.log('Usage: ' + args[0] + ' FILE');
                  process.exit(1);
                }
                var source = require('fs').readFileSync(require('path').normalize(args[1]), "utf8");
                return exports.parser.parse(source);
              };
              if (typeof module !== 'undefined' && require.main === module) {
                exports.main(process.argv.slice(1));
              }
            }
          }).call(this, require('_process'));
        }, {
          "_process": 14,
          "fs": 12,
          "path": 13
        }],
        2: [function (require, module, exports) {
          module.exports = {
            identifier: "[a-zA-Z_]+[a-zA-Z0-9_]*",
            integer: "-?(?:0|[1-9][0-9]*)",
            qq_string: "\"(?:\\\\[\"bfnrt/\\\\]|\\\\u[a-fA-F0-9]{4}|[^\"\\\\])*\"",
            q_string: "'(?:\\\\[\'bfnrt/\\\\]|\\\\u[a-fA-F0-9]{4}|[^\'\\\\])*'"
          };
        }, {}],
        3: [function (require, module, exports) {
          var dict = require('./dict');
          var fs = require('fs');
          var grammar = {
            lex: {
              macros: {
                esc: "\\\\",
                int: dict.integer
              },
              rules: [["\\$", "return 'DOLLAR'"], ["\\.\\.", "return 'DOT_DOT'"], ["\\.", "return 'DOT'"], ["\\*", "return 'STAR'"], [dict.identifier, "return 'IDENTIFIER'"], ["\\[", "return '['"], ["\\]", "return ']'"], [",", "return ','"], ["({int})?\\:({int})?(\\:({int})?)?", "return 'ARRAY_SLICE'"], ["{int}", "return 'INTEGER'"], [dict.qq_string, "yytext = yytext.substr(1,yyleng-2); return 'QQ_STRING';"], [dict.q_string, "yytext = yytext.substr(1,yyleng-2); return 'Q_STRING';"], ["\\(.+?\\)(?=\\])", "return 'SCRIPT_EXPRESSION'"], ["\\?\\(.+?\\)(?=\\])", "return 'FILTER_EXPRESSION'"]]
            },
            start: "JSON_PATH",
            bnf: {
              JSON_PATH: [['DOLLAR', 'yy.ast.set({ expression: { type: "root", value: $1 } }); yy.ast.unshift(); return yy.ast.yield()'], ['DOLLAR PATH_COMPONENTS', 'yy.ast.set({ expression: { type: "root", value: $1 } }); yy.ast.unshift(); return yy.ast.yield()'], ['LEADING_CHILD_MEMBER_EXPRESSION', 'yy.ast.unshift(); return yy.ast.yield()'], ['LEADING_CHILD_MEMBER_EXPRESSION PATH_COMPONENTS', 'yy.ast.set({ operation: "member", scope: "child", expression: { type: "identifier", value: $1 }}); yy.ast.unshift(); return yy.ast.yield()']],
              PATH_COMPONENTS: [['PATH_COMPONENT', ''], ['PATH_COMPONENTS PATH_COMPONENT', '']],
              PATH_COMPONENT: [['MEMBER_COMPONENT', 'yy.ast.set({ operation: "member" }); yy.ast.push()'], ['SUBSCRIPT_COMPONENT', 'yy.ast.set({ operation: "subscript" }); yy.ast.push() ']],
              MEMBER_COMPONENT: [['CHILD_MEMBER_COMPONENT', 'yy.ast.set({ scope: "child" })'], ['DESCENDANT_MEMBER_COMPONENT', 'yy.ast.set({ scope: "descendant" })']],
              CHILD_MEMBER_COMPONENT: [['DOT MEMBER_EXPRESSION', '']],
              LEADING_CHILD_MEMBER_EXPRESSION: [['MEMBER_EXPRESSION', 'yy.ast.set({ scope: "child", operation: "member" })']],
              DESCENDANT_MEMBER_COMPONENT: [['DOT_DOT MEMBER_EXPRESSION', '']],
              MEMBER_EXPRESSION: [['STAR', 'yy.ast.set({ expression: { type: "wildcard", value: $1 } })'], ['IDENTIFIER', 'yy.ast.set({ expression: { type: "identifier", value: $1 } })'], ['SCRIPT_EXPRESSION', 'yy.ast.set({ expression: { type: "script_expression", value: $1 } })'], ['INTEGER', 'yy.ast.set({ expression: { type: "numeric_literal", value: parseInt($1) } })'], ['END', '']],
              SUBSCRIPT_COMPONENT: [['CHILD_SUBSCRIPT_COMPONENT', 'yy.ast.set({ scope: "child" })'], ['DESCENDANT_SUBSCRIPT_COMPONENT', 'yy.ast.set({ scope: "descendant" })']],
              CHILD_SUBSCRIPT_COMPONENT: [['[ SUBSCRIPT ]', '']],
              DESCENDANT_SUBSCRIPT_COMPONENT: [['DOT_DOT [ SUBSCRIPT ]', '']],
              SUBSCRIPT: [['SUBSCRIPT_EXPRESSION', ''], ['SUBSCRIPT_EXPRESSION_LIST', '$1.length > 1? yy.ast.set({ expression: { type: "union", value: $1 } }) : $$ = $1']],
              SUBSCRIPT_EXPRESSION_LIST: [['SUBSCRIPT_EXPRESSION_LISTABLE', '$$ = [$1]'], ['SUBSCRIPT_EXPRESSION_LIST , SUBSCRIPT_EXPRESSION_LISTABLE', '$$ = $1.concat($3)']],
              SUBSCRIPT_EXPRESSION_LISTABLE: [['INTEGER', '$$ = { expression: { type: "numeric_literal", value: parseInt($1) } }; yy.ast.set($$)'], ['STRING_LITERAL', '$$ = { expression: { type: "string_literal", value: $1 } }; yy.ast.set($$)'], ['ARRAY_SLICE', '$$ = { expression: { type: "slice", value: $1 } }; yy.ast.set($$)']],
              SUBSCRIPT_EXPRESSION: [['STAR', '$$ = { expression: { type: "wildcard", value: $1 } }; yy.ast.set($$)'], ['SCRIPT_EXPRESSION', '$$ = { expression: { type: "script_expression", value: $1 } }; yy.ast.set($$)'], ['FILTER_EXPRESSION', '$$ = { expression: { type: "filter_expression", value: $1 } }; yy.ast.set($$)']],
              STRING_LITERAL: [['QQ_STRING', "$$ = $1"], ['Q_STRING', "$$ = $1"]]
            }
          };
          if (fs.readFileSync) {
            grammar.moduleInclude = fs.readFileSync(require.resolve("../include/module.js"));
            grammar.actionInclude = fs.readFileSync(require.resolve("../include/action.js"));
          }
          module.exports = grammar;
        }, {
          "./dict": 2,
          "fs": 12
        }],
        4: [function (require, module, exports) {
          var aesprim = require('./aesprim');
          var slice = require('./slice');
          var _evaluate = require('static-eval');
          var _uniq = require('underscore').uniq;
          var Handlers = function () {
            return this.initialize.apply(this, arguments);
          };
          Handlers.prototype.initialize = function () {
            this.traverse = traverser(true);
            this.descend = traverser();
          };
          Handlers.prototype.keys = Object.keys;
          Handlers.prototype.resolve = function (component) {
            var key = [component.operation, component.scope, component.expression.type].join('-');
            var method = this._fns[key];
            if (!method) throw new Error("couldn't resolve key: " + key);
            return method.bind(this);
          };
          Handlers.prototype.register = function (key, handler) {
            if (!handler instanceof Function) {
              throw new Error("handler must be a function");
            }
            this._fns[key] = handler;
          };
          Handlers.prototype._fns = {
            'member-child-identifier': function (component, partial) {
              var key = component.expression.value;
              var value = partial.value;
              if (value instanceof Object && key in value) {
                return [{
                  value: value[key],
                  path: partial.path.concat(key)
                }];
              }
            },
            'member-descendant-identifier': _traverse(function (key, value, ref) {
              return key == ref;
            }),
            'subscript-child-numeric_literal': _descend(function (key, value, ref) {
              return key === ref;
            }),
            'member-child-numeric_literal': _descend(function (key, value, ref) {
              return String(key) === String(ref);
            }),
            'subscript-descendant-numeric_literal': _traverse(function (key, value, ref) {
              return key === ref;
            }),
            'member-child-wildcard': _descend(function () {
              return true;
            }),
            'member-descendant-wildcard': _traverse(function () {
              return true;
            }),
            'subscript-descendant-wildcard': _traverse(function () {
              return true;
            }),
            'subscript-child-wildcard': _descend(function () {
              return true;
            }),
            'subscript-child-slice': function (component, partial) {
              if (is_array(partial.value)) {
                var args = component.expression.value.split(':').map(_parse_nullable_int);
                var values = partial.value.map(function (v, i) {
                  return {
                    value: v,
                    path: partial.path.concat(i)
                  };
                });
                return slice.apply(null, [values].concat(args));
              }
            },
            'subscript-child-union': function (component, partial) {
              var results = [];
              component.expression.value.forEach(function (component) {
                var _component = {
                  operation: 'subscript',
                  scope: 'child',
                  expression: component.expression
                };
                var handler = this.resolve(_component);
                var _results = handler(_component, partial);
                if (_results) {
                  results = results.concat(_results);
                }
              }, this);
              return unique(results);
            },
            'subscript-descendant-union': function (component, partial, count) {
              var jp = require('..');
              var self = this;
              var results = [];
              var nodes = jp.nodes(partial, '$..*').slice(1);
              nodes.forEach(function (node) {
                if (results.length >= count) return;
                component.expression.value.forEach(function (component) {
                  var _component = {
                    operation: 'subscript',
                    scope: 'child',
                    expression: component.expression
                  };
                  var handler = self.resolve(_component);
                  var _results = handler(_component, node);
                  results = results.concat(_results);
                });
              });
              return unique(results);
            },
            'subscript-child-filter_expression': function (component, partial, count) {
              // slice out the expression from ?(expression)
              var src = component.expression.value.slice(2, -1);
              var ast = aesprim.parse(src).body[0].expression;
              var passable = function (key, value) {
                return evaluate(ast, {
                  '@': value
                });
              };
              return this.descend(partial, null, passable, count);
            },
            'subscript-descendant-filter_expression': function (component, partial, count) {
              // slice out the expression from ?(expression)
              var src = component.expression.value.slice(2, -1);
              var ast = aesprim.parse(src).body[0].expression;
              var passable = function (key, value) {
                return evaluate(ast, {
                  '@': value
                });
              };
              return this.traverse(partial, null, passable, count);
            },
            'subscript-child-script_expression': function (component, partial) {
              var exp = component.expression.value.slice(1, -1);
              return eval_recurse(partial, exp, '$[{{value}}]');
            },
            'member-child-script_expression': function (component, partial) {
              var exp = component.expression.value.slice(1, -1);
              return eval_recurse(partial, exp, '$.{{value}}');
            },
            'member-descendant-script_expression': function (component, partial) {
              var exp = component.expression.value.slice(1, -1);
              return eval_recurse(partial, exp, '$..value');
            }
          };
          Handlers.prototype._fns['subscript-child-string_literal'] = Handlers.prototype._fns['member-child-identifier'];
          Handlers.prototype._fns['member-descendant-numeric_literal'] = Handlers.prototype._fns['subscript-descendant-string_literal'] = Handlers.prototype._fns['member-descendant-identifier'];
          function eval_recurse(partial, src, template) {
            var jp = require('./index');
            var ast = aesprim.parse(src).body[0].expression;
            var value = evaluate(ast, {
              '@': partial.value
            });
            var path = template.replace(/\{\{\s*value\s*\}\}/g, value);
            var results = jp.nodes(partial.value, path);
            results.forEach(function (r) {
              r.path = partial.path.concat(r.path.slice(1));
            });
            return results;
          }
          function is_array(val) {
            return Array.isArray(val);
          }
          function is_object(val) {
            // is this a non-array, non-null object?
            return val && !(val instanceof Array) && val instanceof Object;
          }
          function traverser(recurse) {
            return function (partial, ref, passable, count) {
              var value = partial.value;
              var path = partial.path;
              var results = [];
              var descend = function (value, path) {
                if (is_array(value)) {
                  value.forEach(function (element, index) {
                    if (results.length >= count) {
                      return;
                    }
                    if (passable(index, element, ref)) {
                      results.push({
                        path: path.concat(index),
                        value: element
                      });
                    }
                  });
                  value.forEach(function (element, index) {
                    if (results.length >= count) {
                      return;
                    }
                    if (recurse) {
                      descend(element, path.concat(index));
                    }
                  });
                } else if (is_object(value)) {
                  this.keys(value).forEach(function (k) {
                    if (results.length >= count) {
                      return;
                    }
                    if (passable(k, value[k], ref)) {
                      results.push({
                        path: path.concat(k),
                        value: value[k]
                      });
                    }
                  });
                  this.keys(value).forEach(function (k) {
                    if (results.length >= count) {
                      return;
                    }
                    if (recurse) {
                      descend(value[k], path.concat(k));
                    }
                  });
                }
              }.bind(this);
              descend(value, path);
              return results;
            };
          }
          function _descend(passable) {
            return function (component, partial, count) {
              return this.descend(partial, component.expression.value, passable, count);
            };
          }
          function _traverse(passable) {
            return function (component, partial, count) {
              return this.traverse(partial, component.expression.value, passable, count);
            };
          }
          function evaluate() {
            try {
              return _evaluate.apply(this, arguments);
            } catch (e) {}
          }
          function unique(results) {
            results = results.filter(function (d) {
              return d;
            });
            return _uniq(results, function (r) {
              return r.path.map(function (c) {
                return String(c).replace('-', '--');
              }).join('-');
            });
          }
          function _parse_nullable_int(val) {
            var sval = String(val);
            return sval.match(/^-?[0-9]+$/) ? parseInt(sval) : null;
          }
          module.exports = Handlers;
        }, {
          "..": "jsonpath",
          "./aesprim": "./aesprim",
          "./index": 5,
          "./slice": 7,
          "static-eval": 15,
          "underscore": 12
        }],
        5: [function (require, module, exports) {
          var assert = require('assert');
          var dict = require('./dict');
          var Parser = require('./parser');
          var Handlers = require('./handlers');
          var JSONPath = function () {
            this.initialize.apply(this, arguments);
          };
          JSONPath.prototype.initialize = function () {
            this.parser = new Parser();
            this.handlers = new Handlers();
          };
          JSONPath.prototype.parse = function (string) {
            assert.ok(_is_string(string), "we need a path");
            return this.parser.parse(string);
          };
          JSONPath.prototype.parent = function (obj, string) {
            assert.ok(obj instanceof Object, "obj needs to be an object");
            assert.ok(string, "we need a path");
            var node = this.nodes(obj, string)[0];
            node.path.pop(); /* jshint unused:false */
            return this.value(obj, node.path);
          };
          JSONPath.prototype.apply = function (obj, string, fn) {
            assert.ok(obj instanceof Object, "obj needs to be an object");
            assert.ok(string, "we need a path");
            assert.equal(typeof fn, "function", "fn needs to be function");
            var nodes = this.nodes(obj, string).sort(function (a, b) {
              // sort nodes so we apply from the bottom up
              return b.path.length - a.path.length;
            });
            nodes.forEach(function (node) {
              var key = node.path.pop();
              var parent = this.value(obj, this.stringify(node.path));
              var val = node.value = fn.call(obj, parent[key]);
              parent[key] = val;
            }, this);
            return nodes;
          };
          JSONPath.prototype.value = function (obj, path, value) {
            assert.ok(obj instanceof Object, "obj needs to be an object");
            assert.ok(path, "we need a path");
            if (arguments.length >= 3) {
              var node = this.nodes(obj, path).shift();
              if (!node) return this._vivify(obj, path, value);
              var key = node.path.slice(-1).shift();
              var parent = this.parent(obj, this.stringify(node.path));
              parent[key] = value;
            }
            return this.query(obj, this.stringify(path), 1).shift();
          };
          JSONPath.prototype._vivify = function (obj, string, value) {
            var self = this;
            assert.ok(obj instanceof Object, "obj needs to be an object");
            assert.ok(string, "we need a path");
            var path = this.parser.parse(string).map(function (component) {
              return component.expression.value;
            });
            var setValue = function (path, value) {
              var key = path.pop();
              var node = self.value(obj, path);
              if (!node) {
                setValue(path.concat(), typeof key === 'string' ? {} : []);
                node = self.value(obj, path);
              }
              node[key] = value;
            };
            setValue(path, value);
            return this.query(obj, string)[0];
          };
          JSONPath.prototype.query = function (obj, string, count) {
            assert.ok(obj instanceof Object, "obj needs to be an object");
            assert.ok(_is_string(string), "we need a path");
            var results = this.nodes(obj, string, count).map(function (r) {
              return r.value;
            });
            return results;
          };
          JSONPath.prototype.paths = function (obj, string, count) {
            assert.ok(obj instanceof Object, "obj needs to be an object");
            assert.ok(string, "we need a path");
            var results = this.nodes(obj, string, count).map(function (r) {
              return r.path;
            });
            return results;
          };
          JSONPath.prototype.nodes = function (obj, string, count) {
            assert.ok(obj instanceof Object, "obj needs to be an object");
            assert.ok(string, "we need a path");
            if (count === 0) return [];
            var path = this.parser.parse(string);
            var handlers = this.handlers;
            var partials = [{
              path: ['$'],
              value: obj
            }];
            var matches = [];
            if (path.length && path[0].expression.type == 'root') path.shift();
            if (!path.length) return partials;
            path.forEach(function (component, index) {
              if (matches.length >= count) return;
              var handler = handlers.resolve(component);
              var _partials = [];
              partials.forEach(function (p) {
                if (matches.length >= count) return;
                var results = handler(component, p, count);
                if (index == path.length - 1) {
                  // if we're through the components we're done
                  matches = matches.concat(results || []);
                } else {
                  // otherwise accumulate and carry on through
                  _partials = _partials.concat(results || []);
                }
              });
              partials = _partials;
            });
            return count ? matches.slice(0, count) : matches;
          };
          JSONPath.prototype.stringify = function (path) {
            assert.ok(path, "we need a path");
            var string = '$';
            var templates = {
              'descendant-member': '..{{value}}',
              'child-member': '.{{value}}',
              'descendant-subscript': '..[{{value}}]',
              'child-subscript': '[{{value}}]'
            };
            path = this._normalize(path);
            path.forEach(function (component) {
              if (component.expression.type == 'root') return;
              var key = [component.scope, component.operation].join('-');
              var template = templates[key];
              var value;
              if (component.expression.type == 'string_literal') {
                value = JSON.stringify(component.expression.value);
              } else {
                value = component.expression.value;
              }
              if (!template) throw new Error("couldn't find template " + key);
              string += template.replace(/{{value}}/, value);
            });
            return string;
          };
          JSONPath.prototype._normalize = function (path) {
            assert.ok(path, "we need a path");
            if (typeof path == "string") {
              return this.parser.parse(path);
            } else if (Array.isArray(path) && typeof path[0] == "string") {
              var _path = [{
                expression: {
                  type: "root",
                  value: "$"
                }
              }];
              path.forEach(function (component, index) {
                if (component == '$' && index === 0) return;
                if (typeof component == "string" && component.match("^" + dict.identifier + "$")) {
                  _path.push({
                    operation: 'member',
                    scope: 'child',
                    expression: {
                      value: component,
                      type: 'identifier'
                    }
                  });
                } else {
                  var type = typeof component == "number" ? 'numeric_literal' : 'string_literal';
                  _path.push({
                    operation: 'subscript',
                    scope: 'child',
                    expression: {
                      value: component,
                      type: type
                    }
                  });
                }
              });
              return _path;
            } else if (Array.isArray(path) && typeof path[0] == "object") {
              return path;
            }
            throw new Error("couldn't understand path " + path);
          };
          function _is_string(obj) {
            return Object.prototype.toString.call(obj) == '[object String]';
          }
          JSONPath.Handlers = Handlers;
          JSONPath.Parser = Parser;
          var instance = new JSONPath();
          instance.JSONPath = JSONPath;
          module.exports = instance;
        }, {
          "./dict": 2,
          "./handlers": 4,
          "./parser": 6,
          "assert": 8
        }],
        6: [function (require, module, exports) {
          var grammar = require('./grammar');
          var gparser = require('../generated/parser');
          var Parser = function () {
            var parser = new gparser.Parser();
            var _parseError = parser.parseError;
            parser.yy.parseError = function () {
              if (parser.yy.ast) {
                parser.yy.ast.initialize();
              }
              _parseError.apply(parser, arguments);
            };
            return parser;
          };
          Parser.grammar = grammar;
          module.exports = Parser;
        }, {
          "../generated/parser": 1,
          "./grammar": 3
        }],
        7: [function (require, module, exports) {
          module.exports = function (arr, start, end, step) {
            if (typeof start == 'string') throw new Error("start cannot be a string");
            if (typeof end == 'string') throw new Error("end cannot be a string");
            if (typeof step == 'string') throw new Error("step cannot be a string");
            var len = arr.length;
            if (step === 0) throw new Error("step cannot be zero");
            step = step ? integer(step) : 1;

            // normalize negative values
            start = start < 0 ? len + start : start;
            end = end < 0 ? len + end : end;

            // default extents to extents
            start = integer(start === 0 ? 0 : !start ? step > 0 ? 0 : len - 1 : start);
            end = integer(end === 0 ? 0 : !end ? step > 0 ? len : -1 : end);

            // clamp extents
            start = step > 0 ? Math.max(0, start) : Math.min(len, start);
            end = step > 0 ? Math.min(end, len) : Math.max(-1, end);

            // return empty if extents are backwards
            if (step > 0 && end <= start) return [];
            if (step < 0 && start <= end) return [];
            var result = [];
            for (var i = start; i != end; i += step) {
              if (step < 0 && i <= end || step > 0 && i >= end) break;
              result.push(arr[i]);
            }
            return result;
          };
          function integer(val) {
            return String(val).match(/^[0-9]+$/) ? parseInt(val) : Number.isFinite(val) ? parseInt(val, 10) : 0;
          }
        }, {}],
        8: [function (require, module, exports) {
          // http://wiki.commonjs.org/wiki/Unit_Testing/1.0
          //
          // THIS IS NOT TESTED NOR LIKELY TO WORK OUTSIDE V8!
          //
          // Originally from narwhal.js (http://narwhaljs.org)
          // Copyright (c) 2009 Thomas Robinson <280north.com>
          //
          // Permission is hereby granted, free of charge, to any person obtaining a copy
          // of this software and associated documentation files (the 'Software'), to
          // deal in the Software without restriction, including without limitation the
          // rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
          // sell copies of the Software, and to permit persons to whom the Software is
          // furnished to do so, subject to the following conditions:
          //
          // The above copyright notice and this permission notice shall be included in
          // all copies or substantial portions of the Software.
          //
          // THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
          // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
          // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
          // AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
          // ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
          // WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

          // when used in node, this will actually load the util module we depend on
          // versus loading the builtin util module as happens otherwise
          // this is a bug in node module loading as far as I am concerned
          var util = require('util/');
          var pSlice = Array.prototype.slice;
          var hasOwn = Object.prototype.hasOwnProperty;

          // 1. The assert module provides functions that throw
          // AssertionError's when particular conditions are not met. The
          // assert module must conform to the following interface.

          var assert = module.exports = ok;

          // 2. The AssertionError is defined in assert.
          // new assert.AssertionError({ message: message,
          //                             actual: actual,
          //                             expected: expected })

          assert.AssertionError = function AssertionError(options) {
            this.name = 'AssertionError';
            this.actual = options.actual;
            this.expected = options.expected;
            this.operator = options.operator;
            if (options.message) {
              this.message = options.message;
              this.generatedMessage = false;
            } else {
              this.message = getMessage(this);
              this.generatedMessage = true;
            }
            var stackStartFunction = options.stackStartFunction || fail;
            if (Error.captureStackTrace) {
              Error.captureStackTrace(this, stackStartFunction);
            } else {
              // non v8 browsers so we can have a stacktrace
              var err = new Error();
              if (err.stack) {
                var out = err.stack;

                // try to strip useless frames
                var fn_name = stackStartFunction.name;
                var idx = out.indexOf('\n' + fn_name);
                if (idx >= 0) {
                  // once we have located the function frame
                  // we need to strip out everything before it (and its line)
                  var next_line = out.indexOf('\n', idx + 1);
                  out = out.substring(next_line + 1);
                }
                this.stack = out;
              }
            }
          };

          // assert.AssertionError instanceof Error
          util.inherits(assert.AssertionError, Error);
          function replacer(key, value) {
            if (util.isUndefined(value)) {
              return '' + value;
            }
            if (util.isNumber(value) && !isFinite(value)) {
              return value.toString();
            }
            if (util.isFunction(value) || util.isRegExp(value)) {
              return value.toString();
            }
            return value;
          }
          function truncate(s, n) {
            if (util.isString(s)) {
              return s.length < n ? s : s.slice(0, n);
            } else {
              return s;
            }
          }
          function getMessage(self) {
            return truncate(JSON.stringify(self.actual, replacer), 128) + ' ' + self.operator + ' ' + truncate(JSON.stringify(self.expected, replacer), 128);
          }

          // At present only the three keys mentioned above are used and
          // understood by the spec. Implementations or sub modules can pass
          // other keys to the AssertionError's constructor - they will be
          // ignored.

          // 3. All of the following functions must throw an AssertionError
          // when a corresponding condition is not met, with a message that
          // may be undefined if not provided.  All assertion methods provide
          // both the actual and expected values to the assertion error for
          // display purposes.

          function fail(actual, expected, message, operator, stackStartFunction) {
            throw new assert.AssertionError({
              message: message,
              actual: actual,
              expected: expected,
              operator: operator,
              stackStartFunction: stackStartFunction
            });
          }

          // EXTENSION! allows for well behaved errors defined elsewhere.
          assert.fail = fail;

          // 4. Pure assertion tests whether a value is truthy, as determined
          // by !!guard.
          // assert.ok(guard, message_opt);
          // This statement is equivalent to assert.equal(true, !!guard,
          // message_opt);. To test strictly for the value true, use
          // assert.strictEqual(true, guard, message_opt);.

          function ok(value, message) {
            if (!value) fail(value, true, message, '==', assert.ok);
          }
          assert.ok = ok;

          // 5. The equality assertion tests shallow, coercive equality with
          // ==.
          // assert.equal(actual, expected, message_opt);

          assert.equal = function equal(actual, expected, message) {
            if (actual != expected) fail(actual, expected, message, '==', assert.equal);
          };

          // 6. The non-equality assertion tests for whether two objects are not equal
          // with != assert.notEqual(actual, expected, message_opt);

          assert.notEqual = function notEqual(actual, expected, message) {
            if (actual == expected) {
              fail(actual, expected, message, '!=', assert.notEqual);
            }
          };

          // 7. The equivalence assertion tests a deep equality relation.
          // assert.deepEqual(actual, expected, message_opt);

          assert.deepEqual = function deepEqual(actual, expected, message) {
            if (!_deepEqual(actual, expected)) {
              fail(actual, expected, message, 'deepEqual', assert.deepEqual);
            }
          };
          function _deepEqual(actual, expected) {
            // 7.1. All identical values are equivalent, as determined by ===.
            if (actual === expected) {
              return true;
            } else if (util.isBuffer(actual) && util.isBuffer(expected)) {
              if (actual.length != expected.length) return false;
              for (var i = 0; i < actual.length; i++) {
                if (actual[i] !== expected[i]) return false;
              }
              return true;

              // 7.2. If the expected value is a Date object, the actual value is
              // equivalent if it is also a Date object that refers to the same time.
            } else if (util.isDate(actual) && util.isDate(expected)) {
              return actual.getTime() === expected.getTime();

              // 7.3 If the expected value is a RegExp object, the actual value is
              // equivalent if it is also a RegExp object with the same source and
              // properties (`global`, `multiline`, `lastIndex`, `ignoreCase`).
            } else if (util.isRegExp(actual) && util.isRegExp(expected)) {
              return actual.source === expected.source && actual.global === expected.global && actual.multiline === expected.multiline && actual.lastIndex === expected.lastIndex && actual.ignoreCase === expected.ignoreCase;

              // 7.4. Other pairs that do not both pass typeof value == 'object',
              // equivalence is determined by ==.
            } else if (!util.isObject(actual) && !util.isObject(expected)) {
              return actual == expected;

              // 7.5 For all other Object pairs, including Array objects, equivalence is
              // determined by having the same number of owned properties (as verified
              // with Object.prototype.hasOwnProperty.call), the same set of keys
              // (although not necessarily the same order), equivalent values for every
              // corresponding key, and an identical 'prototype' property. Note: this
              // accounts for both named and indexed properties on Arrays.
            } else {
              return objEquiv(actual, expected);
            }
          }
          function isArguments(object) {
            return Object.prototype.toString.call(object) == '[object Arguments]';
          }
          function objEquiv(a, b) {
            if (util.isNullOrUndefined(a) || util.isNullOrUndefined(b)) return false;
            // an identical 'prototype' property.
            if (a.prototype !== b.prototype) return false;
            // if one is a primitive, the other must be same
            if (util.isPrimitive(a) || util.isPrimitive(b)) {
              return a === b;
            }
            var aIsArgs = isArguments(a),
              bIsArgs = isArguments(b);
            if (aIsArgs && !bIsArgs || !aIsArgs && bIsArgs) return false;
            if (aIsArgs) {
              a = pSlice.call(a);
              b = pSlice.call(b);
              return _deepEqual(a, b);
            }
            var ka = objectKeys(a),
              kb = objectKeys(b),
              key,
              i;
            // having the same number of owned properties (keys incorporates
            // hasOwnProperty)
            if (ka.length != kb.length) return false;
            //the same set of keys (although not necessarily the same order),
            ka.sort();
            kb.sort();
            //~~~cheap key test
            for (i = ka.length - 1; i >= 0; i--) {
              if (ka[i] != kb[i]) return false;
            }
            //equivalent values for every corresponding key, and
            //~~~possibly expensive deep test
            for (i = ka.length - 1; i >= 0; i--) {
              key = ka[i];
              if (!_deepEqual(a[key], b[key])) return false;
            }
            return true;
          }

          // 8. The non-equivalence assertion tests for any deep inequality.
          // assert.notDeepEqual(actual, expected, message_opt);

          assert.notDeepEqual = function notDeepEqual(actual, expected, message) {
            if (_deepEqual(actual, expected)) {
              fail(actual, expected, message, 'notDeepEqual', assert.notDeepEqual);
            }
          };

          // 9. The strict equality assertion tests strict equality, as determined by ===.
          // assert.strictEqual(actual, expected, message_opt);

          assert.strictEqual = function strictEqual(actual, expected, message) {
            if (actual !== expected) {
              fail(actual, expected, message, '===', assert.strictEqual);
            }
          };

          // 10. The strict non-equality assertion tests for strict inequality, as
          // determined by !==.  assert.notStrictEqual(actual, expected, message_opt);

          assert.notStrictEqual = function notStrictEqual(actual, expected, message) {
            if (actual === expected) {
              fail(actual, expected, message, '!==', assert.notStrictEqual);
            }
          };
          function expectedException(actual, expected) {
            if (!actual || !expected) {
              return false;
            }
            if (Object.prototype.toString.call(expected) == '[object RegExp]') {
              return expected.test(actual);
            } else if (actual instanceof expected) {
              return true;
            } else if (expected.call({}, actual) === true) {
              return true;
            }
            return false;
          }
          function _throws(shouldThrow, block, expected, message) {
            var actual;
            if (util.isString(expected)) {
              message = expected;
              expected = null;
            }
            try {
              block();
            } catch (e) {
              actual = e;
            }
            message = (expected && expected.name ? ' (' + expected.name + ').' : '.') + (message ? ' ' + message : '.');
            if (shouldThrow && !actual) {
              fail(actual, expected, 'Missing expected exception' + message);
            }
            if (!shouldThrow && expectedException(actual, expected)) {
              fail(actual, expected, 'Got unwanted exception' + message);
            }
            if (shouldThrow && actual && expected && !expectedException(actual, expected) || !shouldThrow && actual) {
              throw actual;
            }
          }

          // 11. Expected to throw an error:
          // assert.throws(block, Error_opt, message_opt);

          assert.throws = function (block, /*optional*/error, /*optional*/message) {
            _throws.apply(this, [true].concat(pSlice.call(arguments)));
          };

          // EXTENSION! This is annoying to write outside this module.
          assert.doesNotThrow = function (block, /*optional*/message) {
            _throws.apply(this, [false].concat(pSlice.call(arguments)));
          };
          assert.ifError = function (err) {
            if (err) {
              throw err;
            }
          };
          var objectKeys = Object.keys || function (obj) {
            var keys = [];
            for (var key in obj) {
              if (hasOwn.call(obj, key)) keys.push(key);
            }
            return keys;
          };
        }, {
          "util/": 11
        }],
        9: [function (require, module, exports) {
          if (typeof Object.create === 'function') {
            // implementation from standard node.js 'util' module
            module.exports = function inherits(ctor, superCtor) {
              ctor.super_ = superCtor;
              ctor.prototype = Object.create(superCtor.prototype, {
                constructor: {
                  value: ctor,
                  enumerable: false,
                  writable: true,
                  configurable: true
                }
              });
            };
          } else {
            // old school shim for old browsers
            module.exports = function inherits(ctor, superCtor) {
              ctor.super_ = superCtor;
              var TempCtor = function () {};
              TempCtor.prototype = superCtor.prototype;
              ctor.prototype = new TempCtor();
              ctor.prototype.constructor = ctor;
            };
          }
        }, {}],
        10: [function (require, module, exports) {
          module.exports = function isBuffer(arg) {
            return arg && typeof arg === 'object' && typeof arg.copy === 'function' && typeof arg.fill === 'function' && typeof arg.readUInt8 === 'function';
          };
        }, {}],
        11: [function (require, module, exports) {
          (function (process, global) {
            // Copyright Joyent, Inc. and other Node contributors.
            //
            // Permission is hereby granted, free of charge, to any person obtaining a
            // copy of this software and associated documentation files (the
            // "Software"), to deal in the Software without restriction, including
            // without limitation the rights to use, copy, modify, merge, publish,
            // distribute, sublicense, and/or sell copies of the Software, and to permit
            // persons to whom the Software is furnished to do so, subject to the
            // following conditions:
            //
            // The above copyright notice and this permission notice shall be included
            // in all copies or substantial portions of the Software.
            //
            // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
            // OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
            // MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
            // NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
            // DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
            // OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
            // USE OR OTHER DEALINGS IN THE SOFTWARE.

            var formatRegExp = /%[sdj%]/g;
            exports.format = function (f) {
              if (!isString(f)) {
                var objects = [];
                for (var i = 0; i < arguments.length; i++) {
                  objects.push(inspect(arguments[i]));
                }
                return objects.join(' ');
              }
              var i = 1;
              var args = arguments;
              var len = args.length;
              var str = String(f).replace(formatRegExp, function (x) {
                if (x === '%%') return '%';
                if (i >= len) return x;
                switch (x) {
                  case '%s':
                    return String(args[i++]);
                  case '%d':
                    return Number(args[i++]);
                  case '%j':
                    try {
                      return JSON.stringify(args[i++]);
                    } catch (_) {
                      return '[Circular]';
                    }
                  default:
                    return x;
                }
              });
              for (var x = args[i]; i < len; x = args[++i]) {
                if (isNull(x) || !isObject(x)) {
                  str += ' ' + x;
                } else {
                  str += ' ' + inspect(x);
                }
              }
              return str;
            };

            // Mark that a method should not be used.
            // Returns a modified function which warns once by default.
            // If --no-deprecation is set, then it is a no-op.
            exports.deprecate = function (fn, msg) {
              // Allow for deprecating things in the process of starting up.
              if (isUndefined(global.process)) {
                return function () {
                  return exports.deprecate(fn, msg).apply(this, arguments);
                };
              }
              if (process.noDeprecation === true) {
                return fn;
              }
              var warned = false;
              function deprecated() {
                if (!warned) {
                  if (process.throwDeprecation) {
                    throw new Error(msg);
                  } else if (process.traceDeprecation) {
                    console.trace(msg);
                  } else {
                    console.error(msg);
                  }
                  warned = true;
                }
                return fn.apply(this, arguments);
              }
              return deprecated;
            };
            var debugs = {};
            var debugEnviron;
            exports.debuglog = function (set) {
              if (isUndefined(debugEnviron)) debugEnviron = process.env.NODE_DEBUG || '';
              set = set.toUpperCase();
              if (!debugs[set]) {
                if (new RegExp('\\b' + set + '\\b', 'i').test(debugEnviron)) {
                  var pid = process.pid;
                  debugs[set] = function () {
                    var msg = exports.format.apply(exports, arguments);
                    console.error('%s %d: %s', set, pid, msg);
                  };
                } else {
                  debugs[set] = function () {};
                }
              }
              return debugs[set];
            };

            /**
             * Echos the value of a value. Trys to print the value out
             * in the best way possible given the different types.
             *
             * @param {Object} obj The object to print out.
             * @param {Object} opts Optional options object that alters the output.
             */
            /* legacy: obj, showHidden, depth, colors*/
            function inspect(obj, opts) {
              // default options
              var ctx = {
                seen: [],
                stylize: stylizeNoColor
              };
              // legacy...
              if (arguments.length >= 3) ctx.depth = arguments[2];
              if (arguments.length >= 4) ctx.colors = arguments[3];
              if (isBoolean(opts)) {
                // legacy...
                ctx.showHidden = opts;
              } else if (opts) {
                // got an "options" object
                exports._extend(ctx, opts);
              }
              // set default options
              if (isUndefined(ctx.showHidden)) ctx.showHidden = false;
              if (isUndefined(ctx.depth)) ctx.depth = 2;
              if (isUndefined(ctx.colors)) ctx.colors = false;
              if (isUndefined(ctx.customInspect)) ctx.customInspect = true;
              if (ctx.colors) ctx.stylize = stylizeWithColor;
              return formatValue(ctx, obj, ctx.depth);
            }
            exports.inspect = inspect;

            // http://en.wikipedia.org/wiki/ANSI_escape_code#graphics
            inspect.colors = {
              'bold': [1, 22],
              'italic': [3, 23],
              'underline': [4, 24],
              'inverse': [7, 27],
              'white': [37, 39],
              'grey': [90, 39],
              'black': [30, 39],
              'blue': [34, 39],
              'cyan': [36, 39],
              'green': [32, 39],
              'magenta': [35, 39],
              'red': [31, 39],
              'yellow': [33, 39]
            };

            // Don't use 'blue' not visible on cmd.exe
            inspect.styles = {
              'special': 'cyan',
              'number': 'yellow',
              'boolean': 'yellow',
              'undefined': 'grey',
              'null': 'bold',
              'string': 'green',
              'date': 'magenta',
              // "name": intentionally not styling
              'regexp': 'red'
            };
            function stylizeWithColor(str, styleType) {
              var style = inspect.styles[styleType];
              if (style) {
                return '\u001b[' + inspect.colors[style][0] + 'm' + str + '\u001b[' + inspect.colors[style][1] + 'm';
              } else {
                return str;
              }
            }
            function stylizeNoColor(str, styleType) {
              return str;
            }
            function arrayToHash(array) {
              var hash = {};
              array.forEach(function (val, idx) {
                hash[val] = true;
              });
              return hash;
            }
            function formatValue(ctx, value, recurseTimes) {
              // Provide a hook for user-specified inspect functions.
              // Check that value is an object with an inspect function on it
              if (ctx.customInspect && value && isFunction(value.inspect) &&
              // Filter out the util module, it's inspect function is special
              value.inspect !== exports.inspect &&
              // Also filter out any prototype objects using the circular check.
              !(value.constructor && value.constructor.prototype === value)) {
                var ret = value.inspect(recurseTimes, ctx);
                if (!isString(ret)) {
                  ret = formatValue(ctx, ret, recurseTimes);
                }
                return ret;
              }

              // Primitive types cannot have properties
              var primitive = formatPrimitive(ctx, value);
              if (primitive) {
                return primitive;
              }

              // Look up the keys of the object.
              var keys = Object.keys(value);
              var visibleKeys = arrayToHash(keys);
              if (ctx.showHidden) {
                keys = Object.getOwnPropertyNames(value);
              }

              // IE doesn't make error fields non-enumerable
              // http://msdn.microsoft.com/en-us/library/ie/dww52sbt(v=vs.94).aspx
              if (isError(value) && (keys.indexOf('message') >= 0 || keys.indexOf('description') >= 0)) {
                return formatError(value);
              }

              // Some type of object without properties can be shortcutted.
              if (keys.length === 0) {
                if (isFunction(value)) {
                  var name = value.name ? ': ' + value.name : '';
                  return ctx.stylize('[Function' + name + ']', 'special');
                }
                if (isRegExp(value)) {
                  return ctx.stylize(RegExp.prototype.toString.call(value), 'regexp');
                }
                if (isDate(value)) {
                  return ctx.stylize(Date.prototype.toString.call(value), 'date');
                }
                if (isError(value)) {
                  return formatError(value);
                }
              }
              var base = '',
                array = false,
                braces = ['{', '}'];

              // Make Array say that they are Array
              if (isArray(value)) {
                array = true;
                braces = ['[', ']'];
              }

              // Make functions say that they are functions
              if (isFunction(value)) {
                var n = value.name ? ': ' + value.name : '';
                base = ' [Function' + n + ']';
              }

              // Make RegExps say that they are RegExps
              if (isRegExp(value)) {
                base = ' ' + RegExp.prototype.toString.call(value);
              }

              // Make dates with properties first say the date
              if (isDate(value)) {
                base = ' ' + Date.prototype.toUTCString.call(value);
              }

              // Make error with message first say the error
              if (isError(value)) {
                base = ' ' + formatError(value);
              }
              if (keys.length === 0 && (!array || value.length == 0)) {
                return braces[0] + base + braces[1];
              }
              if (recurseTimes < 0) {
                if (isRegExp(value)) {
                  return ctx.stylize(RegExp.prototype.toString.call(value), 'regexp');
                } else {
                  return ctx.stylize('[Object]', 'special');
                }
              }
              ctx.seen.push(value);
              var output;
              if (array) {
                output = formatArray(ctx, value, recurseTimes, visibleKeys, keys);
              } else {
                output = keys.map(function (key) {
                  return formatProperty(ctx, value, recurseTimes, visibleKeys, key, array);
                });
              }
              ctx.seen.pop();
              return reduceToSingleString(output, base, braces);
            }
            function formatPrimitive(ctx, value) {
              if (isUndefined(value)) return ctx.stylize('undefined', 'undefined');
              if (isString(value)) {
                var simple = '\'' + JSON.stringify(value).replace(/^"|"$/g, '').replace(/'/g, "\\'").replace(/\\"/g, '"') + '\'';
                return ctx.stylize(simple, 'string');
              }
              if (isNumber(value)) return ctx.stylize('' + value, 'number');
              if (isBoolean(value)) return ctx.stylize('' + value, 'boolean');
              // For some reason typeof null is "object", so special case here.
              if (isNull(value)) return ctx.stylize('null', 'null');
            }
            function formatError(value) {
              return '[' + Error.prototype.toString.call(value) + ']';
            }
            function formatArray(ctx, value, recurseTimes, visibleKeys, keys) {
              var output = [];
              for (var i = 0, l = value.length; i < l; ++i) {
                if (hasOwnProperty(value, String(i))) {
                  output.push(formatProperty(ctx, value, recurseTimes, visibleKeys, String(i), true));
                } else {
                  output.push('');
                }
              }
              keys.forEach(function (key) {
                if (!key.match(/^\d+$/)) {
                  output.push(formatProperty(ctx, value, recurseTimes, visibleKeys, key, true));
                }
              });
              return output;
            }
            function formatProperty(ctx, value, recurseTimes, visibleKeys, key, array) {
              var name, str, desc;
              desc = Object.getOwnPropertyDescriptor(value, key) || {
                value: value[key]
              };
              if (desc.get) {
                if (desc.set) {
                  str = ctx.stylize('[Getter/Setter]', 'special');
                } else {
                  str = ctx.stylize('[Getter]', 'special');
                }
              } else {
                if (desc.set) {
                  str = ctx.stylize('[Setter]', 'special');
                }
              }
              if (!hasOwnProperty(visibleKeys, key)) {
                name = '[' + key + ']';
              }
              if (!str) {
                if (ctx.seen.indexOf(desc.value) < 0) {
                  if (isNull(recurseTimes)) {
                    str = formatValue(ctx, desc.value, null);
                  } else {
                    str = formatValue(ctx, desc.value, recurseTimes - 1);
                  }
                  if (str.indexOf('\n') > -1) {
                    if (array) {
                      str = str.split('\n').map(function (line) {
                        return '  ' + line;
                      }).join('\n').substr(2);
                    } else {
                      str = '\n' + str.split('\n').map(function (line) {
                        return '   ' + line;
                      }).join('\n');
                    }
                  }
                } else {
                  str = ctx.stylize('[Circular]', 'special');
                }
              }
              if (isUndefined(name)) {
                if (array && key.match(/^\d+$/)) {
                  return str;
                }
                name = JSON.stringify('' + key);
                if (name.match(/^"([a-zA-Z_][a-zA-Z_0-9]*)"$/)) {
                  name = name.substr(1, name.length - 2);
                  name = ctx.stylize(name, 'name');
                } else {
                  name = name.replace(/'/g, "\\'").replace(/\\"/g, '"').replace(/(^"|"$)/g, "'");
                  name = ctx.stylize(name, 'string');
                }
              }
              return name + ': ' + str;
            }
            function reduceToSingleString(output, base, braces) {
              var length = output.reduce(function (prev, cur) {
                if (cur.indexOf('\n') >= 0) ;
                return prev + cur.replace(/\u001b\[\d\d?m/g, '').length + 1;
              }, 0);
              if (length > 60) {
                return braces[0] + (base === '' ? '' : base + '\n ') + ' ' + output.join(',\n  ') + ' ' + braces[1];
              }
              return braces[0] + base + ' ' + output.join(', ') + ' ' + braces[1];
            }

            // NOTE: These type checking functions intentionally don't use `instanceof`
            // because it is fragile and can be easily faked with `Object.create()`.
            function isArray(ar) {
              return Array.isArray(ar);
            }
            exports.isArray = isArray;
            function isBoolean(arg) {
              return typeof arg === 'boolean';
            }
            exports.isBoolean = isBoolean;
            function isNull(arg) {
              return arg === null;
            }
            exports.isNull = isNull;
            function isNullOrUndefined(arg) {
              return arg == null;
            }
            exports.isNullOrUndefined = isNullOrUndefined;
            function isNumber(arg) {
              return typeof arg === 'number';
            }
            exports.isNumber = isNumber;
            function isString(arg) {
              return typeof arg === 'string';
            }
            exports.isString = isString;
            function isSymbol(arg) {
              return typeof arg === 'symbol';
            }
            exports.isSymbol = isSymbol;
            function isUndefined(arg) {
              return arg === void 0;
            }
            exports.isUndefined = isUndefined;
            function isRegExp(re) {
              return isObject(re) && objectToString(re) === '[object RegExp]';
            }
            exports.isRegExp = isRegExp;
            function isObject(arg) {
              return typeof arg === 'object' && arg !== null;
            }
            exports.isObject = isObject;
            function isDate(d) {
              return isObject(d) && objectToString(d) === '[object Date]';
            }
            exports.isDate = isDate;
            function isError(e) {
              return isObject(e) && (objectToString(e) === '[object Error]' || e instanceof Error);
            }
            exports.isError = isError;
            function isFunction(arg) {
              return typeof arg === 'function';
            }
            exports.isFunction = isFunction;
            function isPrimitive(arg) {
              return arg === null || typeof arg === 'boolean' || typeof arg === 'number' || typeof arg === 'string' || typeof arg === 'symbol' ||
              // ES6 symbol
              typeof arg === 'undefined';
            }
            exports.isPrimitive = isPrimitive;
            exports.isBuffer = require('./support/isBuffer');
            function objectToString(o) {
              return Object.prototype.toString.call(o);
            }
            function pad(n) {
              return n < 10 ? '0' + n.toString(10) : n.toString(10);
            }
            var months = ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'];

            // 26 Feb 16:19:34
            function timestamp() {
              var d = new Date();
              var time = [pad(d.getHours()), pad(d.getMinutes()), pad(d.getSeconds())].join(':');
              return [d.getDate(), months[d.getMonth()], time].join(' ');
            }

            // log is just a thin wrapper to console.log that prepends a timestamp
            exports.log = function () {
              console.log('%s - %s', timestamp(), exports.format.apply(exports, arguments));
            };

            /**
             * Inherit the prototype methods from one constructor into another.
             *
             * The Function.prototype.inherits from lang.js rewritten as a standalone
             * function (not on Function.prototype). NOTE: If this file is to be loaded
             * during bootstrapping this function needs to be rewritten using some native
             * functions as prototype setup using normal JavaScript does not work as
             * expected during bootstrapping (see mirror.js in r114903).
             *
             * @param {function} ctor Constructor function which needs to inherit the
             *     prototype.
             * @param {function} superCtor Constructor function to inherit prototype from.
             */
            exports.inherits = require('inherits');
            exports._extend = function (origin, add) {
              // Don't do anything if add isn't an object
              if (!add || !isObject(add)) return origin;
              var keys = Object.keys(add);
              var i = keys.length;
              while (i--) {
                origin[keys[i]] = add[keys[i]];
              }
              return origin;
            };
            function hasOwnProperty(obj, prop) {
              return Object.prototype.hasOwnProperty.call(obj, prop);
            }
          }).call(this, require('_process'), typeof commonjsGlobal !== "undefined" ? commonjsGlobal : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {});
        }, {
          "./support/isBuffer": 10,
          "_process": 14,
          "inherits": 9
        }],
        12: [function (require, module, exports) {}, {}],
        13: [function (require, module, exports) {
          (function (process) {
            // .dirname, .basename, and .extname methods are extracted from Node.js v8.11.1,
            // backported and transplited with Babel, with backwards-compat fixes

            // Copyright Joyent, Inc. and other Node contributors.
            //
            // Permission is hereby granted, free of charge, to any person obtaining a
            // copy of this software and associated documentation files (the
            // "Software"), to deal in the Software without restriction, including
            // without limitation the rights to use, copy, modify, merge, publish,
            // distribute, sublicense, and/or sell copies of the Software, and to permit
            // persons to whom the Software is furnished to do so, subject to the
            // following conditions:
            //
            // The above copyright notice and this permission notice shall be included
            // in all copies or substantial portions of the Software.
            //
            // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
            // OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
            // MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
            // NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
            // DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
            // OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
            // USE OR OTHER DEALINGS IN THE SOFTWARE.

            // resolves . and .. elements in a path array with directory names there
            // must be no slashes, empty elements, or device names (c:\) in the array
            // (so also no leading and trailing slashes - it does not distinguish
            // relative and absolute paths)
            function normalizeArray(parts, allowAboveRoot) {
              // if the path tries to go above the root, `up` ends up > 0
              var up = 0;
              for (var i = parts.length - 1; i >= 0; i--) {
                var last = parts[i];
                if (last === '.') {
                  parts.splice(i, 1);
                } else if (last === '..') {
                  parts.splice(i, 1);
                  up++;
                } else if (up) {
                  parts.splice(i, 1);
                  up--;
                }
              }

              // if the path is allowed to go above the root, restore leading ..s
              if (allowAboveRoot) {
                for (; up--; up) {
                  parts.unshift('..');
                }
              }
              return parts;
            }

            // path.resolve([from ...], to)
            // posix version
            exports.resolve = function () {
              var resolvedPath = '',
                resolvedAbsolute = false;
              for (var i = arguments.length - 1; i >= -1 && !resolvedAbsolute; i--) {
                var path = i >= 0 ? arguments[i] : process.cwd();

                // Skip empty and invalid entries
                if (typeof path !== 'string') {
                  throw new TypeError('Arguments to path.resolve must be strings');
                } else if (!path) {
                  continue;
                }
                resolvedPath = path + '/' + resolvedPath;
                resolvedAbsolute = path.charAt(0) === '/';
              }

              // At this point the path should be resolved to a full absolute path, but
              // handle relative paths to be safe (might happen when process.cwd() fails)

              // Normalize the path
              resolvedPath = normalizeArray(filter(resolvedPath.split('/'), function (p) {
                return !!p;
              }), !resolvedAbsolute).join('/');
              return (resolvedAbsolute ? '/' : '') + resolvedPath || '.';
            };

            // path.normalize(path)
            // posix version
            exports.normalize = function (path) {
              var isAbsolute = exports.isAbsolute(path),
                trailingSlash = substr(path, -1) === '/';

              // Normalize the path
              path = normalizeArray(filter(path.split('/'), function (p) {
                return !!p;
              }), !isAbsolute).join('/');
              if (!path && !isAbsolute) {
                path = '.';
              }
              if (path && trailingSlash) {
                path += '/';
              }
              return (isAbsolute ? '/' : '') + path;
            };

            // posix version
            exports.isAbsolute = function (path) {
              return path.charAt(0) === '/';
            };

            // posix version
            exports.join = function () {
              var paths = Array.prototype.slice.call(arguments, 0);
              return exports.normalize(filter(paths, function (p, index) {
                if (typeof p !== 'string') {
                  throw new TypeError('Arguments to path.join must be strings');
                }
                return p;
              }).join('/'));
            };

            // path.relative(from, to)
            // posix version
            exports.relative = function (from, to) {
              from = exports.resolve(from).substr(1);
              to = exports.resolve(to).substr(1);
              function trim(arr) {
                var start = 0;
                for (; start < arr.length; start++) {
                  if (arr[start] !== '') break;
                }
                var end = arr.length - 1;
                for (; end >= 0; end--) {
                  if (arr[end] !== '') break;
                }
                if (start > end) return [];
                return arr.slice(start, end - start + 1);
              }
              var fromParts = trim(from.split('/'));
              var toParts = trim(to.split('/'));
              var length = Math.min(fromParts.length, toParts.length);
              var samePartsLength = length;
              for (var i = 0; i < length; i++) {
                if (fromParts[i] !== toParts[i]) {
                  samePartsLength = i;
                  break;
                }
              }
              var outputParts = [];
              for (var i = samePartsLength; i < fromParts.length; i++) {
                outputParts.push('..');
              }
              outputParts = outputParts.concat(toParts.slice(samePartsLength));
              return outputParts.join('/');
            };
            exports.sep = '/';
            exports.delimiter = ':';
            exports.dirname = function (path) {
              if (typeof path !== 'string') path = path + '';
              if (path.length === 0) return '.';
              var code = path.charCodeAt(0);
              var hasRoot = code === 47 /*/*/;
              var end = -1;
              var matchedSlash = true;
              for (var i = path.length - 1; i >= 1; --i) {
                code = path.charCodeAt(i);
                if (code === 47 /*/*/) {
                  if (!matchedSlash) {
                    end = i;
                    break;
                  }
                } else {
                  // We saw the first non-path separator
                  matchedSlash = false;
                }
              }
              if (end === -1) return hasRoot ? '/' : '.';
              if (hasRoot && end === 1) {
                // return '//';
                // Backwards-compat fix:
                return '/';
              }
              return path.slice(0, end);
            };
            function basename(path) {
              if (typeof path !== 'string') path = path + '';
              var start = 0;
              var end = -1;
              var matchedSlash = true;
              var i;
              for (i = path.length - 1; i >= 0; --i) {
                if (path.charCodeAt(i) === 47 /*/*/) {
                  // If we reached a path separator that was not part of a set of path
                  // separators at the end of the string, stop now
                  if (!matchedSlash) {
                    start = i + 1;
                    break;
                  }
                } else if (end === -1) {
                  // We saw the first non-path separator, mark this as the end of our
                  // path component
                  matchedSlash = false;
                  end = i + 1;
                }
              }
              if (end === -1) return '';
              return path.slice(start, end);
            }

            // Uses a mixed approach for backwards-compatibility, as ext behavior changed
            // in new Node.js versions, so only basename() above is backported here
            exports.basename = function (path, ext) {
              var f = basename(path);
              if (ext && f.substr(-1 * ext.length) === ext) {
                f = f.substr(0, f.length - ext.length);
              }
              return f;
            };
            exports.extname = function (path) {
              if (typeof path !== 'string') path = path + '';
              var startDot = -1;
              var startPart = 0;
              var end = -1;
              var matchedSlash = true;
              // Track the state of characters (if any) we see before our first dot and
              // after any path separator we find
              var preDotState = 0;
              for (var i = path.length - 1; i >= 0; --i) {
                var code = path.charCodeAt(i);
                if (code === 47 /*/*/) {
                  // If we reached a path separator that was not part of a set of path
                  // separators at the end of the string, stop now
                  if (!matchedSlash) {
                    startPart = i + 1;
                    break;
                  }
                  continue;
                }
                if (end === -1) {
                  // We saw the first non-path separator, mark this as the end of our
                  // extension
                  matchedSlash = false;
                  end = i + 1;
                }
                if (code === 46 /*.*/) {
                  // If this is our first dot, mark it as the start of our extension
                  if (startDot === -1) startDot = i;else if (preDotState !== 1) preDotState = 1;
                } else if (startDot !== -1) {
                  // We saw a non-dot and non-path separator before our dot, so we should
                  // have a good chance at having a non-empty extension
                  preDotState = -1;
                }
              }
              if (startDot === -1 || end === -1 ||
              // We saw a non-dot character immediately before the dot
              preDotState === 0 ||
              // The (right-most) trimmed path component is exactly '..'
              preDotState === 1 && startDot === end - 1 && startDot === startPart + 1) {
                return '';
              }
              return path.slice(startDot, end);
            };
            function filter(xs, f) {
              if (xs.filter) return xs.filter(f);
              var res = [];
              for (var i = 0; i < xs.length; i++) {
                if (f(xs[i], i, xs)) res.push(xs[i]);
              }
              return res;
            }

            // String.prototype.substr - negative index don't work in IE8
            var substr = 'ab'.substr(-1) === 'b' ? function (str, start, len) {
              return str.substr(start, len);
            } : function (str, start, len) {
              if (start < 0) start = str.length + start;
              return str.substr(start, len);
            };
          }).call(this, require('_process'));
        }, {
          "_process": 14
        }],
        14: [function (require, module, exports) {
          // shim for using process in browser
          var process = module.exports = {};

          // cached from whatever global is present so that test runners that stub it
          // don't break things.  But we need to wrap it in a try catch in case it is
          // wrapped in strict mode code which doesn't define any globals.  It's inside a
          // function because try/catches deoptimize in certain engines.

          var cachedSetTimeout;
          var cachedClearTimeout;
          function defaultSetTimout() {
            throw new Error('setTimeout has not been defined');
          }
          function defaultClearTimeout() {
            throw new Error('clearTimeout has not been defined');
          }
          (function () {
            try {
              if (typeof setTimeout === 'function') {
                cachedSetTimeout = setTimeout;
              } else {
                cachedSetTimeout = defaultSetTimout;
              }
            } catch (e) {
              cachedSetTimeout = defaultSetTimout;
            }
            try {
              if (typeof clearTimeout === 'function') {
                cachedClearTimeout = clearTimeout;
              } else {
                cachedClearTimeout = defaultClearTimeout;
              }
            } catch (e) {
              cachedClearTimeout = defaultClearTimeout;
            }
          })();
          function runTimeout(fun) {
            if (cachedSetTimeout === setTimeout) {
              //normal enviroments in sane situations
              return setTimeout(fun, 0);
            }
            // if setTimeout wasn't available but was latter defined
            if ((cachedSetTimeout === defaultSetTimout || !cachedSetTimeout) && setTimeout) {
              cachedSetTimeout = setTimeout;
              return setTimeout(fun, 0);
            }
            try {
              // when when somebody has screwed with setTimeout but no I.E. maddness
              return cachedSetTimeout(fun, 0);
            } catch (e) {
              try {
                // When we are in I.E. but the script has been evaled so I.E. doesn't trust the global object when called normally
                return cachedSetTimeout.call(null, fun, 0);
              } catch (e) {
                // same as above but when it's a version of I.E. that must have the global object for 'this', hopfully our context correct otherwise it will throw a global error
                return cachedSetTimeout.call(this, fun, 0);
              }
            }
          }
          function runClearTimeout(marker) {
            if (cachedClearTimeout === clearTimeout) {
              //normal enviroments in sane situations
              return clearTimeout(marker);
            }
            // if clearTimeout wasn't available but was latter defined
            if ((cachedClearTimeout === defaultClearTimeout || !cachedClearTimeout) && clearTimeout) {
              cachedClearTimeout = clearTimeout;
              return clearTimeout(marker);
            }
            try {
              // when when somebody has screwed with setTimeout but no I.E. maddness
              return cachedClearTimeout(marker);
            } catch (e) {
              try {
                // When we are in I.E. but the script has been evaled so I.E. doesn't  trust the global object when called normally
                return cachedClearTimeout.call(null, marker);
              } catch (e) {
                // same as above but when it's a version of I.E. that must have the global object for 'this', hopfully our context correct otherwise it will throw a global error.
                // Some versions of I.E. have different rules for clearTimeout vs setTimeout
                return cachedClearTimeout.call(this, marker);
              }
            }
          }
          var queue = [];
          var draining = false;
          var currentQueue;
          var queueIndex = -1;
          function cleanUpNextTick() {
            if (!draining || !currentQueue) {
              return;
            }
            draining = false;
            if (currentQueue.length) {
              queue = currentQueue.concat(queue);
            } else {
              queueIndex = -1;
            }
            if (queue.length) {
              drainQueue();
            }
          }
          function drainQueue() {
            if (draining) {
              return;
            }
            var timeout = runTimeout(cleanUpNextTick);
            draining = true;
            var len = queue.length;
            while (len) {
              currentQueue = queue;
              queue = [];
              while (++queueIndex < len) {
                if (currentQueue) {
                  currentQueue[queueIndex].run();
                }
              }
              queueIndex = -1;
              len = queue.length;
            }
            currentQueue = null;
            draining = false;
            runClearTimeout(timeout);
          }
          process.nextTick = function (fun) {
            var args = new Array(arguments.length - 1);
            if (arguments.length > 1) {
              for (var i = 1; i < arguments.length; i++) {
                args[i - 1] = arguments[i];
              }
            }
            queue.push(new Item(fun, args));
            if (queue.length === 1 && !draining) {
              runTimeout(drainQueue);
            }
          };

          // v8 likes predictible objects
          function Item(fun, array) {
            this.fun = fun;
            this.array = array;
          }
          Item.prototype.run = function () {
            this.fun.apply(null, this.array);
          };
          process.title = 'browser';
          process.browser = true;
          process.env = {};
          process.argv = [];
          process.version = ''; // empty string to avoid regexp issues
          process.versions = {};
          function noop() {}
          process.on = noop;
          process.addListener = noop;
          process.once = noop;
          process.off = noop;
          process.removeListener = noop;
          process.removeAllListeners = noop;
          process.emit = noop;
          process.prependListener = noop;
          process.prependOnceListener = noop;
          process.listeners = function (name) {
            return [];
          };
          process.binding = function (name) {
            throw new Error('process.binding is not supported');
          };
          process.cwd = function () {
            return '/';
          };
          process.chdir = function (dir) {
            throw new Error('process.chdir is not supported');
          };
          process.umask = function () {
            return 0;
          };
        }, {}],
        15: [function (require, module, exports) {
          var unparse = require('escodegen').generate;
          module.exports = function (ast, vars) {
            if (!vars) vars = {};
            var FAIL = {};
            var result = function walk(node, scopeVars) {
              if (node.type === 'Literal') {
                return node.value;
              } else if (node.type === 'UnaryExpression') {
                var val = walk(node.argument);
                if (node.operator === '+') return +val;
                if (node.operator === '-') return -val;
                if (node.operator === '~') return ~val;
                if (node.operator === '!') return !val;
                return FAIL;
              } else if (node.type === 'ArrayExpression') {
                var xs = [];
                for (var i = 0, l = node.elements.length; i < l; i++) {
                  var x = walk(node.elements[i]);
                  if (x === FAIL) return FAIL;
                  xs.push(x);
                }
                return xs;
              } else if (node.type === 'ObjectExpression') {
                var obj = {};
                for (var i = 0; i < node.properties.length; i++) {
                  var prop = node.properties[i];
                  var value = prop.value === null ? prop.value : walk(prop.value);
                  if (value === FAIL) return FAIL;
                  obj[prop.key.value || prop.key.name] = value;
                }
                return obj;
              } else if (node.type === 'BinaryExpression' || node.type === 'LogicalExpression') {
                var l = walk(node.left);
                if (l === FAIL) return FAIL;
                var r = walk(node.right);
                if (r === FAIL) return FAIL;
                var op = node.operator;
                if (op === '==') return l == r;
                if (op === '===') return l === r;
                if (op === '!=') return l != r;
                if (op === '!==') return l !== r;
                if (op === '+') return l + r;
                if (op === '-') return l - r;
                if (op === '*') return l * r;
                if (op === '/') return l / r;
                if (op === '%') return l % r;
                if (op === '<') return l < r;
                if (op === '<=') return l <= r;
                if (op === '>') return l > r;
                if (op === '>=') return l >= r;
                if (op === '|') return l | r;
                if (op === '&') return l & r;
                if (op === '^') return l ^ r;
                if (op === '&&') return l && r;
                if (op === '||') return l || r;
                return FAIL;
              } else if (node.type === 'Identifier') {
                if ({}.hasOwnProperty.call(vars, node.name)) {
                  return vars[node.name];
                } else return FAIL;
              } else if (node.type === 'ThisExpression') {
                if ({}.hasOwnProperty.call(vars, 'this')) {
                  return vars['this'];
                } else return FAIL;
              } else if (node.type === 'CallExpression') {
                var callee = walk(node.callee);
                if (callee === FAIL) return FAIL;
                if (typeof callee !== 'function') return FAIL;
                var ctx = node.callee.object ? walk(node.callee.object) : FAIL;
                if (ctx === FAIL) ctx = null;
                var args = [];
                for (var i = 0, l = node.arguments.length; i < l; i++) {
                  var x = walk(node.arguments[i]);
                  if (x === FAIL) return FAIL;
                  args.push(x);
                }
                return callee.apply(ctx, args);
              } else if (node.type === 'MemberExpression') {
                var obj = walk(node.object);
                // do not allow access to methods on Function 
                if (obj === FAIL || typeof obj == 'function') {
                  return FAIL;
                }
                if (node.property.type === 'Identifier') {
                  return obj[node.property.name];
                }
                var prop = walk(node.property);
                if (prop === FAIL) return FAIL;
                return obj[prop];
              } else if (node.type === 'ConditionalExpression') {
                var val = walk(node.test);
                if (val === FAIL) return FAIL;
                return val ? walk(node.consequent) : walk(node.alternate);
              } else if (node.type === 'ExpressionStatement') {
                var val = walk(node.expression);
                if (val === FAIL) return FAIL;
                return val;
              } else if (node.type === 'ReturnStatement') {
                return walk(node.argument);
              } else if (node.type === 'FunctionExpression') {
                var bodies = node.body.body;

                // Create a "scope" for our arguments
                var oldVars = {};
                Object.keys(vars).forEach(function (element) {
                  oldVars[element] = vars[element];
                });
                for (var i = 0; i < node.params.length; i++) {
                  var key = node.params[i];
                  if (key.type == 'Identifier') {
                    vars[key.name] = null;
                  } else return FAIL;
                }
                for (var i in bodies) {
                  if (walk(bodies[i]) === FAIL) {
                    return FAIL;
                  }
                }
                // restore the vars and scope after we walk
                vars = oldVars;
                var keys = Object.keys(vars);
                var vals = keys.map(function (key) {
                  return vars[key];
                });
                return Function(keys.join(', '), 'return ' + unparse(node)).apply(null, vals);
              } else if (node.type === 'TemplateLiteral') {
                var str = '';
                for (var i = 0; i < node.expressions.length; i++) {
                  str += walk(node.quasis[i]);
                  str += walk(node.expressions[i]);
                }
                str += walk(node.quasis[i]);
                return str;
              } else if (node.type === 'TaggedTemplateExpression') {
                var tag = walk(node.tag);
                var quasi = node.quasi;
                var strings = quasi.quasis.map(walk);
                var values = quasi.expressions.map(walk);
                return tag.apply(null, [strings].concat(values));
              } else if (node.type === 'TemplateElement') {
                return node.value.cooked;
              } else return FAIL;
            }(ast);
            return result === FAIL ? undefined : result;
          };
        }, {
          "escodegen": 12
        }],
        "jsonpath": [function (require, module, exports) {
          module.exports = require('./lib/index');
        }, {
          "./lib/index": 5
        }]
      }, {}, ["jsonpath"])("jsonpath");
    });
  })(jsonpath);
  var jp = jsonpath.exports;

  /**
   * Returns the computed data section of a compound
   *
   * @param data Data of a compound data request to the PubChem API
   * @returns Computed Data section
   */
  function getComputedDataSection(data) {
    const computedData = jp.query(data, '$.Section[?(@.TOCHeading==="Chemical and Physical Properties")]' + '.Section[?(@.TOCHeading==="Computed Properties")]');
    return computedData;
  }

  /**
   * Returns a computed data section of a compound
   *
   * @param data Data of a compound data request to the PubChem API
   * @param sectionName Name of the section to be returned
   * @returns Computed Data section
   */
  function getComputedPropertySection(data, sectionName) {
    let returnData = jp.query(data, `$.Section[?(@.TOCHeading==="${sectionName}")].Information[*]`)[0];
    returnData.Description = jp.query(data, `$.Section[?(@.TOCHeading==="${sectionName}")].Description`)[0];
    return returnData;
  }

  /**
   * Returns the number properties of a compound
   *
   * @param data Data of a compound data request to the PubChem API
   * @param sectionName Name of the section to get the data from
   * @returns Computed Data
   */
  function getNumberProperties(data, sectionName) {
    const output = {
      value: null,
      label: null,
      reference: {
        description: null
      },
      description: null
    };
    try {
      const computationalData = getComputedDataSection(data);
      let section = getComputedPropertySection(computationalData[0], sectionName);
      output.value = section.Value.Number[0];
      output.label = sectionName;
      output.description = section.Description;
      output.reference.description = section.Reference[0];
      if (section.Value.Unit) {
        output.units = section.Value.Unit;
      }
      // eslint-disable-next-line no-empty
    } catch (error) {}
    return output;
  }

  /**
   * Returns the complexity of a compound
   *
   * @param data Data of a compound data request to the PubChem API
   * @returns ComputedData
   */
  function getComplexity(data) {
    const complexity = getNumberProperties(data, 'Complexity');
    return complexity;
  }

  /**
   * Returns the formal charge of a compound
   *
   * @param data Data of a compound data request to the PubChem API
   * @returns Computed Data
   */
  function getFormalCharge(data) {
    const formalCharge = getNumberProperties(data, 'Formal Charge');
    return formalCharge;
  }

  /**
   * Returns the heavy atom count of a compound
   *
   * @param data Data of a compound data request to the PubChem API
   * @returns Computed Data
   */
  function getHeavyAtomCount(data) {
    const heavyAtomCount = getNumberProperties(data, 'Heavy Atom Count');
    return heavyAtomCount;
  }

  /**
   * Returns the hydrogen bond acceptor count of a compound
   *
   * @param data Data of a compound data request to the PubChem API
   * @returns Computed Data
   */
  function getHydrogenBondAcceptorCount(data) {
    const hydrogenBondAcceptorCount = getNumberProperties(data, 'Hydrogen Bond Acceptor Count');
    return hydrogenBondAcceptorCount;
  }

  /**
   * Returns the hydrogen bond donor count of a compound
   *
   * @param data Data of a compound data request to the PubChem API
   * @returns ComputedData
   */
  function getHydrogenBondDonorCount(data) {
    const hydrogenBondDonorCount = getNumberProperties(data, 'Hydrogen Bond Donor Count');
    return hydrogenBondDonorCount;
  }

  /**
   * Returns the rotable bond count of a compound
   *
   * @param data Data of a compound data request to the PubChem API
   * @returns ComputedData
   */
  function getRotableBondCount(data) {
    const rotableBondCount = getNumberProperties(data, 'Rotatable Bond Count');
    return rotableBondCount;
  }

  /**
   * Returns the topological polar surface area in angstrom^2
   *
   * @param data Data of a compound data request to the PubChem API
   * @returns Computed Data
   */
  function getTPSA(data) {
    const tpsa = getNumberProperties(data, 'Topological Polar Surface Area');
    return tpsa;
  }

  /**
   * Returns the xLogP3 of a compound
   *
   * @param data Data of a compound data request to the PubChem API
   * @returns Computed Data
   */
  function getxLogP3(data) {
    const xLogP3 = getNumberProperties(data, 'XLogP3');
    return xLogP3;
  }

  /**
   * Returns an object of computed data
   *
   * @param data Data of a compound data request to the PubChem API
   * @returns Object of computed data
   */
  function getComputedData(data) {
    return {
      hydrogenBondDonorCount: getHydrogenBondDonorCount(data),
      hydrogenBondAcceptorCount: getHydrogenBondAcceptorCount(data),
      rotableBondCount: getRotableBondCount(data),
      heavyAtomCount: getHeavyAtomCount(data),
      formalCharge: getFormalCharge(data),
      complexity: getComplexity(data),
      tpsa: getTPSA(data),
      xLogP3: getxLogP3(data)
    };
  }

  var isMergeableObject = function isMergeableObject(value) {
    return isNonNullObject(value) && !isSpecial(value);
  };
  function isNonNullObject(value) {
    return !!value && typeof value === 'object';
  }
  function isSpecial(value) {
    var stringValue = Object.prototype.toString.call(value);
    return stringValue === '[object RegExp]' || stringValue === '[object Date]' || isReactElement(value);
  }

  // see https://github.com/facebook/react/blob/b5ac963fb791d1298e7f396236383bc955f916c1/src/isomorphic/classic/element/ReactElement.js#L21-L25
  var canUseSymbol = typeof Symbol === 'function' && Symbol.for;
  var REACT_ELEMENT_TYPE = canUseSymbol ? Symbol.for('react.element') : 0xeac7;
  function isReactElement(value) {
    return value.$$typeof === REACT_ELEMENT_TYPE;
  }
  function emptyTarget(val) {
    return Array.isArray(val) ? [] : {};
  }
  function cloneUnlessOtherwiseSpecified(value, options) {
    return options.clone !== false && options.isMergeableObject(value) ? deepmerge(emptyTarget(value), value, options) : value;
  }
  function defaultArrayMerge(target, source, options) {
    return target.concat(source).map(function (element) {
      return cloneUnlessOtherwiseSpecified(element, options);
    });
  }
  function getMergeFunction(key, options) {
    if (!options.customMerge) {
      return deepmerge;
    }
    var customMerge = options.customMerge(key);
    return typeof customMerge === 'function' ? customMerge : deepmerge;
  }
  function getEnumerableOwnPropertySymbols(target) {
    return Object.getOwnPropertySymbols ? Object.getOwnPropertySymbols(target).filter(function (symbol) {
      return Object.propertyIsEnumerable.call(target, symbol);
    }) : [];
  }
  function getKeys(target) {
    return Object.keys(target).concat(getEnumerableOwnPropertySymbols(target));
  }
  function propertyIsOnObject(object, property) {
    try {
      return property in object;
    } catch (_) {
      return false;
    }
  }

  // Protects from prototype poisoning and unexpected merging up the prototype chain.
  function propertyIsUnsafe(target, key) {
    return propertyIsOnObject(target, key) // Properties are safe to merge if they don't exist in the target yet,
    && !(Object.hasOwnProperty.call(target, key) // unsafe if they exist up the prototype chain,
    && Object.propertyIsEnumerable.call(target, key)); // and also unsafe if they're nonenumerable.
  }
  function mergeObject(target, source, options) {
    var destination = {};
    if (options.isMergeableObject(target)) {
      getKeys(target).forEach(function (key) {
        destination[key] = cloneUnlessOtherwiseSpecified(target[key], options);
      });
    }
    getKeys(source).forEach(function (key) {
      if (propertyIsUnsafe(target, key)) {
        return;
      }
      if (propertyIsOnObject(target, key) && options.isMergeableObject(source[key])) {
        destination[key] = getMergeFunction(key, options)(target[key], source[key], options);
      } else {
        destination[key] = cloneUnlessOtherwiseSpecified(source[key], options);
      }
    });
    return destination;
  }
  function deepmerge(target, source, options) {
    options = options || {};
    options.arrayMerge = options.arrayMerge || defaultArrayMerge;
    options.isMergeableObject = options.isMergeableObject || isMergeableObject;
    // cloneUnlessOtherwiseSpecified is added to `options` so that custom arrayMerge()
    // implementations can use it. The caller may not replace it.
    options.cloneUnlessOtherwiseSpecified = cloneUnlessOtherwiseSpecified;
    var sourceIsArray = Array.isArray(source);
    var targetIsArray = Array.isArray(target);
    var sourceAndTargetTypesMatch = sourceIsArray === targetIsArray;
    if (!sourceAndTargetTypesMatch) {
      return cloneUnlessOtherwiseSpecified(source, options);
    } else if (sourceIsArray) {
      return options.arrayMerge(target, source, options);
    } else {
      return mergeObject(target, source, options);
    }
  }
  deepmerge.all = function deepmergeAll(array, options) {
    if (!Array.isArray(array)) {
      throw new Error('first argument should be an array');
    }
    return array.reduce(function (prev, next) {
      return deepmerge(prev, next, options);
    }, {});
  };
  var deepmerge_1 = deepmerge;
  var cjs = deepmerge_1;
  var merge = cjs;

  var quantities = {exports: {}};

  /*
  The MIT License (MIT)
  Copyright © 2006-2007 Kevin C. Olbrich
  Copyright © 2010-2016 LIM SAS (http://lim.eu) - Julien Sanchez

  Permission is hereby granted, free of charge, to any person obtaining a copy of
  this software and associated documentation files (the "Software"), to deal in
  the Software without restriction, including without limitation the rights to
  use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
  of the Software, and to permit persons to whom the Software is furnished to do
  so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in all
  copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  SOFTWARE.
  */
  (function (module, exports) {
    (function (global, factory) {
      module.exports = factory() ;
    })(commonjsGlobal, function () {

      /**
       * Tests if a value is a string
       *
       * @param {*} value - Value to test
       *
       * @returns {boolean} true if value is a string, false otherwise
       */
      function isString(value) {
        return typeof value === "string" || value instanceof String;
      }

      /*
       * Prefer stricter Number.isFinite if currently supported.
       * To be dropped when ES6 is finalized. Obsolete browsers will
       * have to use ES6 polyfills.
       */
      var isFiniteImpl = Number.isFinite || window.isFinite;
      /**
       * Tests if a value is a number
       *
       * @param {*} value - Value to test
       *
       * @returns {boolean} true if value is a number, false otherwise
       */
      function isNumber(value) {
        // Number.isFinite allows not to consider NaN or '1' as numbers
        return isFiniteImpl(value);
      }

      /*
       * Identity function
       */
      function identity(value) {
        return value;
      }

      /**
       * Returns unique strings from list
       *
       * @param {string[]} strings - array of strings
       *
       *
       * @returns {string[]} a new array of strings without duplicates
       */
      function uniq(strings) {
        var seen = {};
        return strings.filter(function (item) {
          return seen.hasOwnProperty(item) ? false : seen[item] = true;
        });
      }
      function compareArray(array1, array2) {
        if (array2.length !== array1.length) {
          return false;
        }
        for (var i = 0; i < array1.length; i++) {
          if (array2[i].compareArray) {
            if (!array2[i].compareArray(array1[i])) {
              return false;
            }
          }
          if (array2[i] !== array1[i]) {
            return false;
          }
        }
        return true;
      }
      function assign(target, properties) {
        Object.keys(properties).forEach(function (key) {
          target[key] = properties[key];
        });
      }

      /**
       * Safely multiplies numbers while avoiding floating errors
       * like 0.1 * 0.1 => 0.010000000000000002
       *
       * @param {...number} numbers - numbers to multiply
       *
       * @returns {number} result
       */
      function mulSafe() {
        var result = 1,
          decimals = 0;
        for (var i = 0; i < arguments.length; i++) {
          var arg = arguments[i];
          decimals = decimals + getFractional(arg);
          result *= arg;
        }
        return decimals !== 0 ? round(result, decimals) : result;
      }

      /**
       * Safely divides two numbers while avoiding floating errors
       * like 0.3 / 0.05 => 5.999999999999999
       *
       * @returns {number} result
       * @param {number} num Numerator
       * @param {number} den Denominator
       */
      function divSafe(num, den) {
        if (den === 0) {
          throw new Error("Divide by zero");
        }
        var factor = Math.pow(10, getFractional(den));
        var invDen = factor / (factor * den);
        return mulSafe(num, invDen);
      }

      /**
       * Rounds value at the specified number of decimals
       *
       * @param {number} val - value to round
       * @param {number} decimals - number of decimals
       *
       * @returns {number} rounded number
       */
      function round(val, decimals) {
        return Math.round(val * Math.pow(10, decimals)) / Math.pow(10, decimals);
      }
      function getFractional(num) {
        // Check for NaNs or Infinities
        if (!isFinite(num)) {
          return 0;
        }

        // Faster than parsing strings
        // http://jsperf.com/count-decimals/2
        var count = 0;
        while (num % 1 !== 0) {
          num *= 10;
          count++;
        }
        return count;
      }

      /**
       * Custom error type definition
       * @constructor
       */
      function QtyError() {
        var err;
        if (!this) {
          // Allows to instantiate QtyError without new()
          err = Object.create(QtyError.prototype);
          QtyError.apply(err, arguments);
          return err;
        }
        err = Error.apply(this, arguments);
        this.name = "QtyError";
        this.message = err.message;
        this.stack = err.stack;
      }
      QtyError.prototype = Object.create(Error.prototype, {
        constructor: {
          value: QtyError
        }
      });

      /*
       * Throws incompatible units error
       * @param {string} left - units
       * @param {string} right - units incompatible with first argument
       * @throws "Incompatible units" error
       */
      function throwIncompatibleUnits(left, right) {
        throw new QtyError("Incompatible units: " + left + " and " + right);
      }
      var UNITS = {
        /* prefixes */
        "<googol>": [["googol"], 1e100, "prefix"],
        "<kibi>": [["Ki", "Kibi", "kibi"], Math.pow(2, 10), "prefix"],
        "<mebi>": [["Mi", "Mebi", "mebi"], Math.pow(2, 20), "prefix"],
        "<gibi>": [["Gi", "Gibi", "gibi"], Math.pow(2, 30), "prefix"],
        "<tebi>": [["Ti", "Tebi", "tebi"], Math.pow(2, 40), "prefix"],
        "<pebi>": [["Pi", "Pebi", "pebi"], Math.pow(2, 50), "prefix"],
        "<exi>": [["Ei", "Exi", "exi"], Math.pow(2, 60), "prefix"],
        "<zebi>": [["Zi", "Zebi", "zebi"], Math.pow(2, 70), "prefix"],
        "<yebi>": [["Yi", "Yebi", "yebi"], Math.pow(2, 80), "prefix"],
        "<yotta>": [["Y", "Yotta", "yotta"], 1e24, "prefix"],
        "<zetta>": [["Z", "Zetta", "zetta"], 1e21, "prefix"],
        "<exa>": [["E", "Exa", "exa"], 1e18, "prefix"],
        "<peta>": [["P", "Peta", "peta"], 1e15, "prefix"],
        "<tera>": [["T", "Tera", "tera"], 1e12, "prefix"],
        "<giga>": [["G", "Giga", "giga"], 1e9, "prefix"],
        "<mega>": [["M", "Mega", "mega"], 1e6, "prefix"],
        "<kilo>": [["k", "kilo"], 1e3, "prefix"],
        "<hecto>": [["h", "Hecto", "hecto"], 1e2, "prefix"],
        "<deca>": [["da", "Deca", "deca", "deka"], 1e1, "prefix"],
        "<deci>": [["d", "Deci", "deci"], 1e-1, "prefix"],
        "<centi>": [["c", "Centi", "centi"], 1e-2, "prefix"],
        "<milli>": [["m", "Milli", "milli"], 1e-3, "prefix"],
        "<micro>": [["u", "\u03BC" /*µ as greek letter*/, "\u00B5" /*µ as micro sign*/, "Micro", "mc", "micro"], 1e-6, "prefix"],
        "<nano>": [["n", "Nano", "nano"], 1e-9, "prefix"],
        "<pico>": [["p", "Pico", "pico"], 1e-12, "prefix"],
        "<femto>": [["f", "Femto", "femto"], 1e-15, "prefix"],
        "<atto>": [["a", "Atto", "atto"], 1e-18, "prefix"],
        "<zepto>": [["z", "Zepto", "zepto"], 1e-21, "prefix"],
        "<yocto>": [["y", "Yocto", "yocto"], 1e-24, "prefix"],
        "<1>": [["1", "<1>"], 1, ""],
        /* length units */
        "<meter>": [["m", "meter", "meters", "metre", "metres"], 1.0, "length", ["<meter>"]],
        "<inch>": [["in", "inch", "inches", "\""], 0.0254, "length", ["<meter>"]],
        "<foot>": [["ft", "foot", "feet", "'"], 0.3048, "length", ["<meter>"]],
        "<yard>": [["yd", "yard", "yards"], 0.9144, "length", ["<meter>"]],
        "<mile>": [["mi", "mile", "miles"], 1609.344, "length", ["<meter>"]],
        "<naut-mile>": [["nmi", "naut-mile"], 1852, "length", ["<meter>"]],
        "<league>": [["league", "leagues"], 4828, "length", ["<meter>"]],
        "<furlong>": [["furlong", "furlongs"], 201.2, "length", ["<meter>"]],
        "<rod>": [["rd", "rod", "rods"], 5.029, "length", ["<meter>"]],
        "<mil>": [["mil", "mils"], 0.0000254, "length", ["<meter>"]],
        "<angstrom>": [["ang", "angstrom", "angstroms"], 1e-10, "length", ["<meter>"]],
        "<fathom>": [["fathom", "fathoms"], 1.829, "length", ["<meter>"]],
        "<pica>": [["pica", "picas"], 0.00423333333, "length", ["<meter>"]],
        "<point>": [["pt", "point", "points"], 0.000352777778, "length", ["<meter>"]],
        "<redshift>": [["z", "red-shift", "redshift"], 1.302773e26, "length", ["<meter>"]],
        "<AU>": [["AU", "astronomical-unit"], 149597900000, "length", ["<meter>"]],
        "<light-second>": [["ls", "light-second"], 299792500, "length", ["<meter>"]],
        "<light-minute>": [["lmin", "light-minute"], 17987550000, "length", ["<meter>"]],
        "<light-year>": [["ly", "light-year"], 9460528000000000, "length", ["<meter>"]],
        "<parsec>": [["pc", "parsec", "parsecs"], 30856780000000000, "length", ["<meter>"]],
        "<datamile>": [["DM", "datamile"], 1828.8, "length", ["<meter>"]],
        /* mass */
        "<kilogram>": [["kg", "kilogram", "kilograms"], 1.0, "mass", ["<kilogram>"]],
        "<AMU>": [["u", "AMU", "amu"], 1.660538921e-27, "mass", ["<kilogram>"]],
        "<dalton>": [["Da", "Dalton", "Daltons", "dalton", "daltons"], 1.660538921e-27, "mass", ["<kilogram>"]],
        "<slug>": [["slug", "slugs"], 14.5939029, "mass", ["<kilogram>"]],
        "<short-ton>": [["tn", "ton", "short-ton"], 907.18474, "mass", ["<kilogram>"]],
        "<metric-ton>": [["t", "tonne", "metric-ton"], 1000, "mass", ["<kilogram>"]],
        "<carat>": [["ct", "carat", "carats"], 0.0002, "mass", ["<kilogram>"]],
        "<pound>": [["lbs", "lb", "pound", "pounds", "#"], 0.45359237, "mass", ["<kilogram>"]],
        "<ounce>": [["oz", "ounce", "ounces"], 0.0283495231, "mass", ["<kilogram>"]],
        "<gram>": [["g", "gram", "grams", "gramme", "grammes"], 1e-3, "mass", ["<kilogram>"]],
        "<grain>": [["grain", "grains", "gr"], 6.479891e-5, "mass", ["<kilogram>"]],
        "<dram>": [["dram", "drams", "dr"], 0.0017718452, "mass", ["<kilogram>"]],
        "<stone>": [["stone", "stones", "st"], 6.35029318, "mass", ["<kilogram>"]],
        /* area */
        "<hectare>": [["hectare"], 10000, "area", ["<meter>", "<meter>"]],
        "<acre>": [["acre", "acres"], 4046.85642, "area", ["<meter>", "<meter>"]],
        "<sqft>": [["sqft"], 1, "area", ["<foot>", "<foot>"]],
        /* volume */
        "<liter>": [["l", "L", "liter", "liters", "litre", "litres"], 0.001, "volume", ["<meter>", "<meter>", "<meter>"]],
        "<gallon>": [["gal", "gallon", "gallons"], 0.0037854118, "volume", ["<meter>", "<meter>", "<meter>"]],
        "<gallon-imp>": [["galimp", "gallon-imp", "gallons-imp"], 0.0045460900, "volume", ["<meter>", "<meter>", "<meter>"]],
        "<quart>": [["qt", "quart", "quarts"], 0.00094635295, "volume", ["<meter>", "<meter>", "<meter>"]],
        "<pint>": [["pt", "pint", "pints"], 0.000473176475, "volume", ["<meter>", "<meter>", "<meter>"]],
        "<pint-imp>": [["ptimp", "pint-imp", "pints-imp"], 5.6826125e-4, "volume", ["<meter>", "<meter>", "<meter>"]],
        "<cup>": [["cu", "cup", "cups"], 0.000236588238, "volume", ["<meter>", "<meter>", "<meter>"]],
        "<fluid-ounce>": [["floz", "fluid-ounce", "fluid-ounces"], 2.95735297e-5, "volume", ["<meter>", "<meter>", "<meter>"]],
        "<fluid-ounce-imp>": [["flozimp", "floz-imp", "fluid-ounce-imp", "fluid-ounces-imp"], 2.84130625e-5, "volume", ["<meter>", "<meter>", "<meter>"]],
        "<tablespoon>": [["tb", "tbsp", "tbs", "tablespoon", "tablespoons"], 1.47867648e-5, "volume", ["<meter>", "<meter>", "<meter>"]],
        "<teaspoon>": [["tsp", "teaspoon", "teaspoons"], 4.92892161e-6, "volume", ["<meter>", "<meter>", "<meter>"]],
        "<bushel>": [["bu", "bsh", "bushel", "bushels"], 0.035239072, "volume", ["<meter>", "<meter>", "<meter>"]],
        "<oilbarrel>": [["bbl", "oilbarrel", "oilbarrels", "oil-barrel", "oil-barrels"], 0.158987294928, "volume", ["<meter>", "<meter>", "<meter>"]],
        "<beerbarrel>": [["bl", "bl-us", "beerbarrel", "beerbarrels", "beer-barrel", "beer-barrels"], 0.1173477658, "volume", ["<meter>", "<meter>", "<meter>"]],
        "<beerbarrel-imp>": [["blimp", "bl-imp", "beerbarrel-imp", "beerbarrels-imp", "beer-barrel-imp", "beer-barrels-imp"], 0.16365924, "volume", ["<meter>", "<meter>", "<meter>"]],
        /* speed */
        "<kph>": [["kph"], 0.277777778, "speed", ["<meter>"], ["<second>"]],
        "<mph>": [["mph"], 0.44704, "speed", ["<meter>"], ["<second>"]],
        "<knot>": [["kt", "kn", "kts", "knot", "knots"], 0.514444444, "speed", ["<meter>"], ["<second>"]],
        "<fps>": [["fps"], 0.3048, "speed", ["<meter>"], ["<second>"]],
        /* acceleration */
        "<gee>": [["gee"], 9.80665, "acceleration", ["<meter>"], ["<second>", "<second>"]],
        "<Gal>": [["Gal"], 1e-2, "acceleration", ["<meter>"], ["<second>", "<second>"]],
        /* temperature_difference */
        "<kelvin>": [["degK", "kelvin"], 1.0, "temperature", ["<kelvin>"]],
        "<celsius>": [["degC", "celsius", "celsius", "centigrade"], 1.0, "temperature", ["<kelvin>"]],
        "<fahrenheit>": [["degF", "fahrenheit"], 5 / 9, "temperature", ["<kelvin>"]],
        "<rankine>": [["degR", "rankine"], 5 / 9, "temperature", ["<kelvin>"]],
        "<temp-K>": [["tempK", "temp-K"], 1.0, "temperature", ["<temp-K>"]],
        "<temp-C>": [["tempC", "temp-C"], 1.0, "temperature", ["<temp-K>"]],
        "<temp-F>": [["tempF", "temp-F"], 5 / 9, "temperature", ["<temp-K>"]],
        "<temp-R>": [["tempR", "temp-R"], 5 / 9, "temperature", ["<temp-K>"]],
        /* time */
        "<second>": [["s", "sec", "secs", "second", "seconds"], 1.0, "time", ["<second>"]],
        "<minute>": [["min", "mins", "minute", "minutes"], 60.0, "time", ["<second>"]],
        "<hour>": [["h", "hr", "hrs", "hour", "hours"], 3600.0, "time", ["<second>"]],
        "<day>": [["d", "day", "days"], 3600 * 24, "time", ["<second>"]],
        "<week>": [["wk", "week", "weeks"], 7 * 3600 * 24, "time", ["<second>"]],
        "<fortnight>": [["fortnight", "fortnights"], 1209600, "time", ["<second>"]],
        "<year>": [["y", "yr", "year", "years", "annum"], 31556926, "time", ["<second>"]],
        "<decade>": [["decade", "decades"], 315569260, "time", ["<second>"]],
        "<century>": [["century", "centuries"], 3155692600, "time", ["<second>"]],
        /* pressure */
        "<pascal>": [["Pa", "pascal", "Pascal"], 1.0, "pressure", ["<kilogram>"], ["<meter>", "<second>", "<second>"]],
        "<bar>": [["bar", "bars"], 100000, "pressure", ["<kilogram>"], ["<meter>", "<second>", "<second>"]],
        "<mmHg>": [["mmHg"], 133.322368, "pressure", ["<kilogram>"], ["<meter>", "<second>", "<second>"]],
        "<inHg>": [["inHg"], 3386.3881472, "pressure", ["<kilogram>"], ["<meter>", "<second>", "<second>"]],
        "<torr>": [["torr"], 133.322368, "pressure", ["<kilogram>"], ["<meter>", "<second>", "<second>"]],
        "<atm>": [["atm", "ATM", "atmosphere", "atmospheres"], 101325, "pressure", ["<kilogram>"], ["<meter>", "<second>", "<second>"]],
        "<psi>": [["psi"], 6894.76, "pressure", ["<kilogram>"], ["<meter>", "<second>", "<second>"]],
        "<cmh2o>": [["cmH2O", "cmh2o"], 98.0638, "pressure", ["<kilogram>"], ["<meter>", "<second>", "<second>"]],
        "<inh2o>": [["inH2O", "inh2o"], 249.082052, "pressure", ["<kilogram>"], ["<meter>", "<second>", "<second>"]],
        /* viscosity */
        "<poise>": [["P", "poise"], 0.1, "viscosity", ["<kilogram>"], ["<meter>", "<second>"]],
        "<stokes>": [["St", "stokes"], 1e-4, "viscosity", ["<meter>", "<meter>"], ["<second>"]],
        /* substance */
        "<mole>": [["mol", "mole"], 1.0, "substance", ["<mole>"]],
        /* molar_concentration */
        "<molar>": [["M", "molar"], 1000, "molar_concentration", ["<mole>"], ["<meter>", "<meter>", "<meter>"]],
        "<wtpercent>": [["wt%", "wtpercent"], 10, "molar_concentration", ["<kilogram>"], ["<meter>", "<meter>", "<meter>"]],
        /* activity */
        "<katal>": [["kat", "katal", "Katal"], 1.0, "activity", ["<mole>"], ["<second>"]],
        "<unit>": [["U", "enzUnit", "unit"], 16.667e-16, "activity", ["<mole>"], ["<second>"]],
        /* capacitance */
        "<farad>": [["F", "farad", "Farad"], 1.0, "capacitance", ["<second>", "<second>", "<second>", "<second>", "<ampere>", "<ampere>"], ["<meter>", "<meter>", "<kilogram>"]],
        /* charge */
        "<coulomb>": [["C", "coulomb", "Coulomb"], 1.0, "charge", ["<ampere>", "<second>"]],
        "<Ah>": [["Ah"], 3600, "charge", ["<ampere>", "<second>"]],
        /* current */
        "<ampere>": [["A", "Ampere", "ampere", "amp", "amps"], 1.0, "current", ["<ampere>"]],
        /* conductance */
        "<siemens>": [["S", "Siemens", "siemens"], 1.0, "conductance", ["<second>", "<second>", "<second>", "<ampere>", "<ampere>"], ["<kilogram>", "<meter>", "<meter>"]],
        /* inductance */
        "<henry>": [["H", "Henry", "henry"], 1.0, "inductance", ["<meter>", "<meter>", "<kilogram>"], ["<second>", "<second>", "<ampere>", "<ampere>"]],
        /* potential */
        "<volt>": [["V", "Volt", "volt", "volts"], 1.0, "potential", ["<meter>", "<meter>", "<kilogram>"], ["<second>", "<second>", "<second>", "<ampere>"]],
        /* resistance */
        "<ohm>": [["Ohm", "ohm", "\u03A9" /*Ω as greek letter*/, "\u2126" /*Ω as ohm sign*/], 1.0, "resistance", ["<meter>", "<meter>", "<kilogram>"], ["<second>", "<second>", "<second>", "<ampere>", "<ampere>"]],
        /* magnetism */
        "<weber>": [["Wb", "weber", "webers"], 1.0, "magnetism", ["<meter>", "<meter>", "<kilogram>"], ["<second>", "<second>", "<ampere>"]],
        "<tesla>": [["T", "tesla", "teslas"], 1.0, "magnetism", ["<kilogram>"], ["<second>", "<second>", "<ampere>"]],
        "<gauss>": [["G", "gauss"], 1e-4, "magnetism", ["<kilogram>"], ["<second>", "<second>", "<ampere>"]],
        "<maxwell>": [["Mx", "maxwell", "maxwells"], 1e-8, "magnetism", ["<meter>", "<meter>", "<kilogram>"], ["<second>", "<second>", "<ampere>"]],
        "<oersted>": [["Oe", "oersted", "oersteds"], 250.0 / Math.PI, "magnetism", ["<ampere>"], ["<meter>"]],
        /* energy */
        "<joule>": [["J", "joule", "Joule", "joules", "Joules"], 1.0, "energy", ["<meter>", "<meter>", "<kilogram>"], ["<second>", "<second>"]],
        "<erg>": [["erg", "ergs"], 1e-7, "energy", ["<meter>", "<meter>", "<kilogram>"], ["<second>", "<second>"]],
        "<btu>": [["BTU", "btu", "BTUs"], 1055.056, "energy", ["<meter>", "<meter>", "<kilogram>"], ["<second>", "<second>"]],
        "<calorie>": [["cal", "calorie", "calories"], 4.18400, "energy", ["<meter>", "<meter>", "<kilogram>"], ["<second>", "<second>"]],
        "<Calorie>": [["Cal", "Calorie", "Calories"], 4184.00, "energy", ["<meter>", "<meter>", "<kilogram>"], ["<second>", "<second>"]],
        "<therm-US>": [["th", "therm", "therms", "Therm", "therm-US"], 105480400, "energy", ["<meter>", "<meter>", "<kilogram>"], ["<second>", "<second>"]],
        "<Wh>": [["Wh"], 3600, "energy", ["<meter>", "<meter>", "<kilogram>"], ["<second>", "<second>"]],
        "<electronvolt>": [["eV", "electronvolt", "electronvolts"], 1.602176634E-19, "energy", ["<meter>", "<meter>", "<kilogram>"], ["<second>", "<second>"]],
        /* force */
        "<newton>": [["N", "Newton", "newton"], 1.0, "force", ["<kilogram>", "<meter>"], ["<second>", "<second>"]],
        "<dyne>": [["dyn", "dyne"], 1e-5, "force", ["<kilogram>", "<meter>"], ["<second>", "<second>"]],
        "<pound-force>": [["lbf", "pound-force"], 4.448222, "force", ["<kilogram>", "<meter>"], ["<second>", "<second>"]],
        /* frequency */
        "<hertz>": [["Hz", "hertz", "Hertz"], 1.0, "frequency", ["<1>"], ["<second>"]],
        /* angle */
        "<radian>": [["rad", "radian", "radians"], 1.0, "angle", ["<radian>"]],
        "<degree>": [["deg", "degree", "degrees"], Math.PI / 180.0, "angle", ["<radian>"]],
        "<arcminute>": [["arcmin", "arcminute", "arcminutes"], Math.PI / 10800.0, "angle", ["<radian>"]],
        "<arcsecond>": [["arcsec", "arcsecond", "arcseconds"], Math.PI / 648000.0, "angle", ["<radian>"]],
        "<gradian>": [["gon", "grad", "gradian", "grads"], Math.PI / 200.0, "angle", ["<radian>"]],
        "<steradian>": [["sr", "steradian", "steradians"], 1.0, "solid_angle", ["<steradian>"]],
        /* rotation */
        "<rotation>": [["rotation"], 2.0 * Math.PI, "angle", ["<radian>"]],
        "<rpm>": [["rpm"], 2.0 * Math.PI / 60.0, "angular_velocity", ["<radian>"], ["<second>"]],
        /* information */
        "<byte>": [["B", "byte", "bytes"], 1.0, "information", ["<byte>"]],
        "<bit>": [["b", "bit", "bits"], 0.125, "information", ["<byte>"]],
        /* information rate */
        "<Bps>": [["Bps"], 1.0, "information_rate", ["<byte>"], ["<second>"]],
        "<bps>": [["bps"], 0.125, "information_rate", ["<byte>"], ["<second>"]],
        /* currency */
        "<dollar>": [["USD", "dollar"], 1.0, "currency", ["<dollar>"]],
        "<cents>": [["cents"], 0.01, "currency", ["<dollar>"]],
        /* luminosity */
        "<candela>": [["cd", "candela"], 1.0, "luminosity", ["<candela>"]],
        "<lumen>": [["lm", "lumen"], 1.0, "luminous_power", ["<candela>", "<steradian>"]],
        "<lux>": [["lux"], 1.0, "illuminance", ["<candela>", "<steradian>"], ["<meter>", "<meter>"]],
        /* power */
        "<watt>": [["W", "watt", "watts"], 1.0, "power", ["<kilogram>", "<meter>", "<meter>"], ["<second>", "<second>", "<second>"]],
        "<volt-ampere>": [["VA", "volt-ampere"], 1.0, "power", ["<kilogram>", "<meter>", "<meter>"], ["<second>", "<second>", "<second>"]],
        "<volt-ampere-reactive>": [["var", "Var", "VAr", "VAR", "volt-ampere-reactive"], 1.0, "power", ["<kilogram>", "<meter>", "<meter>"], ["<second>", "<second>", "<second>"]],
        "<horsepower>": [["hp", "horsepower"], 745.699872, "power", ["<kilogram>", "<meter>", "<meter>"], ["<second>", "<second>", "<second>"]],
        /* radiation */
        "<gray>": [["Gy", "gray", "grays"], 1.0, "radiation", ["<meter>", "<meter>"], ["<second>", "<second>"]],
        "<roentgen>": [["R", "roentgen"], 0.009330, "radiation", ["<meter>", "<meter>"], ["<second>", "<second>"]],
        "<sievert>": [["Sv", "sievert", "sieverts"], 1.0, "radiation", ["<meter>", "<meter>"], ["<second>", "<second>"]],
        "<becquerel>": [["Bq", "becquerel", "becquerels"], 1.0, "radiation", ["<1>"], ["<second>"]],
        "<curie>": [["Ci", "curie", "curies"], 3.7e10, "radiation", ["<1>"], ["<second>"]],
        /* rate */
        "<cpm>": [["cpm"], 1.0 / 60.0, "rate", ["<count>"], ["<second>"]],
        "<dpm>": [["dpm"], 1.0 / 60.0, "rate", ["<count>"], ["<second>"]],
        "<bpm>": [["bpm"], 1.0 / 60.0, "rate", ["<count>"], ["<second>"]],
        /* resolution / typography */
        "<dot>": [["dot", "dots"], 1, "resolution", ["<each>"]],
        "<pixel>": [["pixel", "px"], 1, "resolution", ["<each>"]],
        "<ppi>": [["ppi"], 1, "resolution", ["<pixel>"], ["<inch>"]],
        "<dpi>": [["dpi"], 1, "typography", ["<dot>"], ["<inch>"]],
        /* other */
        "<cell>": [["cells", "cell"], 1, "counting", ["<each>"]],
        "<each>": [["each"], 1.0, "counting", ["<each>"]],
        "<count>": [["count"], 1.0, "counting", ["<each>"]],
        "<base-pair>": [["bp", "base-pair"], 1.0, "counting", ["<each>"]],
        "<nucleotide>": [["nt", "nucleotide"], 1.0, "counting", ["<each>"]],
        "<molecule>": [["molecule", "molecules"], 1.0, "counting", ["<1>"]],
        "<dozen>": [["doz", "dz", "dozen"], 12.0, "prefix_only", ["<each>"]],
        "<percent>": [["%", "percent"], 0.01, "prefix_only", ["<1>"]],
        "<ppm>": [["ppm"], 1e-6, "prefix_only", ["<1>"]],
        "<ppb>": [["ppb"], 1e-9, "prefix_only", ["<1>"]],
        "<ppt>": [["ppt"], 1e-12, "prefix_only", ["<1>"]],
        "<ppq>": [["ppq"], 1e-15, "prefix_only", ["<1>"]],
        "<gross>": [["gr", "gross"], 144.0, "prefix_only", ["<dozen>", "<dozen>"]],
        "<decibel>": [["dB", "decibel", "decibels"], 1.0, "logarithmic", ["<decibel>"]]
      };
      var BASE_UNITS = ["<meter>", "<kilogram>", "<second>", "<mole>", "<ampere>", "<radian>", "<kelvin>", "<temp-K>", "<byte>", "<dollar>", "<candela>", "<each>", "<steradian>", "<decibel>"];
      var UNITY = "<1>";
      var UNITY_ARRAY = [UNITY];

      // Setup

      /**
       * Asserts unit definition is valid
       *
       * @param {string} unitDef - Name of unit to test
       * @param {Object} definition - Definition of unit to test
       *
       * @returns {void}
       * @throws {QtyError} if unit definition is not valid
       */
      function validateUnitDefinition(unitDef, definition) {
        var scalar = definition[1];
        var numerator = definition[3] || [];
        var denominator = definition[4] || [];
        if (!isNumber(scalar)) {
          throw new QtyError(unitDef + ": Invalid unit definition. " + "'scalar' must be a number");
        }
        numerator.forEach(function (unit) {
          if (UNITS[unit] === undefined) {
            throw new QtyError(unitDef + ": Invalid unit definition. " + "Unit " + unit + " in 'numerator' is not recognized");
          }
        });
        denominator.forEach(function (unit) {
          if (UNITS[unit] === undefined) {
            throw new QtyError(unitDef + ": Invalid unit definition. " + "Unit " + unit + " in 'denominator' is not recognized");
          }
        });
      }
      var PREFIX_VALUES = {};
      var PREFIX_MAP = {};
      var UNIT_VALUES = {};
      var UNIT_MAP = {};
      var OUTPUT_MAP = {};
      for (var unitDef in UNITS) {
        if (UNITS.hasOwnProperty(unitDef)) {
          var definition = UNITS[unitDef];
          if (definition[2] === "prefix") {
            PREFIX_VALUES[unitDef] = definition[1];
            for (var i = 0; i < definition[0].length; i++) {
              PREFIX_MAP[definition[0][i]] = unitDef;
            }
          } else {
            validateUnitDefinition(unitDef, definition);
            UNIT_VALUES[unitDef] = {
              scalar: definition[1],
              numerator: definition[3],
              denominator: definition[4]
            };
            for (var j = 0; j < definition[0].length; j++) {
              UNIT_MAP[definition[0][j]] = unitDef;
            }
          }
          OUTPUT_MAP[unitDef] = definition[0][0];
        }
      }

      /**
       * Returns a list of available units of kind
       *
       * @param {string} [kind] - kind of units
       * @returns {array} names of units
       * @throws {QtyError} if kind is unknown
       */
      function getUnits(kind) {
        var i;
        var units = [];
        var unitKeys = Object.keys(UNITS);
        if (typeof kind === "undefined") {
          for (i = 0; i < unitKeys.length; i++) {
            if (["", "prefix"].indexOf(UNITS[unitKeys[i]][2]) === -1) {
              units.push(unitKeys[i].substr(1, unitKeys[i].length - 2));
            }
          }
        } else if (this.getKinds().indexOf(kind) === -1) {
          throw new QtyError("Kind not recognized");
        } else {
          for (i = 0; i < unitKeys.length; i++) {
            if (UNITS[unitKeys[i]][2] === kind) {
              units.push(unitKeys[i].substr(1, unitKeys[i].length - 2));
            }
          }
        }
        return units.sort(function (a, b) {
          if (a.toLowerCase() < b.toLowerCase()) {
            return -1;
          }
          if (a.toLowerCase() > b.toLowerCase()) {
            return 1;
          }
          return 0;
        });
      }

      /**
       * Returns a list of alternative names for a unit
       *
       * @param {string} unitName - name of unit
       * @returns {string[]} aliases for unit
       * @throws {QtyError} if unit is unknown
       */
      function getAliases(unitName) {
        if (!UNIT_MAP[unitName]) {
          throw new QtyError("Unit not recognized");
        }
        return UNITS[UNIT_MAP[unitName]][0];
      }
      var SIGNATURE_VECTOR = ["length", "time", "temperature", "mass", "current", "substance", "luminosity", "currency", "information", "angle"];

      /*
      calculates the unit signature id for use in comparing compatible units and simplification
      the signature is based on a simple classification of units and is based on the following publication
       Novak, G.S., Jr. "Conversion of units of measurement", IEEE Transactions on Software Engineering,
      21(8), Aug 1995, pp.651-661
      doi://10.1109/32.403789
      http://ieeexplore.ieee.org/Xplore/login.jsp?url=/iel1/32/9079/00403789.pdf?isnumber=9079&prod=JNL&arnumber=403789&arSt=651&ared=661&arAuthor=Novak%2C+G.S.%2C+Jr.
      */
      function unitSignature() {
        if (this.signature) {
          return this.signature;
        }
        var vector = unitSignatureVector.call(this);
        for (var i = 0; i < vector.length; i++) {
          vector[i] *= Math.pow(20, i);
        }
        return vector.reduce(function (previous, current) {
          return previous + current;
        }, 0);
      }

      // calculates the unit signature vector used by unit_signature
      function unitSignatureVector() {
        if (!this.isBase()) {
          return unitSignatureVector.call(this.toBase());
        }
        var vector = new Array(SIGNATURE_VECTOR.length);
        for (var i = 0; i < vector.length; i++) {
          vector[i] = 0;
        }
        var r, n;
        for (var j = 0; j < this.numerator.length; j++) {
          if (r = UNITS[this.numerator[j]]) {
            n = SIGNATURE_VECTOR.indexOf(r[2]);
            if (n >= 0) {
              vector[n] = vector[n] + 1;
            }
          }
        }
        for (var k = 0; k < this.denominator.length; k++) {
          if (r = UNITS[this.denominator[k]]) {
            n = SIGNATURE_VECTOR.indexOf(r[2]);
            if (n >= 0) {
              vector[n] = vector[n] - 1;
            }
          }
        }
        return vector;
      }
      var SIGN = "[+-]";
      var INTEGER = "\\d+";
      var SIGNED_INTEGER = SIGN + "?" + INTEGER;
      var FRACTION = "\\." + INTEGER;
      var FLOAT = "(?:" + INTEGER + "(?:" + FRACTION + ")?" + ")" + "|" + "(?:" + FRACTION + ")";
      var EXPONENT = "[Ee]" + SIGNED_INTEGER;
      var SCI_NUMBER = "(?:" + FLOAT + ")(?:" + EXPONENT + ")?";
      var SIGNED_NUMBER = SIGN + "?\\s*" + SCI_NUMBER;
      var QTY_STRING = "(" + SIGNED_NUMBER + ")?" + "\\s*([^/]*)(?:\/(.+))?";
      var QTY_STRING_REGEX = new RegExp("^" + QTY_STRING + "$");
      var POWER_OP = "\\^|\\*{2}";
      // Allow unit powers representing scalar, length, area, volume; 4 is for some
      // special case representations in SI base units.
      var SAFE_POWER = "[01234]";
      var TOP_REGEX = new RegExp("([^ \\*\\d]+?)(?:" + POWER_OP + ")?(-?" + SAFE_POWER + "(?![a-zA-Z]))");
      var BOTTOM_REGEX = new RegExp("([^ \\*\\d]+?)(?:" + POWER_OP + ")?(" + SAFE_POWER + "(?![a-zA-Z]))");

      /* parse a string into a unit object.
       * Typical formats like :
       * "5.6 kg*m/s^2"
       * "5.6 kg*m*s^-2"
       * "5.6 kilogram*meter*second^-2"
       * "2.2 kPa"
       * "37 degC"
       * "1"  -- creates a unitless constant with value 1
       * "GPa"  -- creates a unit with scalar 1 with units 'GPa'
       * 6'4"  -- recognized as 6 feet + 4 inches
       * 8 lbs 8 oz -- recognized as 8 lbs + 8 ounces
       */
      function parse(val) {
        if (!isString(val)) {
          val = val.toString();
        }
        val = val.trim();
        var result = QTY_STRING_REGEX.exec(val);
        if (!result) {
          throw new QtyError(val + ": Quantity not recognized");
        }
        var scalarMatch = result[1];
        if (scalarMatch) {
          // Allow whitespaces between sign and scalar for loose parsing
          scalarMatch = scalarMatch.replace(/\s/g, "");
          this.scalar = parseFloat(scalarMatch);
        } else {
          this.scalar = 1;
        }
        var top = result[2];
        var bottom = result[3];
        var n, x, nx;
        // TODO DRY me
        while (result = TOP_REGEX.exec(top)) {
          n = parseFloat(result[2]);
          if (isNaN(n)) {
            // Prevents infinite loops
            throw new QtyError("Unit exponent is not a number");
          }
          // Disallow unrecognized unit even if exponent is 0
          if (n === 0 && !UNIT_TEST_REGEX.test(result[1])) {
            throw new QtyError("Unit not recognized");
          }
          x = result[1] + " ";
          nx = "";
          for (var i = 0; i < Math.abs(n); i++) {
            nx += x;
          }
          if (n >= 0) {
            top = top.replace(result[0], nx);
          } else {
            bottom = bottom ? bottom + nx : nx;
            top = top.replace(result[0], "");
          }
        }
        while (result = BOTTOM_REGEX.exec(bottom)) {
          n = parseFloat(result[2]);
          if (isNaN(n)) {
            // Prevents infinite loops
            throw new QtyError("Unit exponent is not a number");
          }
          // Disallow unrecognized unit even if exponent is 0
          if (n === 0 && !UNIT_TEST_REGEX.test(result[1])) {
            throw new QtyError("Unit not recognized");
          }
          x = result[1] + " ";
          nx = "";
          for (var j = 0; j < n; j++) {
            nx += x;
          }
          bottom = bottom.replace(result[0], nx);
        }
        if (top) {
          this.numerator = parseUnits(top.trim());
        }
        if (bottom) {
          this.denominator = parseUnits(bottom.trim());
        }
      }
      var PREFIX_REGEX = Object.keys(PREFIX_MAP).sort(function (a, b) {
        return b.length - a.length;
      }).join("|");
      var UNIT_REGEX = Object.keys(UNIT_MAP).sort(function (a, b) {
        return b.length - a.length;
      }).join("|");
      /*
       * Minimal boundary regex to support units with Unicode characters
       * \b only works for ASCII
       */
      var BOUNDARY_REGEX = "\\b|$";
      var UNIT_MATCH = "(" + PREFIX_REGEX + ")??(" + UNIT_REGEX + ")(?:" + BOUNDARY_REGEX + ")";
      var UNIT_TEST_REGEX = new RegExp("^\\s*(" + UNIT_MATCH + "[\\s\\*]*)+$");
      var UNIT_MATCH_REGEX = new RegExp(UNIT_MATCH, "g"); // g flag for multiple occurences
      var parsedUnitsCache = {};
      /**
       * Parses and converts units string to normalized unit array.
       * Result is cached to speed up next calls.
       *
       * @param {string} units Units string
       * @returns {string[]} Array of normalized units
       *
       * @example
       * // Returns ["<second>", "<meter>", "<second>"]
       * parseUnits("s m s");
       *
       */
      function parseUnits(units) {
        var cached = parsedUnitsCache[units];
        if (cached) {
          return cached;
        }
        var unitMatch,
          normalizedUnits = [];

        // Scan
        if (!UNIT_TEST_REGEX.test(units)) {
          throw new QtyError("Unit not recognized");
        }
        while (unitMatch = UNIT_MATCH_REGEX.exec(units)) {
          normalizedUnits.push(unitMatch.slice(1));
        }
        normalizedUnits = normalizedUnits.map(function (item) {
          return PREFIX_MAP[item[0]] ? [PREFIX_MAP[item[0]], UNIT_MAP[item[1]]] : [UNIT_MAP[item[1]]];
        });

        // Flatten and remove null elements
        normalizedUnits = normalizedUnits.reduce(function (a, b) {
          return a.concat(b);
        }, []);
        normalizedUnits = normalizedUnits.filter(function (item) {
          return item;
        });
        parsedUnitsCache[units] = normalizedUnits;
        return normalizedUnits;
      }

      /**
       * Parses a string as a quantity
       * @param {string} value - quantity as text
       * @throws if value is not a string
       * @returns {Qty|null} Parsed quantity or null if unrecognized
       */
      function globalParse(value) {
        if (!isString(value)) {
          throw new QtyError("Argument should be a string");
        }
        try {
          return this(value);
        } catch (e) {
          return null;
        }
      }

      /**
       * Tests if a value is a Qty instance
       *
       * @param {*} value - Value to test
       *
       * @returns {boolean} true if value is a Qty instance, false otherwise
       */
      function isQty(value) {
        return value instanceof Qty;
      }
      function Qty(initValue, initUnits) {
        assertValidConstructorArgs.apply(null, arguments);
        if (!isQty(this)) {
          return new Qty(initValue, initUnits);
        }
        this.scalar = null;
        this.baseScalar = null;
        this.signature = null;
        this._conversionCache = {};
        this.numerator = UNITY_ARRAY;
        this.denominator = UNITY_ARRAY;
        if (isDefinitionObject(initValue)) {
          this.scalar = initValue.scalar;
          this.numerator = initValue.numerator && initValue.numerator.length !== 0 ? initValue.numerator : UNITY_ARRAY;
          this.denominator = initValue.denominator && initValue.denominator.length !== 0 ? initValue.denominator : UNITY_ARRAY;
        } else if (initUnits) {
          parse.call(this, initUnits);
          this.scalar = initValue;
        } else {
          parse.call(this, initValue);
        }

        // math with temperatures is very limited
        if (this.denominator.join("*").indexOf("temp") >= 0) {
          throw new QtyError("Cannot divide with temperatures");
        }
        if (this.numerator.join("*").indexOf("temp") >= 0) {
          if (this.numerator.length > 1) {
            throw new QtyError("Cannot multiply by temperatures");
          }
          if (!compareArray(this.denominator, UNITY_ARRAY)) {
            throw new QtyError("Cannot divide with temperatures");
          }
        }
        this.initValue = initValue;
        updateBaseScalar.call(this);
        if (this.isTemperature() && this.baseScalar < 0) {
          throw new QtyError("Temperatures must not be less than absolute zero");
        }
      }
      Qty.prototype = {
        // Properly set up constructor
        constructor: Qty
      };

      /**
       * Asserts constructor arguments are valid
       *
       * @param {*} value - Value to test
       * @param {string} [units] - Optional units when value is passed as a number
       *
       * @returns {void}
       * @throws {QtyError} if constructor arguments are invalid
       */
      function assertValidConstructorArgs(value, units) {
        if (units) {
          if (!(isNumber(value) && isString(units))) {
            throw new QtyError("Only number accepted as initialization value " + "when units are explicitly provided");
          }
        } else {
          if (!(isString(value) || isNumber(value) || isQty(value) || isDefinitionObject(value))) {
            throw new QtyError("Only string, number or quantity accepted as " + "single initialization value");
          }
        }
      }

      /**
       * Tests if a value is a Qty definition object
       *
       * @param {*} value - Value to test
       *
       * @returns {boolean} true if value is a definition object, false otherwise
       */
      function isDefinitionObject(value) {
        return value && typeof value === "object" && value.hasOwnProperty("scalar");
      }
      function updateBaseScalar() {
        if (this.baseScalar) {
          return this.baseScalar;
        }
        if (this.isBase()) {
          this.baseScalar = this.scalar;
          this.signature = unitSignature.call(this);
        } else {
          var base = this.toBase();
          this.baseScalar = base.scalar;
          this.signature = base.signature;
        }
      }
      var KINDS = {
        "-312078": "elastance",
        "-312058": "resistance",
        "-312038": "inductance",
        "-152058": "potential",
        "-152040": "magnetism",
        "-152038": "magnetism",
        "-7997": "specific_volume",
        "-79": "snap",
        "-59": "jolt",
        "-39": "acceleration",
        "-38": "radiation",
        "-20": "frequency",
        "-19": "speed",
        "-18": "viscosity",
        "-17": "volumetric_flow",
        "-1": "wavenumber",
        "0": "unitless",
        "1": "length",
        "2": "area",
        "3": "volume",
        "20": "time",
        "400": "temperature",
        "7941": "yank",
        "7942": "power",
        "7959": "pressure",
        "7961": "force",
        "7962": "energy",
        "7979": "viscosity",
        "7981": "momentum",
        "7982": "angular_momentum",
        "7997": "density",
        "7998": "area_density",
        "8000": "mass",
        "152020": "radiation_exposure",
        "159999": "magnetism",
        "160000": "current",
        "160020": "charge",
        "312058": "conductance",
        "312078": "capacitance",
        "3199980": "activity",
        "3199997": "molar_concentration",
        "3200000": "substance",
        "63999998": "illuminance",
        "64000000": "luminous_power",
        "1280000000": "currency",
        "25599999980": "information_rate",
        "25600000000": "information",
        "511999999980": "angular_velocity",
        "512000000000": "angle"
      };

      /**
       * Returns the list of available well-known kinds of units, e.g.
       * "radiation" or "length".
       *
       * @returns {string[]} names of kinds of units
       */
      function getKinds() {
        return uniq(Object.keys(KINDS).map(function (knownSignature) {
          return KINDS[knownSignature];
        }));
      }
      Qty.prototype.kind = function () {
        return KINDS[this.signature.toString()];
      };
      assign(Qty.prototype, {
        isDegrees: function () {
          // signature may not have been calculated yet
          return (this.signature === null || this.signature === 400) && this.numerator.length === 1 && compareArray(this.denominator, UNITY_ARRAY) && (this.numerator[0].match(/<temp-[CFRK]>/) || this.numerator[0].match(/<(kelvin|celsius|rankine|fahrenheit)>/));
        },
        isTemperature: function () {
          return this.isDegrees() && this.numerator[0].match(/<temp-[CFRK]>/);
        }
      });
      function subtractTemperatures(lhs, rhs) {
        var lhsUnits = lhs.units();
        var rhsConverted = rhs.to(lhsUnits);
        var dstDegrees = Qty(getDegreeUnits(lhsUnits));
        return Qty({
          "scalar": lhs.scalar - rhsConverted.scalar,
          "numerator": dstDegrees.numerator,
          "denominator": dstDegrees.denominator
        });
      }
      function subtractTempDegrees(temp, deg) {
        var tempDegrees = deg.to(getDegreeUnits(temp.units()));
        return Qty({
          "scalar": temp.scalar - tempDegrees.scalar,
          "numerator": temp.numerator,
          "denominator": temp.denominator
        });
      }
      function addTempDegrees(temp, deg) {
        var tempDegrees = deg.to(getDegreeUnits(temp.units()));
        return Qty({
          "scalar": temp.scalar + tempDegrees.scalar,
          "numerator": temp.numerator,
          "denominator": temp.denominator
        });
      }
      function getDegreeUnits(units) {
        if (units === "tempK") {
          return "degK";
        } else if (units === "tempC") {
          return "degC";
        } else if (units === "tempF") {
          return "degF";
        } else if (units === "tempR") {
          return "degR";
        } else {
          throw new QtyError("Unknown type for temp conversion from: " + units);
        }
      }
      function toDegrees(src, dst) {
        var srcDegK = toDegK(src);
        var dstUnits = dst.units();
        var dstScalar;
        if (dstUnits === "degK") {
          dstScalar = srcDegK.scalar;
        } else if (dstUnits === "degC") {
          dstScalar = srcDegK.scalar;
        } else if (dstUnits === "degF") {
          dstScalar = srcDegK.scalar * 9 / 5;
        } else if (dstUnits === "degR") {
          dstScalar = srcDegK.scalar * 9 / 5;
        } else {
          throw new QtyError("Unknown type for degree conversion to: " + dstUnits);
        }
        return Qty({
          "scalar": dstScalar,
          "numerator": dst.numerator,
          "denominator": dst.denominator
        });
      }
      function toDegK(qty) {
        var units = qty.units();
        var q;
        if (units.match(/(deg)[CFRK]/)) {
          q = qty.baseScalar;
        } else if (units === "tempK") {
          q = qty.scalar;
        } else if (units === "tempC") {
          q = qty.scalar;
        } else if (units === "tempF") {
          q = qty.scalar * 5 / 9;
        } else if (units === "tempR") {
          q = qty.scalar * 5 / 9;
        } else {
          throw new QtyError("Unknown type for temp conversion from: " + units);
        }
        return Qty({
          "scalar": q,
          "numerator": ["<kelvin>"],
          "denominator": UNITY_ARRAY
        });
      }
      function toTemp(src, dst) {
        var dstUnits = dst.units();
        var dstScalar;
        if (dstUnits === "tempK") {
          dstScalar = src.baseScalar;
        } else if (dstUnits === "tempC") {
          dstScalar = src.baseScalar - 273.15;
        } else if (dstUnits === "tempF") {
          dstScalar = src.baseScalar * 9 / 5 - 459.67;
        } else if (dstUnits === "tempR") {
          dstScalar = src.baseScalar * 9 / 5;
        } else {
          throw new QtyError("Unknown type for temp conversion to: " + dstUnits);
        }
        return Qty({
          "scalar": dstScalar,
          "numerator": dst.numerator,
          "denominator": dst.denominator
        });
      }
      function toTempK(qty) {
        var units = qty.units();
        var q;
        if (units.match(/(deg)[CFRK]/)) {
          q = qty.baseScalar;
        } else if (units === "tempK") {
          q = qty.scalar;
        } else if (units === "tempC") {
          q = qty.scalar + 273.15;
        } else if (units === "tempF") {
          q = (qty.scalar + 459.67) * 5 / 9;
        } else if (units === "tempR") {
          q = qty.scalar * 5 / 9;
        } else {
          throw new QtyError("Unknown type for temp conversion from: " + units);
        }
        return Qty({
          "scalar": q,
          "numerator": ["<temp-K>"],
          "denominator": UNITY_ARRAY
        });
      }
      assign(Qty.prototype, {
        /**
         * Converts to other compatible units.
         * Instance's converted quantities are cached for faster subsequent calls.
         *
         * @param {(string|Qty)} other - Target units as string or retrieved from
         *                               other Qty instance (scalar is ignored)
         *
         * @returns {Qty} New converted Qty instance with target units
         *
         * @throws {QtyError} if target units are incompatible
         *
         * @example
         * var weight = Qty("25 kg");
         * weight.to("lb"); // => Qty("55.11556554621939 lbs");
         * weight.to(Qty("3 g")); // => Qty("25000 g"); // scalar of passed Qty is ignored
         */
        to: function (other) {
          var cached, target;
          if (other === undefined || other === null) {
            return this;
          }
          if (!isString(other)) {
            return this.to(other.units());
          }
          cached = this._conversionCache[other];
          if (cached) {
            return cached;
          }

          // Instantiating target to normalize units
          target = Qty(other);
          if (target.units() === this.units()) {
            return this;
          }
          if (!this.isCompatible(target)) {
            if (this.isInverse(target)) {
              target = this.inverse().to(other);
            } else {
              throwIncompatibleUnits(this.units(), target.units());
            }
          } else {
            if (target.isTemperature()) {
              target = toTemp(this, target);
            } else if (target.isDegrees()) {
              target = toDegrees(this, target);
            } else {
              var q = divSafe(this.baseScalar, target.baseScalar);
              target = Qty({
                "scalar": q,
                "numerator": target.numerator,
                "denominator": target.denominator
              });
            }
          }
          this._conversionCache[other] = target;
          return target;
        },
        // convert to base SI units
        // results of the conversion are cached so subsequent calls to this will be fast
        toBase: function () {
          if (this.isBase()) {
            return this;
          }
          if (this.isTemperature()) {
            return toTempK(this);
          }
          var cached = baseUnitCache[this.units()];
          if (!cached) {
            cached = toBaseUnits(this.numerator, this.denominator);
            baseUnitCache[this.units()] = cached;
          }
          return cached.mul(this.scalar);
        },
        // Converts the unit back to a float if it is unitless.  Otherwise raises an exception
        toFloat: function () {
          if (this.isUnitless()) {
            return this.scalar;
          }
          throw new QtyError("Can't convert to Float unless unitless.  Use Unit#scalar");
        },
        /**
         * Returns the nearest multiple of quantity passed as
         * precision
         *
         * @param {(Qty|string|number)} precQuantity - Quantity, string formated
         *   quantity or number as expected precision
         *
         * @returns {Qty} Nearest multiple of precQuantity
         *
         * @example
         * Qty('5.5 ft').toPrec('2 ft'); // returns 6 ft
         * Qty('0.8 cu').toPrec('0.25 cu'); // returns 0.75 cu
         * Qty('6.3782 m').toPrec('cm'); // returns 6.38 m
         * Qty('1.146 MPa').toPrec('0.1 bar'); // returns 1.15 MPa
         *
         */
        toPrec: function (precQuantity) {
          if (isString(precQuantity)) {
            precQuantity = Qty(precQuantity);
          }
          if (isNumber(precQuantity)) {
            precQuantity = Qty(precQuantity + " " + this.units());
          }
          if (!this.isUnitless()) {
            precQuantity = precQuantity.to(this.units());
          } else if (!precQuantity.isUnitless()) {
            throwIncompatibleUnits(this.units(), precQuantity.units());
          }
          if (precQuantity.scalar === 0) {
            throw new QtyError("Divide by zero");
          }
          var precRoundedResult = mulSafe(Math.round(this.scalar / precQuantity.scalar), precQuantity.scalar);
          return Qty(precRoundedResult + this.units());
        }
      });

      /**
       * Configures and returns a fast function to convert
       * Number values from units to others.
       * Useful to efficiently convert large array of values
       * with same units into others with iterative methods.
       * Does not take care of rounding issues.
       *
       * @param {string} srcUnits Units of values to convert
       * @param {string} dstUnits Units to convert to
       *
       * @returns {Function} Converting function accepting Number value
       *   and returning converted value
       *
       * @throws "Incompatible units" if units are incompatible
       *
       * @example
       * // Converting large array of numbers with the same units
       * // into other units
       * var converter = Qty.swiftConverter("m/h", "ft/s");
       * var convertedSerie = largeSerie.map(converter);
       *
       */
      function swiftConverter(srcUnits, dstUnits) {
        var srcQty = Qty(srcUnits);
        var dstQty = Qty(dstUnits);
        if (srcQty.eq(dstQty)) {
          return identity;
        }
        var convert;
        if (!srcQty.isTemperature()) {
          convert = function (value) {
            return value * srcQty.baseScalar / dstQty.baseScalar;
          };
        } else {
          convert = function (value) {
            // TODO Not optimized
            return srcQty.mul(value).to(dstQty).scalar;
          };
        }
        return function converter(value) {
          var i, length, result;
          if (!Array.isArray(value)) {
            return convert(value);
          } else {
            length = value.length;
            result = [];
            for (i = 0; i < length; i++) {
              result.push(convert(value[i]));
            }
            return result;
          }
        };
      }
      var baseUnitCache = {};
      function toBaseUnits(numerator, denominator) {
        var num = [];
        var den = [];
        var q = 1;
        var unit;
        for (var i = 0; i < numerator.length; i++) {
          unit = numerator[i];
          if (PREFIX_VALUES[unit]) {
            // workaround to fix
            // 0.1 * 0.1 => 0.010000000000000002
            q = mulSafe(q, PREFIX_VALUES[unit]);
          } else {
            if (UNIT_VALUES[unit]) {
              q *= UNIT_VALUES[unit].scalar;
              if (UNIT_VALUES[unit].numerator) {
                num.push(UNIT_VALUES[unit].numerator);
              }
              if (UNIT_VALUES[unit].denominator) {
                den.push(UNIT_VALUES[unit].denominator);
              }
            }
          }
        }
        for (var j = 0; j < denominator.length; j++) {
          unit = denominator[j];
          if (PREFIX_VALUES[unit]) {
            q /= PREFIX_VALUES[unit];
          } else {
            if (UNIT_VALUES[unit]) {
              q /= UNIT_VALUES[unit].scalar;
              if (UNIT_VALUES[unit].numerator) {
                den.push(UNIT_VALUES[unit].numerator);
              }
              if (UNIT_VALUES[unit].denominator) {
                num.push(UNIT_VALUES[unit].denominator);
              }
            }
          }
        }

        // Flatten
        num = num.reduce(function (a, b) {
          return a.concat(b);
        }, []);
        den = den.reduce(function (a, b) {
          return a.concat(b);
        }, []);
        return Qty({
          "scalar": q,
          "numerator": num,
          "denominator": den
        });
      }
      Qty.parse = globalParse;
      Qty.getUnits = getUnits;
      Qty.getAliases = getAliases;
      Qty.mulSafe = mulSafe;
      Qty.divSafe = divSafe;
      Qty.getKinds = getKinds;
      Qty.swiftConverter = swiftConverter;
      Qty.Error = QtyError;
      assign(Qty.prototype, {
        // Returns new instance with units of this
        add: function (other) {
          if (isString(other)) {
            other = Qty(other);
          }
          if (!this.isCompatible(other)) {
            throwIncompatibleUnits(this.units(), other.units());
          }
          if (this.isTemperature() && other.isTemperature()) {
            throw new QtyError("Cannot add two temperatures");
          } else if (this.isTemperature()) {
            return addTempDegrees(this, other);
          } else if (other.isTemperature()) {
            return addTempDegrees(other, this);
          }
          return Qty({
            "scalar": this.scalar + other.to(this).scalar,
            "numerator": this.numerator,
            "denominator": this.denominator
          });
        },
        sub: function (other) {
          if (isString(other)) {
            other = Qty(other);
          }
          if (!this.isCompatible(other)) {
            throwIncompatibleUnits(this.units(), other.units());
          }
          if (this.isTemperature() && other.isTemperature()) {
            return subtractTemperatures(this, other);
          } else if (this.isTemperature()) {
            return subtractTempDegrees(this, other);
          } else if (other.isTemperature()) {
            throw new QtyError("Cannot subtract a temperature from a differential degree unit");
          }
          return Qty({
            "scalar": this.scalar - other.to(this).scalar,
            "numerator": this.numerator,
            "denominator": this.denominator
          });
        },
        mul: function (other) {
          if (isNumber(other)) {
            return Qty({
              "scalar": mulSafe(this.scalar, other),
              "numerator": this.numerator,
              "denominator": this.denominator
            });
          } else if (isString(other)) {
            other = Qty(other);
          }
          if ((this.isTemperature() || other.isTemperature()) && !(this.isUnitless() || other.isUnitless())) {
            throw new QtyError("Cannot multiply by temperatures");
          }

          // Quantities should be multiplied with same units if compatible, with base units else
          var op1 = this;
          var op2 = other;

          // so as not to confuse results, multiplication and division between temperature degrees will maintain original unit info in num/den
          // multiplication and division between deg[CFRK] can never factor each other out, only themselves: "degK*degC/degC^2" == "degK/degC"
          if (op1.isCompatible(op2) && op1.signature !== 400) {
            op2 = op2.to(op1);
          }
          var numdenscale = cleanTerms(op1.numerator, op1.denominator, op2.numerator, op2.denominator);
          return Qty({
            "scalar": mulSafe(op1.scalar, op2.scalar, numdenscale[2]),
            "numerator": numdenscale[0],
            "denominator": numdenscale[1]
          });
        },
        div: function (other) {
          if (isNumber(other)) {
            if (other === 0) {
              throw new QtyError("Divide by zero");
            }
            return Qty({
              "scalar": this.scalar / other,
              "numerator": this.numerator,
              "denominator": this.denominator
            });
          } else if (isString(other)) {
            other = Qty(other);
          }
          if (other.scalar === 0) {
            throw new QtyError("Divide by zero");
          }
          if (other.isTemperature()) {
            throw new QtyError("Cannot divide with temperatures");
          } else if (this.isTemperature() && !other.isUnitless()) {
            throw new QtyError("Cannot divide with temperatures");
          }

          // Quantities should be multiplied with same units if compatible, with base units else
          var op1 = this;
          var op2 = other;

          // so as not to confuse results, multiplication and division between temperature degrees will maintain original unit info in num/den
          // multiplication and division between deg[CFRK] can never factor each other out, only themselves: "degK*degC/degC^2" == "degK/degC"
          if (op1.isCompatible(op2) && op1.signature !== 400) {
            op2 = op2.to(op1);
          }
          var numdenscale = cleanTerms(op1.numerator, op1.denominator, op2.denominator, op2.numerator);
          return Qty({
            "scalar": mulSafe(op1.scalar, numdenscale[2]) / op2.scalar,
            "numerator": numdenscale[0],
            "denominator": numdenscale[1]
          });
        },
        // Returns a Qty that is the inverse of this Qty,
        inverse: function () {
          if (this.isTemperature()) {
            throw new QtyError("Cannot divide with temperatures");
          }
          if (this.scalar === 0) {
            throw new QtyError("Divide by zero");
          }
          return Qty({
            "scalar": 1 / this.scalar,
            "numerator": this.denominator,
            "denominator": this.numerator
          });
        }
      });
      function cleanTerms(num1, den1, num2, den2) {
        function notUnity(val) {
          return val !== UNITY;
        }
        num1 = num1.filter(notUnity);
        num2 = num2.filter(notUnity);
        den1 = den1.filter(notUnity);
        den2 = den2.filter(notUnity);
        var combined = {};
        function combineTerms(terms, direction) {
          var k;
          var prefix;
          var prefixValue;
          for (var i = 0; i < terms.length; i++) {
            if (PREFIX_VALUES[terms[i]]) {
              k = terms[i + 1];
              prefix = terms[i];
              prefixValue = PREFIX_VALUES[prefix];
              i++;
            } else {
              k = terms[i];
              prefix = null;
              prefixValue = 1;
            }
            if (k && k !== UNITY) {
              if (combined[k]) {
                combined[k][0] += direction;
                var combinedPrefixValue = combined[k][2] ? PREFIX_VALUES[combined[k][2]] : 1;
                combined[k][direction === 1 ? 3 : 4] *= divSafe(prefixValue, combinedPrefixValue);
              } else {
                combined[k] = [direction, k, prefix, 1, 1];
              }
            }
          }
        }
        combineTerms(num1, 1);
        combineTerms(den1, -1);
        combineTerms(num2, 1);
        combineTerms(den2, -1);
        var num = [];
        var den = [];
        var scale = 1;
        for (var prop in combined) {
          if (combined.hasOwnProperty(prop)) {
            var item = combined[prop];
            var n;
            if (item[0] > 0) {
              for (n = 0; n < item[0]; n++) {
                num.push(item[2] === null ? item[1] : [item[2], item[1]]);
              }
            } else if (item[0] < 0) {
              for (n = 0; n < -item[0]; n++) {
                den.push(item[2] === null ? item[1] : [item[2], item[1]]);
              }
            }
            scale *= divSafe(item[3], item[4]);
          }
        }
        if (num.length === 0) {
          num = UNITY_ARRAY;
        }
        if (den.length === 0) {
          den = UNITY_ARRAY;
        }

        // Flatten
        num = num.reduce(function (a, b) {
          return a.concat(b);
        }, []);
        den = den.reduce(function (a, b) {
          return a.concat(b);
        }, []);
        return [num, den, scale];
      }
      assign(Qty.prototype, {
        eq: function (other) {
          return this.compareTo(other) === 0;
        },
        lt: function (other) {
          return this.compareTo(other) === -1;
        },
        lte: function (other) {
          return this.eq(other) || this.lt(other);
        },
        gt: function (other) {
          return this.compareTo(other) === 1;
        },
        gte: function (other) {
          return this.eq(other) || this.gt(other);
        },
        // Compare two Qty objects. Throws an exception if they are not of compatible types.
        // Comparisons are done based on the value of the quantity in base SI units.
        //
        // NOTE: We cannot compare inverses as that breaks the general compareTo contract:
        //   if a.compareTo(b) < 0 then b.compareTo(a) > 0
        //   if a.compareTo(b) == 0 then b.compareTo(a) == 0
        //
        //   Since "10S" == ".1ohm" (10 > .1) and "10ohm" == ".1S" (10 > .1)
        //     Qty("10S").inverse().compareTo("10ohm") == -1
        //     Qty("10ohm").inverse().compareTo("10S") == -1
        //
        //   If including inverses in the sort is needed, I suggest writing: Qty.sort(qtyArray,units)
        compareTo: function (other) {
          if (isString(other)) {
            return this.compareTo(Qty(other));
          }
          if (!this.isCompatible(other)) {
            throwIncompatibleUnits(this.units(), other.units());
          }
          if (this.baseScalar < other.baseScalar) {
            return -1;
          } else if (this.baseScalar === other.baseScalar) {
            return 0;
          } else if (this.baseScalar > other.baseScalar) {
            return 1;
          }
        },
        // Return true if quantities and units match
        // Unit("100 cm").same(Unit("100 cm"))  # => true
        // Unit("100 cm").same(Unit("1 m"))     # => false
        same: function (other) {
          return this.scalar === other.scalar && this.units() === other.units();
        }
      });
      assign(Qty.prototype, {
        // returns true if no associated units
        // false, even if the units are "unitless" like 'radians, each, etc'
        isUnitless: function () {
          return [this.numerator, this.denominator].every(function (item) {
            return compareArray(item, UNITY_ARRAY);
          });
        },
        /*
        check to see if units are compatible, but not the scalar part
        this check is done by comparing signatures for performance reasons
        if passed a string, it will create a unit object with the string and then do the comparison
        this permits a syntax like:
        unit =~ "mm"
        if you want to do a regexp on the unit string do this ...
        unit.units =~ /regexp/
        */
        isCompatible: function (other) {
          if (isString(other)) {
            return this.isCompatible(Qty(other));
          }
          if (!isQty(other)) {
            return false;
          }
          if (other.signature !== undefined) {
            return this.signature === other.signature;
          } else {
            return false;
          }
        },
        /*
        check to see if units are inverse of each other, but not the scalar part
        this check is done by comparing signatures for performance reasons
        if passed a string, it will create a unit object with the string and then do the comparison
        this permits a syntax like:
        unit =~ "mm"
        if you want to do a regexp on the unit string do this ...
        unit.units =~ /regexp/
        */
        isInverse: function (other) {
          return this.inverse().isCompatible(other);
        },
        // Returns 'true' if the Unit is represented in base units
        isBase: function () {
          if (this._isBase !== undefined) {
            return this._isBase;
          }
          if (this.isDegrees() && this.numerator[0].match(/<(kelvin|temp-K)>/)) {
            this._isBase = true;
            return this._isBase;
          }
          this.numerator.concat(this.denominator).forEach(function (item) {
            if (item !== UNITY && BASE_UNITS.indexOf(item) === -1) {
              this._isBase = false;
            }
          }, this);
          if (this._isBase === false) {
            return this._isBase;
          }
          this._isBase = true;
          return this._isBase;
        }
      });
      function NestedMap() {}
      NestedMap.prototype.get = function (keys) {
        // Allows to pass key1, key2, ... instead of [key1, key2, ...]
        if (arguments.length > 1) {
          // Slower with Firefox but faster with Chrome than
          // Array.prototype.slice.call(arguments)
          // See http://jsperf.com/array-apply-versus-array-prototype-slice-call
          keys = Array.apply(null, arguments);
        }
        return keys.reduce(function (map, key, index) {
          if (map) {
            var childMap = map[key];
            if (index === keys.length - 1) {
              return childMap ? childMap.data : undefined;
            } else {
              return childMap;
            }
          }
        }, this);
      };
      NestedMap.prototype.set = function (keys, value) {
        if (arguments.length > 2) {
          keys = Array.prototype.slice.call(arguments, 0, -1);
          value = arguments[arguments.length - 1];
        }
        return keys.reduce(function (map, key, index) {
          var childMap = map[key];
          if (childMap === undefined) {
            childMap = map[key] = {};
          }
          if (index === keys.length - 1) {
            childMap.data = value;
            return value;
          } else {
            return childMap;
          }
        }, this);
      };

      /**
       * Default formatter
       *
       * @param {number} scalar - scalar value
       * @param {string} units - units as string
       *
       * @returns {string} formatted result
       */
      function defaultFormatter(scalar, units) {
        return (scalar + " " + units).trim();
      }

      /**
       *
       * Configurable Qty default formatter
       *
       * @type {function}
       *
       * @param {number} scalar
       * @param {string} units
       *
       * @returns {string} formatted result
       */
      Qty.formatter = defaultFormatter;
      assign(Qty.prototype, {
        // returns the 'unit' part of the Unit object without the scalar
        units: function () {
          if (this._units !== undefined) {
            return this._units;
          }
          var numIsUnity = compareArray(this.numerator, UNITY_ARRAY);
          var denIsUnity = compareArray(this.denominator, UNITY_ARRAY);
          if (numIsUnity && denIsUnity) {
            this._units = "";
            return this._units;
          }
          var numUnits = stringifyUnits(this.numerator);
          var denUnits = stringifyUnits(this.denominator);
          this._units = numUnits + (denIsUnity ? "" : "/" + denUnits);
          return this._units;
        },
        /**
         * Stringifies the quantity
         * Deprecation notice: only units parameter is supported.
         *
         * @param {(number|string|Qty)} targetUnitsOrMaxDecimalsOrPrec -
         *                              target units if string,
         *                              max number of decimals if number,
         *                              passed to #toPrec before converting if Qty
         *
         * @param {number=} maxDecimals - Maximum number of decimals of
         *                                formatted output
         *
         * @returns {string} reparseable quantity as string
         */
        toString: function (targetUnitsOrMaxDecimalsOrPrec, maxDecimals) {
          var targetUnits;
          if (isNumber(targetUnitsOrMaxDecimalsOrPrec)) {
            targetUnits = this.units();
            maxDecimals = targetUnitsOrMaxDecimalsOrPrec;
          } else if (isString(targetUnitsOrMaxDecimalsOrPrec)) {
            targetUnits = targetUnitsOrMaxDecimalsOrPrec;
          } else if (isQty(targetUnitsOrMaxDecimalsOrPrec)) {
            return this.toPrec(targetUnitsOrMaxDecimalsOrPrec).toString(maxDecimals);
          }
          var out = this.to(targetUnits);
          var outScalar = maxDecimals !== undefined ? round(out.scalar, maxDecimals) : out.scalar;
          out = (outScalar + " " + out.units()).trim();
          return out;
        },
        /**
         * Format the quantity according to optional passed target units
         * and formatter
         *
         * @param {string} [targetUnits=current units] -
         *                 optional units to convert to before formatting
         *
         * @param {function} [formatter=Qty.formatter] -
         *                   delegates formatting to formatter callback.
         *                   formatter is called back with two parameters (scalar, units)
         *                   and should return formatted result.
         *                   If unspecified, formatting is delegated to default formatter
         *                   set to Qty.formatter
         *
         * @example
         * var roundingAndLocalizingFormatter = function(scalar, units) {
         *   // localize or limit scalar to n max decimals for instance
         *   // return formatted result
         * };
         * var qty = Qty('1.1234 m');
         * qty.format(); // same units, default formatter => "1.234 m"
         * qty.format("cm"); // converted to "cm", default formatter => "123.45 cm"
         * qty.format(roundingAndLocalizingFormatter); // same units, custom formatter => "1,2 m"
         * qty.format("cm", roundingAndLocalizingFormatter); // convert to "cm", custom formatter => "123,4 cm"
         *
         * @returns {string} quantity as string
         */
        format: function (targetUnits, formatter) {
          if (arguments.length === 1) {
            if (typeof targetUnits === "function") {
              formatter = targetUnits;
              targetUnits = undefined;
            }
          }
          formatter = formatter || Qty.formatter;
          var targetQty = this.to(targetUnits);
          return formatter.call(this, targetQty.scalar, targetQty.units());
        }
      });
      var stringifiedUnitsCache = new NestedMap();
      /**
       * Returns a string representing a normalized unit array
       *
       * @param {string[]} units Normalized unit array
       * @returns {string} String representing passed normalized unit array and
       *   suitable for output
       *
       */
      function stringifyUnits(units) {
        var stringified = stringifiedUnitsCache.get(units);
        if (stringified) {
          return stringified;
        }
        var isUnity = compareArray(units, UNITY_ARRAY);
        if (isUnity) {
          stringified = "1";
        } else {
          stringified = simplify(getOutputNames(units)).join("*");
        }

        // Cache result
        stringifiedUnitsCache.set(units, stringified);
        return stringified;
      }
      function getOutputNames(units) {
        var unitNames = [],
          token,
          tokenNext;
        for (var i = 0; i < units.length; i++) {
          token = units[i];
          tokenNext = units[i + 1];
          if (PREFIX_VALUES[token]) {
            unitNames.push(OUTPUT_MAP[token] + OUTPUT_MAP[tokenNext]);
            i++;
          } else {
            unitNames.push(OUTPUT_MAP[token]);
          }
        }
        return unitNames;
      }
      function simplify(units) {
        // this turns ['s','m','s'] into ['s2','m']

        var unitCounts = units.reduce(function (acc, unit) {
          var unitCounter = acc[unit];
          if (!unitCounter) {
            acc.push(unitCounter = acc[unit] = [unit, 0]);
          }
          unitCounter[1]++;
          return acc;
        }, []);
        return unitCounts.map(function (unitCount) {
          return unitCount[0] + (unitCount[1] > 1 ? unitCount[1] : "");
        });
      }
      Qty.version = "1.8.0";
      return Qty;
    });
  })(quantities);
  var Qty = quantities.exports;

  /**
   * Parse a string that may contain min / max and units values
   * @param {string} string
   * @param {object} [options={}]
   * @param {number} [options.defaultValue]
   * @param {string} [options.defjaultUnits]
   * @param {string} [options.targetUnits]
   * @param {string} [options.optional=false] Is this value optional. Would through an error if empty and not optional
   */
  function parseNumbersUnits(string = '', options = {}) {
    const {
      defaultUnits = undefined,
      targetUnits = undefined,
      defaultValue = undefined,
      optional = false
    } = options;
    let normalized = String(string).replace(/ /g, '').replace(/,/g, '.');
    normalized = normalized.replace(/Â°/g, '°');
    if (normalized.match(/^\(.*\)$/)) {
      normalized = normalized.substring(1, normalized.length - 2);
    }

    // still parenthesis ??? We remove what is after
    normalized = normalized.replace(/\(.*/, '');
    if (optional && !normalized) return {};
    let splitter = /^([0-9.Ee-]*)([a-zA-Z^/ °0-9]*)$/;
    if (!normalized.match(splitter)) {
      throw Error(`Can not parseNumbersUnits of: ${string}`);
    }
    let numbers = normalized.replace(splitter, '$1');
    let units = normalized.replace(splitter, '$2').trim();
    let low;
    let high;
    if (numbers === '') {
      if (defaultValue) {
        numbers = String(defaultValue).replace(/ /g, '');
      } else {
        throw Error(`Can not parseNumbersUnits of: ${string}`);
      }
    }
    if (numbers.includes('--')) {
      // -5--4
      low = Number(numbers.split('--')[0]);
      high = Number(`-${numbers.split('--')[1]}`);
    } else if (numbers.startsWith('-')) {
      // -5 or -1-1 (minus 1 to plus 1)
      let subparts = numbers.split('-');
      switch (subparts.length) {
        case 2:
          low = Number(numbers);
          break;
        case 3:
          low = Number(`-${subparts[1]}`);
          high = Number(+subparts[2]);
          break;
        default:
          throw new Error(`Can not parse: ${string}`);
      }
    } else {
      let subparts = numbers.split('-');
      low = subparts[0] !== '' ? Number(subparts[0]) : undefined;
      high = subparts[1] !== undefined ? Number(subparts[1]) : undefined;
    }
    if (!units) units = defaultUnits;

    // Should we convert the units
    if (targetUnits) {
      let convert = Qty.swiftConverter(units.replace(/°/g, 'temp'), targetUnits.replace(/°/g, 'temp'));
      if (low !== undefined) {
        low = convert(low);
      }
      if (high !== undefined) {
        high = convert(high);
      }
      units = targetUnits;
    }
    return {
      low,
      high,
      units
    };
  }

  /**
   *
   * @param {String} string
   * @param {object} [options={}]
   * @param {object} [options.temperature={}]
   * @param {string} [options.temperature.defaultUnits]
   * @param {string} [options.temperature.targetUnits]
   * @param {object} [options.pressure={}]
   * @param {number} [options.pressure.defaultValue]
   * @param {string} [options.pressure.defaultUnits]
   * @param {string} [options.pressure.targetUnits]
   * @param {string} [options.pressure.optional]
   */
  function parseBoilingPoint(string, options = {}) {
    let parts = String(string).split(/[@/]|, | at /);
    return {
      temperature: parseNumbersUnits(parts[0], options.temperature),
      pressure: parseNumbersUnits(parts[1], options.pressure)
    };
  }

  /**
   *
   * @param {String} string
   * @param {object} [options={}]
   * @param {object} [options.value={}]
   * @param {string} [options.value.defaultUnits]
   * @param {string} [options.value.targetUnits]
   * @param {object} [options.temperature={}]
   * @param {number} [options.temperature.defaultValue]
   * @param {string} [options.temperature.defaultUnits]
   * @param {string} [options.temperature.targetUnits]
   */
  function parseDensity(string, options = {}) {
    string = String(string);
    string = string.replace(/\(.*/, '');
    string = string.replace('g/cu cm', 'g/cm^3');
    let parts = String(string).split(/[@]|, | at /);
    let value = parts[0];
    let temperature = parts[1];
    if (temperature) {
      temperature = temperature.replace(/ *t= */, '');
    }
    return {
      value: parseNumbersUnits(value, options.value),
      temperature: parseNumbersUnits(temperature, options.temperature)
    };
  }

  /**
   *
   * @param {String} string
   * @param {object} [options={}]
   * @param {object} [options.value={}]
   * @param {string} [options.value.defaultUnits]
   * @param {string} [options.value.targetUnits]
   * @param {object} [options.temperature={}]
   * @param {number} [options.temperature.defaultValue]
   * @param {string} [options.temperature.defaultUnits]
   * @param {string} [options.temperature.targetUnits]
   */
  function parseRefractiveIndex(string, options = {}) {
    string = String(string).replace(/^[^0-9.]*/, '');
    let parts = string.split(/at|[@/]|, /);
    let value = parts[0];
    let temperature = parts[1];
    if (temperature) {
      temperature = temperature.replace(/ *t= */, '');
    }
    return {
      value: parseNumbersUnits(value, options.value),
      temperature: parseNumbersUnits(temperature, options.temperature)
    };
  }

  /**
   *
   * @param {String} string
   * @param {object} [options={}]
   * @param {object} [options.temperature={}]
   * @param {string} [options.temperature.defaultUnits]
   * @param {string} [options.temperature.targetUnits]
   * @param {string} [options.pressure.optional]
   * @param {object} [options.pressure={}]
   * @param {string} [options.pressure.defaultUnits]
   * @param {string} [options.pressure.targetUnits]

   */
  function parseVaporPressure(string, options = {}) {
    let parts = String(string).split(/[@/]|, | at /);
    return {
      pressure: parseNumbersUnits(parts[0], options.pressure),
      temperature: parseNumbersUnits(parts[1], options.temperature)
    };
  }

  /**
   * Returns all references cited in the PubChem entry
   *
   * @param data Data of a compound data request to the PubChem API
   * @returns References
   */
  function getReferences(data) {
    const references = jp.query(data, '$.Reference[*]').reduce((ref, entry) => {
      ref[entry.ReferenceNumber] = {
        url: entry.URL,
        sourceName: entry.SourceName,
        name: entry.Name,
        description: entry.Description
      };
      return ref;
    }, {});
    return references;
  }

  function extractExperimentalData(data, sectionName, options = {}) {
    const {
      parser
    } = options;
    const references = getReferences(data);
    const experimentalSection = getExperimentalDataSection(data);
    const results = [];
    if (!experimentalSection || experimentalSection.length === 0) {
      return results;
    }
    jp.query(experimentalSection[0], `$.Section[?(@.TOCHeading==="${sectionName}")].Information[*]`).forEach(entry => {
      jp.query(entry, '$.Value.StringWithMarkup[*].String').forEach(original => {
        const result = {
          reference: references[entry.ReferenceNumber],
          data: {
            original
          }
        };
        if (parser) {
          try {
            result.data.parsed = parser(original, options);
          } catch (e) {
            result.data.parsed = {
              error: e.toString()
            };
          }
        }
        results.push(result);
      });
    });
    return results;
  }
  function getExperimentalDataSection(data) {
    const experimentalData = jp.query(data, '$.Section[?(@.TOCHeading==="Chemical and Physical Properties")]' + '.Section[?(@.TOCHeading==="Experimental Properties")]');
    return experimentalData;
  }

  /**
   * Returns the boiling point of a compound
   *
   * @param data Data of a compound data request to the PubChem API
   * @param options Options for the compound
   * @returns ExperimentalData
   */
  function getBoilingPoint(data, options = {}) {
    const boilingPoint = extractExperimentalData(data, 'Boiling Point', {
      parser: value => parseBoilingPoint(value, merge({
        pressure: {
          defaultValue: 760,
          defaultUnits: 'torr'
        }
      }, options))
    });
    return boilingPoint;
  }

  /**
   * Returns the refractive index of a compound
   * @param data Data of a compound data request to the PubChem API
   * @returns ExperimentalData
   */
  function getDensity(data = {}, options = {}) {
    const density = extractExperimentalData(data, 'Density', {
      parser: value => {
        return parseDensity(value, options);
      }
    });
    return density;
  }

  /**
   *
   *
   * @export
   * @param {Object} data response of a compound data request to the PubChem API
   * @param {object} [options={}]
   * @param {object} [options.targetUnits]
   * @returns {ExperimentalData}
   */
  function getFlashPoint(data, options = {}) {
    const flashPoint = extractExperimentalData(data, 'Flash Point', {
      parser: value => parseNumbersUnits(value, options.temperature)
    });
    return flashPoint;
  }

  /**
   * Returns the melting point of a compound
   * @param data Data of a compound data request to the PubChem API
   * @param options Options for the compound
   * @returns ExperimentalData
   */
  function getMeltingPoint(data, options = {}) {
    const meltingPoint = extractExperimentalData(data, 'Melting Point', {
      parser: value => parseNumbersUnits(value, options.temperature)
    });
    return meltingPoint;
  }

  /**
   * Returns the refractive index of a compound
   * @param data Data of a compound data request to the PubChem API
   * @returns ExperimentalData
   */
  function getRefractiveIndex(data = {}) {
    const refractiveIndex = extractExperimentalData(data, 'Refractive Index', {
      parser: value => parseRefractiveIndex(value)
    });
    return refractiveIndex;
  }

  /**
   * Returns the solubility of a compound
   * @param data Data of a compound data request to the PubChem API
   * @returns ExperimentalData
   */
  function getSolubility(data) {
    const solubility = extractExperimentalData(data, 'Solubility');
    return solubility;
  }

  /**
   * Returns the vapor pressure of a compound
   * @param data Data of a compound data request to the PubChem API
   * @param options Options for the compound
   */
  function getVaporPressure(data, options = {}) {
    const vaporPressure = extractExperimentalData(data, 'Vapor Pressure', {
      parser: value => parseVaporPressure(value, merge({
        temperature: {
          optional: true
        }
      }, options))
    });
    return vaporPressure;
  }

  /**
   * Returns the experimental data of a compound
   * @param data Data of a compound data request to the PubChem API
   * @param options Options for the compound
   * @returns ExperimentalData
   */
  function getExperimentalData(data, options) {
    return {
      boilingPoint: getBoilingPoint(data, options),
      density: getDensity(data, options),
      flashPoint: getFlashPoint(data, options),
      meltingPoint: getMeltingPoint(data, options),
      solubility: getSolubility(data),
      vaporPressure: getVaporPressure(data, options),
      refractiveIndex: getRefractiveIndex(data)
    };
  }

  function getFormula(data) {
    return {
      value: jp.query(data, '$.Section[?(@.TOCHeading==="Names and Identifiers")]' + '.Section[?(@.TOCHeading==="Molecular Formula")]' + '.Information[0]')[0].Value.StringWithMarkup[0].String,
      label: 'Molecular Formula',
      description: jp.query(data, '$.Section[?(@.TOCHeading==="Names and Identifiers")]' + '.Section[?(@.TOCHeading==="Molecular Formula")]')[0].Description
    };
  }

  // Names and Identifiers
  function getInChI(data) {
    return {
      value: jp.query(data, '$.Section[?(@.TOCHeading==="Names and Identifiers")]' + '.Section[?(@.TOCHeading==="Computed Descriptors")]' + '.Section[?(@.TOCHeading==="InChI")]' + '.Information[0]')[0].Value.StringWithMarkup[0].String,
      label: 'InChI',
      description: jp.query(data, '$.Section[?(@.TOCHeading==="Names and Identifiers")]' + '.Section[?(@.TOCHeading==="Computed Descriptors")]' + '.Section[?(@.TOCHeading==="InChI")]')[0].Description
    };
  }

  // Names and Identifiers
  function getInChIKey(data) {
    return {
      value: jp.query(data, '$.Section[?(@.TOCHeading==="Names and Identifiers")]' + '.Section[?(@.TOCHeading==="Computed Descriptors")]' + '.Section[?(@.TOCHeading==="InChIKey")]' + '.Information[0]')[0].Value.StringWithMarkup[0].String,
      label: 'InChIKey',
      description: jp.query(data, '$.Section[?(@.TOCHeading==="Names and Identifiers")]' + '.Section[?(@.TOCHeading==="Computed Descriptors")]' + '.Section[?(@.TOCHeading==="InChIKey")]')[0].Description
    };
  }

  // Names and Identifiers
  function getSMILES(data) {
    return {
      value: jp.query(data, '$.Section[?(@.TOCHeading==="Names and Identifiers")]' + '.Section[?(@.TOCHeading==="Computed Descriptors")]' + '.Section[?(@.TOCHeading==="Canonical SMILES")]' + '.Information[0]')[0].Value.StringWithMarkup[0].String,
      label: 'Canonical SMILES',
      description: jp.query(data, '$.Section[?(@.TOCHeading==="Names and Identifiers")]' + '.Section[?(@.TOCHeading==="Computed Descriptors")]' + '.Section[?(@.TOCHeading==="Canonical SMILES")]')[0].Description
    };
  }

  function getIdentifiers(data) {
    return {
      formula: getFormula(data),
      inchi: getInChI(data),
      inchiKey: getInChIKey(data),
      smiles: getSMILES(data)
    };
  }

  const ghsPictogramText = {
    GHS01: 'Explosive',
    GHS02: 'Flammable',
    GHS03: 'Oxidizing',
    GHS04: 'Compressed Gas',
    GHS05: 'Corrosive',
    GHS06: 'Toxic',
    GHS07: 'Harmful Irritant',
    GHS08: 'Health Hazard',
    GHS09: 'Environmental Hazard'
  };

  const hazardStatements = {
    H200: 'Unstable explosive',
    H201: 'Explosive; mass explosion hazard',
    H202: 'Explosive; severe projection hazard',
    H203: 'Explosive; fire, blast or projection hazard',
    H204: 'Fire or projection hazard',
    H205: 'May mass explode in fire',
    H220: 'Extremely flammable gas',
    H221: 'Flammable gas',
    H222: 'Extremely flammable aerosol',
    H223: 'Flammable aerosol',
    H224: 'Extremely flammable liquid and vapour',
    H225: 'Highly flammable liquid and vapour',
    H226: 'Flammable liquid and vapour',
    H227: 'Combustible liquid',
    H228: 'Flammable solid',
    H229: 'Pressurized container: may burst if heated',
    H230: 'May react explosively even in the absence of air',
    H231: 'May react explosively even in the absence of air at elevated pressure and/or temperature',
    H240: 'Heating may cause an explosion',
    H241: 'Heating may cause a fire or explosion',
    H242: 'Heating may cause a fire',
    H250: 'Catches fire spontaneously if exposed to air',
    H251: 'Self-heating; may catch fire',
    H252: 'Self-heating in large quantities; may catch fire',
    H260: 'In contact with water releases flammable gases which may ignite spontaneously',
    H261: 'In contact with water releases flammable gas',
    H270: 'May cause or intensify fire; oxidizer',
    H271: 'May cause fire or explosion; strong oxidizer',
    H272: 'May intensify fire; oxidizer',
    H280: 'Contains gas under pressure; may explode if heated',
    H281: 'Contains refrigerated gas; may cause cryogenic burns or injury',
    H290: 'May be corrosive to metals',
    H300: 'Fatal if swallowed',
    H301: 'Toxic if swallowed',
    H302: 'Harmful if swallowed',
    H303: 'May be harmful if swallowed',
    H304: 'May be fatal if swallowed and enters airways',
    H305: 'May be harmful if swallowed and enters airways',
    H310: 'Fatal in contact with skin',
    H311: 'Toxic in contact with skin',
    H312: 'Harmful in contact with skin',
    H313: 'May be harmful in contact with skin',
    H314: 'Causes severe skin burns and eye damage',
    H315: 'Causes skin irritation',
    H316: 'Causes mild skin irritation',
    H317: 'May cause an allergic skin reaction',
    H318: 'Causes serious eye damage',
    H319: 'Causes serious eye irritation',
    H320: 'Causes eye irritation',
    H330: 'Fatal if inhaled',
    H331: 'Toxic if inhaled',
    H332: 'Harmful if inhaled',
    H333: 'May be harmful if inhaled',
    H334: 'May cause allergy or asthma symptoms or breathing difficulties if inhaled',
    H335: 'May cause respiratory irritation',
    H336: 'May cause drowsiness or dizziness',
    H340: 'May cause genetic defects',
    H341: 'Suspected of causing genetic defects',
    H350: 'May cause cancer',
    H351: 'Suspected of causing cancer',
    H360: 'May damage fertility or the unborn child',
    H361: 'Suspected of damaging fertility or the unborn child',
    H361d: 'Suspected of damaging the unborn child',
    H362: 'May cause harm to breast-fed children',
    H370: 'Causes damage to organs',
    H371: 'May cause damage to organs',
    H372: 'Causes damage to organs through prolonged or repeated exposure',
    H373: 'May cause damage to organs through prolonged or repeated exposure',
    H400: 'Very toxic to aquatic life',
    H401: 'Toxic to aquatic life',
    H402: 'Harmful to aquatic life',
    H410: 'Very toxic to aquatic life with long lasting effects',
    H411: 'Toxic to aquatic life with long lasting effects',
    H412: 'Harmful to aquatic life with long lasting effects',
    H413: 'May cause long lasting harmful effects to aquatic life',
    H420: 'Harms public health and the environment by destroying ozone in the upper atmosphere',
    EUH001: 'Explosive when dry',
    EUH006: 'Explosive with or without contact with air',
    EUH014: 'Reacts violently with water',
    EUH018: 'In use may form flammable/explosive vapour-air mixture',
    EUH019: 'May form explosive peroxides',
    EUH044: 'Risk of explosion if heated under confinement',
    EUH029: 'Contact with water liberates toxic gas',
    EUH031: 'Contact with acids liberates toxic gas',
    EUH032: 'Contact with acids liberates very toxic gas',
    EUH066: 'Repeated exposure may cause skin dryness or cracking',
    EUH070: 'Toxic by eye contact',
    EUH071: 'Corrosive to the respiratory tract',
    EUH059: 'Hazardous to the ozone layer, superseded by GHS Class 5.1 in the second adaptation to technical progress of CLP.',
    EUH201: 'Contains lead. Should not be used on surfaces liable to be chewed or sucked by children.',
    EUH201A: 'Warning! Contains lead.',
    EUH202: 'Cyanoacrylate. Danger. Bonds skin and eyes in seconds. Keep out of the reach of children.',
    EUH203: 'Contains chromium(VI). May produce an allergic reaction.',
    EUH204: 'Contains isocyanates. May produce an allergic reaction.',
    EUH205: 'Contains epoxy constituents. May produce an allergic reaction.',
    EUH206: 'Warning! Do not use together with other products. May release dangerous gases (chlorine).',
    EUH207: 'Warning! Contains cadmium. Dangerous fumes are formed during use. See information supplied by the manufacturer. Comply with the safety instructions.',
    EUH208: 'Contains <name of sensitising substance>. May produce an allergic reaction.',
    EUH209: 'Can become highly flammable in use.',
    EUH209A: 'Can become flammable in use.',
    EUH210: 'Safety data sheet available on request.',
    EUH401: 'To avoid risks to human health and the environment, comply with the instructions for use.'
  };

  const precautionaryStatements = {
    P101: 'If medical advice is needed, have product container or label at hand.',
    P102: 'Keep out of reach of children.',
    P103: 'Read label before use.',
    P201: 'Obtain special instructions before use.',
    P202: 'Do not handle until all safety precautions have been read and understood.',
    P210: 'Keep away from heat, hot surfaces, sparks, open flames and other ignition sources. No smoking. [As modified by IV ATP]',
    P211: 'Do not spray on an open flame or other ignition source.',
    P220: 'Keep/Store away from clothing/…/combustible materials. [As modified by IV ATP]',
    P221: 'Take any precaution to avoid mixing with combustibles.',
    P222: 'Do not allow contact with air.',
    P223: 'Do not allow contact with water. [As modified by IV ATP]',
    P230: 'Keep wetted with …',
    P231: 'Handle under inert gas.',
    P232: 'Protect from moisture.',
    P233: 'Keep container tightly closed.',
    P234: 'Keep only in original container.',
    P235: 'Keep cool..',
    P240: 'Ground/bond container and receiving equipment.',
    P241: 'Use explosion-proof electrical/ventilating/light/…/equipment.',
    P242: 'Use only non-sparking tools.',
    P243: 'Take precautionary measures against static discharge.',
    P244: 'Keep valves and fittings free from oil and grease. [As modified by IV ATP]',
    P250: 'Do not subject to grinding/shock/…/friction.',
    P251: 'Do not pierce or burn, even after use. [As modified by IV ATP]',
    P260: 'Do not breathe dust/fume/gas/mist/vapours/spray.',
    P261: 'Avoid breathing dust/fume/ gas/mist/vapours/spray. [As modified by IV ATP]',
    P262: 'Do not get in eyes, on skin, or on clothing.',
    P263: 'Avoid contact during pregnancy/while nursing.',
    P264: 'Wash … thoroughly after handling.',
    P270: 'Do not eat, drink or smoke when using this product.',
    P271: 'Use only outdoors or in a well-ventilated area.',
    P272: 'Contaminated work clothing should not be allowed out of the workplace.',
    P273: 'Avoid release to the environment.',
    P280: 'Wear protective gloves/protective clothing/eye protection/face protection. [As modified by IV ATP]',
    P281: '[Deleted by IV ATP]',
    P282: 'Wear cold insulating gloves/face shield/eye protection.',
    P283: 'Wear fire/flame resistant/retardant clothing.',
    P284: '[In case of inadequate ventilation] wear respiratory protection. [As modified by IV ATP]',
    P285: '[Deleted by IV ATP]',
    'P231+P232': 'Handle under inert gas. Protect from moisture',
    'P264+P265': 'Wash hands [and …] thoroughly after handling. Do not touch eyes',
    'P235+P410': 'Keep cool. Protect from sunlight',
    P301: 'IF SWALLOWED:',
    P302: 'IF ON SKIN:',
    P303: 'IF ON SKIN (or hair):',
    P304: 'IF INHALED:',
    P305: 'IF IN EYES:',
    P306: 'IF ON CLOTHING:',
    P307: '[Deleted by IV ATP]',
    P308: 'IF exposed or concerned:',
    P309: '[Deleted by IV ATP]',
    P310: 'Immediately call a POISON CENTER/doctor/… [As modified by IV ATP]',
    P311: 'Call a POISON CENTER/ doctor/… [As modified by IV ATP]',
    P312: 'Call a POISON CENTER/ doctor/…/if you feel unwell. [As modified by IV ATP]',
    P313: 'Get medical advice/attention.',
    P314: 'Get Medical advice/attention if you feel unwell.',
    P315: 'Get immediate medical advice/attention.',
    P320: 'Specific treatment is urgent (see … on this label).',
    P321: 'Specific treatment (see … on this label).',
    P322: '[Deleted by IV ATP]',
    P330: 'Rinse mouth.',
    P331: 'Do NOT induce vomiting.',
    P332: 'If skin irritation occurs:',
    P333: 'If skin irritation or a rash occurs:',
    P334: 'Immerse in cool water/wrap in wet bandages.',
    P335: 'Brush off loose particles from skin.',
    P336: 'Thaw frosted parts with lukewarm water. Do not rub affected areas.',
    P337: 'If eye irritation persists:',
    P338: 'Remove contact lenses if present and easy to do. continue rinsing.',
    P340: 'Remove person to fresh air and keep comfortable for breathing.',
    P341: '[Deleted by IV ATP]',
    P342: 'If experiencing respiratory symptoms:',
    P350: '[Deleted by IV ATP]',
    P351: 'Rinse cautiously with water for several minutes.',
    P352: 'Wash with plenty of water/… [As modified by IV ATP]',
    P353: 'Rinse skin with water/shower.',
    P360: 'Rinse immediately contaminated clothing and skin with plenty of water before removing clothes.',
    P361: 'Take off immediately all contaminated clothing. [As modified by IV ATP]',
    P362: 'Take off contaminated clothing. [As modified by IV ATP]',
    P363: 'Wash contaminated clothing before reuse. [As modified by IV ATP]',
    P364: 'And wash it before reuse. [Added by IV ATP]',
    P370: 'In case of fire:',
    P371: 'In case of major fire and large quantities:',
    P372: 'Explosion risk in case of fire.',
    P373: 'DO NOT fight fire when fire reaches explosives.',
    P374: 'Fight fire with normal precautions from a reasonable distance.',
    P375: 'Fight fire remotely due to the risk of explosion.',
    P376: 'Stop leak if safe to do so.',
    P377: 'Leaking gas fire – do not extinguish unless leak can be stopped safely.',
    P378: 'Use … to extinguish.',
    P380: 'Evacuate area.',
    P381: 'Eliminate all ignition sources if safe to do so.',
    P391: 'Collect spillage.',
    'P301+P310': 'IF SWALLOWED: Immediately call a POISON CENTER/doctor/… [As modified by IV ATP]',
    'P301+P312': 'IF SWALLOWED: Call a POISON CENTER/doctor/…/if you feel unwell. [As modified by IV ATP]',
    'P301+P316': 'IF SWALLOWED: Get emergency medical help immediately.',
    'P301+P330+P331': 'IF SWALLOWED: Rinse mouth. Do NOT induce vomiting.',
    'P302+P334': 'IF ON SKIN: Immerse in cool water/wrap in wet bandages.',
    'P302+P350': '[Deleted by IV ATP]',
    'P302+P352': 'IF ON SKIN: Wash with plenty of water/… [As modified by IV ATP]',
    'P303+P361+P353': 'IF ON SKIN (or hair): Take off immediately all contaminated clothing. Rinse skin with water/ shower. [As modified by IV ATP]',
    'P304+P312': 'IF INHALED: Call a POISON CENTER or doctor/physician if you feel unwell.',
    'P304+P340': 'IF INHALED: Remove person to fresh air and keep comfortable for breathing. [As modified by IV ATP]',
    'P304+P341': '[Deleted by IV ATP]',
    'P305+P351+P338': 'IF IN EYES: Rinse cautiously with water for several minutes. Remove contact lenses if present and easy to do – continue rinsing.',
    'P306+360': 'IF ON CLOTHING: Rinse immediately contaminated clothing and skin with plenty of water before removing clothes.',
    'P307+P311': 'IF exposed: Call a POISON CENTER or doctor/physician.',
    'P308+P311': 'IF exposed or concerned: Call a POISON CENTER/ doctor/… [Added by IV ATP]',
    'P309+P311': '[Deleted by IV ATP]',
    'P332+P313': 'If skin irritation occurs: Get medical advice/attention.',
    'P333+P313': 'If skin irritation or a rash occurs: Get medical advice/attention.',
    'P335+P334': 'Brush off loose particles from skin. Immerse in cool water/wrap in wet bandages.',
    'P337+P313': 'If eye irritation persists get medical advice/attention.',
    'P342+P311': 'If experiencing respiratory symptoms: Call a POISON CENTER/doctor/… [As modified by IV ATP]',
    'P361+P364': 'Take off immediately all contaminated clothing and wash it before reuse. [Added by IV ATP]',
    'P362+P364': 'Take off contaminated clothing and wash it before reuse. [Added by IV ATP]',
    'P370+P376': 'In case of fire: Stop leak if safe to do so.',
    'P370+P378': 'In case of fire: Use … to extinguish. [As modified by IV ATP]',
    'P370+P380': 'In case of fire: Evacuate area.',
    'P370+P380+P375': 'In case of fire: Evacuate area. Fight fire remotely due to the risk of explosion.',
    'P371+P380+P375': 'In case of major fire and large quantities: Evacuate area. Fight fire remotely due to the risk of explosion.',
    P401: 'Store …',
    P402: 'Store in a dry place.',
    P403: 'Store in a well ventilated place.',
    P404: 'Store in a closed container.',
    P405: 'Store locked up.',
    P406: 'Store in a corrosive resistant/… container with a resistant inner liner.',
    P407: 'Maintain air gap between stacks/pallets.',
    P410: 'Protect from sunlight.',
    P411: 'Store at temperatures not exceeding … °C/… °F.',
    P412: 'Do not expose to temperatures exceeding 50 °C/122 °F.',
    P413: 'Store bulk masses greater than … kg/… lbs at temperatures not exceeding … °C/… °F.',
    P420: 'Store away from other materials.',
    P422: 'Store contents under …',
    'P402+P404': 'Store in a dry place. Store in a closed container.',
    'P403+P233': 'Store in a well ventilated place. Keep container tightly closed.',
    'P403+P235': 'Store in a well ventilated place. Keep cool.',
    'P410+P403': 'Protect from sunlight. Store in a well-ventilated place.',
    'P410+P412': 'Protect from sunlight. Do not expose to temperatures exceeding 50 °C/122 °F.',
    'P411+P235': 'Store at temperatures not exceeding … °C/… °F. Keep cool.',
    P501: 'Dispose of contents/container to … [… in accordance with local/regional/national/international regulation (to be specified)].'
  };

  /**
   * Extracts GHS information (H/P-Statements and pictograms)
   * @param data The data to extract from
   * @return The extracted data
   */
  function getGHS(data) {
    const references = getReferences(data);
    let pictograms;
    try {
      pictograms = jp.query(data, '$.Section[?(@.TOCHeading==="Safety and Hazards")]' + '.Section[?(@.TOCHeading==="Hazards Identification")]' + '.Section[?(@.TOCHeading==="GHS Classification")]' + '.Information[?(@.Name==="Pictogram(s)")]').map(entry => ({
        reference: references[entry.ReferenceNumber],
        data: jp.query(entry, '$.Value.StringWithMarkup[*].Markup[*]').map(entry => {
          let code = entry.URL.match(/GHS\d+/)[0];
          return {
            code,
            description: ghsPictogramText[code]
          };
        })
      }));
    } catch (error) {
      pictograms = [];
    }
    let hStatements;
    try {
      hStatements = jp.query(data, '$.Section[?(@.TOCHeading==="Safety and Hazards")]' + '.Section[?(@.TOCHeading==="Hazards Identification")]' + '.Section[?(@.TOCHeading==="GHS Classification")]' + '.Information[?(@.Name==="GHS Hazard Statements")]').map(entry => ({
        reference: references[entry.ReferenceNumber],
        data: jp.query(entry, '$.Value.StringWithMarkup[*]').map(entry => entry.String.match(/H\d+/)[0]).map(hCode => ({
          code: hCode,
          description: hazardStatements[hCode]
        }))
      }));
    } catch (error) {
      hStatements = [];
    }
    //ToDo(kjappelbaum): investigate in more detail why they do not have the full P statements
    //For P statements the full sentence (with conditions) is more important than just the number
    let pStatements;
    try {
      pStatements = jp.query(data, '$.Section[?(@.TOCHeading==="Safety and Hazards")]' + '.Section[?(@.TOCHeading==="Hazards Identification")]' + '.Section[?(@.TOCHeading==="GHS Classification")]' + '.Information[?(@.Name==="Precautionary Statement Codes")]').map(entry => ({
        reference: references[entry.ReferenceNumber],
        data: jp.query(entry, '$.Value.StringWithMarkup[*]').map(entry => entry.String.match(/(?<oneP>(?<!\+)P\d\d\d(?!\+))|(?<twoP>P\d\d\d\+P\d\d\d(?!\+))|(?<threeP>P\d\d\d\+P\d\d\d\+P\d\d\d(?!\+))/gm))[0].map(pCode => ({
          code: pCode,
          description: precautionaryStatements[pCode]
        }))
      }));
    } catch (error) {
      pStatements = [];
    }
    return {
      pictograms,
      hStatements,
      pStatements
    };
  }
  /**
   * We combine all the results and keep
   */
  function getGHSSummary(data) {
    let result = getGHS(data);
    return {
      pictograms: getUnique(result.pictograms),
      hStatements: getUnique(result.hStatements),
      pStatements: getUnique(result.pStatements)
    };
  }
  function getUnique(entries) {
    let uniqueMap = {};
    entries.map(entry => entry.data.forEach(line => {
      uniqueMap[line.code] = line;
    }));
    return Object.keys(uniqueMap).map(code => uniqueMap[code]).sort((a, b) => a.code < b.code ? -1 : 1);
  }

  class CompoundData {
    constructor(data) {
      this.data = data;
    }
    getReferences() {
      return getReferences(this.data);
    }
    getExperimentalData(options) {
      return getExperimentalData(this.data, options);
    }
    getIdentifiers() {
      return getIdentifiers(this.data);
    }
    get computed() {
      return getComputedData(this.data);
    }
    /**
     * Property containing a summary of GHS information
     */
    get ghs() {
      return getGHSSummary(this.data);
    }
    /**
     * Canonical SMILES
     */
    getSMILES() {
      return getSMILES(this.data);
    }
    /**
     * Return molecular formula in Hill notation
     */
    getFormula() {
      return getFormula(this.data);
    }
    /**
     * Return the International Chemical Identifier (InChI) computed from chemical structure using the International Union of Pure and Applied Chemistry (IUPAC) standard
     */
    getInChI() {
      return getInChI(this.data);
    }
    /**
     * International Chemical Identifier hash (InChIKey) computed from chemical structure using the International Union of Pure and Applied Chemistry (IUPAC) standard.
     */
    getInChIKey() {
      return getInChIKey(this.data);
    }
    /**
     * Detailed information about GHS information
     */
    getGHS() {
      return getGHS(this.data);
    }
    getMeltingPoint(options) {
      return getMeltingPoint(this.data, options);
    }
    getBoilingPoint(options) {
      return getBoilingPoint(this.data, options);
    }
    getDensity(options) {
      return getDensity(this.data, options);
    }
    getVaporPressure(options) {
      return getVaporPressure(this.data, options);
    }
    getSolubility() {
      return getSolubility(this.data);
    }
    getFlashPoint(options) {
      return getFlashPoint(this.data, options);
    }
    toJSON() {
      const methods = Object.entries(Object.getOwnPropertyDescriptors(CompoundData.prototype)).filter(([, descriptor]) => typeof descriptor.get === 'function').map(([key]) => key);
      let result = {};
      for (let method of methods) {
        result[method] = this[method];
      }
      return result;
    }
  }

  async function compoundDataFromCID(cid, options = {}) {
    const {
      cache
    } = options;
    let compoundData;
    if (cache?.(cid)) {
      compoundData = cache(cid);
    } else {
      const dataResponse = await fetch(`https://pubchem.ncbi.nlm.nih.gov/rest/pug_view/data/compound/${cid}/JSON`);
      compoundData = (await dataResponse.json()).Record;
      if (cache) {
        cache(cid, compoundData);
      }
    }
    return new CompoundData(compoundData);
  }

  function checkCompoundsResult(compounds) {
    if (!Array.isArray(compounds) || compounds.length === 0) {
      throw new Error('No compound found');
    }
    if (compounds.length !== 1) {
      throw new Error('More than one compound found');
    }
    if (!('id' in compounds[0].id)) {
      throw new Error('No compound found');
    }
  }

  async function compoundFromInchiKey(inchiKey, options = {}) {
    const {
      cache
    } = options;
    let compounds;
    if (cache?.(inchiKey)) {
      compounds = cache(inchiKey);
    } else {
      const encodedInchiKey = encodeURIComponent(inchiKey);
      const moleculeResponse = await fetch(`https://pubchem.ncbi.nlm.nih.gov/rest/pug/compound/inchikey/${encodedInchiKey}/json`);
      compounds = (await moleculeResponse.json()).PC_Compounds;
      if (cache) {
        cache(inchiKey, compounds);
      }
    }
    checkCompoundsResult(compounds);
    return new Compound(compounds[0], {
      cache
    });
  }

  async function compoundFromName(smiles, options = {}) {
    const {
      cache
    } = options;
    let compounds;
    if (cache?.(smiles)) {
      compounds = cache(smiles);
    } else {
      const encodedName = encodeURIComponent(smiles);
      const moleculeResponse = await fetch(`https://pubchem.ncbi.nlm.nih.gov/rest/pug/compound/name/${encodedName}/json`);
      compounds = (await moleculeResponse.json()).PC_Compounds;
      if (cache) {
        cache(smiles, compounds);
      }
    }
    checkCompoundsResult(compounds);
    return new Compound(compounds[0], {
      cache
    });
  }

  async function compoundFromSmiles(smiles, options = {}) {
    const {
      cache
    } = options;
    let compounds;
    if (cache?.(smiles)) {
      compounds = cache(smiles);
    } else {
      const encodedSmiles = encodeURIComponent(smiles);
      const moleculeResponse = await fetch(`https://pubchem.ncbi.nlm.nih.gov/rest/pug/compound/smiles/${encodedSmiles}/json`);
      compounds = (await moleculeResponse.json()).PC_Compounds;
      if (cache) {
        cache(smiles, compounds);
      }
    }
    checkCompoundsResult(compounds);
    return new Compound(compounds[0], {
      cache
    });
  }

  class Compound {
    constructor(data, options = {}) {
      this.data = data;
      this.cache = options.cache;
    }
    getCID() {
      return this.data?.id?.id?.cid;
    }
    getData() {
      const cid = this.getCID();
      let cd = compoundDataFromCID(cid, {
        cache: this.cache
      });
      return cd;
    }
    toJSON() {
      const methods = Object.entries(Object.getOwnPropertyDescriptors(Compound.prototype)).filter(([, descriptor]) => typeof descriptor.get === 'function').map(([key]) => key);
      let result = {};
      for (let method of methods) {
        result[method] = this[method];
      }
      return result;
    }
  }
  Compound.fromSmiles = compoundFromSmiles;
  Compound.fromName = compoundFromName;
  Compound.fromInchiKey = compoundFromInchiKey;

  /**
   * We check that the hazards are present in the reagents
   * @param {object} reagent
   */
  async function ensureHHazardAndPhysical(reagent, options = {}) {
    const {
      logger
    } = options;
    if (reagent.hazards) return;
    try {
      const compound = await Compound.fromSmiles(reagent.smiles);
      const data = await compound.getData();
      const hStatements = data.getGHS().hStatements;
      reagent.hStatements = hStatements;
      const allCodes = hStatements.map(h => h.data.map(d => d.code)).flat();
      const uniqueHs = [...new Set(allCodes).keys()];
      reagent.hazards = uniqueHs;
    } catch (e) {
      logger.error(`Could not get hazards for ${reagent.smiles}: ${e.toString()}`);
      reagent.hStatements = [];
      reagent.hazards = [];
    }
  }

  var core = {};

  var openchemlibCore = {};

  (function(exports){(function(root){function getExports($wnd){var $doc=$wnd.document;var $gwt={};var navigator={userAgent:'webkit'};function noop(){}var __gwtModuleFunction=noop;__gwtModuleFunction.__moduleStartupDone=noop;var Hlb='object',Ilb='anonymous',Jlb='fnStack',Klb='\n',Llb={4:1,10:1,5:1,8:1},Mlb='Unknown',Nlb='boolean',Olb='number',Plb='string',Qlb=2147483647,Rlb='For input string: "',Slb='null',Tlb='__noinit__',Ulb={4:1,5:1,8:1},Vlb={4:1,15:1,22:1},Wlb=' (copy)',Xlb={4:1,10:1,31:1,5:1,17:1,8:1,29:1},Ylb=65536,Zlb=65535,$lb=10000,_lb=', length: ',amb='Index: ',bmb=', Size: ',cmb='fromIndex: ',dmb=', toIndex: ',emb={12:1,4:1,5:1},fmb={4:1},gmb={7:1,4:1,5:1},hmb=16777215,imb=65280,jmb=0.30000001192092896,kmb=545460846592,lmb=4294967296,mmb=8589934592,nmb=17179869184,omb=34359738368,pmb=68719476736,qmb=137438953472,rmb=274877906944,smb='<line x1="',tmb='" ',umb='y1="',vmb='x2="',wmb='y2="',xmb='stroke="',ymb='stroke-width="',zmb='" />',Amb={11:1,4:1,5:1},Bmb=536870912,Cmb=2.617993878,Dmb=3.665191429,Emb=6.283185307179586,Fmb=3.141592653589793,Gmb=1.5707963267948966,Hmb=16384,Imb=4096,Jmb={l:0,m:0,h:1},Kmb={l:0,m:0,h:2},Lmb={l:0,m:0,h:4},Mmb=1920,Nmb=1024,Omb=234881024,Pmb=167772160,Qmb=100663296,Rmb=201326592,Smb=114688,Tmb=4063232,Umb=3538944,Vmb=3014656,Wmb=2097152,Xmb=393216,Ymb=917504,Zmb=1966080,$mb=17042430230528,_mb=16492674416640,anb=15942918602752,bnb=14843406974976,cnb=12644383719424,dnb=8796093022208,enb=549755813888,fnb=1649267441664,gnb=3848290697216,hnb=8246337208320,inb=29360128,jnb=268435456,knb=8192,lnb=2048,mnb=-1.5707963267948966,nnb=130560,onb=6291456,pnb=1.0471975511965976,qnb=0.5235987755982988,rnb=786432,snb=524288,tnb=262144,unb=-16777216,vnb=16711680,wnb=-32768,xnb='<DrawingObject type="',ynb='><\/DrawingObject>',znb={4:1,5:1,13:1},Anb={4:1,5:1},Bnb='unsupported atomicNo:',Cnb=2.8415926535897933,Dnb={26:1,4:1,10:1,5:1,8:1},Enb={4:1,5:1,17:1,8:1},Fnb={9:1,4:1,5:1},Gnb=131072,Hnb={l:6,m:0,h:4},Inb=1048576,Jnb=3221225472,Knb={l:0,m:0,h:3},Lnb=8388608,Mnb=-65536,Nnb={38:1,39:1,45:1},Onb={38:1,39:1,80:1,45:1,98:1},Pnb={4:1,5:1,38:1,39:1,80:1,18:1,45:1,98:1,157:1},Qnb='??',Rnb=2013265920,Snb=32505856,Tnb=31744,Unb=1.7976931348623157E308,Vnb={105:1,4:1,10:1,5:1,17:1,8:1},Wnb=33554432,Xnb=67108864,Ynb=32768,Znb=-33554433,$nb=-33292289,_nb=-3.141592653589793,aob=4194303,bob=3072,cob={36:1,4:1,5:1},dob=0.7853981633974483,eob=3.061592653589793,fob=1073741824,gob=541165879296,hob={14:1,4:1,5:1,8:1},iob=281.17,job=289.19,kob=294.21,lob='0.0000',mob='M  END\n',nob='ATOMS',oob=-2147483648,pob='M  END',qob='$$$$',rob='M  V30 ',sob='M  V30 COUNTS ',tob=')\n',uob='M  V30 MDLV30/STEREL',vob='M  V30 MDLV30/STERAC',wob=3.4028234663852886E38,xob={l:2,m:0,h:4},yob=4194304,zob={l:4179966,m:4063288,h:7},Aob={l:4194302,m:4193343,h:7},Bob={117:1,103:1,104:1,4:1,10:1,5:1,8:1},Cob='class="event" ',Dob='opacity="0" />',Eob='Assignment of aromatic double bonds failed',Fob=1099511627776,Gob=2199023255552,Hob=4398046511104,Iob='Members of ESR groups must only be stereo centers with known configuration.',Job='Over- or under-specified stereo feature or more than one racemic type bond',Kob='Ambiguous configuration at stereo center because of 2 parallel bonds',Lob={91:1,75:1,25:1,4:1},Mob=100000,Nob=3.1415927410125732,Oob=1.5707963705062866,Pob=0.029999999329447746,Qob=6.2831854820251465,Rob=1.9106119871139526,Sob=2.2639999389648438,Tob=2.16759991645813,Uob=2.0662999153137207,Vob=2.3561999797821045,Wob=2.2844998836517334,Xob=1.9106120066311025,Yob=2.094395160675049,Zob=0.6000000238418579,$ob=1.7999999523162842,_ob=0.05000000074505806,apb={4:1,10:1,5:1,8:1,30:1},bpb=0.2617993950843811,cpb=2.0943951023931953,dpb=1.2000000476837158,epb=1.4299999475479126,fpb=1.659999966621399,gpb=1.4600000381469727,hpb=1.8200000524520874,ipb=2.4600000381469727,jpb=2.4200000762939453,kpb=2.450000047683716,lpb=2.440000057220459,mpb=2.4000000953674316,npb=2.319999933242798,opb=2.2899999618530273,ppb=1.8600000143051147,qpb=2.5299999713897705,rpb=2.490000009536743,spb=2.4700000286102295,tpb=2.880000114440918,upb=2.9200000762939453,vpb=2.869999885559082,wpb=2.8299999237060547,xpb=2.7899999618530273,ypb=2.809999942779541,zpb=2.799999952316284,Apb=3.049999952316284,Bpb=1.3300000429153442,Cpb=1.3899999856948853,Dpb=1.159999966621399,Epb=1.1100000143051147,Fpb=1.0700000524520874,Gpb=1.9600000381469727,Hpb=1.7100000381469727,Ipb=1.3600000143051147,Jpb=1.340000033378601,Kpb=1.2200000286102295,Lpb=1.2400000095367432,Mpb=1.2100000381469727,Npb=1.850000023841858,Opb=1.6299999952316284,Ppb=1.4700000286102295,Qpb=1.2799999713897705,Rpb=1.440000057220459,Spb=1.399999976158142,Tpb=1.7599999904632568,Upb=1.7300000190734863,Vpb=1.7200000286102295,Wpb=1.6799999475479126,Xpb=1.690000057220459,Ypb=1.6699999570846558,Zpb=1.649999976158142,$pb=1.7000000476837158,_pb=1.6200000047683716,aqb=1.3700000047683716,bqb=1.2899999618530273,cqb=1.4500000476837158,dqb=1.5700000524520874,eqb=-0.5235987755982988,fqb=-1.0471975511965976,gqb=-0.7853981633974483,hqb=0.017453292519943295,iqb=0.17453292519943295,jqb=1.0E-4,kqb={114:1},lqb=57.29577951308232,mqb=0.021922173386725217,nqb=1.0E-8,oqb=2.5120960256267386,pqb=1.0E-5,qqb='MMFF94s+',rqb='nonbonded cutoff',sqb='dielectric constant',tqb='dielectric model',uqb='angle bend',vqb='bond stretch',wqb='electrostatic',xqb='out of plane',yqb='stretch bend',zqb='torsion angle',Aqb='van der waals',Bqb={4:1,10:1,5:1,17:1,8:1},Cqb=0.07000000000000006,Dqb=0.1200000000000001,Eqb=-7.840000000000001,Fqb='OCL_RXN_V1.0:',Gqb="'$MOL' tag not found",Hqb="'M  END' not found",Iqb='\nActelion Java MolfileCreator 2.0\n\n  0  0  0  0  0  0              0 V3000\n',Jqb='M  V30 END CTAB',Kqb=2475109711874,Lqb=2475109711875,Mqb=2887426572290,Nqb=2887426572291,Oqb=2887627898882,Pqb=2887627898883,Qqb=2887627997186,Rqb=3437182386178,Sqb=3437182386179,Tqb=3437383712770,Uqb=3437383811074,Vqb=3437652148226,Wqb=3437652377602,Xqb=4674132967426,Yqb=4674334294018,Zqb=4674334392322,$qb=4674602729474,_qb=4674602958850,arb=5086449827842,brb=5086449827848,crb=5086651154434,drb=5086651252738,erb=5086651252743,frb=5086919589890,grb=5086919688194,hrb=5636406968322,irb=5636407066626,jrb=5636675502082,krb={l:589826,m:590112,h:4},lrb={l:589827,m:590112,h:4},mrb={l:589826,m:590160,h:4},nrb={l:589827,m:590160,h:4},orb={l:688130,m:590160,h:4},prb={l:589826,m:590224,h:4},qrb={l:589827,m:590224,h:4},rrb={l:819203,m:590224,h:4},srb={l:589826,m:590368,h:4},trb={l:688130,m:590368,h:4},urb={l:819202,m:590368,h:4},vrb={l:819208,m:590368,h:4},wrb={l:589826,m:590416,h:4},xrb={l:589832,m:590416,h:4},yrb={l:688130,m:590416,h:4},zrb={l:819202,m:590416,h:4},Arb={l:589826,m:598304,h:4},Brb={l:589827,m:598304,h:4},Crb={l:688130,m:598304,h:4},Drb={l:1114114,m:598304,h:4},Erb={l:1212418,m:598304,h:4},Frb={l:589826,m:598308,h:4},Grb={l:589826,m:688416,h:4},Hrb={l:589826,m:688464,h:4},Irb={l:589826,m:688720,h:4},Jrb={l:688130,m:688720,h:4},Krb={l:589826,m:590112,h:288},Lrb={l:589826,m:590112,h:336},Mrb={l:589826,m:688416,h:336},Nrb={l:589826,m:688464,h:336},Orb={l:688130,m:688464,h:336},Prb={l:589826,m:590112,h:400},Qrb={l:589826,m:688416,h:400},Rrb={l:589826,m:688464,h:400},Srb={l:688130,m:688464,h:400},Trb={l:589826,m:819488,h:400},Urb={l:589826,m:819536,h:400},Vrb={l:589826,m:819600,h:400},Wrb={l:688130,m:819600,h:400},Xrb={l:819202,m:819600,h:400},Yrb={l:589831,m:688416,h:592},Zrb={l:589831,m:688464,h:592},$rb={l:688135,m:688464,h:592},_rb={l:589831,m:819536,h:592},asb={l:688135,m:819536,h:592},bsb={l:688135,m:819600,h:592},csb={l:589832,m:1212704,h:592},dsb={l:589832,m:1212752,h:592},esb={l:688136,m:1212752,h:592},fsb={l:589831,m:688464,h:656},gsb={l:589826,m:590112,h:8480},hsb={l:589826,m:688416,h:8480},isb={l:589826,m:688464,h:8480},jsb={l:688130,m:688464,h:8480},ksb={l:819202,m:819600,h:8480},lsb={l:688135,m:1212752,h:8480},msb={l:589832,m:1213008,h:8480},nsb={l:688136,m:1213008,h:8480},osb={l:589826,m:590112,h:8484},psb={l:589826,m:590160,h:8484},qsb={l:688130,m:598304,h:8484},rsb=0.6262000203132629,ssb=-1.3825000524520874,tsb=0.33169999718666077,usb=-1.4915000200271606,vsb=0.3540000021457672,wsb=0.38179999589920044,xsb=-0.6019999980926514,ysb=-0.7379999756813049,zsb='Atom-types are 64-bit numbers describing atoms and their near surrounding.',Asb='Recognized atom types and their contributions are:',Bsb='Druglikeness predictor not properly initialized.',Csb=3.009999990463257,Dsb=-0.17000000178813934,Esb=-0.1809999942779541,Fsb=-0.2029999941587448,Gsb=2147483648,Hsb='MMFF94',Isb='MMFF94s',Jsb='117\nint,int,int,int,float\n0,2,0,0,0.020\n1,2,1,2,0.030\n1,2,2,2,0.027\n1,2,2,3,0.026\n1,2,2,5,0.013\n1,2,2,37,0.032\n2,2,2,5,0.013\n2,2,3,5,0.012\n2,2,5,5,0.006\n2,2,5,6,0.027\n2,2,5,37,0.017\n2,2,5,40,0.012\n2,2,5,41,0.008\n0,3,0,0,0.130\n1,3,1,7,0.146\n1,3,2,7,0.138\n1,3,3,7,0.134\n1,3,5,7,0.122\n1,3,6,7,0.141\n1,3,7,10,0.129\n1,3,7,37,0.138\n2,3,5,7,0.113\n2,3,5,9,0.081\n2,3,6,7,0.127\n2,3,7,10,0.116\n3,3,5,7,0.113\n3,3,6,7,0.127\n5,3,5,7,0.103\n5,3,5,9,0.074\n5,3,5,54,0.078\n5,3,6,7,0.119\n5,3,7,10,0.102\n5,3,9,40,0.067\n6,3,7,37,0.127\n7,3,10,10,0.113\n7,3,20,20,0.151\n9,3,40,40,0.057\n0,8,0,0,0.000\n0,10,0,0,0.015\n1,10,1,3,0.015\n1,10,3,6,0.015\n1,10,3,28,0.015\n3,10,3,28,0.015\n3,10,28,28,0.015\n0,17,0,0,0.000\n0,26,0,0,0.000\n0,30,0,0,0.010\n5,30,20,30,0.008\n0,37,0,0,0.035\n1,37,37,37,0.040\n2,37,37,37,0.031\n3,37,37,37,0.027\n5,37,37,37,0.015\n5,37,37,38,0.046\n5,37,37,63,0.008\n5,37,37,64,0.012\n5,37,37,69,0.016\n5,37,38,38,0.084\n6,37,37,37,0.048\n15,37,37,37,0.025\n37,37,37,40,0.046\n0,39,0,0,0.020\n1,39,63,63,0.012\n23,39,63,63,-0.014\n23,39,63,65,0.021\n23,39,65,65,0.062\n0,40,0,0,0.030\n1,40,28,37,0.030\n2,40,28,28,0.030\n3,40,28,28,0.030\n28,40,28,37,0.030\n0,41,0,0,0.180\n1,41,32,32,0.178\n2,41,32,32,0.161\n5,41,32,32,0.158\n0,43,0,0,0.000\n0,45,0,0,0.150\n0,49,0,0,0.000\n50,49,50,50,0.000\n0,54,0,0,0.020\n1,54,3,36,0.016\n3,54,36,36,0.018\n0,55,0,0,0.020\n1,55,36,57,0.020\n36,55,36,57,0.020\n0,56,0,0,0.020\n1,56,36,57,0.020\n36,56,36,57,0.020\n0,57,0,0,0.080\n5,57,55,55,0.038\n56,57,56,56,0.158\n0,58,0,0,0.025\n0,63,0,0,0.050\n5,63,39,64,0.019\n5,63,39,66,0.068\n5,63,44,64,0.014\n5,63,44,66,0.055\n5,63,59,64,0.033\n5,63,59,66,0.085\n37,63,39,64,0.010\n0,64,0,0,0.040\n5,64,63,64,0.006\n5,64,63,66,0.043\n5,64,64,65,0.052\n5,64,65,66,0.094\n37,64,63,64,-0.01\n0,67,0,0,0.070\n0,69,0,0,0.070\n32,69,37,37,0.067\n0,73,0,0,0.000\n0,78,0,0,0.045\n5,78,78,81,0.046\n0,80,0,0,0.080\n5,80,81,81,0.057\n0,81,0,0,0.025\n36,81,78,80,0.016\n0,82,0,0,0.000\n',Ksb={131:1,4:1,5:1,8:1},Lsb='undefined',Msb=0.08726646502812703,Nsb=0.003921568859368563,Osb='Too many percent/per mille characters in pattern "',Psb=1048575,Qsb=17592186044416,Rsb=1000000000,Ssb=-17592186044416,Tsb='CSS1Compat',Usb=5.56,Vsb=11.12,Wsb=13.34,Xsb=14.44,Ysb=0.3010299956639812,Zsb='BigInteger divide by zero',$sb=4294967295,_sb={l:0,m:0,h:524288},atb={27:1,88:1},btb={99:1},ctb={38:1,39:1,45:1,86:1},dtb='delete',etb=15525485,ftb=5.9604644775390625E-8,gtb=16777216,htb={4:1,27:1,52:1,64:1},itb='Invalid UTF8 sequence',jtb=0.20000000298023224,ktb=' distance:',ltb='gGP`@dfyjidNcGI[WQCP`<',mtb={43:1};var Ykb={};var Zkb={};var $kb={};var _kb={};var alb={};var blb={};var clb={};var dlb={};var elb={};var flb={};var glb={};var hlb={};var ilb={};var jlb={};var klb={};var llb={};var mlb={};var nlb={};var olb={};var plb={};var qlb={};var rlb={};var slb={};var tlb={};var ulb={};var vlb={};var wlb={};var xlb={};var ylb={};var zlb={};var Alb={};var Blb={};var Clb={};var Dlb={};var Elb={};var Flb={};var Glb={};var _;var R1;var L1;Ykb._0=function _0(){};function Q1(a,b){typeof window===Hlb&&typeof window['$gwt']===Hlb&&(window['$gwt'][a]=b);}function P1(b,c,d,e){Ykb.O1();var f=L1;function g(){for(var a=0;a<f.length;a++){f[a]();}}if(b){try{Xkb(g)();}catch(a){b(c,a);}}else {Xkb(g)();}}Ykb.O1=function O1(){L1==null&&(L1=[]);};function N1(){Ykb.O1();var a=L1;for(var b=0;b<arguments.length;b++){a.push(arguments[b]);}}Ykb.M1=function M1(){};function a2(){}function _1(a){if(Array.isArray(a)&&a.uc===a2){return Zkb.Mc(a);}return a.toString();}function $1(a,b){var c=$wnd;if(a===''){return c;}var d=a.split('.');!(d[0]in c)&&c.execScript&&c.execScript('var '+d[0]);if(b){var e=b.prototype.sc;e.e=b;}for(var f;d.length&&(f=d.shift());){c=c[f]=c[f]||!d.length&&b||{};}return c;}Ykb.Z1=function Z1(a){function b(){}b.prototype=a||{};return new b();};Ykb.Y1=function Y1(a){return a instanceof Array?a[0]:null;};function X1(a,b,c){var d=function(){return a.apply(d,arguments);};b.apply(d,c);return d;}function W1(){}function V1(a,b){for(var c in b){b[c]['configurable']=true;}Object.defineProperties(a,b);}function U1(a,b,c){var d=R1;var e=d[a];var f=Ykb.Y1(e);if(e&&!f){_=e;}else {_=Ykb.T1(b);_.tc=c;!b&&(_.uc=a2);d[a]=_;}for(var g=3;g<arguments.length;++g){arguments[g].prototype=_;}f&&(_.sc=f);}Ykb.T1=function T1(a){var b=a&&a.prototype;!b&&(b=R1[a]);return Ykb.Z1(b);};Ykb.S1=function S1(){};$wnd.goog=$wnd.goog||{};$wnd.goog.global=$wnd.goog.global||$wnd;R1={};Zkb.Bc=function Bc(a,b){return uX(a)===uX(b);};Zkb.Cc=function Cc(a){return a.sc;};Zkb.Dc=function Dc(a){return alb.wgb(a);};function Ec(){}Zkb.Gc=function Gc(a,b){return rX(a)?Zkb.c5(a,b):oX(a)?Zkb.V3(a,b):nX(a)?Zkb.P2(a,b):lX(a)?a.ib(b):iW(a)?Zkb.Bc(a,b):$kb.pU(a,b);};Zkb.Ic=function Ic(a){return rX(a)?Zkb.e5():oX(a)?Zkb.W3():nX(a)?Zkb.Q2():lX(a)?a.sc:iW(a)?Zkb.Cc(a):$kb.qU(a);};Zkb.Kc=function Kc(a){return rX(a)?Zkb.f5(a):oX(a)?Zkb.X3(a):nX(a)?Zkb.R2(a):lX(a)?a.kb():iW(a)?Zkb.Dc(a):$kb.rU(a);};Zkb.Mc=function Mc(a){var b;return Zkb.q3(Zkb.Ic(a))+'@'+(b=alb.Pgb(alb.Ogb(Zkb.Kc(a))),b.toString(16));};U1(1,null,{},Ec);_.ib=function Fc(a){return Zkb.Bc(this,a);};_.jb=function Hc(){return Zkb.Cc(this);};_.kb=function Jc(){return Zkb.Dc(this);};_.lb=function Lc(){var a;return Zkb.q3(Zkb.Ic(this))+'@'+(a=alb.Pgb(alb.Ogb(Zkb.Kc(this))),a.toString(16));};_.equals=function(a){return this.ib(a);};_.hashCode=function(){return this.kb();};_.toString=function(){return this.lb();};$kb.pU=function pU(a,b){return $kb.vU(a)?$kb.sU(a,b):uX(a)===uX(b);};$kb.qU=function qU(a){return a.sc||Array.isArray(a)&&aW(Ykb.r$,1)||Ykb.r$;};$kb.rU=function rU(a){return $kb.wU(a)?$kb.tU(a):alb.wgb(a);};$kb.sU=function sU(a,b){return a.equals(b);};$kb.tU=function tU(a){return a.hashCode();};$kb.uU=function uU(){return [];};$kb.vU=function vU(a){return !!a&&!!a.equals;};$kb.wU=function wU(a){return !!a&&!!a.hashCode;};$kb.xU=function xU(a){return a.toString?a.toString():'[JavaScriptObject]';};_kb.bV=function bV(){_kb.bV=W1;var a,b;b=!_kb.kV();a=new _kb.tV();_kb.aV=b?new _kb.lV():a;};_kb.cV=function cV(a){_kb.bV();_kb.aV.Tb(a);};_kb.dV=function dV(a){_kb.bV();var b;b=_kb.aV.Ub(a);return _kb.eV(b);};_kb.eV=function eV(a){var b,c,d,e;b='cV';c='mz';e=$wnd.Math.min(a.length,5);for(d=e-1;d>=0;d--){if(Zkb.c5(a[d].d,b)||Zkb.c5(a[d].d,c)){a.length>=d+1&&alb.Pgb(a).splice(0,d+1);break;}}return a;};_kb.fV=function fV(a){var b=/function(?:\s+([\w$]+))?\s*\(/;var c=b.exec(a);return c&&c[1]||Ilb;};_kb.gV=function gV(a){_kb.bV();return a&&a[Jlb]?a[Jlb]:[];};_kb.hV=function hV(a){_kb.bV();return a.name||(a.name=_kb.fV(a.toString()));};_kb.iV=function iV(a){_kb.bV();return parseInt(a)||-1;};_kb.jV=function jV(a){_kb.bV();var b=a.backingJsObject;if(b&&b.stack){var c=b.stack;var d=b+Klb;c.substring(0,d.length)==d&&(c=c.substring(d.length));return c.split(Klb);}return [];};_kb.kV=function kV(){if(Error.stackTraceLimit>0){$wnd.Error.stackTraceLimit=Error.stackTraceLimit=64;return true;}return 'stack'in new Error();};U1(330,1,{});_kb.lV=function lV(){};U1(236,330,{},_kb.lV);_.Tb=function mV(a){var b={};var c=[];a[Jlb]=c;var d=arguments.callee.caller;while(d){var e=_kb.hV(d);c.push(e);var f=':'+e;var g=b[f];if(g){var h,i;for(h=0,i=g.length;h<i;h++){if(g[h]===d){return;}}}(g||(b[f]=[])).push(d);d=d.caller;}};_.Ub=function nV(a){var b,c,d,e;d=_kb.gV(a);c=$kb.DU(d);e=gW(Ykb.h_,Llb,66,c,0,1);for(b=0;b<c;b++){e[b]=new Zkb.T4($kb.CU(d,b),null,-1);}return e;};_kb.oV=function oV(a,b){var c,d,e,f,g,h,i,j,k;j='';if(alb.Pgb(b).length==0){return a.Vb(Mlb,Ilb,-1,-1);}k=Zkb.q5(b);Zkb.c5(alb.Pgb(k).substr(0,3),'at ')&&(k=(alb.Kgb(3,alb.Pgb(k).length+1),alb.Pgb(k).substr(3)));k=_kb.pV(k);g=alb.Pgb(k).indexOf('(');if(g==-1){g=alb.Pgb(k).indexOf('@');if(g==-1){j=k;k='';}else {j=Zkb.q5((alb.Kgb(g+1,alb.Pgb(k).length+1),alb.Pgb(k).substr(g+1)));k=Zkb.q5((alb.Jgb(0,g,alb.Pgb(k).length),alb.Pgb(k).substr(0,g)));}}else {c=alb.Pgb(k).indexOf(')',g);j=(alb.Jgb(g+1,c,alb.Pgb(k).length),alb.Pgb(k).substr(g+1,c-(g+1)));k=Zkb.q5((alb.Jgb(0,g,alb.Pgb(k).length),alb.Pgb(k).substr(0,g)));}g=Zkb.g5(k,s5(46));g!=-1&&(k=(alb.Kgb(g+1,alb.Pgb(k).length+1),alb.Pgb(k).substr(g+1)));(alb.Pgb(k).length==0||Zkb.c5(k,'Anonymous function'))&&(k=Ilb);h=Zkb.j5(j,s5(58));e=Zkb.k5(j,s5(58),h-1);i=-1;d=-1;f=Mlb;if(h!=-1&&e!=-1){f=(alb.Jgb(0,e,alb.Pgb(j).length),alb.Pgb(j).substr(0,e));i=_kb.iV((alb.Jgb(e+1,h,alb.Pgb(j).length),alb.Pgb(j).substr(e+1,h-(e+1))));d=_kb.iV((alb.Kgb(h+1,alb.Pgb(j).length+1),alb.Pgb(j).substr(h+1)));}return a.Vb(f,k,i,d);};_kb.pV=function pV(a){return a.replace(/\[.*?\]/g,'');};U1(331,330,{});_.Tb=function qV(a){};_.Vb=function rV(a,b,c,d){return new Zkb.T4(b,a+'@'+d,c<0?-1:c);};_.Ub=function sV(a){var b,c,d,e,f,g;e=_kb.jV(a);f=gW(Ykb.h_,Llb,66,0,0,1);b=0;d=$kb.DU(e);if(d==0){return f;}g=_kb.oV(this,$kb.CU(e,0));Zkb.c5(g.d,Ilb)||(f[b++]=g);for(c=1;c<d;c++){f[b++]=_kb.oV(this,$kb.CU(e,c));}return f;};_kb.tV=function tV(){};U1(237,331,{},_kb.tV);_.Vb=function uV(a,b,c,d){return new Zkb.T4(b,a,-1);};Ykb._V=function _V(a){return a;};function aW(a,b){return Ykb.bW(a,b);}Ykb.bW=function bW(a,b){return Zkb.A3(a,b);};Ykb.cW=function cW(a){return a.__elementTypeCategory$==null?10:a.__elementTypeCategory$;};Ykb.dW=function dW(a){return a.__elementTypeId$;};function eW(a,b,c,d,e,f){return Ykb.fW(a,b,c,d,e,0,f);}Ykb.fW=function fW(a,b,c,d,e,f,g){var h,i,j,k,l;k=e[f];j=f==g-1;h=j?d:0;l=Ykb.hW(h,k);d!=10&&oW(aW(a,g-f),b[f],c[f],h,l);if(!j){++f;for(i=0;i<k;++i){Ykb.jW(l,i,Ykb.fW(a,b,c,d,e,f,g));}}return l;};function gW(a,b,c,d,e,f){var g;g=Ykb.hW(e,d);e!=10&&oW(aW(a,f),b,c,e,g);return g;}Ykb.hW=function hW(a,b){var c=new Array(b);var d;switch(a){case 14:case 15:d=0;break;case 16:d=false;break;default:return c;}for(var e=0;e<b;++e){c[e]=d;}return c;};function iW(a){return Array.isArray(a)&&a.uc===a2;}Ykb.jW=function jW(a,b,c){return a[b]=c;};function kW(a,b,c){return Ykb.jW(a,b,c);}Ykb.lW=function lW(a,b){a.sc=b;};Ykb.mW=function mW(a,b){a.__elementTypeCategory$=b;};Ykb.nW=function nW(a,b){a.__elementTypeId$=b;};function oW(a,b,c,d,e){Ykb.lW(e,a);e.tc=b;e.uc=a2;Ykb.nW(e,c);Ykb.mW(e,d);return e;}Ykb.pW=function pW(a,b){Ykb.cW(b)!=10&&oW(Zkb.Ic(b),b.tc,Ykb.dW(b),Ykb.cW(b),a);return Ykb._V(a);};function kX(a,b){if(rX(a)){return !!jX[b];}else if(a.tc){return !!a.tc[b];}else if(oX(a)){return !!iX[b];}else if(nX(a)){return !!hX[b];}return false;}function lX(a){return !Array.isArray(a)&&a.uc===a2;}function mX(a,b){return a!=null&&kX(a,b);}function nX(a){return typeof a===Nlb;}function oX(a){return typeof a===Olb;}function pX(a){return a!=null&&Ykb.sX(a)&&!(a.uc===a2);}function qX(a,b){return Ykb.tX(a,b);}function rX(a){return typeof a===Plb;}Ykb.sX=function sX(a){return typeof a===Hlb||typeof a==='function';};Ykb.tX=function tX(a,b){return a&&b&&a instanceof b;};function uX(a){return a==null?null:a;}function vX(a){return Math.max(Math.min(a,Qlb),-2147483648)|0;}var hX;var iX;var jX;Ykb.a1=function a1(a){return a&&a.__java$exception;};function b1(a){var b;if(mX(a,22)){return a;}b=Ykb.a1(a);if(!b){b=new $kb.jU(a);_kb.cV(b);}return b;}function c1(a){return a.backingJsObject;}function s2(a){var b;if(a==null){return false;}b=typeof a;return Zkb.c5(b,Nlb)||Zkb.c5(b,Olb)||Zkb.c5(b,Plb)||a.$implements__java_io_Serializable||Array.isArray(a);}function L3(a){var b;b=typeof a;if(Zkb.c5(b,Nlb)||Zkb.c5(b,Olb)||Zkb.c5(b,Plb)){return true;}return a!=null&&a.$implements__java_lang_Comparable;}Zkb.L2=function L2(){Zkb.L2=W1;K2=alb.Pgb(false);alb.Pgb(true);};Zkb.M2=function M2(a){return alb.Qgb((alb.Egb(a),a));};Zkb.N2=function N2(a,b){return T2(alb.Qgb((alb.Egb(a),a)),alb.Qgb((alb.Egb(b),b)));};Zkb.O2=function O2(a,b){return Zkb.N2(a,b);};Zkb.P2=function P2(a,b){return alb.Egb(a),uX(a)===uX(b);};Zkb.Q2=function Q2(){return Ykb.R$;};Zkb.R2=function R2(a){return alb.Qgb((alb.Egb(a),a))?1231:1237;};function S2(a){Zkb.L2();return Zkb.c5(Nlb,typeof a);}function T2(a,b){Zkb.L2();return a==b?0:a?1:-1;}Zkb.U2=function U2(a,b){Zkb.L2();return rX(a)?Zkb.Y4(a,b):oX(a)?Zkb.T3(a,b):nX(a)?Zkb.O2(a,b):a.qb(b);};hX={4:1,233:1,27:1};var K2;function V2(a){if(Zkb.c5(typeof a,Plb)){return true;}return a!=null&&a.$implements__java_lang_CharSequence;}Zkb.o3=function o3(a){a.i=n3++;};Zkb.p3=function p3(a){if(a.n!=null){return;}Zkb.E3(a);};Zkb.q3=function q3(a){Zkb.p3(a);return a.n;};Zkb.r3=function r3(a){return (a.f&4)!=0;};Zkb.s3=function s3(a){return (a.f&1)!=0;};Zkb.t3=function t3(){Zkb.o3(this);this.n=null;this.j=null;this.g=null;this.d=null;this.b=null;this.k=null;this.a=null;};Zkb.v3=function v3(a){var b;b=new Zkb.t3();b.n='Class$'+(a?'S'+a:''+b.i);b.b=b.n;b.j=b.n;return b;};function w3(a){var b;b=Zkb.v3(a);Zkb.I3(a,b);return b;}function x3(a,b){var c;c=Zkb.v3(a);Zkb.I3(a,c);c.f=b?8:0;return c;}function y3(a){var b;b=Zkb.v3(a);b.k=a;b.f=1;return b;}Zkb.A3=function A3(a,b){var c=a.a=a.a||[];return c[b]||(c[b]=a.Wb(b));};function C3(a){if(a._b()){return null;}var b=a.k;return R1[b];}Zkb.E3=function E3(a){if(a.$b()){var b=a.c;b._b()?a.n='['+b.k:!b.$b()?a.n='[L'+b.Yb()+';':a.n='['+b.Yb();a.b=b.Xb()+'[]';a.j=b.Zb()+'[]';return;}var c=a.g;var d=a.d;d=d.split('/');a.n=Zkb.H3('.',[c,Zkb.H3('$',d)]);a.b=Zkb.H3('.',[c,Zkb.H3('.',d)]);a.j=d[d.length-1];};Zkb.H3=function H3(a,b){var c=0;while(!b[c]||b[c]==''){c++;}var d=b[c++];for(;c<b.length;c++){if(!b[c]||b[c]==''){continue;}d+=a+b[c];}return d;};Zkb.I3=function I3(a,b){if(!a){return;}b.k=a;var d=C3(b);if(!d){R1[a]=[b];return;}d.sc=b;};U1(158,1,{},Zkb.t3);_.Wb=function u3(a){var b;b=new Zkb.t3();b.f=4;a>1?b.c=Zkb.A3(this,a-1):b.c=this;return b;};_.Xb=function z3(){Zkb.p3(this);return this.b;};_.Yb=function B3(){return Zkb.q3(this);};_.Zb=function D3(){Zkb.p3(this);return this.j;};_.$b=function F3(){return Zkb.r3(this);};_._b=function G3(){return Zkb.s3(this);};_.lb=function J3(){return ((this.f&2)!=0?'interface ':(this.f&1)!=0?'':'class ')+(Zkb.p3(this),this.n);};_.f=0;_.i=0;var n3=1;Zkb.N3=function N3(a){return Zkb.c5(Olb,typeof a)||qX(a,$wnd.java.lang.Number$impl);};Zkb.O3=function O3(a){Zkb.M3==null&&(Zkb.M3=new RegExp('^\\s*[+-]?(NaN|Infinity|((\\d+\\.?\\d*)|(\\.\\d+))([eE][+-]?\\d+)?[dDfF]?)\\s*$'));if(!Zkb.M3.test(a)){throw c1(new Zkb.S4(Rlb+a+'"'));}return parseFloat(a);};Zkb.P3=function P3(a,b,c){var d,e,f,g,h;if(a==null){throw c1(new Zkb.S4(Slb));}f=alb.Pgb(a).length;g=f>0&&(alb.Kgb(0,alb.Pgb(a).length),alb.Pgb(a).charCodeAt(0)==45||(alb.Kgb(0,alb.Pgb(a).length),alb.Pgb(a).charCodeAt(0)==43))?1:0;for(d=g;d<f;d++){if(_2((alb.Kgb(d,alb.Pgb(a).length),alb.Pgb(a).charCodeAt(d)))==-1){throw c1(new Zkb.S4(Rlb+a+'"'));}}h=parseInt(a,10);e=h<b;if(isNaN(h)){throw c1(new Zkb.S4(Rlb+a+'"'));}else if(e||h>c){throw c1(new Zkb.S4(Rlb+a+'"'));}return h;};Zkb.Q3=function Q3(a){return oX(a)?Zkb.U3(a):a.ac();};Zkb.R3=function R3(a){return oX(a)?Zkb.Y3(a):a.bc();};U1(95,1,{4:1,95:1});Zkb.S3=function S3(a,b){return $3(alb.Rgb((alb.Egb(a),a)),alb.Rgb((alb.Egb(b),b)));};Zkb.T3=function T3(a,b){return Zkb.S3(a,b);};Zkb.U3=function U3(a){return alb.Rgb((alb.Egb(a),a));};Zkb.V3=function V3(a,b){return alb.Egb(a),uX(a)===uX(b);};Zkb.W3=function W3(){return Ykb.U$;};Zkb.X3=function X3(a){return vX(alb.Rgb((alb.Egb(a),a)));};Zkb.Y3=function Y3(a){return vX(alb.Rgb((alb.Egb(a),a)));};function Z3(a){return Zkb.c5(Olb,typeof a);}function $3(a,b){if(a<b){return -1;}if(a>b){return 1;}if(a==b){return a==0?$3(1/a,1/b):0;}return isNaN(a)?isNaN(b)?0:1:-1;}function _3(a){if(isNaN(a)){return {l:0,m:0,h:524160};}return alb.Lgb(a);}iX={4:1,27:1,234:1,95:1};Zkb.Vy=function Vy(a){a.g=gW(Ykb.h_,Llb,66,0,0,1);};Zkb.Wy=function Wy(a){_kb.cV(a);};Zkb.Xy=function Xy(a){return _kb.dV(a);};Zkb.Yy=function Yy(a){if(a.j){a.backingJsObject!==Tlb&&a.Hb();a.g=null;}return a;};Zkb.Zy=function Zy(a){return a.e;};Zkb.$y=function $y(d,b){if(b instanceof Object){try{b.__java$exception=d;if(navigator.userAgent.toLowerCase().indexOf('msie')!=-1&&$doc.documentMode<9){return;}var c=d;Object.defineProperties(b,{cause:{get:function(){var a=c.Fb();return a&&a.Db();}},suppressed:{get:function(){return c.Eb();}}});}catch(a){}}};Zkb._y=function _y(a,b,c){var d,e,f,g,h;Zkb.az(a);for(e=(a.i==null&&(a.i=gW(Ykb.m_,Llb,22,0,0,1)),a.i),f=0,g=e.length;f<g;++f){d=e[f];Zkb._y(d,b,'\t'+c);}h=a.e;!!h&&Zkb._y(h,b,c);};Zkb.az=function az(a){var b,c,d;for(b=(a.g==null&&(a.g=Zkb.Xy(a)),a.g),c=0,d=b.length;c<d;++c){}};Zkb.bz=function bz(a,b){a.backingJsObject=b;Zkb.$y(a,b);};Zkb.cz=function cz(a){return Zkb.dz(a,a.Gb());};Zkb.dz=function dz(a,b){var c;c=Zkb.q3(a.sc);return b==null?c:c+': '+b;};Zkb.ez=function ez(){Zkb.Vy(this);Zkb.Yy(this);this.Hb();};Zkb.fz=function fz(a){Zkb.Vy(this);this.f=a;Zkb.Yy(this);this.Hb();};Zkb.hz=function hz(b){if(!('stack'in b)){try{throw b;}catch(a){}}return b;};function nz(a){var b;if(a!=null){b=a.__java$exception;if(b){return b;}}return qX(a,TypeError)?new Zkb.P4(a):new Zkb.bU(a);}U1(22,1,{4:1,22:1});_.Cb=function gz(a){return new Error(a);};_.Db=function iz(){return this.backingJsObject;};_.Eb=function jz(){var a,b,c;c=(this.i==null&&(this.i=gW(Ykb.m_,Llb,22,0,0,1)),this.i);b=gW(Ykb.f_,Ulb,1,c.length,5,1);for(a=0;a<c.length;a++){b[a]=c[a].backingJsObject;}return b;};_.Fb=function kz(){return Zkb.Zy(this);};_.Gb=function lz(){return this.f;};_.Hb=function mz(){Zkb.bz(this,Zkb.hz(this.Cb(Zkb.dz(this,this.f))));Zkb.Wy(this);};_.lb=function oz(){return Zkb.cz(this);};_.backingJsObject=Tlb;_.j=true;Zkb.pz=function pz(){Zkb.ez.call(this);};Zkb.qz=function qz(a){Zkb.Vy(this);Zkb.Yy(this);this.backingJsObject=a;Zkb.$y(this,a);this.f=a==null?Slb:_1(a);};Zkb.rz=function rz(a){Zkb.fz.call(this,a);};U1(15,22,Vlb,Zkb.rz);Zkb.sz=function sz(){Zkb.pz.call(this);};Zkb.tz=function tz(a){Zkb.qz.call(this,a);};Zkb.uz=function uz(a){Zkb.rz.call(this,a);};U1(41,15,Vlb);Zkb.G2=function G2(){Zkb.sz.call(this);};Zkb.H2=function H2(a){Zkb.uz.call(this,a);};U1(69,41,Vlb,Zkb.G2,Zkb.H2);Zkb.aU=function aU(){Zkb.sz.call(this);};Zkb.bU=function bU(a){Zkb.tz.call(this,a);};Zkb.cU=function cU(a){Zkb.uz.call(this,a);};U1(100,41,Vlb,Zkb.bU);Zkb.O4=function O4(){Zkb.aU.call(this);};Zkb.P4=function P4(a){Zkb.bU.call(this,a);};Zkb.Q4=function Q4(a){Zkb.cU.call(this,a);};U1(62,100,Vlb,Zkb.O4,Zkb.P4,Zkb.Q4);_.Cb=function R4(a){return new TypeError(a);};Zkb.X4=function X4(a,b){alb.Kgb(b,alb.Pgb(a).length);return alb.Pgb(a).charCodeAt(b);};Zkb.Y4=function Y4(a,b){return Zkb.Z4(a,b);};Zkb.Z4=function Z4(a,b){var c,d;c=Zkb.U3(alb.Pgb(a));d=Zkb.U3(alb.Pgb(b));return c==d?0:c<d?-1:1;};Zkb.$4=function $4(a,b){return Zkb.Z4(alb.Pgb(a).toLowerCase(),alb.Pgb(b).toLowerCase());};Zkb._4=function _4(a,b){return alb.Egb(a),a+(''+(alb.Egb(b),b));};Zkb.a5=function a5(a){var b;return Zkb.u5(alb.ogb(a,0,(b=a.length,alb.lgb(),b)));};Zkb.b5=function b5(a){var b;b=alb.Pgb(Wlb).length;return Zkb.c5(alb.Pgb(a).substr(alb.Pgb(a).length-b,b),Wlb);};Zkb.c5=function c5(a,b){return alb.Egb(a),uX(a)===uX(b);};Zkb.d5=function d5(a,b){alb.Egb(a);if(b==null){return false;}if(Zkb.c5(a,b)){return true;}return alb.Pgb(a).length==alb.Pgb(b).length&&Zkb.c5(alb.Pgb(a).toLowerCase(),alb.Pgb(b).toLowerCase());};Zkb.e5=function e5(){return Ykb.l_;};Zkb.f5=function f5(a){var b,c;b=0;for(c=0;c<alb.Pgb(a).length;c++){b=(b<<5)-b+(alb.Kgb(c,alb.Pgb(a).length),alb.Pgb(a).charCodeAt(c))|0;}return b;};Zkb.g5=function g5(a,b){return alb.Pgb(a).indexOf(b);};Zkb.h5=function h5(a,b,c){return alb.Pgb(a).indexOf(b,c);};function i5(a){return Zkb.c5(Plb,typeof a);}Zkb.j5=function j5(a,b){return alb.Pgb(a).lastIndexOf(b);};Zkb.k5=function k5(a,b,c){return alb.Pgb(a).lastIndexOf(b,c);};Zkb.l5=function l5(a,b){var c;c=Zkb.m5(b,'([/\\\\\\.\\*\\+\\?\\|\\(\\)\\[\\]\\{\\}$^])','\\\\$1');return Zkb.m5(a,c,'');};Zkb.m5=function m5(a,b,c){c=Zkb.t5(c);return alb.Pgb(a).replace(new RegExp(b,'g'),c);};Zkb.n5=function n5(a,b){var c,d,e,f,g,h,i,j;c=new RegExp(b,'g');i=gW(Ykb.l_,Xlb,2,0,6,1);d=0;j=a;f=null;while(true){h=c.exec(j);if(h==null||j==''){i[d]=j;break;}else {g=h.index;i[d]=(alb.Jgb(0,g,alb.Pgb(j).length),alb.Pgb(j).substr(0,g));j=Zkb.p5(j,g+alb.Pgb(alb.Pgb(h)[0]).length,alb.Pgb(j).length);c.lastIndex=0;if(f==j){i[d]=(alb.Jgb(0,1,alb.Pgb(j).length),alb.Pgb(j).substr(0,1));j=(alb.Kgb(1,alb.Pgb(j).length+1),alb.Pgb(j).substr(1));}f=j;++d;}}if(alb.Pgb(a).length>0){e=i.length;while(e>0&&i[e-1]==''){--e;}e<i.length&&(alb.Pgb(i).length=e);}return i;};Zkb.o5=function o5(a,b){alb.Kgb(b,alb.Pgb(a).length+1);return alb.Pgb(a).substr(b);};Zkb.p5=function p5(a,b,c){alb.Jgb(b,c,alb.Pgb(a).length);return alb.Pgb(a).substr(b,c-b);};Zkb.q5=function q5(a){var b,c,d;c=alb.Pgb(a).length;d=0;while(d<c&&(alb.Kgb(d,alb.Pgb(a).length),alb.Pgb(a).charCodeAt(d)<=32)){++d;}b=c;while(b>d&&(alb.Kgb(b-1,alb.Pgb(a).length),alb.Pgb(a).charCodeAt(b-1)<=32)){--b;}return d>0||b<c?(alb.Jgb(d,b,alb.Pgb(a).length),alb.Pgb(a).substr(d,b-d)):a;};Zkb.r5=function r5(a){return String.fromCharCode.apply(null,a);};function s5(a){var b,c;if(a>=Ylb){b=55296+(a-Ylb>>10&1023)&Zlb;c=56320+(a-Ylb&1023)&Zlb;return String.fromCharCode(b)+(''+String.fromCharCode(c));}else {return String.fromCharCode(a&Zlb);}}Zkb.t5=function t5(a){var b;b=0;while(0<=(b=alb.Pgb(a).indexOf('\\',b))){alb.Kgb(b+1,alb.Pgb(a).length);alb.Pgb(a).charCodeAt(b+1)==36?a=(alb.Jgb(0,b,alb.Pgb(a).length),alb.Pgb(a).substr(0,b)+'$'+Zkb.o5(a,++b)):a=(alb.Jgb(0,b,alb.Pgb(a).length),alb.Pgb(a).substr(0,b)+(''+Zkb.o5(a,++b)));}return a;};Zkb.u5=function u5(a){return Zkb.v5(a,0,a.length);};Zkb.v5=function v5(a,b,c){var d,e,f,g;f=b+c;alb.Jgb(b,f,a.length);g='';for(e=b;e<f;){d=$wnd.Math.min(e+$lb,f);g+=Zkb.r5(alb.Pgb(a).slice(e,d));e=d;}return g;};jX={4:1,160:1,27:1,2:1};Zkb.M5=function M5(a){Zkb.H2.call(this,a);};U1(179,69,Vlb,Zkb.M5);alb.agb=function agb(a){var b;b=alb.Pgb(a).slice();return alb.kgb(b,a);};alb.bgb=function bgb(a,b,c,d,e,f){var g,h,i,j,k;if(e==0){return;}if(uX(a)===uX(c)){a=alb.Pgb(a).slice(b,b+e);b=0;}i=alb.Pgb(c);for(h=b,j=b+e;h<j;){g=$wnd.Math.min(h+$lb,j);e=g-h;k=alb.Pgb(a).slice(h,g);alb.Pgb(k).splice(0,0,alb.Pgb(d),alb.Pgb(f?e:0));Array.prototype.splice.apply(i,k);h=g;d+=e;}};alb.cgb=function cgb(a,b){return alb.kgb(new Array(b),a);};alb.dgb=function dgb(a,b,c){alb.Pgb(a).splice(b,0,c);};alb.egb=function egb(a,b,c){alb.bgb(c,0,a,b,c.length,false);};alb.fgb=function fgb(a,b){alb.Pgb(a).push(b);};alb.ggb=function ggb(a,b){alb.Pgb(a).push(b);};alb.hgb=function hgb(a,b,c){alb.Pgb(a).splice(b,c);};alb.igb=function igb(a,b){alb.Pgb(a).length=b;};alb.jgb=function jgb(a,b){alb.Pgb(a).sort(b);};U1(374,1,{});alb.tgb=function tgb(){};alb.ugb=function ugb(a){switch(typeof a){case Plb:return Zkb.f5(alb.Pgb(a));case Olb:return Zkb.X3(alb.Pgb(a));case Nlb:return Zkb.R2(alb.Pgb(a));default:return a==null?0:alb.wgb(a);}};alb.vgb=function vgb(){return ++alb.sgb;};alb.wgb=function wgb(a){return a.$H||(a.$H=alb.vgb());};U1(328,1,{},alb.tgb);alb.sgb=0;alb.xgb=function xgb(a){if(!a){throw c1(new Zkb.b4());}};alb.ygb=function ygb(a,b){if(!a){throw c1(new Zkb.c4(b));}};alb.zgb=function zgb(a,b){if(0>a){throw c1(new Zkb.c4('fromIndex: 0 > toIndex: '+a));}if(a>b){throw c1(new Zkb.J2('fromIndex: 0, toIndex: '+a+_lb+b));}};alb.Agb=function Agb(a){if(a<0){throw c1(new Zkb.N4('Negative array size: '+a));}};alb.Bgb=function Bgb(a,b){if(a!=b){throw c1(new dlb.Icb());}};alb.Cgb=function Cgb(a){if(!a){throw c1(new dlb.Ndb());}};alb.Dgb=function Dgb(a,b){if(a<0||a>=b){throw c1(new Zkb.H2(amb+a+bmb+b));}};alb.Egb=function Egb(a){if(a==null){throw c1(new Zkb.O4());}return a;};alb.Fgb=function Fgb(a,b){if(a==null){throw c1(new Zkb.Q4(b));}};alb.Ggb=function Ggb(a,b){if(a<0||a>b){throw c1(new Zkb.H2(amb+a+bmb+b));}};alb.Hgb=function Hgb(a,b,c){if(a<0||b>c){throw c1(new Zkb.H2(cmb+a+dmb+b+', size: '+c));}if(a>b){throw c1(new Zkb.c4(cmb+a+' > toIndex: '+b));}};alb.Igb=function Igb(a){if(!a){throw c1(new Zkb.d4());}};alb.Jgb=function Jgb(a,b,c){if(a<0||b>c||b<a){throw c1(new Zkb.M5(cmb+a+dmb+b+_lb+c));}};alb.Kgb=function Kgb(a,b){if(a<0||a>=b){throw c1(new Zkb.M5(amb+a+bmb+b));}};alb.Lgb=function Lgb(a){var b,c;b=new ArrayBuffer(8);alb.Pgb(new Float64Array(b))[0]=a;c=alb.Pgb(new Uint32Array(b));return alb.Sgb(c[0]|0,c[1]|0);};alb.Mgb=function Mgb(a,b){return a[b];};alb.Ngb=function Ngb(a){return a===undefined;};alb.Ogb=function Ogb(a){return a>>>0;};alb.Pgb=function Pgb(a){return a;};alb.Qgb=function Qgb(a){return a;};alb.Rgb=function Rgb(a){return a;};U1(329,1,{});Ykb.f_=w3(1);Ykb.r$=w3(0);Ykb.y$=w3(330);Ykb.v$=w3(236);Ykb.x$=w3(331);Ykb.w$=w3(237);Ykb.R$=w3(233);Ykb.T$=w3(158);Ykb.e_=w3(95);Ykb.U$=w3(234);Ykb.m_=w3(22);Ykb.W$=w3(15);Ykb.g_=w3(41);Ykb.Z$=w3(69);Ykb._$=w3(100);Ykb.c_=w3(62);Ykb.l_=w3(2);Ykb.k_=w3(179);Ykb.t0=w3(328);Ykb.u0=w3(329);blb.Nc=function Nc(a){var b,c,d,e,f,g,h,i,j,k,l,m,n,p,q,r,s,t,u,v,w,A,B,C,D,F,G,H,I,J,K,L,M,N,O,P,Q;this.c=a.length;this.d=a[0].length;G=$wnd.Math.min(this.c,this.d);this.e=gW(Ykb.yX,emb,6,$wnd.Math.min(this.c+1,this.d),15,1);this.a=eW(Ykb.yX,[Llb,emb],[12,6],15,[this.c,G],2);this.b=eW(Ykb.yX,[Llb,emb],[12,6],15,[this.d,this.d],2);e=gW(Ykb.yX,emb,6,this.d,15,1);Q=gW(Ykb.yX,emb,6,this.c,15,1);D=$wnd.Math.min(this.c-1,this.d);F=$wnd.Math.max(0,$wnd.Math.min(this.d-2,this.c));for(v=0;v<$wnd.Math.max(D,F);v++){if(v<D){this.e[v]=0;for(l=v;l<this.c;l++){this.e[v]=blb.Oc(this.e[v],a[l][v]);}if(this.e[v]!=0){a[v][v]<0&&(this.e[v]=-this.e[v]);for(k=v;k<this.c;k++){a[k][v]/=this.e[v];}a[v][v]+=1;}this.e[v]=-this.e[v];}for(q=v+1;q<this.d;q++){if(v<D&this.e[v]!=0){P=0;for(l=v;l<this.c;l++){P+=a[l][v]*a[l][q];}P=-P/a[v][v];for(k=v;k<this.c;k++){a[k][q]+=P*a[k][v];}}e[q]=a[v][q];}if(true&v<D){for(k=v;k<this.c;k++){this.a[k][v]=a[k][v];}}if(v<F){e[v]=0;for(l=v+1;l<this.d;l++){e[v]=blb.Oc(e[v],e[l]);}if(e[v]!=0){e[v+1]<0&&(e[v]=-e[v]);for(m=v+1;m<this.d;m++){e[m]/=e[v];}e[v+1]+=1;}e[v]=-e[v];if(v+1<this.c&e[v]!=0){for(m=v+1;m<this.c;m++){Q[m]=0;}for(r=v+1;r<this.d;r++){for(n=v+1;n<this.c;n++){Q[n]+=e[r]*a[n][r];}}for(s=v+1;s<this.d;s++){P=-e[s]/e[v+1];for(n=v+1;n<this.c;n++){a[n][s]+=P*Q[n];}}}for(k=v+1;k<this.d;k++){this.b[k][v]=e[k];}}}H=$wnd.Math.min(this.d,this.c+1);D<this.d&&(this.e[D]=a[D][D]);this.c<H&&(this.e[H-1]=0);F+1<H&&(e[F]=a[F][H-1]);e[H-1]=0;for(t=D;t<G;t++){for(k=0;k<this.c;k++){this.a[k][t]=0;}this.a[t][t]=1;}for(w=D-1;w>=0;w--){if(this.e[w]!=0){for(p=w+1;p<G;p++){P=0;for(l=w;l<this.c;l++){P+=this.a[l][w]*this.a[l][p];}P=-P/this.a[w][w];for(m=w;m<this.c;m++){this.a[m][p]+=P*this.a[m][w];}}for(n=w;n<this.c;n++){this.a[n][w]=-this.a[n][w];}this.a[w][w]=1+this.a[w][w];for(k=0;k<w-1;k++){this.a[k][w]=0;}}else {for(k=0;k<this.c;k++){this.a[k][w]=0;}this.a[w][w]=1;}}for(A=this.d-1;A>=0;A--){if(A<F&e[A]!=0){for(p=A+1;p<G;p++){P=0;for(l=A+1;l<this.d;l++){P+=this.b[l][A]*this.b[l][p];}P=-P/this.b[A+1][A];for(m=A+1;m<this.d;m++){this.b[m][p]+=P*this.b[m][A];}}}for(k=0;k<this.d;k++){this.b[k][A]=0;}this.b[A][A]=1;}I=H-1;h=$wnd.Math.pow(2,-52);while(H>0){for(u=H-2;u>=-1;u--){if(u==-1){break;}if($wnd.Math.abs(e[u])<=h*($wnd.Math.abs(this.e[u])+$wnd.Math.abs(this.e[u+1]))){e[u]=0;break;}}if(u==H-2){B=4;}else {for(C=H-1;C>=u;C--){if(C==u){break;}P=(C!=H?$wnd.Math.abs(e[C]):0)+(C!=u+1?$wnd.Math.abs(e[C-1]):0);if($wnd.Math.abs(this.e[C])<=h*P){this.e[C]=0;break;}}if(C==u){B=3;}else if(C==H-1){B=1;}else {B=2;u=C;}}++u;switch(B){case 1:{i=e[H-2];e[H-2]=0;for(p=H-2;p>=u;p--){P=blb.Oc(this.e[p],i);d=this.e[p]/P;M=i/P;this.e[p]=P;if(p!=u){i=-M*e[p-1];e[p-1]=d*e[p-1];}for(k=0;k<this.d;k++){P=d*this.b[k][p]+M*this.b[k][H-1];this.b[k][H-1]=-M*this.b[k][p]+d*this.b[k][H-1];this.b[k][p]=P;}}}break;case 2:{i=e[u-1];e[u-1]=0;for(p=u;p<H;p++){P=blb.Oc(this.e[p],i);d=this.e[p]/P;M=i/P;this.e[p]=P;i=-M*e[p];e[p]=d*e[p];for(k=0;k<this.c;k++){P=d*this.a[k][p]+M*this.a[k][u-1];this.a[k][u-1]=-M*this.a[k][p]+d*this.a[k][u-1];this.a[k][p]=P;}}}break;case 3:{J=$wnd.Math.max($wnd.Math.max($wnd.Math.max($wnd.Math.max($wnd.Math.abs(this.e[H-1]),$wnd.Math.abs(this.e[H-2])),$wnd.Math.abs(e[H-2])),$wnd.Math.abs(this.e[u])),$wnd.Math.abs(e[u]));N=this.e[H-1]/J;O=this.e[H-2]/J;g=e[H-2]/J;L=this.e[u]/J;f=e[u]/J;b=((O+N)*(O-N)+g*g)/2;c=N*g*(N*g);K=0;if(b!=0|c!=0){K=$wnd.Math.sqrt(b*b+c);b<0&&(K=-K);K=c/(b+K);}i=(L+N)*(L-N)+K;j=L*f;for(p=u;p<H-1;p++){P=blb.Oc(i,j);d=i/P;M=j/P;p!=u&&(e[p-1]=P);i=d*this.e[p]+M*e[p];e[p]=d*e[p]-M*this.e[p];j=M*this.e[p+1];this.e[p+1]=d*this.e[p+1];for(l=0;l<this.d;l++){P=d*this.b[l][p]+M*this.b[l][p+1];this.b[l][p+1]=-M*this.b[l][p]+d*this.b[l][p+1];this.b[l][p]=P;}P=blb.Oc(i,j);d=i/P;M=j/P;this.e[p]=P;i=d*e[p]+M*this.e[p+1];this.e[p+1]=-M*e[p]+d*this.e[p+1];j=M*e[p+1];e[p+1]=d*e[p+1];if(p<this.c-1){for(k=0;k<this.c;k++){P=d*this.a[k][p]+M*this.a[k][p+1];this.a[k][p+1]=-M*this.a[k][p]+d*this.a[k][p+1];this.a[k][p]=P;}}}e[H-2]=i;}break;case 4:{if(this.e[u]<=0){this.e[u]=this.e[u]<0?-this.e[u]:0;for(k=0;k<=I;k++){this.b[k][u]=-this.b[k][u];}}while(u<I){if(this.e[u]>=this.e[u+1]){break;}P=this.e[u];this.e[u]=this.e[u+1];this.e[u+1]=P;if(u<this.d-1){for(k=0;k<this.d;k++){P=this.b[k][u+1];this.b[k][u+1]=this.b[k][u];this.b[k][u]=P;}}if(u<this.c-1){for(k=0;k<this.c;k++){P=this.a[k][u+1];this.a[k][u+1]=this.a[k][u];this.a[k][u]=P;}}++u;}--H;}}}};blb.Oc=function Oc(a,b){var c;if($wnd.Math.abs(a)>$wnd.Math.abs(b)){c=b/a;c=$wnd.Math.abs(a)*$wnd.Math.sqrt(1+c*c);}else if(b!=0){c=a/b;c=$wnd.Math.abs(b)*$wnd.Math.sqrt(1+c*c);}else {c=0;}return c;};U1(156,1,fmb,blb.Nc);_.c=0;_.d=0;Ykb.CX=w3(156);clb.Qc=function Qc(){clb.Qc=W1;clb.Pc=oW(aW(Ykb.AX,1),gmb,6,15,[0,hmb,14286847,13402367,12779264,16758197,9474192,3166456,16715021,9494608,11789301,11230450,9109248,12560038,15780000,16744448,16777008,2093087,8442339,9388244,4062976,15132390,12567239,10921643,9083335,10255047,14706227,15765664,5296208,13140019,8224944,12750735,6721423,12419299,16752896,10889513,6076625,7351984,imb,9764863,9756896,7586505,5551541,3907230,2396047,687500,27013,12632256,16767375,10909043,6717568,10380213,13924864,9699476,4366000,5707663,51456,7394559,16777159,14286791,13107143,10747847,9437127,6422471,4587463,3211207,2097095,65436,58997,54354,48952,43812,5096191,5089023,2200790,2522539,2516630,1528967,13684960,16765219,12105936,10900557,5724513,10375093,11230208,7688005,4358806,4325478,32000,7384058,47871,41471,36863,33023,27647,5528818,7888099,9064419,10565332,11739092,11739066,11734438,12389767,13041766,13369433,13697103,14221381,14680120,15073326,15400998,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13158600,1334015,56540,15075850,15132160,56540,15075850,15461355,8553170,1016335,1016335,1334015,15132160,3289770,14456450,16422400,16422400,11819700,3289770,1016335]);};clb.Rc=function Rc(a){a.u=new plb.XF();};clb.Sc=function Sc(a){var b,c;if((a.D&32)!=0)return;c=clb.Jt(a.J);if(c!=null){if(a.v.a==0&&a.v.b==0){b=a.P.c*clb.vk(a.J);a.u=clb.Md(a);clb.bd(a,b);clb.Jd(a,null,b,0);}clb.Os(a,vX(a.w));a.J.O!=1&&clb.Kd(a,448);clb.Is(a,c,a.v.a,a.v.b+jmb*a.w);}};clb.Tc=function Tc(a,b){return a==null?b:b==null?a:a+','+b;};clb.Uc=function Uc(a){var b;b=a.P.c*clb.vk(a.J);a.W=b*0.06;a.R=b*0.15;a.Q=b*0.38;a.U=b*0.47;a.V=vX(b*a.H*0.6+0.5);a.T=b*0.12;a.X=b*0.4;a.w=b*0.5+0.5;};clb.Vc=function Vc(a){var b,c;a=e1(a,kmb);for(c=0;c<(olb.NF(),olb.MF).length;c++)if(o1(a,olb.MF[c]))return olb.LF[c];b=new Zkb.L5('R');z1(e1(a,lmb),0)&&(b.a+='0',b);z1(e1(a,mmb),0)&&(b.a+='3',b);z1(e1(a,nmb),0)&&(b.a+='4',b);z1(e1(a,omb),0)&&(b.a+='5',b);z1(e1(a,pmb),0)&&(b.a+='6',b);z1(e1(a,qmb),0)&&(b.a+='7',b);z1(e1(a,rmb),0)&&(b.a+='8',b);return b.a;};clb.Wc=function Wc(a,b,c,d){var e,f,g;e=new clb.Sd();f=new clb.Sd();e.a=b.a;e.c=b.c;e.b=(b.a+b.b)/2;e.d=(b.c+b.d)/2;f.a=e.b;f.c=e.d;f.b=b.b;f.d=b.d;if(clb.Gd(a,e)){clb.Kd(a,a.p[c]);g=smb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(e.a),(Blb.f8(),Blb.b8))))+tmb+umb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(e.c),Blb.b8)))+tmb+vmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(e.b),Blb.b8)))+tmb+wmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(e.d),Blb.b8)))+tmb+xmb+a.d+tmb+ymb+a.j+zmb;clb.Rs(a,g);}if(clb.Gd(a,f)){clb.Kd(a,a.p[d]);g=smb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(f.a),(Blb.f8(),Blb.b8))))+tmb+umb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(f.c),Blb.b8)))+tmb+vmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(f.b),Blb.b8)))+tmb+wmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(f.d),Blb.b8)))+tmb+xmb+a.d+tmb+ymb+a.j+zmb;clb.Rs(a,g);}clb.Kd(a,a.O);};clb.Xc=function Xc(a,b,c,d){var e,f,g,h,i,j,k,l,m;l=(b.b-b.a)/10;m=(b.d-b.c)/10;e=new clb.Sd();if(clb.cl(a.J,clb.tn(a.J,c,d))){f=-3;g=-3;}else {f=a.p[c];g=a.p[d];}clb.Kd(a,f);e.a=b.a;e.c=b.c;e.b=b.a+l*2;e.d=b.c+m*2;i=smb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(e.a),(Blb.f8(),Blb.b8))))+tmb+umb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(e.c),Blb.b8)))+tmb+vmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(e.b),Blb.b8)))+tmb+wmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(e.d),Blb.b8)))+tmb+xmb+a.d+tmb+ymb+a.j+zmb;clb.Rs(a,i);e.a=b.a+l*4;e.c=b.c+m*4;e.b=b.a+l*5;e.d=b.c+m*5;j=smb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(e.a),Blb.b8)))+tmb+umb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(e.c),Blb.b8)))+tmb+vmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(e.b),Blb.b8)))+tmb+wmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(e.d),Blb.b8)))+tmb+xmb+a.d+tmb+ymb+a.j+zmb;clb.Rs(a,j);clb.Kd(a,g);e.a=b.a+l*5;e.c=b.c+m*5;e.b=b.a+l*6;e.d=b.c+m*6;k=smb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(e.a),Blb.b8)))+tmb+umb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(e.c),Blb.b8)))+tmb+vmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(e.b),Blb.b8)))+tmb+wmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(e.d),Blb.b8)))+tmb+xmb+a.d+tmb+ymb+a.j+zmb;clb.Rs(a,k);e.a=b.a+l*8;e.c=b.c+m*8;e.b=b.b;e.d=b.d;h=smb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(e.a),Blb.b8)))+tmb+umb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(e.c),Blb.b8)))+tmb+vmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(e.b),Blb.b8)))+tmb+wmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(e.d),Blb.b8)))+tmb+xmb+a.d+tmb+ymb+a.j+zmb;clb.Rs(a,h);clb.Kd(a,a.O);};clb.Yc=function Yc(a,b,c){clb.Js(a,b-a.T/2,c-a.T/2,a.T);};clb.Zc=function Zc(a,b,c,d){var e;if(clb.cl(a.J,clb.tn(a.J,c,d))){clb.Kd(a,-3);e=smb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(b.a),(Blb.f8(),Blb.b8))))+tmb+umb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(b.c),Blb.b8)))+tmb+vmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(b.b),Blb.b8)))+tmb+wmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(b.d),Blb.b8)))+tmb+xmb+a.d+tmb+ymb+a.j+zmb;clb.Rs(a,e);clb.Kd(a,a.O);}else if(a.p[c]!=a.p[d]){clb.Wc(a,b,c,d);}else if(a.p[c]!=0){clb.Kd(a,a.p[c]);e=smb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(b.a),(Blb.f8(),Blb.b8))))+tmb+umb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(b.c),Blb.b8)))+tmb+vmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(b.b),Blb.b8)))+tmb+wmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(b.d),Blb.b8)))+tmb+xmb+a.d+tmb+ymb+a.j+zmb;clb.Rs(a,e);clb.Kd(a,a.O);}else {e=smb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(b.a),(Blb.f8(),Blb.b8))))+tmb+umb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(b.c),Blb.b8)))+tmb+vmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(b.b),Blb.b8)))+tmb+wmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(b.d),Blb.b8)))+tmb+xmb+a.d+tmb+ymb+a.j+zmb;clb.Rs(a,e);}};clb.$c=function $c(a,b,c,d,e,f,g){g.a=b.a+e;g.c=b.c+f;g.b=b.b+e;g.d=b.d+f;clb.Zc(a,g,c,d);};clb._c=function _c(a,b,c,d){var e,f,g,h,i,j,k,l,m,n,o,p;l=b.b-b.a;o=b.d-b.c;i=$wnd.Math.sqrt(l*l+o*o);j=2*I1(p1($wnd.Math.round(i/(4*a.W))));m=l/(j-1);p=o/(j-1);if(clb.cl(a.J,clb.tn(a.J,c,d))){e=-3;f=-3;}else {e=a.p[c];f=a.p[d];}k=b.a-a.W/2;n=b.c-a.W/2;clb.Kd(a,e);for(h=0;h<(j/2|0);h++){clb.Js(a,k,n,a.W);k+=m;n+=p;}clb.Kd(a,f);for(g=0;g<(j/2|0);g++){clb.Js(a,k,n,a.W);k+=m;n+=p;}clb.Kd(a,a.O);};clb.ad=function ad(a,b,c,d){var e,f,g,h,i,j,k,l,m,n,o,p,q,r;i=(b.c-b.d)/9;n=(b.b-b.a)/9;j=b.b+i;o=b.d+n;k=b.b-i;p=b.d-n;l=(b.a+j)/2;q=(b.c+o)/2;m=(b.a+k)/2;r=(b.c+p)/2;g=new plb.SF(3);h=new plb.SF(4);plb.RF(g,b.a,b.c);plb.RF(g,l,q);plb.RF(g,m,r);plb.RF(h,m,r);plb.RF(h,l,q);plb.RF(h,j,o);plb.RF(h,k,p);if(clb.cl(a.J,clb.tn(a.J,c,d))){e=-3;f=-3;}else {e=a.p[c];f=a.p[d];if(a.J.O!=1){f=clb.ed(a,c);e==clb.ek(a.J,c)&&(e=f);}}clb.Kd(a,e);clb.Hs(a,g);clb.Kd(a,f);clb.Hs(a,h);clb.Kd(a,a.O);};clb.bd=function bd(a,b){var c,d;for(d=0;d<a.Y.a.length;d++)a.u=plb.WF(a.u,dlb.Bi(a.Y,d));clb.cd(a,b);c=0.1*b;a.u.c-=c;a.u.d-=c;a.u.b+=2*c;a.u.a+=2*c;};clb.cd=function cd(a,b){var c,d,e,f,g,h,i;e=gW(Ykb.Z0,Amb,6,a.J.q,16,1);for(d=0;d<a.J.r;d++){if(clb.al(a.J,d)){e[clb.zk(a.J,0,d)]=true;e[clb.zk(a.J,1,d)]=true;}}g=new plb.XF();for(c=0;c<a.J.q;c++){f=z1(e1(clb.pk(a.J,c),Bmb),0)?b*0.47:e[c]?b*0.38:0;if(f!=0){h=clb.Mh(a.P,clb.rk(a.J,c));i=clb.Nh(a.P,clb.sk(a.J,c));plb.VF(g,h-f,i-f,f*2,f*2);a.u=plb.WF(a.u,g);}}};clb.dd=function dd(a,b){var c;c=a.K!=0?a.K:a.B!=0?a.B:-1;return slb.FT(b,c);};clb.ed=function ed(a,b){var c,d;if((a.D&4224)!=0)return a.p[b];d=clb.fd(a,b);if(d==-1){c=clb.an(a.J,b);if(c!=-1){b=c;d=clb.fd(a,b);}}if(d==-1)return a.p[b];switch(d&255){case 1:return 384;case 2:return 64;default:return 448;}};clb.fd=function fd(a,b){var c,d,e;e=-1;d=-1;if((a.D&128)!=0)return e;if(clb.$k(a.J,b)){e=clb.ik(a.J,b);d=clb.hk(a.J,b);}c=clb.cn(a.J,b);if(c!=-1){e=clb.Ek(a.J,c);d=clb.Dk(a.J,c);}e!=-1&&e!=0&&(e|=d<<8);return e;};clb.gd=function gd(a){var b,c,d,e,f;clb.Ms(a,2*a.Q);e=new clb.Sd();for(d=0;d<a.J.r;d++){b=clb.zk(a.J,0,d);c=clb.zk(a.J,1,d);if(clb.al(a.J,d)){e.a=clb.Mh(a.P,clb.rk(a.J,b));e.c=clb.Nh(a.P,clb.sk(a.J,b));e.b=clb.Mh(a.P,clb.rk(a.J,c));e.d=clb.Nh(a.P,clb.sk(a.J,c));clb.Kd(a,-2);f=smb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(e.a),(Blb.f8(),Blb.b8))))+tmb+umb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(e.c),Blb.b8)))+tmb+vmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(e.b),Blb.b8)))+tmb+wmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(e.d),Blb.b8)))+tmb+xmb+a.d+tmb+ymb+a.j+zmb;clb.Rs(a,f);}}};clb.hd=function hd(a){var b,c,d,e,f,g,h;if(a.J.K){g=a.U;clb.Kd(a,-7);for(b=0;b<a.J.f;b++)z1(e1(clb.pk(a.J,b),Bmb),0)&&clb.Js(a,clb.Mh(a.P,clb.rk(a.J,b))-g,clb.Nh(a.P,clb.sk(a.J,b))-g,2*g);clb.Ms(a,2*a.U);f=new clb.Sd();for(e=0;e<a.J.r;e++){c=clb.zk(a.J,0,e);d=clb.zk(a.J,1,e);if(z1(e1(e1(clb.pk(a.J,c),clb.pk(a.J,d)),Bmb),0)){f.a=clb.Mh(a.P,clb.rk(a.J,c));f.c=clb.Nh(a.P,clb.sk(a.J,c));f.b=clb.Mh(a.P,clb.rk(a.J,d));f.d=clb.Nh(a.P,clb.sk(a.J,d));h=smb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(f.a),(Blb.f8(),Blb.b8))))+tmb+umb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(f.c),Blb.b8)))+tmb+vmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(f.b),Blb.b8)))+tmb+wmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(f.d),Blb.b8)))+tmb+xmb+a.d+tmb+ymb+a.j+zmb;clb.Rs(a,h);}}}};clb.jd=function jd(a){var b,c,d,e;if(a.J.K){clb.Kd(a,320);if((a.D&8)!=0)for(b=0;b<a.J.f;b++)z1(e1(clb.pk(a.J,b),-536870913),0)&&clb.Js(a,clb.Mh(a.P,clb.rk(a.J,b))-a.X/2,clb.Nh(a.P,clb.sk(a.J,b))-a.X/2,a.X);for(e=0;e<a.J.g;e++){if(clb.Jk(a.J,e)!=0){c=clb.zk(a.J,0,e);d=clb.zk(a.J,1,e);clb.Js(a,(clb.Mh(a.P,clb.rk(a.J,c))+clb.Mh(a.P,clb.rk(a.J,d))-a.X)/2,(clb.Nh(a.P,clb.sk(a.J,c))+clb.Nh(a.P,clb.sk(a.J,d))-a.X)/2,a.X);}}}};clb.kd=function kd(a){a.H=1;a.P=new clb.Oh();a.Y=new dlb.Qi();a.S=new dlb.Qi();a.r=gW(Ykb.Z0,Amb,6,a.J.q,16,1);a.v=new plb.OF();a.O=0;a.A=-1;clb.Od(a);};clb.ld=function ld(a,b){var c;if(clb.gn(a.J,b)==0)return false;for(c=0;c<clb.gn(a.J,b);c++)if(!clb.cl(a.J,clb.xn(a.J,b,c)))return false;return true;};clb.md=function md(a){var b;a.q=gW(Ykb.Z0,Amb,6,a.J.q,16,1);for(b=0;b<a.J.r;b++){a.q[clb.zk(a.J,0,b)]=true;a.q[clb.zk(a.J,1,b)]=true;}};clb.nd=function nd(a,b){var c;if(clb.wn(a.J,b)!=2)return false;for(c=0;c<2;c++)if(clb.yn(a.J,b,c)!=2)return false;return true;};clb.od=function od(a,b,c,d,e){var f,g,h,i,j,k,l,m,n,o;m=false;e.a=0;e.b=0;d>0?f=Cmb:f=Dmb;o=clb.yk(a.J,b,c);for(k=0;k<clb.wn(a.J,b);k++){g=clb.xn(a.J,b,k);h=o;clb.zk(a.J,0,g)==b?l=clb.zk(a.J,1,g):l=clb.zk(a.J,0,g);if(l==c)continue;n=clb.yk(a.J,b,l);h<n&&(h+=Emb);i=h-n;if(d>0){i<Fmb&&(m=true);i>Cmb&&(i=Cmb);i<0.523598776&&(i=0.523598776);if(i<=f){f=i;j=a.R*$wnd.Math.tan(f-Gmb)/2;e.a=-(j*$wnd.Math.sin(h));e.b=-(j*$wnd.Math.cos(h));}}else {i>=Fmb&&(m=true);i<Dmb&&(i=Dmb);i>5.759586531&&(i=5.759586531);if(i>=f){f=i;j=a.R*$wnd.Math.tan(4.712388981-f)/2;e.a=-(j*$wnd.Math.sin(h));e.b=-(j*$wnd.Math.cos(h));}}}return m;};clb.pd=function pd(a,b,c,d){var e;if(b==0){c<0?d.a=a.R:d.a=-a.R;d.b=0;return;}e=$wnd.Math.atan(c/b);b<0&&(e+=Fmb);d.a=-(a.R*$wnd.Math.sin(e));d.b=a.R*$wnd.Math.cos(e);};clb.qd=function qd(a,b,c,d){var e,f,g,h,i,j,k,l,m,n,o,p;e=new clb.Sd();i=new clb.Sd();k=new plb.OF();j=new plb.OF();g=clb.zk(a.J,0,c);h=clb.zk(a.J,1,c);if(d){m=b.a;b.a=b.b;b.b=m;m=b.c;b.c=b.d;b.d=m;n=g;g=h;h=n;}if(!clb.Gd(a,b))return;if(clb.zo(a.J,c)){e.a=b.a;e.c=b.c;e.b=b.b;e.d=b.d;l=d?-clb.Wn(a.J,c):clb.Wn(a.J,c);l==0&&(l=1);clb.pd(a,b.b-b.a,b.d-b.c,k);if(l>0){i.a=b.a+k.a;i.c=b.c+k.b;i.b=b.b+k.a;i.d=b.d+k.b;if(clb.od(a,g,h,1,j)||clb.wn(a.J,g)>1){i.a+=j.a+k.b;i.c+=j.b-k.a;}}else {i.a=b.a-k.a;i.c=b.c-k.b;i.b=b.b-k.a;i.d=b.d-k.b;if(clb.od(a,g,h,-1,j)||clb.wn(a.J,g)>1){i.a+=j.a+k.b;i.c+=j.b-k.a;}}clb.Kk(a.J,c)==386&&clb.Fd(e,i);clb.Gd(a,e)&&clb.Zc(a,e,g,h);clb.Kk(a.J,c)==64?clb.Gd(a,i)&&clb.Xc(a,i,g,h):clb.Gd(a,i)&&clb.Zc(a,i,g,h);}else {clb.pd(a,b.b-b.a,b.d-b.c,k);o=k.a/2;p=k.b/2;f=false;e.a=b.a+o;e.c=b.c+p;e.b=b.b+o;e.d=b.d+p;if(clb.wn(a.J,g)>1){if(clb.od(a,g,h,1,j)){e.a+=j.a;e.c+=j.b;if(clb.wn(a.J,g)==2){if(j.a!=0||j.b!=0){e.a+=k.b;e.c-=k.a;}}}else {a.o[g]=new plb.PF(e.a,e.c);}}i.a=b.a-o;i.c=b.c-p;i.b=b.b-o;i.d=b.d-p;if(clb.wn(a.J,g)>1){if(clb.od(a,g,h,0,j)){i.a+=j.a;i.c+=j.b;if(clb.wn(a.J,g)==2){if(j.a!=0||j.b!=0){i.a+=k.b;i.c-=k.a;}}}else {a.o[g]=new plb.PF(i.a,i.c);f=true;}}clb.Kk(a.J,c)==386&&clb.Fd(e,i);if(clb.Kk(a.J,c)==64){if(f){clb.Xc(a,e,g,h);clb.Zc(a,i,g,h);}else {clb.Zc(a,e,g,h);clb.Xc(a,i,g,h);}}else {clb.Zc(a,e,g,h);clb.Zc(a,i,g,h);}}};clb.rd=function rd(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o;k=a.O;l=a.C;if((a.D&Hmb)!=0){a.O=-6;a.C=-8355712;clb.Kd(a,1);}a.o=gW(Ykb.QZ,Ulb,50,a.J.q,0,1);for(i=0;i<a.J.r;i++)(clb.Kk(a.J,i)==2||clb.Kk(a.J,i)==386||clb.Kk(a.J,i)==64)&&clb.ud(a,i);for(j=0;j<a.J.r;j++)clb.Kk(a.J,j)!=2&&clb.Kk(a.J,j)!=386&&clb.Kk(a.J,j)!=64&&clb.ud(a,j);if((a.D&64)==0){for(h=0;h<a.J.r;h++){if(clb.Ck(a.J,h)!=0){e=null;clb.Ck(a.J,h)==1||clb.Ck(a.J,h)==2?(clb.Hk(a.J,h)==2||clb.Ek(a.J,h)==0||b[clb.Ek(a.J,h)][clb.Dk(a.J,h)]>1)&&(clb.Ck(a.J,h)==1?e=clb.Hk(a.J,h)==2?'E':clb.el(a.J,h)?'p':'P':e=clb.Hk(a.J,h)==2?'Z':clb.el(a.J,h)?'m':'M'):e='?';if(e!=null){clb.Os(a,(a.V*2+1)/3|0);clb.Kd(a,clb.cl(a.J,h)?-3:a.J.O==1||(a.D&Imb)!=0?a.O:448);c=clb.zk(a.J,0,h);d=clb.zk(a.J,1,h);n=(clb.Mh(a.P,clb.rk(a.J,c))+clb.Mh(a.P,clb.rk(a.J,d)))/2;o=(clb.Nh(a.P,clb.sk(a.J,c))+clb.Nh(a.P,clb.sk(a.J,d)))/2;f=(clb.Mh(a.P,clb.rk(a.J,c))-clb.Mh(a.P,clb.rk(a.J,d)))/3;g=(clb.Nh(a.P,clb.sk(a.J,c))-clb.Nh(a.P,clb.sk(a.J,d)))/3;clb.xd(a,n+g,o-f,e,true);clb.Kd(a,a.O);clb.Os(a,a.V);}}}}if((a.D&4)!=0){clb.Os(a,(a.V*2+1)/3|0);clb.Kd(a,384);for(h=0;h<a.J.r;h++){c=clb.zk(a.J,0,h);d=clb.zk(a.J,1,h);m=clb.qo(a.J,h)?'d':clb.mo(a.J,h)?'a':'';n=(clb.Mh(a.P,clb.rk(a.J,c))+clb.Mh(a.P,clb.rk(a.J,d)))/2;o=(clb.Nh(a.P,clb.sk(a.J,c))+clb.Nh(a.P,clb.sk(a.J,d)))/2;clb.xd(a,n,o,m+(''+h),true);}clb.Kd(a,a.O);clb.Os(a,a.V);}if((a.D&Hmb)!=0){a.O=k;a.C=l;}};clb.sd=function sd(a){var b,c;for(c=new dlb.Obb(a.S);c.a<c.c.a.length;){b=dlb.Nbb(c);clb.Kd(a,b.a);clb.Yc(a,b.b,b.c);}clb.Kd(a,a.O);};clb.td=function td(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z,$;a.I||clb.Ks(a,b,(clb.jk(a.J,b),clb.Mh(a.P,clb.rk(a.J,b))),clb.Nh(a.P,clb.sk(a.J,b)));M=null;if(clb.dk(a.J,b)!=0){U=$wnd.Math.abs(clb.dk(a.J,b))==1?'':''+$wnd.Math.abs(clb.dk(a.J,b));M=clb.dk(a.J,b)<0?U+'-':U+'+';}D=null;N=clb.pk(a.J,b);if(j1(N,0)!=0){z1(e1(N,Jmb),0)&&(D=D==null?'*':D+','+'*');z1(e1(N,Kmb),0)&&(D=D==null?'!*':D+','+'!*');z1(e1(N,Lmb),0)?D=D==null?'ha':D+','+'ha':z1(e1(N,2),0)?D=D==null?'a':D+','+'a':z1(e1(N,4),0)&&(D=D==null?'!a':D+','+'!a');z1(e1(N,Imb),0)&&(D=D==null?'s':D+','+'s');if(z1(e1(N,Mmb),0)){w=e1(N,Mmb);j1(w,1792)==0?D=D==null?'h0':D+','+'h0':j1(w,1664)==0?D=D==null?'h1':D+','+'h1':j1(w,1408)==0?D=D==null?'h2':D+','+'h2':j1(w,128)==0?D=D==null?'h>0':D+','+'h>0':j1(w,384)==0?D=D==null?'h>1':D+','+'h>1':j1(w,896)==0?D=D==null?'h>2':D+','+'h>2':j1(w,Nmb)==0?D=D==null?'h<3':D+','+'h<3':j1(w,1536)==0&&(D=D==null?'h<2':D+','+'h<2');}if(z1(e1(N,Omb),0)){i=e1(N,Omb);j1(i,Pmb)==0?D=D==null?'c0':D+','+'c0':j1(i,Qmb)==0?D=D==null?'c+':D+','+'c+':j1(i,Rmb)==0&&(D=D==null?'c-':D+','+'c-');}if(z1(e1(N,Smb),0)){L=e1(N,Smb);j1(L,98304)==0?D=D==null?'pi0':D+','+'pi0':j1(L,81920)==0?D=D==null?'pi1':D+','+'pi1':j1(L,49152)==0?D=D==null?'pi2':D+','+'pi2':j1(L,Hmb)==0&&(D=D==null?'pi>0':D+','+'pi>0');}if(z1(e1(N,Tmb),0)){K=e1(N,Tmb);j1(K,3801088)==0?D=D==null?'n1':D+','+'n1':j1(K,Umb)==0?D=D==null?'n2':D+','+'n2':j1(K,Vmb)==0?D=D==null?'n3':D+','+'n3':j1(K,3145728)==0?D=D==null?'n<3':D+','+'n<3':j1(K,Wmb)==0?D=D==null?'n<4':D+','+'n<4':j1(K,Xmb)==0?D=D==null?'n>1':D+','+'n>1':j1(K,Ymb)==0?D=D==null?'n>2':D+','+'n>2':j1(K,Zmb)==0&&(D=D==null?'n>3':D+','+'n>3');}if(z1(e1(N,$mb),0)){o=e1(N,$mb);j1(o,_mb)==0?D=D==null?'e0':D+','+'e0':j1(o,anb)==0?D=D==null?'e1':D+','+'e1':j1(o,bnb)==0?D=D==null?'e2':D+','+'e2':j1(o,cnb)==0?D=D==null?'e3':D+','+'e3':j1(o,15393162788864)==0?D=D==null?'e<2':D+','+'e<2':j1(o,13194139533312)==0?D=D==null?'e<3':D+','+'e<3':j1(o,dnb)==0?D=D==null?'e<4':D+','+'e<4':j1(o,enb)==0?D=D==null?'e>0':D+','+'e>0':j1(o,fnb)==0?D=D==null?'e>1':D+','+'e>1':j1(o,gnb)==0?D=D==null?'e>2':D+','+'e>2':j1(o,hnb)==0?D=D==null?'e>3':D+','+'e>3':j1(o,4947802324992)==0?D=D==null?'e1-2':D+','+'e1-2':j1(o,9345848836096)==0?D=D==null?'e1-3':D+','+'e1-3':j1(o,10445360463872)==0&&(D=D==null?'e2-3':D+','+'e2-3');}if(z1(e1(N,120),0)){Q=e1(N,120);j1(Q,112)==0?D=D==null?'!r':D+','+'!r':j1(Q,8)==0?D=D==null?'r':D+','+'r':j1(Q,96)==0?D=D==null?'rb<3':D+','+'rb<3':j1(Q,104)==0?D=D==null?'rb2':D+','+'rb2':j1(Q,88)==0?D=D==null?'rb3':D+','+'rb3':j1(Q,56)==0&&(D=D==null?'rb4':D+','+'rb4');}z1(e1(N,inb),0)&&(D=D==null?'r'+J1(D1(e1(N,inb),22)):D+','+('r'+J1(D1(e1(N,inb),22))));z1(e1(N,kmb),0)&&(D=clb.Tc(D,clb.Vc(N)));z1(e1(N,jnb),0)&&(D=D==null?'f':D+','+'f');}clb.nk(a.J,b)!=0&&(D=clb.Tc(D,''+clb.nk(a.J,b)));T=0;if(clb.qk(a.J,b)!=0){switch(clb.qk(a.J,b)){case 16:M=M==null?'|':M+','+'|';break;case 32:T=1;break;case 48:T=2;}}l=null;if((a.D&64)==0){if(clb.Xk(a.J,b))l='?';else if(clb.ck(a.J,b)!=0){if(clb.ik(a.J,b)==0||c==null||c[clb.ik(a.J,b)][clb.hk(a.J,b)]>1){if(clb.wn(a.J,b)==2){switch(clb.ck(a.J,b)){case 2:l=clb.Zk(a.J,b)?'p':'P';break;case 1:l=clb.Zk(a.J,b)?'m':'M';break;default:l='*';}}else {switch(clb.ck(a.J,b)){case 1:l=clb.Zk(a.J,b)?'r':'R';break;case 2:l=clb.Zk(a.J,b)?'s':'S';break;default:l='*';}}}}}(a.D&768)!=0&&(l=clb.Tc(l,''+clb.Rt(a.J,b)));I=null;(a.D&16)!=0&&clb.mk(a.J,b)!=0&&(I=''+clb.mk(a.J,b));q=null;if(clb._n(a.J,b)!=-1){p=clb.fd(a,b);p!=-1&&(q=p==0?'abs':((p&255)==1?'&':'or')+(1+(p>>8)));}A=0;(a.D&knb)==0&&(a.J.K?z1(e1(clb.pk(a.J,b),lnb),0)&&(A=clb.Kn(a.J,b)):(clb.uk(a.J,b)!=6||clb.nk(a.J,b)!=0||!a.q[b]||clb.qk(a.J,b)!=0)&&(A=clb.Kn(a.J,b)));H=false;f=clb.fk(a.J,b);if(f!=null&&Zkb.c5(alb.Pgb(f).substr(0,1),']')){D=clb.Tc((alb.Kgb(1,alb.Pgb(f).length+1),alb.Pgb(f).substr(1)),D);f=null;H=true;}if(f!=null){A=0;}else if(clb.kk(a.J,b)!=null){e=z1(e1(clb.pk(a.J,b),1),0)?'[!':'[';f=e+clb.lk(a.J,b)+']';alb.Pgb(f).length>5&&(f=e+clb.kk(a.J,b).length+']');z1(e1(clb.pk(a.J,b),lnb),0)&&(A=-1);}else if(z1(e1(clb.pk(a.J,b),1),0)){f='?';z1(e1(clb.pk(a.J,b),lnb),0)&&(A=-1);}else (clb.uk(a.J,b)!=6||M!=null||D!=null||A>0||!a.q[b])&&(f=clb.jk(a.J,b));G=0;!clb.nl(a.J,b)&z1(e1(clb.pk(a.J,b),Bmb),0)&&clb.Kd(a,-8);if(f!=null){G=(O=(V=ylb.h2(a.e,f),new zlb.n2(V)).b,O);clb.xd(a,clb.Mh(a.P,clb.rk(a.J,b)),clb.Nh(a.P,clb.sk(a.J,b)),f,true);a.r[b]=true;}else clb.nd(a,b)&&clb.wd(a,clb.Mh(a.P,clb.rk(a.J,b)),clb.Nh(a.P,clb.sk(a.J,b)),b);if(M!=null){clb.Os(a,(a.V*2+1)/3|0);X=clb.Mh(a.P,clb.rk(a.J,b))+((G+(O=(V=ylb.h2(a.e,M),new zlb.n2(V)).b,O))/2+1);Z=clb.Nh(a.P,clb.sk(a.J,b))-((a.k*4-4)/8|0);clb.xd(a,X,Z,M,true);clb.Os(a,a.V);}(a.D&2)!=0&&(D=''+b);if(D!=null){H?clb.Os(a,(a.V*5+1)/6|0):clb.Os(a,(a.V*2+1)/3|0);X=clb.Mh(a.P,clb.rk(a.J,b))-(G+(O=(V=ylb.h2(a.e,D),new zlb.n2(V)).b,O))/2;Z=clb.Nh(a.P,clb.sk(a.J,b))-((a.k*4-4)/8|0);clb.xd(a,X,Z,D,true);clb.Os(a,a.V);}if(l!=null){clb.Os(a,(a.V*2+1)/3|0);X=clb.Mh(a.P,clb.rk(a.J,b))-(G+(O=(V=ylb.h2(a.e,l),new zlb.n2(V)).b,O))/2;Z=clb.Nh(a.P,clb.sk(a.J,b))+((a.k*4+4)/8|0);S=a.A;a.J.O!=1&&(a.D&Imb)==0&&clb.Kd(a,448);clb.xd(a,X,Z,l,false);clb.Kd(a,S);clb.Os(a,a.V);}if(I!=null){clb.Os(a,(a.V*2+1)/3|0);X=clb.Mh(a.P,clb.rk(a.J,b))+((G+(O=(V=ylb.h2(a.e,I),new zlb.n2(V)).b,O))/2+1);Z=clb.Nh(a.P,clb.sk(a.J,b))+((a.k*4+4)/8|0);S=a.A;clb.Kd(a,clb._k(a.J,b)?384:448);clb.xd(a,X,Z,I,true);clb.Kd(a,S);clb.Os(a,a.V);}if(q!=null){d=clb.Bd(a,b);clb.Os(a,(a.V*2+1)/3|0);X=clb.Mh(a.P,clb.rk(a.J,b))+0.7*a.k*$wnd.Math.sin(d);Z=clb.Nh(a.P,clb.sk(a.J,b))+0.7*a.k*$wnd.Math.cos(d);S=a.A;!a.I&&a.J.O!=1&&clb.Kd(a,clb.ed(a,b));clb.xd(a,X,Z,q,false);clb.Kd(a,S);clb.Os(a,a.V);}if(A==0&&T==0){a.A==-8&&clb.Kd(a,-9);return;}u=gW(Ykb.yX,emb,6,4,15,1);for(C=0;C<clb.hn(a.J,b);C++){h=clb.xn(a.J,b,C);for(F=0;F<2;F++){if(clb.zk(a.J,F,h)==b){R=clb.yk(a.J,clb.zk(a.J,F,h),clb.zk(a.J,1-F,h));if(R<mnb){u[0]-=R+Gmb;u[3]+=R+Fmb;}else if(R<0){u[2]+=R+Gmb;u[3]-=R;}else if(R<Gmb){u[1]+=R;u[2]+=Gmb-R;}else {u[0]+=R-Gmb;u[1]+=Fmb-R;}}}}clb.wn(a.J,b)==0?clb.gl(a.J,b)?u[3]-=0.2:u[1]-=0.2:u[1]-=0.1;(M!=null||I!=null)&&(u[1]+=10);(D!=null||l!=null)&&(u[3]+=10);s='';if(A!=0){v=(P=(W=ylb.h2(a.e,'H'),new zlb.n2(W)).b,P);t=0;r=a.k;if(A==-1){s='n';clb.Os(a,(a.V*2+1)/3|0);t=(O=(V=ylb.h2(a.e,s),new zlb.n2(V)).b,O);}else if(A>1){s=''+A;clb.Os(a,(a.V*2+1)/3|0);t=(O=(V=ylb.h2(a.e,s),new zlb.n2(V)).b,O);}if(u[1]<0.6||u[3]<0.6){k=clb.Nh(a.P,clb.sk(a.J,b));if(u[1]<=u[3]){u[1]+=10;j=clb.Mh(a.P,clb.rk(a.J,b))+(G+v)/2;}else {u[3]+=10;j=clb.Mh(a.P,clb.rk(a.J,b))-(G+v)/2-t;}}else {j=clb.Mh(a.P,clb.rk(a.J,b));if(u[0]<u[2]){u[0]+=10;k=clb.Nh(a.P,clb.sk(a.J,b))-r;}else {u[2]+=10;k=clb.Nh(a.P,clb.sk(a.J,b))+r;}}if(t>0){X=j+(v+t)/2;Z=k+((a.k*4+4)/8|0);clb.xd(a,X,Z,s,true);clb.Os(a,a.V);}clb.xd(a,j,k,'H',true);}g=0;if(T!=0){J=50;m=0;for(B=0;B<4;B++){n=B>1?B-2:B+2;if(u[B]<J){g=B;J=u[B];m=u[n];}else if(u[B]==J){if(u[n]>m){g=B;m=u[n];}}}switch(g){case 0:j=clb.Mh(a.P,clb.rk(a.J,b));k=clb.Nh(a.P,clb.sk(a.J,b))-a.T-G/2;break;case 1:j=clb.Mh(a.P,clb.rk(a.J,b))+a.T+G/2;k=clb.Nh(a.P,clb.sk(a.J,b));break;case 2:j=clb.Mh(a.P,clb.rk(a.J,b));k=clb.Nh(a.P,clb.sk(a.J,b))+a.T+G/2;break;default:j=clb.Mh(a.P,clb.rk(a.J,b))-a.T-G/2;k=clb.Nh(a.P,clb.sk(a.J,b));}if(T==1){dlb.wi(a.Y,new plb.YF(j-a.T,k-a.T,2*a.T,2*a.T));a.I||dlb.wi(a.S,new clb.Rd(j,k,clb.ld(a,b)?-3:a.p[b]));}else {switch(g){case 2:case 0:Y=2*a.T;$=0;j-=a.T;break;case 1:Y=0;$=2*a.T;k-=a.T;break;default:Y=0;$=2*a.T;k-=a.T;}dlb.wi(a.Y,new plb.YF(j-a.T,k-a.T,2*a.T,2*a.T));a.I||dlb.wi(a.S,new clb.Rd(j,k,clb.ld(a,b)?-3:a.p[b]));dlb.wi(a.Y,new plb.YF(j+Y-a.T,k+$-a.T,2*a.T,2*a.T));a.I||dlb.wi(a.S,new clb.Rd(j+Y,k+$,clb.ld(a,b)?-3:a.p[b]));}}a.A==-8&&clb.Kd(a,-9);};clb.ud=function ud(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w;u=new clb.Sd();c=new clb.Sd();g=new clb.Sd();q=new plb.OF();p=new plb.OF();e=clb.zk(a.J,0,b);f=clb.zk(a.J,1,b);clb.Ls(a,b,clb.Mh(a.P,clb.rk(a.J,e)),clb.Nh(a.P,clb.sk(a.J,e)),clb.Mh(a.P,clb.rk(a.J,f)),clb.Nh(a.P,clb.sk(a.J,f)));!clb.nl(a.J,e)&&!clb.nl(a.J,f)&&z1(e1(B1(clb.pk(a.J,e),clb.pk(a.J,f)),Bmb),0)&&clb.Kd(a,-8);if(!a.o[e]){u.a=clb.Mh(a.P,clb.rk(a.J,e));u.c=clb.Nh(a.P,clb.sk(a.J,e));}else {u.a=a.o[e].a;u.c=a.o[e].b;}if(!a.o[f]){u.b=clb.Mh(a.P,clb.rk(a.J,f));u.d=clb.Nh(a.P,clb.sk(a.J,f));}else {u.b=a.o[f].a;u.d=a.o[f].b;}if((clb.Jk(a.J,b)&nnb)!=0){clb.Gd(a,u)&&clb.Gs(a,u);clb.Kd(a,-9);return;}h=clb.Kk(a.J,b)==64?0:clb.Kk(a.J,b)==32?1:clb.Hk(a.J,b);switch(h){case 1:i=clb.Kk(a.J,b);if((a.D&128)!=0&&(i==257||i==129)){t=clb.zk(a.J,0,b);n=clb.ik(a.J,t);if(n!=0){m=clb.hk(a.J,t);l=0;for(d=0;d<a.J.f;d++)clb.ik(a.J,d)==n&&clb.hk(a.J,d)==m&&++l;l==1&&(i=1);}}switch(i){case 1:clb.Gd(a,u)&&clb.Zc(a,u,e,f);break;case 257:clb.Dd(a,u,e,f);break;case 129:v=u.b-u.a;w=u.d-u.c;if(clb.cl(a.J,clb.tn(a.J,e,f))){j=-3;k=-3;}else {j=a.p[e];k=clb.ed(a,e);j==clb.ek(a.J,e)&&(j=k);}for(o=2;o<17;o+=2){c.a=u.a+o*v/17-o*w/128;c.c=u.c+o*w/17+o*v/128;c.b=u.a+o*v/17+o*w/128;c.d=u.c+o*w/17-o*v/128;if(clb.Gd(a,c)){clb.Kd(a,o<9?j:k);r=smb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(c.a),(Blb.f8(),Blb.b8))))+tmb+umb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(c.c),Blb.b8)))+tmb+vmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(c.b),Blb.b8)))+tmb+wmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(c.d),Blb.b8)))+tmb+xmb+a.d+tmb+ymb+a.j+zmb;clb.Rs(a,r);clb.Kd(a,a.O);}}break;case 32:clb.Gd(a,u)&&clb._c(a,u,e,f);}break;case 0:case 2:if((a.r[e]||clb.mn(a.J,e)==2)&&(a.r[f]||clb.mn(a.J,f)==2)&&!clb.zo(a.J,b)&&h==2){if(!clb.Gd(a,u))break;clb.pd(a,u.b-u.a,u.d-u.c,q);v=q.a/2;w=q.b/2;c.a=u.a+v;c.c=u.c+w;c.b=u.b+v;c.d=u.d+w;g.a=u.a-v;g.c=u.c-w;g.b=u.b-v;g.d=u.d-w;clb.Kk(a.J,b)==386&&clb.Fd(c,g);clb.Zc(a,c,e,f);h==2?clb.Zc(a,g,e,f):clb.Xc(a,g,e,f);}else if((a.r[f]||clb.mn(a.J,f)==2)&&h==2){clb.qd(a,u,b,false);}else if((a.r[e]||clb.mn(a.J,e)==2)&&h==2){clb.qd(a,u,b,true);}else {s=clb.Wn(a.J,b);s==0&&(s=1);c.a=u.a;c.c=u.c;c.b=u.b;c.d=u.d;clb.pd(a,u.b-u.a,u.d-u.c,q);if(s>0){g.a=u.a+q.a;g.c=u.c+q.b;g.b=u.b+q.a;g.d=u.d+q.b;if(clb.od(a,e,f,1,p)||clb.wn(a.J,e)>1){g.a+=p.a+q.b;g.c+=p.b-q.a;}if(clb.od(a,f,e,-1,p)||clb.wn(a.J,f)>1){g.b+=p.a-q.b;g.d+=p.b+q.a;}}else {g.a=u.a-q.a;g.c=u.c-q.b;g.b=u.b-q.a;g.d=u.d-q.b;if(clb.od(a,e,f,-1,p)||clb.wn(a.J,e)>1){g.a+=p.a+q.b;g.c+=p.b-q.a;}if(clb.od(a,f,e,1,p)||clb.wn(a.J,f)>1){g.b+=p.a-q.b;g.d+=p.b+q.a;}}clb.Kk(a.J,b)==386&&clb.Fd(c,g);clb.Gd(a,c)&&clb.Zc(a,c,e,f);h==2?clb.Gd(a,g)&&clb.Zc(a,g,e,f):clb.Gd(a,g)&&clb.Xc(a,g,e,f);}break;case 3:if(clb.Gd(a,u)){clb.Zc(a,u,e,f);clb.pd(a,u.b-u.a,u.d-u.c,q);clb.$c(a,u,e,f,q.a,q.b,c);clb.$c(a,u,e,f,-q.a,-q.b,c);}break;case 4:if(clb.Gd(a,u)){clb.pd(a,u.b-u.a,u.d-u.c,q);clb.$c(a,u,e,f,1.5*q.a,1.5*q.b,c);clb.$c(a,u,e,f,0.5*q.a,0.5*q.b,c);clb.$c(a,u,e,f,-0.5*q.a,-0.5*q.b,c);clb.$c(a,u,e,f,-1.5*q.a,-1.5*q.b,c);}break;case 5:if(clb.Gd(a,u)){clb.Zc(a,u,e,f);clb.pd(a,u.b-u.a,u.d-u.c,q);clb.$c(a,u,e,f,2*q.a,2*q.b,c);clb.$c(a,u,e,f,q.a,q.b,c);clb.$c(a,u,e,f,-q.a,-q.b,c);clb.$c(a,u,e,f,-2*q.a,-2*q.b,c);}}a.A==-8&&clb.Kd(a,-9);};clb.vd=function vd(a){var b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r;o=false;for(d=0;d<a.J.g;d++){j=null;if(clb.bl(a.J,d)){l=clb.Bk(a.J,d);k=clb.Ak(a.J,d);j=l==k?'['+l+']':'['+l+':'+k+']';}else (clb.Jk(a.J,d)&onb)!=0?j=(clb.Jk(a.J,d)&onb)==Wmb?'a':(clb.Jk(a.J,d)&384)==256?'r!a':'!a':(clb.Jk(a.J,d)&384)!=0&&(j=(clb.Jk(a.J,d)&384)==256?'r':'!r');n=(clb.Jk(a.J,d)&Ymb)>>17;n!=0&&(j=(j==null?'':j)+n);if(j!=null){b=clb.zk(a.J,0,d);c=clb.zk(a.J,1,d);if(!o){clb.Os(a,(a.V*2+1)/3|0);o=true;}q=(clb.Mh(a.P,clb.rk(a.J,b))+clb.Mh(a.P,clb.rk(a.J,c)))/2;r=(clb.Nh(a.P,clb.sk(a.J,b))+clb.Nh(a.P,clb.sk(a.J,c)))/2;f=clb.Mh(a.P,clb.rk(a.J,c))-clb.Mh(a.P,clb.rk(a.J,b));g=clb.Nh(a.P,clb.sk(a.J,c))-clb.Nh(a.P,clb.sk(a.J,b));e=$wnd.Math.sqrt(f*f+g*g);i=(m=(p=ylb.h2(a.e,j),new zlb.n2(p)).b,0.6*m);h=0.55*a.k;e!=0&&(f>0?clb.xd(a,q+i*g/e,r-h*f/e,j,true):clb.xd(a,q-i*g/e,r+h*f/e,j,true));}}o&&clb.Os(a,a.V);};clb.wd=function wd(a,b,c,d){dlb.wi(a.Y,new plb.YF(b-a.T,c-a.T,2*a.T,2*a.T));a.I||dlb.wi(a.S,new clb.Rd(b,c,clb.ld(a,d)?-3:a.p[d]));};clb.xd=function xd(a,b,c,d,e){var f,g,h,i,j;if(e){g=(f=(h=ylb.h2(a.e,d),new zlb.n2(h)).b,f);i=g/2+(a.k/8|0);j=a.k/2|0;(d=='+'||d=='-')&&(j=j*2/3);dlb.wi(a.Y,new plb.YF(b-i,c-j,2*i,2*j));}a.I||clb.Is(a,d,b,c);};clb.yd=function yd(a){var b;b=a.a;a.a=a.b;a.b=b;b=a.c;a.c=a.d;a.d=b;};clb.zd=function zd(a,b,c){var d;d=b==0?Emb+a[0]-a[a.length-1]:a[b]-a[b-1];c>-2.0943951023931953&&c<pnb?d-=2*$wnd.Math.cos(c+qnb):d-=0.5*$wnd.Math.cos(c+qnb);return d;};clb.Ad=function Ad(a){var b;b=new plb.XF();if(a.a<=a.b){b.c=a.a;b.b=a.b-a.a;}else {b.c=a.b;b.b=a.a-a.b;}if(a.c<=a.d){b.d=a.c;b.a=a.d-a.c;}else {b.d=a.d;b.a=a.c-a.d;}return b;};clb.Bd=function Bd(a,b){var c,d,e,f,g,h,i;c=gW(Ykb.yX,emb,6,clb.gn(a.J,b),15,1);for(e=0;e<clb.gn(a.J,b);e++)c[e]=clb.yk(a.J,b,clb.vn(a.J,b,e));alb.jgb(c,alb.Pgb(X1(dlb.ocb.prototype.kc,dlb.ocb,[])));f=clb.Cd(c,0);g=clb.zd(c,0,f);for(d=1;d<c.length;d++){h=clb.Cd(c,d);i=clb.zd(c,d,h);if(g<i){g=i;f=h;}}return f;};clb.Cd=function Cd(a,b){var c;if(b>0)return (a[b]+a[b-1])/2;c=Fmb+(a[0]+a[a.length-1])/2;return c>Fmb?c-Emb:c;};clb.Dd=function Dd(a,b,c,d){var e,f,g,h;h=new clb.Sd();if(b.a==b.b&&b.c==b.d)return;h.a=b.a;h.c=b.c;h.b=b.b;h.d=b.d;g=clb.Ad(h);for(e=0;e<a.Y.a.length;e++){f=dlb.Bi(a.Y,e);if(f.c>g.c+g.b||f.d>g.d+g.a||g.c>f.c+f.b||g.d>f.d+f.a)continue;if(clb.Ed(a,h.a,h.c,e)){if(clb.Ed(a,h.b,h.d,e))return;clb.Hd(a,h,0,e);clb.Dd(a,h,c,d);return;}if(clb.Ed(a,h.b,h.d,e)){clb.Hd(a,h,1,e);clb.Dd(a,h,c,d);return;}}clb.ad(a,h,c,d);};clb.Ed=function Ed(a,b,c,d){var e;if((a.D&1)!=0)return false;e=dlb.Bi(a.Y,d);return b>e.c&&b<e.c+e.b&&c>e.d&&c<e.d+e.a;};clb.Fd=function Fd(a,b){var c;c=a.b;a.b=b.b;b.b=c;c=a.d;a.d=b.d;b.d=c;};clb.Gd=function Gd(a,b){var c,d,e,f,g,h;if(b.a==b.b&&b.c==b.d){for(g=new dlb.Obb(a.Y);g.a<g.c.a.length;){f=dlb.Nbb(g);if(plb.TF(f,b.a,b.c))return false;}return true;}h=clb.Ad(b);c=false;if(b.a>b.b){clb.yd(b);c=true;}for(d=0;d<a.Y.a.length;d++){f=dlb.Bi(a.Y,d);if(f.c>h.c+h.b||f.d>h.d+h.a||h.c>f.c+f.b||h.d>f.d+f.a)continue;if(clb.Ed(a,b.a,b.c,d)){if(clb.Ed(a,b.b,b.d,d)){c&&clb.yd(b);return false;}clb.Hd(a,b,0,d);e=clb.Gd(a,b);c&&clb.yd(b);return e;}if(clb.Ed(a,b.b,b.d,d)){clb.Hd(a,b,1,d);e=clb.Gd(a,b);c&&clb.yd(b);return e;}}c&&clb.yd(b);return true;};clb.Hd=function Hd(a,b,c,d){var e,f,g,h,i,j,k,l,m,n,o;if(c==0){l=b.a;n=b.c;m=b.b;o=b.d;}else {l=b.b;n=b.d;m=b.a;o=b.c;}k=dlb.Bi(a.Y,d);i=m>l?k.c+k.b:k.c;j=o>n?k.d+k.a:k.d;e=m-l;f=o-n;if($wnd.Math.abs(e)>$wnd.Math.abs(f)){if(n==o){g=i;h=n;}else {g=l+e*(j-n)/f;if(m>l==i>g){h=j;}else {g=i;h=n+f*(i-l)/e;}}}else {if(l==m){g=l;h=j;}else {h=n+f*(i-l)/e;if(o>n==j>h){g=i;}else {g=l+e*(j-n)/f;h=j;}}}if(c==0){b.a=g;b.c=h;}else {b.b=g;b.d=h;}};clb.Id=function Id(a){var b,c,d,e;if(a.J.q==0)return;clb.Gt(a.J,(a.D&256)!=0?63:(a.D&512)!=0?95:31);clb.Uc(a);c=clb.Lt(a.J);d=false;a.p=gW(Ykb.AX,gmb,6,a.J.q,15,1);for(b=0;b<a.J.q;b++){a.p[b]=clb.ek(a.J,b);a.p[b]!=0&&(d=true);clb.nl(a.J,b)&&(a.p[b]=128);clb.Sk(a.J,b)&&(a.D&lnb)==0&&(a.p[b]=256);}clb.Kd(a,-10);clb.hd(a);clb.gd(a);clb.jd(a);clb.Sc(a);clb.Os(a,a.V);clb.Ms(a,a.W);clb.Kd(a,a.O);clb.md(a);alb.igb(a.S.a,0);alb.igb(a.Y.a,0);if((a.D&1)!=0){clb.rd(a,c);clb.sd(a);clb.vd(a);}for(e=0;e<a.J.q;e++){if(clb.ld(a,e)){clb.Kd(a,-3);clb.td(a,e,c);clb.Kd(a,a.O);}else if(a.p[e]!=0){clb.Kd(a,a.p[e]);clb.td(a,e,c);clb.Kd(a,a.O);}else if(!d&&a.J.O!=1&&clb.uk(a.J,e)!=1&&clb.uk(a.J,e)!=6&&(a.D&Nmb)==0&&clb.kk(a.J,e)==null&&clb.uk(a.J,e)<clb.Pc.length){clb.Ld(a,clb.dd(a,clb.Pc[clb.uk(a.J,e)]));clb.td(a,e,c);clb.Kd(a,a.O);}else {clb.td(a,e,c);}}if((a.D&1)==0){clb.sd(a);clb.vd(a);clb.rd(a,c);}};clb.Jd=function Jd(a,b,c,d){var e;e=c/2;switch(d&rnb){case rnb:if(b){a.v.a=b.c+b.b/2;a.v.b=b.d+b.a-e;break;}case 0:a.v.a=a.u.c+a.u.b/2;a.v.b=a.u.d+a.u.a+e;!!b&&a.v.b>b.d+b.a-e&&(a.v.b=b.d+b.a-e);break;case snb:if(b){a.v.a=b.c+b.b/2;a.v.b=b.d+e;break;}case tnb:a.v.a=a.u.c+a.u.b/2;a.v.b=a.u.d-e;!!b&&a.v.b<b.d+e&&(a.v.b=b.d+e);}};clb.Kd=function Kd(a,b){if(a.I)return;if(b==-10){a.A=-999;b=a.O;}b!=-2&&b!=-7&&a.L!=0&&(b=-4);if(b==a.A)return;if(a.A==-8&&b!=-9)return;b==-8&&(a.M=a.A);b==-9&&(b=a.M);a.A=b;switch(b){case 0:clb.Ns(a,a.C==0?unb:a.C);break;case-6:clb.Ns(a,a.C);break;case-4:clb.Ns(a,a.L);break;case-2:clb.Ns(a,a.s);break;case-3:clb.Ns(a,a.t);break;case-7:clb.Ns(a,a.F);break;case-8:clb.Ns(a,a.G);break;case-5:clb.Ns(a,a.N);break;case 64:a.d='rgb(32,96,255)';break;case 128:a.d='rgb(255,0,0)';break;case 256:a.d='rgb(192,0,255)';break;case 192:a.d='rgb(0,255,0)';break;case 320:a.d='rgb(255,160,0)';break;case 384:a.d='rgb(0,128,0)';break;case 448:a.d='rgb(160,0,0)';break;case 1:a.d='rgb(128,128,128)';break;default:a.d='rgb(0,0,0)';}};clb.Ld=function Ld(a,b){if(a.L!=0){if(a.A!=-4){a.A=-4;clb.Ns(a,a.L);}return;}a.A=-5;a.N=b;a.d='rgb('+((b&vnb)>>16)+','+((b&imb)>>8)+','+(b&255)+')';};clb.Md=function Md(a){var b,c,d,e,f;e=clb.Mh(a.P,clb.rk(a.J,0));c=clb.Mh(a.P,clb.rk(a.J,0));f=clb.Nh(a.P,clb.sk(a.J,0));d=clb.Nh(a.P,clb.sk(a.J,0));for(b=0;b<a.J.q;b++){e>clb.Mh(a.P,clb.rk(a.J,b))&&(e=clb.Mh(a.P,clb.rk(a.J,b)));c<clb.Mh(a.P,clb.rk(a.J,b))&&(c=clb.Mh(a.P,clb.rk(a.J,b)));f>clb.Nh(a.P,clb.sk(a.J,b))&&(f=clb.Nh(a.P,clb.sk(a.J,b)));d<clb.Nh(a.P,clb.sk(a.J,b))&&(d=clb.Nh(a.P,clb.sk(a.J,b)));}return new plb.YF(e,f,c-e,d-f);};clb.Nd=function Nd(a,b){var c,d;if(a.J.q==0)return null;a.u=clb.Md(a);c=a.P.c*clb.vk(a.J);d=new clb.Ph(a.u,b,c);if(d.c==1&&d.a==0&&d.b==0){d=null;}else {clb.Ih(d,a.P);clb.Kh(d,a.u);}clb.Jd(a,b,c,Ylb);return d;};clb.Od=function Od(a){var b;b=a.K!=0?a.K:a.B!=0?a.B:-1;a.s=slb.GT(b);a.t=slb.FT(wnb,b);a.F=-24321;a.G=-6291392;};clb.Pd=function Pd(a,b){var c,d,e,f;if(a.J.q==0)return null;e=clb.Ps(a,b);clb.Gt(a.J,(a.D&256)!=0?63:(a.D&512)!=0?95:31);clb.md(a);alb.igb(a.S.a,0);alb.igb(a.Y.a,0);clb.Uc(a);clb.Os(a,a.V);a.I=true;for(d=0;d<a.J.q;d++)clb.td(a,d,null);a.I=false;c=a.P.c*clb.vk(a.J);clb.bd(a,c);clb.Jd(a,b,c,Ylb);if(plb.UF(b,a.u))return e;f=new clb.Ph(a.u,b,c);clb.Ih(f,a.P);clb.Kh(f,a.u);clb.Jh(f,a.v);if(!e)return f;clb.Ih(f,e);return e;};clb.Qd=function Qd(a,b){clb.Rc(this);this.J=a;this.D=b;clb.kd(this);};U1(244,1,{});_.s=0;_.t=0;_.w=0;_.A=0;_.B=0;_.C=0;_.D=0;_.F=0;_.G=0;_.H=0;_.I=false;_.K=0;_.L=0;_.M=0;_.N=0;_.O=0;_.Q=0;_.R=0;_.T=0;_.U=0;_.V=0;_.W=0;_.X=0;Ykb.FX=w3(244);clb.Rd=function Rd(a,b,c){this.b=a;this.c=b;this.a=c;};U1(111,1,{111:1},clb.Rd);_.a=0;_.b=0;_.c=0;Ykb.DX=w3(111);clb.Sd=function Sd(){};U1(60,1,{},clb.Sd);_.a=0;_.b=0;_.c=0;_.d=0;Ykb.EX=w3(60);clb.Td=function Td(a){return xnb+a.ob()+'"'+a.nb()+ynb;};U1(154,1,{154:1});_.lb=function Ud(){var a;a=new Zkb.z5();Zkb.y5(a,xnb+this.ob()+'"'+this.nb()+ynb);return a.a;};_.d=false;Ykb.GX=w3(154);clb.Vd=function Vd(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X;J=gW(Ykb.Z0,Amb,6,b.i.a.length,16,1);A=gW(Ykb.AX,gmb,6,a.f.f,15,1);for(T=0;T<b.i.a.length;T++){J[T]=true;for(q=dlb.Bi(b.j,T),r=0,s=q.length;r<s;++r){t=q[r];if(!a.e[t]){J[T]=false;break;}}if(J[T])for(d=dlb.Bi(b.i,T),g=0,j=d.length;g<j;++g){c=d[g];++A[c];}}I=gW(Ykb.Z0,Amb,6,a.f.f,16,1);for(U=0;U<b.i.a.length;U++){V=dlb.Bi(b.j,U).length;if(V==3||V==5||V==6||V==7){if(J[U]){for(e=dlb.Bi(b.i,U),h=0,k=e.length;h<k;++h){c=e[h];I[c]=true;}Q=true;M=-1;N=0;for(f=dlb.Bi(b.i,U),i=0,l=f.length;i<l;++i){c=f[i];if(V==6||A[c]>1){if(!clb.Zd(a,c,false)){Q=false;break;}}else {S=V==5?clb.Wd(a,c,false):clb.Xd(a,c,false);if(clb.Zd(a,c,false)){if(N<S){N=S;M=c;}}else {if(N==10){Q=false;break;}M=c;N=20;}}}if(Q){for(d=dlb.Bi(b.i,U),g=0,j=d.length;g<j;++g){c=d[g];if(c==M){V==5?clb.Wd(a,c,true):clb.Xd(a,c,true);clb.ie(a,c);}else {clb.Zd(a,c,true);}}}}}}w=gW(Ykb.AX,gmb,6,a.f.f,15,1);C=gW(Ykb.Z0,Amb,6,a.f.f,16,1);for(p=0;p<a.f.g;p++){m=clb.zk(a.f,0,p);n=clb.zk(a.f,1,p);if(!I[m]&&!I[n]){if(a.e[p]){++w[m];++w[n];}if(clb.Kk(a.f,p)==32){C[m]=true;C[n]=true;}}}R=gW(Ykb.AX,gmb,6,a.f.f,15,1);B=gW(Ykb.AX,gmb,6,a.f.f,15,1);for(X=0;X<a.f.f;X++){if(w[X]==1){B[0]=X;v=0;D=0;while(v<=D){for(F=0;F<clb.wn(a.f,B[v]);F++){if(a.e[clb.xn(a.f,B[v],F)]){u=clb.vn(a.f,B[v],F);if((v==0||u!=B[v-1])&&w[u]!=0){B[++D]=u;if((w[u]&1)!=0){for(L=1;L<D;L+=2)R[B[L]]=-1;D=0;}break;}}}++v;}}}o=gW(Ykb.Z0,Amb,6,a.f.f,16,1);for(W=0;W<a.f.f;W++){if(!o[W]&&w[W]!=0){B[0]=W;o[W]=true;v=0;D=0;while(v<=D){for(F=0;F<clb.wn(a.f,B[v]);F++){if(a.e[clb.xn(a.f,B[v],F)]){u=clb.vn(a.f,B[v],F);if(!o[u]){B[++D]=u;o[u]=true;}}}++v;}if((D&1)==0){for(G=0;G<=D;G++)R[B[G]]==0&&(R[B[G]]=clb.Yd(a,B[G],false));K=true;for(H=0;H<=D;H++){if(R[B[H]]<=0){if(!clb.Zd(a,B[H],false)){K=false;break;}}}if(K){P=0;O=-1;for(F=0;F<=D;F++){if(P<R[B[F]]){P=R[B[F]];O=B[F];}}if(P>0){clb.Yd(a,O,true);clb.ie(a,O);}}}}}};clb.Wd=function Wd(a,b,c){if(clb.uk(a.f,b)==7){if(clb.gn(a.f,b)==3)return 6;else if(clb.wn(a.f,b)==2)return 4;}else if(clb.uk(a.f,b)==8){return 10;}else if(clb.uk(a.f,b)==15||clb.uk(a.f,b)==33){if(clb.wn(a.f,b)==3)return 8;}else if(clb.uk(a.f,b)==16||clb.uk(a.f,b)==34||clb.uk(a.f,b)==52){if(clb.wn(a.f,b)==2)return 12;}else if(clb.uk(a.f,b)==6){c&&clb.Il(a.f,b,-1);return clb.gn(a.f,b)!=clb.hn(a.f,b)?2:3;}return 0;};clb.Xd=function Xd(a,b,c){if(a.a){if(clb.gn(a.f,b)!=3)return 0;}else {if(clb.gn(a.f,b)>3)return 0;}if(clb.uk(a.f,b)==6){c&&clb.Il(a.f,b,1);return 2;}if(clb.uk(a.f,b)==5){return 4;}return 0;};clb.Yd=function Yd(a,b,c){if(clb.dk(a.f,b)!=0)return 0;if(a.a){if(clb.uk(a.f,b)==5){if(clb.Pn(a.f,b)!=2)return 0;c&&clb.Il(a.f,b,1);return 1;}if(clb.uk(a.f,b)==7){if(clb.Pn(a.f,b)!=2)return 0;c&&clb.Il(a.f,b,-1);return clb._d(a,b)?6:3;}if(clb.uk(a.f,b)==8){if(clb.Pn(a.f,b)!=1)return 0;c&&clb.Il(a.f,b,-1);return clb._d(a,b)?7:4;}if(clb.uk(a.f,b)==16){if(clb.Pn(a.f,b)!=1)return 0;c&&clb.Il(a.f,b,-1);return clb._d(a,b)?5:2;}if(clb.uk(a.f,b)==34){if(clb.Pn(a.f,b)!=1)return 0;c&&clb.Il(a.f,b,-1);return clb._d(a,b)?4:1;}}else {if(clb.uk(a.f,b)==5){if(clb.Pn(a.f,b)>2)return 0;c&&clb.Il(a.f,b,1);return 1;}if(clb.uk(a.f,b)==7){if(clb.Pn(a.f,b)>2)return 0;c&&clb.Il(a.f,b,-1);return clb._d(a,b)?5:3;}if(clb.uk(a.f,b)==8){if(clb.Pn(a.f,b)>1)return 0;c&&clb.Il(a.f,b,-1);return clb._d(a,b)?7:4;}if(clb.uk(a.f,b)==16){if(clb.Pn(a.f,b)>1)return 0;c&&clb.Il(a.f,b,-1);return clb._d(a,b)?5:2;}}return 0;};clb.Zd=function Zd(a,b,c){var d,e,f;d=clb.uk(a.f,b);if(d>=5&&d<=8||d==15||d==16||d==33||d==34||d==52){f=clb.Ln(a.f,b);if(f!=0)return true;e=clb.dk(a.f,b);if(d==5&&e>=0){c&&clb.Il(a.f,b,e-1);return true;}if(d!=5&&e<=0){c&&clb.Il(a.f,b,e+1);return true;}}return false;};clb.$d=function $d(a,b,c,d){var e;for(e=0;e<clb.wn(a.f,b);e++)if(d[clb.xn(a.f,b,e)]==1&&clb.vn(a.f,b,e)!=c)return e;return -1;};clb._d=function _d(a,b){var c;for(c=0;c<clb.wn(a.f,b);c++)if(clb.jl(a.f,clb.vn(a.f,b,c)))return true;return false;};clb.ae=function ae(a,b,c){var d;for(d=0;d<clb.wn(a.f,b);d++)if(c[clb.xn(a.f,b,d)]>1)return true;return false;};clb.be=function be(a,b){var c;for(c=0;c<clb.wn(a.f,b);c++)if(a.e[clb.xn(a.f,b,c)])return true;return false;};clb.ce=function ce(a,b,c){var d,e,f,g,h,i,j,k,l,m;clb.Gt(a.f,1);if(b!=null){a.e=b;}else {a.e=gW(Ykb.Z0,Amb,6,a.f.g,16,1);for(e=0;e<a.f.g;e++){if(clb.Kk(a.f,e)==64){a.e[e]=true;clb.jm(a.f,e,1);}}}a.g=0;a.d=gW(Ykb.Z0,Amb,6,a.f.f,16,1);for(f=0;f<a.f.g;f++){if(a.e[f]){++a.c;for(h=0;h<2;h++){if(!a.d[clb.zk(a.f,h,f)]){a.d[clb.zk(a.f,h,f)]=true;++a.b;}}}}if(a.c==0)return true;a.a=false;clb.ke(a,c);a.f.K&&clb.ee(a);m=new clb.Fr(a.f,1);c&&clb.Vd(a,m);clb.le(a,m);clb.he(a,m);clb.je(a);clb.fe(a);while(clb.ge(a,m))clb.fe(a);while(a.c!=0){g=false;if(!g){for(k=0;k<m.i.a.length;k++){if(dlb.Bi(m.j,k).length==6){j=true;l=dlb.Bi(m.j,k);for(i=0;i<6;i++){if(!a.e[l[i]]){j=false;break;}}if(j){for(h=0;h<6;h+=2)clb.de(a,l[h]);g=true;break;}}}}if(!g){for(d=0;d<a.f.g;d++){if(a.e[d]){clb.de(a,d);clb.fe(a);g=true;break;}}}}return a.b==a.g;};clb.de=function de(a,b){var c,d,e,f;if(clb.Kk(a.f,b)==1){clb.jm(a.f,b,2);a.g+=2;}for(e=0;e<2;e++){c=clb.zk(a.f,e,b);a.d[c]=false;for(f=0;f<clb.wn(a.f,c);f++){d=clb.xn(a.f,c,f);if(a.e[d]){a.e[d]=false;--a.c;}}}};clb.ee=function ee(a){var b,c,d,e,f,g,h,i;for(c=0;c<a.f.g;c++){if(a.e[c]){for(e=0;e<2;e++){h=clb.zk(a.f,e,c);b=false;for(g=0;g<clb.wn(a.f,h);g++){if(c!=clb.xn(a.f,h,g)&&a.e[clb.xn(a.f,h,g)]){b=true;break;}}if(!b){i=c;d=clb.zk(a.f,1-e,c);while(i!=-1){a.e[i]=false;--a.c;clb.jm(a.f,i,64);i=-1;h=d;for(f=0;f<clb.wn(a.f,h);f++){if(a.e[clb.xn(a.f,h,f)]){if(i==-1){i=clb.xn(a.f,h,f);d=clb.vn(a.f,h,f);}else {h=-1;i=-1;break;}}}}break;}}}}};clb.fe=function fe(a){var b,c,d,e,f,g,h;do{h=false;for(c=0;c<a.f.g;c++){if(a.e[c]){f=false;for(e=0;e<2;e++){d=clb.zk(a.f,e,c);b=false;for(g=0;g<clb.wn(a.f,d);g++){if(c!=clb.xn(a.f,d,g)&&a.e[clb.xn(a.f,d,g)]){b=true;break;}}if(!b){f=true;break;}}if(f){h=true;clb.de(a,c);}}}}while(h);};clb.ge=function ge(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o;o=gW(Ykb.AX,gmb,6,a.f.g,15,1);for(m=0;m<b.i.a.length;m++){n=dlb.Bi(b.j,m);l=true;for(k=0;k<n.length;k++){if(!a.e[n[k]]){l=false;break;}}if(l)for(j=0;j<n.length;j++)++o[n[j]];}i=a.c;for(f=0;f<a.f.g;f++){if(o[f]==1){for(j=0;j<2&&a.e[f];j++){c=clb.zk(a.f,j,f);d=clb.zk(a.f,1-j,f);if(clb.ae(a,c,o)&&!clb.ae(a,d,o)){while(-1!=(h=clb.$d(a,d,c,o))){e=clb.vn(a.f,d,h);g=clb.xn(a.f,d,h);if(!a.e[g])break;clb.de(a,g);h=clb.$d(a,e,d,o);if(h==-1)break;c=e;d=clb.vn(a.f,e,h);}}}}}return i!=a.c;};clb.he=function he(a,b){var c;for(c=0;c<a.f.g;c++){if(a.e[c]&&clb.yr(b,c)){clb.ie(a,clb.zk(a.f,0,c));clb.ie(a,clb.zk(a.f,1,c));}}};clb.ie=function ie(a,b){var c,d;if(a.d[b]){a.d[b]=false;--a.b;}for(d=0;d<clb.wn(a.f,b);d++){c=clb.xn(a.f,b,d);if(a.e[c]){a.e[c]=false;--a.c;}}};clb.je=function je(a){var b,c,d,e,f;for(c=0;c<a.f.g;c++){if(clb.Hk(a.f,c)==2){for(e=0;e<2;e++){b=clb.zk(a.f,e,c);if(clb.uk(a.f,b)<=8){for(f=0;f<clb.wn(a.f,b);f++){d=clb.xn(a.f,b,f);if(a.e[d]){clb.ie(a,b);break;}}}}}}};clb.ke=function ke(a,b){var c;for(c=0;c<a.f.f;c++)a.d[c]&&clb.Ln(a.f,c)==0&&(!b||clb.uk(a.f,c)==5&&clb.dk(a.f,c)<0||clb.uk(a.f,c)==6||clb.uk(a.f,c)==14||clb.gl(a.f,c)&&clb.dk(a.f,c)>0)&&clb.ie(a,c);};clb.le=function le(a,b){var c,d,e,f,g,h,i,j,k,l,m,n;for(k=0;k<b.i.a.length;k++){n=dlb.Bi(b.j,k).length;if(n==3||n==5||n==7){l=dlb.Bi(b.i,k);for(d=0;d<n;d++){c=l[d];clb.be(a,c)&&(n==5?(clb.uk(a.f,c)==6&&clb.dk(a.f,c)==-1&&clb.gn(a.f,c)==3||clb.uk(a.f,c)==7&&clb.dk(a.f,c)==0&&clb.gn(a.f,c)==3||clb.uk(a.f,c)==8&&clb.dk(a.f,c)==0&&clb.wn(a.f,c)==2||clb.uk(a.f,c)==16&&clb.dk(a.f,c)==0&&clb.wn(a.f,c)==2||clb.uk(a.f,c)==34&&clb.dk(a.f,c)==0&&clb.wn(a.f,c)==2)&&clb.ie(a,c):(clb.uk(a.f,c)==5&&clb.dk(a.f,c)==0&&clb.gn(a.f,c)==3||clb.uk(a.f,c)==6&&clb.dk(a.f,c)==1)&&clb.ie(a,c));}}}for(j=0;j<b.i.a.length;j++){if(dlb.Bi(b.j,j).length==5){m=dlb.Bi(b.j,j);f=true;for(e=0;e<m.length;e++){if(!a.e[m[e]]){f=false;break;}}if(f){l=dlb.Bi(b.i,j);h=0;g=-1;for(d=0;d<m.length;d++){if(clb.dk(a.f,l[d])==-1&&clb.uk(a.f,l[d])==6){i=clb.gn(a.f,l[d])==3?3:clb.hn(a.f,l[d])==3?2:1;if(h<i){h=i;g=l[d];}}}g!=-1&&clb.ie(a,g);}}}};clb.me=function me(a){this.f=a;};U1(76,1,{},clb.me);_.a=false;_.b=0;_.c=0;_.g=0;Ykb.HX=w3(76);clb.ne=function ne(a,b){var c,d;c=0;for(d=0;d<a.j[b];d++)a.n[b][d]==2&&(clb.uk(a,a.i[b][d])==7||clb.uk(a,a.i[b][d])==8||clb.uk(a,a.i[b][d])==16)&&++c;return c;};clb.oe=function oe(a,b){var c,d,e,f,g,h;if(a.s[b]==0){return false;}h=true;c=a.s[b];f=a.j[b];g=0;for(d=0;d<f;d++){e=a.i[b][d];g+=a.s[e];}$wnd.Math.abs(c)<=$wnd.Math.abs(g)&&Zkb.M4(c)!=Zkb.M4(g)&&(h=false);return h;};clb.pe=function pe(a,b){var c,d,e,f,g,h,i;if(a.C[b]!=8||a.s[b]!=0||a.j[b]!=1||a.n[b][0]!=1)return false;c=a.i[b][0];if(a.C[c]==6){g=a.j[c];for(d=0;d<g;d++){e=a.i[c][d];if(e==b){continue;}if(a.C[e]!=8){continue;}f=clb.tn(a,c,e);if(a.H[f]==2)return true;}}else if(a.C[c]==7){if(a.s[c]==1)return true;}else if(a.C[c]==16){h=a.j[c];i=0;for(d=0;d<h;d++){e=a.i[c][d];if(e==b)continue;if(a.C[e]!=8)continue;f=clb.tn(a,c,e);a.H[f]==2&&++i;}if(i==2)return true;}else if(clb.qe(a,b))return true;return false;};clb.qe=function qe(a,b){var c,d,e,f,g;if(a.C[b]!=8)return false;if(a.j[b]!=1)return false;c=a.i[b][0];if(a.C[c]==15){g=a.j[c];for(d=0;d<g;d++){e=a.i[c][d];if(e==b)continue;if(a.C[e]!=8)continue;f=clb.tn(a,c,e);if(a.H[f]==2)return true;}}return false;};clb.re=function re(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A;if(a.C[b]!=7||a.s[b]!=0||a.j[b]+a.o[b]>3)return false;if(b<a.f&&clb.rr(a.p,b)){if(a.o[b]!=1)return false;if(clb.pn(a,b,7)!=1)return false;u=(clb.Gt(a,7),a.p);for(s=0;s<u.i.a.length;s++){if(clb.tr(u,s,b)){if(dlb.Bi(u.j,s).length==5||dlb.Bi(u.j,s).length==6){v=dlb.Bi(u.i,s);q=-1;for(i=0;i<v.length;i++){if(v[i]==b){q=i;break;}}e=0;r=null;p=null;if(v.length==5){r=gW(Ykb.AX,gmb,6,2,15,1);r[0]=v[q-1<0?q+4:q-1];r[1]=v[q-4<0?q+1:q-4];p=gW(Ykb.AX,gmb,6,2,15,1);p[0]=v[q-2<0?q+3:q-2];p[1]=v[q-3<0?q+2:q-3];}if(v.length==6){r=gW(Ykb.AX,gmb,6,3,15,1);r[0]=v[q-1<0?q+5:q-1];r[1]=v[q-3<0?q+3:q-3];r[2]=v[q-5<0?q+1:q-5];p=gW(Ykb.AX,gmb,6,2,15,1);p[0]=v[q-2<0?q+4:q-2];p[1]=v[q-4<0?q+2:q-4];}for(j=0;j<v.length;j++)b!=v[j]&&clb.uk(a,v[j])==7&&clb.mn(a,v[j])==1&&--e;for(k=0;k<r.length;k++){f=-1;g=-1;for(o=0;o<clb.wn(a,r[k]);o++){if(!clb.mo(a,clb.xn(a,r[k],o))){f=clb.vn(a,r[k],o);g=clb.xn(a,r[k],o);break;}}if(f!=-1){if(a.C[f]==7&&a.o[f]==0&&a.j[f]+a.o[f]<=3&&!clb.se(a,f,false)){++e;continue;}if(a.C[f]==8&&a.j[f]==1){e+=2;continue;}if(g<a.g&&clb.sr(a.p,g)){for(w=0;w<u.i.a.length;w++){if(u.d[w]&&clb.tr(u,w,f)){t=dlb.Bi(u.i,w);for(n=0;n<t.length;n++){if(clb.uk(a,t[n])==7&&clb.mn(a,t[n])==1){--e;break;}}break;}}}}}for(l=0;l<p.length;l++){f=-1;for(n=0;n<clb.wn(a,p[l]);n++)clb.mo(a,clb.xn(a,p[l],n))||(f=clb.vn(a,p[l],n));clb.uk(a,p[l])==6?f!=-1&&clb.ne(a,f)!=0&&--e:clb.uk(a,p[l])==7&&clb.mn(a,p[l])==0&&(f==-1||!(f<a.f&&clb.rr(a.p,f))&&clb.ne(a,f)==0)&&++e;}return e>0;}break;}}return false;}if(a.o[b]>1)return false;if(a.o[b]==1){m=-1;A=0;for(i=0;i<a.j[b];i++){d=a.i[b][i];if(a.n[b][i]==2){if(a.C[d]!=6)return false;m=d;continue;}if(a.C[d]==8)return false;if(a.C[d]==7){--A;clb.se(a,d,false)&&--A;continue;}d<a.f&&clb.rr(a.p,d)&&--A;}if(m==-1)return false;c=0;for(j=0;j<a.j[m];j++){if(a.n[m][j]==1){d=a.i[m][j];if(clb.ne(a,d)!=0)return false;d<a.f&&clb.rr(a.p,d)&&++c;a.C[d]==7&&!clb.se(a,d,true)&&++A;(a.C[d]==8||a.C[d]==16)&&--A;}}c==2&&--A;return A>=0;}for(h=0;h<a.j[b];h++){d=a.i[b][h];if(d<a.f&&clb.rr(a.p,d))return false;if(a.C[d]!=6)return false;if(clb.ne(a,d)!=0)return false;if(a.o[d]!=0&&clb.te(a,d))return false;}return true;};clb.se=function se(a,b,c){var d,e,f;d=false;for(f=0;f<a.j[b];f++){if(!clb.mo(a,a.k[b][f])&&a.n[b][f]==1){e=a.i[b][f];if(!(e<a.f&&clb.rr(a.p,e))&&(a.C[e]==6&&clb.ne(a,e)==1||a.C[e]==16&&clb.ne(a,e)==2)){if(d||!c)return true;d=true;}}}return false;};clb.te=function te(a,b){var c,d,e;for(d=0;d<a.j[b];d++){if(a.n[b][d]!=1){c=a.i[b][d];for(e=0;e<a.j[c];e++)if(a.n[c][e]==1&&clb.ne(a,a.i[c][e])!=0)return true;}}return false;};clb.we=function we(){clb.we=W1;clb.ue=oW(aW(Ykb.Y0,1),znb,6,15,[-1,-1,-1,0,0,1,2,3,4,5,-1,0,0,0,6,7,8,9,-1,0,0,10,10,10,10,10,10,10,10,10,10,1,11,11,12,13,-1,0,0,10,10,10,10,10,10,10,10,10,10,0,0,0,11,14,-1,0,0,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,10,10,10,10,10,10,10,10,1,1,1,1,-1,-1,-1,-1,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1]);clb.ve=oW(aW(Ykb.Y0,1),znb,6,15,[-1,-1,-1,0,0,0,2,5,5,5,-1,0,0,0,0,9,9,9,-1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,9,-1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,-1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,-1,-1,-1,-1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1]);};clb.xe=function xe(a,b,c){clb.we();var d,e,f,g,h,i,j,k,l,m,n,o,p,q;clb.Gt(a,7);n=gW(Ykb.BX,Anb,6,a.j[b],14,1);m=0;for(i=0;i<a.j[b];i++){e=a.i[b][i];if(a.C[e]==1)continue;g=0;if((c&32)!=0){f=q1(a.n[b][i]);c==32190?j1(f,3)<0&&clb.qo(a,a.k[b][i])&&a.o[b]==1&&(f=0):j1(f,3)<0&&clb.mo(a,a.k[b][i])&&(f=0);g=B1(g,C1(f,4));}if((c&128)!=0){if(clb.ue[a.C[e]]==-1)throw c1(new Zkb.rz(Bnb+a.C[e]));g=d1(g,q1(clb.ue[a.C[e]]));}else if((c&64)!=0){if(clb.ve[a.C[e]]==-1)throw c1(new Zkb.rz(Bnb+a.C[e]));g=d1(g,q1(clb.ve[a.C[e]]));}if((c&256)!=0){o=a.j[e]-1;o>3&&(o=3);(c&512)==0&&o>1&&(o=1);g=B1(g,Ykb.m1(o<<6));}(c&Nmb)!=0&&(a.u[e]&8)!=0&&(g=B1(g,256));(c&lnb)!=0&&e<a.f&&clb.rr(a.p,e)&&(g=B1(g,512));(c&Hmb)!=0&&(a.u[e]&knb)!=0&&(g=B1(g,Nmb));k=0;while(j1(g,n[k])<0)++k;for(l=i;l>k;l--)n[l]=n[l-1];n[k]=g;++m;}m>4&&(m=4);d=0;for(j=0;j<m;j++){d=C1(d,11);d=B1(d,n[j]);}d=C1(d,15);if(clb.ue[a.C[b]]==-1)throw c1(new Zkb.rz(Bnb+a.C[b]));d=B1(d,q1(clb.ue[a.C[b]]));if((c&2)!=0){q=!!a.p&&b<a.f?clb.gr(a.p,b):0;q>9&&(q=9);q>2&&(q-=2);d=B1(d,Ykb.m1(q<<4));}else (c&1)!=0&&(a.u[b]&8)!=0&&(d=B1(d,64));(c&4)!=0&&b<a.f&&clb.rr(a.p,b)&&(d=B1(d,Nmb));(c&8)!=0&&(a.u[b]&Imb)!=0&&(d=B1(d,lnb));(c&16)!=0&&(a.u[b]&knb)!=0&&(d=B1(d,Imb));if((c&Imb)!=0){clb.oe(a,b)&&(d=B1(d,knb));if(clb.re(a,b)){for(h=0;h<a.f;h++){if(clb.pe(a,h)){d=B1(d,Hmb);break;}}}}if((c&knb)!=0){p=q1(clb.pn(a,b,10));d=B1(d,C1(p,7));}return d;};clb.ye=function ye(a,b,c,d,e,f){var g,h,i,j;i=0;for(h=0;h<a.P.f;h++)z1(e1(clb.pk(a.P,a.w[h]),d),0)&&++i;if(i==0)return;clb.wf(a,b);clb.rf(a,Ykb.m1(i),c);for(g=0;g<a.P.f;g++){j=e1(clb.pk(a.P,a.w[g]),d);if(j1(j,0)!=0){clb.rf(a,Ykb.m1(g),c);e!=1&&clb.rf(a,D1(j,f),e);}}};clb.ze=function ze(a,b,c,d,e,f){var g,h,i,j;i=0;for(h=0;h<a.P.g;h++)(clb.Jk(a.P,a.A[h])&d)!=0&&++i;if(i==0)return;clb.wf(a,b);clb.rf(a,Ykb.m1(i),c);for(g=0;g<a.P.g;g++){j=clb.Jk(a.P,a.A[g])&d;if(j!=0){clb.rf(a,Ykb.m1(g),c);e!=1&&clb.rf(a,Ykb.m1(j>>f),e);}}};clb.Ae=function Ae(a){var b,c,d,e,f,g;while(true){f=gW(Ykb.Z0,Amb,6,a.S+1,16,1);d=-1;for(c=0;c<a.P.f;c++){if(clb.Ln(a.P,c)!=0){f[a.d[c]]&&d<a.d[c]&&(d=a.d[c]);f[a.d[c]]=true;}}if(d==-1)break;e=0;for(b=0;b<a.P.f;b++){g=0;a.d[b]==d&&(g=++e);clb.sg(a.c[b],b);clb.pg(a.c[b],a.b,q1(a.d[b]));clb.pg(a.c[b],8,Ykb.m1(g));}a.S=clb._e(a);}};clb.Be=function Be(a){var b,c,d,e;for(c=0;c<a.P.f;c++){clb.sg(a.c[c],c);clb.pg(a.c[c],2*a.b+4,C1(q1(a.d[c]),a.b+4));}e=false;for(b=0;b<a.P.f;b++)e=e|clb.Oe(a,b,3);for(d=0;d<a.P.g;d++)e=e|clb.Je(a,d,3);if(!e)return false;while(a.S<a.P.f){e=clb.Ye(a);if(!e)break;clb.$e(a);!!a.N&&clb.Ig(a.N,a.d);}return true;};clb.Ce=function Ce(a){var b,c,d,e,f;for(c=0;c<a.P.f;c++){clb.sg(a.c[c],c);clb.pg(a.c[c],a.b+1,q1(2*a.d[c]));}f=gW(Ykb.AX,gmb,6,a.S+1,15,1);for(d=0;d<a.P.f;d++)++f[a.d[d]];e=1;while(f[e]==1)++e;for(b=0;b<a.P.f;b++){if(a.d[b]==e){clb.qg(a.c[b],1);break;}}a.S=clb._e(a);};clb.De=function De(a,b,c){var d,e,f,g,h;if(clb.uk(a.P,b)!=6&&clb.uk(a.P,b)!=7)return false;e=clb.vn(a.P,b,0);f=clb.vn(a.P,b,1);if(clb.mn(a.P,e)!=1||clb.mn(a.P,f)!=1)return false;if(clb.wn(a.P,e)==1||clb.wn(a.P,f)==1)return false;if(clb.gn(a.P,e)>3||clb.gn(a.P,f)>3)return false;g=new clb.oj(a.P,a.d,b,e);if(g.f&&c==1)return false;h=new clb.oj(a.P,a.d,b,f);if(h.f&&c==1)return false;if(g.f&&h.f)return false;if(c==3){g.f&&g.c&&(a.U[b]=true);h.f&&h.c&&(a.U[b]=true);}d=a.hb?clb.Fe(a,g,h):clb.Ee(g,h);if(c==1){a.bb[b]=d;}else if(c==2){g.f&&(d==1?clb.qg(a.c[g.b],q1(a.d[e])):clb.qg(a.c[g.d],q1(a.d[e])));h.f&&(d==2?clb.qg(a.c[h.b],q1(a.d[f])):clb.qg(a.c[h.d],q1(a.d[f])));}return true;};clb.Ee=function Ee(a,b){var c,d,e;d=clb.nj(a);e=clb.nj(b);if(d==-1||e==-1||(d+e&1)==0)return 3;c=0;switch(d+e){case 3:case 7:c=2;break;case 5:c=1;}return c;};clb.Fe=function Fe(a,b,c){var d,e;d=gW(Ykb.AX,gmb,6,4,15,1);d[0]=b.b;d[1]=b.a;d[2]=c.a;d[3]=c.b;e=clb.Jj(a.P,d);if($wnd.Math.abs(e)<0.3||$wnd.Math.abs(e)>Cnb)return 3;return e<0?2:1;};clb.Ge=function Ge(a,b,c){var d,e,f,g,h;if(!clb.no(a.P,b))return false;d=clb.zk(a.P,0,b);e=clb.zk(a.P,1,b);g=new clb.oj(a.P,a.d,d,e);if(g.f&&c==1)return false;h=new clb.oj(a.P,a.d,e,d);if(h.f&&c==1)return false;if(g.f&&h.f)return false;if(c==3){g.f&&(a.T[b]=clb.Mf(a,e));h.f&&(a.T[b]=clb.Mf(a,d));}f=a.hb?clb.Ie(a,g,h):clb.He(g,h);if(c==1){a.k[b]=f;}else if(c==2){g.f&&(f==2?clb.qg(a.c[g.b],q1(a.d[e])):clb.qg(a.c[g.d],q1(a.d[e])));h.f&&(f==2?clb.qg(a.c[h.b],q1(a.d[d])):clb.qg(a.c[h.d],q1(a.d[d])));}return true;};clb.He=function He(a,b){var c,d,e;d=clb.nj(a);e=clb.nj(b);if(d==-1||e==-1||(d+e&1)==0)return 3;c=0;switch(d+e){case 3:case 7:c=1;break;case 5:c=2;}return c;};clb.Ie=function Ie(a,b,c){var d,e;d=gW(Ykb.AX,gmb,6,4,15,1);d[0]=b.b;d[1]=b.a;d[2]=c.a;d[3]=c.b;e=clb.Jj(a.P,d);if($wnd.Math.abs(e)<0.3||$wnd.Math.abs(e)>Cnb)return 3;return e<0?1:2;};clb.Je=function Je(a,b,c){var d,e,f,g,h;if(a.k[b]!=0)return false;if(clb.Hk(a.P,b)==1)return clb.Ge(a,b,c);if(clb.Hk(a.P,b)!=2)return false;if(clb.mo(a.P,b))return false;e=clb.zk(a.P,0,b);f=clb.zk(a.P,1,b);if(clb.wn(a.P,e)==1||clb.wn(a.P,f)==1)return false;if(clb.wn(a.P,e)>3||clb.wn(a.P,f)>3)return false;if(clb.mn(a.P,e)==2||clb.mn(a.P,f)==2)return false;g=new clb.oj(a.P,a.d,f,e);if(g.f&&c==1)return false;h=new clb.oj(a.P,a.d,e,f);if(h.f&&c==1)return false;if(g.f&&h.f)return false;if(c==3){g.f&&g.c&&(a.T[b]=true);h.f&&h.c&&(a.T[b]=true);}d=clb.fl(a.P,b)?3:a.hb?clb.Le(a,g,h):clb.Ke(g,h);if(c==1){a.k[b]=d;}else if(c==2){g.f&&(d==1?clb.qg(a.c[g.b],q1(a.d[e])):d==2&&clb.qg(a.c[g.d],q1(a.d[e])));h.f&&(d==1?clb.qg(a.c[h.b],q1(a.d[f])):d==2&&clb.qg(a.c[h.d],q1(a.d[f])));}return true;};clb.Ke=function Ke(a,b){if(clb.nj(a)==-1||clb.nj(b)==-1)return 3;if(((clb.nj(a)|clb.nj(b))&1)!=0)return 3;return clb.nj(a)==clb.nj(b)?1:2;};clb.Le=function Le(a,b,c){var d,e,f,g,h,i,j;f=gW(Ykb.yX,emb,6,3,15,1);f[0]=clb.rk(a.P,c.a)-clb.rk(a.P,b.a);f[1]=clb.sk(a.P,c.a)-clb.sk(a.P,b.a);f[2]=clb.tk(a.P,c.a)-clb.tk(a.P,b.a);i=gW(Ykb.yX,emb,6,3,15,1);i[0]=clb.rk(a.P,b.b)-clb.rk(a.P,b.a);i[1]=clb.sk(a.P,b.b)-clb.sk(a.P,b.a);i[2]=clb.tk(a.P,b.b)-clb.tk(a.P,b.a);j=gW(Ykb.yX,emb,6,3,15,1);j[0]=clb.rk(a.P,c.b)-clb.rk(a.P,c.a);j[1]=clb.sk(a.P,c.b)-clb.sk(a.P,c.a);j[2]=clb.tk(a.P,c.b)-clb.tk(a.P,c.a);g=gW(Ykb.yX,emb,6,3,15,1);g[0]=f[1]*i[2]-f[2]*i[1];g[1]=f[2]*i[0]-f[0]*i[2];g[2]=f[0]*i[1]-f[1]*i[0];h=gW(Ykb.yX,emb,6,3,15,1);h[0]=f[1]*g[2]-f[2]*g[1];h[1]=f[2]*g[0]-f[0]*g[2];h[2]=f[0]*g[1]-f[1]*g[0];d=(i[0]*h[0]+i[1]*h[1]+i[2]*h[2])/($wnd.Math.sqrt(i[0]*i[0]+i[1]*i[1]+i[2]*i[2])*$wnd.Math.sqrt(h[0]*h[0]+h[1]*h[1]+h[2]*h[2]));e=(j[0]*h[0]+j[1]*h[1]+j[2]*h[2])/($wnd.Math.sqrt(j[0]*j[0]+j[1]*j[1]+j[2]*j[2])*$wnd.Math.sqrt(h[0]*h[0]+h[1]*h[1]+h[2]*h[2]));return d<0^e<0?1:2;};clb.Me=function Me(a,b){var c,d,e,f;c=clb.bk(a.P,b);d=clb.Jn(a.P,b,false);e=clb.Jn(a.P,b,true);f=-1;if(d!=e){c!=-1&&c>d?f=c<<24>>24:f=d<<24>>24;}else if(c!=-1){(c>e||c<e&&c>=clb.Pn(a.P,b))&&(f=c<<24>>24);}else if(!clb.Ro(a.P,b)&&clb.An(a.P,b)!=0){f=clb.Pn(a.P,b);f-=clb.Ok(a.P,b,f);}clb.gf(a,b,f);return f;};clb.Ne=function Ne(a){var b,c,d,e,f,g,h,i,j,k,l;d=gW(Ykb.AX,gmb,6,a.M,15,1);for(b=0;b<a.P.f;b++){k=clb.wn(a.P,b)+clb.Mn(a.P,b);j=0;for(f=0;f<clb.hn(a.P,b);f++){if(f<clb.wn(a.P,b)||f>=clb.gn(a.P,b)){l=2*a.d[clb.vn(a.P,b,f)];c=clb.xn(a.P,b,f);clb.Hk(a.P,c)==2&&(clb.mo(a.P,c)||++l);for(h=0;h<j;h++)if(l<d[h])break;for(i=j;i>h;i--)d[i]=d[i-1];d[h]=l;++j;}}clb.sg(a.c[b],b);clb.pg(a.c[b],a.b,q1(a.d[b]));for(g=k;g<a.M;g++)clb.pg(a.c[b],a.b+1,0);for(e=0;e<k;e++)clb.pg(a.c[b],a.b+1,Ykb.m1(d[e]));}};clb.Oe=function Oe(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o;if(a.bb[b]!=0)return false;if(clb.uk(a.P,b)!=5&&clb.uk(a.P,b)!=6&&clb.uk(a.P,b)!=7&&clb.uk(a.P,b)!=14&&clb.uk(a.P,b)!=15&&clb.uk(a.P,b)!=16)return false;if(clb.mn(a.P,b)!=0){if(clb.oo(a.P,b))return clb.De(a,b,c);if(clb.uk(a.P,b)!=15&&clb.uk(a.P,b)!=16)return false;}if(clb.wn(a.P,b)<3||clb.gn(a.P,b)>4)return false;if(clb.dk(a.P,b)>0&&clb.uk(a.P,b)==6)return false;if(clb.uk(a.P,b)==5&&clb.gn(a.P,b)!=4)return false;if(clb.uk(a.P,b)==7&&!a.Q[b])return false;n=gW(Ykb.AX,gmb,6,4,15,1);o=gW(Ykb.AX,gmb,6,4,15,1);j=gW(Ykb.Z0,Amb,6,4,16,1);for(h=0;h<clb.gn(a.P,b);h++){f=-1;e=0;for(i=0;i<clb.gn(a.P,b);i++){if(!j[i]){if(f<a.d[clb.vn(a.P,b,i)]){f=a.d[clb.vn(a.P,b,i)];e=i;}}}n[h]=e;o[h]=f;j[e]=true;}if(clb.gn(a.P,b)==4&&o[0]==o[1]&&o[2]==o[3])return false;if(clb.gn(a.P,b)==4&&(o[0]==o[2]||o[1]==o[3]))return false;if(clb.gn(a.P,b)==3&&o[0]==o[2])return false;k=0;l=0;m=false;for(g=1;g<clb.gn(a.P,b);g++){if(o[g-1]==o[g]){if(c==1||o[g]==0)return false;k=clb.vn(a.P,b,n[g-1]);l=clb.vn(a.P,b,n[g]);c==3&&clb.zo(a.P,clb.xn(a.P,b,n[g]))&&(a.U[b]=true);m=true;}}if(c!=1&&!m)return false;d=a.hb?clb.Qe(a,b,n):clb.Pe(a,b,n);c==1?a.bb[b]=d:c==2&&(d==1?clb.qg(a.c[k],q1(a.d[b])):d==2&&clb.qg(a.c[l],q1(a.d[b])));return true;};clb.Pe=function Pe(a,b,c){var d,e,f,g,h,i,j,k,l,m;m=oW(aW(Ykb.AX,2),Dnb,7,0,[oW(aW(Ykb.AX,1),gmb,6,15,[2,1,2,1]),oW(aW(Ykb.AX,1),gmb,6,15,[1,2,2,1]),oW(aW(Ykb.AX,1),gmb,6,15,[1,1,2,2]),oW(aW(Ykb.AX,1),gmb,6,15,[2,1,1,2]),oW(aW(Ykb.AX,1),gmb,6,15,[2,2,1,1]),oW(aW(Ykb.AX,1),gmb,6,15,[1,2,1,2])]);d=gW(Ykb.yX,emb,6,clb.gn(a.P,b),15,1);for(g=0;g<clb.gn(a.P,b);g++)d[g]=clb.yk(a.P,clb.vn(a.P,b,c[g]),b);j=clb.Cn(a.P,b,c,d,null)<<24>>24;if(j!=3)return j;k=0;l=0;for(h=0;h<clb.gn(a.P,b);h++){e=clb.xn(a.P,b,c[h]);if(clb.zk(a.P,0,e)==b){if(clb.Kk(a.P,e)==129){l!=0&&clb.sm(a.P,b);k=h;l=1;}if(clb.Kk(a.P,e)==257){l!=0&&clb.sm(a.P,b);k=h;l=2;}}}if(l==0)return 3;for(f=1;f<clb.gn(a.P,b);f++)d[f]<d[0]&&(d[f]+=Emb);if(clb.gn(a.P,b)==3){switch(k){case 0:(d[1]<d[2]&&d[2]-d[1]<Fmb||d[1]>d[2]&&d[1]-d[2]>Fmb)&&(l=3-l);break;case 1:d[2]-d[0]>Fmb&&(l=3-l);break;case 2:d[1]-d[0]<Fmb&&(l=3-l);}return l==1?2:1;}i=0;d[1]<=d[2]&&d[2]<=d[3]?i=0:d[1]<=d[3]&&d[3]<=d[2]?i=1:d[2]<=d[1]&&d[1]<=d[3]?i=2:d[2]<=d[3]&&d[3]<=d[1]?i=3:d[3]<=d[1]&&d[1]<=d[2]?i=4:d[3]<=d[2]&&d[2]<=d[1]&&(i=5);return m[i][k]==l?2:1;};clb.Qe=function Qe(a,b,c){var d,e,f,g,h,i;d=gW(Ykb.AX,gmb,6,4,15,1);for(h=0;h<clb.gn(a.P,b);h++)d[h]=clb.vn(a.P,b,c[h]);clb.gn(a.P,b)==3&&(d[3]=b);e=eW(Ykb.yX,[Llb,emb],[12,6],15,[3,3],2);for(g=0;g<3;g++){e[g][0]=clb.rk(a.P,d[g+1])-clb.rk(a.P,d[0]);e[g][1]=clb.sk(a.P,d[g+1])-clb.sk(a.P,d[0]);e[g][2]=clb.tk(a.P,d[g+1])-clb.tk(a.P,d[0]);}i=gW(Ykb.yX,emb,6,3,15,1);i[0]=e[0][1]*e[1][2]-e[0][2]*e[1][1];i[1]=e[0][2]*e[1][0]-e[0][0]*e[1][2];i[2]=e[0][0]*e[1][1]-e[0][1]*e[1][0];f=(e[2][0]*i[0]+e[2][1]*i[1]+e[2][2]*i[2])/($wnd.Math.sqrt(e[2][0]*e[2][0]+e[2][1]*e[2][1]+e[2][2]*e[2][2])*$wnd.Math.sqrt(i[0]*i[0]+i[1]*i[1]+i[2]*i[2]));return f>0?1:2;};clb.Re=function Re(a){var b,c;b=0;dlb.kcb(a.c);for(c=0;c<a.c.length;c++){(c==0||clb.rg(a.c[c],a.c[c-1])!=0)&&++b;a.d[a.c[c].a]=b;}return b;};clb.Se=function Se(a){var b,c,d,e,f,g,h,i,j,k,l,m;if(a.v)return;a.v=new dlb.Qi();k=0;l=gW(Ykb.AX,gmb,6,a.P.f,15,1);g=gW(Ykb.AX,gmb,6,a.P.f,15,1);i=gW(Ykb.AX,gmb,6,a.P.g,15,1);for(b=0;b<a.P.f;b++){if(l[b]==0&&(clb.yo(a.P,b)||clb.mn(a.P,b)==1)){g[0]=b;h=1;j=0;l[b]=++k;c=gW(Ykb.Z0,Amb,6,a.P.g,16,1);for(f=0;f<h;f++){for(m=0;m<clb.wn(a.P,g[f]);m++){e=clb.xn(a.P,g[f],m);if(clb.zo(a.P,e)||clb.Hk(a.P,e)==2||clb.no(a.P,e)){d=clb.vn(a.P,g[f],m);if(!c[e]){i[j++]=e;c[e]=true;}if(l[d]==0){g[h++]=d;l[d]=k;}}}}dlb.wi(a.v,new clb.yg(g,h,i,j));}}};clb.Te=function Te(a){var b;a.Q=gW(Ykb.Z0,Amb,6,a.P.f,16,1);for(b=0;b<a.P.f;b++){if(clb.uk(a.P,b)==7){if(clb.wn(a.P,b)==4){a.Q[b]=true;continue;}if(clb.wn(a.P,b)==3){if(clb.qn(a.P,b)==3){a.Q[b]=true;continue;}if(clb.dk(a.P,b)==1){a.Q[b]=true;continue;}if(clb.so(a.P,b,true))continue;if((a.O&32)!=0){a.Q[b]=true;continue;}if(clb.xo(a.P,b)){a.Q[b]=true;continue;}}}}};clb.Ue=function Ue(a,b){var c,d,e,f;e=false;for(d=0;d<a.P.g;d++)if(clb.Je(a,d,1)){a.o[d]=a.J;b&&clb.hf(a,d);e=true;}f=false;for(c=0;c<a.P.f;c++)if(clb.Oe(a,c,1)){a.gb[c]=a.J;b&&clb.jf(a,c);f=true;}f&&(a.J=!a.J);return e||f;};clb.Ve=function Ve(a){var b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B;s=gW(Ykb.Z0,Amb,6,a.P.f,16,1);t=gW(Ykb.Z0,Amb,6,a.P.g,16,1);b=0;v=false;if((a.O&128)!=0){a.W=gW(Ykb.AX,gmb,6,a.P.f,15,1);a.V=gW(Ykb.AX,gmb,6,a.P.g,15,1);}for(d=0;d<a.P.f;d++){if(a.U[d]){if(!a.db[d]){if(clb.Oe(a,d,1)){a.db[d]=true;s[d]=true;++b;}}}}for(f=0;f<a.P.g;f++){if(a.T[f]){if(!a.n[f]){if(clb.Je(a,f,1)){a.n[f]=true;t[f]=true;++b;}}}}if(b==1){for(c=0;c<a.P.f;c++){if(s[c]){a.bb[c]=0;break;}}for(e=0;e<a.P.g;e++){if(t[e]){a.k[e]=0;break;}}}else if(b>1){clb.Se(a);a.R=0;for(h=new dlb.Obb(a.v);h.a<h.c.a.length;){g=dlb.Nbb(h);u=0;w=0;k=0;j=0;l=-1;i=-1;for(o=0;o<g.a.length;o++){if(s[g.a[o]]){++u;if(a.bb[g.a[o]]==1||a.bb[g.a[o]]==2){++w;v=true;if(l<a.d[g.a[o]]){l=a.d[g.a[o]];k=g.a[o];}}}}for(p=0;p<g.b.length;p++){if(t[g.b[p]]){++u;A=a.d[clb.zk(a.P,0,g.b[p])];B=a.d[clb.zk(a.P,1,g.b[p])];m=A>B?(A<<16)+B:(B<<16)+A;if(a.k[g.b[p]]==1||a.k[g.b[p]]==2){++w;v=true;if(i<m){i=m;j=g.b[p];}}}}if(u==0)continue;if(u==1){for(q=0;q<g.a.length;q++)s[g.a[q]]&&(a.bb[g.a[q]]=0);for(n=0;n<g.b.length;n++)t[g.b[n]]&&(a.k[g.b[n]]=0);}else {if(w==1){for(q=0;q<g.a.length;q++)s[g.a[q]]&&(a.bb[g.a[q]]=3);for(n=0;n<g.b.length;n++)t[g.b[n]]&&(a.k[g.b[n]]=3);}else {if((a.O&128)!=0){++a.R;for(q=0;q<g.a.length;q++)s[g.a[q]]&&(a.W[g.a[q]]=a.R);for(n=0;n<g.b.length;n++)t[g.b[n]]&&(a.V[g.b[n]]=a.R);}r=false;l!=-1?a.bb[k]==2&&(r=true):a.k[j]==2&&(r=true);if(r){for(q=0;q<g.a.length;q++){if(s[g.a[q]]){switch(a.bb[g.a[q]]){case 1:a.bb[g.a[q]]=2;break;case 2:a.bb[g.a[q]]=1;}}}for(n=0;n<g.b.length;n++){if(t[g.b[n]]){switch(a.k[g.b[n]]){case 1:a.k[g.b[n]]=2;break;case 2:a.k[g.b[n]]=1;}}}}}}}}return v;};clb.We=function We(a,b){var c,d,e,f,g,h,i,j,k,l,m;f=eW(Ykb.AX,[Dnb,gmb],[7,6],15,[2,32],2);for(g=0;g<2;g++){c=gW(Ykb.AX,Dnb,7,32,0,2);m=0;for(e=0;e<32;e++){if(b[g][e]!=null){k=b[g][e].length;c[e]=gW(Ykb.AX,gmb,6,k,15,1);for(h=0;h<k;h++)c[e][h]=a.d[b[g][e][h]];alb.jgb(c[e],alb.Pgb(X1(dlb.ucb.prototype.kc,dlb.ucb,[])));++m;}}for(l=m;l>0;l--){j=0;i=null;for(d=0;d<32;d++){if(c[d]!=null){if(i==null||i.length<c[d].length){i=c[d];j=d;}else if(i.length==c[d].length){for(h=i.length-1;h>=0;h--){if(i[h]<c[d][h]){i=c[d];j=d;break;}}}}}f[g][j]=l;c[j]=null;}}return f;};clb.Xe=function Xe(a){var b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t;l=false;if(a.P.K){for(j=0;j<a.P.g;j++){if(clb.Jk(a.P,j)!=0){l=true;break;}}}a.M=2;for(c=0;c<a.P.f;c++)a.M=$wnd.Math.max(a.M,clb.wn(a.P,c)+clb.Mn(a.P,c));i=$wnd.Math.max(2,l?(62+a.b+a.M*(a.b+23))/63|0:(62+a.b+a.M*(a.b+5))/63|0);a.d=gW(Ykb.AX,gmb,6,a.P.q,15,1);a.c=gW(Ykb.MX,Enb,110,a.P.f,0,1);for(d=0;d<a.P.f;d++)a.c[d]=new clb.tg(i);h=false;for(e=0;e<a.P.f;e++){clb.sg(a.c[e],e);z1(e1(clb.pk(a.P,e),1),0)||clb.kk(a.P,e)!=null?clb.pg(a.c[e],8,6):clb.pg(a.c[e],8,q1(clb.uk(a.P,e)));clb.pg(a.c[e],8,q1(clb.nk(a.P,e)));clb.pg(a.c[e],2,q1(clb.mn(a.P,e)));clb.pg(a.c[e],4,q1(clb.wn(a.P,e)+clb.Mn(a.P,e)));z1(e1(clb.pk(a.P,e),1),0)?clb.pg(a.c[e],4,8):clb.pg(a.c[e],4,q1(8+clb.dk(a.P,e)));clb.pg(a.c[e],5,q1($wnd.Math.min(31,clb.qn(a.P,e))));clb.pg(a.c[e],4,q1(clb.Me(a,e)+1));clb.pg(a.c[e],2,q1(clb.qk(a.P,e)>>4));if(a.P.K){clb.pg(a.c[e],46,clb.pk(a.P,e));clb.kk(a.P,e)!=null&&(h=true);}}a.S=clb._e(a);if(a.S<a.P.f){for(b=0;b<a.P.f;b++){clb.sg(a.c[b],b);clb.pg(a.c[b],a.b,q1(a.d[b]));m=gW(Ykb.AX,gmb,6,clb.wn(a.P,b),15,1);for(o=0;o<clb.wn(a.P,b);o++){m[o]=a.d[clb.vn(a.P,b,o)]<<5;m[o]|=$wnd.Math.min(31,clb.un(a.P,clb.xn(a.P,b,o)));}alb.jgb(m,alb.Pgb(X1(dlb.ucb.prototype.kc,dlb.ucb,[])));for(p=a.M;p>m.length;p--)clb.pg(a.c[b],a.b+5,0);for(n=m.length-1;n>=0;n--)clb.pg(a.c[b],a.b+5,Ykb.m1(m[n]));}a.S=clb._e(a);}if(h&&a.S<a.P.f){for(b=0;b<a.P.f;b++){clb.sg(a.c[b],b);clb.pg(a.c[b],a.b,q1(a.d[b]));g=clb.kk(a.P,b);s=g==null?0:$wnd.Math.min(12,g.length);for(o=12;o>s;o--)clb.pg(a.c[b],8,0);for(n=s-1;n>=0;n--)clb.pg(a.c[b],8,Ykb.m1(g[n]));}a.S=clb._e(a);}if(l&&a.S<a.P.f){for(b=0;b<a.P.f;b++){clb.sg(a.c[b],b);clb.pg(a.c[b],a.b,q1(a.d[b]));k=gW(Ykb.BX,Anb,6,clb.wn(a.P,b)+clb.Mn(a.P,b),14,1);q=0;for(o=0;o<clb.hn(a.P,b);o++){if(o<clb.wn(a.P,b)||o>=clb.gn(a.P,b)){k[q]=q1(a.d[clb.vn(a.P,b,o)]);k[q]=C1(k[q],23);k[q]=B1(k[q],q1(clb.Jk(a.P,clb.xn(a.P,b,o))));++q;}}alb.jgb(k,alb.Pgb(X1(dlb.rcb.prototype.lc,dlb.rcb,[])));for(p=a.M;p>k.length;p--)clb.pg(a.c[b],a.b+23,0);for(n=k.length-1;n>=0;n--)clb.pg(a.c[b],a.b+23,k[n]);}a.S=clb._e(a);}if((a.O&8)!=0&&a.S<a.P.f){r=new clb.Dt();for(f=0;f<a.P.f;f++)clb.fk(a.P,f)!=null&&clb.Bt(r,clb.fk(a.P,f));for(b=0;b<a.P.f;b++){t=clb.fk(a.P,b)==null?0:1+clb.Ct(r,clb.fk(a.P,b));clb.sg(a.c[b],b);clb.pg(a.c[b],a.b,q1(a.d[b]));clb.pg(a.c[b],a.b,Ykb.m1(t));}a.S=clb._e(a);}if((a.O&16)!=0&&a.S<a.P.f){for(b=0;b<a.P.f;b++){clb.sg(a.c[b],b);clb.pg(a.c[b],a.b,q1(a.d[b]));clb.pg(a.c[b],1,q1(clb.nl(a.P,b)?1:0));}a.S=clb._e(a);}(a.O&512)!=0&&a.P.K&&clb.Ae(a);};clb.Ye=function Ye(a){var b,c,d,e,f,g,h,i,j;for(c=0;c<a.P.f;c++){clb.sg(a.c[c],c);clb.pg(a.c[c],2*a.b+4,C1(q1(a.d[c]),a.b+4));}for(i=1;i<=a.S;i++){e=false;for(d=0;d<a.P.f;d++)a.d[d]==i&&(e=e|clb.Oe(a,d,2));if(e){h=a.S;a.S=clb._e(a);if(a.S!=h)return true;for(b=0;b<a.P.f;b++){clb.sg(a.c[b],b);clb.pg(a.c[b],2*a.b+4,C1(q1(a.d[b]),a.b+4));}}}j=gW(Ykb.NX,Enb,141,a.P.g,0,1);for(g=0;g<j.length;g++)j[g]=new clb.wg(a.d[clb.zk(a.P,0,g)],a.d[clb.zk(a.P,1,g)],g);dlb.icb(j,0,j.length,null);for(f=0;f<j.length;f++){if(clb.Je(a,j[f].a,2)){while(f+1<j.length&&clb.vg(j[f],j[f+1])==0)clb.Je(a,j[++f].a,2);h=a.S;a.S=clb._e(a);if(a.S!=h)return true;for(b=0;b<a.P.f;b++){clb.sg(a.c[b],b);clb.pg(a.c[b],2*a.b+4,C1(q1(a.d[b]),a.b+4));}}}return false;};clb.Ze=function Ze(a){var b,c,d,e,f,g,h,i,j,k;f=0;for(c=0;c<a.P.f;c++)a._[c]!=0&&(a._[c]!=2||(a.O&256)==0)&&++f;if(f==0)return;k=gW(Ykb.AX,gmb,6,f,15,1);f=0;for(d=0;d<a.P.f;d++){if(a._[d]!=0&&(a._[d]!=2||(a.O&256)==0)){k[f]=a._[d]<<29|a.$[d]<<24|a.d[d]<<12|d;++f;}}alb.jgb(k,alb.Pgb(X1(dlb.ucb.prototype.kc,dlb.ucb,[])));g=0;j=0;h=k[0]&unb;while(true){++j;if(j==k.length||h!=(k[j]&unb)){e=gW(Ykb.AX,gmb,6,j-g,15,1);for(i=g;i<j;i++){b=k[i]&4095;e[i-g]=b;a.eb[b]=true;}dlb.wi(a.fb,e);if(j==k.length)break;h=k[j]&unb;g=j;}}};clb.$e=function $e(a){var b,c,d,e,f,g,h,i,j,k,l,m,n;h=false;for(i=0;i<a.fb.a.length;i++){g=dlb.Bi(a.fb,i);b=true;n=-1;j=false;for(l=0;l<g.length;l++){c=g[l];if(a.bb[c]==0){b=false;break;}if(a.bb[c]!=3){k=true;for(m=0;m<g.length;m++){if(m!=l&&a.d[c]==a.d[g[m]]){k=false;break;}}if(k&&n<a.d[c]){n=a.d[c];j=a.bb[c]==1;}}}if(b&&n!=-1){for(d=g,e=0,f=d.length;e<f;++e){c=d[e];(a.bb[c]==1||a.bb[c]==2)&&(a.cb[c]=j);a.eb[c]=false;}dlb.Ji(a.fb,g);h=true;--i;}}return h;};clb._e=function _e(a){var b,c;b=clb.Re(a);do{c=b;clb.Ne(a);b=clb.Re(a);}while(c!=b);return b;};clb.af=function af(a){(a.O&1)!=0&&(a.O&2)==0&&(a.e=dlb.Ubb(a.d,a.P.f));if((a.O&lnb)==0){a.U=gW(Ykb.Z0,Amb,6,a.P.f,16,1);a.T=gW(Ykb.Z0,Amb,6,a.P.g,16,1);if(a.S<a.P.f){clb.Be(a);if((a.O&lnb)==0){clb.$e(a);!!a.N&&clb.Ig(a.N,a.d);}}}a.e==null&&(a.O&1)!=0&&(a.O&2)!=0&&(a.e=dlb.Ubb(a.d,a.P.f));while(a.S<a.P.f){clb.Ce(a);if((a.O&lnb)==0){clb.$e(a);!!a.N&&clb.Ig(a.N,a.d);}}if((a.O&lnb)==0){clb.$e(a);clb.Ve(a);clb.zf(a);}};clb.bf=function bf(a){var b,c,d,e,f;f=a.S;e=dlb.Ubb(a.d,a.P.f);if(!a.P.K){clb.df(a);clb.Rf(a,f,e);}a._=gW(Ykb.wX,Fnb,6,a.P.f,15,1);a.$=gW(Ykb.wX,Fnb,6,a.P.f,15,1);for(c=0;c<a.P.f;c++){a._[c]=clb.ik(a.P,c)<<24>>24;a.$[c]=clb.hk(a.P,c)<<24>>24;}a.j=gW(Ykb.wX,Fnb,6,a.P.g,15,1);a.i=gW(Ykb.wX,Fnb,6,a.P.g,15,1);for(d=0;d<a.P.g;d++){a.j[d]=clb.Ek(a.P,d)<<24>>24;a.i[d]=clb.Dk(a.P,d)<<24>>24;}clb.cf(a);a.X=false;a.K=gW(Ykb.Z0,Amb,6,a.P.f,16,1);for(b=0;b<a.P.f;b++){if(a.bb[b]!=0){a.K[b]=true;a.X=true;}}clb.ff(a);a.N=null;a.ab=gW(Ykb.Z0,Amb,6,a.P.f,16,1);if(a.X){a.N=new clb.Og(a.P,e,a.K,a.bb,a.k,a._,a.$,a.gb,a.o,a.ab);clb.Jg(a.N);}a.cb=gW(Ykb.Z0,Amb,6,a.P.f,16,1);a.eb=gW(Ykb.Z0,Amb,6,a.P.f,16,1);a.fb=new dlb.Qi();!!a.N&&clb.Ig(a.N,a.d);clb.Ze(a);clb.Rf(a,f,e);clb.ef(a);!!a.N&&(a.I=clb.Fg(a.N));clb.qf(a);};clb.cf=function cf(a){var b,c,d,e,f,g;a.J=true;f=clb.Ue(a,false);while(a.S<a.P.f&&f){for(b=0;b<a.P.f;b++){clb.sg(a.c[b],b);clb.pg(a.c[b],a.b,q1(a.d[b]));g=a.bb[b]<<7;if((a.bb[b]==1||a.bb[b]==2)&&a._[b]!=0){g|=a._[b]<<5;g|=a.$[b];}clb.pg(a.c[b],18,Ykb.m1(g<<9));}for(c=0;c<a.P.g;c++){d=a.k[c]<<7;if((a.k[c]==1||a.k[c]==2)&&clb.Kk(a.P,c)==1&&a.j[c]!=0){d|=a.j[c]<<5;d|=a.i[c];}clb.qg(a.c[clb.zk(a.P,0,c)],Ykb.m1(d));clb.qg(a.c[clb.zk(a.P,1,c)],Ykb.m1(d));}e=clb._e(a);if(a.S==e)break;a.S=e;f=clb.Ue(a,false);}};clb.df=function df(a){var b,c,d,e;a.J=true;a.Y=gW(Ykb.wX,Fnb,6,a.P.f,15,1);a.f=gW(Ykb.wX,Fnb,6,a.P.g,15,1);e=clb.Ue(a,true);while(a.S<a.P.f&&e){for(b=0;b<a.P.f;b++){clb.sg(a.c[b],b);clb.pg(a.c[b],a.b+4,q1(a.d[b]<<4|a.bb[b]<<2));}for(c=0;c<a.P.g;c++){clb.qg(a.c[clb.zk(a.P,0,c)],q1(a.k[c]));clb.qg(a.c[clb.zk(a.P,1,c)],q1(a.k[c]));}d=clb._e(a);if(a.S==d)break;a.S=d;e=clb.Ue(a,true);}};clb.ef=function ef(a){var b,c,d,e,f,g,h;a.J=true;d=clb.pf(a);!!a.N&&clb.Ig(a.N,a.d)&&(d=clb.pf(a));clb.Ue(a,false)&&clb.$e(a);g=true;while(a.S<a.P.f&&g){e=clb.We(a,d);for(b=0;b<a.P.f;b++){clb.sg(a.c[b],b);clb.pg(a.c[b],a.b,q1(a.d[b]));clb.pg(a.c[b],20,0);!a.ab[b]&&a._[b]!=0&&clb.qg(a.c[b],q1((a._[b]<<18)+(e[a._[b]==1?0:1][a.$[b]]<<8)));h=a.bb[b];a.cb[b]&&(h==1?h=2:h==2&&(h=1));clb.qg(a.c[b],Ykb.m1(h<<4));}for(c=0;c<a.P.g;c++){clb.qg(a.c[clb.zk(a.P,0,c)],q1(a.k[c]));clb.qg(a.c[clb.zk(a.P,1,c)],q1(a.k[c]));}f=clb._e(a);if(a.S==f)break;a.S=f;g=false;if(!!a.N&&clb.Ig(a.N,a.d)){g=true;d=clb.pf(a);}if(clb.Ue(a,false)){g=true;clb.$e(a);}}};clb.ff=function ff(a){var b,c;for(b=0;b<a.P.f;b++)(!a.K[b]||a.bb[b]==3)&&(a._[b]=0);for(c=0;c<a.P.g;c++)(clb.Kk(a.P,c)!=1||a.k[c]==0||a.k[c]==3)&&(a.j[c]=0);};clb.gf=function gf(a,b,c){if(a.a==null){a.a=gW(Ykb.wX,Fnb,6,a.P.f,15,1);dlb.Xbb(a.a);}a.a[b]=c<<24>>24;};clb.hf=function hf(b,c){var d,e,f,g,h,i;if((b.k[c]==1||b.k[c]==2)&&!clb.Co(b.P,c)){h=false;try{for(g=0;g<2;g++){d=clb.zk(b.P,g,c);if(clb.wn(b.P,d)==3){e=gW(Ykb.AX,gmb,6,2,15,1);f=0;for(i=0;i<clb.wn(b.P,d);i++)clb.xn(b.P,d,i)!=c&&(e[f++]=clb.vn(b.P,d,i));b.d[e[0]]>b.d[e[1]]^clb.kf(b,d,e[0],e[1])&&(h=!h);}}}catch(a){a=b1(a);if(mX(a,15)){b.f[c]=3;return;}else throw c1(a);}b.k[c]==1^h?b.f[c]=1:b.f[c]=2;}};clb.jf=function jf(b,c){var d,e,f,g,h,i,j;if(b.bb[c]==1||b.bb[c]==2){i=false;if(clb.mn(b.P,c)==2){try{for(h=0;h<2;h++){d=clb.vn(b.P,c,h);if(clb.wn(b.P,d)==3){f=gW(Ykb.AX,gmb,6,2,15,1);g=0;for(j=0;j<clb.wn(b.P,d);j++)clb.yn(b.P,d,j)==1&&(f[g++]=clb.vn(b.P,d,j));b.d[f[0]]>b.d[f[1]]^clb.kf(b,d,f[0],f[1])&&(i=!i);}}}catch(a){a=b1(a);if(mX(a,15)){b.Y[c]=3;return;}else throw c1(a);}}else {try{e=clb.mf(b,c);}catch(a){a=b1(a);if(mX(a,15)){b.Y[c]=3;return;}else throw c1(a);}for(h=1;h<e.length;h++)for(j=0;j<h;j++)b.d[e[h]]<b.d[e[j]]&&(i=!i);}b.bb[c]==1^i?b.Y[c]=1:b.Y[c]=2;}};clb.kf=function kf(a,b,c,d){var e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G,H,I,J,K,L;if(clb.uk(a.P,c)!=clb.uk(a.P,d))return clb.uk(a.P,c)>clb.uk(a.P,d);if(clb.nk(a.P,c)!=clb.nk(a.P,d)){H=clb.kl(a.P,c)?(clb.wj(),clb.uj)[clb.uk(a.P,c)]:clb.nk(a.P,c);I=clb.kl(a.P,d)?(clb.wj(),clb.uj)[clb.uk(a.P,d)]:clb.nk(a.P,d);return H>I;}w=a.P.f;s=gW(Ykb.AX,gmb,6,w,15,1);u=gW(Ykb.AX,gmb,6,w,15,1);v=gW(Ykb.AX,gmb,6,w,15,1);t=gW(Ykb.Z0,Amb,6,w,16,1);i=gW(Ykb.Z0,Amb,6,a.P.q,16,1);s[0]=b;s[1]=c;s[2]=d;u[0]=-1;u[1]=0;u[2]=0;i[b]=true;i[c]=true;i[d]=true;m=1;A=2;G=gW(Ykb.AX,gmb,6,64,15,1);G[1]=1;G[2]=3;o=2;while(m<=A){while(m<G[o]){n=s[m];if(!t[m]){p=0;q=0;for(C=0;C<clb.wn(a.P,n);C++){k=clb.vn(a.P,n,C);if(A+clb.yn(a.P,n,C)+1>=w){w+=a.P.f;s=clb.Vf(s,w);u=clb.Vf(u,w);v=clb.Vf(v,w);t=clb.Wf(t,w);}if(clb.qo(a.P,clb.xn(a.P,n,C))){++p;q+=clb.uk(a.P,k);}else {for(F=1;F<clb.yn(a.P,n,C);F++){++A;s[A]=k;u[A]=m;t[A]=true;}}K=u[m];if(k==s[K])continue;h=false;if(i[k]){J=u[K];while(J!=-1){if(k==s[J]){h=true;break;}J=u[J];}}if(h){++A;s[A]=k;u[A]=m;t[A]=true;}else {++A;s[A]=k;u[A]=m;i[k]=true;}}if(p!=0){++A;v[A]=(q<<2)/p|0;u[A]=m;t[A]=true;}}++m;if(m==$lb){throw c1(new Zkb.rz('Emergency break in while loop.'));}}G.length==o+1&&(G=clb.Vf(G,G.length+64));G[o+1]=A+1;for(B=G[o];B<G[o+1];B++){v[B]==0&&(v[B]=(clb.uk(a.P,s[B])==151?1:clb.uk(a.P,s[B])==152?1:clb.uk(a.P,s[B]))<<2);v[B]+=v[u[B]]<<16;}clb.of(a,t,v,u,s,G,o);if(v[1]!=v[2])return v[1]>v[2];o>1&&clb.lf(v,u,G,o);++o;}l=gW(Ykb.AX,gmb,6,a.P.f,15,1);D=false;for(f=0;f<a.P.f;f++){if(i[f]&&!clb.kl(a.P,f)){D=true;break;}}if(D){for(g=0;g<a.P.f;g++)l[g]=clb.kl(a.P,g)?(clb.wj(),clb.uj)[clb.uk(a.P,g)]:clb.nk(a.P,g);if(clb.nf(a,t,v,u,s,l,G,o))return v[1]>v[2];}dlb.bcb(l,l.length,0);r=false;for(j=0;j<a.P.g;j++){if(i[clb.zk(a.P,0,j)]||i[clb.zk(a.P,1,j)]){if(a.f[j]==1){l[clb.zk(a.P,0,j)]=1;l[clb.zk(a.P,1,j)]=1;r=true;}else if(a.f[j]==2){l[clb.zk(a.P,0,j)]=2;l[clb.zk(a.P,1,j)]=2;r=true;}}}if(r&&clb.nf(a,t,v,u,s,l,G,o))return v[1]>v[2];dlb.bcb(l,l.length,0);L=false;for(e=0;e<a.P.f;e++){if(i[e]){if(a.Y[e]==2){l[e]=1;L=true;}else if(a.Y[e]==1){l[e]=2;L=true;}}}if(L&&clb.nf(a,t,v,u,s,l,G,o))return v[1]>v[2];throw c1(new Zkb.rz('no distinction applying CIP rules'));};clb.lf=function lf(a,b,c,d){var e,f,g,h,i,j,k,l,m;l=c[d];g=c[d+1]-l;m=gW(Ykb.KX,Ulb,143,g,0,1);for(i=0;i<g;i++){m[i]=new clb.og();m[i].c=a[i+l];m[i].b=b[i+l];m[i].a=i+l;}e=new clb.lg();for(k=d;k>1;k--){for(j=0;j<g;j++){m[j].c+=a[m[j].b]<<16;m[j].b=b[m[j].b];}dlb.icb(m,0,m.length,e);f=1;for(h=0;h<g;h++){a[m[h].a]=f;h!=g-1&&clb.kg(m[h],m[h+1])!=0&&++f;}}};clb.mf=function mf(a,b){var c,d,e,f,g,h,i;g=clb.gn(a.P,b);h=gW(Ykb.AX,gmb,6,g,15,1);for(e=0;e<g;e++)h[e]=clb.vn(a.P,b,e);for(d=g;d>1;d--){c=false;for(f=1;f<d;f++){if(clb.kf(a,b,h[f-1],h[f])){c=true;i=h[f-1];h[f-1]=h[f];h[f]=i;}}if(!c)break;}return h;};clb.nf=function nf(a,b,c,d,e,f,g,h){var i,j;for(j=1;j<h;j++){for(i=g[j];i<g[j+1];i++)c[i]=f[e[i]]+(c[d[i]]<<8);clb.of(a,b,c,d,e,g,j);if(c[1]!=c[2])return true;j>1&&clb.lf(c,d,g,j);}return false;};clb.of=function of(a,b,c,d,e,f,g){var h,i,j,k,l,m,n,o,p,q,r;for(l=g;l>1;l--){p=f[l]-f[l-1];r=gW(Ykb.IX,Ulb,142,p,0,1);h=f[l];for(o=0;o<p;o++){q=f[l-1]+o;m=h;while(m<f[l+1]&&d[m]==q)++m;r[o]=new clb.ig();r[o].c=q;r[o].d=c[q];r[o].b=b[q]?0:clb.Vn(a.P,e[q]);r[o].a=gW(Ykb.AX,gmb,6,m-h,15,1);for(k=h;k<m;k++)r[o].a[k-h]=c[k];alb.jgb(r[o].a,alb.Pgb(X1(dlb.ucb.prototype.kc,dlb.ucb,[])));h=m;}i=new clb.fg();dlb.icb(r,0,r.length,i);j=1;for(n=0;n<p;n++){c[r[n].c]=j;n!=p-1&&clb.eg(r[n],r[n+1])!=0&&++j;}}};clb.pf=function pf(a){var b,c;c=eW(Ykb.AX,[Llb,Dnb],[26,7],0,[2,32],2);for(b=0;b<a.P.f;b++){a.K[b]&&(a._[b]==1?c[0][a.$[b]]=clb.Pg(c[0][a.$[b]],b):a._[b]==2&&(c[1][a.$[b]]=clb.Pg(c[0][a.$[b]],b)));}return c;};clb.qf=function qf(a){var b,c,d,e,f,g,h,i,j,k,l,m;f=0;k=0;g=0;h=0;i=0;j=0;l=0;m=false;b=gW(Ykb.Z0,Amb,6,32,16,1);for(c=0;c<a.P.f;c++){if(a.bb[c]!=0){++f;if(a.bb[c]==3){++k;}else {if(a._[c]==0){++g;!!a.N&&clb.Eg(a.N,c)&&++h;}else if(a._[c]==2){a.$[c]==0&&++j;}else if(a._[c]==1){e=a.$[c];if(!b[e]){++l;b[e]=true;}a.$[c]==0&&++i;!!a.N&&clb.Eg(a.N,c)&&(m=true);}}}}for(d=0;d<a.P.g;d++){if(a.k[d]!=0&&clb.Kk(a.P,d)==1){++f;if(a.k[d]==3){++k;}else {if(a.j[d]==0){++g;!!a.N&&clb.Eg(a.N,clb.zk(a.P,0,d))&&clb.Eg(a.N,clb.zk(a.P,1,d))&&++h;}else if(a.j[d]==2){a.i[d]==0&&++j;}else if(a.j[d]==1){e=a.i[d];if(!b[e]){++l;b[e]=true;}a.i[d]==0&&++i;!!a.N&&clb.Eg(a.N,clb.zk(a.P,0,d))&&clb.Eg(a.N,clb.zk(a.P,1,d))&&(m=true);}}}}if(f==0){clb.km(a.P,Ylb);return;}if(k!=0){clb.km(a.P,0);return;}if(a.I){clb.km(a.P,Gnb+(1<<l));return;}i+h==f&&!m?clb.km(a.P,196608):g==f?clb.km(a.P,tnb):j==f?clb.km(a.P,327680):g==f-1&&i==1?clb.km(a.P,Xmb):clb.km(a.P,458752+(1<<l));};clb.rf=function rf(a,b,c){while(c!=0){if(a.r==0){(!a.p||a.t!=63)&&(a.t+=64);Zkb.C5(a.s,a.t&Zlb);a.r=6;a.t=0;}a.t<<=1;a.t=I1(B1(q1(a.t),e1(b,1)));b=D1(b,1);--c;--a.r;}};clb.sf=function sf(a){a.t<<=a.r;(!a.p||a.t!=63)&&(a.t+=64);Zkb.C5(a.s,a.t&Zlb);return a.s.a;};clb.tf=function tf(a,b){a.s=new Zkb.J5();a.r=6;a.t=0;a.p=b;};clb.uf=function uf(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o,p,q;if(a.P.f==0){a.q='';return;}l=false;if(a.hb&&a.P.q>a.P.f&&!a.P.K){l=true;for(i=0;i<a.P.f;i++){if(clb.Kn(a.P,i)!=0){l=false;break;}}}q=a.hb?16:8;clb.tf(a,true);Zkb.C5(a.s,l?35:33);clb.rf(a,q1(a.hb?1:0),1);clb.rf(a,Ykb.m1(b?1:0),1);clb.rf(a,Ykb.m1(q/2|0),4);o=0;for(j=1;j<a.P.f;j++)o=clb.Hf(a,a.w[j],a.C[j]==-1?-1:a.w[a.C[j]],o,c);if(l){for(i=0;i<a.P.f;i++){d=a.w[i];for(n=clb.wn(a.P,d);n<clb.gn(a.P,d);n++)o=clb.Hf(a,clb.vn(a.P,d,n),d,o,c);}}if(a.P.f>1&&o==0){a.q='';return;}g=1<<q;m=o/(g/2-1);p=o+m/2;for(k=1;k<a.P.f;k++)clb.vf(a,a.w[k],a.C[k]==-1?-1:a.w[a.C[k]],p,m,q,c);if(l){for(h=0;h<a.P.f;h++){d=a.w[h];for(n=clb.wn(a.P,d);n<clb.gn(a.P,d);n++)clb.vf(a,clb.vn(a.P,d,n),d,p,m,q,c);}}if(b){f=a.hb?1.5:(clb.wj(),clb.wj(),clb.vj);e=clb.xk(a.P,l?a.P.q:a.P.f,l?a.P.r:a.P.g,f,c);clb.rf(a,q1($wnd.Math.min(g-1,$wnd.Math.max(0,vX(0.5+$wnd.Math.log(e/0.1)*$wnd.Math.LOG10E/($wnd.Math.log(2000)*$wnd.Math.LOG10E)*(g-1))))),q);clb.rf(a,q1(clb.yf(c[a.w[0]].a/e,g)),q);clb.rf(a,q1(clb.yf(c[a.w[0]].b/e,g)),q);a.hb&&clb.rf(a,q1(clb.yf(c[a.w[0]].c/e,g)),q);}a.q=clb.sf(a);};clb.vf=function vf(a,b,c,d,e,f,g){var h,i,j;h=c==-1?(g[b].a-g[a.w[0]].a)/8:g[b].a-g[c].a;i=c==-1?(g[b].b-g[a.w[0]].b)/8:g[b].b-g[c].b;clb.rf(a,q1(vX((d+h)/e)),f);clb.rf(a,q1(vX((d+i)/e)),f);if(a.hb){j=c==-1?(g[b].c-g[a.w[0]].c)/8:g[b].c-g[c].c;clb.rf(a,q1(vX((d+j)/e)),f);}};clb.wf=function wf(a,b){var c;for(c=0;c<a.u;c++)b-=16;b<0&&(Zkb.O5(),String.fromCharCode(10));while(b>15){clb.rf(a,1,1);clb.rf(a,15,4);b-=16;++a.u;}clb.rf(a,1,1);clb.rf(a,Ykb.m1(b),4);};clb.xf=function xf(a){var b,c,d,e,f,g;if(a.P.f==0){a.L='';return;}f=0;d=false;e=false;for(c=0;c<a.P.f;c++){f<clb.mk(a.P,c)&&(f=clb.mk(a.P,c));clb._k(a.P,c)?d=true:e=true;}if(f==0){a.L='';return;}g=clb.cg(f);clb.tf(a,true);clb.rf(a,Ykb.m1(g),4);clb.rf(a,Ykb.m1(d?1:0),1);clb.rf(a,Ykb.m1(e?1:0),1);for(b=0;b<a.P.f;b++){clb.rf(a,q1(clb.mk(a.P,a.w[b])),g);d&&e&&clb.rf(a,q1(clb._k(a.P,a.w[b])?1:0),1);}a.L=clb.sf(a);};clb.yf=function yf(a,b){var c,d,e,f;c=b/2|0;e=a<0;a=$wnd.Math.abs(a);f=b/32|0;d=$wnd.Math.min(c-1,I1(p1($wnd.Math.round(a*c/(a+f)))));return e?c+d:d;};clb.zf=function zf(a){var b,c,d;for(b=0;b<a.P.f;b++){a.bb[b]==3&&!clb.Xk(a.P,b)&&clb.sm(a.P,b);(clb.ik(a.P,b)==1||clb.ik(a.P,b)==2)&&a.bb[b]==3&&clb.sm(a.P,b);clb.Xk(a.P,b)&&a.bb[b]!=3&&!clb.Tf(a,b)&&clb.sm(a.P,b);}for(d=0;d<a.P.r;d++)clb.pl(a.P,d)&&!clb.Sf(a,d)&&clb.sm(a.P,clb.zk(a.P,0,d));for(c=0;c<a.P.g;c++){if(clb.Hk(a.P,c)==2){if(clb.fl(a.P,c)&&(a.k[c]==1||a.k[c]==2)){a.k[c]=3;clb.jm(a.P,c,386);}if(a.k[c]==3&&!a.n[c]){if(clb.Kk(a.P,c)!=386){clb.sm(a.P,clb.zk(a.P,0,c));clb.sm(a.P,clb.zk(a.P,1,c));}}}if(clb.Kk(a.P,c)==1&&a.k[c]==3&&!clb.Xk(a.P,clb.zk(a.P,0,c))&&!clb.Xk(a.P,clb.zk(a.P,1,c))){clb.sm(a.P,clb.zk(a.P,0,c));clb.sm(a.P,clb.zk(a.P,1,c));}if((clb.Ek(a.P,c)==1||clb.Ek(a.P,c)==2)&&(clb.Kk(a.P,c)!=1||a.k[c]!=1&&a.k[c]!=2)){clb.sm(a.P,clb.zk(a.P,0,c));clb.sm(a.P,clb.zk(a.P,1,c));}}};clb.Af=function Af(a){var b,c,d,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v;if(a.P.f==0)return;if(a.D)return;a.G=0;v=0;for(c=1;c<a.P.f;c++)a.d[c]>a.d[v]&&(v=c);d=gW(Ykb.Z0,Amb,6,a.P.f,16,1);g=gW(Ykb.Z0,Amb,6,a.P.g,16,1);a.F=gW(Ykb.AX,gmb,6,a.P.f,15,1);a.w=gW(Ykb.AX,gmb,6,a.P.f,15,1);a.C=gW(Ykb.AX,gmb,6,a.P.f,15,1);a.A=gW(Ykb.AX,gmb,6,a.P.g,15,1);a.w[0]=v;a.F[v]=0;d[v]=true;i=0;j=1;k=0;while(i<a.P.f){if(i<j){while(true){o=0;p=0;m=-1;b=a.w[i];for(q=0;q<clb.hn(a.P,b);q++){if(q<clb.wn(a.P,b)||q>=clb.gn(a.P,b)){h=clb.vn(a.P,b,q);if(!d[h]&&a.d[h]>m){o=h;p=clb.xn(a.P,b,q);m=a.d[h];}}}if(m==-1)break;a.F[o]=j;a.C[j]=i;a.w[j++]=o;a.A[k++]=p;d[o]=true;g[p]=true;}++i;}else {n=0;m=-1;for(b=0;b<a.P.f;b++){if(!d[b]&&a.d[b]>m){n=b;m=a.d[b];}}a.F[n]=j;a.C[j]=-1;a.w[j++]=n;d[n]=true;}}a.B=gW(Ykb.AX,gmb,6,2*(a.P.g-k),15,1);while(true){s=a.P.M;t=a.P.M;u=-1;for(f=0;f<a.P.g;f++){if(!g[f]){if(a.F[clb.zk(a.P,0,f)]<a.F[clb.zk(a.P,1,f)]){r=a.F[clb.zk(a.P,0,f)];l=a.F[clb.zk(a.P,1,f)];}else {r=a.F[clb.zk(a.P,1,f)];l=a.F[clb.zk(a.P,0,f)];}if(r<s||r==s&&l<t){s=r;t=l;u=f;}}}if(u==-1)break;g[u]=true;a.A[k++]=u;a.B[2*a.G]=s;a.B[2*a.G+1]=t;++a.G;}a.D=true;};clb.Bf=function Bf(a){var b,c,d,e,f,g,h,i,j,k,l,m,n,o;i=null;o=clb.Xn(a.P);for(l=0;l<o.i.a.length;l++){if(o.e[l]){f=0;m=dlb.Bi(o.i,l);for(c=m,d=0,e=c.length;d<e;++d){b=c[d];clb.Nf(a,b)&&++f;}if(f!=0){n=dlb.Bi(o.j,l);i==null&&(i=gW(Ykb.Z0,Amb,6,a.P.g,16,1));if(f==m.length){j=-1;k=Qlb;for(g=0;g<m.length;g++){if(k>a.w[n[g]]){k=a.w[n[g]];j=g;}}while(f>0){i[n[j]]=true;j=clb._f(j+2,m.length);f-=2;}}else {h=0;while(clb.Nf(a,m[h]))++h;while(!clb.Nf(a,m[h]))h=clb._f(h+1,m.length);while(f>0){i[n[h]]=true;h=clb._f(h+2,m.length);f-=2;while(!clb.Nf(a,m[h]))h=clb._f(h+1,m.length);}}}}}return i;};clb.Cf=function Cf(a,b){return a.k[b];};clb.Df=function Df(a){return clb.Ef(a,a.hb);};clb.Ef=function Ef(a,b){if(a.q==null){clb.Af(a);clb.uf(a,b,a.P.J);}return a.q;};clb.Ff=function Ff(a){if(a.L==null){clb.Af(a);clb.xf(a);}return a.L;};clb.Gf=function Gf(a){if(a.H==null){clb.Af(a);if((a.O&lnb)==0){clb.Pf(a);clb.Qf(a,1);clb.Qf(a,2);}clb.Of(a);}return a.H;};clb.Hf=function Hf(a,b,c,d,e){var f,g,h;f=c==-1?$wnd.Math.abs(e[b].a-e[a.w[0]].a)/8:$wnd.Math.abs(e[b].a-e[c].a);d<f&&(d=f);g=c==-1?$wnd.Math.abs(e[b].b-e[a.w[0]].b)/8:$wnd.Math.abs(e[b].b-e[c].b);d<g&&(d=g);if(a.hb){h=c==-1?$wnd.Math.abs(e[b].c-e[a.w[0]].c)/8:$wnd.Math.abs(e[b].c-e[c].c);d<h&&(d=h);}return d;};clb.If=function If(a,b){return a.V[b];};clb.Jf=function Jf(a,b){return a.W[b];};clb.Kf=function Kf(a,b){return a.e==null?-1:a.e[b];};clb.Lf=function Lf(a,b){return a.bb[b];};clb.Mf=function Mf(a,b){var c,d,e,f,g,h,i;i=clb.Xn(a.P);for(c=0;c<i.i.a.length;c++){if(i.d[c]&&clb.tr(i,c,b)){for(e=dlb.Bi(i.i,c),f=0,g=e.length;f<g;++f){d=e[f];if(d!=b)for(h=0;h<clb.wn(a.P,d);h++)if(clb.no(a.P,clb.xn(a.P,d,h)))return true;}return false;}}return false;};clb.Nf=function Nf(a,b){var c,d,e;if(clb.mn(a.P,b)<2)return false;if(clb.wn(a.P,b)==2)return true;c=0;for(e=0;e<clb.wn(a.P,b);e++){d=clb.xn(a.P,b,e);clb.mo(a.P,d)&&(c+=clb.Hk(a.P,d)-1);}return c>1;};clb.Of=function Of(a){var b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X;clb.tf(a,false);clb.rf(a,9,4);T=$wnd.Math.max(clb.cg(a.P.f),clb.cg(a.P.g));clb.rf(a,Ykb.m1(T),4);if(T==0){clb.rf(a,q1(a.P.K?1:0),1);clb.rf(a,0,1);a.H=clb.sf(a);return;}U=W=V=H=0;for(i=0;i<a.P.f;i++){if(o1(e1(clb.pk(a.P,i),1),0)){switch(clb.uk(a.P,i)){case 6:break;case 7:++U;break;case 8:++W;break;default:++V;}clb.dk(a.P,i)!=0&&++H;}}clb.rf(a,q1(a.P.f),T);clb.rf(a,q1(a.P.g),T);clb.rf(a,Ykb.m1(U),T);clb.rf(a,Ykb.m1(W),T);clb.rf(a,Ykb.m1(V),T);clb.rf(a,Ykb.m1(H),T);for(j=0;j<a.P.f;j++)clb.uk(a.P,a.w[j])==7&&o1(e1(clb.pk(a.P,a.w[j]),1),0)&&clb.rf(a,Ykb.m1(j),T);for(m=0;m<a.P.f;m++)clb.uk(a.P,a.w[m])==8&&o1(e1(clb.pk(a.P,a.w[m]),1),0)&&clb.rf(a,Ykb.m1(m),T);for(n=0;n<a.P.f;n++)if(clb.uk(a.P,a.w[n])!=6&&clb.uk(a.P,a.w[n])!=7&&clb.uk(a.P,a.w[n])!=8&&o1(e1(clb.pk(a.P,a.w[n]),1),0)){clb.rf(a,Ykb.m1(n),T);clb.rf(a,q1(clb.uk(a.P,a.w[n])),8);}for(o=0;o<a.P.f;o++)if(clb.dk(a.P,a.w[o])!=0&&o1(e1(clb.pk(a.P,a.w[o]),1),0)){clb.rf(a,Ykb.m1(o),T);clb.rf(a,q1(8+clb.dk(a.P,a.w[o])),4);}S=0;v=0;for(p=1;p<a.P.f;p++){if(a.C[p]==-1){L=0;}else {L=1+a.C[p]-v;v=a.C[p];}S<L&&(S=L);}K=clb.cg(S);clb.rf(a,Ykb.m1(K),4);v=0;for(q=1;q<a.P.f;q++){if(a.C[q]==-1){L=0;}else {L=1+a.C[q]-v;v=a.C[q];}clb.rf(a,Ykb.m1(L),K);}for(N=0;N<2*a.G;N++)clb.rf(a,q1(a.B[N]),T);for(A=0;A<a.P.g;A++){G=(clb.Jk(a.P,a.A[A])&nnb)!=0||clb.Kk(a.P,a.A[A])==32?1:clb.qo(a.P,a.A[A])?0:$wnd.Math.min(3,clb.Hk(a.P,a.A[A]));clb.rf(a,Ykb.m1(G),2);}c=0;if((a.O&lnb)==0){for(r=0;r<a.P.f;r++)a.Z[a.w[r]]!=0&&a.Z[a.w[r]]!=3&&++c;}clb.rf(a,Ykb.m1(c),T);if((a.O&lnb)==0){for(r=0;r<a.P.f;r++){if(a.Z[a.w[r]]!=0&&a.Z[a.w[r]]!=3){clb.rf(a,Ykb.m1(r),T);if(a._[a.w[r]]==0){clb.rf(a,q1(a.Z[a.w[r]]),3);}else {X=a.Z[a.w[r]]==1?a._[a.w[r]]==1?4:6:a._[a.w[r]]==1?5:7;clb.rf(a,Ykb.m1(X),3);clb.rf(a,q1(a.$[a.w[r]]),3);}}}}b=0;if((a.O&lnb)==0){for(B=0;B<a.P.g;B++)a.g[a.A[B]]!=0&&a.g[a.A[B]]!=3&&(!clb.Co(a.P,a.A[B])||clb.Kk(a.P,a.A[B])==1)&&++b;}clb.rf(a,Ykb.m1(b),T);if((a.O&lnb)==0){for(B=0;B<a.P.g;B++){if(a.g[a.A[B]]!=0&&a.g[a.A[B]]!=3&&(!clb.Co(a.P,a.A[B])||clb.Kk(a.P,a.A[B])==1)){clb.rf(a,Ykb.m1(B),T);if(clb.Kk(a.P,a.A[B])==1){if(a.j[a.A[B]]==0){clb.rf(a,q1(a.g[a.A[B]]),3);}else {X=a.g[a.A[B]]==1?a.j[a.A[B]]==1?4:6:a.j[a.A[B]]==1?5:7;clb.rf(a,Ykb.m1(X),3);clb.rf(a,q1(a.i[a.A[B]]),3);}}else {clb.rf(a,q1(a.g[a.A[B]]),2);}}}}clb.rf(a,q1(a.P.K?1:0),1);I=0;for(s=0;s<a.P.f;s++)clb.nk(a.P,a.w[s])!=0&&++I;if(I!=0){clb.wf(a,1);clb.rf(a,Ykb.m1(I),T);for(r=0;r<a.P.f;r++){if(clb.nk(a.P,a.w[r])!=0){clb.rf(a,Ykb.m1(r),T);clb.rf(a,q1(clb.nk(a.P,a.w[r])),8);}}}a.u=0;if(a.P.K){clb.ye(a,0,T,lnb,1,-1);clb.ye(a,3,T,Imb,1,-1);clb.ye(a,4,T,120,4,3);clb.ye(a,5,T,Hnb,2,1);clb.ye(a,6,T,1,1,-1);clb.ye(a,7,T,Mmb,4,7);I=0;for(r=0;r<a.P.f;r++)clb.kk(a.P,a.w[r])!=null&&++I;if(I>0){clb.wf(a,8);clb.rf(a,Ykb.m1(I),T);for(t=0;t<a.P.f;t++){u=clb.kk(a.P,a.w[t]);if(u!=null){clb.rf(a,Ykb.m1(t),T);clb.rf(a,q1(u.length),4);for(e=u,f=0,g=e.length;f<g;++f){d=e[f];clb.rf(a,Ykb.m1(d),8);}}}}clb.ze(a,9,T,384,2,7);clb.ze(a,10,T,31,5,0);clb.ye(a,11,T,knb,1,-1);clb.ze(a,12,T,nnb,8,9);clb.ye(a,13,T,Smb,3,14);clb.ye(a,14,T,Tmb,5,17);clb.ye(a,16,T,inb,3,22);}I=0;for(k=0;k<a.P.f;k++)a.a!=null&&a.a[a.w[k]]!=-1&&++I;if(I!=0){clb.wf(a,17);clb.rf(a,Ykb.m1(I),T);for(r=0;r<a.P.f;r++){if(a.a!=null&&a.a[a.w[r]]!=-1){clb.rf(a,Ykb.m1(r),T);clb.rf(a,q1(a.a[a.w[r]]),4);}}}if((a.O&8)!=0||(a.O&Nmb)!=0){I=0;R=0;for(r=0;r<a.P.f;r++){P=clb.fk(a.P,a.w[r]);if(P!=null){++I;R=$wnd.Math.max(R,alb.Pgb(P).length);}}if(I!=0){Q=clb.cg(R);clb.wf(a,18);clb.rf(a,Ykb.m1(I),T);clb.rf(a,Ykb.m1(Q),4);for(t=0;t<a.P.f;t++){J=clb.fk(a.P,a.w[t]);if(J!=null){clb.rf(a,Ykb.m1(t),T);clb.rf(a,q1(alb.Pgb(J).length),Q);for(M=0;M<alb.Pgb(J).length;M++)clb.rf(a,(alb.Kgb(M,alb.Pgb(J).length),q1(alb.Pgb(J).charCodeAt(M))),7);}}}}if(a.P.K){clb.ye(a,19,T,Omb,3,25);clb.ze(a,20,T,Ymb,3,17);}I=0;for(l=0;l<a.P.f;l++)clb.qk(a.P,a.w[l])!=0&&++I;if(I!=0){clb.wf(a,21);clb.rf(a,Ykb.m1(I),T);for(h=0;h<a.P.f;h++){if(clb.qk(a.P,a.w[h])!=0){clb.rf(a,Ykb.m1(h),T);clb.rf(a,q1(clb.qk(a.P,a.w[h])>>4),2);}}}if(a.P.K){clb.ye(a,22,T,jnb,1,-1);clb.ze(a,23,T,Inb,1,-1);clb.ze(a,24,T,onb,2,21);}if((a.O&16)!=0){for(h=0;h<a.P.f;h++){if(clb.nl(a.P,a.w[h])){clb.wf(a,25);for(d=0;d<a.P.f;d++)clb.rf(a,q1(clb.nl(a.P,a.w[d])?1:0),1);break;}}}O=clb.Bf(a);if(O!=null){I=0;for(B=0;B<a.P.g;B++)O[a.A[B]]&&++I;clb.wf(a,26);clb.rf(a,Ykb.m1(I),T);for(C=0;C<a.P.g;C++)O[a.A[C]]&&clb.rf(a,Ykb.m1(C),T);}a.P.K&&clb.ye(a,27,T,Bmb,1,-1);I=0;for(D=0;D<a.P.g;D++)clb.Kk(a.P,a.A[D])==32&&++I;if(I!=0){clb.wf(a,28);clb.rf(a,Ykb.m1(I),T);for(B=0;B<a.P.g;B++)clb.Kk(a.P,a.A[B])==32&&clb.rf(a,Ykb.m1(B),T);}if(a.P.K){clb.ye(a,29,T,Jnb,2,30);clb.ye(a,30,T,kmb,7,32);clb.ye(a,32,T,Knb,2,44);clb.ye(a,33,T,$mb,5,39);clb.ye(a,34,T,Lmb,1,-1);clb.ze(a,35,T,Lnb,1,-1);clb.ze(a,36,T,96,2,5);}I=0;for(F=0;F<a.P.g;F++)(clb.Kk(a.P,a.A[F])==8||clb.Kk(a.P,a.A[F])==16)&&++I;if(I!=0){clb.wf(a,37);clb.rf(a,Ykb.m1(I),T);for(w=0;w<a.P.g;w++){if(clb.Kk(a.P,a.A[w])==8||clb.Kk(a.P,a.A[w])==16){clb.rf(a,Ykb.m1(w),T);clb.rf(a,q1(clb.Kk(a.P,a.A[w])==8?0:1),1);}}}clb.rf(a,0,1);a.H=clb.sf(a);};clb.Pf=function Pf(a){var b,c,d,e,f,g,h,i,j,k,l;a.Z=gW(Ykb.wX,Fnb,6,a.P.f,15,1);for(b=0;b<a.P.f;b++){if(a.bb[b]==1||a.bb[b]==2){i=a.cb[b];if(clb.oo(a.P,b)){for(h=0;h<clb.wn(a.P,b);h++){e=clb.vn(a.P,b,h);l=0;k=gW(Ykb.AX,gmb,6,3,15,1);for(j=0;j<clb.wn(a.P,e);j++){k[l]=clb.vn(a.P,e,j);k[l]!=b&&++l;}l==2&&a.d[k[0]]>a.d[k[1]]^a.F[k[0]]<a.F[k[1]]&&(i=!i);}}else {for(h=1;h<clb.wn(a.P,b);h++){for(j=0;j<h;j++){f=clb.vn(a.P,b,h);g=clb.vn(a.P,b,j);a.d[f]>a.d[g]&&(i=!i);a.F[f]<a.F[g]&&(i=!i);}}}a.Z[b]=a.bb[b]==1^i?1:2;}else {a.Z[b]=a.bb[b];}}a.g=gW(Ykb.wX,Fnb,6,a.P.g,15,1);for(c=0;c<a.P.g;c++){if(a.k[c]==1||a.k[c]==2){i=false;for(h=0;h<2;h++){d=clb.zk(a.P,h,c);if(clb.wn(a.P,d)==3){k=gW(Ykb.AX,gmb,6,2,15,1);l=0;for(j=0;j<3;j++)clb.vn(a.P,d,j)!=clb.zk(a.P,1-h,c)&&(k[l++]=clb.vn(a.P,d,j));a.d[k[0]]>a.d[k[1]]&&(i=!i);a.F[k[0]]<a.F[k[1]]&&(i=!i);}}a.g[c]=a.k[c]==1^i?1:2;}else {a.g[c]=a.k[c];}}};clb.Qf=function Qf(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o;i=gW(Ykb.AX,gmb,6,32,15,1);j=0;for(d=0;d<a.P.f;d++){if((a.Z[d]==1||a.Z[d]==2)&&a._[d]==b){h=a.$[d];if(i[h]<a.d[d]){i[h]==0&&++j;i[h]=a.d[d];}}}for(f=0;f<a.P.g;f++){if((a.g[f]==1||a.g[f]==2)&&a.j[f]==b&&clb.Kk(a.P,f)==1){h=a.i[f];o=$wnd.Math.max(a.d[clb.zk(a.P,0,f)],a.d[clb.zk(a.P,1,f)]);if(i[h]<o){i[h]==0&&++j;i[h]=o;}}}g=gW(Ykb.wX,Fnb,6,32,15,1);for(k=0;k<j;k++){m=-1;n=0;for(l=0;l<32;l++){if(n<i[l]){n=i[l];m=l;}}i[m]=0;g[m]=k<<24>>24;}for(c=0;c<a.P.f;c++)(a.Z[c]==1||a.Z[c]==2)&&a._[c]==b&&(a.$[c]=g[a.$[c]]);for(e=0;e<a.P.g;e++)(a.g[e]==1||a.g[e]==2)&&a.j[e]==b&&clb.Kk(a.P,e)==1&&(a.i[e]=g[a.i[e]]);};clb.Rf=function Rf(a,b,c){var d,e;a.S=b;for(d=0;d<a.P.f;d++){a.d[d]=c[d];a.bb[d]=0;a.gb[d]=false;}for(e=0;e<a.P.g;e++){a.k[e]=0;a.o[e]=false;}};clb.Sf=function Sf(a,b){var c,d,e;c=clb.zk(a.P,0,b);if(c>=a.P.f)return false;if(a.bb[c]==1||a.bb[c]==2)return true;if(a.bb[c]==3)return false;d=clb.cn(a.P,c);if(d!=-1)return a.k[d]==1||a.k[d]==2;for(e=0;e<clb.wn(a.P,c);e++){if(clb.yn(a.P,c,e)==2){if(a.bb[clb.vn(a.P,c,e)]==1||a.bb[clb.vn(a.P,c,e)]==2)return true;}}return false;};clb.Tf=function Tf(a,b){var c;for(c=0;c<clb.wn(a.P,b);c++)if(a.k[clb.xn(a.P,b,c)]==3&&clb.yn(a.P,b,c)==1)return true;return false;};clb.Uf=function Uf(a){var b,c,d,e,f,g,h;g=gW(Ykb.AX,gmb,6,a.S+1,15,1);for(c=0;c<a.P.f;c++){clb.ik(a.P,c)==0&&(a.bb[c]==1?++g[a.d[c]]:a.bb[c]==2&&--g[a.d[c]]);}for(e=0;e<a.P.g;e++){if(clb.Hk(a.P,e)==1&&clb.Ek(a.P,e)==0){if(a.k[e]==1){++g[a.d[clb.zk(a.P,0,e)]];++g[a.d[clb.zk(a.P,1,e)]];}else if(a.k[e]==2){--g[a.d[clb.zk(a.P,0,e)]];--g[a.d[clb.zk(a.P,1,e)]];}}}for(h=1;h<=a.S;h++){if(g[h]!=0){f=g[h]<0;if(f){for(b=0;b<a.P.f;b++){clb.ik(a.P,b)==0&&(a.bb[b]==1?a.bb[b]=2:a.bb[b]==2&&(a.bb[b]=1));}for(d=0;d<a.P.g;d++){clb.Hk(a.P,d)==1&&clb.Ek(a.P,d)==0&&(a.k[d]==1?a.k[d]=2:a.k[d]==2&&(a.k[d]=1));}}return f;}}return false;};clb.Vf=function Vf(a,b){var c;c=gW(Ykb.AX,gmb,6,b,15,1);Zkb.P5(a,0,c,0,a.length);return c;};clb.Wf=function Wf(a,b){var c;c=gW(Ykb.Z0,Amb,6,b,16,1);Zkb.P5(a,0,c,0,a.length);return c;};clb.Xf=function Xf(a){var b,c;if(a.Y!=null)for(b=0;b<a.P.f;b++)clb.Hl(a.P,b,a.Y[b]);if(a.f!=null)for(c=0;c<a.P.g;c++)clb.cm(a.P,c,a.f[c]);};clb.Yf=function Yf(a){var b,c,d,e,f,g,h,i,j,k,l;for(b=0;b<a.P.f;b++){if(a.bb[b]==1||a.bb[b]==2){i=false;if(clb.oo(a.P,b)){for(h=0;h<clb.wn(a.P,b);h++){e=clb.vn(a.P,b,h);l=0;k=gW(Ykb.AX,gmb,6,3,15,1);for(j=0;j<clb.wn(a.P,e);j++){k[l]=clb.vn(a.P,e,j);k[l]!=b&&++l;}l==2&&a.d[k[0]]>a.d[k[1]]^k[0]<k[1]&&(i=!i);}}else {for(h=1;h<clb.wn(a.P,b);h++){for(j=0;j<h;j++){f=clb.vn(a.P,b,h);g=clb.vn(a.P,b,j);a.d[f]>a.d[g]&&(i=!i);f<g&&(i=!i);}}}clb.Tl(a.P,b,a.bb[b]==1^i?1:2,a.db[b]);}else {clb.Tl(a.P,b,a.bb[b],a.db[b]);}}for(c=0;c<a.P.g;c++){if(a.k[c]==1||a.k[c]==2){i=false;for(h=0;h<2;h++){d=clb.zk(a.P,h,c);if(clb.wn(a.P,d)==3){k=gW(Ykb.AX,gmb,6,2,15,1);l=0;for(j=0;j<3;j++)clb.vn(a.P,d,j)!=clb.zk(a.P,1-h,c)&&(k[l++]=clb.vn(a.P,d,j));a.d[k[0]]>a.d[k[1]]&&(i=!i);k[0]<k[1]&&(i=!i);}}clb.gm(a.P,c,a.k[c]==1^i?1:2,a.n[c]);}else {clb.gm(a.P,c,a.k[c],a.n[c]);}}};clb.Zf=function Zf(a){var b;for(b=0;b<a.P.f;b++){clb.Xl(a.P,b,a.K[b]);}};clb.$f=function $f(a){var b,c,d;for(b=0;b<a.P.f;b++)!clb.Xk(a.P,b)&&a.bb[b]==3&&clb.Kl(a.P,b,true);for(c=0;c<a.P.g;c++){if(a.k[c]==3){d=clb.Hk(a.P,c);d==1?clb.Kl(a.P,clb.zk(a.P,0,c),true):d==2&&clb.jm(a.P,c,386);}}};clb._f=function _f(a,b){return a<b?a:a-b;};clb.ag=function ag(a){clb.bg.call(this,a,0);};clb.bg=function bg(a,b){this.P=a;this.O=b;clb.Gt(this.P,7);this.b=clb.cg(this.P.f);(this.O&lnb)==0&&clb.Te(this);this.hb=(b&64)!=0||clb.Wk(this.P);if((this.O&lnb)==0){this.bb=gW(Ykb.wX,Fnb,6,this.P.f,15,1);this.db=gW(Ykb.Z0,Amb,6,this.P.f,16,1);this.gb=gW(Ykb.Z0,Amb,6,this.P.f,16,1);this.k=gW(Ykb.wX,Fnb,6,this.P.g,15,1);this.o=gW(Ykb.Z0,Amb,6,this.P.g,16,1);this.n=gW(Ykb.Z0,Amb,6,this.P.g,16,1);}clb.Xe(this);(this.O&lnb)==0&&clb.bf(this);clb.af(this);};clb.cg=function cg(a){var b;b=0;while(a>0){a>>=1;++b;}return b;};U1(28,1,{},clb.ag,clb.bg);_.b=0;_.p=false;_.r=0;_.t=0;_.u=0;_.D=false;_.G=0;_.I=false;_.J=false;_.M=0;_.O=0;_.R=0;_.S=0;_.X=false;_.hb=false;Ykb.SX=w3(28);clb.dg=function dg(a,b){var c,d,e,f;if(a.d!=b.d)return a.d>b.d?1:-1;e=a.a.length;f=b.a.length;c=$wnd.Math.min(e,f);for(d=0;d<c;d++){--e;--f;if(a.a[e]!=b.a[f])return a.a[e]>b.a[f]?1:-1;}if(e!=f)return e>f?1:-1;if(a.b!=b.b)return a.b>b.b?1:-1;return 0;};clb.eg=function eg(a,b){return clb.dg(a,b);};clb.fg=function fg(){};U1(238,1,{},clb.fg);_.pb=function gg(a,b){return clb.eg(a,b);};_.ib=function hg(a){return this===a;};Ykb.JX=w3(238);clb.ig=function ig(){};U1(142,1,{142:1},clb.ig);_.b=0;_.c=0;_.d=0;Ykb.IX=w3(142);clb.jg=function jg(a,b){if(a.c!=b.c)return a.c>b.c?1:-1;return 0;};clb.kg=function kg(a,b){return clb.jg(a,b);};clb.lg=function lg(){};U1(239,1,{},clb.lg);_.pb=function mg(a,b){return clb.kg(a,b);};_.ib=function ng(a){return this===a;};Ykb.LX=w3(239);clb.og=function og(){};U1(143,1,{143:1},clb.og);_.a=0;_.b=0;_.c=0;Ykb.KX=w3(143);clb.pg=function pg(a,b,c){if(a.b==0){++a.c;a.b=63;}if(a.b==63){a.d[a.c]=B1(a.d[a.c],c);a.b-=b;}else {if(a.b>=b){a.d[a.c]=C1(a.d[a.c],b);a.d[a.c]=B1(a.d[a.c],c);a.b-=b;}else {a.d[a.c]=C1(a.d[a.c],a.b);a.d[a.c]=B1(a.d[a.c],D1(c,b-a.b));b-=a.b;++a.c;a.b=63-b;a.d[a.c]=B1(a.d[a.c],e1(c,Ykb.m1((1<<b)-1)));}}};clb.qg=function qg(a,b){a.d[a.c]=d1(a.d[a.c],b);};clb.rg=function rg(a,b){var c;for(c=0;c<a.c;c++)if(z1(a.d[c],b.d[c]))return u1(a.d[c],b.d[c])?-1:1;return o1(a.d[a.c],b.d[a.c])?0:u1(a.d[a.c],b.d[a.c])?-1:1;};clb.sg=function sg(a,b){a.a=b;a.c=0;a.b=63;dlb.Zbb(a.d);};clb.tg=function tg(a){this.d=gW(Ykb.BX,Anb,6,a,14,1);};U1(110,1,{110:1,27:1},clb.tg);_.qb=function ug(a){return clb.rg(this,a);};_.a=0;_.b=0;_.c=0;Ykb.MX=w3(110);clb.vg=function vg(a,b){if(a.b!=b.b)return a.b>b.b?-1:1;if(a.c!=b.c)return a.c>b.c?-1:1;return 0;};clb.wg=function wg(a,b,c){this.b=$wnd.Math.max(a,b);this.c=$wnd.Math.min(a,b);this.a=c;};U1(141,1,{141:1,27:1},clb.wg);_.qb=function xg(a){return clb.vg(this,a);};_.a=0;_.b=0;_.c=0;Ykb.NX=w3(141);clb.yg=function yg(a,b,c,d){this.a=(alb.Agb(b),dlb.Wbb(a,gW(Ykb.AX,gmb,6,b,15,1),b));this.b=(alb.Agb(d),dlb.Wbb(c,gW(Ykb.AX,gmb,6,d,15,1),d));};U1(173,1,{173:1},clb.yg);Ykb.OX=w3(173);clb.zg=function zg(a,b){var c,d;for(d=0;d<a.g[b].length;d++){c=a.g[b][d];if(a.f[c]&&(a.o[c]==1||a.o[c]==2)&&a.k[c]==0)return true;}return false;};clb.Ag=function Ag(a,b,c){var d,e,f,g,h;e=0;g=0;for(h=0;h<a.g[b].length;h++){d=a.g[b][h];if(a.k[d]==c){f=1<<a.j[d];if((g&f)==0){g|=f;++e;}}}return e;};clb.Bg=function Bg(a){var b,c,d,e,f,g,h,i,j,k,l,m;k=new dlb.hfb();for(l=0;l<a.i.f;l++){if(clb.mn(a.i,l)<2||clb.wn(a.i,l)>2){for(g=1;g<clb.wn(a.i,l);g++){b=clb.vn(a.i,l,g);for(h=0;h<g;h++){c=clb.vn(a.i,l,h);clb.Gg(a,b,c)&&(i=clb.Ng(a,b,c),!!i&&clb.Up(i,a.f)&&dlb.keb(k.a,i,(Zkb.L2(),K2))==null);}}}}for(m=0;m<a.i.g;m++){if(a.c[m]!=0){if(clb.Hk(a.i,m)!=2||a.c[m]!=2)continue;}b=clb.zk(a.i,0,m);c=clb.zk(a.i,1,m);clb.Gg(a,b,c)&&(i=clb.Ng(a,b,c),!!i&&clb.Up(i,a.f)&&dlb.keb(k.a,i,(Zkb.L2(),K2))==null);}a.g=gW(Ykb.AX,Dnb,7,k.a.c,0,2);a.e=gW(Ykb.Z0,Amb,6,a.i.f,16,1);f=0;for(j=(e=new dlb.Ceb(new dlb.Heb(new dlb.Wab(k.a).a).b),new dlb.cbb(e));dlb.H9(j.a.a);){i=(d=dlb.Aeb(j.a),d.hc());a.g[f++]=i.b;for(g=0;g<i.b.length;g++)a.e[i.b[g]]=true;}};clb.Cg=function Cg(a,b,c,d){var e,f,g,h,i,j,k;e=gW(Ykb.AX,gmb,6,clb.wn(a.i,c),15,1);h=0;for(g=0;g<clb.wn(a.i,c);g++){e[h]=clb.vn(a.i,c,g);!d[e[h]]&&clb.Gg(a,b,e[h])&&++h;}if(h==0)return -1;if(h==1)return e[0];i=-1;j=Qlb;for(f=0;f<h;f++){k=clb.Un(a.i,b,e[f],Qlb,d);if(k<j){j=k;i=e[f];}}return i;};clb.Dg=function Dg(a,b){return a.f[b]&&(a.o[b]==1||a.o[b]==2);};clb.Eg=function Eg(a,b){return a.e[b];};clb.Fg=function Fg(a){var b,c;c=true;for(b=0;b<a.i.f;b++){if(a.o[b]!=0&&!a.e[b]){c=false;break;}}return c;};clb.Gg=function Gg(a,b,c){var d,e,f,g,h;if(b==c)return false;if(a.a[b]!=a.a[c])return false;if(a.o[b]!=0){if(a.o[b]==3||a.o[c]==3)return false;if(a.p[b]^a.o[b]!==a.o[c])return false;if(a.k[b]!==a.k[c]||a.j[b]!==a.j[c])return false;}d=clb.tn(a.i,b,c);if(d!=-1){if(clb.Hk(a.i,d)==1&&a.c[d]!=0)return false;if(clb.Hk(a.i,d)==2&&a.c[d]==1)return false;}if(clb.mn(a.i,b)==1&&!clb.lo(a.i,b)){e=-1;for(h=0;h<clb.wn(a.i,b);h++){if(clb.vn(a.i,b,h)!=c&&clb.yn(a.i,b,h)==2){e=clb.xn(a.i,b,h);break;}}f=-1;for(g=0;g<clb.wn(a.i,c);g++){if(clb.vn(a.i,c,g)!=b&&clb.yn(a.i,c,g)==2){f=clb.xn(a.i,c,g);break;}}if(e!=-1&&a.c[e]!=0&&a.d[e]^a.c[e]===a.c[f])return false;}return true;};clb.Hg=function Hg(a,b,c,d,e){var f,g,h,i,j,k;i=null;f=null;for(k=0;k<a.g[b].length;k++){g=a.g[b][k];a.f[g]&&(a.o[g]==1||a.o[g]==2)&&(a.k[g]==0?f=clb.Pg(f,(e[g]<<16)+g):a.k[g]==d&&a.j[g]==c&&(i=clb.Pg(i,(e[g]<<16)+g)));}h=clb.bh(i,f);if(h==0)return false;if(h<0){for(j=0;j<a.g[b].length;j++){g=a.g[b][j];if(a.f[g]&&(a.o[g]==1||a.o[g]==2)){if(a.k[g]==0){a.k[g]=d<<24>>24;a.j[g]=c<<24>>24;}else if(a.k[g]==d&&a.j[g]==c){a.k[g]=0;a.j[g]=-1;}}}}return true;};clb.Ig=function Ig(a,b){var c,d,e,f,g,h;if(!a.b)return false;e=false;for(f=a.b.a.length-1;f>=0;f--){d=false;g=dlb.Bi(a.b,f);g.a==2?d=clb.Hg(a,g.b,g.c,g.d,b):g.a==1&&(d=clb.Mg(a,g.b,b));if(d){dlb.Ji(a.b,g);for(h=0;h<a.g[g.b].length;h++){c=a.g[g.b][h];a.n[c]=false;}e=true;}}return e;};clb.Jg=function Jg(a){var b,c,d,e,f,g,h,i;if(a.g!=null){g=new clb.ah(a);a.b=new dlb.Qi();for(e=0;e<a.g.length;e++){d=clb.Ug(g,e);if(d==0){clb.Qg(g,e);h=clb.Ag(a,e,2);b=clb.Ag(a,e,1);c=clb.zg(a,e);if(h==1&&b==1&&!c){clb.Lg(a,e,g.a+g.f++);dlb.wi(a.b,new clb.mj(e,1,-1,-1));}if(h>0){if(c){clb.Kg(a,e,g.i+g.g++,2);++h;}dlb.wi(a.b,new clb.mj(e,1,-1,-1));}else if(b>0){c&&clb.Kg(a,e,g.a+g.f++,1);dlb.wi(a.b,new clb.mj(e,1,-1,-1));}else if(c){clb.Kg(a,e,g.a+g.f++,1);dlb.wi(a.b,new clb.mj(e,1,-1,-1));}}else if(d==1){if(clb.zg(a,e)){f=clb.Tg(g,e);i=clb.Vg(g,e);dlb.wi(a.b,new clb.mj(e,2,f,i));}else {clb.Qg(g,e);dlb.wi(a.b,new clb.mj(e,1,-1,-1));}}}}};clb.Kg=function Kg(a,b,c,d){var e,f;for(f=0;f<a.g[b].length;f++){e=a.g[b][f];if(a.f[e]&&(a.o[e]==1||a.o[e]==2)&&a.k[e]==0){a.k[e]=d<<24>>24;a.j[e]=c<<24>>24;}}};clb.Lg=function Lg(a,b,c){var d,e;for(e=0;e<a.g[b].length;e++){d=a.g[b][e];if(a.k[d]==2){a.k[d]=1;a.j[d]=c<<24>>24;}}};clb.Mg=function Mg(a,b,c){var d,e,f,g,h,i,j,k;f=a.g[b];e=1;for(i=0;i<f.length;i++){d=f[i];if(a.f[d]&&a.k[d]==2){e=2;break;}}g=gW(Ykb.AX,Dnb,7,32,0,2);for(j=0;j<f.length;j++){d=f[j];a.f[d]&&a.k[d]==e&&(g[a.j[d]]=clb.Pg(g[a.j[d]],(c[d]<<16)+d));}for(k=0;k<32;k++)g[k]!=null&&alb.jgb(g[k],alb.Pgb(X1(dlb.ucb.prototype.kc,dlb.ucb,[])));dlb.mcb(g,new clb.dh());if(clb.bh(g[0],g[1])==0)return false;for(h=0;h<g[0].length;h++){d=g[0][h]&Zlb;a.k[d]=0;a.j[d]=-1;}return true;};clb.Ng=function Ng(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v;i=gW(Ykb.AX,gmb,6,a.i.f,15,1);r=gW(Ykb.AX,gmb,6,a.i.f,15,1);o=gW(Ykb.Z0,Amb,6,a.i.f,16,1);j=gW(Ykb.Z0,Amb,6,a.i.f,16,1);s=new clb.Vp(a.i.f);i[0]=b;r[b]=c;r[c]=-2;s.a[b]=true;s.a[c]=true;f=0;k=0;while(f<=k){g=i[f];if(r[g]==g){for(l=0;l<clb.wn(a.i,g);l++){d=clb.vn(a.i,g,l);if(!s.a[d]){if(clb.yn(a.i,g,l)==2&&clb.uk(a.i,d)<10){i[++k]=d;r[d]=d;j[d]=j[g]||clb.mn(a.i,d)==2;o[d]=j[g]&&!o[g];s.a[d]=true;}else if(j[g]&&o[g]){t=clb.Cg(a,d,r[g],s.a);if(t==-1)return null;i[++k]=d;r[d]=t;r[t]=-2;j[d]=false;s.a[d]=true;s.a[t]=true;}else if(clb.zo(a.i,clb.xn(a.i,g,l))){i[++k]=d;r[d]=d;j[d]=false;s.a[d]=true;if((clb.uk(a.i,d)==6&&clb.mn(a.i,d)==0||clb.uk(a.i,d)==7&&clb.dk(a.i,d)==1||clb.uk(a.i,d)==14||clb.uk(a.i,d)==15&&clb.wn(a.i,d)>2||clb.uk(a.i,d)==16&&clb.wn(a.i,d)>2)&&clb.wn(a.i,d)>2){h=false;for(p=1;p<clb.wn(a.i,d);p++){u=clb.vn(a.i,d,p);if(!s.a[u]){for(q=0;q<p;q++){v=clb.vn(a.i,d,q);if(!s.a[v]){if(clb.Gg(a,u,v)){i[++k]=u;r[u]=v;r[v]=-2;j[u]=false;s.a[u]=true;s.a[v]=true;h=true;}}}}}if(!h)return null;}}}}}else {e=gW(Ykb.Z0,Amb,6,clb.wn(a.i,g),16,1);for(m=0;m<clb.wn(a.i,g);m++){d=clb.vn(a.i,g,m);if(s.a[d]){e[m]=r[d]==d;}else {for(p=0;p<clb.wn(a.i,d);p++){if(clb.vn(a.i,d,p)==r[g]){e[m]=true;break;}}}}for(n=0;n<clb.wn(a.i,g);n++){if(e[n]){d=clb.vn(a.i,g,n);if(s.a[d]){if(clb.tn(a.i,d,r[g])==-1)return null;}else {i[++k]=d;r[d]=d;o[d]=false;j[d]=true;s.a[d]=true;}}}for(l=0;l<clb.wn(a.i,g);l++){if(!e[l]){d=clb.vn(a.i,g,l);if(!s.a[d]){t=clb.Cg(a,d,r[g],s.a);if(t==-1)return null;i[++k]=d;r[d]=t;r[t]=-2;j[d]=false;s.a[d]=true;s.a[t]=true;}}}}++f;}return s;};clb.Og=function Og(a,b,c,d,e,f,g,h,i,j){this.i=a;this.a=b;this.f=c;this.o=d;this.c=e;this.k=f;this.j=g;this.p=h;this.d=i;this.n=j;clb.Bg(this);};clb.Pg=function Pg(a,b){var c,d;d=gW(Ykb.AX,gmb,6,a==null?1:a.length+1,15,1);for(c=0;c<d.length-1;c++)d[c]=a[c];d[d.length-1]=b;return d;};U1(263,1,{},clb.Og);Ykb.QX=w3(263);clb.Qg=function Qg(a,b){var c,d,e,f,g,h;for(e=0;e<a.b;e++){if(a.e[e][b]&&a.c[e]!=-3){for(d=0;d<=a.j.g.length;d++){if(d!=b&&a.e[e][d]){a.e[e][b]=false;h=e<a.a?e:e<a.b?e-a.a:-1;g=clb.$g(a,e<a.a?1:e<a.b?2:0);for(f=0;f<a.j.g[b].length;f++){c=a.j.g[b][f];clb.Dg(a.j,c)&&a.j.j[c]==h&&(a.j.j[c]=g<<24>>24);}}}}}};clb.Rg=function Rg(a,b,c){var d,e,f,g,h;h=false;g=1;b[c]=g;d=true;while(d){d=false;for(e=0;e<a.b;e++){if(b[e]==g){for(f=0;f<a.b;f++){if(b[f]==0&&clb.Zg(a,e,f)){if(a.c[f]==-2){b[f]=g+1;d=true;}else if(a.c[f]!=a.c[c]){b[f]=g+1;h=true;}}}}}++g;}return h;};clb.Sg=function Sg(a,b,c,d){var e,f,g,h,i,j,k,l,m,n,o;for(i=d+1;i<a.j.g.length;i++){if(i!=d&&a.e[b][i]&&a.e[c][i]){g=gW(Ykb.AX,gmb,6,2,15,1);g[0]=c;g[1]=b;return g;}}o=gW(Ykb.AX,gmb,6,a.b,15,1);k=gW(Ykb.AX,gmb,6,a.b,15,1);j=gW(Ykb.AX,gmb,6,a.b,15,1);f=0;l=0;j[0]=b;k[b]=1;while(f<=l){for(m=0;m<a.d[j[f]].length;m++){e=a.d[j[f]][m];if(e==c){if(f==0)continue;h=k[j[f]]+1;g=gW(Ykb.AX,gmb,6,h,15,1);g[0]=e;g[1]=j[f];for(n=2;n<h;n++)g[n]=o[g[n-1]];return g;}if(k[e]==0&&a.c[e]!=-3){k[e]=k[j[f]]+1;j[++l]=e;o[e]=j[f];}}++f;}return null;};clb.Tg=function Tg(a,b){var c;for(c=0;c<a.b;c++)if(a.e[c][b]&&a.c[c]==-3)return c<a.a?c:c<a.b?c-a.a:-1;return -1;};clb.Ug=function Ug(a,b){var c,d;c=0;for(d=0;d<a.b;d++)a.e[d][b]&&a.c[d]==-3&&++c;return c;};clb.Vg=function Vg(a,b){var c;for(c=0;c<a.b;c++)if(a.e[c][b]&&a.c[c]==-3)return c<a.a?1:c<a.b?2:0;return -1;};clb.Wg=function Wg(a,b){return b<a.a?b:b<a.b?b-a.a:-1;};clb.Xg=function Xg(a,b){return b<a.a?1:b<a.b?2:0;};clb.Yg=function Yg(a,b){var c,d;d=a.j.k[b];c=a.j.j[b];return d==0?a.b:d==1?c:a.a+c;};clb.Zg=function Zg(a,b,c){var d;for(d=0;d<a.j.g.length;d++)if(a.e[b][d]&&a.e[c][d])return true;return false;};clb.$g=function $g(a,b){return b==1?a.a+a.f++:a.i+a.g++;};clb._g=function _g(a,b){var c,d,e,f,g,h,i,j,k,l;k=Qlb;i=-1;l=-1;j=-1;for(d=0;d<a.j.i.f;d++){if(clb.Dg(a.j,d)&&a.j.k[d]!=0){for(h=0;h<b.length;h++){e=clb.Wg(a,b[h]);f=clb.Xg(a,b[h]);if(a.j.k[d]==f&&a.j.j[d]==e){if(k>a.j.a[d]+(f==1?Ylb:0)){k=a.j.a[d]+(f==1?Ylb:0);i=e;l=f;j=b[h];}}}}}for(c=0;c<a.j.i.f;c++){if(clb.Dg(a.j,c)&&a.j.k[c]==l&&a.j.j[c]==i){a.j.k[c]=0;a.j.j[c]=-1;}}for(g=0;g<a.j.g.length;g++)a.e[j][g]=false;};clb.ah=function ah(a){var b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q;this.j=a;for(d=0;d<a.i.f;d++){a.f[d]&&(a.o[d]==1||a.o[d]==2)&&(a.k[d]==1?this.a<=a.j[d]&&(this.a=1+a.j[d]):a.k[d]==2&&this.i<=a.j[d]&&(this.i=1+a.j[d]));}this.b=this.a+this.i;this.e=eW(Ykb.Z0,[Llb,Amb],[11,6],16,[this.b+1,a.g.length+1],2);for(e=0;e<a.i.f;e++)a.f[e]&&(a.o[e]==1||a.o[e]==2)&&!a.e[e]&&(this.e[clb.Yg(this,e)][a.g.length]=true);for(i=0;i<a.g.length;i++){for(q=0;q<a.g[i].length;q++){c=a.g[i][q];a.f[c]&&(a.o[c]==1||a.o[c]==2)&&(this.e[clb.Yg(this,c)][i]=true);}}this.d=gW(Ykb.AX,Dnb,7,this.b,0,2);for(j=0;j<a.g.length;j++){for(n=1;n<this.b;n++){if(this.e[n][j]){for(o=0;o<n;o++){if(this.e[o][j]){this.d[n]=clb.Pg(this.d[n],o);this.d[o]=clb.Pg(this.d[o],n);}}}}}this.c=gW(Ykb.AX,gmb,6,this.b+1,15,1);for(m=0;m<this.b;m++){this.e[m][a.g.length]?this.c[m]=-1:this.c[m]=-2;}for(k=0;k<a.g.length;k++){if(this.e[this.b][k]){for(l=0;l<this.b;l++){this.e[l][k]&&this.c[l]!=k&&(this.c[l]==-2?this.c[l]=k:this.c[l]=-3);}}}for(b=0;b<this.b;b++){if(this.c[b]>=-1){f=gW(Ykb.AX,gmb,6,this.b,15,1);if(clb.Rg(this,f,b)){for(l=0;l<this.b;l++){f[l]!=0&&(this.c[l]=-3);}}}}for(h=0;h<a.g.length-1;h++){for(n=1;n<this.b;n++){if(this.e[n][h]&&this.c[n]!=-3){for(o=0;o<n;o++){if(this.e[o][h]&&this.c[o]!=-3){g=clb.Sg(this,n,o,h);if(g!=null){for(p=0;p<g.length;p++)this.c[g[p]]=-3;clb._g(this,g);break;}}}}}}};U1(264,1,{},clb.ah);_.a=0;_.b=0;_.f=0;_.g=0;_.i=0;Ykb.PX=w3(264);clb.bh=function bh(a,b){var c,d;if(a==null)return b==null?0:1;if(b==null)return -1;c=$wnd.Math.min(a.length,b.length);for(d=0;d<c;d++)if((a[d]&Mnb)!=(b[d]&Mnb))return (a[d]&Mnb)<(b[d]&Mnb)?-1:1;return a.length==b.length?0:a.length<b.length?-1:1;};clb.dh=function dh(){};U1(265,1,{},clb.dh);_.pb=function eh(a,b){return clb.bh(a,b);};_.ib=function fh(a){return this===a;};Ykb.RX=w3(265);clb.gh=function gh(a,b){switch(b){case 0:return clb.hh(a,false);case 1:return clb.jh(a);case 2:return clb.ih(a);case 3:return clb.lh(a);case 4:return clb.kh(a);}return null;};clb.hh=function hh(b,c){try{if(!c)return clb.Gf(new clb.ag(b));b=clb.Kt(b);clb.Qo(b,true);clb.fq(b);return clb.Gf(new clb.ag(b));}catch(a){a=b1(a);if(mX(a,22)){Zkb.O5();return null;}else throw c1(a);}};clb.ih=function ih(b){var c,d;try{b=clb.Kt(b);clb.Ut(b);c=b.r;for(d=0;d<c;d++){b.H[d]=1;b.T=0;}return clb.Gf(new clb.ag(b));}catch(a){a=b1(a);if(mX(a,22)){Zkb.O5();return null;}else throw c1(a);}};clb.jh=function jh(b){try{b=clb.Kt(b);clb.Ut(b);return clb.Gf(new clb.ag(b));}catch(a){a=b1(a);if(mX(a,22)){Zkb.O5();return null;}else throw c1(a);}};clb.kh=function kh(b){var c;try{b=clb.Kt(b);clb.Ut(b);c=clb.ku(new clb.nu(b));return clb.Gf(new clb.bg(c,8));}catch(a){a=b1(a);if(mX(a,22)){Zkb.O5();return null;}else throw c1(a);}};clb.lh=function lh(b){var c;try{c=clb.ku(new clb.nu(b));return clb.Gf(new clb.bg(c,8));}catch(a){a=b1(a);if(mX(a,22)){Zkb.O5();return null;}else throw c1(a);}};clb.mh=function mh(a,b,c,d){a.a+=b;a.b+=c;a.c+=d;};clb.nh=function nh(a,b){a.a+=b.a;a.b+=b.b;a.c+=b.c;return a;};clb.oh=function oh(a,b){return new clb.Dh(a.a+b.a,a.b+b.b,a.c+b.c);};clb.ph=function ph(a,b){a.a=(a.a+b.a)/2;a.b=(a.b+b.b)/2;a.c=(a.c+b.c)/2;return a;};clb.qh=function qh(a,b){if(a.a!=b.a)return a.a<b.a?-1:1;if(a.b!=b.b)return a.b<b.b?-1:1;if(a.c!=b.c)return a.c<b.c?-1:1;return 0;};clb.rh=function rh(a,b){return new clb.Dh(a.b*b.c-a.c*b.b,-(a.a*b.c-a.c*b.a),a.a*b.b-a.b*b.a);};clb.sh=function sh(a,b){return $wnd.Math.sqrt((b.a-a.a)*(b.a-a.a)+(b.b-a.b)*(b.b-a.b)+(b.c-a.c)*(b.c-a.c));};clb.th=function th(a,b){var c;if(b==null||!mX(b,24))return false;c=b;return $wnd.Math.abs(c.a-a.a)+$wnd.Math.abs(c.b-a.b)+$wnd.Math.abs(c.c-a.c)<1.0E-6;};clb.uh=function uh(a,b){var c,d,e;d=a.a*a.a+a.b*a.b+a.c*a.c;e=b.a*b.a+b.b*b.b+b.c*b.c;if(d==0||e==0)return 0;c=(a.a*b.a+a.b*b.b+a.c*b.c)/$wnd.Math.sqrt(d*e);if(c>=1)return 0;if(c<=-1)return Fmb;return $wnd.Math.acos(c);};clb.vh=function vh(a,b){var c,d,e;c=a.a;d=a.b;e=a.c;a.a=c*b[0][0]+d*b[1][0]+e*b[2][0];a.b=c*b[0][1]+d*b[1][1]+e*b[2][1];a.c=c*b[0][2]+d*b[1][2]+e*b[2][2];return a;};clb.wh=function wh(a,b){a.a*=b;a.b*=b;a.c*=b;return a;};clb.xh=function xh(a,b,c,d){a.a=b;a.b=c;a.c=d;};clb.yh=function yh(a,b){clb.xh(a,b.a,b.b,b.c);return a;};clb.zh=function zh(a,b){a.a-=b.a;a.b-=b.b;a.c-=b.c;return a;};clb.Ah=function Ah(a,b){return new clb.Dh(a.a-b.a,a.b-b.b,a.c-b.c);};clb.Bh=function Bh(a){var b;b=$wnd.Math.sqrt(a.a*a.a+a.b*a.b+a.c*a.c);if(b==0){Zkb.O5();a.a=1;a.b=0;a.c=0;return a;}a.a/=b;a.b/=b;a.c/=b;return a;};clb.Ch=function Ch(){};clb.Dh=function Dh(a,b,c){this.a=a;this.b=b;this.c=c;};clb.Eh=function Eh(a){clb.Dh.call(this,a.a,a.b,a.c);};U1(24,1,{24:1,4:1,27:1},clb.Ch,clb.Dh,clb.Eh);_.qb=function Fh(a){return clb.qh(this,a);};_.ib=function Gh(a){return clb.th(this,a);};_.lb=function Hh(){var a;a=new Dlb.q8('0.00');return '['+Dlb.o8(a,this.a)+', '+Dlb.o8(a,this.b)+', '+Dlb.o8(a,this.c)+']';};_.a=0;_.b=0;_.c=0;Ykb.TX=w3(24);clb.Ih=function Ih(a,b){b.c*=a.c;b.a=b.a*a.c+a.a;b.b=b.b*a.c+a.b;};clb.Jh=function Jh(a,b){b.a=b.a*a.c+a.a;b.b=b.b*a.c+a.b;};clb.Kh=function Kh(a,b){b.c=b.c*a.c+a.a;b.d=b.d*a.c+a.b;b.b*=a.c;b.a*=a.c;};clb.Lh=function Lh(a){a.a=0;a.b=0;a.c=1;};clb.Mh=function Mh(a,b){return b*a.c+a.a;};clb.Nh=function Nh(a,b){return b*a.c+a.b;};clb.Oh=function Oh(){clb.Lh(this);};clb.Ph=function Ph(a,b,c){var d,e,f,g;clb.Lh(this);e=b.b/a.b;g=b.a/a.a;f=0;f==0&&(f=24);d=f/c;this.c=$wnd.Math.min(d,$wnd.Math.min(e,g));this.a=b.c+b.b/2-this.c*(a.c+a.b/2);this.b=b.d+b.a/2-this.c*(a.d+a.a/2);};U1(144,1,{},clb.Oh,clb.Ph);_.lb=function Qh(){return 'DepictorTransformation Offset: '+this.a+','+this.b+' Scaling: '+this.c;};_.a=0;_.b=0;_.c=0;Ykb.UX=w3(144);clb.Rh=function Rh(a){var b,c,d,e;if(!Zkb.c5(alb.Pgb(a).substr(0,21),xnb)||(d=alb.Pgb(ynb).length,!Zkb.c5(alb.Pgb(a).substr(alb.Pgb(a).length-d,d),ynb)))return null;c=Zkb.h5(a,s5(34),21);if(c==-1)return null;e=(alb.Jgb(21,c,alb.Pgb(a).length),alb.Pgb(a).substr(21,c-21));b=Zkb.p5(a,21+alb.Pgb(e).length+1,alb.Pgb(a).length-17);if(Zkb.c5(e,'arrow'))return new nlb.XE(b);if(Zkb.c5(e,'text'))return new clb.Cu(b);return null;};dlb.Sh=function Sh(a,b,c){var d,e;for(e=a.rb();e.ec();){d=e.fc();if(uX(b)===uX(d)||b!=null&&Zkb.Gc(b,d)){c&&e.gc();return true;}}return false;};dlb.Th=function Th(a,b){var c,d;alb.Egb(b);for(d=b.rb();d.ec();){c=d.fc();if(!a.contains(c)){return false;}}return true;};dlb.Uh=function Uh(a,b){var c,d,e;alb.Egb(b);c=false;for(d=a.rb();d.ec();){e=d.fc();if(b.contains(e)){d.gc();c=true;}}return c;};dlb.Vh=function Vh(a){var b,c,d;d=new dlb.aeb('[',']');for(c=a.rb();c.ec();){b=c.fc();dlb.$db(d,uX(b)===uX(a)?'(this Collection)':b==null?Slb:_1(b));}return !d.a?d.c:alb.Pgb(d.e).length==0?d.a.a:d.a.a+(''+d.e);};U1(39,1,Nnb);_.add=function Wh(a){throw c1(new Zkb.S5('Add not supported on this collection'));};_.addAll=function Xh(a){var b,c,d;alb.Egb(a);b=false;for(d=a.rb();d.ec();){c=d.fc();b=b|this.add(c);}return b;};_.clear=function Yh(){var a;for(a=this.rb();a.ec();){a.fc();a.gc();}};_.contains=function Zh(a){return dlb.Sh(this,a,false);};_.containsAll=function $h(a){return dlb.Th(this,a);};_.isEmpty=function _h(){return this.size()==0;};_.remove=function ai(a){return dlb.Sh(this,a,true);};_.removeAll=function bi(a){return dlb.Uh(this,a);};_.retainAll=function ci(a){var b,c,d;alb.Egb(a);b=false;for(c=this.rb();c.ec();){d=c.fc();if(!a.contains(d)){c.gc();b=true;}}return b;};_.toArray=function di(){return this.sb(gW(Ykb.f_,Ulb,1,this.size(),5,1));};_.sb=function ei(a){var b,c,d,e;e=this.size();a.length<e&&(a=alb.kgb(new Array(e),a));d=a;c=this.rb();for(b=0;b<e;++b){kW(d,b,c.fc());}a.length>e&&Ykb.jW(a,e,null);return a;};_.lb=function fi(){return dlb.Vh(this);};Ykb.u_=w3(39);dlb.gi=function gi(a,b,c){return new dlb.R9(a,b,c);};U1(80,39,Onb);_.addAtIndex=function hi(a,b){throw c1(new Zkb.S5('Add not supported on this list'));};_.add=function ii(a){this.addAtIndex(this.size(),a);return true;};_.addAllAtIndex=function ji(a,b){var c,d,e;alb.Egb(b);c=false;for(e=b.rb();e.ec();){d=e.fc();this.addAtIndex(a++,d);c=true;}return c;};_.clear=function ki(){this.tb(0,this.size());};_.ib=function li(a){var b,c,d,e,f;if(a===this){return true;}if(!mX(a,98)){return false;}f=a;if(this.size()!=f.size()){return false;}e=f.rb();for(c=this.rb();c.ec();){b=c.fc();d=e.fc();if(!(uX(b)===uX(d)||b!=null&&Zkb.Gc(b,d))){return false;}}return true;};_.kb=function mi(){return dlb.xcb(this);};_.indexOf=function ni(a){var b,c;for(b=0,c=this.size();b<c;++b){if(dlb.Odb(a,this.getAtIndex(b))){return b;}}return -1;};_.rb=function oi(){return new dlb.K9(this);};_.lastIndexOf=function pi(a){var b;for(b=this.size()-1;b>-1;--b){if(dlb.Odb(a,this.getAtIndex(b))){return b;}}return -1;};_.removeAtIndex=function qi(a){throw c1(new Zkb.S5('Remove not supported on this list'));};_.tb=function ri(a,b){var c,d;d=new dlb.P9(this,a);for(c=a;c<b;++c){alb.Cgb(d.a<d.c.size());d.c.getAtIndex(d.b=d.a++);dlb.J9(d);}};_.setAtIndex=function si(a,b){throw c1(new Zkb.S5('Set not supported on this list'));};_.subList=function ti(a,b){return dlb.gi(this,a,b);};Ykb.B_=w3(80);function K3(a){if(a==null){return false;}return a.$implements__java_lang_Cloneable||Array.isArray(a);}dlb.ui=function ui(a){a.a=gW(Ykb.f_,Ulb,1,0,5,1);};dlb.vi=function vi(a,b,c){alb.Ggb(b,a.a.length);alb.dgb(a.a,b,c);};dlb.wi=function wi(a,b){alb.ggb(a.a,b);return true;};dlb.xi=function xi(a,b,c){var d,e;alb.Ggb(b,a.a.length);d=c.toArray();e=d.length;if(e==0){return false;}alb.egb(a.a,b,d);return true;};dlb.yi=function yi(a,b){var c,d;c=b.toArray();d=c.length;if(d==0){return false;}alb.egb(a.a,a.a.length,c);return true;};dlb.zi=function zi(a){alb.igb(a.a,0);};dlb.Ai=function Ai(a,b){return dlb.Di(a,b,0)!=-1;};dlb.Bi=function Bi(a,b){alb.Dgb(b,a.a.length);return a.a[b];};dlb.Ci=function Ci(a,b){return dlb.Di(a,b,0);};dlb.Di=function Di(a,b,c){for(;c<a.a.length;++c){if(dlb.Odb(b,a.a[c])){return c;}}return -1;};dlb.Ei=function Ei(a){return a.a.length==0;};dlb.Fi=function Fi(a){return new dlb.Obb(a);};dlb.Gi=function Gi(a,b){return dlb.Hi(a,b,a.a.length-1);};dlb.Hi=function Hi(a,b,c){for(;c>=0;--c){if(dlb.Odb(b,a.a[c])){return c;}}return -1;};dlb.Ii=function Ii(a,b){var c;c=(alb.Dgb(b,a.a.length),a.a[b]);alb.hgb(a.a,b,1);return c;};dlb.Ji=function Ji(a,b){var c;c=dlb.Di(a,b,0);if(c==-1){return false;}dlb.Ii(a,c);return true;};dlb.Ki=function Ki(a,b,c){var d;alb.Hgb(b,c,a.a.length);d=c-b;alb.hgb(a.a,b,d);};dlb.Li=function Li(a,b,c){var d;d=(alb.Dgb(b,a.a.length),a.a[b]);a.a[b]=c;return d;};dlb.Mi=function Mi(a){return a.a.length;};dlb.Ni=function Ni(a,b){dlb.lcb(a.a,a.a.length,b);};dlb.Oi=function Oi(a){return alb.agb(a.a);};dlb.Pi=function Pi(a,b){var c,d;d=a.a.length;b.length<d&&(b=alb.kgb(new Array(d),b));for(c=0;c<d;++c){kW(b,c,a.a[c]);}b.length>d&&Ykb.jW(b,d,null);return b;};dlb.Qi=function Qi(){dlb.ui(this);};dlb.Ri=function Ri(a){dlb.ui(this);alb.ygb(a>=0,'Initial capacity must not be negative');};U1(18,80,Pnb,dlb.Qi,dlb.Ri);_.addAtIndex=function Si(a,b){dlb.vi(this,a,b);};_.add=function Ti(a){return dlb.wi(this,a);};_.addAllAtIndex=function Ui(a,b){return dlb.xi(this,a,b);};_.addAll=function Vi(a){return dlb.yi(this,a);};_.clear=function Wi(){dlb.zi(this);};_.contains=function Xi(a){return dlb.Ai(this,a);};_.getAtIndex=function Yi(a){return dlb.Bi(this,a);};_.indexOf=function Zi(a){return dlb.Ci(this,a);};_.isEmpty=function $i(){return dlb.Ei(this);};_.rb=function _i(){return dlb.Fi(this);};_.lastIndexOf=function aj(a){return dlb.Gi(this,a);};_.removeAtIndex=function bj(a){return dlb.Ii(this,a);};_.remove=function cj(a){return dlb.Ji(this,a);};_.tb=function dj(a,b){dlb.Ki(this,a,b);};_.setAtIndex=function ej(a,b){return dlb.Li(this,a,b);};_.size=function fj(){return dlb.Mi(this);};_.toArray=function gj(){return dlb.Oi(this);};_.sb=function hj(a){return dlb.Pi(this,a);};Ykb.S_=w3(18);clb.ij=function ij(a){var b,c;c=new Zkb.z5();for(b=0;b<a.a.length;b++)Zkb.y5(c,clb.Td((alb.Dgb(b,a.a.length),a.a[b]))+Klb);return c.a;};clb.jj=function jj(b){var c;dlb.Qi.call(this);try{if(b){for(c=0;c<b.a.length;c++)dlb.wi(this,(alb.Dgb(c,b.a.length),b.a[c]).mb());}}catch(a){a=b1(a);if(!mX(a,15))throw c1(a);}};clb.kj=function kj(a){var b,c,d;dlb.Qi.call(this);if(a==null||alb.Pgb(a).length==0)return;b=0;c=Zkb.g5(a,s5(10));while(c!=-1){d=clb.Rh((alb.Jgb(b,c,alb.Pgb(a).length),alb.Pgb(a).substr(b,c-b)));!!d&&(alb.ggb(this.a,d),true);b=c+1;c=Zkb.h5(a,s5(10),b);}};U1(166,18,Pnb,clb.jj,clb.kj);_.lb=function lj(){return clb.ij(this);};Ykb.VX=w3(166);clb.mj=function mj(a,b,c,d){this.b=a;this.a=b;this.c=c;this.d=d;};U1(83,1,{83:1},clb.mj);_.a=0;_.b=0;_.c=0;_.d=0;Ykb.WX=w3(83);clb.nj=function nj(a){var b,c,d,e,f,g;if(a.j!=0)return a.j;if(a.i&&clb.uk(a.e,a.a)!=15&&clb.uk(a.e,a.a)!=16){for(g=0;g<clb.gn(a.e,a.a);g++){f=clb.xn(a.e,a.a,g);if(clb.ql(a.e,f,a.a)){clb.vn(a.e,a.a,g)==a.b?a.j=clb.Kk(a.e,f)==257?3:1:a.j=clb.Kk(a.e,f)==257?1:3;return a.j;}}}b=clb.yk(a.e,a.a,a.g);d=clb.yk(a.e,a.a,a.b);d<b&&(d+=Emb);if(clb.gn(a.e,a.a)==2){c=d-b;if(c>3.0915926535897933&&c<3.191592653589793){a.j=-1;return a.j;}a.j=c<Fmb?4:2;return a.j;}else {e=clb.yk(a.e,a.a,a.d);e<b&&(e+=Emb);a.j=e<d?2:4;return a.j;}};clb.oj=function oj(a,b,c,d){var e,f,g,h;this.e=a;this.g=c;this.a=d;g=-1;for(h=0;h<clb.gn(this.e,this.a);h++){e=clb.vn(this.e,this.a,h);f=clb.xn(this.e,this.a,h);if(e==this.g){clb.Kk(this.e,f)==386&&(this.j=-1);continue;}if(clb.ql(this.e,f,this.a)){this.i&&(a.u[d]|=Ylb);this.i=true;}if(g==b[e]){this.d=e;this.f=true;this.c=clb.zo(this.e,f);}else if(g<b[e]){g=b[e];this.d=this.b;this.b=e;}else {this.d=e;}}};U1(96,1,{},clb.oj);_.a=0;_.b=0;_.c=false;_.d=0;_.f=false;_.g=0;_.i=false;_.j=0;Ykb.XX=w3(96);clb.wj=function wj(){clb.wj=W1;clb.qj=oW(aW(Ykb.l_,1),Xlb,2,6,['?','H','He','Li','Be','B','C','N','O','F','Ne','Na','Mg','Al','Si','P','S','Cl','Ar','K','Ca','Sc','Ti','V','Cr','Mn','Fe','Co','Ni','Cu','Zn','Ga','Ge','As','Se','Br','Kr','Rb','Sr','Y','Zr','Nb','Mo','Tc','Ru','Rh','Pd','Ag','Cd','In','Sn','Sb','Te','I','Xe','Cs','Ba','La','Ce','Pr','Nd','Pm','Sm','Eu','Gd','Tb','Dy','Ho','Er','Tm','Yb','Lu','Hf','Ta','W','Re','Os','Ir','Pt','Au','Hg','Tl','Pb','Bi','Po','At','Rn','Fr','Ra','Ac','Th','Pa','U','Np','Pu','Am','Cm','Bk','Cf','Es','Fm','Md','No','Lr','Rf','Db','Sg','Bh','Hs','Mt','Ds','Rg','Cn','Nh','Fl','Mc','Lv','Ts','Og',Qnb,Qnb,Qnb,Qnb,Qnb,Qnb,Qnb,Qnb,Qnb,Qnb,'R4','R5','R6','R7','R8','R9','R10','R11','R12','R13','R14','R15','R16','R1','R2','R3','A','A1','A2','A3',Qnb,Qnb,'D','T','X','R','H2','H+','Nnn','HYD','Pol',Qnb,Qnb,Qnb,Qnb,Qnb,Qnb,Qnb,Qnb,Qnb,Qnb,Qnb,'Ala','Arg','Asn','Asp','Cys','Gln','Glu','Gly','His','Ile','Leu','Lys','Met','Phe','Pro','Ser','Thr','Trp','Tyr','Val']);clb.uj=oW(aW(Ykb.Y0,1),znb,6,15,[0,1,4,7,9,11,12,14,16,19,20,23,24,27,28,31,32,35,40,39,40,45,48,51,52,55,56,59,58,63,64,69,74,75,80,79,84,85,88,89,90,93,98,0,102,103,106,107,114,115,120,121,130,127,132,133,138,139,140,141,142,0,152,153,158,159,164,165,166,169,174,175,180,181,184,187,192,193,195,197,202,205,208,209,209,210,222,223,226,227,232,231,238,237,244,243,247,247,251,252,257,258,259,262,267,268,271,270,277,276,281,281,283,285,289,289,293,294,294,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,71,156,114,115,103,128,129,57,137,113,113,128,131,147,97,87,101,186,163,99]);clb.tj=oW(aW(Ykb.wX,1),Fnb,6,15,[6]);clb.pj=oW(aW(Ykb.wX,1),Fnb,6,15,[2]);clb.rj=oW(aW(Ykb.wX,2),Llb,9,0,[null,oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[0]),oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[4]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[0]),oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[4]),oW(aW(Ykb.wX,1),Fnb,6,15,[3,5]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,4,6]),oW(aW(Ykb.wX,1),Fnb,6,15,[1,3,5,7]),oW(aW(Ykb.wX,1),Fnb,6,15,[0]),oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),null,null,null,null,null,null,null,null,null,null,oW(aW(Ykb.wX,1),Fnb,6,15,[2,3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,4]),oW(aW(Ykb.wX,1),Fnb,6,15,[3,5]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,4,6]),oW(aW(Ykb.wX,1),Fnb,6,15,[1,3,5,7]),oW(aW(Ykb.wX,1),Fnb,6,15,[0,2]),oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),null,null,null,null,null,null,null,null,null,null,oW(aW(Ykb.wX,1),Fnb,6,15,[1,2,3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,4]),oW(aW(Ykb.wX,1),Fnb,6,15,[3,5]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,4,6]),oW(aW(Ykb.wX,1),Fnb,6,15,[1,3,5,7]),oW(aW(Ykb.wX,1),Fnb,6,15,[0,2,4,6]),oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2])]);clb.sj=oW(aW(Ykb.wX,2),Llb,9,0,[null,oW(aW(Ykb.wX,1),Fnb,6,15,[1]),null,oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),null,null,oW(aW(Ykb.wX,1),Fnb,6,15,[-3]),oW(aW(Ykb.wX,1),Fnb,6,15,[-2]),oW(aW(Ykb.wX,1),Fnb,6,15,[-1]),null,oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),null,oW(aW(Ykb.wX,1),Fnb,6,15,[-3]),oW(aW(Ykb.wX,1),Fnb,6,15,[-2]),oW(aW(Ykb.wX,1),Fnb,6,15,[-1]),null,oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,3,4]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,3,4,5]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,3,6]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,3,4,7]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,3]),oW(aW(Ykb.wX,1),Fnb,6,15,[1,2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,4]),oW(aW(Ykb.wX,1),Fnb,6,15,[-3,3,5]),oW(aW(Ykb.wX,1),Fnb,6,15,[-2]),oW(aW(Ykb.wX,1),Fnb,6,15,[-1]),null,oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[4]),oW(aW(Ykb.wX,1),Fnb,6,15,[3,5]),oW(aW(Ykb.wX,1),Fnb,6,15,[6]),oW(aW(Ykb.wX,1),Fnb,6,15,[4,6,7]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,4]),oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,4]),oW(aW(Ykb.wX,1),Fnb,6,15,[-3,3,5]),oW(aW(Ykb.wX,1),Fnb,6,15,[-2,4,6]),oW(aW(Ykb.wX,1),Fnb,6,15,[-1]),null,oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3,4]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[4]),oW(aW(Ykb.wX,1),Fnb,6,15,[5]),oW(aW(Ykb.wX,1),Fnb,6,15,[6]),oW(aW(Ykb.wX,1),Fnb,6,15,[4,6,7]),oW(aW(Ykb.wX,1),Fnb,6,15,[3,4]),oW(aW(Ykb.wX,1),Fnb,6,15,[3,4]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,4]),oW(aW(Ykb.wX,1),Fnb,6,15,[1,3]),oW(aW(Ykb.wX,1),Fnb,6,15,[1,2]),oW(aW(Ykb.wX,1),Fnb,6,15,[1,3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,4]),oW(aW(Ykb.wX,1),Fnb,6,15,[3,5]),oW(aW(Ykb.wX,1),Fnb,6,15,[-2,2,4]),oW(aW(Ykb.wX,1),Fnb,6,15,[-1,1]),null,oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[4]),oW(aW(Ykb.wX,1),Fnb,6,15,[4,5]),oW(aW(Ykb.wX,1),Fnb,6,15,[3,4,5,6]),oW(aW(Ykb.wX,1),Fnb,6,15,[3,4,5,6]),oW(aW(Ykb.wX,1),Fnb,6,15,[3,4,5,6]),oW(aW(Ykb.wX,1),Fnb,6,15,[3,4,5,6]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3,4]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3])]);};clb.xj=function xj(a,b,c,d){var e;e=clb.yj(a,6);clb.xh(a.J[e],b,c,d);return e;};clb.yj=function yj(a,b){a.q>=a.M&&clb.om(a,a.M*2);a.C[a.q]=0;clb._l(a,a.q,b);a.s[a.q]=0;a.u[a.q]=0;a.B[a.q]=0;a.w[a.q]=0;clb.xh(a.J[a.q],0,0,0);a.v!=null&&(a.v[a.q]=null);a.t!=null&&(a.t[a.q]=null);a.T=0;return a.q++;};clb.zj=function zj(a,b,c){return clb.Aj(a,b,c,clb.jl(a,b)||clb.jl(a,c)?32:1);};clb.Aj=function Aj(a,b,c,d){var e;if(b==c)return -1;for(e=0;e<a.r;e++){if(a.D[0][e]==b&&a.D[1][e]==c||a.D[0][e]==c&&a.D[1][e]==b){a.H[e]<d&&(a.H[e]=d);return e;}}a.r>=a.N&&clb.pm(a,a.N*2);a.D[0][a.r]=b;a.D[1][a.r]=c;a.H[a.r]=d;a.F[a.r]=0;a.G[a.r]=0;a.T=0;return a.r++;};clb.Bj=function Bj(a,b){return clb.Cj(a,b,b.q,b.r);};clb.Cj=function Cj(a,b,c,d){var e,f,g,h,i;a.K=a.K|b.K;f=gW(Ykb.AX,gmb,6,b.q,15,1);h=clb.Cl(a,1);i=clb.Cl(a,2);for(e=0;e<c;e++){f[e]=clb.Pj(b,a,e,h,i);}for(g=0;g<d;g++){clb.Qj(b,a,g,h,i,f[b.D[0][g]],f[b.D[1][g]],false);}a.L=a.L&&b.L;a.I=0;a.T=0;return f;};clb.Dj=function Dj(a,b,c,d,e,f,g,h){var i,j;i=clb._j(a,b,c);if(i==-1){a.q>=a.M&&clb.om(a,a.M*2);i=clb.yj(a,d);clb.xh(a.J[i],b,c,0);a.A[i]=e;clb.Gl(a,i,f);clb.Vl(a,i,g);clb.Ll(a,i,h);return true;}j=clb.Kj(a,i,d,e,f,g);clb.Ll(a,i,h);return j;};clb.Ej=function Ej(a,b,c,d){var e;for(e=0;e<a.r;e++){if(a.D[0][e]==b&&a.D[1][e]==c||a.D[0][e]==c&&a.D[1][e]==b){clb.Mj(a,e,d);a.T=0;return e;}}a.r>=a.N&&clb.pm(a,a.N*2);a.D[0][a.r]=b;a.D[1][a.r]=c;a.H[a.r]=d;a.F[a.r]=0;a.G[a.r]=0;a.T=0;return a.r++;};clb.Fj=function Fj(a,b,c,d,e,f){var g,h,i;while(a.q+d>a.M)clb.om(a,a.M*2);while(a.r+d>a.N)clb.pm(a,a.N*2);g=clb._j(a,b,c);if(g!=-1)return clb.Gj(a,g,d,e,f);h=clb.ak(a,b,c);if(h!=-1)return clb.Hj(a,h,d,e,f);g=clb.xj(a,b,c,0);i=Fmb*(d-2)/d;clb.ul(a,g,d,g,e,0,Fmb-i,f);a.T=0;return true;};clb.Gj=function Gj(a,b,c,d,e){var f,g,h,i,j,k;if(d&&clb.Pn(a,b)>1||!d&&clb.Pn(a,b)>2)return false;g=0;f=gW(Ykb.yX,emb,6,4,15,1);for(i=0;i<a.r;i++){for(j=0;j<2;j++){if(a.D[j][i]==b){if(g==2){g=3;break;}f[g++]=clb.yk(a,b,a.D[1-j][i]);}}if(g==3)break;}if(g==3)return false;k=g==1?f[0]+Fmb:$wnd.Math.abs(f[0]-f[1])>Fmb?(f[0]+f[1])/2:(f[0]+f[1])/2+Fmb;h=Fmb*(c-2)/c;clb.ul(a,b,c,b,d,k-h/2,Fmb-h,e);a.T=0;return true;};clb.Hj=function Hj(a,b,c,d,e){var f,g,h,i,j,k,l,m,n,o,p;j=gW(Ykb.AX,gmb,6,2,15,1);i=gW(Ykb.yX,emb,6,2,15,1);j[0]=a.D[0][b];j[1]=a.D[1][b];if(clb.Pn(a,j[0])>3)return false;if(clb.Pn(a,j[1])>3)return false;g=0;f=gW(Ykb.yX,emb,6,4,15,1);for(m=0;m<a.r;m++){if(m==b)continue;for(n=0;n<2;n++){for(o=0;o<2;o++){if(a.D[n][m]==j[o]){if(g==4){g=5;break;}f[g++]=clb.yk(a,j[o],a.D[1-n][m]);}}if(g==5)break;}if(g==5)break;}if(g==5)return false;i[0]=clb.yk(a,j[0],j[1]);if(i[0]<0){i[1]=i[0]+Fmb;h=0;}else {i[1]=i[0];i[0]=i[1]-Fmb;h=1;}p=0;for(l=0;l<g;l++){f[l]>i[0]&&f[l]<i[1]?--p:++p;}h=p>0?1-h:h;k=Fmb*(c-2)/c;clb.ul(a,j[h],c-1,j[1-h],d,i[p>0?0:1]+Fmb-k,Fmb-k,e);a.T=0;return true;};clb.Ij=function Ij(a,b,c){var d,e,f,g,h;e=gW(Ykb.AX,gmb,6,b.q,15,1);g=clb.Cl(a,1);h=clb.Cl(a,2);for(d=0;d<b.q;d++){b.C[d]!=0?e[d]=clb.Pj(b,a,d,g,h):e[d]=c;}for(f=0;f<b.r;f++){clb.Qj(b,a,f,g,h,e[b.D[0][f]],e[b.D[1][f]],false);}a.L=a.L&&b.L;a.I=0;a.T=0;return e;};clb.Jj=function Jj(a,b){var c,d,e,f,g,h,i,j,k;c=a.J[b[0]];d=a.J[b[1]];e=a.J[b[2]];f=a.J[b[3]];i=new clb.Dh(d.a-c.a,d.b-c.b,d.c-c.c);j=new clb.Dh(e.a-d.a,e.b-d.b,e.c-d.c);k=new clb.Dh(f.a-e.a,f.b-e.b,f.c-e.c);g=new clb.Dh(i.b*j.c-i.c*j.b,-(i.a*j.c-i.c*j.a),i.a*j.b-i.b*j.a);h=new clb.Dh(j.b*k.c-j.c*k.b,-(j.a*k.c-j.c*k.a),j.a*k.b-j.b*k.a);return -$wnd.Math.atan2($wnd.Math.sqrt(j.a*j.a+j.b*j.b+j.c*j.c)*(i.a*h.a+i.b*h.b+i.c*h.c),g.a*h.a+g.b*h.b+g.c*h.c);};clb.Kj=function Kj(a,b,c,d,e,f){if((c==1||c==151||c==152)&&clb.Pn(a,b)>1)return false;a.B[b]=e1(a.B[b],-2);a.v!=null&&(a.v[b]=null);a.t!=null&&(a.t[b]=null);if(c==a.C[b]&&d==a.A[b]&&e==((a.u[b]&Rnb)>>>27)-1&&f==(a.u[b]&48))return false;if(c==151||c==152){d=c-149;c=1;}a.u[b]&=960;a.C[b]=c;a.A[b]=d;a.s[b]=0;a.B[b]=0;clb.Gl(a,b,e);clb.Vl(a,b,f);clb.Al(a,a.w[b]);a.T=0;return true;};clb.Lj=function Lj(a,b,c){if(c){if(a.s[b]>8)return false;++a.s[b];}else {if(a.s[b]<-8)return false;--a.s[b];}a.T=0;return true;};clb.Mj=function Mj(a,b,c){var d,e,f,g,h;f=false;g=a.H[b];if(c==511){f=clb.Tk(a,b);}else if(clb.To(a,b,c)){if(c==257||c==129){d=clb.vl(a,b,a.D[0][b]);e=clb.vl(a,b,a.D[1][b]);if(c==g){if(d==e||e){h=a.D[0][b];a.D[0][b]=a.D[1][b];a.D[1][b]=h;f=true;}}else {if(!d&&e){h=a.D[0][b];a.D[0][b]=a.D[1][b];a.D[1][b]=h;}a.H[b]=c;f=true;}}else {a.H[b]=c;f=true;}}if(f){a.T=(g&127)==(c&127)?a.T&7:0;a.G[b]=0;}return f;};clb.Nj=function Nj(a){a.q=0;a.r=0;a.K=false;a.L=false;a.I=0;a.v=null;a.t=null;a.P=null;a.T=0;};clb.Oj=function Oj(a){var b,c,d,e,f,g,h,i;for(g=0;g<a.r;g++){if(a.H[g]==512){c=a.D[0][g];d=a.D[1][g];if(a.C[c]==-1^a.C[d]==-1){if(a.s[c]!=0&&a.s[d]!=0){if(a.s[c]<0^a.s[d]<0){if(a.s[c]<0){++a.s[c];--a.s[d];}else {--a.s[c];++a.s[d];}}}}}}i=gW(Ykb.AX,gmb,6,a.q,15,1);e=0;for(b=0;b<a.q;b++){if(a.C[b]==-1){i[b]=-1;continue;}if(e<b){a.C[e]=a.C[b];a.s[e]=a.s[b];a.A[e]=a.A[b];a.u[e]=a.u[b];a.B[e]=a.B[b];a.w[e]=a.w[b];clb.yh(a.J[e],a.J[b]);a.v!=null&&(a.v[e]=a.v[b]);a.t!=null&&(a.t[e]=a.t[b]);}i[b]=e;++e;}a.q=e;h=0;for(f=0;f<a.r;f++){if(a.H[f]==512)continue;a.H[h]=a.H[f];a.F[h]=a.F[f];a.G[h]=a.G[f];a.D[0][h]=i[a.D[0][f]];a.D[1][h]=i[a.D[1][f]];++h;}a.r=h;return i;};clb.Pj=function Pj(a,b,c,d,e){var f,g,h;f=b.q;f>=b.M&&clb.om(b,b.M*2);h=(a.u[c]&rnb)>>18;g=-1;h==1?d==-1?g=clb.Cl(b,h):g=$wnd.Math.min(31,d+((a.u[c]&rnb)>>18!=1&&(a.u[c]&rnb)>>18!=2?-1:(a.u[c]&Snb)>>20)):h==2&&(e==-1?g=clb.Cl(b,h):g=$wnd.Math.min(31,e+((a.u[c]&rnb)>>18!=1&&(a.u[c]&rnb)>>18!=2?-1:(a.u[c]&Snb)>>20)));b.C[f]=a.C[c];b.s[f]=a.s[c];b.A[f]=a.A[c];b.u[f]=a.u[c];b.B[f]=b.K?a.B[c]:0;clb.yh(b.J[f],a.J[c]);b.w[f]=a.w[c];b.v!=null&&(b.v[f]=null);if(a.v!=null&&a.v[c]!=null&&b.K){b.v==null&&(b.v=gW(Ykb.AX,Dnb,7,b.C.length,0,2));b.v[f]=dlb.Ubb(a.v[c],a.v[c].length);}b.t!=null&&(b.t[f]=null);if(a.t!=null&&a.t[c]!=null){b.t==null&&(b.t=gW(Ykb.wX,Llb,9,b.C.length,0,2));b.t[f]=dlb.Sbb(a.t[c],a.t[c].length);}if(g!=-1){b.u[f]&=-32505857;b.u[f]|=g<<20;}++b.q;b.T=0;return f;};clb.Qj=function Qj(a,b,c,d,e,f,g,h){var i,j,k,l;j=b.r;j>=b.N&&clb.pm(b,b.N*2);l=(a.F[c]&768)>>8;k=-1;l==1&&(d==-1?k=clb.Cl(b,l):k=$wnd.Math.min(32,d+((a.F[c]&768)>>8!=1&&(a.F[c]&768)>>8!=2?-1:(a.F[c]&Tnb)>>10)));l==2&&(e==-1?k=clb.Cl(b,l):k=$wnd.Math.min(32,e+((a.F[c]&768)>>8!=1&&(a.F[c]&768)>>8!=2?-1:(a.F[c]&Tnb)>>10)));b.D[0][j]=f;b.D[1][j]=g;i=h&&a.vb(c)?64:a.H[c];b.H[j]=i;b.F[j]=a.F[c];b.G[j]=b.K?a.G[c]:0;if(k!=-1){b.F[j]&=-31745;b.F[j]|=k<<10;}++b.r;b.T=0;return j;};clb.Rj=function Rj(a,b,c,d,e,f,g){return clb.Qj(a,b,c,d,e,f==null?a.D[0][c]:f[a.D[0][c]],f==null?a.D[1][c]:f[a.D[1][c]],g);};clb.Sj=function Sj(a,b){var c,d;b.v=null;b.t=null;b.K=a.K;b.q=0;for(c=0;c<a.q;c++)clb.Pj(a,b,c,0,0);b.r=0;for(d=0;d<a.r;d++)clb.Qj(a,b,d,0,0,a.D[0][d],a.D[1][d],false);a.ub(b);};clb.Tj=function Tj(a,b){b.K=a.K;b.L=a.L;b.S=a.S;b.I=a.I;b.P=a.P;b.T=a.T&24;};clb.Uj=function Uj(a,b){var c,d,e,f;for(c=0;c<a.r;c++){for(e=0;e<2;e++){if(a.D[e][c]==b){a.H[c]=512;d=0;for(f=0;f<a.r;f++){if(f==c)continue;(a.D[0][f]===a.D[1-e][c]||a.D[1][f]===a.D[1-e][c])&&++d;}if(d==0){clb.Al(a,a.w[a.D[1-e][c]]);a.C[a.D[1-e][c]]=-1;}}}}clb.Al(a,a.w[b]);a.C[b]=-1;a.v!=null&&(a.v[b]=null);a.t!=null&&(a.t[b]=null);clb.Oj(a);a.T=0;};clb.Vj=function Vj(a,b,c){var d,e;d=clb._j(a,b,c);if(d!=-1){(a.u[d]&512)!=0?clb.$j(a):clb.Uj(a,d);a.T=0;return true;}e=clb.ak(a,b,c);if(e!=-1){(a.u[a.D[0][e]]&a.u[a.D[1][e]]&512)!=0?clb.$j(a):clb.Yj(a,e);a.T=0;return true;}return false;};clb.Wj=function Wj(a,b){var c,d,e,f;if(b.length==0)return null;for(d=b,e=0,f=d.length;e<f;++e){c=d[e];a.C[c]=-1;}return clb.Zj(a);};clb.Xj=function Xj(a,b){a.H[b]=512;clb.Oj(a);a.T=0;};clb.Yj=function Yj(a,b){var c,d,e;for(d=0;d<2;d++){c=0;for(e=0;e<a.r;e++){if(e==b)continue;(a.D[0][e]===a.D[d][b]||a.D[1][e]===a.D[d][b])&&++c;}if(c==0){clb.Al(a,a.w[a.D[d][b]]);a.C[a.D[d][b]]=-1;}}a.H[b]=512;clb.Oj(a);a.T=0;};clb.Zj=function Zj(a){var b,c,d;d=false;for(b=0;b<a.q;b++){if(a.C[b]==-1){d=true;clb.Al(a,a.w[b]);}}for(c=0;c<a.r;c++){if(a.H[c]==512){d=true;}else if(a.C[a.D[0][c]]==-1||a.C[a.D[1][c]]==-1){a.H[c]=512;d=true;}}if(d){a.T=0;return clb.Oj(a);}return null;};clb.$j=function $j(a){var b,c;c=false;for(b=0;b<a.q;b++){if((a.u[b]&512)!=0){a.C[b]=-1;c=true;}}return c&&clb.Zj(a)!=null;};clb._j=function _j(a,b,c){var d,e,f,g,h,i,j,k;g=-1;e=clb.wk(a,a.q,a.r,clb.vj);h=Unb;i=e*e/12;for(d=0;d<a.q;d++){j=a.J[d].a;k=a.J[d].b;f=(b-j)*(b-j)+(c-k)*(c-k);if(f<i&&f<h){h=f;g=d;}}return g;};clb.ak=function ak(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s;m=-1;o=clb.wk(a,a.q,a.r,clb.vj);n=Unb;for(d=0;d<a.r;d++){p=a.J[a.D[0][d]].a;r=a.J[a.D[0][d]].b;q=a.J[a.D[1][d]].a;s=a.J[a.D[1][d]].b;k=q-p;l=s-r;e=$wnd.Math.sqrt(k*k+l*l);f=(p+q)/2;g=(r+s)/2;k=b-f;l=c-g;if($wnd.Math.sqrt(k*k+l*l)>e/2)continue;if(q==p)j=$wnd.Math.abs(p-b);else {h=(s-r)/(p-q);i=-h*p-r;j=$wnd.Math.abs((h*b+c+i)/$wnd.Math.sqrt(h*h+1));}if(j<o&&j<n){n=j;m=d;}}return m;};clb.bk=function bk(a,b){return ((a.u[b]&Rnb)>>>27)-1;};clb.ck=function ck(a,b){return (a.u[b]&49152)>>14;};clb.dk=function dk(a,b){return a.s[b];};clb.ek=function ek(a,b){return a.u[b]&448;};clb.fk=function fk(a,b){return a.t==null?null:a.t[b]==null?null:Zkb.a5(a.t[b]);};clb.gk=function gk(a,b){return a.t==null?null:a.t[b];};clb.hk=function hk(a,b){return (a.u[b]&rnb)>>18!=1&&(a.u[b]&rnb)>>18!=2?-1:(a.u[b]&Snb)>>20;};clb.ik=function ik(a,b){return (a.u[b]&rnb)>>18;};clb.jk=function jk(a,b){return clb.qj[a.C[b]];};clb.kk=function kk(a,b){return a.v==null?null:a.v[b];};clb.lk=function lk(a,b){var c,d,e;if(a.v==null||a.v[b]==null)return z1(e1(a.B[b],1),0)?'':clb.qj[a.C[b]];e='';for(d=0;d<a.v[b].length;d++){d>0&&(e=(alb.Egb(e),e+(alb.Egb(','),',')));c=a.v[b][d];e=Zkb._4(e,clb.qj[c]);}return e;};clb.mk=function mk(a,b){return $wnd.Math.abs(a.w[b]);};clb.nk=function nk(a,b){return a.A[b];};clb.ok=function ok(a,b){return a.u[b]&3;};clb.pk=function pk(a,b){return a.B[b];};clb.qk=function qk(a,b){return a.u[b]&48;};clb.rk=function rk(a,b){return a.J[b].a;};clb.sk=function sk(a,b){return a.J[b].b;};clb.tk=function tk(a,b){return a.J[b].c;};clb.uk=function uk(a,b){return a.C[b];};clb.vk=function vk(a){return clb.wk(a,a.q,a.r,clb.vj);};clb.wk=function wk(a,b,c,d){return clb.xk(a,b,c,d,a.J);};clb.xk=function xk(a,b,c,d,e){var f,g,h,i,j,k,l,m,n,o;l=false;m=0;for(j=0;j<c;j++)a.H[j]!=32&&(a.G[j]&nnb)==0&&++m;if(m==0){for(k=0;k<c;k++)(a.G[k]&nnb)==0&&++m;l=true;}if(m==0){if(b<2)return d;o=Unb;for(f=1;f<b;f++){for(g=0;g<f;g++){n=clb.sh(e[f],e[g]);n>0&&n<o&&(o=n);}}return o!=Unb?0.6*o:d;}h=0;for(i=0;i<c;i++){(l||a.H[i]!=32)&&(a.G[i]&nnb)==0&&(h+=clb.sh(e[a.D[1][i]],e[a.D[0][i]]));}return h/m;};clb.yk=function yk(a,b,c){return clb.Lm(a.J[b].a,a.J[b].b,a.J[c].a,a.J[c].b);};clb.zk=function zk(a,b,c){return a.D[b][c];};clb.Ak=function Ak(a,b){return ((a.G[b]&7680)>>9)+((a.G[b]&122880)>>13);};clb.Bk=function Bk(a,b){return (a.G[b]&7680)>>9;};clb.Ck=function Ck(a,b){return (a.F[b]&48)>>4;};clb.Dk=function Dk(a,b){return (a.F[b]&768)>>8!=1&&(a.F[b]&768)>>8!=2?-1:(a.F[b]&Tnb)>>10;};clb.Ek=function Ek(a,b){return (a.F[b]&768)>>8;};clb.Fk=function Fk(a,b){var c,d,e,f;c=a.D[0][b];d=a.D[1][b];e=a.J[d].a-a.J[c].a;f=a.J[d].b-a.J[c].b;return $wnd.Math.sqrt(e*e+f*f);};clb.Gk=function Gk(a,b,c){var d;for(d=0;d<a.r;d++)if(a.D[0][d]==b&&a.D[1][d]==c||a.D[0][d]==c&&a.D[1][d]==b)if(a.H[d]!=512)return d;return -1;};clb.Hk=function Hk(a,b){switch(a.H[b]&127){case 1:case 64:return 1;case 2:return 2;case 4:return 3;case 8:return 4;case 16:return 5;default:return 0;}};clb.Ik=function Ik(a,b){return a.F[b]&3;};clb.Jk=function Jk(a,b){return a.G[b];};clb.Kk=function Kk(a,b){return a.H[b];};clb.Lk=function Lk(a,b){return a.H[b]&127;};clb.Mk=function Mk(a,b){var c,d,e,f,g;if(a.q==0)return null;d=a.J[0].a;f=a.J[0].b;e=a.J[0].a;g=a.J[0].b;for(c=1;c<a.q;c++){d>a.J[c].a?d=a.J[c].a:e<a.J[c].a&&(e=a.J[c].a);f>a.J[c].b?f=a.J[c].b:g<a.J[c].b&&(g=a.J[c].b);}if(!b){b=new plb.YF(d,f,e-d,g-f);}else {b.c=d;b.d=f;b.b=e-d;b.a=g-f;}return b;};clb.Nk=function Nk(a,b){var c;c=a.C[b]<clb.rj.length?clb.rj[a.C[b]]:null;return c==null?6:c[c.length-1];};clb.Ok=function Ok(a,b,c){var d,e;if(a.C[b]>=171&&a.C[b]<=190)return 0;e=0;(a.u[b]&48)==32&&(e-=1);((a.u[b]&48)==16||(a.u[b]&48)==48)&&(e-=2);d=a.s[b];if(d==0&&a.K){o1(e1(a.B[b],Omb),Rmb)&&(d=-1);o1(e1(a.B[b],Omb),Qmb)&&(d=1);}a.C[b]==7||a.C[b]==8||a.C[b]==9?e+=d:a.C[b]==6||a.C[b]==14||a.C[b]==32?e-=$wnd.Math.abs(d):a.C[b]==15||a.C[b]==33?c-e-d<=3?e+=d:e-=d:a.C[b]==16||a.C[b]==34||a.C[b]==52?c-e-d<=4?e+=d:e-=$wnd.Math.abs(d):a.C[b]==17||a.C[b]==35||a.C[b]==53?c-e-d<=5?e+=d:e-=$wnd.Math.abs(d):e-=d;return e;};clb.Pk=function Pk(a,b){var c;c=clb.Qk(a,b);return c+clb.Ok(a,b,c);};clb.Qk=function Qk(a,b){var c,d;c=((a.u[b]&Rnb)>>>27)-1;c==-1&&(c=(d=a.C[b]<clb.rj.length?clb.rj[a.C[b]]:null,d==null?6:d[d.length-1]));return c;};clb.Rk=function Rk(a,b){var c,d,e,f,g;f=clb.rl(a,a.D[0][b])||clb.rl(a,a.D[1][b])?5:3;for(d=0;d<2;d++){c=a.D[d][b];e=clb.Hk(a,b)+(g=clb.Qk(a,c),g+clb.Ok(a,c,g))-clb.Pn(a,c);f>e&&(f=e);}return f;};clb.Sk=function Sk(a,b){return (a.u[b]&Ylb)!=0;};clb.Tk=function Tk(a,b){var c,d,e;d=clb.Rk(a,b);c=clb.jl(a,a.D[0][b])||clb.jl(a,a.D[1][b]);e=c?32:1;if(a.H[b]==16){a.H[b]=e;a.T=0;return true;}if(a.H[b]==8){a.H[b]=d>4?16:e;a.T=0;return true;}if(a.H[b]==4){a.H[b]=d>3?8:e;a.T=0;return true;}if(a.H[b]==2){a.H[b]=386;a.T&=7;if((a.F[b]&128)==0)return true;}if(a.H[b]==386){d>2?a.H[b]=4:a.H[b]=e;a.T=0;return true;}if((384&a.H[b])!=0){a.H[b]=1;a.T&=7;return true;}if(!c&&d<2)return false;if(a.H[b]==1){a.H[b]=2;a.T=0;return true;}if(d<1)return false;if(a.H[b]==32){a.H[b]=1;a.T=0;return true;}return false;};clb.Uk=function Uk(a){var b;a.T=0;a.C=gW(Ykb.AX,gmb,6,a.M,15,1);a.s=gW(Ykb.AX,gmb,6,a.M,15,1);a.w=gW(Ykb.AX,gmb,6,a.M,15,1);a.J=gW(Ykb.TX,Vnb,24,a.M,0,1);for(b=0;b<a.M;b++)a.J[b]=new clb.Ch();a.A=gW(Ykb.AX,gmb,6,a.M,15,1);a.u=gW(Ykb.AX,gmb,6,a.M,15,1);a.B=gW(Ykb.BX,Anb,6,a.M,14,1);a.v=null;a.t=null;a.D=eW(Ykb.AX,[Dnb,gmb],[7,6],15,[2,a.N],2);a.H=gW(Ykb.AX,gmb,6,a.N,15,1);a.F=gW(Ykb.AX,gmb,6,a.N,15,1);a.G=gW(Ykb.AX,gmb,6,a.N,15,1);};clb.Vk=function Vk(a,b){a.T&=~b;};clb.Wk=function Wk(a){var b;for(b=0;b<a.q;b++)if(a.J[b].c!=0)return true;return false;};clb.Xk=function Xk(a,b){return (a.u[b]&Wnb)!=0;};clb.Yk=function Yk(a,b){return a.C[b]==-1;};clb.Zk=function Zk(a,b){return (a.u[b]&4)!=0;};clb.$k=function $k(a,b){return (a.u[b]&Xnb)!=0;};clb._k=function _k(a,b){return a.w[b]<0;};clb.al=function al(a,b){return (a.F[b]&Ynb)!=0;};clb.bl=function bl(a,b){return (a.G[b]&nnb)!=0;};clb.cl=function cl(a,b){return (a.F[b]&Ylb)!=0;};clb.dl=function dl(a,b){return a.H[b]==512;};clb.el=function el(a,b){return (a.F[b]&4)!=0;};clb.fl=function fl(a,b){return (a.F[b]&Gnb)!=0;};clb.gl=function gl(a,b){var c,d,e,f;if(a.K){if(z1(e1(a.B[b],1),0))return false;if(a.v!=null&&a.v[b]!=null)for(d=a.v[b],e=0,f=d.length;e<f;++e){c=d[e];if(!clb.Om(c))return false;}}return clb.Om(a.C[b]);};clb.hl=function hl(a,b){var c,d,e,f;if(a.K){if(z1(e1(a.B[b],1),0))return false;if(a.v!=null&&a.v[b]!=null)for(d=a.v[b],e=0,f=d.length;e<f;++e){c=d[e];if(!clb.Pm(c))return false;}}return clb.Pm(a.C[b]);};clb.il=function il(a,b){return (a.u[b]&Gnb)!=0;};clb.jl=function jl(a,b){var c,d,e,f;if(a.K){if(z1(e1(a.B[b],1),0))return false;if(a.v!=null&&a.v[b]!=null)for(d=a.v[b],e=0,f=d.length;e<f;++e){c=d[e];if(!(c>=3&&c<=4||c>=11&&c<=13||c>=19&&c<=31||c>=37&&c<=51||c>=55&&c<=84||c>=87&&c<=103))return false;}}return clb.Qm(a.C[b]);};clb.kl=function kl(a,b){return a.A[b]==0;};clb.ll=function ll(a,b){var c,d,e,f;if(a.K){if(z1(e1(a.B[b],1),0))return false;if(a.v!=null&&a.v[b]!=null)for(d=a.v[b],e=0,f=d.length;e<f;++e){c=d[e];if(!(c==1||c>=5&&c<=9||c>=14&&c<=17||c>=32&&c<=35||c>=52&&c<=53))return false;}}return clb.Rm(a.C[b]);};clb.ml=function ml(a){var b;for(b=0;b<a.q;b++){switch(a.C[b]){case 1:case 5:case 6:case 7:case 8:case 9:case 14:case 15:case 16:case 17:case 33:case 34:case 35:case 52:case 53:continue;default:return false;}}return true;};clb.nl=function nl(a,b){return (a.u[b]&512)!=0;};clb.ol=function ol(a,b){return (a.u[a.D[0][b]]&a.u[a.D[1][b]]&512)!=0;};clb.pl=function pl(a,b){return a.H[b]==257||a.H[b]==129;};clb.ql=function ql(a,b,c){return (a.H[b]==257||a.H[b]==129)&&a.D[0][b]==c;};clb.rl=function rl(a,b){var c,d,e,f;if(a.K){if(z1(e1(a.B[b],1),0))return false;if(a.v!=null&&a.v[b]!=null)for(d=a.v[b],e=0,f=d.length;e<f;++e){c=d[e];if(!(c>=3&&c<=4||c>=11&&c<=13||c>=19&&c<=31||c>=37&&c<=51||c>=55&&c<=84||c>=87&&c<=103))return false;}}return clb.Sm(a.C[b]);};clb.sl=function sl(a,b){a.C[b]=-1;};clb.tl=function tl(a,b){a.H[b]=512;};clb.ul=function ul(a,b,c,d,e,f,g,h){var i,j,k,l,m,n,o,p,q,r;if(b!=d){q=a.J[b].a-a.J[d].a;r=a.J[b].b-a.J[d].b;h=$wnd.Math.sqrt(q*q+r*r);}i=b;k=clb.tm(a,b)!=3;for(p=1;p<c;p++){m=a.J[i].a+h*$wnd.Math.sin(f);n=a.J[i].b+h*$wnd.Math.cos(f);o=-1;for(l=0;l<a.q;l++){if($wnd.Math.abs(m-a.J[l].a)<4&&$wnd.Math.abs(n-a.J[l].b)<4){o=l;break;}}if(o==-1){o=clb.xj(a,m,n,0);a.J[o].a=m;a.J[o].b=n;a.J[o].c=0;}j=clb.Gk(a,i,o);if(j==-1){j=clb.Aj(a,i,o,clb.jl(a,i)||clb.jl(a,o)?32:1);if(e){k&&clb.tm(a,a.D[0][j])<4&&clb.tm(a,a.D[1][j])<3&&(a.H[j]=2);k=!k;}}i=o;f+=g;}j=clb.Gk(a,i,d);j==-1&&(j=clb.Aj(a,i,d,clb.jl(a,i)||clb.jl(a,d)?32:1));e&&k&&clb.tm(a,a.D[0][j])<4&&clb.tm(a,a.D[1][j])<4&&(a.H[j]=2);};clb.vl=function vl(a,b,c){var d,e;if(clb.Hk(a,b)!=1)return false;if((a.u[c]&3)!=0)return true;for(e=0;e<a.r;e++)if(e!=b&&a.H[e]==2&&(a.D[0][e]==c&&(a.u[a.D[1][e]]&3)!=0||a.D[1][e]==c&&(a.u[a.D[0][e]]&3)!=0))return true;for(d=0;d<a.r;d++)if(d!=b&&a.H[d]==1&&(a.D[0][d]==c||a.D[1][d]==c)&&(a.F[d]&3)!=0)return true;return false;};clb.wl=function wl(a){var b;for(b=0;b<a.q;b++)a.u[b]&=-449;};clb.xl=function xl(a){var b;for(b=0;b<a.q;b++)a.u[b]&=-131073;};clb.yl=function yl(a){var b;for(b=0;b<a.q;b++)a.u[b]&=-513;};clb.zl=function zl(a){var b;for(b=0;b<a.r;b++)a.F[b]&=-98305;};clb.Al=function Al(a,b){var c;for(c=0;c<a.q;c++)$wnd.Math.abs(a.w[c])==$wnd.Math.abs(b)&&(a.w[c]=0);};clb.Bl=function Bl(a){var b,c,d,e;e=false;for(c=0;c<a.q;c++){if(z1(e1(a.B[c],Bmb),0)){a.C[c]=-1;e=true;}}e&&clb.Zj(a);if(a.v!=null){a.v=null;e=true;}for(b=0;b<a.q;b++){if(z1(a.B[b],0)){a.B[b]=0;e=true;}}for(d=0;d<a.r;d++){if(a.G[d]!=0){a.G[d]=0;e=true;}if(a.H[d]==64){a.H[d]=1;e=true;}}e&&(a.T=0);return e;};clb.Cl=function Cl(a,b){var c,d,e,f,g,h,i,j,k;if(b==0)return 0;h=null;for(d=0;d<a.q;d++){if((a.u[d]&rnb)>>18==b){h==null&&(h=gW(Ykb.Z0,Amb,6,32,16,1));h[(a.u[d]&rnb)>>18!=1&&(a.u[d]&rnb)>>18!=2?-1:(a.u[d]&Snb)>>20]=true;}}for(f=0;f<a.r;f++){if((a.F[f]&768)>>8==b){h==null&&(h=gW(Ykb.Z0,Amb,6,32,16,1));h[(a.F[f]&768)>>8!=1&&(a.F[f]&768)>>8!=2?-1:(a.F[f]&Tnb)>>10]=true;}}k=0;if(h!=null){j=gW(Ykb.AX,gmb,6,32,15,1);for(i=0;i<32;i++)h[i]&&(j[i]=k++);for(c=0;c<a.q;c++){if((a.u[c]&rnb)>>18==b){g=j[(a.u[c]&rnb)>>18!=1&&(a.u[c]&rnb)>>18!=2?-1:(a.u[c]&Snb)>>20];a.u[c]&=-32505857;a.u[c]|=g<<20;}}for(e=0;e<a.r;e++){if((a.F[e]&768)>>8==b){g=j[(a.F[e]&768)>>8!=1&&(a.F[e]&768)>>8!=2?-1:(a.F[e]&Tnb)>>10];a.F[e]&=-31745;a.F[e]|=g<<10;}}}return k;};clb.Dl=function Dl(a,b){var c;for(c=0;c<a.q;c++){a.J[c].a*=b;a.J[c].b*=b;}};clb.El=function El(a,b){a.q=b;a.T=0;};clb.Fl=function Fl(a,b){a.r=b;a.T=0;};clb.Gl=function Gl(a,b,c){if(c>=-1&&c<=14){a.u[b]&=-2013265921;a.u[b]|=1+c<<27;if(a.C[b]==6){if(c==-1||c==0||c==2||c==4){a.u[b]&=-49;c==2&&(a.u[b]|=16);}}}};clb.Hl=function Hl(a,b,c){a.u[b]&=-49153;a.u[b]|=c<<14;};clb.Il=function Il(a,b,c){a.s[b]=c;a.T=0;};clb.Jl=function Jl(a,b,c){a.u[b]&=-449;a.u[b]|=c;};clb.Kl=function Kl(a,b,c){c?a.u[b]|=Wnb:a.u[b]&=Znb;a.T&=7;};clb.Ll=function Ll(a,b,c){var d,e;if(c!=null){if(alb.Pgb(c).length==0)c=null;else {d=clb.Nm(c,321);if(d!=0&&Zkb.c5(c,clb.qj[d])||Zkb.c5(c,'?')){clb._l(a,b,d);c=null;}}}if(c==null){a.t!=null&&(a.t[b]=null);}else {a.t==null&&(a.t=gW(Ykb.wX,Llb,9,a.M,0,2));a.t[b]=alb.qgb((e=c,alb.lgb(),e));}};clb.Ml=function Ml(a,b,c){c!=null&&c.length==0&&(c=null);if(c==null){a.t!=null&&(a.t[b]=null);}else {a.t==null&&(a.t=gW(Ykb.wX,Llb,9,a.M,0,2));a.t[b]=c;}};clb.Nl=function Nl(a,b,c,d){var e,f,g;if(c==0){a.u[b]&=$nb;a.u[b]|=c<<18;}else {if(d>=32)return;if(d==-1){g=-1;for(f=0;f<a.q;f++)f!=b&&c==(a.u[f]&rnb)>>18&&g<((a.u[f]&rnb)>>18!=1&&(a.u[f]&rnb)>>18!=2?-1:(a.u[f]&Snb)>>20)&&(g=(a.u[f]&rnb)>>18!=1&&(a.u[f]&rnb)>>18!=2?-1:(a.u[f]&Snb)>>20);for(e=0;e<a.r;e++)c==(a.F[e]&768)>>8&&g<((a.F[e]&768)>>8!=1&&(a.F[e]&768)>>8!=2?-1:(a.F[e]&Tnb)>>10)&&(g=(a.F[e]&768)>>8!=1&&(a.F[e]&768)>>8!=2?-1:(a.F[e]&Tnb)>>10);d=g+1;if(d>=32)return;}a.u[b]&=$nb;a.u[b]|=c<<18|d<<20;}a.T&=7;};clb.Ol=function Ol(a,b,c){a.v==null&&(a.v=gW(Ykb.AX,Dnb,7,a.M,0,2));alb.jgb(c,alb.Pgb(X1(dlb.ucb.prototype.kc,dlb.ucb,[])));a.v[b]=c;a.T=0;a.K=true;};clb.Pl=function Pl(a,b,c,d){var e;if(c==null){a.v!=null&&(a.v[b]=null);return;}if(c.length==1&&!d){e=c[0];a.C[b]!=e&&clb.Kj(a,b,e,0,-1,0);a.v!=null&&(a.v[b]=null);return;}a.v==null&&(a.v=gW(Ykb.AX,Dnb,7,a.M,0,2));a.v[b]=c;d&&(a.B[b]=B1(a.B[b],1));a.T=0;a.K=true;};clb.Ql=function Ql(a,b,c,d){a.w[b]=d?-c:c;};clb.Rl=function Rl(a,b,c){c?a.u[b]|=Gnb:a.u[b]&=-131073;};clb.Sl=function Sl(a,b,c){a.A[b]=c;a.T&=7;};clb.Tl=function Tl(a,b,c,d){a.u[b]&=-33554440;a.u[b]|=c;d&&(a.u[b]|=4);};clb.Ul=function Ul(a,b,c,d){d?a.B[b]=B1(a.B[b],c):a.B[b]=e1(a.B[b],A1(c));a.T=0;a.K=true;};clb.Vl=function Vl(a,b,c){a.u[b]&=-49;a.u[b]|=c;a.T&=7;};clb.Wl=function Wl(a,b,c){c?a.u[b]|=512:a.u[b]&=-513;};clb.Xl=function Xl(a,b,c){a.u[b]&=-67108865;c&&(a.u[b]|=Xnb);};clb.Yl=function Yl(a,b,c){a.J[b].a=c;a.T&=7;};clb.Zl=function Zl(a,b,c){a.J[b].b=c;a.T&=7;};clb.$l=function $l(a,b,c){a.J[b].c=c;a.T&=7;};clb._l=function _l(a,b,c){if(c>=0&&c<=190){if(c==151||c==152){a.C[b]=1;a.A[b]=c-149;}else {a.C[b]=c;a.A[b]=0;}a.u[b]&=-2013265921;a.T=0;}};clb.am=function am(a,b,c,d){a.D[b][c]=d;a.T=0;};clb.bm=function bm(a,b,c){c?a.F[b]|=Ynb:a.F[b]&=-32769;};clb.cm=function cm(a,b,c){a.F[b]&=-49;a.F[b]|=c<<4;};clb.dm=function dm(a,b,c,d){var e,f,g;if(c==0){a.F[b]&=-32513;a.F[b]|=c<<8;}else {if(d>=32)return;if(d==-1){g=-1;for(f=0;f<a.q;f++)c==(a.u[f]&rnb)>>18&&g<((a.u[f]&rnb)>>18!=1&&(a.u[f]&rnb)>>18!=2?-1:(a.u[f]&Snb)>>20)&&(g=(a.u[f]&rnb)>>18!=1&&(a.u[f]&rnb)>>18!=2?-1:(a.u[f]&Snb)>>20);for(e=0;e<a.r;e++)e!=b&&c==(a.F[e]&768)>>8&&g<((a.F[e]&768)>>8!=1&&(a.F[e]&768)>>8!=2?-1:(a.F[e]&Tnb)>>10)&&(g=(a.F[e]&768)>>8!=1&&(a.F[e]&768)>>8!=2?-1:(a.F[e]&Tnb)>>10);d=g+1;if(d>=32)return;}a.F[b]&=-32513;a.F[b]|=c<<8|d<<10;}a.T&=7;};clb.em=function em(a,b,c){c?a.F[b]|=Ylb:a.F[b]&=-65537;};clb.fm=function fm(a,b,c){a.H[b]=c==1?1:c==2?2:c==3?4:32;a.T=0;};clb.gm=function gm(a,b,c,d){a.F[b]&=-131080;a.F[b]|=c;d&&(a.F[b]|=4);};clb.hm=function hm(a,b){a.F[b]|=Gnb;};clb.im=function im(a,b,c,d){d?a.G[b]|=c:a.G[b]&=~c;a.T=0;a.K=true;};clb.jm=function jm(a,b,c){a.H[b]=c;a.T=0;};clb.km=function km(a,b){a.I=b;};clb.lm=function lm(a,b){if(a.K!=b){a.K=b;b||clb.Bl(a);a.T=0;}};clb.mm=function mm(a,b){a.T=b;};clb.nm=function nm(a,b){a.S=b;};clb.om=function om(a,b){var c,d;a.C=clb.Fm(a.C,b);a.s=clb.Fm(a.s,b);a.w=clb.Fm(a.w,b);d=a.J.length;a.J=clb.Hm(a.J,b);for(c=d;c<b;c++)a.J[c]=new clb.Ch();a.A=clb.Fm(a.A,b);a.u=clb.Fm(a.u,b);a.B=clb.Gm(a.B,b);a.v!=null&&(a.v=clb.Jm(a.v,b));a.t!=null&&(a.t=clb.Im(a.t,b));a.M=b;};clb.pm=function pm(a,b){a.D[0]=clb.Fm(a.D[0],b);a.D[1]=clb.Fm(a.D[1],b);a.H=clb.Fm(a.H,b);a.F=clb.Fm(a.F,b);a.G=clb.Fm(a.G,b);a.N=b;};clb.qm=function qm(a,b){a.O=b;};clb.rm=function rm(a,b){a.P=b;};clb.sm=function sm(a,b){a.u[b]|=Ylb;};clb.tm=function tm(a,b){var c,d;d=0;for(c=0;c<a.r;c++)(a.D[0][c]==b||a.D[1][c]==b)&&(d+=clb.Hk(a,c));return d;};clb.um=function um(a){var b,c,d;c=false;d=false;for(b=0;b<a.q;b++){if(a.A[b]!=0){a.A[b]=0;c=true;a.C[b]==1&&(d=true);}}d&&(a.T=0);return c;};clb.vm=function vm(a,b,c){return clb.jl(a,b)||clb.jl(a,c)?32:1;};clb.wm=function wm(a,b,c){var d,e,f,g,h,i;g=a.C[b];a.C[b]=a.C[c];a.C[c]=g;g=a.s[b];a.s[b]=a.s[c];a.s[c]=g;g=a.A[b];a.A[b]=a.A[c];a.A[c]=g;g=a.u[b];a.u[b]=a.u[c];a.u[c]=g;i=a.B[b];a.B[b]=a.B[c];a.B[c]=i;g=a.w[b];a.w[b]=a.w[c];a.w[c]=g;f=a.J[b];a.J[b]=a.J[c];a.J[c]=f;if(a.v!=null){h=a.v[b];a.v[b]=a.v[c];a.v[c]=h;}if(a.t!=null){h=a.t[b];a.t[b]=a.t[c];a.t[c]=h;}for(d=0;d<a.r;d++){for(e=0;e<2;e++){a.D[e][d]==b?a.D[e][d]=c:a.D[e][d]==c&&(a.D[e][d]=b);}}a.T=0;};clb.xm=function xm(a,b,c){var d;d=a.D[0][b];a.D[0][b]=a.D[0][c];a.D[0][c]=d;d=a.D[1][b];a.D[1][b]=a.D[1][c];a.D[1][c]=d;d=a.H[b];a.H[b]=a.H[c];a.H[c]=d;d=a.F[b];a.F[b]=a.F[c];a.F[c]=d;d=a.G[b];a.G[b]=a.G[c];a.G[c]=d;a.T=0;};clb.ym=function ym(a,b,c){var d;for(d=0;d<a.q;d++){a.J[d].a+=b;a.J[d].b+=c;}a.U+=b;a.V+=c;};clb.zm=function zm(a,b,c){var d,e;e=c&127;d=clb.Rk(a,b);switch(e){case 1:case 64:return d>=1;case 2:return d>=2;case 4:return d>=3;case 8:return d>=4;case 16:return d>=5;case 32:return true;default:return false;}};clb.Am=function Am(a,b,c,d){var e,f,g;for(e=0;e<a.q;e++){if(!d||(a.u[e]&512)!=0){g=a.R[e]*b;f=a.Q[e]-c;a.J[e].a=a.U+g*$wnd.Math.sin(f);a.J[e].b=a.V+g*$wnd.Math.cos(f);}}d&&(a.T&=7);};clb.Bm=function Bm(a,b,c){var d,e,f;a.U=b;a.V=c;a.Q=gW(Ykb.yX,emb,6,a.q,15,1);a.R=gW(Ykb.yX,emb,6,a.q,15,1);for(d=0;d<a.q;d++){e=b-a.J[d].a;f=c-a.J[d].b;a.R[d]=$wnd.Math.sqrt(e*e+f*f);a.Q[d]=clb.Lm(b,c,a.J[d].a,a.J[d].b);}};clb.Cm=function Cm(){this.M=this.N=256;clb.Uk(this);};clb.Dm=function Dm(a,b){this.M=$wnd.Math.max(1,a);this.N=$wnd.Math.max(1,b);clb.Uk(this);};clb.Fm=function Fm(a,b){var c;c=gW(Ykb.AX,gmb,6,b,15,1);Zkb.P5(a,0,c,0,$wnd.Math.min(a.length,b));return c;};clb.Gm=function Gm(a,b){var c;c=gW(Ykb.BX,Anb,6,b,14,1);Zkb.P5(a,0,c,0,$wnd.Math.min(a.length,b));return c;};clb.Hm=function Hm(a,b){var c,d;c=gW(Ykb.TX,Vnb,24,b,0,1);for(d=0;d<a.length;d++)!!a[d]&&(c[d]=new clb.Eh(a[d]));return c;};clb.Im=function Im(a,b){var c,d;c=gW(Ykb.wX,Llb,9,b,0,2);for(d=0;d<a.length;d++){if(a[d]!=null){c[d]=gW(Ykb.wX,Fnb,6,a[d].length,15,1);Zkb.P5(a[d],0,c[d],0,a[d].length);}}return c;};clb.Jm=function Jm(a,b){var c,d;c=gW(Ykb.AX,Dnb,7,b,0,2);for(d=0;d<a.length;d++){if(a[d]!=null){c[d]=gW(Ykb.AX,gmb,6,a[d].length,15,1);Zkb.P5(a[d],0,c[d],0,a[d].length);}}return c;};clb.Km=function Km(a){clb.wj();return a>=0&&a<clb.rj.length&&clb.rj[a]!=null?clb.rj[a]:a>=171&&a<=190?clb.pj:clb.tj;};clb.Lm=function Lm(a,b,c,d){clb.wj();var e,f,g;f=c-a;g=d-b;if(g!=0){e=$wnd.Math.atan(f/g);g<0&&(f<0?e-=Fmb:e+=Fmb);}else e=f>0?Gmb:mnb;return e;};clb.Mm=function Mm(a,b){clb.wj();var c;c=a-b;while(c<_nb)c+=Emb;while(c>Fmb)c-=Emb;return c;};clb.Nm=function Nm(a,b){clb.wj();var c,d,e,f,g;if((b&256)!=0&&Zkb.c5(a,'?'))return 0;for(d=1;d<=128;d++)if(!Zkb.c5(a,Qnb)&&Zkb.d5(a,clb.qj[d]))return d;if((b&2)!=0)for(e=129;e<=144;e++)if(Zkb.d5(a,clb.qj[e]))return e;if((b&4)!=0)for(f=146;f<=148;f++)if(Zkb.d5(a,clb.qj[f]))return f;if((b&1)!=0)for(g=151;g<=152;g++)if(Zkb.d5(a,clb.qj[g]))return g;if((b&32)!=0)if(Zkb.d5(a,clb.qj[153]))return 153;if((b&8)!=0)if(Zkb.d5(a,clb.qj[154]))return 154;if((b&16)!=0)if(Zkb.d5(a,clb.qj[145]))return 145;if((b&128)!=0)if(Zkb.d5(a,clb.qj[159]))return 159;if((b&64)!=0)for(c=171;c<=190;c++)if(Zkb.d5(a,clb.qj[c]))return c;return 0;};clb.Om=function Om(a){clb.wj();switch(a){case 7:case 8:case 9:case 15:case 16:case 17:case 33:case 34:case 35:case 52:case 53:return true;}return false;};clb.Pm=function Pm(a){clb.wj();if(a==1||a==6)return false;if(clb.Om(a))return false;if(a==2||a==10||a==18||a==36||a==54)return false;if(a>103)return false;return true;};clb.Qm=function Qm(a){return a>=3&&a<=4||a>=11&&a<=13||a>=19&&a<=31||a>=37&&a<=51||a>=55&&a<=84||a>=87&&a<=103;};clb.Rm=function Rm(a){return a==1||a>=5&&a<=9||a>=14&&a<=17||a>=32&&a<=35||a>=52&&a<=53;};clb.Sm=function Sm(a){return a>=21&&a<=30||a>=39&&a<=48||a==57||a>=72&&a<=80||a==89||a>=104&&a<=112;};U1(75,1,{75:1,4:1});_.ub=function Em(a){clb.Tj(this,a);};_.vb=function Tm(a){return this.H[a]==64;};_.q=0;_.r=0;_.I=0;_.K=false;_.L=false;_.M=0;_.N=0;_.O=0;_.S=false;_.T=0;_.U=0;_.V=0;clb.vj=24;Ykb.dY=w3(75);clb.Um=function Um(a,b,c,d){var e,f,g,h,i,j,k,l,m;clb.Gt(b,1);d==null&&(d=gW(Ykb.AX,gmb,6,b.q,15,1));h=clb.Cl(a,1);i=clb.Cl(a,2);m=gW(Ykb.Z0,Amb,6,b.q,16,1);j=gW(Ykb.AX,gmb,6,b.q,15,1);j[0]=c;m[c]=true;d[c]=clb.Pj(b,a,c,h,i);g=0;k=0;while(g<=k){for(l=0;l<clb.gn(b,j[g]);l++){f=b.i[j[g]][l];if(!m[f]){j[++k]=f;m[f]=true;d[f]=clb.Pj(b,a,f,h,i);}}++g;}for(e=0;e<b.r;e++)m[b.D[0][e]]&&clb.Qj(b,a,e,h,i,d==null?b.D[0][e]:d[b.D[0][e]],d==null?b.D[1][e]:d[b.D[1][e]],false);clb.Cl(a,1);clb.Cl(a,2);a.T=0;};clb.Vm=function Vm(a){var b,c,d,e,f,g,h,i,j,k,l,m;a.j=gW(Ykb.AX,gmb,6,a.q,15,1);a.e=gW(Ykb.AX,gmb,6,a.q,15,1);a.i=gW(Ykb.AX,Dnb,7,a.q,0,2);a.k=gW(Ykb.AX,Dnb,7,a.q,0,2);a.n=gW(Ykb.AX,Dnb,7,a.q,0,2);a.o=gW(Ykb.AX,gmb,6,a.f,15,1);j=gW(Ykb.AX,gmb,6,a.q,15,1);for(g=0;g<a.r;g++){++j[a.D[0][g]];++j[a.D[1][g]];}for(d=0;d<a.q;d++){a.i[d]=gW(Ykb.AX,gmb,6,j[d],15,1);a.k[d]=gW(Ykb.AX,gmb,6,j[d],15,1);a.n[d]=gW(Ykb.AX,gmb,6,j[d],15,1);}l=false;for(h=0;h<a.g;h++){m=clb.Hk(a,h);if(m==0){l=true;continue;}for(k=0;k<2;k++){c=a.D[k][h];b=a.e[c];a.n[c][b]=m;a.i[c][b]=a.D[1-k][h];a.k[c][b]=h;++a.e[c];++a.j[c];c<a.f&&(m>1?a.o[c]+=m-1:a.H[h]==64&&(a.o[c]=1));}}for(i=a.g;i<a.r;i++){m=clb.Hk(a,i);if(m==0){l=true;continue;}for(k=0;k<2;k++){c=a.D[k][i];b=a.e[c];a.n[c][b]=m;a.i[c][b]=a.D[1-k][i];a.k[c][b]=i;++a.e[c];a.D[1-k][i]<a.f&&++a.j[c];}}if(l){b=gW(Ykb.AX,gmb,6,a.q,15,1);for(e=0;e<a.q;e++)b[e]=a.e[e];for(f=0;f<a.r;f++){m=clb.Hk(a,f);if(m==0){for(k=0;k<2;k++){c=a.D[k][f];a.n[c][b[c]]=m;a.i[c][b[c]]=a.D[1-k][f];a.k[c][b[c]]=f;++b[c];}}}}};clb.Wm=function Wm(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w;clb.Gt(a,1);c&&(b=true);for(i=0;i<a.r;i++){j=clb.Hk(a,i);if(j==1||j==2){if(a.s[a.D[0][i]]>0&&a.s[a.D[1][i]]<0){f=a.D[0][i];g=a.D[1][i];}else if(a.s[a.D[0][i]]<0&&a.s[a.D[1][i]]>0){f=a.D[1][i];g=a.D[0][i];}else continue;if(clb.jl(a,f)||clb.jl(a,g))continue;if(a.C[f]<9&&clb.Pn(a,f)>3||a.C[g]<9&&clb.Pn(a,g)>3)continue;l=clb.Kn(a,f)!=0;a.s[f]-=1;a.s[g]+=1;if(!l){s=a.H[i];j==1?a.H[i]=2:a.H[i]=4;if(s==129||s==257){w=a.D[0][i];r=clb.Io(a,w,false);if(a.D[0][r]!=w){a.D[1][r]=a.D[0][r];a.D[1][r]=w;}}}a.T=0;}}t=0;p=0;n=0;for(e=0;e<a.q;e++){t+=a.s[e];if(a.s[e]<0&&!clb.ho(a,e)){++p;clb.gl(a,e)&&(n-=a.s[e]);}}if(!b&&t!=0)throw c1(new Zkb.rz("molecule's overall charges are not balanced"));clb.Gt(a,1);u=0;v=c?t+n:n;for(h=0;h<a.q;h++){if(a.s[h]>0){if(!clb.go(a,h)&&clb.gl(a,h)){k=$wnd.Math.min(clb.Kn(a,h),a.s[h]);if(k!=0&&v>=k){t-=k;u-=k;v-=k;a.s[h]-=k;a.T&=1;}}}}q=c?t:u;if(q<0){o=gW(Ykb.AX,gmb,6,p,15,1);p=0;for(f=0;f<a.q;f++){a.s[f]<0&&!clb.ho(a,f)&&(o[p++]=(a.C[f]<<22)+f);}alb.jgb(o,alb.Pgb(X1(dlb.ucb.prototype.kc,dlb.ucb,[])));for(m=o.length-1;q<0&&m>=o.length-p;m--){d=o[m]&aob;if(clb.gl(a,d)){k=$wnd.Math.min(-q,-a.s[d]);t+=k;q+=k;a.s[d]+=k;a.T&=1;}}}return t;};clb.Xm=function Xm(a){var b,c,d,e,f,g,h,i,j,k,l,m,n;if(!a.K)return false;for(c=0;c<a.q;c++){n=clb.Qk(a,c);n+clb.Ok(a,c,n)-clb.Pn(a,c)<=0&&!(a.s[c]==0&&(a.C[c]==5||(e=a.C[c],e==7||e==15||e==33)||(d=a.C[c],d==8||d==16||d==34||d==52)))&&(a.B[c]=e1(a.B[c],-6145));}g=false;for(b=0;b<a.f;b++){h=a.e[b]-a.j[b];if(!a.S&&h>0){if(o1(e1(a.B[b],lnb),0)){k=o1(e1(a.B[b],Mmb),896)?3:o1(e1(a.B[b],Mmb),384)?2:o1(e1(a.B[b],128),128)?1:0;i=(n=clb.Qk(a,b),n+clb.Ok(a,b,n)-clb.Pn(a,b));a.s[b]==0&&o1(e1(a.B[b],Omb),0)&&a.C[b]!=6&&++i;l=h;l>3-k&&(l=3-k);l>i+h-k&&(l=i+h-k);if(l>0){m=k==0?0:C1(e1(a.B[b],Mmb),l);m=B1(m,Ykb.m1((l==3?7:h==2?3:1)<<7));a.B[b]=e1(a.B[b],-1921);a.B[b]=B1(a.B[b],e1(Mmb,m));}}for(j=a.j[b];j<a.e[b];j++){f=a.k[b][j];if(a.H[f]==1){a.C[a.i[b][j]]=-1;a.H[f]=512;g=true;}}}}g&&clb.Oj(a);return g;};clb.Ym=function Ym(a,b){var c,d,e,f;if(a.o[b]==2&&a.j[b]==2&&a.n[b][0]==2){for(e=0;e<2;e++){c=clb.bn(a,b,a.i[b][e]);if(c!=-1){for(f=0;f<a.j[c];f++){d=a.k[c][f];(a.H[d]==257||a.H[d]==129)&&a.D[0][d]==c&&(a.H[a.k[c][f]]=1);}}}return;}if(a.o[b]==0||a.C[b]>=15){for(e=0;e<a.e[b];e++){d=a.k[b][e];(a.H[d]==257||a.H[d]==129)&&a.D[0][d]==b&&a.D[0][d]==b&&(a.H[d]=1);}}};clb.Zm=function Zm(a,b,c,d,e){var f,g,h,i,j;d&&clb.Gt(a,7);b.v=null;a.K&&clb.lm(b,true);i=c.length;e==null&&(e=gW(Ykb.AX,gmb,6,i,15,1));b.q=0;for(f=0;f<i;f++)e[f]=c[f]?clb.Pj(a,b,f,0,0):-1;b.r=0;for(j=0;j<a.r;j++){g=a.D[0][j];h=a.D[1][j];if(g<i&&h<i){if(c[g]&&c[h])clb.Qj(a,b,j,0,0,e==null?a.D[0][j]:e[a.D[0][j]],e==null?a.D[1][j]:e[a.D[1][j]],d);else if(a.s[g]!=0&&a.s[h]!=0&&a.s[g]<0^a.s[h]<0){c[g]&&(b.s[e[g]]+=a.s[g]<0?1:-1);c[h]&&(b.s[e[h]]+=a.s[h]<0?1:-1);}}}clb.Tj(a,b);!!a.d&&(b.T=0);b.T=0;clb.Cl(b,1);clb.Cl(b,2);b.q!=i&&clb.lm(b,true);d&&clb.ce(new clb.me(b),null,false);};clb.$m=function $m(a,b,c,d,e){var f,g,h,i,j;d&&clb.Gt(a,7);b.v=null;a.K&&clb.lm(b,true);e==null&&(e=gW(Ykb.AX,gmb,6,a.q,15,1));b.q=0;for(f=0;f<a.q;f++){e[f]=-1;for(j=0;j<a.j[f];j++){if(c[a.k[f][j]]){e[f]=clb.Pj(a,b,f,0,0);break;}}}b.r=0;for(i=0;i<a.r;i++)if(c[i]){clb.Qj(a,b,i,0,0,e==null?a.D[0][i]:e[a.D[0][i]],e==null?a.D[1][i]:e[a.D[1][i]],d);}else {g=a.D[0][i];h=a.D[1][i];if(e[g]==-1^e[h]==-1){if(a.s[g]!=0&&a.s[h]!=0&&a.s[g]<0^a.s[h]<0){e[g]!=-1&&(b.s[e[g]]+=a.s[g]<0?1:-1);e[h]!=-1&&(b.s[e[h]]+=a.s[h]<0?1:-1);}}}clb.Tj(a,b);!!a.d&&(b.T=0);b.T=0;clb.Cl(b,1);clb.Cl(b,2);b.q!=a.q&&clb.lm(b,true);d&&clb.ce(new clb.me(b),null,false);return e;};clb._m=function _m(a,b){var c,d,e,f,g,h,i,j,k,l;if((b&~a.T)==0)return;if((a.T&1)==0){clb.fo(a);clb.Vm(a);a.T|=1;if(clb.Xm(a)){clb.fo(a);clb.Vm(a);}}if((b&~a.T)==0)return;if((a.T&-7)!=0){for(d=0;d<a.f;d++)a.u[d]&=-15369;for(f=0;f<a.g;f++)a.F[f]&=-705;if((b&4)==0){clb.en(a,1);a.T|=2;return;}clb.en(a,7);for(e=0;e<a.f;e++){for(k=0;k<a.j[e];k++){i=a.k[e][k];if(i<a.g&&clb.sr(a.p,i))continue;h=a.i[e][k];for(l=0;l<a.j[h];l++){if(a.k[h][l]==i)continue;a.n[h][l]>1&&(a.C[a.i[h][l]]==6?a.u[e]|=Imb:!clb.mo(a,a.k[h][l])&&clb.gl(a,a.i[h][l])&&(a.u[e]|=knb));}}}while(true){j=false;for(c=0;c<a.f;c++){if(a.o[c]>0&&(a.u[c]&knb)!=0&&!clb.rr(a.p,c)){for(k=0;k<a.j[c];k++){if(a.n[c][k]>1){h=a.i[c][k];i=a.k[c][k];for(l=0;l<a.j[h];l++){if(a.k[h][l]!=i){g=a.i[h][l];if((a.u[g]&knb)==0){a.u[g]|=knb;j=true;}}}}}}}if(!j)break;}}a.T|=6;};clb.an=function an(a,b){var c,d,e,f,g;c=-1;if(a.o[b]==1){for(f=0;f<a.j[b];f++){if(a.n[b][f]==2){d=a.i[b][f];if(a.j[d]==2&&a.o[d]==2){for(g=0;g<2;g++){e=a.i[d][g];if(e!=b&&a.o[e]==1){c=d;break;}}}break;}}}return c;};clb.bn=function bn(a,b,c){var d,e;d=b;while(a.j[c]==2&&a.o[c]==2&&c!=d){e=c;c=a.i[c][0]==b?a.i[c][1]:a.i[c][0];b=e;}return c==d?-1:c;};clb.cn=function cn(a,b){var c;if(a.j[b]==3&&b<a.f&&clb.rr(a.p,b)&&(!!a.p&&b<a.f?clb.gr(a.p,b):0)>=5)for(c=0;c<a.j[b];c++)if(clb.no(a,a.k[b][c]))return a.k[b][c];return -1;};clb.dn=function dn(a,b,c,d,e){var f,g,h,i,j,k;clb.Gt(a,7);if((a.u[b]&bob)==0||c&&!(b<a.f&&clb.rr(a.p,b)))return;i=gW(Ykb.AX,gmb,6,a.f,15,1);i[0]=b;d[b]=true;h=0;j=0;while(h<=j){for(k=0;k<a.j[i[h]];k++){g=a.k[i[h]][k];if(!e[g]&&(a.F[g]&64)!=0&&(!c||g<a.g&&clb.sr(a.p,g))){e[g]=true;f=a.i[i[h]][k];if(!d[f]){d[f]=true;i[++j]=f;}}}++h;}};clb.en=function en(a,b){var c,d,e,f,g,h,i,j;a.p=new clb.Fr(a,b);d=gW(Ykb.AX,gmb,6,a.f,15,1);for(e=0;e<a.g;e++){if(clb.ir(a.p,e)!=0){a.F[e]|=64;++d[a.D[0][e]];++d[a.D[1][e]];}}for(c=0;c<a.f;c++){d[c]==2?a.u[c]|=Nmb:d[c]==3?a.u[c]|=lnb:d[c]>3&&(a.u[c]|=bob);}for(j=0;j<a.p.i.a.length;j++){g=clb.kr(a.p,j);i=clb.lr(a.p,j);h=g.length;for(f=0;f<h;f++){a.u[g[f]]|=8;a.F[i[f]]|=128;a.H[i[f]]==386&&(a.H[i[f]]=2);}}};clb.fn=function fn(a){var b,c,d,e,f,g,h,i;h=gW(Ykb.Z0,Amb,6,a.q,16,1);for(c=0;c<a.q;c++)h[c]=a.C[c]==1&&a.A[c]==0&&a.s[c]==0&&(a.t==null||a.t[c]==null);i=gW(Ykb.Z0,Amb,6,a.q,16,1);for(g=0;g<a.r;g++){d=a.D[0][g];e=a.D[1][g];if(clb.Hk(a,g)!=1){h[d]=false;h[e]=false;continue;}i[d]&&(h[d]=false);i[e]&&(h[e]=false);h[d]&&clb.jl(a,e)&&a.C[e]!=13&&(h[d]=false);h[e]&&clb.jl(a,d)&&a.C[d]!=13&&(h[e]=false);i[d]=true;i[e]=true;}for(f=0;f<a.r;f++){if(h[a.D[0][f]]&&h[a.D[1][f]]){h[a.D[0][f]]=false;h[a.D[1][f]]=false;}}for(b=0;b<a.q;b++)i[b]||(h[b]=false);return h;};clb.gn=function gn(a,b){return a.e[b];};clb.hn=function hn(a,b){return a.i[b].length;};clb.jn=function jn(a,b){return a.e[b]-clb.On(a,b)+clb.Kn(a,b);};clb.kn=function kn(a){var b,c;clb.Gt(a,7);b=0;for(c=0;c<a.p.i.a.length;c++)clb.qr(a.p,c)&&++b;return b;};clb.ln=function ln(a,b){var c,d;c=0;for(d=0;d<a.j[b];d++)clb.gl(a,a.i[b][d])&&!clb.bl(a,a.k[b][d])&&++c;return c;};clb.mn=function mn(a,b){return a.o[b];};clb.nn=function nn(a,b){clb.Gt(a,7);return a.o[b]==2&&a.j[b]==2?clb.Go(a,b,false):clb.Io(a,b,false);};clb.on=function on(a,b){var c;c=a.u[b]&bob;return c==0?0:c==Nmb?2:c==lnb?3:4;};clb.pn=function pn(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o;clb.Gt(a,7);f=gW(Ykb.Z0,Amb,6,a.g,16,1);l=gW(Ykb.Z0,Amb,6,a.g,16,1);o=gW(Ykb.AX,gmb,6,a.f,15,1);g=0;for(h=1;h<a.j[b];h++){d=a.k[b][h];if((a.F[d]&64)!=0){for(j=0;j<h;j++){e=a.k[b][j];if((a.F[e]&64)!=0){l[d]=true;l[e]=true;n=clb.Rn(a,o,a.i[b][h],a.i[b][j],c-2,null,l);l[d]=false;l[e]=false;if(n!=-1){i=false;m=gW(Ykb.AX,gmb,6,n,15,1);clb.Sn(a,o,m,n);for(k=0;k<n;k++){if(!f[m[k]]){f[m[k]]=true;i=true;}}i&&++g;}}}}}return g;};clb.qn=function qn(a,b){return !!a.p&&b<a.f?clb.gr(a.p,b):0;};clb.rn=function rn(a,b){if(b){clb.Gt(a,1);return clb.wk(a,a.f,a.g,clb.vj);}else {return clb.wk(a,a.q,a.r,clb.vj);}};clb.sn=function sn(a){var b,c,d,e,f,g,h,i;clb.Gt(a,1);h=gW(Ykb.zX,cob,6,a.f,15,1);d=gW(Ykb.AX,gmb,6,a.f,15,1);for(i=0;i<a.f;i++){d[0]=i;e=gW(Ykb.AX,gmb,6,a.f,15,1);e[i]=1;c=0;f=0;while(c<=f){for(g=0;g<a.j[d[c]];g++){b=a.i[d[c]][g];if(e[b]==0){e[b]=e[d[c]]+1;d[++f]=b;h[i]+=e[b]-1;}}++c;}h[i]/=f;}return h;};clb.tn=function tn(a,b,c){var d;for(d=0;d<a.i[b].length;d++)if(a.i[b][d]==c)return a.k[b][d];return -1;};clb.un=function un(a,b){return !!a.p&&b<a.g?clb.ir(a.p,b):0;};clb.vn=function vn(a,b,c){return a.i[b][c];};clb.wn=function wn(a,b){return a.j[b];};clb.xn=function xn(a,b,c){return a.k[b][c];};clb.yn=function yn(a,b,c){return a.n[b][c];};clb.zn=function zn(a,b){var c,d;c=0;for(d=0;d<a.j[b];d++)z1(e1(a.B[d],Bmb),0)&&++c;return c;};clb.An=function An(a,b){return a.e[b]-a.j[b];};clb.Bn=function Bn(a,b,c,d,e){var f,g,h,i;g=a.e[b];if(a.o[b]!=0||b<a.f&&clb.rr(a.p,b)||a.j[b]<3||g>4)return false;i=gW(Ykb.Z0,Amb,6,4,16,1);for(h=0;h<g;h++){f=3.9269908169872414-d[h];if($wnd.Math.abs(dob-f%Gmb)>0.0872664675116539)return false;e[h]=3&vX(f/Gmb);if(i[e[h]])return false;i[e[h]]=true;if((e[h]&1)==0){if(a.H[a.k[b][c[h]]]!=1)return false;}else {if(!clb.ql(a,a.k[b][c[h]],b))return false;}}return i[0]&&i[2];};clb.Cn=function Cn(a,b,c,d,e){var f,g,h,i,j,k,l,m;if((!!a.p&&b<a.f?clb.gr(a.p,b):0)>24)return 3;f=a.e[b];e==null&&(e=gW(Ykb.AX,gmb,6,f,15,1));if(!clb.Bn(a,b,c,d,e))return 3;i=-1;for(j=0;j<f;j++){if((e[j]&1)==1){g=a.H[a.k[b][c[j]]];if(i!=-1&&i!=g)return 3;i=g;}}k=$wnd.Math.abs(e[0]-e[1])==2?1:0;h=e[k]-e[k+1];m=$wnd.Math.abs(h)==3^e[k]<e[k+1];l=f==3||(e[3]&1)==1;return m^l^i==129?1:2;};clb.Dn=function Dn(a,b,c){var d,e,f,g,h,i,j,k,l,m;clb.Gt(a,1);m=gW(Ykb.Z0,Amb,6,a.q,16,1);j=gW(Ykb.AX,gmb,6,a.q,15,1);j[0]=b;m[b]=true;g=0;k=0;i=1;while(g<=k){f=c?clb.hn(a,j[g]):a.e[j[g]];for(l=0;l<f;l++){e=a.i[j[g]][l];if(!m[e]){j[++k]=e;m[e]=true;++i;}}++g;}h=gW(Ykb.AX,gmb,6,i,15,1);i=0;for(d=0;d<a.q;d++)m[d]&&(h[i++]=d);return h;};clb.En=function En(a,b,c,d){var e,f,g,h,i,j,k,l,m;clb.Gt(a,1);for(f=0;f<a.q;f++)b[f]=-1;j=0;for(e=0;e<a.q;e++){if(b[e]==-1&&(!c||(a.u[e]&Gnb)!=0)){b[e]=j;k=gW(Ykb.AX,gmb,6,a.q,15,1);k[0]=e;i=0;l=0;while(i<=l){h=d?clb.hn(a,k[i]):a.e[k[i]];for(m=0;m<h;m++){g=a.i[k[i]][m];if(b[g]==-1&&(!c||(a.u[g]&Gnb)!=0)){k[++l]=g;b[g]=j;}}++i;}++j;}}return j;};clb.Fn=function Fn(a,b,c,d){var e,f,g,h,i,j,k,l,m;clb.Gt(a,1);for(f=0;f<a.q;f++)b[f]=-1;j=0;for(e=0;e<a.q;e++){if(b[e]==-1){b[e]=j;k=gW(Ykb.AX,gmb,6,a.q,15,1);k[0]=e;i=0;l=0;while(i<=l){h=d?clb.hn(a,k[i]):a.e[k[i]];for(m=0;m<h;m++){g=a.i[k[i]][m];if(b[g]==-1&&!c[a.k[k[i]][m]]){k[++l]=g;b[g]=j;}}++i;}++j;}}return j;};clb.Gn=function Gn(a,b){var c;return c=clb.Qk(a,b),c+clb.Ok(a,b,c)-clb.Pn(a,b);};clb.Hn=function Hn(a,b){var c,d,e,f,g,h;f=gW(Ykb.AX,gmb,6,a.q,15,1);for(d=0;d<a.q;d++)f[d]=d;e=a.q;do--e;while(e>=0&&b[e]);for(c=0;c<e;c++){if(b[f[c]]){h=f[c];f[c]=f[e];f[e]=h;g=b[c];b[c]=b[e];b[e]=g;do--e;while(b[e]);}}return f;};clb.In=function In(a){return clb.Hn(a,clb.fn(a));};clb.Jn=function Jn(a,b,c){var d,e,f;e=clb.Pn(a,b);e-=clb.Ok(a,b,e);c&&(e-=a.e[b]-a.j[b]);f=clb.Km(a.C[b]);if(e<=f[0])return -1;for(d=1;d<f.length;d++)if(f[d]>=e)return f[d];return e;};clb.Kn=function Kn(a,b){var c,d,e,f,g,h;if(a.K&&o1(e1(a.B[b],lnb),0))return 0;if(!clb.Ro(a,b))return 0;clb.Gt(a,1);g=0;for(e=0;e<a.e[b];e++)g+=a.n[b][e];if(a.K){c=1;for(d=0;d<a.j[b];d++)a.H[a.k[b][d]]==64&&++c;g+=c>>1;}g-=clb.Ok(a,b,g);f=((a.u[b]&Rnb)>>>27)-1;if(f==-1){h=clb.Km(a.C[b]);f=h[0];for(d=1;f<g&&d<h.length;d++)f=h[d];}return $wnd.Math.max(0,f-g);};clb.Ln=function Ln(a,b){var c,d,e,f,g;e=clb.Pn(a,b);c=clb.Ok(a,b,e);f=((a.u[b]&Rnb)>>>27)-1;if(f==-1){g=clb.Km(a.C[b]);d=0;while(e>g[d]+c&&d<g.length-1)++d;f=g[d];}return f+c-e;};clb.Mn=function Mn(a,b){return a.i[b].length-a.e[b];};clb.Nn=function Nn(a){var b,c,d,e;clb.Gt(a,1);e=0;for(b=0;b<a.q;b++){d=a.A[b]!=0?a.A[b]:clb.uj[a.C[b]];e+=d+clb.Kn(a,b)*clb.uj[1];if(a.C[b]>=171&&a.C[b]<=190){c=a.e[b];c>2&&(e-=(c-2)*clb.uj[1]);}}return e;};clb.On=function On(a,b){var c,d;c=a.j[b];for(d=0;d<a.j[b];d++)a.C[a.i[b][d]]==1&&--c;return c;};clb.Pn=function Pn(a,b){var c,d,e,f,g,h;a.wb(1);g=false;d=false;h=0;for(e=0;e<a.e[b];e++){if(!a.K||o1(e1(a.B[a.i[b][e]],Bmb),0)){f=a.n[b][e];h+=f;f>1&&(g=true);c=a.k[b][e];a.H[c]==64&&(d=true);}}d&&!g&&++h;return h;};clb.Qn=function Qn(a,b,c){var d,e,f;e=0;for(f=0;f<a.j[b];f++){d=a.i[b][f];d!=c&&a.j[d]>2&&++e;}return e;};clb.Rn=function Rn(a,b,c,d,e,f,g){var h,i,j,k,l,m,n,o,p;if(c==d){b[0]=c;return 0;}a.wb(1);k=gW(Ykb.AX,gmb,6,a.q,15,1);j=gW(Ykb.AX,gmb,6,a.q,15,1);p=gW(Ykb.AX,gmb,6,a.q,15,1);j[0]=c;k[c]=1;i=0;l=0;while(i<=l&&k[j[i]]<=e){o=j[i];for(m=0;m<a.e[o];m++){if(g==null||g.length<=a.k[o][m]||!g[a.k[o][m]]){h=a.i[o][m];if(h==d){n=k[o];b[n]=h;b[--n]=o;while(n>0){b[n-1]=p[b[n]];--n;}return k[o];}if(k[h]==0&&(f==null||f.length<=h||!f[h])){j[++l]=h;k[h]=k[o]+1;p[h]=o;}}}++i;}return -1;};clb.Sn=function Sn(a,b,c,d){var e,f;clb.Gt(a,1);for(e=0;e<d;e++){for(f=0;f<a.e[b[e]];f++){if(a.i[b[e]][f]==b[e+1]){c[e]=a.k[b[e]][f];break;}}}};clb.Tn=function Tn(a,b,c){var d,e,f,g,h,i;if(b==c)return 0;clb.Gt(a,1);g=gW(Ykb.AX,gmb,6,a.q,15,1);f=gW(Ykb.AX,gmb,6,a.q,15,1);f[0]=b;g[b]=1;e=0;h=0;while(e<=h){for(i=0;i<a.e[f[e]];i++){d=a.i[f[e]][i];if(d==c)return g[f[e]];if(g[d]==0){f[++h]=d;g[d]=g[f[e]]+1;}}++e;}return -1;};clb.Un=function Un(a,b,c,d,e){var f,g,h,i,j,k;if(b==c)return 0;a.wb(1);i=gW(Ykb.AX,gmb,6,a.q,15,1);h=gW(Ykb.AX,gmb,6,a.q,15,1);h[0]=b;i[b]=1;g=0;j=0;while(g<=j&&i[h[g]]<=d){for(k=0;k<a.e[h[g]];k++){f=a.i[h[g]][k];if(f==c)return i[h[g]];if(i[f]==0&&(e==null||e.length<=f||!e[f])){h[++j]=f;i[f]=i[h[g]]+1;}}++g;}return -1;};clb.Vn=function Vn(a,b){return a.e[b]-a.j[b]+clb.Kn(a,b);};clb.Wn=function Wn(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o;o=gW(Ykb.AX,gmb,6,16,15,1);c=gW(Ykb.yX,emb,6,16,15,1);f=gW(Ykb.yX,emb,6,2,15,1);d=0;for(k=0;k<2;k++){e=a.D[k][b];for(l=0;l<a.j[e];l++){i=a.k[e][l];if(i==b)continue;if(d==4)return 0;h=a.i[e][l];o[d]=16;a.o[h]!=0&&(o[d]+=(a.u[h]&bob)!=0?1:4);if((a.F[b]&64)!=0&&(a.F[i]&64)!=0){m=clb.or(a.p,b,i);m!=-1&&(o[d]+=clb.qr(a.p,m)?64:6);}c[d++]=clb.Lm(a.J[e].a,a.J[e].b,a.J[h].a,a.J[h].b);}}f[0]=clb.yk(a,a.D[0][b],a.D[1][b]);if(f[0]<0){f[1]=f[0]+Fmb;g=false;}else {f[1]=f[0];f[0]=f[1]-Fmb;g=true;}n=0;for(j=0;j<d;j++){c[j]>f[0]&&c[j]<f[1]?n-=o[j]:n+=o[j];}return g?-n:n;};clb.Xn=function Xn(a){clb.Gt(a,7);return a.p;};clb.Yn=function Yn(a){var b,c,d,e,f,g,h,i,j;j=0;clb.Gt(a,7);for(d=0;d<a.g;d++){if(clb.Hk(a,d)==1&&(a.F[d]&64)==0){h=true;for(g=0;g<2;g++){b=a.D[g][d];if(a.j[b]==1){h=false;break;}if(a.C[b]==7&&!(b<a.f&&clb.rr(a.p,b))){c=a.D[1-g][d];for(i=0;i<a.j[c];i++){e=a.i[c][i];f=a.k[c][i];if(f!=d&&clb.Hk(a,f)>1&&!(e<a.f&&clb.rr(a.p,e))&&clb.gl(a,e)){h=false;break;}}}}h&&!clb.vo(a,d)&&++j;}}return j;};clb.Zn=function Zn(a,b,c){var d,e,f,g,h,i;e=0;for(f=0;f<a.j[b];f++){d=a.i[b][f];if(d!=c){g=0;for(h=0;h<a.j[d];h++){i=a.i[d][h];i!=b&&clb.mo(a,a.k[d][h])&&a.j[i]>2&&++g;}g==2&&++e;}}return e;};clb.$n=function $n(a,b){var c,d,e,f;c=a.e[b];f=gW(Ykb.AX,gmb,6,c,15,1);for(e=0;e<c;e++)f[e]=(a.i[b][e]<<16)+e;alb.jgb(f,alb.Pgb(X1(dlb.ucb.prototype.kc,dlb.ucb,[])));for(d=0;d<c;d++)f[d]&=Zlb;return f;};clb._n=function _n(a,b){var c,d;clb.Gt(a,1);if(a.j[b]==2&&a.n[b][0]==2&&a.n[b][1]==2){for(c=0;c<2;c++)for(d=0;d<a.e[a.i[b][c]];d++)if(clb.ql(a,a.k[a.i[b][c]][d],a.i[b][c]))return a.k[a.i[b][c]][d];}else {for(c=0;c<a.e[b];c++)if(clb.ql(a,a.k[b][c],b))return a.k[b][c];}return -1;};clb.ao=function ao(a,b,c){if(clb.Hk(a,b)!=1)return 0;return 16-a.e[c]+((a.H[b]&384)==0||a.D[0][b]!=c?Ynb:0)+(a.C[c]==1?Imb:0)+(a.e[c]==1?lnb:0)+((a.u[c]&3)==0?Nmb:0)+((a.F[b]&64)!=0?0:512)+(a.C[c]!=6?256:0);};clb.bo=function bo(a,b,c,d,e,f){var g,h,i,j,k;clb.Gt(a,1);if(e){clb.Nj(e);e.K=false;}i=gW(Ykb.AX,gmb,6,a.q,15,1);d==null?d=gW(Ykb.Z0,Amb,6,a.q,16,1):dlb.ecb(d,d.length);i[0]=b;i[1]=c;d[b]=true;d[c]=true;h=1;j=1;while(h<=j){for(k=0;k<a.e[i[h]];k++){g=a.i[i[h]][k];if(g==b){if(h!=1)return -1;}if(!d[g]){d[g]=true;i[++j]=g;}}++h;}if(e){f==null&&(f=gW(Ykb.AX,gmb,6,d.length,15,1));clb.Zm(a,e,d,false,f);clb.Kj(e,f[b],0,0,-1,0);}d[b]=false;return j;};clb.co=function co(a,b,c){var d,e,f,g,h,i;clb.Gt(a,1);f=gW(Ykb.AX,gmb,6,a.f,15,1);i=gW(Ykb.Z0,Amb,6,a.f,16,1);f[0]=b;f[1]=c;i[b]=true;i[c]=true;e=1;g=1;while(e<=g){for(h=0;h<a.j[f[e]];h++){d=a.i[f[e]][h];if(d==b){if(e!=1)return -1;}if(!i[d]){i[d]=true;f[++g]=d;}}++e;}return g;};clb.eo=function eo(a,b,c){var d,e,f,g,h,i,j,k,l,m,n;if(clb.Hk(a,c)!=2&&!(c<a.g&&clb.sr(a.p,c)))return -1;n=a.F[c]&3;if(n!=1&&n!=2)return -1;for(i=0;i<2;i++){d=a.D[i][c];e=a.D[1-i][c];m=-1;g=false;for(k=0;k<a.j[d];k++){f=a.i[d][k];f!=e&&(f==b?g=true:m=f);}if(g){l=-1;h=-1;for(j=0;j<a.j[e];j++){f=a.i[e][j];if(f!=d){if(l==-1)l=f;else if(f>l)h=f;else {h=l;l=f;}}}if(a.j[d]==2){if(a.j[e]==2)return n==2?l:-1;return n==2?l:h;}else {if(a.j[e]==2)return n==2^b<m?-1:l;return n==2^b<m?h:l;}}}return -1;};clb.fo=function fo(a){var b,c,d,e,f,g,h,i,j,k;g=clb.fn(a);i=a.q;do--i;while(i>=0&&g[i]);for(b=0;b<i;b++){if(g[b]){clb.wm(a,b,i);k=g[b];g[b]=g[i];g[i]=k;do--i;while(g[i]);}}a.f=i+1;if(a.q==a.f){a.g=a.r;return;}h=gW(Ykb.Z0,Amb,6,a.r,16,1);for(f=0;f<a.r;f++){c=a.D[0][f];d=a.D[1][f];(g[c]||g[d])&&(h[f]=true);}j=a.r;do--j;while(j>=0&&h[j]);for(e=0;e<j;e++){if(h[e]){clb.xm(a,e,j);h[e]=false;do--j;while(h[j]);}}a.g=j+1;};clb.go=function go(a,b){var c;for(c=0;c<a.j[b];c++)if(a.s[a.i[b][c]]<0)return true;return false;};clb.ho=function ho(a,b){var c;for(c=0;c<a.j[b];c++)if(a.s[a.i[b][c]]>0)return true;return false;};clb.io=function io(a,b){var c;c=a.C[b];return c==3||c==11||c==19||c==37||c==55;};clb.jo=function jo(a,b){return (a.u[b]&Imb)!=0;};clb.ko=function ko(a,b){var c,d,e,f,g,h;clb.Gt(a,1);for(g=0;g<2;g++){c=a.D[g][b];if(a.C[c]==7){d=a.D[1-g][b];for(h=0;h<a.j[d];h++){e=a.i[d][h];f=a.k[d][h];if((a.C[e]==7||a.C[e]==8||a.C[e]==16)&&clb.Hk(a,f)>=2)return true;}}}return false;};clb.lo=function lo(a,b){return b<a.f&&clb.rr(a.p,b);};clb.mo=function mo(a,b){return b<a.g&&clb.sr(a.p,b);};clb.no=function no(a,b){var c,d,e,f,g,h;if(a.H[b]!=1||b<a.g&&clb.sr(a.p,b)||(a.F[b]&64)!=0&&(!!a.p&&b<a.g?clb.ir(a.p,b):0)<7)return false;c=a.D[0][b];if(!(c<a.f&&clb.rr(a.p,c))||(!!a.p&&c<a.f?clb.gr(a.p,c):0)<5)return false;d=a.D[1][b];if(!(d<a.f&&clb.rr(a.p,d))||(!!a.p&&d<a.f?clb.gr(a.p,d):0)<5)return false;e=clb.Qn(a,c,d);f=clb.Qn(a,d,c);if((!!a.p&&c<a.f?clb.gr(a.p,c):0)>5&&(!!a.p&&d<a.f?clb.gr(a.p,d):0)>5)return e+f>2;g=clb.Zn(a,c,d);h=clb.Zn(a,d,c);if(e==2&&h>=1)return true;if(f==2&&g>=1)return true;if(g==2&&(f>=1||h>=1))return true;if(h==2&&(e>=1||g>=1))return true;return false;};clb.oo=function oo(a,b){return a.o[b]==2&&a.j[b]==2&&a.n[b][0]==2&&a.n[b][1]==2&&a.C[b]<=7;};clb.po=function po(a,b){var c;c=a.C[b];return c==8||c==16||c==34||c==52;};clb.qo=function qo(a,b){return b<a.g&&(clb.wr(a.p,b)||a.H[b]==64);};clb.ro=function ro(a,b){var c;c=a.C[b];return c==12||c==20||c==38||c==56;};clb.so=function so(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o,p;if(a.C[b]!=7||a.j[b]==4)return false;if(b<a.f&&clb.rr(a.p,b)||a.o[b]!=0||z1(e1(a.B[b],jnb),0))return true;if(a.s[b]==1)return false;for(i=0;i<a.j[b];i++)if(clb.un(a,a.k[b][i])==3)return false;g=0;for(j=0;j<a.j[b];j++){if(a.n[b][j]==1){d=a.C[a.i[b][j]];(d==8||d==9||d==17)&&++g;}}if(g==0){for(h=0;h<a.j[b];h++){e=a.i[b][h];if(a.o[e]!=0){if(e<a.f&&clb.rr(a.p,e)){if((!!a.p&&e<a.f?clb.gr(a.p,e):0)>=5){p=0;for(m=0;m<a.j[e];m++){o=a.i[e][m];o!=b&&clb.On(a,o)>=3&&++p;}n=clb.On(a,b);if(p==2&&n>=2||p==1&&n==3)continue;}return !c||!clb.xo(a,b);}for(l=0;l<a.j[e];l++){if(a.n[e][l]==2||clb.mo(a,a.k[e][l]))return !c||!clb.xo(a,b);}}}}if(g<2){for(h=0;h<a.j[b];h++){e=a.i[b][h];k=false;f=false;for(l=0;l<a.j[e];l++){if(a.i[e][l]!=b){a.n[e][l]!=1&&(a.C[a.i[e][l]]==7||a.C[a.i[e][l]]==8||a.C[a.i[e][l]]==16)&&(k=true);a.n[e][l]==1&&a.C[a.i[e][l]]==7&&(f=true);}}if(k&&(!f||g==0))return !c||!clb.xo(a,b);}}return false;};clb.to=function to(a,b){var c;c=a.C[b];return c==9||c==17||c==35||c==53;};clb.uo=function uo(a,b){var c;c=a.C[b];return c==7||c==15||c==33;};clb.vo=function vo(a,b){var c,d,e,f,g,h;if(clb.Hk(a,b)!=1)return false;for(f=0;f<2;f++){c=a.D[f][b];h=a.D[1-f][b];while(a.o[c]==2&&a.j[c]==2&&a.C[c]<10){for(g=0;g<2;g++){d=a.i[c][g];if(d!=h){if(a.j[d]==1)return true;e=a.k[c][g];if(clb.Hk(a,e)==1&&e<b)return true;h=c;c=d;break;}}}if(a.j[c]==1)return true;}return false;};clb.wo=function wo(a,b,c,d,e){var f,g,h,i,j,k,l,m,n,o,p,q,r,s;m=gW(Ykb.Z0,Amb,6,a.g,16,1);m[e]=true;n=gW(Ykb.AX,gmb,6,11,15,1);o=clb.Rn(a,n,d,b,10,null,m);if(o==-1)return false;g=1;while(!clb.tr(a.p,c,n[g]))++g;f=o-g;h=n[g];s=clb.nr(a.p,c);if(s==6&&f==2&&g==3){if(clb.on(a,n[1])>=3){r=clb.kr(a.p,c);for(l=0;l<6;l++){if(b==r[l]){q=clb.Er(a.p,c,h==r[clb.Er(a.p,c,l+2)]?l-2:l+2);p=r[q];k=a.u[p]&bob;if((k==0?0:k==Nmb?2:k==lnb?3:4)>=3&&clb.Un(a,n[1],p,2,null)==2)return true;break;}}}}i=a.o[h]==1||h<a.f&&clb.rr(a.p,h)||clb.so(a,h,false);j=!i&&a.C[h]==7&&a.s[h]!=1;if(f==1&&!i&&!j&&s<=4&&g<=3)return true;switch(s){case 4:if(!i&&!j&&g<=4)return true;break;case 5:if(j){if(g<=3)return true;}else if(!i){if(g<=4)return true;}break;case 6:if(f==2){if(i){if(g<=4)return true;}else if(!j){if(g<=3)return true;}}else if(f==3){if(i){if(g<=6)return true;}else {if(g<=4)return true;}}break;case 7:if(f==3){if(g<=3)return true;}}return false;};clb.xo=function xo(a,b){var c,d,e,f,g;if(b<a.f&&clb.rr(a.p,b)||a.o[b]!=0||z1(e1(a.B[b],jnb),0)||(d=a.u[b]&bob,(d==0?0:d==Nmb?2:d==lnb?3:4)<3))return false;g=!!a.p&&b<a.f?clb.gr(a.p,b):0;if(g>7)return false;f=0;while(f<a.p.i.a.length){if(clb.nr(a.p,f)==g&&clb.tr(a.p,f,b))break;++f;}if(f>=Nmb&&f==a.p.i.a.length)return false;for(e=0;e<a.j[b];e++){c=a.k[b][e];if(!clb.ur(a.p,f,c)&&clb.wo(a,b,f,a.i[b][e],c))return true;}return false;};clb.yo=function yo(a,b){return (a.u[b]&bob)!=0;};clb.zo=function zo(a,b){return (a.F[b]&64)!=0;};clb.Ao=function Ao(a,b){return a.C[b]==1&&a.A[b]==0&&a.s[b]==0&&(a.t==null||a.t[b]==null);};clb.Bo=function Bo(a,b){return (a.u[b]&8)!=0;};clb.Co=function Co(a,b){return (a.F[b]&128)!=0;};clb.Do=function Do(a,b){return (a.u[b]&knb)!=0;};clb.Eo=function Eo(a){var b,c,d,e,f,g,h,i,j,k,l;clb.Gt(a,1);clb.Fo(a);j=false;for(c=0;c<a.f;c++){if(a.C[c]==7&&a.s[c]==0){l=clb.Pn(a,c);if(l==4){for(k=0;k<a.j[c];k++){h=a.i[c][k];if(a.n[c][k]==1&&a.C[h]==8&&a.j[h]==1&&a.s[h]==0){j=true;++a.s[c];--a.s[h];break;}}}else if(l==5){for(k=0;k<a.j[c];k++){h=a.i[c][k];i=a.k[c][k];if(a.n[c][k]==2&&a.C[h]==8){j=true;++a.s[c];--a.s[h];a.H[i]=1;break;}if(a.n[c][k]==3&&a.C[h]==7){j=true;++a.s[c];--a.s[h];a.H[i]=2;break;}}}}}g=false;for(f=0;f<a.g;f++){for(k=0;k<2;k++){if(clb.gl(a,a.D[k][f])){b=a.D[1-k][f];e=a.C[b];if(e==3||e==11||e==19||e==37||e==55||(d=a.C[b],d==12||d==20||d==38||d==56)){if(clb.Hk(a,f)==1){++a.s[b];--a.s[a.D[k][f]];a.H[f]=512;g=true;}else if(a.H[f]==32){a.H[f]=512;g=true;}}break;}}}if(g){clb.Oj(a);j=true;}j&&(a.T=0);return j;};clb.Fo=function Fo(a){var b;for(b=0;b<a.g;b++)if(a.H[b]==64)return clb.ce(new clb.me(a),null,false);return false;};clb.Go=function Go(a,b,c){var d,e,f,g,h,i,j,k;j=-1;e=0;for(h=0;h<2;h++){d=a.i[b][h];for(i=0;i<a.e[d];i++){f=a.i[d][i];if(f!=b){g=a.k[d][i];k=clb.ao(a,g,f);if(e<k&&(!c||!(a.H[g]==257||a.H[g]==129))){e=k;j=g;}}}}return j;};clb.Ho=function Ho(a,b){var c,d,e,f,g,h,i,j;i=-1;d=0;for(g=0;g<2;g++){c=a.D[g][b];for(h=0;h<a.e[c];h++){e=a.i[c][h];if(e!=a.D[1-g][b]){f=a.k[c][h];j=clb.ao(a,f,e);if(d<j){d=j;i=f;}}}}return i;};clb.Io=function Io(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A;d=a.e[b];e=gW(Ykb.yX,emb,6,d,15,1);for(q=0;q<d;q++)e[q]=clb.yk(a,b,a.i[b][q]);for(r=1;r<d;r++){for(u=0;u<r;u++){f=$wnd.Math.abs(clb.Mm(e[r],e[u]));if(f<0.08||f>eob){g=0;h=0;for(v=0;v<d;v++){if(v!=r&&v!=u){g+=$wnd.Math.abs(slb.zT(e[r],e[v]));h+=$wnd.Math.abs(slb.zT(e[u],e[v]));}}j=g<h?a.k[b][r]:a.k[b][u];if(clb.Hk(a,j)==1&&(!c||!(a.H[j]==257||a.H[j]==129)))return j;}}}t=gW(Ykb.Z0,Amb,6,d,16,1);for(s=0;s<d;s++){k=-10;l=10;for(u=0;u<d;u++){if(u!=s){o=slb.zT(e[s],e[u]);o<0?k<o&&(k=o):l>o&&(l=o);}t[s]=l-k<Fmb;}}w=-1;i=0;for(p=0;p<d;p++){m=a.i[b][p];n=a.k[b][p];A=clb.ao(a,n,m);t[p]&&(A+=Hmb);if(i<A&&(!c||!(a.H[n]==257||a.H[n]==129))){i=A;w=n;}}return w;};clb.Jo=function Jo(a,b){var c,d,e,f;clb.Gt(a,b?15:1);a.q=a.f;a.r=a.g;for(d=0;d<a.f;d++){if(a.e[d]!=a.j[d]){c=clb.Jn(a,d,false);a.e[d]=a.j[d];if(c!=-1){f=clb.Jn(a,d,true);if(c!=f){e=((a.u[d]&Rnb)>>>27)-1;(e==-1||e<c)&&clb.Gl(a,d,c);}}}}b&&clb.Po(a);a.T=0;};clb.Ko=function Ko(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A;if(a.j[b]!=2||a.n[b][0]!=2||a.n[b][1]!=2||a.j[a.i[b][0]]<2||a.j[a.i[b][1]]<2||a.o[a.i[b][0]]!=1||a.o[a.i[b][1]]!=1){clb.Tl(a,b,0,false);return;}v=-1;u=-1;t=-1;q=-1;f=0;for(l=0;l<2;l++){d=a.i[b][l];for(o=0;o<a.e[d];o++){g=a.i[d][o];if(g!=b){h=a.k[d][o];w=clb.ao(a,h,g);if(f<w){f=w;u=g;v=h;t=d;q=a.i[b][1-l];}}}}if(u==-1)return;for(m=0;m<2;m++){d=a.i[b][m];for(o=0;o<a.e[d];o++){g=a.i[d][o];h=a.k[d][o];g!=b&&a.D[0][h]==d&&(a.H[h]=1);}}if(a.D[1][v]!=u){a.D[0][v]=a.D[1][v];a.D[1][v]=u;}i=Qlb;for(n=0;n<a.j[t];n++){g=a.i[t][n];g!=b&&i>g&&(i=g);}r=gW(Ykb.AX,gmb,6,2,15,1);s=0;for(k=0;k<a.j[q];k++){g=a.i[q][k];g!=b&&(r[s++]=g);}c=clb.Lm(a.J[b].a,a.J[b].b,a.J[q].a,a.J[q].b);e=0;if(s==2){if(r[0]>r[1]){A=r[0];r[0]=r[1];r[1]=A;}j=clb.Mm(c,clb.yk(a,q,r[0]));p=clb.Mm(c,clb.yk(a,q,r[1]));e=j-p;}else {e=clb.Mm(c,clb.yk(a,q,r[0]));}e<0^(a.u[b]&3)==1^i==u?a.H[v]=257:a.H[v]=129;};clb.Lo=function Lo(a,b,c,d){var e,f,g,h,i,j;e=a.e[b];h=gW(Ykb.AX,gmb,6,e,15,1);j=clb.Cn(a,b,c,d,h);if(j==3)return false;g=(a.u[b]&3)==j?257:129;for(i=0;i<e;i++){if((h[i]&1)==1){f=a.k[b][c[i]];a.H[f]=g;if(a.D[0][f]!=b){a.D[1][f]=a.D[0][f];a.D[0][f]=b;}}}return true;};clb.Mo=function Mo(a,b){a.T|=248&(8|b);};clb.No=function No(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q;clb.Ym(a,b);if((a.u[b]&3)==0||(a.u[b]&3)==3)return;if(a.o[b]==2&&a.j[b]==2){clb.Ko(a,b);return;}if(a.j[b]<3||a.j[b]>4){clb.Tl(a,b,0,false);return;}c=a.e[b];o=false;for(g=0;g<c;g++){if(clb.Hk(a,a.k[b][g])==1){o=true;break;}}if(!o)return;p=clb.$n(a,b);d=gW(Ykb.yX,emb,6,c,15,1);for(h=0;h<c;h++)d[h]=clb.yk(a,a.i[b][p[h]],b);for(i=0;i<c;i++)a.D[0][a.k[b][i]]==b&&clb.Hk(a,a.k[b][i])==1&&(a.H[a.k[b][i]]=1);if((!!a.p&&b<a.f?clb.gr(a.p,b):0)<=24&&clb.Lo(a,b,p,d))return;m=clb.Io(a,b,true);if(a.D[0][m]!=b){a.D[1][m]=a.D[0][m];a.D[0][m]=b;}n=-1;for(j=0;j<c;j++){if(m==a.k[b][p[j]]){n=j;break;}}q=oW(aW(Ykb.AX,2),Dnb,7,0,[oW(aW(Ykb.AX,1),gmb,6,15,[2,1,2,1]),oW(aW(Ykb.AX,1),gmb,6,15,[1,2,2,1]),oW(aW(Ykb.AX,1),gmb,6,15,[1,1,2,2]),oW(aW(Ykb.AX,1),gmb,6,15,[2,1,1,2]),oW(aW(Ykb.AX,1),gmb,6,15,[2,2,1,1]),oW(aW(Ykb.AX,1),gmb,6,15,[1,2,1,2])]);for(f=1;f<c;f++)d[f]<d[0]&&(d[f]+=Emb);if(c==3){k=false;switch(n){case 0:k=d[1]<d[2]&&d[2]-d[1]<Fmb||d[1]>d[2]&&d[1]-d[2]>Fmb;break;case 1:k=d[2]-d[0]>Fmb;break;case 2:k=d[1]-d[0]<Fmb;}e=(a.u[b]&3)==1^k?257:129;}else {l=0;d[1]<=d[2]&&d[2]<=d[3]?l=0:d[1]<=d[3]&&d[3]<=d[2]?l=1:d[2]<=d[1]&&d[1]<=d[3]?l=2:d[2]<=d[3]&&d[3]<=d[1]?l=3:d[3]<=d[1]&&d[1]<=d[2]?l=4:d[3]<=d[2]&&d[2]<=d[1]&&(l=5);e=(a.u[b]&3)==1^q[l][n]==1?129:257;}a.H[m]=e;};clb.Oo=function Oo(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A;if((a.F[b]&3)==0||(a.F[b]&3)==3||!clb.no(a,b))return;v=-1;t=-1;u=-1;s=-1;e=0;for(l=0;l<2;l++){d=a.D[l][b];for(o=0;o<a.e[d];o++){h=a.k[d][o];if(h!=b&&clb.Hk(a,h)==1){g=a.i[d][o];w=clb.ao(a,h,g);if(e<w){e=w;t=g;v=h;u=d;s=a.D[1-l][b];}}}}if(t==-1)return;for(m=0;m<2;m++){for(o=0;o<a.e[a.D[m][b]];o++){h=a.k[a.D[m][b]][o];h!=b&&clb.Hk(a,h)==1&&(a.H[h]=1);}}if(a.D[1][v]!=t){a.D[0][v]=a.D[1][v];a.D[1][v]=t;}i=Qlb;for(n=0;n<a.j[u];n++){g=a.i[u][n];a.k[u][n]!=b&&i>g&&(i=g);}q=gW(Ykb.AX,gmb,6,2,15,1);r=0;for(k=0;k<a.j[s];k++)a.k[s][k]!=b&&(q[r++]=a.i[s][k]);f=clb.Lm(a.J[u].a,a.J[u].b,a.J[s].a,a.J[s].b);c=0;if(r==2){if(q[0]>q[1]){A=q[0];q[0]=q[1];q[1]=A;}j=clb.Mm(f,clb.yk(a,s,q[0]));p=clb.Mm(f,clb.yk(a,s,q[1]));c=j-p;}else {c=clb.Mm(f,clb.yk(a,s,q[0]));}c<0^(a.F[b]&3)==2^i==t?a.H[v]=257:a.H[v]=129;};clb.Po=function Po(a){var b,c,d,e;clb.Gt(a,7);for(d=0;d<a.g;d++)(a.H[d]==257||a.H[d]==129)&&(a.H[d]=1);for(b=0;b<a.f;b++)clb.No(a,b);for(e=0;e<a.g;e++)clb.Oo(a,e);for(c=0;c<a.g;c++)a.H[c]==2&&(a.F[c]&3)==3&&(a.H[c]=386);};clb.Qo=function Qo(b,c){var d,e,f,g,h,i,j,k,l,m;i=gW(Ykb.AX,gmb,6,b.q,15,1);h=clb.En(b,i,false,c);if(h<=1)return null;j=gW(Ykb.AX,gmb,6,h,15,1);for(e=0;e<b.f;e++)++j[i[e]];l=0;m=j[0];for(k=1;k<h;k++){if(m<j[k]){m=j[k];l=k;}}for(d=0;d<b.q;d++)i[d]!=l&&(b.C[d]=-1);for(g=0;g<b.r;g++)(!c&&b.H[g]==32||i[b.D[0][g]]!=l)&&(b.H[g]=512);f=clb.Oj(b);b.T=0;try{clb.Wm(b,true,true);}catch(a){a=b1(a);if(!mX(a,15))throw c1(a);}return f;};clb.Ro=function Ro(a,b){if((a.u[b]&Rnb)!=0)return true;if(a.C[b]==1)return false;return clb.ll(a,b)||a.C[b]==13||a.C[b]>=171;};clb.So=function So(a){var b,c,d,e,f,g,h,i,j,k;f=clb.wk(a,a.q,a.r,clb.vj);g=f*f/16;for(d=1;d<a.q;d++){for(e=0;e<d;e++){i=a.J[e].a-a.J[d].a;j=a.J[e].b-a.J[d].b;k=a.J[e].c-a.J[d].c;if(i*i+j*j+k*k<g)throw c1(new Zkb.rz('The distance between two atoms is too close.'));}}clb.Gt(a,1);b=0;for(c=0;c<a.f;c++){if(clb.Pn(a,c)>(h=clb.Qk(a,c),h+clb.Ok(a,c,h)))throw c1(new Zkb.rz('atom valence exceeded'));b+=a.s[c];}if(b!=0)throw c1(new Zkb.rz('unbalanced atom charge'));};clb.To=function To(a,b,c){var d;d=clb.zm(a,b,c);if(d&&c==386){clb.Gt(a,7);d=d&(a.F[b]&128)==0;}return d;};clb.Uo=function Uo(){clb.Cm.call(this);};clb.Vo=function Vo(a,b){clb.Dm.call(this,a,b);};clb.Wo=function Wo(a){clb.Dm.call(this,!a?256:a.M,!a?256:a.N);!!a&&clb.Sj(a,this);};U1(91,75,{91:1,75:1,4:1});_.wb=function Xo(a){clb._m(this,a);};_.vb=function Yo(a){return clb.qo(this,a);};_.f=0;_.g=0;Ykb.YX=w3(91);clb.Zo=function Zo(a,b){return $wnd.Math.pow(10,$wnd.Math.log(2000)*$wnd.Math.LOG10E*a/(b-1)-1);};clb.$o=function $o(a,b){var c,d;c=b;d=0;while(b!=0){if(a.d==0){a.f=(a.c[++a.e]&63)<<11;a.d=6;}d|=(Ylb&a.f)>>16-c+b;a.f<<=1;--b;--a.d;}return d;};clb._o=function _o(a,b,c){a.d=6;a.e=c;a.c=b;a.f=(b[a.e]&63)<<11;};clb.ap=function ap(a,b){var c,d,e,f;d=b/2|0;e=a>=d;e&&(a-=d);f=b/32|0;c=f*a/(d-a);return e?-c:c;};clb.bp=function bp(a,b){var c;return b==null||alb.Pgb(b).length==0?null:clb.dp(a,alb.qgb((c=b,alb.lgb(),c)),null);};clb.cp=function cp(a,b,c){var d,e;return b==null?null:clb.dp(a,alb.qgb((e=b,alb.lgb(),e)),c==null?null:alb.qgb((d=c,d)));};clb.dp=function dp(a,b,c){var d,e,f,g,h;clb._o(a,b,0);d=clb.$o(a,4);g=clb.$o(a,4);d>8&&(d=g);e=clb.$o(a,d);f=clb.$o(a,g);h=new clb.Zt(e,f);clb.gp(a,h,b,c,0);return h;};clb.ep=function ep(a,b,c){var d,e,f,g;if(c==null||alb.Pgb(c).length==0){clb.fp(a,b,null,null);return;}d=Zkb.g5(c,s5(32));d>0&&d<alb.Pgb(c).length-1?clb.fp(a,b,alb.qgb((f=(alb.Jgb(0,d,alb.Pgb(c).length),alb.Pgb(c).substr(0,d)),alb.lgb(),f)),alb.qgb((g=(alb.Kgb(d+1,alb.Pgb(c).length+1),alb.Pgb(c).substr(d+1)),g))):clb.fp(a,b,alb.qgb((e=c,alb.lgb(),e)),null);};clb.fp=function fp(a,b,c,d){if(c==null||c.length==0){clb.Nj(b);return;}clb.gp(a,b,c,d,0);};clb.gp=function gp(b,c,d,e,f){var g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z,$,ab,bb,cb,db,eb,fb,gb,hb,ib,jb,kb,lb,mb,nb,ob,pb,qb,rb,sb,tb,ub,vb,wb,xb,yb,zb,Ab,Bb,Cb,Db,Eb,Fb,Gb,Hb,Ib,Jb,Kb,Lb,Mb,Nb,Ob,Pb,Qb,Rb,Sb,Tb,Ub,Vb,Wb,Xb,Yb,Zb,$b,_b,ac,bc,cc,dc,ec,fc,gc,hc,ic,jc,kc,lc,mc,nc,oc,pc,qc,rc,sc,tc,uc,vc,wc,xc,yc,zc,Ac;clb.Nj(c);if(d==null||0>=d.length)return;b.g=c;uc=8;e!=null&&(f<0||f>=e.length)&&(e=null);clb._o(b,d,0);i=clb.$o(b,4);B=clb.$o(b,4);if(i>8){uc=i;i=B;}if(i==0){clb.lm(b.g,clb.$o(b,1)==1);return;}j=clb.$o(b,i);k=clb.$o(b,B);ic=clb.$o(b,i);mc=clb.$o(b,i);lc=clb.$o(b,i);O=clb.$o(b,i);for(o=0;o<j;o++)clb.yj(b.g,6);for(kb=0;kb<ic;kb++)clb._l(b.g,clb.$o(b,i),7);for(lb=0;lb<mc;lb++)clb._l(b.g,clb.$o(b,i),8);for(wb=0;wb<lc;wb++)clb._l(b.g,clb.$o(b,i),clb.$o(b,8));for(Hb=0;Hb<O;Hb++)clb.Il(b.g,clb.$o(b,i),clb.$o(b,4)-8);P=1+k-j;V=clb.$o(b,4);A=0;clb.Yl(b.g,0,0);clb.Zl(b.g,0,0);clb.$l(b.g,0,0);W=e!=null&&e[f]>=39;tc=0;wc=0;yc=0;Ac=0;R=false;S=false;if(W){if(e.length>2*j-2&&e[2*j-2]==39||e.length>3*j-3&&e[3*j-3]==39){S=true;R=e.length==3*j-3+9;_b=R?3*j-3:2*j-2;w=86*(e[_b+1]-40)+e[_b+2]-40;tc=$wnd.Math.pow(10,w/2000-1);_b+=2;vc=86*(e[_b+1]-40)+e[_b+2]-40;wc=$wnd.Math.pow(10,vc/1500-1);_b+=2;xc=86*(e[_b+1]-40)+e[_b+2]-40;yc=$wnd.Math.pow(10,xc/1500-1);if(R){_b+=2;zc=86*(e[_b+1]-40)+e[_b+2]-40;Ac=$wnd.Math.pow(10,zc/1500-1);}}else {R=e.length==3*j-3;}}if(b.xb()&&R){e=null;W=false;}for(Sb=1;Sb<j;Sb++){X=clb.$o(b,V);if(X==0){if(W){clb.Yl(b.g,Sb,clb.rk(b.g,0)+8*(e[Sb*2-2]-83));clb.Zl(b.g,Sb,clb.sk(b.g,0)+8*(e[Sb*2-1]-83));R&&clb.$l(b.g,Sb,clb.tk(b.g,0)+8*(e[2*j-3+Sb]-83));}++P;continue;}A+=X-1;if(W){clb.Yl(b.g,Sb,clb.rk(b.g,A)+e[Sb*2-2]-83);clb.Zl(b.g,Sb,clb.sk(b.g,A)+e[Sb*2-1]-83);R&&clb.$l(b.g,Sb,clb.tk(b.g,A)+(e[2*j-3+Sb]-83));}clb.Aj(b.g,A,Sb,1);}for(Wb=0;Wb<P;Wb++)clb.Aj(b.g,clb.$o(b,i),clb.$o(b,i),1);ac=gW(Ykb.Z0,Amb,6,k,16,1);for(I=0;I<k;I++){J=clb.$o(b,2);switch(J){case 0:ac[I]=true;break;case 2:clb.jm(b.g,I,2);break;case 3:clb.jm(b.g,I,4);}}h=clb.$o(b,i);for(Xb=0;Xb<h;Xb++){n=clb.$o(b,i);if(uc==8){nc=clb.$o(b,2);if(nc==3){clb.Nl(b.g,n,1,0);clb.Tl(b.g,n,1,false);}else {clb.Tl(b.g,n,nc,false);}}else {nc=clb.$o(b,3);switch(nc){case 4:clb.Tl(b.g,n,1,false);clb.Nl(b.g,n,1,clb.$o(b,3));break;case 5:clb.Tl(b.g,n,2,false);clb.Nl(b.g,n,1,clb.$o(b,3));break;case 6:clb.Tl(b.g,n,1,false);clb.Nl(b.g,n,2,clb.$o(b,3));break;case 7:clb.Tl(b.g,n,2,false);clb.Nl(b.g,n,2,clb.$o(b,3));break;default:clb.Tl(b.g,n,nc,false);}}}uc==8&&clb.$o(b,1)==0&&(b.g.L=true);g=clb.$o(b,B);for(Yb=0;Yb<g;Yb++){D=clb.$o(b,B);if(clb.Kk(b.g,D)==1){nc=clb.$o(b,3);switch(nc){case 4:clb.gm(b.g,D,1,false);clb.dm(b.g,D,1,clb.$o(b,3));break;case 5:clb.gm(b.g,D,2,false);clb.dm(b.g,D,1,clb.$o(b,3));break;case 6:clb.gm(b.g,D,1,false);clb.dm(b.g,D,2,clb.$o(b,3));break;case 7:clb.gm(b.g,D,2,false);clb.dm(b.g,D,2,clb.$o(b,3));break;default:clb.gm(b.g,D,nc,false);}}else {clb.gm(b.g,D,clb.$o(b,2),false);}}clb.lm(b.g,clb.$o(b,1)==1);m=null;kc=0;while(clb.$o(b,1)==1){U=kc+clb.$o(b,4);switch(U){case 0:jc=clb.$o(b,i);for(Zb=0;Zb<jc;Zb++){n=clb.$o(b,i);clb.Ul(b.g,n,lnb,true);}break;case 1:jc=clb.$o(b,i);for($b=0;$b<jc;$b++){n=clb.$o(b,i);gc=clb.$o(b,8);clb.Sl(b.g,n,gc);}break;case 2:jc=clb.$o(b,B);for(mb=0;mb<jc;mb++){clb.$o(b,B);}break;case 3:jc=clb.$o(b,i);for(nb=0;nb<jc;nb++){n=clb.$o(b,i);clb.Ul(b.g,n,Imb,true);}break;case 4:jc=clb.$o(b,i);for(ob=0;ob<jc;ob++){n=clb.$o(b,i);rc=C1(q1(clb.$o(b,4)),3);clb.Ul(b.g,n,rc,true);}break;case 5:jc=clb.$o(b,i);for(pb=0;pb<jc;pb++){n=clb.$o(b,i);l=C1(q1(clb.$o(b,2)),1);clb.Ul(b.g,n,l,true);}break;case 6:jc=clb.$o(b,i);for(qb=0;qb<jc;qb++){n=clb.$o(b,i);clb.Ul(b.g,n,1,true);}break;case 7:jc=clb.$o(b,i);for(rb=0;rb<jc;rb++){n=clb.$o(b,i);hb=C1(q1(clb.$o(b,4)),7);clb.Ul(b.g,n,hb,true);}break;case 8:jc=clb.$o(b,i);for(sb=0;sb<jc;sb++){n=clb.$o(b,i);t=clb.$o(b,4);r=gW(Ykb.AX,gmb,6,t,15,1);for(bc=0;bc<t;bc++){s=clb.$o(b,8);r[bc]=s;}clb.Ol(b.g,n,r);}break;case 9:jc=clb.$o(b,B);for(tb=0;tb<jc;tb++){D=clb.$o(b,B);rc=clb.$o(b,2)<<7;clb.im(b.g,D,rc,true);}break;case 10:jc=clb.$o(b,B);for(ub=0;ub<jc;ub++){D=clb.$o(b,B);L=clb.$o(b,5);clb.im(b.g,D,L,true);}break;case 11:jc=clb.$o(b,i);for(vb=0;vb<jc;vb++){n=clb.$o(b,i);clb.Ul(b.g,n,knb,true);}break;case 12:jc=clb.$o(b,B);for(xb=0;xb<jc;xb++){D=clb.$o(b,B);M=clb.$o(b,8)<<9;clb.im(b.g,D,M,true);}break;case 13:jc=clb.$o(b,i);for(yb=0;yb<jc;yb++){n=clb.$o(b,i);oc=C1(q1(clb.$o(b,3)),14);clb.Ul(b.g,n,oc,true);}break;case 14:jc=clb.$o(b,i);for(zb=0;zb<jc;zb++){n=clb.$o(b,i);hc=C1(q1(clb.$o(b,5)),17);clb.Ul(b.g,n,hc,true);}break;case 15:case 31:kc+=16;break;case 16:jc=clb.$o(b,i);for(Ab=0;Ab<jc;Ab++){n=clb.$o(b,i);qc=C1(q1(clb.$o(b,3)),22);clb.Ul(b.g,n,qc,true);}break;case 17:jc=clb.$o(b,i);for(Bb=0;Bb<jc;Bb++){n=clb.$o(b,i);clb.Gl(b.g,n,clb.$o(b,4));}break;case 18:jc=clb.$o(b,i);fc=clb.$o(b,4);for(Cb=0;Cb<jc;Cb++){n=clb.$o(b,i);T=clb.$o(b,fc);cc=gW(Ykb.wX,Fnb,6,T,15,1);for(bc=0;bc<T;bc++)cc[bc]=clb.$o(b,7)<<24>>24;clb.Ll(b.g,n,Zkb.u5(alb.ogb(cc,0,(dc=cc.length,alb.lgb(),dc))));}break;case 19:jc=clb.$o(b,i);for(Db=0;Db<jc;Db++){n=clb.$o(b,i);N=C1(q1(clb.$o(b,3)),25);clb.Ul(b.g,n,N,true);}break;case 20:jc=clb.$o(b,B);for(Eb=0;Eb<jc;Eb++){D=clb.$o(b,B);qc=clb.$o(b,3)<<17;clb.im(b.g,D,qc,true);}break;case 21:jc=clb.$o(b,i);for(Fb=0;Fb<jc;Fb++){n=clb.$o(b,i);clb.Vl(b.g,n,clb.$o(b,2)<<4);}break;case 22:jc=clb.$o(b,i);for(Gb=0;Gb<jc;Gb++){n=clb.$o(b,i);clb.Ul(b.g,n,jnb,true);}break;case 23:jc=clb.$o(b,B);for(Ib=0;Ib<jc;Ib++){D=clb.$o(b,B);clb.im(b.g,D,Inb,true);}break;case 24:jc=clb.$o(b,B);for(Jb=0;Jb<jc;Jb++){D=clb.$o(b,B);l=clb.$o(b,2)<<21;clb.im(b.g,D,l,true);}break;case 25:for(Kb=0;Kb<j;Kb++)clb.$o(b,1)==1&&clb.Wl(b.g,Kb,true);break;case 26:jc=clb.$o(b,B);m=gW(Ykb.AX,gmb,6,jc,15,1);for(Lb=0;Lb<jc;Lb++)m[Lb]=clb.$o(b,B);break;case 27:jc=clb.$o(b,i);for(Mb=0;Mb<jc;Mb++){n=clb.$o(b,i);clb.Ul(b.g,n,Bmb,true);}break;case 28:jc=clb.$o(b,B);for(Nb=0;Nb<jc;Nb++)clb.jm(b.g,clb.$o(b,B),32);break;case 29:jc=clb.$o(b,i);for(Ob=0;Ob<jc;Ob++){n=clb.$o(b,i);gb=C1(q1(clb.$o(b,2)),30);clb.Ul(b.g,n,gb,true);}break;case 30:jc=clb.$o(b,i);for(Pb=0;Pb<jc;Pb++){n=clb.$o(b,i);qc=C1(q1(clb.$o(b,7)),32);clb.Ul(b.g,n,qc,true);}break;case 32:jc=clb.$o(b,i);for(Qb=0;Qb<jc;Qb++){n=clb.$o(b,i);sc=C1(q1(clb.$o(b,2)),44);clb.Ul(b.g,n,sc,true);}break;case 33:jc=clb.$o(b,i);for(Rb=0;Rb<jc;Rb++){n=clb.$o(b,i);bb=C1(q1(clb.$o(b,5)),39);clb.Ul(b.g,n,bb,true);}break;case 34:jc=clb.$o(b,i);for(Tb=0;Tb<jc;Tb++){n=clb.$o(b,i);clb.Ul(b.g,n,Lmb,true);}break;case 35:jc=clb.$o(b,B);for(Ub=0;Ub<jc;Ub++){D=clb.$o(b,B);clb.im(b.g,D,Lnb,true);}break;case 36:jc=clb.$o(b,B);for(Vb=0;Vb<jc;Vb++){D=clb.$o(b,B);K=clb.$o(b,2)<<5;clb.im(b.g,D,K,true);}break;case 37:jc=clb.$o(b,B);for(jb=0;jb<jc;jb++){D=clb.$o(b,B);K=clb.$o(b,1)==0?8:16;clb.jm(b.g,D,K);}}}clb.ce(new clb.me(b.g),ac,false);if(m!=null)for(F=m,G=0,H=F.length;G<H;++G){D=F[G];clb.jm(b.g,D,clb.Kk(b.g,D)==2?4:2);}if(e==null&&!b.i&&d.length>b.e+1&&(d[b.e+1]==32||d[b.e+1]==9)){e=d;f=b.e+2;}if(e!=null){try{if(e[f]==33||e[f]==35){clb._o(b,e,f+1);R=clb.$o(b,1)==1;S=clb.$o(b,1)==1;pc=2*clb.$o(b,4);C=1<<pc;eb=0;D=0;for(p=1;p<j;p++){if(D<k&&clb.zk(b.g,1,D)==p){eb=clb.zk(b.g,0,D++);db=1;}else {eb=0;db=8;}clb.Yl(b.g,p,clb.rk(b.g,eb)+db*(clb.$o(b,pc)-(C/2|0)));clb.Zl(b.g,p,clb.sk(b.g,eb)+db*(clb.$o(b,pc)-(C/2|0)));R&&clb.$l(b.g,p,clb.tk(b.g,eb)+db*(clb.$o(b,pc)-(C/2|0)));}if(e[f]==35){ib=0;fb=gW(Ykb.AX,gmb,6,j,15,1);for(q=0;q<j;q++)ib+=fb[q]=clb.Kn(b.g,q);for(n=0;n<j;n++){for(jb=0;jb<fb[n];jb++){hb=clb.yj(b.g,1);clb.Aj(b.g,n,hb,1);clb.Yl(b.g,hb,clb.rk(b.g,n)+(clb.$o(b,pc)-(C/2|0)));clb.Zl(b.g,hb,clb.sk(b.g,n)+(clb.$o(b,pc)-(C/2|0)));R&&clb.$l(b.g,hb,clb.tk(b.g,n)+(clb.$o(b,pc)-(C/2|0)));}}j+=ib;k+=ib;}v=R?1.5:(clb.wj(),clb.wj(),clb.vj);u=clb.wk(b.g,j,k,v);if(S){tc=clb.Zo(clb.$o(b,pc),C);wc=tc*clb.ap(clb.$o(b,pc),C);yc=tc*clb.ap(clb.$o(b,pc),C);R&&(Ac=tc*clb.ap(clb.$o(b,pc),C));db=tc/u;for(n=0;n<j;n++){clb.Yl(b.g,n,wc+db*clb.rk(b.g,n));clb.Zl(b.g,n,yc+db*clb.sk(b.g,n));R&&clb.$l(b.g,n,Ac+db*clb.tk(b.g,n));}}else {tc=1.5;db=tc/u;for(n=0;n<j;n++){clb.Yl(b.g,n,db*clb.rk(b.g,n));clb.Zl(b.g,n,db*clb.sk(b.g,n));R&&clb.$l(b.g,n,db*clb.tk(b.g,n));}}}else {R&&!S&&tc==0&&(tc=1.5);if(tc!=0&&b.g.r!=0){u=0;for(D=0;D<b.g.r;D++){Y=clb.rk(b.g,clb.zk(b.g,0,D))-clb.rk(b.g,clb.zk(b.g,1,D));Z=clb.sk(b.g,clb.zk(b.g,0,D))-clb.sk(b.g,clb.zk(b.g,1,D));$=R?clb.tk(b.g,clb.zk(b.g,0,D))-clb.tk(b.g,clb.zk(b.g,1,D)):0;u+=$wnd.Math.sqrt(Y*Y+Z*Z+$*$);}u/=b.g.r;cb=tc/u;for(n=0;n<b.g.q;n++){clb.Yl(b.g,n,clb.rk(b.g,n)*cb+wc);clb.Zl(b.g,n,clb.sk(b.g,n)*cb+yc);R&&clb.$l(b.g,n,clb.tk(b.g,n)*cb+Ac);}}}}catch(a){a=b1(a);if(mX(a,15)){ab=a;Zkb._y(ab,(Zkb.O5(),Zkb.N5),'');'Faulty id-coordinates:'+Zkb.dz(ab,ab.Gb())+' '+Zkb.u5(alb.ogb(d,0,(ec=d.length,alb.lgb(),ec)))+' '+Zkb.u5(alb.ogb(e,0,(dc=e.length,dc)));e=null;R=false;}else throw c1(a);}}Q=e!=null&&!R;if(Q||b.xb()){clb.Gt(b.g,7);for(D=0;D<b.g.g;D++)clb.Hk(b.g,D)==2&&!clb.Co(b.g,D)&&clb.Ik(b.g,D)==0&&clb.hm(b.g,D);}clb.Mo(b.g,0);if(!Q&&b.xb()){try{b.yb(b.g);Q=true;}catch(a){a=b1(a);if(mX(a,15)){ab=a;Zkb._y(ab,(Zkb.O5(),Zkb.N5),'');'2D-coordinate creation failed:'+Zkb.dz(ab,ab.Gb())+' '+Zkb.u5(alb.ogb(d,0,(dc=d.length,alb.lgb(),dc)));}else throw c1(a);}}if(Q){clb.Po(b.g);clb.Tt(b.g);}else R||clb.Mo(b.g,0);};clb.hp=function hp(a,b){var c,d,e,f,g,h;if(b.length<=0||b[0]<64)return;clb._o(a,b,0);h=clb.$o(a,4);e=clb.$o(a,1)==1;f=clb.$o(a,1)==1;for(c=0;c<a.g.f;c++){g=clb.$o(a,h);d=e;e&&f&&(d=clb.$o(a,1)==1);clb.Ql(a.g,c,g,d);}};clb.ip=function ip(){};U1(245,1,{},clb.ip);_.xb=function jp(){return false;};_.yb=function kp(a){throw c1(new Zkb.rz('Unexpected request to invent coordinates. Check source code logic!'));};_.d=0;_.e=0;_.f=0;_.i=false;Ykb.ZX=w3(245);clb.lp=function lp(a){};clb.mp=function mp(a){clb.lp(this);this.b=a;};U1(48,245,{},clb.mp);_.xb=function np(){return this.b;};_.yb=function op(a){var b;b=new glb.Rx(this.a);b.g=new dlb.Zdb(78187493520);glb.yx(b,a);};_.a=2;_.b=false;Ykb.$X=w3(48);clb.pp=function pp(a,b,c,d){var e,f,g,h,i,j,k,l,m,n,o,p,q,r;e=b.a;n=b.g;j=z1(e1(clb.pk(a.k,e),1),0);f=clb.kk(a.k,e);l=f!=null?clb.wp(a,e,f,d):j?'*':clb.jk(a.k,e);!j&&f==null&&clb.lo(a.k,e)&&(a.j&4)==0&&(clb.mn(a.k,e)!=0||clb.bk(a.k,e)==-1&&clb.qk(a.k,e)==0)&&(l=alb.Pgb(l).toLowerCase());b.f&&(c.a+='(',c);n!=-1&&clb.tp(a,clb.tn(a.k,b.a,b.g),b.g,c);g=clb.dk(a.k,e);if(g==0&&(a.j&1)!=0){h=e1(clb.pk(a.k,e),Omb);j1(h,Rmb)==0?g=-1:j1(h,Qmb)==0&&(g=1);}k=clb.nk(a.k,e);m=(a.j&2)!=0?clb.mk(a.k,e):0;o=(a.j&1)!=0?clb.Cp(a,e,d):null;r=!j&&!clb.Jp(clb.uk(a.k,e))||f!=null||(clb.ok(a.k,e)==1||clb.ok(a.k,e)==2)&&(q=clb.ik(a.k,e)-1,!(q!=-1&&a.i[q][clb.hk(a.k,e)]<=1))&&(clb.uk(a.k,e)!=7||clb.dk(a.k,e)>0)||clb.lo(a.k,e)&&clb.mn(a.k,e)==0&&(a.j&4)==0||g!=0||k!=0||m!=0||clb.bk(a.k,e)!=-1||clb.qk(a.k,e)!=0||o!=null;r&&(c.a+='[',c);k!=0&&(c.a+=k,c);c.a+=''+l;(clb.ok(a.k,e)==1||clb.ok(a.k,e)==2)&&(p=clb.ik(a.k,e)-1,!(p!=-1&&a.i[p][clb.hk(a.k,e)]<=1))&&(clb.uk(a.k,e)!=7||clb.dk(a.k,e)>0)&&Zkb.G5(c,clb.Bp(a,e,n));if((a.j&1)==0&&r){i=clb.Vn(a.k,e);i==1?(c.a+='H',c):i>1&&(c.a+='H'+i,c);}if(g!=0){c.a+=String.fromCharCode(g>0?43:45);$wnd.Math.abs(g)>1&&Zkb.D5(c,$wnd.Math.abs(g));}o!=null&&(c.a+=''+o,c);if(m!=0){c.a+=':';c.a+=m;}r&&(c.a+=']',c);clb.up(a,b,c);b.e&&(c.a+=')',c);};clb.qp=function qp(a,b,c){var d,e,f,g,h;f=true;h=dlb.Bi(a.g,b).a;g=clb.Fp(a,h);while(g!=-1){d=clb.vn(a.k,h,g);e=clb.xn(a.k,h,g);g=clb.Fp(a,d);clb.sp(a,new clb.Vs(d,e,h,c&&f,c&&g==-1),++b);h=d;f=false;}};clb.rp=function rp(a,b,c){var d,e,f,g;for(e=b,f=0,g=e.length;f<g;++f){d=e[f];a.f[d&1073741823]=(d&fob)!=0^c?2:1;}};clb.sp=function sp(a,b,c){dlb.vi(a.g,c,b);a.b[b.a]=true;b.g!=-1&&(a.c[clb.tn(a.k,b.a,b.g)]=true);};clb.tp=function tp(a,b,c,d){var e,f,g,h,i;i=alb.Pgb(d.a).length;a.f[b]!=0&&Zkb.C5(d,a.f[b]==1?47:92);if(a.j==1){f=clb.Jk(a.k,127);if(f!=0){(f&1)!=0&&a.f[b]==0&&(d.a+='-',d);if((f&2)!=0){alb.Pgb(d.a).length!=i&&(d.a+=',',d);d.a+='=';}if((f&4)!=0){alb.Pgb(d.a).length!=i&&(d.a+=',',d);d.a+='#';}if((f&8)!=0){alb.Pgb(d.a).length!=i&&(d.a+=',',d);d.a+='$';}if((f&16)!=0){alb.Pgb(d.a).length!=i&&(d.a+=',',d);d.a+='$';}if((f&64)!=0){alb.Pgb(d.a).length!=i&&(d.a+=',',d);d.a+=':';}if((f&32)!=0){alb.Pgb(d.a).length!=i&&(d.a+=',',d);Zkb.G5(d,clb.jl(a.k,c)?'<-':'->');}}}if(i==alb.Pgb(d.a).length&&(!clb.mo(a.k,b)||(a.j&4)!=0)){e=clb.Kk(a.k,b)&127;e==1?clb.lo(a.k,clb.zk(a.k,0,b))&&clb.lo(a.k,clb.zk(a.k,1,b))&&(a.j&4)==0&&a.f[b]==0&&(d.a+='-',d):e==2?(d.a+='=',d):e==4?(d.a+='#',d):e==8?(d.a+='$',d):e==16?(d.a+='$',d):e==64?(d.a+=':',d):e==32&&Zkb.G5(d,clb.jl(a.k,c)?'<-':'->');}if(a.j==1){g=i==alb.Pgb(d.a).length?'':';';h=clb.Jk(a.k,b)&384;h==256?(d.a+=g+'@',d):h==128&&(d.a+=g+'!@',d);}};clb.up=function up(a,b,c){var d,e,f;if(b.c!=null){for(e=0;e<b.c.length;e++){for(f=0;f<clb.wn(a.k,b.a);f++){if(b.c[e]==clb.vn(a.k,b.a,f)){d=clb.xn(a.k,b.a,f);b.d[e]||clb.tp(a,d,b.a,c);a.e[d]>9&&(c.a+='%',c);Zkb.D5(c,a.e[d]);}}}}};clb.vp=function vp(a){var b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G,H,I,J,K,L,M,N,O;M=new dlb.Qi();for(r=new dlb.Obb(a.g);r.a<r.c.a.length;){q=dlb.Nbb(r);if(q.g!=-1){t=clb.tn(a.k,q.a,q.g);if(!clb.no(a.k,t)&&!clb.Co(a.k,t)&&(clb.Ik(a.k,t)==1||clb.Ik(a.k,t)==2)){K=dlb.Bi(a.g,a.q[q.g]);c=gW(Ykb.AX,gmb,6,clb.wn(a.k,q.a)+clb.wn(a.k,K.a)-2,15,1);B=0;L=false;if(K.g!=-1){c[B++]=K.b;}else {u=-1;N=-1;v=Qlb;for(D=0;D<clb.wn(a.k,K.a);D++){l=clb.vn(a.k,K.a,D);if(l!=q.a){if(u==-1){u=D;v=a.q[l];}else {if(v<a.q[l]){N=D;}else {N=u;u=D;}}}}if(N==-1){H=clb.vn(a.k,K.a,u);I=clb.xn(a.k,K.a,u);c[B++]=I|(clb.Hp(a,K.a,H)?fob:0);}else {m=clb.vn(a.k,K.a,u);o=clb.xn(a.k,K.a,u);n=clb.vn(a.k,K.a,N);p=clb.xn(a.k,K.a,N);c[B++]=o|(clb.Hp(a,K.a,m)?fob:0);c[B++]=p|(clb.Hp(a,K.a,n)?0:fob);}}if(clb.wn(a.k,K.a)==3&&K.g!=-1){for(D=0;D<clb.wn(a.k,K.a);D++){l=clb.vn(a.k,K.a,D);if(l!=K.g&&l!=q.a){d=clb.xn(a.k,K.a,D);c[B++]=d|(clb.Hp(a,K.a,l)?fob:0);l<K.g&&(L=!L);break;}}}clb.Ik(a.k,t)==2&&(L=!L);for(C=0;C<clb.wn(a.k,q.a);C++){i=clb.vn(a.k,q.a,C);if(i!=q.g){A=L;if(clb.wn(a.k,q.a)==3){for(G=0;G<clb.wn(a.k,q.a);G++){l=clb.vn(a.k,q.a,G);if(l!=q.g&&l!=i){l<i&&(A=!A);break;}}}if(clb.el(a.k,t)){w=clb.If(a.d,t);if(!a.n[w]){a.n[w]=true;a.o[w]=A;}a.o[w]&&(A=!A);}j=clb.tn(a.k,q.a,i);c[B++]=j|(A^clb.Hp(a,q.a,i)?0:fob);}}alb.ggb(M.a,c);}}}a.f=gW(Ykb.AX,gmb,6,a.k.g,15,1);M.a.length!=0&&clb.rp(a,dlb.Ii(M,0),false);while(M.a.length!=0){O=M.a.length;for(C=M.a.length-1;C>=0;C--){c=(alb.Dgb(C,M.a.length),M.a[C]);J=0;F=false;k=false;for(f=c,g=0,h=f.length;g<h;++g){e=f[g];b=e&1073741823;if(a.f[b]!=0){s=(e&fob)!=0^a.f[b]==2;J==0?F=s:F!=s&&(k=true);++J;}}if(J!=0){c=dlb.Ii(M,C);k||clb.rp(a,c,F);}}O==M.a.length&&clb.rp(a,dlb.Ii(M,0),false);}};clb.wp=function wp(a,b,c,d){var e,f,g,h,i,j,k;k=alb.Pgb(d.a).length;0<k?d.a=Zkb.p5(d.a,0,0):0>k&&(d.a+=Zkb.u5(gW(Ykb.xX,Anb,6,-k,15,1)));i=clb.lo(a.k,b)&&(a.j&4)==0;for(f=c,g=0,h=f.length;g<h;++g){e=f[g];alb.Pgb(d.a).length!=0&&(d.a+=',',d);j=(clb.wj(),clb.qj)[e];Zkb.G5(d,i?alb.Pgb(j).toLowerCase():j);}return d.a;};clb.xp=function xp(a){var b,c,d,e,f,g,h,i;if(!a.k||a.k.q==0)return '';clb.Gt(a.k,15);a.d=new clb.bg(a.k,129);e=a.d.R;a.o=gW(Ykb.Z0,Amb,6,e+1,16,1);a.n=gW(Ykb.Z0,Amb,6,e+1,16,1);a.i=eW(Ykb.AX,[Dnb,gmb],[7,6],15,[2,32],2);for(b=0;b<a.k.f;b++){i=clb.ik(a.k,b)-1;i!=-1&&++a.i[i][clb.hk(a.k,b)];}clb.Ap(a);clb.yp(a);clb.vp(a);d=new Zkb.J5();c=new Zkb.J5();f=true;for(h=new dlb.Obb(a.g);h.a<h.c.a.length;){g=dlb.Nbb(h);g.g==-1&&(f?f=false:(d.a+='.',d));clb.pp(a,g,d,c);}return d.a;};clb.yp=function yp(a){var b,c,d,e,f,g,h,i,j,k,l;for(l=new dlb.Obb(a.g);l.a<l.c.a.length;){j=dlb.Nbb(l);c=0;for(f=0;f<clb.wn(a.k,j.a);f++)a.c[clb.xn(a.k,j.a,f)]||++c;if(c!=0){j.c=gW(Ykb.AX,gmb,6,c,15,1);c=0;for(g=0;g<clb.wn(a.k,j.a);g++){if(!a.c[clb.xn(a.k,j.a,g)]){i=clb.vn(a.k,j.a,g);j.c[c++]=a.q[i]<<16|i;}}alb.jgb(j.c,alb.Pgb(X1(dlb.ucb.prototype.kc,dlb.ucb,[])));for(e=0;e<j.c.length;e++)j.c[e]=Zlb&j.c[e];}}d=gW(Ykb.Z0,Amb,6,a.k.g,16,1);a.e=gW(Ykb.AX,gmb,6,a.k.g,15,1);for(k=new dlb.Obb(a.g);k.a<k.c.a.length;){j=dlb.Nbb(k);if(j.c!=null){j.d=gW(Ykb.Z0,Amb,6,j.c.length,16,1);for(e=0;e<j.c.length;e++){for(h=0;h<clb.wn(a.k,j.a);h++){if(j.c[e]==clb.vn(a.k,j.a,h)){b=clb.xn(a.k,j.a,h);if(a.c[b]){d[a.e[b]]=false;}else {a.c[b]=true;j.d[e]=true;a.e[b]=1;while(d[a.e[b]])++a.e[b];d[a.e[b]]=true;}}}}}}};clb.zp=function zp(a){var b,c,d,e;d=-1;e=Qlb;for(b=0;b<a.k.f;b++){if(!a.b[b]){c=a.a[b];z1(e1(clb.pk(a.k,b),Bmb),0)&&(c+=fob);clb.wn(a.k,b)==0?c+=1056964608:c+=clb.wn(a.k,b)<<24;if(e>c){e=c;d=b;}}}return d;};clb.Ap=function Ap(a){var b,c,d,e,f;a.a=a.d.d;a.b=gW(Ykb.Z0,Amb,6,a.k.f,16,1);a.c=gW(Ykb.Z0,Amb,6,a.k.g,16,1);a.g=new dlb.Qi();b=clb.zp(a);while(b!=-1){c=a.g.a.length;clb.sp(a,new clb.Vs(b,-1,-1,false,false),c);if(clb.wn(a.k,b)!=0){clb.qp(a,c,false);while(c<a.g.a.length-1){while(clb.Gp(a,dlb.Bi(a.g,c).a))clb.qp(a,c,true);++c;}}b=clb.zp(a);}a.q=gW(Ykb.AX,gmb,6,a.k.f,15,1);d=0;for(f=new dlb.Obb(a.g);f.a<f.c.a.length;){e=dlb.Nbb(f);a.q[e.a]=d++;}};clb.Bp=function Bp(a,b,c){var d,e,f,g,h,i,j,k,l,m,n;h=false;if(clb.mn(a.k,b)!=0&&clb.wn(a.k,b)==2&&clb.yn(a.k,b,0)==2&&clb.yn(a.k,b,1)==2){for(f=0;f<clb.wn(a.k,b);f++){d=clb.vn(a.k,b,f);n=0;m=gW(Ykb.AX,gmb,6,3,15,1);for(j=0;j<clb.wn(a.k,d);j++){m[n]=clb.vn(a.k,d,j);m[n]!=b&&++n;}n==2&&a.q[m[0]]<a.q[m[1]]^m[0]<m[1]&&(h=!h);}}else {k=gW(Ykb.AX,gmb,6,4,15,1);l=gW(Ykb.AX,gmb,6,4,15,1);g=0;if(c!=-1){k[g]=c;l[g++]=8*a.q[c];}if(clb.Kn(a.k,b)!=0){k[g]=Qlb;l[g++]=8*a.q[b];}else if(clb.wn(a.k,b)==3){k[g]=Qlb;l[g++]=8*a.q[b];}for(f=0;f<clb.wn(a.k,b);f++){d=clb.vn(a.k,b,f);if(d!=c){k[g]=d;l[g++]=clb.Ep(a,b,f);}}h=clb.Ip(k,l);}i=clb.ok(a.k,b)==1^h;if(clb.Zk(a.k,b)){e=clb.Jf(a.d,b);if(!a.n[e]){a.n[e]=true;a.o[e]=i;}a.o[e]&&(i=!i);}return i?'@@':'@';};clb.Cp=function Cp(a,b,c){var d,e,f,g,h,i,j,k;h=alb.Pgb(c.a).length;0<h?c.a=Zkb.p5(c.a,0,0):0>h&&(c.a+=Zkb.u5(gW(Ykb.xX,Anb,6,-h,15,1)));i=clb.pk(a.k,b);e=I1(D1(e1(i,Omb),3));switch(e){case 20971520:c.a+='+0';break;case 25165824:clb.dk(a.k,b)==0&&(c.a+='-',c);break;case 12582912:clb.dk(a.k,b)==0&&(c.a+='+',c);}d=e1(i,Hnb);j1(d,2)==0?(c.a+=';a',c):j1(d,4)==0&&(c.a+=';A',c);f=e1(i,Mmb);j1(f,0)!=0&&(j1(f,1792)==0?(c.a+=';H0',c):j1(f,1664)==0?(c.a+=';H1',c):j1(f,1408)==0?(c.a+=';H2',c):j1(f,896)==0?(c.a+=';H3',c):j1(f,128)==0?(c.a+=';!H0',c):j1(f,384)==0?(c.a+=';!H0;!H1',c):j1(f,1536)==0?(c.a+=';!H2;!H3',c):j1(f,Nmb)==0&&(c.a+=';!H3',c));k=e1(i,120);j1(k,8)==0?(c.a+=';!R0',c):j1(k,16)==0?(c.a+=';!R1',c):j1(k,32)==0?(c.a+=';!R2',c):j1(k,64)==0?(c.a+=';!R3',c):j1(k,112)==0?(c.a+=';R0',c):j1(k,104)==0?(c.a+=';R1',c):j1(k,88)==0?(c.a+=';R2',c):j1(k,56)==0&&(c.a+=';R3',c);j=e1(i,kmb);if(j1(j,lmb)==0)c.a+=';!r'+J1(j);else if(j1(j,gob)==0)c.a+=';r'+J1(j);else if(j1(j,0)!=0){if(z1(e1(j,rmb),0)){o1(e1(j,lmb),0)&&(c.a+=';!r0'+J1(j),c);o1(e1(j,mmb),0)&&(c.a+=';!r3'+J1(j),c);o1(e1(j,nmb),0)&&(c.a+=';!r4'+J1(j),c);o1(e1(j,omb),0)&&(c.a+=';!r5'+J1(j),c);o1(e1(j,pmb),0)&&(c.a+=';!r6'+J1(j),c);o1(e1(j,qmb),0)&&(c.a+=';!r7'+J1(j),c);}else {c.a+=';';z1(e1(j,lmb),0)&&(c.a+='r0,'+J1(j),c);z1(e1(j,mmb),0)&&(c.a+='r3,'+J1(j),c);z1(e1(j,nmb),0)&&(c.a+='r4,'+J1(j),c);z1(e1(j,omb),0)&&(c.a+='r5,'+J1(j),c);z1(e1(j,pmb),0)&&(c.a+='r6,'+J1(j),c);z1(e1(j,qmb),0)&&(c.a+='r7,'+J1(j),c);Zkb.B2(c,alb.Pgb(c.a).length-1);}}if(j1(j,0)==0){j=D1(e1(i,inb),22);j1(j,0)!=0&&(c.a+=';r'+J1(j),c);}g=e1(i,Tmb);j1(g,3801088)==0&&(c.a+=';D1',c);j1(g,Umb)==0&&(c.a+=';D2',c);j1(g,Vmb)==0&&(c.a+=';D3',c);j1(g,3145728)==0&&(c.a+=';!D3;!D4',c);j1(g,Wmb)==0&&(c.a+=';!D4',c);j1(g,Xmb)==0&&(c.a+=';!D0;!D1',c);j1(g,Ymb)==0&&(c.a+=';!D0;!D1;!D2',c);j1(g,Zmb)==0&&(c.a+=';!D0;!D1;!D2;!D3',c);z1(e1(i,lnb),0)&&Zkb.G5(c,';D'+clb.wn(a.k,b));z1(e1(i,Imb),0)&&Zkb.G5(c,';!D'+clb.wn(a.k,b));return alb.Pgb(c.a).length==0?null:c.a;};clb.Dp=function Dp(a){a.p==null&&(a.p=clb.xp(a));return a.p;};clb.Ep=function Ep(a,b,c){var d,e,f,g,h;d=clb.xn(a.k,b,c);g=clb.vn(a.k,b,c);if(a.e[d]!=0){h=8*a.q[b]+1;e=dlb.Bi(a.g,a.q[b]).c;for(f=0;f<e.length&&g!=e[f];f++)++h;return h;}return 8*a.q[g];};clb.Fp=function Fp(a,b){var c,d,e,f,g;c=-1;d=-1;for(f=0;f<clb.wn(a.k,b);f++){e=clb.vn(a.k,b,f);g=(clb.yn(a.k,b,f)<<24)+a.a[e];if(!a.b[e]&&(c==-1||d<g)){c=f;d=g;}}return c;};clb.Gp=function Gp(a,b){var c;for(c=0;c<clb.wn(a.k,b);c++)if(!a.b[clb.vn(a.k,b,c)])return true;return false;};clb.Hp=function Hp(a,b,c){var d,e;d=dlb.Bi(a.g,a.q[b]);if(d.g==c)return false;e=dlb.Bi(a.g,a.q[c]);if(e.g==b)return true;return clb.Us(e,b);};clb.Ip=function Ip(a,b){var c,d,e;d=false;for(c=1;c<4;c++){for(e=0;e<c;e++){a[e]>a[c]&&(d=!d);b[e]>b[c]&&(d=!d);}}return d;};clb.Jp=function Jp(a){return a>=5&&a<=9||a>=15&&a<=17||a==35||a==53;};clb.Kp=function Kp(a){clb.Mp.call(this,a,false);};clb.Lp=function Lp(a,b){this.k=a;this.j=b;};clb.Mp=function Mp(a,b){clb.Lp.call(this,a,b?2:0);};clb.Np=function Np(a){var b,c,d,e;e=new Zkb.J5();for(c=0;c<a.g.a.length;c++){c!=0&&(e.a+='.',e);Zkb.G5(e,clb.Dp(new clb.Lp(dlb.Bi(a.g,c),2)));}e.a+='>';for(d=0;d<a.a.a.length;d++){d!=0&&(e.a+='.',e);Zkb.G5(e,clb.Dp(new clb.Kp(dlb.Bi(a.a,d))));}e.a+='>';for(b=0;b<a.f.a.length;b++){b!=0&&(e.a+='.',e);Zkb.G5(e,clb.Dp(new clb.Lp(dlb.Bi(a.f,b),2)));}return e.a;};U1(90,1,{},clb.Kp,clb.Lp,clb.Mp);_.j=0;Ykb._X=w3(90);clb.Op=function Op(a,b){this.b=a;this.a=b;};U1(3,1,{3:1},clb.Op);_.a=0;_.b=0;Ykb.aY=w3(3);clb.Qp=function Qp(){clb.Qp=W1;clb.Pp=oW(aW(Ykb.aY,2),Llb,14,0,[null,oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(0,1.007825032),new clb.Op(1,2.014101778),new clb.Op(2,3.016049268),new clb.Op(3,4.027834627),new clb.Op(4,5.039542911),new clb.Op(5,6.044942608)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(1,3.01602931),new clb.Op(2,4.00260325),new clb.Op(3,5.012223628),new clb.Op(4,6.018888072),new clb.Op(5,7.028030527),new clb.Op(6,8.033921838),new clb.Op(7,9.043820323),new clb.Op(8,10.052399713)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(1,4.027182329),new clb.Op(2,5.012537796),new clb.Op(3,6.015122281),new clb.Op(4,7.016004049),new clb.Op(5,8.02248667),new clb.Op(6,9.026789122),new clb.Op(7,10.035480884),new clb.Op(8,11.043796166),new clb.Op(9,12.05378)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(1,5.04079),new clb.Op(2,6.019725804),new clb.Op(3,7.016929246),new clb.Op(4,8.005305094),new clb.Op(5,9.012182135),new clb.Op(6,10.01353372),new clb.Op(7,11.021657653),new clb.Op(8,12.026920631),new clb.Op(9,13.036133834),new clb.Op(10,14.042815522)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(2,7.029917389),new clb.Op(3,8.024606713),new clb.Op(4,9.013328806),new clb.Op(5,10.012937027),new clb.Op(6,11.009305466),new clb.Op(7,12.014352109),new clb.Op(8,13.017780267),new clb.Op(9,14.025404064),new clb.Op(10,15.031097291),new clb.Op(11,16.039808836),new clb.Op(12,17.046931399),new clb.Op(13,18.05617),new clb.Op(14,19.06373)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(2,8.037675026),new clb.Op(3,9.031040087),new clb.Op(4,10.01685311),new clb.Op(5,11.011433818),new clb.Op(6,12),new clb.Op(7,13.003354838),new clb.Op(8,14.003241988),new clb.Op(9,15.010599258),new clb.Op(10,16.014701243),new clb.Op(11,17.022583712),new clb.Op(12,18.026757058),new clb.Op(13,19.035248094),new clb.Op(14,20.040322395),new clb.Op(15,21.04934),new clb.Op(16,22.05645)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(3,10.042618),new clb.Op(4,11.026796226),new clb.Op(5,12.018613202),new clb.Op(6,13.005738584),new clb.Op(7,14.003074005),new clb.Op(8,15.000108898),new clb.Op(9,16.006101417),new clb.Op(10,17.008449673),new clb.Op(11,18.014081827),new clb.Op(12,19.017026896),new clb.Op(13,20.023367295),new clb.Op(14,21.027087574),new clb.Op(15,22.034440259),new clb.Op(16,23.04051),new clb.Op(17,24.0505)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(4,12.034404776),new clb.Op(5,13.0248104),new clb.Op(6,14.008595285),new clb.Op(7,15.003065386),new clb.Op(8,15.994914622),new clb.Op(9,16.999131501),new clb.Op(10,17.999160419),new clb.Op(11,19.00357873),new clb.Op(12,20.00407615),new clb.Op(13,21.008654631),new clb.Op(14,22.009967157),new clb.Op(15,23.015691325),new clb.Op(16,24.020369922),new clb.Op(17,25.02914),new clb.Op(18,26.03775)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(5,14.03608),new clb.Op(6,15.018010856),new clb.Op(7,16.01146573),new clb.Op(8,17.002095238),new clb.Op(9,18.000937667),new clb.Op(10,18.998403205),new clb.Op(11,19.999981324),new clb.Op(12,20.999948921),new clb.Op(13,22.00299925),new clb.Op(14,23.003574385),new clb.Op(15,24.008099371),new clb.Op(16,25.012094963),new clb.Op(17,26.019633157),new clb.Op(18,27.026892316),new clb.Op(19,28.03567),new clb.Op(20,29.04326)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(6,16.025756907),new clb.Op(7,17.017697565),new clb.Op(8,18.005697066),new clb.Op(9,19.001879839),new clb.Op(10,19.992440176),new clb.Op(11,20.993846744),new clb.Op(12,21.99138551),new clb.Op(13,22.994467337),new clb.Op(14,23.993615074),new clb.Op(15,24.997789899),new clb.Op(16,26.000461498),new clb.Op(17,27.0076152),new clb.Op(18,28.012108072),new clb.Op(19,29.019345902),new clb.Op(20,30.023872),new clb.Op(21,31.03311),new clb.Op(22,32.03991)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(7,18.02718),new clb.Op(8,19.01387945),new clb.Op(9,20.00734826),new clb.Op(10,20.997655099),new clb.Op(11,21.994436782),new clb.Op(12,22.989769675),new clb.Op(13,23.990963332),new clb.Op(14,24.989954352),new clb.Op(15,25.992589898),new clb.Op(16,26.994008702),new clb.Op(17,27.99889041),new clb.Op(18,29.002811301),new clb.Op(19,30.009226487),new clb.Op(20,31.013595108),new clb.Op(21,32.019649792),new clb.Op(22,33.027386),new clb.Op(23,34.0349),new clb.Op(24,35.04418)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(8,20.018862744),new clb.Op(9,21.011714174),new clb.Op(10,21.999574055),new clb.Op(11,22.99412485),new clb.Op(12,23.985041898),new clb.Op(13,24.985837023),new clb.Op(14,25.98259304),new clb.Op(15,26.984340742),new clb.Op(16,27.983876703),new clb.Op(17,28.988554743),new clb.Op(18,29.990464529),new clb.Op(19,30.996548459),new clb.Op(20,31.999145889),new clb.Op(21,33.005586975),new clb.Op(22,34.00907244),new clb.Op(23,35.018669),new clb.Op(24,36.02245),new clb.Op(25,37.03124)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(8,21.02804),new clb.Op(9,22.01952),new clb.Op(10,23.0072649),new clb.Op(11,23.999940911),new clb.Op(12,24.990428555),new clb.Op(13,25.986891659),new clb.Op(14,26.981538441),new clb.Op(15,27.981910184),new clb.Op(16,28.980444848),new clb.Op(17,29.982960304),new clb.Op(18,30.983946023),new clb.Op(19,31.988124379),new clb.Op(20,32.990869587),new clb.Op(21,33.996927255),new clb.Op(22,34.99993765),new clb.Op(23,36.006351501),new clb.Op(24,37.01031),new clb.Op(25,38.0169),new clb.Op(26,39.0219)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(8,22.03453),new clb.Op(9,23.02552),new clb.Op(10,24.011545711),new clb.Op(11,25.00410664),new clb.Op(12,25.992329935),new clb.Op(13,26.986704764),new clb.Op(14,27.976926533),new clb.Op(15,28.976494719),new clb.Op(16,29.973770218),new clb.Op(17,30.975363275),new clb.Op(18,31.974148129),new clb.Op(19,32.97800052),new clb.Op(20,33.978575745),new clb.Op(21,34.984584158),new clb.Op(22,35.986687363),new clb.Op(23,36.99299599),new clb.Op(24,37.99598),new clb.Op(25,39.0023),new clb.Op(26,40.0058),new clb.Op(27,41.0127),new clb.Op(28,42.0161)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(9,24.03435),new clb.Op(10,25.02026),new clb.Op(11,26.01178),new clb.Op(12,26.999191645),new clb.Op(13,27.99231233),new clb.Op(14,28.981801376),new clb.Op(15,29.978313807),new clb.Op(16,30.973761512),new clb.Op(17,31.973907163),new clb.Op(18,32.971725281),new clb.Op(19,33.973636381),new clb.Op(20,34.973314249),new clb.Op(21,35.978259824),new clb.Op(22,36.979608338),new clb.Op(23,37.98447),new clb.Op(24,38.98642),new clb.Op(25,39.99105),new clb.Op(26,40.9948),new clb.Op(27,42.00009),new clb.Op(28,43.00331),new clb.Op(29,44.00988),new clb.Op(30,45.01514),new clb.Op(31,46.02383)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(10,26.02788),new clb.Op(11,27.018795),new clb.Op(12,28.004372661),new clb.Op(13,28.996608805),new clb.Op(14,29.984902954),new clb.Op(15,30.979554421),new clb.Op(16,31.97207069),new clb.Op(17,32.971458497),new clb.Op(18,33.967866831),new clb.Op(19,34.96903214),new clb.Op(20,35.96708088),new clb.Op(21,36.971125716),new clb.Op(22,37.971163443),new clb.Op(23,38.975135275),new clb.Op(24,39.97547),new clb.Op(25,40.98003),new clb.Op(26,41.98149),new clb.Op(27,42.9866),new clb.Op(28,43.98832),new clb.Op(29,44.99482),new clb.Op(30,45.99957),new clb.Op(31,47.00762),new clb.Op(32,48.01299),new clb.Op(33,49.02201)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(11,28.02851),new clb.Op(12,29.01411),new clb.Op(13,30.00477),new clb.Op(14,30.992416014),new clb.Op(15,31.985688908),new clb.Op(16,32.977451798),new clb.Op(17,33.973761967),new clb.Op(18,34.968852707),new clb.Op(19,35.968306945),new clb.Op(20,36.9659026),new clb.Op(21,37.96801055),new clb.Op(22,38.968007677),new clb.Op(23,39.970415555),new clb.Op(24,40.970650212),new clb.Op(25,41.973174994),new clb.Op(26,42.974203385),new clb.Op(27,43.978538712),new clb.Op(28,44.9797),new clb.Op(29,45.98412),new clb.Op(30,46.98795),new clb.Op(31,47.99485),new clb.Op(32,48.99989),new clb.Op(33,50.00773),new clb.Op(34,51.01353)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(12,30.02156),new clb.Op(13,31.012126),new clb.Op(14,31.99766066),new clb.Op(15,32.989928719),new clb.Op(16,33.980270118),new clb.Op(17,34.975256726),new clb.Op(18,35.967546282),new clb.Op(19,36.966775912),new clb.Op(20,37.962732161),new clb.Op(21,38.964313413),new clb.Op(22,39.962383123),new clb.Op(23,40.964500828),new clb.Op(24,41.963046386),new clb.Op(25,42.965670701),new clb.Op(26,43.965365269),new clb.Op(27,44.968094979),new clb.Op(28,45.968093467),new clb.Op(29,46.972186238),new clb.Op(30,47.97507),new clb.Op(31,48.98218),new clb.Op(32,49.98594),new clb.Op(33,50.99324),new clb.Op(34,51.99817),new clb.Op(35,53.006227)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(13,32.02192),new clb.Op(14,33.00726),new clb.Op(15,33.99841),new clb.Op(16,34.988011615),new clb.Op(17,35.981293405),new clb.Op(18,36.973376915),new clb.Op(19,37.969080107),new clb.Op(20,38.963706861),new clb.Op(21,39.963998672),new clb.Op(22,40.961825972),new clb.Op(23,41.962403059),new clb.Op(24,42.960715746),new clb.Op(25,43.961556146),new clb.Op(26,44.960699658),new clb.Op(27,45.961976203),new clb.Op(28,46.961677807),new clb.Op(29,47.965512946),new clb.Op(30,48.967450084),new clb.Op(31,49.972782832),new clb.Op(32,50.97638),new clb.Op(33,51.98261),new clb.Op(34,52.98712),new clb.Op(35,53.99399),new clb.Op(36,54.999388)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(14,34.01412),new clb.Op(15,35.004765),new clb.Op(16,35.993087234),new clb.Op(17,36.985871505),new clb.Op(18,37.976318637),new clb.Op(19,38.970717729),new clb.Op(20,39.962591155),new clb.Op(21,40.962278349),new clb.Op(22,41.958618337),new clb.Op(23,42.958766833),new clb.Op(24,43.955481094),new clb.Op(25,44.956185938),new clb.Op(26,45.953692759),new clb.Op(27,46.954546459),new clb.Op(28,47.952533512),new clb.Op(29,48.955673302),new clb.Op(30,49.957518286),new clb.Op(31,50.961474238),new clb.Op(32,51.9651),new clb.Op(33,52.97005),new clb.Op(34,53.97468),new clb.Op(35,54.98055),new clb.Op(36,55.98579),new clb.Op(37,56.992356)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(15,36.01492),new clb.Op(16,37.00305),new clb.Op(17,37.9947),new clb.Op(18,38.984790009),new clb.Op(19,39.977964014),new clb.Op(20,40.969251316),new clb.Op(21,41.965516761),new clb.Op(22,42.96115098),new clb.Op(23,43.959403048),new clb.Op(24,44.955910243),new clb.Op(25,45.95517025),new clb.Op(26,46.952408027),new clb.Op(27,47.952234991),new clb.Op(28,48.950024065),new clb.Op(29,49.952187008),new clb.Op(30,50.9536027),new clb.Op(31,51.95665),new clb.Op(32,52.95817),new clb.Op(33,53.963),new clb.Op(34,54.9694),new clb.Op(35,55.97266),new clb.Op(36,56.97704),new clb.Op(37,57.98307),new clb.Op(38,58.988041)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(16,38.00977),new clb.Op(17,39.001323),new clb.Op(18,39.990498907),new clb.Op(19,40.983131),new clb.Op(20,41.973031622),new clb.Op(21,42.968523342),new clb.Op(22,43.959690235),new clb.Op(23,44.958124349),new clb.Op(24,45.952629491),new clb.Op(25,46.951763792),new clb.Op(26,47.947947053),new clb.Op(27,48.947870789),new clb.Op(28,49.944792069),new clb.Op(29,50.946616017),new clb.Op(30,51.946898175),new clb.Op(31,52.949731709),new clb.Op(32,53.95087),new clb.Op(33,54.95512),new clb.Op(34,55.95799),new clb.Op(35,56.9643),new clb.Op(36,57.96611),new clb.Op(37,58.97196),new clb.Op(38,59.97564),new clb.Op(39,60.982018)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(17,40.01109),new clb.Op(18,40.99974),new clb.Op(19,41.99123),new clb.Op(20,42.98065),new clb.Op(21,43.9744),new clb.Op(22,44.965782286),new clb.Op(23,45.960199491),new clb.Op(24,46.954906918),new clb.Op(25,47.95225448),new clb.Op(26,48.948516914),new clb.Op(27,49.947162792),new clb.Op(28,50.943963675),new clb.Op(29,51.944779658),new clb.Op(30,52.944342517),new clb.Op(31,53.946444381),new clb.Op(32,54.947238194),new clb.Op(33,55.95036),new clb.Op(34,56.95236),new clb.Op(35,57.95665),new clb.Op(36,58.9593),new clb.Op(37,59.9645),new clb.Op(38,60.96741),new clb.Op(39,61.97314),new clb.Op(40,62.97675)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(18,42.00643),new clb.Op(19,42.997707),new clb.Op(20,43.98547),new clb.Op(21,44.97916),new clb.Op(22,45.968361649),new clb.Op(23,46.962906512),new clb.Op(24,47.954035861),new clb.Op(25,48.951341135),new clb.Op(26,49.946049607),new clb.Op(27,50.944771767),new clb.Op(28,51.940511904),new clb.Op(29,52.940653781),new clb.Op(30,53.938884921),new clb.Op(31,54.940844164),new clb.Op(32,55.940645238),new clb.Op(33,56.9437538),new clb.Op(34,57.94425),new clb.Op(35,58.94863),new clb.Op(36,59.94973),new clb.Op(37,60.95409),new clb.Op(38,61.9558),new clb.Op(39,62.96186),new clb.Op(40,63.9642),new clb.Op(41,64.97037)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(19,44.00687),new clb.Op(20,44.99451),new clb.Op(21,45.98672),new clb.Op(22,46.9761),new clb.Op(23,47.96887),new clb.Op(24,48.959623415),new clb.Op(25,49.95424396),new clb.Op(26,50.948215487),new clb.Op(27,51.945570079),new clb.Op(28,52.941294702),new clb.Op(29,53.940363247),new clb.Op(30,54.938049636),new clb.Op(31,55.938909366),new clb.Op(32,56.938287458),new clb.Op(33,57.939986451),new clb.Op(34,58.940447166),new clb.Op(35,59.943193998),new clb.Op(36,60.94446),new clb.Op(37,61.94797),new clb.Op(38,62.94981),new clb.Op(39,63.95373),new clb.Op(40,64.9561),new clb.Op(41,65.96082),new clb.Op(42,66.96382)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(19,45.01456),new clb.Op(20,46.00081),new clb.Op(21,46.99289),new clb.Op(22,47.98056),new clb.Op(23,48.97361),new clb.Op(24,49.962993316),new clb.Op(25,50.956824936),new clb.Op(26,51.948116526),new clb.Op(27,52.945312282),new clb.Op(28,53.939614836),new clb.Op(29,54.938298029),new clb.Op(30,55.934942133),new clb.Op(31,56.935398707),new clb.Op(32,57.933280458),new clb.Op(33,58.934880493),new clb.Op(34,59.934076943),new clb.Op(35,60.936749461),new clb.Op(36,61.936770495),new clb.Op(37,62.940118442),new clb.Op(38,63.94087),new clb.Op(39,64.94494),new clb.Op(40,65.94598),new clb.Op(41,66.95),new clb.Op(42,67.95251),new clb.Op(43,68.9577)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(21,48.00176),new clb.Op(22,48.98972),new clb.Op(23,49.98154),new clb.Op(24,50.97072),new clb.Op(25,51.96359),new clb.Op(26,52.954224985),new clb.Op(27,53.948464147),new clb.Op(28,54.942003149),new clb.Op(29,55.939843937),new clb.Op(30,56.936296235),new clb.Op(31,57.935757571),new clb.Op(32,58.933200194),new clb.Op(33,59.933822196),new clb.Op(34,60.932479381),new clb.Op(35,61.934054212),new clb.Op(36,62.933615218),new clb.Op(37,63.935813523),new clb.Op(38,64.936484581),new clb.Op(39,65.939825412),new clb.Op(40,66.94061),new clb.Op(41,67.94436),new clb.Op(42,68.9452),new clb.Op(43,69.94981),new clb.Op(44,70.95173),new clb.Op(45,71.95641)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(22,49.99593),new clb.Op(23,50.98772),new clb.Op(24,51.97568),new clb.Op(25,52.96846),new clb.Op(26,53.957910508),new clb.Op(27,54.951336329),new clb.Op(28,55.942136339),new clb.Op(29,56.939800489),new clb.Op(30,57.935347922),new clb.Op(31,58.934351553),new clb.Op(32,59.930790633),new clb.Op(33,60.931060442),new clb.Op(34,61.928348763),new clb.Op(35,62.929672948),new clb.Op(36,63.927969574),new clb.Op(37,64.930088013),new clb.Op(38,65.929115232),new clb.Op(39,66.931569638),new clb.Op(40,67.931844932),new clb.Op(41,68.935181837),new clb.Op(42,69.93614),new clb.Op(43,70.94),new clb.Op(44,71.9413),new clb.Op(45,72.94608),new clb.Op(46,73.94791),new clb.Op(47,74.95297),new clb.Op(48,75.95533),new clb.Op(49,76.96083),new clb.Op(50,77.9638)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(23,51.99718),new clb.Op(24,52.98555),new clb.Op(25,53.97671),new clb.Op(26,54.96605),new clb.Op(27,55.95856),new clb.Op(28,56.949215695),new clb.Op(29,57.944540734),new clb.Op(30,58.939504114),new clb.Op(31,59.937368123),new clb.Op(32,60.933462181),new clb.Op(33,61.932587299),new clb.Op(34,62.929601079),new clb.Op(35,63.929767865),new clb.Op(36,64.927793707),new clb.Op(37,65.928873041),new clb.Op(38,66.927750294),new clb.Op(39,67.929637875),new clb.Op(40,68.929425281),new clb.Op(41,69.932409287),new clb.Op(42,70.932619818),new clb.Op(43,71.93552),new clb.Op(44,72.93649),new clb.Op(45,73.9402),new clb.Op(46,74.9417),new clb.Op(47,75.94599),new clb.Op(48,76.94795),new clb.Op(49,77.95281),new clb.Op(50,78.95528),new clb.Op(51,79.96189)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(24,53.99295),new clb.Op(25,54.98398),new clb.Op(26,55.97238),new clb.Op(27,56.96491),new clb.Op(28,57.954596465),new clb.Op(29,58.949267074),new clb.Op(30,59.941832031),new clb.Op(31,60.939513907),new clb.Op(32,61.934334132),new clb.Op(33,62.933215563),new clb.Op(34,63.929146578),new clb.Op(35,64.929245079),new clb.Op(36,65.926036763),new clb.Op(37,66.927130859),new clb.Op(38,67.924847566),new clb.Op(39,68.926553538),new clb.Op(40,69.92532487),new clb.Op(41,70.927727195),new clb.Op(42,71.926861122),new clb.Op(43,72.929779469),new clb.Op(44,73.929458261),new clb.Op(45,74.932937379),new clb.Op(46,75.933394207),new clb.Op(47,76.937085857),new clb.Op(48,77.938569576),new clb.Op(49,78.942095175),new clb.Op(50,79.944414722),new clb.Op(51,80.95048),new clb.Op(52,81.95484)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(25,55.99491),new clb.Op(26,56.98293),new clb.Op(27,57.97425),new clb.Op(28,58.96337),new clb.Op(29,59.95706),new clb.Op(30,60.94917),new clb.Op(31,61.944179608),new clb.Op(32,62.939141527),new clb.Op(33,63.936838307),new clb.Op(34,64.932739322),new clb.Op(35,65.931592355),new clb.Op(36,66.928204915),new clb.Op(37,67.927983497),new clb.Op(38,68.925580912),new clb.Op(39,69.926027741),new clb.Op(40,70.92470501),new clb.Op(41,71.92636935),new clb.Op(42,72.925169832),new clb.Op(43,73.926940999),new clb.Op(44,74.926500645),new clb.Op(45,75.928928262),new clb.Op(46,76.929281189),new clb.Op(47,77.93165595),new clb.Op(48,78.932916371),new clb.Op(49,79.936588154),new clb.Op(50,80.937752955),new clb.Op(51,81.94316),new clb.Op(52,82.94687),new clb.Op(53,83.95234)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(26,57.99101),new clb.Op(27,58.98175),new clb.Op(28,59.97019),new clb.Op(29,60.96379),new clb.Op(30,61.95465),new clb.Op(31,62.94964),new clb.Op(32,63.941572638),new clb.Op(33,64.939440762),new clb.Op(34,65.933846798),new clb.Op(35,66.932738415),new clb.Op(36,67.928097266),new clb.Op(37,68.927972002),new clb.Op(38,69.924250365),new clb.Op(39,70.924953991),new clb.Op(40,71.922076184),new clb.Op(41,72.923459361),new clb.Op(42,73.921178213),new clb.Op(43,74.922859494),new clb.Op(44,75.921402716),new clb.Op(45,76.923548462),new clb.Op(46,77.922852886),new clb.Op(47,78.92540156),new clb.Op(48,79.925444764),new clb.Op(49,80.928821065),new clb.Op(50,81.929550326),new clb.Op(51,82.93451),new clb.Op(52,83.93731),new clb.Op(53,84.94269),new clb.Op(54,85.94627)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(27,59.99313),new clb.Op(28,60.98062),new clb.Op(29,61.9732),new clb.Op(30,62.96369),new clb.Op(31,63.957572),new clb.Op(32,64.949484),new clb.Op(33,65.944099147),new clb.Op(34,66.939190417),new clb.Op(35,67.936792976),new clb.Op(36,68.932280154),new clb.Op(37,69.930927811),new clb.Op(38,70.927114724),new clb.Op(39,71.926752647),new clb.Op(40,72.923825288),new clb.Op(41,73.923929076),new clb.Op(42,74.921596417),new clb.Op(43,75.922393933),new clb.Op(44,76.920647703),new clb.Op(45,77.921828577),new clb.Op(46,78.920948498),new clb.Op(47,79.922578162),new clb.Op(48,80.922132884),new clb.Op(49,81.924504668),new clb.Op(50,82.924980625),new clb.Op(51,83.92906),new clb.Op(52,84.93181),new clb.Op(53,85.93623),new clb.Op(54,86.93958),new clb.Op(55,87.94456),new clb.Op(56,88.94923)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(31,64.96466),new clb.Op(32,65.95521),new clb.Op(33,66.95009),new clb.Op(34,67.94187),new clb.Op(35,68.939562155),new clb.Op(36,69.933504),new clb.Op(37,70.931868378),new clb.Op(38,71.927112313),new clb.Op(39,72.9267668),new clb.Op(40,73.922476561),new clb.Op(41,74.922523571),new clb.Op(42,75.919214107),new clb.Op(43,76.91991461),new clb.Op(44,77.917309522),new clb.Op(45,78.918499802),new clb.Op(46,79.916521828),new clb.Op(47,80.917992931),new clb.Op(48,81.9167),new clb.Op(49,82.919119072),new clb.Op(50,83.918464523),new clb.Op(51,84.922244678),new clb.Op(52,85.924271165),new clb.Op(53,86.928520749),new clb.Op(54,87.931423982),new clb.Op(55,88.93602),new clb.Op(56,89.93942),new clb.Op(57,90.94537),new clb.Op(58,91.94933)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(32,66.96479),new clb.Op(33,67.958248),new clb.Op(34,68.950178),new clb.Op(35,69.944208),new clb.Op(36,70.939246),new clb.Op(37,71.936496876),new clb.Op(38,72.931794889),new clb.Op(39,73.929891152),new clb.Op(40,74.92577641),new clb.Op(41,75.924541974),new clb.Op(42,76.921380123),new clb.Op(43,77.92114613),new clb.Op(44,78.918337647),new clb.Op(45,79.918529952),new clb.Op(46,80.91629106),new clb.Op(47,81.916804666),new clb.Op(48,82.915180219),new clb.Op(49,83.916503685),new clb.Op(50,84.915608027),new clb.Op(51,85.918797162),new clb.Op(52,86.920710713),new clb.Op(53,87.924065908),new clb.Op(54,88.92638726),new clb.Op(55,89.930634988),new clb.Op(56,90.9339653),new clb.Op(57,91.939255258),new clb.Op(58,92.9431),new clb.Op(59,93.94868)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(33,68.96532),new clb.Op(34,69.95601),new clb.Op(35,70.95051),new clb.Op(36,71.94190754),new clb.Op(37,72.938931115),new clb.Op(38,73.933258225),new clb.Op(39,74.931033794),new clb.Op(40,75.925948304),new clb.Op(41,76.92466788),new clb.Op(42,77.920386271),new clb.Op(43,78.920082992),new clb.Op(44,79.91637804),new clb.Op(45,80.916592419),new clb.Op(46,81.913484601),new clb.Op(47,82.914135952),new clb.Op(48,83.911506627),new clb.Op(49,84.912526954),new clb.Op(50,85.910610313),new clb.Op(51,86.913354251),new clb.Op(52,87.914446951),new clb.Op(53,88.917632505),new clb.Op(54,89.919523803),new clb.Op(55,90.923442418),new clb.Op(56,91.926152752),new clb.Op(57,92.931265246),new clb.Op(58,93.934362),new clb.Op(59,94.93984),new clb.Op(60,95.94307),new clb.Op(61,96.94856)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(34,70.96532),new clb.Op(35,71.95908),new clb.Op(36,72.950366),new clb.Op(37,73.944470376),new clb.Op(38,74.938569199),new clb.Op(39,75.935071448),new clb.Op(40,76.930406599),new clb.Op(41,77.928141485),new clb.Op(42,78.923996719),new clb.Op(43,79.922519322),new clb.Op(44,80.918994165),new clb.Op(45,81.918207691),new clb.Op(46,82.915111951),new clb.Op(47,83.914384676),new clb.Op(48,84.911789341),new clb.Op(49,85.91116708),new clb.Op(50,86.909183465),new clb.Op(51,87.911318556),new clb.Op(52,88.912279939),new clb.Op(53,89.914808941),new clb.Op(54,90.91653416),new clb.Op(55,91.919725442),new clb.Op(56,92.922032765),new clb.Op(57,93.926407326),new clb.Op(58,94.92931926),new clb.Op(59,95.934283962),new clb.Op(60,96.937342863),new clb.Op(61,97.941703557),new clb.Op(62,98.945420616),new clb.Op(63,99.94987),new clb.Op(64,100.953195994),new clb.Op(65,101.95921)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(35,72.96597),new clb.Op(36,73.95631),new clb.Op(37,74.94992),new clb.Op(38,75.94161),new clb.Op(39,76.937761511),new clb.Op(40,77.932179362),new clb.Op(41,78.929707076),new clb.Op(42,79.924524588),new clb.Op(43,80.923213095),new clb.Op(44,81.918401258),new clb.Op(45,82.917555029),new clb.Op(46,83.913424778),new clb.Op(47,84.912932689),new clb.Op(48,85.909262351),new clb.Op(49,86.908879316),new clb.Op(50,87.905614339),new clb.Op(51,88.907452906),new clb.Op(52,89.907737596),new clb.Op(53,90.910209845),new clb.Op(54,91.911029895),new clb.Op(55,92.91402241),new clb.Op(56,93.915359856),new clb.Op(57,94.919358213),new clb.Op(58,95.921680473),new clb.Op(59,96.926148757),new clb.Op(60,97.928471177),new clb.Op(61,98.933315038),new clb.Op(62,99.935351729),new clb.Op(63,100.940517434),new clb.Op(64,101.943018795),new clb.Op(65,102.94895),new clb.Op(66,103.95233)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(38,76.94962),new clb.Op(39,77.9435),new clb.Op(40,78.937350712),new clb.Op(41,79.931982402),new clb.Op(42,80.929128719),new clb.Op(43,81.926792071),new clb.Op(44,82.922352572),new clb.Op(45,83.920387768),new clb.Op(46,84.916427076),new clb.Op(47,85.914887724),new clb.Op(48,86.910877833),new clb.Op(49,87.909503361),new clb.Op(50,88.905847902),new clb.Op(51,89.907151443),new clb.Op(52,90.907303415),new clb.Op(53,91.908946832),new clb.Op(54,92.909581582),new clb.Op(55,93.911594008),new clb.Op(56,94.912823709),new clb.Op(57,95.915897787),new clb.Op(58,96.918131017),new clb.Op(59,97.922219525),new clb.Op(60,98.924634736),new clb.Op(61,99.927756402),new clb.Op(62,100.930313395),new clb.Op(63,101.933555501),new clb.Op(64,102.93694),new clb.Op(65,103.94145),new clb.Op(66,104.94509),new clb.Op(67,105.95022)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(39,78.94916),new clb.Op(40,79.94055),new clb.Op(41,80.936815296),new clb.Op(42,81.931086249),new clb.Op(43,82.92865213),new clb.Op(44,83.92325),new clb.Op(45,84.92146522),new clb.Op(46,85.916472851),new clb.Op(47,86.914816578),new clb.Op(48,87.910226179),new clb.Op(49,88.908888916),new clb.Op(50,89.904703679),new clb.Op(51,90.905644968),new clb.Op(52,91.905040106),new clb.Op(53,92.906475627),new clb.Op(54,93.906315765),new clb.Op(55,94.908042739),new clb.Op(56,95.908275675),new clb.Op(57,96.910950716),new clb.Op(58,97.912746366),new clb.Op(59,98.916511084),new clb.Op(60,99.917761704),new clb.Op(61,100.921139958),new clb.Op(62,101.922981089),new clb.Op(63,102.926597062),new clb.Op(64,103.92878),new clb.Op(65,104.93305),new clb.Op(66,105.93591),new clb.Op(67,106.94086),new clb.Op(68,107.94428)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(40,80.94905),new clb.Op(41,81.94313),new clb.Op(42,82.936703713),new clb.Op(43,83.93357),new clb.Op(44,84.927906486),new clb.Op(45,85.925037588),new clb.Op(46,86.920361435),new clb.Op(47,87.91833144),new clb.Op(48,88.913495503),new clb.Op(49,89.911264109),new clb.Op(50,90.906990538),new clb.Op(51,91.907193214),new clb.Op(52,92.906377543),new clb.Op(53,93.907283457),new clb.Op(54,94.906835178),new clb.Op(55,95.908100076),new clb.Op(56,96.908097144),new clb.Op(57,97.91033069),new clb.Op(58,98.911617864),new clb.Op(59,99.914181434),new clb.Op(60,100.915251567),new clb.Op(61,101.918037417),new clb.Op(62,102.919141297),new clb.Op(63,103.922459464),new clb.Op(64,104.923934023),new clb.Op(65,105.92819),new clb.Op(66,106.93031),new clb.Op(67,107.93501),new clb.Op(68,108.93763),new clb.Op(69,109.94268)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(41,82.94874),new clb.Op(42,83.94009),new clb.Op(43,84.93659),new clb.Op(44,85.930695167),new clb.Op(45,86.92732683),new clb.Op(46,87.921952728),new clb.Op(47,88.919480562),new clb.Op(48,89.913936161),new clb.Op(49,90.911750754),new clb.Op(50,91.90681048),new clb.Op(51,92.906812213),new clb.Op(52,93.905087578),new clb.Op(53,94.905841487),new clb.Op(54,95.904678904),new clb.Op(55,96.906021033),new clb.Op(56,97.905407846),new clb.Op(57,98.907711598),new clb.Op(58,99.907477149),new clb.Op(59,100.910346543),new clb.Op(60,101.910297162),new clb.Op(61,102.913204596),new clb.Op(62,103.913758387),new clb.Op(63,104.916972087),new clb.Op(64,105.918134284),new clb.Op(65,106.921694724),new clb.Op(66,107.923973837),new clb.Op(67,108.92781),new clb.Op(68,109.92973),new clb.Op(69,110.93451),new clb.Op(70,111.93684),new clb.Op(71,112.94203)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(42,84.94894),new clb.Op(43,85.94288),new clb.Op(44,86.93653),new clb.Op(45,87.93283),new clb.Op(46,88.92754288),new clb.Op(47,89.92355583),new clb.Op(48,90.9184282),new clb.Op(49,91.915259655),new clb.Op(50,92.910248473),new clb.Op(51,93.909656309),new clb.Op(52,94.907656454),new clb.Op(53,95.907870803),new clb.Op(54,96.906364843),new clb.Op(55,97.907215692),new clb.Op(56,98.906254554),new clb.Op(57,99.907657594),new clb.Op(58,100.90731438),new clb.Op(59,101.909212938),new clb.Op(60,102.909178805),new clb.Op(61,103.911444898),new clb.Op(62,104.911658043),new clb.Op(63,105.914355408),new clb.Op(64,106.915081691),new clb.Op(65,107.918479973),new clb.Op(66,108.919980998),new clb.Op(67,109.92339),new clb.Op(68,110.92505),new clb.Op(69,111.92924),new clb.Op(70,112.93133),new clb.Op(71,113.93588),new clb.Op(72,114.93828)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(43,86.94918),new clb.Op(44,87.94042),new clb.Op(45,88.93611),new clb.Op(46,89.92978),new clb.Op(47,90.926377434),new clb.Op(48,91.92012),new clb.Op(49,92.917051523),new clb.Op(50,93.911359569),new clb.Op(51,94.910412729),new clb.Op(52,95.907597681),new clb.Op(53,96.907554546),new clb.Op(54,97.905287111),new clb.Op(55,98.905939307),new clb.Op(56,99.904219664),new clb.Op(57,100.905582219),new clb.Op(58,101.904349503),new clb.Op(59,102.906323677),new clb.Op(60,103.905430145),new clb.Op(61,104.907750341),new clb.Op(62,105.907326913),new clb.Op(63,106.909907207),new clb.Op(64,107.910192211),new clb.Op(65,108.913201565),new clb.Op(66,109.913966185),new clb.Op(67,110.91756),new clb.Op(68,111.918821673),new clb.Op(69,112.92254),new clb.Op(70,113.923891981),new clb.Op(71,114.92831),new clb.Op(72,115.93016),new clb.Op(73,116.93479),new clb.Op(74,117.93703)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(44,88.94938),new clb.Op(45,89.94287),new clb.Op(46,90.93655),new clb.Op(47,91.93198),new clb.Op(48,92.92574),new clb.Op(49,93.921698),new clb.Op(50,94.915898541),new clb.Op(51,95.914518212),new clb.Op(52,96.911336643),new clb.Op(53,97.910716431),new clb.Op(54,98.908132101),new clb.Op(55,99.90811663),new clb.Op(56,100.906163526),new clb.Op(57,101.906842845),new clb.Op(58,102.905504182),new clb.Op(59,103.906655315),new clb.Op(60,104.905692444),new clb.Op(61,105.907284615),new clb.Op(62,106.90675054),new clb.Op(63,107.908730768),new clb.Op(64,108.908735621),new clb.Op(65,109.910949525),new clb.Op(66,110.91166),new clb.Op(67,111.913969253),new clb.Op(68,112.91542),new clb.Op(69,113.91734336),new clb.Op(70,114.920124676),new clb.Op(71,115.922746643),new clb.Op(72,116.92535),new clb.Op(73,117.92943),new clb.Op(74,118.93136),new clb.Op(75,119.93578),new clb.Op(76,120.93808)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(45,90.94948),new clb.Op(46,91.94042),new clb.Op(47,92.93591),new clb.Op(48,93.92877),new clb.Op(49,94.92469),new clb.Op(50,95.91822194),new clb.Op(51,96.916478921),new clb.Op(52,97.912720751),new clb.Op(53,98.911767757),new clb.Op(54,99.908504596),new clb.Op(55,100.908289144),new clb.Op(56,101.905607716),new clb.Op(57,102.906087204),new clb.Op(58,103.904034912),new clb.Op(59,104.905084046),new clb.Op(60,105.903483087),new clb.Op(61,106.905128453),new clb.Op(62,107.903894451),new clb.Op(63,108.905953535),new clb.Op(64,109.905152385),new clb.Op(65,110.907643952),new clb.Op(66,111.907313277),new clb.Op(67,112.910151346),new clb.Op(68,113.910365322),new clb.Op(69,114.91368341),new clb.Op(70,115.914158288),new clb.Op(71,116.91784),new clb.Op(72,117.918983915),new clb.Op(73,118.92268),new clb.Op(74,119.92403),new clb.Op(75,120.92818),new clb.Op(76,121.9298),new clb.Op(77,122.93426)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(47,93.94278),new clb.Op(48,94.93548),new clb.Op(49,95.93068),new clb.Op(50,96.924),new clb.Op(51,97.921759995),new clb.Op(52,98.917597103),new clb.Op(53,99.916069387),new clb.Op(54,100.912802135),new clb.Op(55,101.911999996),new clb.Op(56,102.908972453),new clb.Op(57,103.908628228),new clb.Op(58,104.906528234),new clb.Op(59,105.906666431),new clb.Op(60,106.90509302),new clb.Op(61,107.905953705),new clb.Op(62,108.904755514),new clb.Op(63,109.90611046),new clb.Op(64,110.905294679),new clb.Op(65,111.907004132),new clb.Op(66,112.906565708),new clb.Op(67,113.908807907),new clb.Op(68,114.908762282),new clb.Op(69,115.911359558),new clb.Op(70,116.911684187),new clb.Op(71,117.914582383),new clb.Op(72,118.915666045),new clb.Op(73,119.918788609),new clb.Op(74,120.919851074),new clb.Op(75,121.92332),new clb.Op(76,122.9249),new clb.Op(77,123.92853),new clb.Op(78,124.93054),new clb.Op(79,125.9345),new clb.Op(80,126.93688)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(48,95.93977),new clb.Op(49,96.93494),new clb.Op(50,97.927579),new clb.Op(51,98.92501),new clb.Op(52,99.920230232),new clb.Op(53,100.918681442),new clb.Op(54,101.914777255),new clb.Op(55,102.913418952),new clb.Op(56,103.909848091),new clb.Op(57,104.909467818),new clb.Op(58,105.906458007),new clb.Op(59,106.906614232),new clb.Op(60,107.904183403),new clb.Op(61,108.904985569),new clb.Op(62,109.903005578),new clb.Op(63,110.904181628),new clb.Op(64,111.902757226),new clb.Op(65,112.904400947),new clb.Op(66,113.903358121),new clb.Op(67,114.905430553),new clb.Op(68,115.904755434),new clb.Op(69,116.907218242),new clb.Op(70,117.906914144),new clb.Op(71,118.909922582),new clb.Op(72,119.909851352),new clb.Op(73,120.91298039),new clb.Op(74,121.9135),new clb.Op(75,122.917003675),new clb.Op(76,123.917648302),new clb.Op(77,124.92124717),new clb.Op(78,125.922353996),new clb.Op(79,126.926434822),new clb.Op(80,127.927760617),new clb.Op(81,128.93226),new clb.Op(82,129.93398)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(49,97.94224),new clb.Op(50,98.93461),new clb.Op(51,99.931149033),new clb.Op(52,100.92656),new clb.Op(53,101.924707541),new clb.Op(54,102.919913896),new clb.Op(55,103.918338416),new clb.Op(56,104.914673434),new clb.Op(57,105.913461134),new clb.Op(58,106.910292195),new clb.Op(59,107.909719683),new clb.Op(60,108.907154078),new clb.Op(61,109.907168783),new clb.Op(62,110.905110677),new clb.Op(63,111.905533338),new clb.Op(64,112.904061223),new clb.Op(65,113.904916758),new clb.Op(66,114.903878328),new clb.Op(67,115.905259995),new clb.Op(68,116.904515731),new clb.Op(69,117.906354623),new clb.Op(70,118.905846334),new clb.Op(71,119.907961505),new clb.Op(72,120.907848847),new clb.Op(73,121.910277103),new clb.Op(74,122.910438951),new clb.Op(75,123.913175916),new clb.Op(76,124.913601387),new clb.Op(77,125.916464532),new clb.Op(78,126.917344048),new clb.Op(79,127.920170658),new clb.Op(80,128.921657958),new clb.Op(81,129.924854941),new clb.Op(82,130.926767408),new clb.Op(83,131.932919005),new clb.Op(84,132.93834),new clb.Op(85,133.94466)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(50,99.938954),new clb.Op(51,100.93606),new clb.Op(52,101.93049),new clb.Op(53,102.92813),new clb.Op(54,103.923185469),new clb.Op(55,104.921390409),new clb.Op(56,105.916880472),new clb.Op(57,106.915666702),new clb.Op(58,107.911965339),new clb.Op(59,108.911286879),new clb.Op(60,109.907852688),new clb.Op(61,110.907735404),new clb.Op(62,111.90482081),new clb.Op(63,112.905173373),new clb.Op(64,113.902781816),new clb.Op(65,114.903345973),new clb.Op(66,115.901744149),new clb.Op(67,116.902953765),new clb.Op(68,117.901606328),new clb.Op(69,118.90330888),new clb.Op(70,119.902196571),new clb.Op(71,120.904236867),new clb.Op(72,121.903440138),new clb.Op(73,122.905721901),new clb.Op(74,123.90527463),new clb.Op(75,124.907784924),new clb.Op(76,125.907653953),new clb.Op(77,126.91035098),new clb.Op(78,127.910534953),new clb.Op(79,128.913439976),new clb.Op(80,129.913852185),new clb.Op(81,130.916919144),new clb.Op(82,131.917744455),new clb.Op(83,132.923814085),new clb.Op(84,133.928463576),new clb.Op(85,134.93473),new clb.Op(86,135.93934),new clb.Op(87,136.94579)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(52,102.94012),new clb.Op(53,103.936287),new clb.Op(54,104.931528593),new clb.Op(55,105.928183134),new clb.Op(56,106.92415),new clb.Op(57,107.92216),new clb.Op(58,108.918136092),new clb.Op(59,109.917533911),new clb.Op(60,110.912534147),new clb.Op(61,111.91239464),new clb.Op(62,112.909377941),new clb.Op(63,113.909095876),new clb.Op(64,114.906598812),new clb.Op(65,115.906797235),new clb.Op(66,116.90483959),new clb.Op(67,117.905531885),new clb.Op(68,118.90394646),new clb.Op(69,119.905074315),new clb.Op(70,120.903818044),new clb.Op(71,121.905175415),new clb.Op(72,122.904215696),new clb.Op(73,123.905937525),new clb.Op(74,124.905247804),new clb.Op(75,125.907248153),new clb.Op(76,126.906914564),new clb.Op(77,127.90916733),new clb.Op(78,128.909150092),new clb.Op(79,129.911546459),new clb.Op(80,130.911946487),new clb.Op(81,131.914413247),new clb.Op(82,132.915236466),new clb.Op(83,133.920551554),new clb.Op(84,134.925167962),new clb.Op(85,135.93066),new clb.Op(86,136.93531),new clb.Op(87,137.94096),new clb.Op(88,138.94571)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(54,105.937702),new clb.Op(55,106.935036),new clb.Op(56,107.929486838),new clb.Op(57,108.927456483),new clb.Op(58,109.922407164),new clb.Op(59,110.921120589),new clb.Op(60,111.917061617),new clb.Op(61,112.915452551),new clb.Op(62,113.912498025),new clb.Op(63,114.911578627),new clb.Op(64,115.908420253),new clb.Op(65,116.90863418),new clb.Op(66,117.905825187),new clb.Op(67,118.90640811),new clb.Op(68,119.904019891),new clb.Op(69,120.904929815),new clb.Op(70,121.903047064),new clb.Op(71,122.904272951),new clb.Op(72,123.902819466),new clb.Op(73,124.904424718),new clb.Op(74,125.903305543),new clb.Op(75,126.90521729),new clb.Op(76,127.904461383),new clb.Op(77,128.906595593),new clb.Op(78,129.906222753),new clb.Op(79,130.90852188),new clb.Op(80,131.908523782),new clb.Op(81,132.910939068),new clb.Op(82,133.911540546),new clb.Op(83,134.916450782),new clb.Op(84,135.920103155),new clb.Op(85,136.925324769),new clb.Op(86,137.92922),new clb.Op(87,138.93473),new clb.Op(88,139.9387),new clb.Op(89,140.94439),new clb.Op(90,141.9485)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(55,107.943291),new clb.Op(56,108.938191658),new clb.Op(57,109.934634181),new clb.Op(58,110.930276),new clb.Op(59,111.92797),new clb.Op(60,112.923644245),new clb.Op(61,113.92185),new clb.Op(62,114.918272),new clb.Op(63,115.916735014),new clb.Op(64,116.913647692),new clb.Op(65,117.91337523),new clb.Op(66,118.910180837),new clb.Op(67,119.910047843),new clb.Op(68,120.907366063),new clb.Op(69,121.907592451),new clb.Op(70,122.905597944),new clb.Op(71,123.906211423),new clb.Op(72,124.90462415),new clb.Op(73,125.905619387),new clb.Op(74,126.90446842),new clb.Op(75,127.905805254),new clb.Op(76,128.904987487),new clb.Op(77,129.906674018),new clb.Op(78,130.906124168),new clb.Op(79,131.907994525),new clb.Op(80,132.907806465),new clb.Op(81,133.909876552),new clb.Op(82,134.91005031),new clb.Op(83,135.914655105),new clb.Op(84,136.917872653),new clb.Op(85,137.922383666),new clb.Op(86,138.926093402),new clb.Op(87,139.93121),new clb.Op(88,140.93483),new clb.Op(89,141.94018),new clb.Op(90,142.94407),new clb.Op(91,143.94961)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(56,109.944476),new clb.Op(57,110.941632),new clb.Op(58,111.93566535),new clb.Op(59,112.933382836),new clb.Op(60,113.928145),new clb.Op(61,114.926979032),new clb.Op(62,115.921394197),new clb.Op(63,116.920564355),new clb.Op(64,117.91657092),new clb.Op(65,118.915554295),new clb.Op(66,119.91215199),new clb.Op(67,120.911386497),new clb.Op(68,121.908548396),new clb.Op(69,122.908470748),new clb.Op(70,123.905895774),new clb.Op(71,124.906398236),new clb.Op(72,125.904268868),new clb.Op(73,126.905179581),new clb.Op(74,127.903530436),new clb.Op(75,128.904779458),new clb.Op(76,129.903507903),new clb.Op(77,130.90508192),new clb.Op(78,131.904154457),new clb.Op(79,132.90590566),new clb.Op(80,133.905394504),new clb.Op(81,134.907207499),new clb.Op(82,135.907219526),new clb.Op(83,136.911562939),new clb.Op(84,137.913988549),new clb.Op(85,138.918786859),new clb.Op(86,139.921635665),new clb.Op(87,140.926646282),new clb.Op(88,141.929702981),new clb.Op(89,142.93489),new clb.Op(90,143.93823),new clb.Op(91,144.94367),new clb.Op(92,145.9473),new clb.Op(93,146.95301)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(57,111.950331),new clb.Op(58,112.944535512),new clb.Op(59,113.940841319),new clb.Op(60,114.935939),new clb.Op(61,115.932914152),new clb.Op(62,116.928639484),new clb.Op(63,117.926554883),new clb.Op(64,118.922370879),new clb.Op(65,119.920678219),new clb.Op(66,120.917183637),new clb.Op(67,121.916121946),new clb.Op(68,122.912990168),new clb.Op(69,123.912245731),new clb.Op(70,124.909724871),new clb.Op(71,125.909447953),new clb.Op(72,126.9074176),new clb.Op(73,127.907747919),new clb.Op(74,128.906063369),new clb.Op(75,129.906706163),new clb.Op(76,130.905460232),new clb.Op(77,131.906429799),new clb.Op(78,132.90544687),new clb.Op(79,133.906713419),new clb.Op(80,134.905971903),new clb.Op(81,135.907305741),new clb.Op(82,136.907083505),new clb.Op(83,137.911010537),new clb.Op(84,138.913357921),new clb.Op(85,139.917277075),new clb.Op(86,140.920043984),new clb.Op(87,141.924292317),new clb.Op(88,142.927330292),new clb.Op(89,143.932027373),new clb.Op(90,144.935388226),new clb.Op(91,145.940162028),new clb.Op(92,146.943864435),new clb.Op(93,147.948899539),new clb.Op(94,148.95272),new clb.Op(95,149.95797),new clb.Op(96,150.962)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(58,113.950941),new clb.Op(59,114.94771),new clb.Op(60,115.94168),new clb.Op(61,116.937700229),new clb.Op(62,117.93344),new clb.Op(63,118.931051927),new clb.Op(64,119.926045941),new clb.Op(65,120.924485908),new clb.Op(66,121.92026),new clb.Op(67,122.91885),new clb.Op(68,123.915088437),new clb.Op(69,124.914620234),new clb.Op(70,125.911244146),new clb.Op(71,126.911121328),new clb.Op(72,127.90830887),new clb.Op(73,128.908673749),new clb.Op(74,129.906310478),new clb.Op(75,130.906930798),new clb.Op(76,131.905056152),new clb.Op(77,132.906002368),new clb.Op(78,133.904503347),new clb.Op(79,134.905682749),new clb.Op(80,135.904570109),new clb.Op(81,136.905821414),new clb.Op(82,137.905241273),new clb.Op(83,138.908835384),new clb.Op(84,139.910599485),new clb.Op(85,140.914406439),new clb.Op(86,141.916448175),new clb.Op(87,142.920617184),new clb.Op(88,143.922940468),new clb.Op(89,144.926923807),new clb.Op(90,145.930106645),new clb.Op(91,146.933992519),new clb.Op(92,147.937682377),new clb.Op(93,148.94246),new clb.Op(94,149.94562),new clb.Op(95,150.9507),new clb.Op(96,151.95416),new clb.Op(97,152.95961)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(60,116.95001),new clb.Op(61,117.94657),new clb.Op(62,118.94099),new clb.Op(63,119.93807),new clb.Op(64,120.93301),new clb.Op(65,121.93071),new clb.Op(66,122.92624),new clb.Op(67,123.92453),new clb.Op(68,124.92067),new clb.Op(69,125.91937),new clb.Op(70,126.91616),new clb.Op(71,127.91544794),new clb.Op(72,128.912667334),new clb.Op(73,129.91232),new clb.Op(74,130.910108489),new clb.Op(75,131.910110399),new clb.Op(76,132.908396372),new clb.Op(77,133.908489607),new clb.Op(78,134.906971003),new clb.Op(79,135.907651181),new clb.Op(80,136.906465656),new clb.Op(81,137.907106826),new clb.Op(82,138.90634816),new clb.Op(83,139.909472552),new clb.Op(84,140.910957016),new clb.Op(85,141.914074489),new clb.Op(86,142.916058646),new clb.Op(87,143.919591666),new clb.Op(88,144.92163837),new clb.Op(89,145.925700146),new clb.Op(90,146.927819639),new clb.Op(91,147.932191197),new clb.Op(92,148.93437),new clb.Op(93,149.93857),new clb.Op(94,150.94156),new clb.Op(95,151.94611),new clb.Op(96,152.94945),new clb.Op(97,153.9544),new clb.Op(98,154.95813)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(61,118.95276),new clb.Op(62,119.94664),new clb.Op(63,120.94367),new clb.Op(64,121.93801),new clb.Op(65,122.93551),new clb.Op(66,123.93052),new clb.Op(67,124.92854),new clb.Op(68,125.9241),new clb.Op(69,126.92275),new clb.Op(70,127.91887),new clb.Op(71,128.918679183),new clb.Op(72,129.914339361),new clb.Op(73,130.914424137),new clb.Op(74,131.91149),new clb.Op(75,132.91155),new clb.Op(76,133.909026379),new clb.Op(77,134.909145555),new clb.Op(78,135.907143574),new clb.Op(79,136.907777634),new clb.Op(80,137.905985574),new clb.Op(81,138.906646605),new clb.Op(82,139.905434035),new clb.Op(83,140.908271103),new clb.Op(84,141.909239733),new clb.Op(85,142.912381158),new clb.Op(86,143.913642686),new clb.Op(87,144.917227871),new clb.Op(88,145.918689722),new clb.Op(89,146.922510962),new clb.Op(90,147.924394738),new clb.Op(91,148.928289207),new clb.Op(92,149.930226399),new clb.Op(93,150.93404),new clb.Op(94,151.93638),new clb.Op(95,152.94058),new clb.Op(96,153.94332),new clb.Op(97,154.94804),new clb.Op(98,155.95126),new clb.Op(99,156.95634)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(62,120.955364),new clb.Op(63,121.95165),new clb.Op(64,122.94596),new clb.Op(65,123.94296),new clb.Op(66,124.93783),new clb.Op(67,125.93531),new clb.Op(68,126.93083),new clb.Op(69,127.9288),new clb.Op(70,128.92486),new clb.Op(71,129.92338),new clb.Op(72,130.920060245),new clb.Op(73,131.91912),new clb.Op(74,132.9162),new clb.Op(75,133.915672),new clb.Op(76,134.91313914),new clb.Op(77,135.912646935),new clb.Op(78,136.910678351),new clb.Op(79,137.910748891),new clb.Op(80,138.908932181),new clb.Op(81,139.909071204),new clb.Op(82,140.907647726),new clb.Op(83,141.910039865),new clb.Op(84,142.910812233),new clb.Op(85,143.913300595),new clb.Op(86,144.914506897),new clb.Op(87,145.917588016),new clb.Op(88,146.918979001),new clb.Op(89,147.922183237),new clb.Op(90,148.923791056),new clb.Op(91,149.926995031),new clb.Op(92,150.928227869),new clb.Op(93,151.9316),new clb.Op(94,152.93365),new clb.Op(95,153.93739),new clb.Op(96,154.93999),new clb.Op(97,155.94412),new clb.Op(98,156.94717),new clb.Op(99,157.95178),new clb.Op(100,158.95523)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(66,125.94307),new clb.Op(67,126.9405),new clb.Op(68,127.93539),new clb.Op(69,128.932385),new clb.Op(70,129.92878),new clb.Op(71,130.927102697),new clb.Op(72,131.92312),new clb.Op(73,132.92221),new clb.Op(74,133.918645),new clb.Op(75,134.91824),new clb.Op(76,135.915020542),new clb.Op(77,136.91463973),new clb.Op(78,137.91291745),new clb.Op(79,138.91192415),new clb.Op(80,139.909309824),new clb.Op(81,140.9096048),new clb.Op(82,141.907718643),new clb.Op(83,142.909809626),new clb.Op(84,143.910082629),new clb.Op(85,144.912568847),new clb.Op(86,145.913112139),new clb.Op(87,146.916095794),new clb.Op(88,147.916888516),new clb.Op(89,148.92014419),new clb.Op(90,149.920886563),new clb.Op(91,150.923824739),new clb.Op(92,151.924682428),new clb.Op(93,152.927694534),new clb.Op(94,153.929483295),new clb.Op(95,154.932629551),new clb.Op(96,155.9352),new clb.Op(97,156.93927),new clb.Op(98,157.94187),new clb.Op(99,158.94639),new clb.Op(100,159.94939),new clb.Op(101,160.95433)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(67,127.94826),new clb.Op(68,128.94316),new clb.Op(69,129.94045),new clb.Op(70,130.9358),new clb.Op(71,131.93375),new clb.Op(72,132.92972),new clb.Op(73,133.92849),new clb.Op(74,134.924617),new clb.Op(75,135.923447865),new clb.Op(76,136.920713),new clb.Op(77,137.920432261),new clb.Op(78,138.916759814),new clb.Op(79,139.915801649),new clb.Op(80,140.913606636),new clb.Op(81,141.912950738),new clb.Op(82,142.910927571),new clb.Op(83,143.912585768),new clb.Op(84,144.912743879),new clb.Op(85,145.914692165),new clb.Op(86,146.915133898),new clb.Op(87,147.917467786),new clb.Op(88,148.918329195),new clb.Op(89,149.920979477),new clb.Op(90,150.921202693),new clb.Op(91,151.923490557),new clb.Op(92,152.924113189),new clb.Op(93,153.926547019),new clb.Op(94,154.928097047),new clb.Op(95,155.931060357),new clb.Op(96,156.9332),new clb.Op(97,157.93669),new clb.Op(98,158.93913),new clb.Op(99,159.94299),new clb.Op(100,160.94586),new clb.Op(101,161.95029),new clb.Op(102,162.95352)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(68,129.94863),new clb.Op(69,130.94589),new clb.Op(70,131.94082),new clb.Op(71,132.93873),new clb.Op(72,133.93402),new clb.Op(73,134.93235),new clb.Op(74,135.9283),new clb.Op(75,136.927046709),new clb.Op(76,137.92354),new clb.Op(77,138.922302),new clb.Op(78,139.918991),new clb.Op(79,140.918468512),new clb.Op(80,141.915193274),new clb.Op(81,142.914623555),new clb.Op(82,143.91199473),new clb.Op(83,144.913405611),new clb.Op(84,145.91303676),new clb.Op(85,146.914893275),new clb.Op(86,147.914817914),new clb.Op(87,148.917179521),new clb.Op(88,149.917271454),new clb.Op(89,150.919928351),new clb.Op(90,151.919728244),new clb.Op(91,152.922093907),new clb.Op(92,153.922205303),new clb.Op(93,154.92463594),new clb.Op(94,155.925526236),new clb.Op(95,156.928354506),new clb.Op(96,157.929987938),new clb.Op(97,158.9332),new clb.Op(98,159.93514),new clb.Op(99,160.93883),new clb.Op(100,161.94122),new clb.Op(101,162.94536),new clb.Op(102,163.94828),new clb.Op(103,164.95298)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(69,131.95416),new clb.Op(70,132.9489),new clb.Op(71,133.94632),new clb.Op(72,134.94172),new clb.Op(73,135.9395),new clb.Op(74,136.93521),new clb.Op(75,137.93345),new clb.Op(76,138.92882915),new clb.Op(77,139.928083921),new clb.Op(78,140.924885867),new clb.Op(79,141.923400033),new clb.Op(80,142.920286634),new clb.Op(81,143.918774116),new clb.Op(82,144.916261285),new clb.Op(83,145.917199714),new clb.Op(84,146.916741206),new clb.Op(85,147.918153775),new clb.Op(86,148.917925922),new clb.Op(87,149.919698294),new clb.Op(88,150.919846022),new clb.Op(89,151.921740399),new clb.Op(90,152.921226219),new clb.Op(91,153.922975386),new clb.Op(92,154.922889429),new clb.Op(93,155.924750855),new clb.Op(94,156.925419435),new clb.Op(95,157.927841923),new clb.Op(96,158.9290845),new clb.Op(97,159.931460406),new clb.Op(98,160.93368),new clb.Op(99,161.93704),new clb.Op(100,162.93921),new clb.Op(101,163.94299),new clb.Op(102,164.94572),new clb.Op(103,165.94997),new clb.Op(104,166.95305)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(72,135.94707),new clb.Op(73,136.94465),new clb.Op(74,137.93997),new clb.Op(75,138.93808),new clb.Op(76,139.933236934),new clb.Op(77,140.93221),new clb.Op(78,141.927908919),new clb.Op(79,142.926738636),new clb.Op(80,143.923390357),new clb.Op(81,144.921687498),new clb.Op(82,145.918305344),new clb.Op(83,146.919089446),new clb.Op(84,147.918109771),new clb.Op(85,148.919336427),new clb.Op(86,149.918655455),new clb.Op(87,150.920344273),new clb.Op(88,151.919787882),new clb.Op(89,152.921746283),new clb.Op(90,153.920862271),new clb.Op(91,154.922618801),new clb.Op(92,155.922119552),new clb.Op(93,156.923956686),new clb.Op(94,157.924100533),new clb.Op(95,158.926385075),new clb.Op(96,159.927050616),new clb.Op(97,160.929665688),new clb.Op(98,161.930981211),new clb.Op(99,162.93399),new clb.Op(100,163.93586),new clb.Op(101,164.93938),new clb.Op(102,165.9416),new clb.Op(103,166.94557),new clb.Op(104,167.94836),new clb.Op(105,168.95287)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(73,137.95287),new clb.Op(74,138.94803),new clb.Op(75,139.945367985),new clb.Op(76,140.94116),new clb.Op(77,141.939073781),new clb.Op(78,142.93475),new clb.Op(79,143.93253),new clb.Op(80,144.92888),new clb.Op(81,145.927180629),new clb.Op(82,146.924037176),new clb.Op(83,147.924298636),new clb.Op(84,148.92324163),new clb.Op(85,149.923654158),new clb.Op(86,150.923098169),new clb.Op(87,151.924071324),new clb.Op(88,152.923430858),new clb.Op(89,153.924686236),new clb.Op(90,154.923500411),new clb.Op(91,155.924743749),new clb.Op(92,156.924021155),new clb.Op(93,157.92541026),new clb.Op(94,158.925343135),new clb.Op(95,159.927164021),new clb.Op(96,160.927566289),new clb.Op(97,161.929484803),new clb.Op(98,162.930643942),new clb.Op(99,163.933347253),new clb.Op(100,164.93488),new clb.Op(101,165.93805),new clb.Op(102,166.94005),new clb.Op(103,167.94364),new clb.Op(104,168.94622),new clb.Op(105,169.95025),new clb.Op(106,170.9533)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(74,139.95379),new clb.Op(75,140.95119),new clb.Op(76,141.946695946),new clb.Op(77,142.94383),new clb.Op(78,143.93907),new clb.Op(79,144.936717),new clb.Op(80,145.932720118),new clb.Op(81,146.930878496),new clb.Op(82,147.927177882),new clb.Op(83,148.927333981),new clb.Op(84,149.925579728),new clb.Op(85,150.92617963),new clb.Op(86,151.924713874),new clb.Op(87,152.925760865),new clb.Op(88,153.924422046),new clb.Op(89,154.92574895),new clb.Op(90,155.924278273),new clb.Op(91,156.925461256),new clb.Op(92,157.924404637),new clb.Op(93,158.92573566),new clb.Op(94,159.925193718),new clb.Op(95,160.926929595),new clb.Op(96,161.926794731),new clb.Op(97,162.928727532),new clb.Op(98,163.929171165),new clb.Op(99,164.931699828),new clb.Op(100,165.932803241),new clb.Op(101,166.935649025),new clb.Op(102,167.93723),new clb.Op(103,168.940303648),new clb.Op(104,169.94267),new clb.Op(105,170.94648),new clb.Op(106,171.94911),new clb.Op(107,172.95344)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(75,141.95986),new clb.Op(76,142.95469),new clb.Op(77,143.95164),new clb.Op(78,144.94688),new clb.Op(79,145.9441),new clb.Op(80,146.93984),new clb.Op(81,147.937269),new clb.Op(82,148.933789944),new clb.Op(83,149.932760914),new clb.Op(84,150.931680791),new clb.Op(85,151.931740598),new clb.Op(86,152.930194506),new clb.Op(87,153.930596268),new clb.Op(88,154.929079084),new clb.Op(89,155.929001869),new clb.Op(90,156.928188059),new clb.Op(91,157.92894573),new clb.Op(92,158.927708537),new clb.Op(93,159.928725679),new clb.Op(94,160.927851662),new clb.Op(95,161.92909242),new clb.Op(96,162.928730286),new clb.Op(97,163.930230577),new clb.Op(98,164.930319169),new clb.Op(99,165.932281267),new clb.Op(100,166.933126195),new clb.Op(101,167.935496424),new clb.Op(102,168.936868306),new clb.Op(103,169.939614951),new clb.Op(104,170.941461227),new clb.Op(105,171.94482),new clb.Op(106,172.94729),new clb.Op(107,173.95115),new clb.Op(108,174.95405)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(76,143.96059),new clb.Op(77,144.95746),new clb.Op(78,145.95212),new clb.Op(79,146.94931),new clb.Op(80,147.94444),new clb.Op(81,148.942780527),new clb.Op(82,149.937171034),new clb.Op(83,150.93746),new clb.Op(84,151.935078452),new clb.Op(85,152.935093125),new clb.Op(86,153.932777294),new clb.Op(87,154.933204273),new clb.Op(88,155.931015001),new clb.Op(89,156.931945517),new clb.Op(90,157.929912),new clb.Op(91,158.930680718),new clb.Op(92,159.929078924),new clb.Op(93,160.930001348),new clb.Op(94,161.928774923),new clb.Op(95,162.930029273),new clb.Op(96,163.929196996),new clb.Op(97,164.9307228),new clb.Op(98,165.93028997),new clb.Op(99,166.932045448),new clb.Op(100,167.932367781),new clb.Op(101,168.934588082),new clb.Op(102,169.935460334),new clb.Op(103,170.938025885),new clb.Op(104,171.939352149),new clb.Op(105,172.9424),new clb.Op(106,173.94434),new clb.Op(107,174.94793),new clb.Op(108,175.95029),new clb.Op(109,176.95437)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(77,145.966495),new clb.Op(78,146.961081),new clb.Op(79,147.95755),new clb.Op(80,148.95265),new clb.Op(81,149.94967),new clb.Op(82,150.944842),new clb.Op(83,151.9443),new clb.Op(84,152.942027631),new clb.Op(85,153.940832325),new clb.Op(86,154.939191562),new clb.Op(87,155.939006895),new clb.Op(88,156.936756069),new clb.Op(89,157.936996),new clb.Op(90,158.934808966),new clb.Op(91,159.935090772),new clb.Op(92,160.933398042),new clb.Op(93,161.933970147),new clb.Op(94,162.932647648),new clb.Op(95,163.933450972),new clb.Op(96,164.932432463),new clb.Op(97,165.933553133),new clb.Op(98,166.932848844),new clb.Op(99,167.934170375),new clb.Op(100,168.934211117),new clb.Op(101,169.935797877),new clb.Op(102,170.936425817),new clb.Op(103,171.938396118),new clb.Op(104,172.939600336),new clb.Op(105,173.942164618),new clb.Op(106,174.943832897),new clb.Op(107,175.946991412),new clb.Op(108,176.94904),new clb.Op(109,177.95264),new clb.Op(110,178.95534)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(78,147.96676),new clb.Op(79,148.96348),new clb.Op(80,149.95799),new clb.Op(81,150.954657965),new clb.Op(82,151.950167),new clb.Op(83,152.94921),new clb.Op(84,153.945651145),new clb.Op(85,154.945792),new clb.Op(86,155.942847109),new clb.Op(87,156.94265865),new clb.Op(88,157.939857897),new clb.Op(89,158.940153735),new clb.Op(90,159.93756),new clb.Op(91,160.937357719),new clb.Op(92,161.93575),new clb.Op(93,162.936265492),new clb.Op(94,163.93452),new clb.Op(95,164.935397592),new clb.Op(96,165.933879623),new clb.Op(97,166.934946862),new clb.Op(98,167.933894465),new clb.Op(99,168.93518712),new clb.Op(100,169.934758652),new clb.Op(101,170.936322297),new clb.Op(102,171.936377696),new clb.Op(103,172.938206756),new clb.Op(104,173.938858101),new clb.Op(105,174.941272494),new clb.Op(106,175.942568409),new clb.Op(107,176.945257126),new clb.Op(108,177.946643396),new clb.Op(109,178.95017),new clb.Op(110,179.95233),new clb.Op(111,180.95615)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(79,149.972668),new clb.Op(80,150.967147),new clb.Op(81,151.96361),new clb.Op(82,152.95869),new clb.Op(83,153.9571),new clb.Op(84,154.953641324),new clb.Op(85,155.952907),new clb.Op(86,156.950101536),new clb.Op(87,157.948577981),new clb.Op(88,158.946615113),new clb.Op(89,159.945383),new clb.Op(90,160.943047504),new clb.Op(91,161.943222),new clb.Op(92,162.941203796),new clb.Op(93,163.941215),new clb.Op(94,164.939605886),new clb.Op(95,165.939762646),new clb.Op(96,166.938307056),new clb.Op(97,167.938698576),new clb.Op(98,168.937648757),new clb.Op(99,169.93847219),new clb.Op(100,170.937909903),new clb.Op(101,171.939082239),new clb.Op(102,172.938926901),new clb.Op(103,173.940333522),new clb.Op(104,174.940767904),new clb.Op(105,175.942682399),new clb.Op(106,176.943754987),new clb.Op(107,177.945951366),new clb.Op(108,178.947324216),new clb.Op(109,179.949879968),new clb.Op(110,180.95197),new clb.Op(111,181.95521),new clb.Op(112,182.95757),new clb.Op(113,183.96117)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(82,153.96425),new clb.Op(83,154.96276),new clb.Op(84,155.959247),new clb.Op(85,156.958127),new clb.Op(86,157.95405528),new clb.Op(87,158.954003),new clb.Op(88,159.950713588),new clb.Op(89,160.950330852),new clb.Op(90,161.947202977),new clb.Op(91,162.947057),new clb.Op(92,163.944422),new clb.Op(93,164.94454),new clb.Op(94,165.94225),new clb.Op(95,166.9426),new clb.Op(96,167.94063),new clb.Op(97,168.941158567),new clb.Op(98,169.93965),new clb.Op(99,170.94049),new clb.Op(100,171.93945798),new clb.Op(101,172.94065),new clb.Op(102,173.940040159),new clb.Op(103,174.941502991),new clb.Op(104,175.941401828),new clb.Op(105,176.943220013),new clb.Op(106,177.943697732),new clb.Op(107,178.945815073),new clb.Op(108,179.94654876),new clb.Op(109,180.949099124),new clb.Op(110,181.950552893),new clb.Op(111,182.953531012),new clb.Op(112,183.95544788),new clb.Op(113,184.95878),new clb.Op(114,185.96092)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(83,155.971689),new clb.Op(84,156.968145),new clb.Op(85,157.966368),new clb.Op(86,158.96232309),new clb.Op(87,159.961358),new clb.Op(88,160.958372992),new clb.Op(89,161.956556553),new clb.Op(90,162.95431665),new clb.Op(91,163.95357),new clb.Op(92,164.950817),new clb.Op(93,165.95047),new clb.Op(94,166.948639),new clb.Op(95,167.947787),new clb.Op(96,168.94592),new clb.Op(97,169.94609),new clb.Op(98,170.94446),new clb.Op(99,171.944739818),new clb.Op(100,172.94459),new clb.Op(101,173.944167937),new clb.Op(102,174.94365),new clb.Op(103,175.944740551),new clb.Op(104,176.944471766),new clb.Op(105,177.945750349),new clb.Op(106,178.945934113),new clb.Op(107,179.947465655),new clb.Op(108,180.947996346),new clb.Op(109,181.950152414),new clb.Op(110,182.951373188),new clb.Op(111,183.954009331),new clb.Op(112,184.955559086),new clb.Op(113,185.9585501),new clb.Op(114,186.96041),new clb.Op(115,187.96371)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(84,157.973939),new clb.Op(85,158.97228),new clb.Op(86,159.968369),new clb.Op(87,160.967089),new clb.Op(88,161.962750303),new clb.Op(89,162.962532),new clb.Op(90,163.95898381),new clb.Op(91,164.958335962),new clb.Op(92,165.955019896),new clb.Op(93,166.954672),new clb.Op(94,167.951863),new clb.Op(95,168.951759),new clb.Op(96,169.948473988),new clb.Op(97,170.94946),new clb.Op(98,171.948228837),new clb.Op(99,172.948884),new clb.Op(100,173.94616),new clb.Op(101,174.94677),new clb.Op(102,175.94559),new clb.Op(103,176.94662),new clb.Op(104,177.945848364),new clb.Op(105,178.947071733),new clb.Op(106,179.946705734),new clb.Op(107,180.948198054),new clb.Op(108,181.948205519),new clb.Op(109,182.950224458),new clb.Op(110,183.950932553),new clb.Op(111,184.953420586),new clb.Op(112,185.954362204),new clb.Op(113,186.957158365),new clb.Op(114,187.958486954),new clb.Op(115,188.96191222),new clb.Op(116,189.963179541)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(85,159.981485),new clb.Op(86,160.977661),new clb.Op(87,161.975707),new clb.Op(88,162.971375872),new clb.Op(89,163.970319),new clb.Op(90,164.967050268),new clb.Op(91,165.965211372),new clb.Op(92,166.962564),new clb.Op(93,167.961609),new clb.Op(94,168.95883),new clb.Op(95,169.958163),new clb.Op(96,170.955547),new clb.Op(97,171.955285),new clb.Op(98,172.953062),new clb.Op(99,173.952114),new clb.Op(100,174.951393),new clb.Op(101,175.95157),new clb.Op(102,176.95027),new clb.Op(103,177.950851081),new clb.Op(104,178.949981038),new clb.Op(105,179.95078768),new clb.Op(106,180.950064596),new clb.Op(107,181.951211444),new clb.Op(108,182.950821349),new clb.Op(109,183.952524289),new clb.Op(110,184.952955747),new clb.Op(111,185.954986529),new clb.Op(112,186.955750787),new clb.Op(113,187.958112287),new clb.Op(114,188.959228359),new clb.Op(115,189.961816139),new clb.Op(116,190.963123592),new clb.Op(117,191.96596)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(86,161.983819),new clb.Op(87,162.982048),new clb.Op(88,163.977927),new clb.Op(89,164.976475),new clb.Op(90,165.971934911),new clb.Op(91,166.971554),new clb.Op(92,167.967832911),new clb.Op(93,168.967076205),new clb.Op(94,169.963569716),new clb.Op(95,170.96304),new clb.Op(96,171.960078),new clb.Op(97,172.959791),new clb.Op(98,173.956307704),new clb.Op(99,174.95708),new clb.Op(100,175.953757941),new clb.Op(101,176.955045),new clb.Op(102,177.953348225),new clb.Op(103,178.953951),new clb.Op(104,179.952308241),new clb.Op(105,180.953274494),new clb.Op(106,181.952186222),new clb.Op(107,182.95311),new clb.Op(108,183.952490808),new clb.Op(109,184.954043023),new clb.Op(110,185.953838355),new clb.Op(111,186.955747928),new clb.Op(112,187.955835993),new clb.Op(113,188.958144866),new clb.Op(114,189.95844521),new clb.Op(115,190.960927951),new clb.Op(116,191.961479047),new clb.Op(117,192.964148083),new clb.Op(118,193.965179314),new clb.Op(119,194.968123889),new clb.Op(120,195.96962255)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(88,164.98758),new clb.Op(89,165.985506),new clb.Op(90,166.980951577),new clb.Op(91,167.979966),new clb.Op(92,168.976390868),new clb.Op(93,169.974441697),new clb.Op(94,170.971779),new clb.Op(95,171.970643),new clb.Op(96,172.967707),new clb.Op(97,173.966804),new clb.Op(98,174.964279),new clb.Op(99,175.963511),new clb.Op(100,176.96117),new clb.Op(101,177.960084944),new clb.Op(102,178.95915),new clb.Op(103,179.958555615),new clb.Op(104,180.957642156),new clb.Op(105,181.958127689),new clb.Op(106,182.956814),new clb.Op(107,183.957388318),new clb.Op(108,184.95659),new clb.Op(109,185.957951104),new clb.Op(110,186.95736083),new clb.Op(111,187.958851962),new clb.Op(112,188.958716473),new clb.Op(113,189.960592299),new clb.Op(114,190.960591191),new clb.Op(115,191.962602198),new clb.Op(116,192.9629237),new clb.Op(117,193.96507561),new clb.Op(118,194.9659768),new clb.Op(119,195.968379906),new clb.Op(120,196.969636496),new clb.Op(121,197.97228),new clb.Op(122,198.973787159)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(90,167.988035),new clb.Op(91,168.986421),new clb.Op(92,169.981734918),new clb.Op(93,170.981251),new clb.Op(94,171.977376138),new clb.Op(95,172.976499642),new clb.Op(96,173.972811276),new clb.Op(97,174.972276),new clb.Op(98,175.969),new clb.Op(99,176.968453),new clb.Op(100,177.964894223),new clb.Op(101,178.965475),new clb.Op(102,179.962023729),new clb.Op(103,180.963177),new clb.Op(104,181.961267637),new clb.Op(105,182.961729),new clb.Op(106,183.959851685),new clb.Op(107,184.960753782),new clb.Op(108,185.959432346),new clb.Op(109,186.960697),new clb.Op(110,187.959395697),new clb.Op(111,188.9608319),new clb.Op(112,189.959930073),new clb.Op(113,190.961684653),new clb.Op(114,191.961035158),new clb.Op(115,192.962984504),new clb.Op(116,193.962663581),new clb.Op(117,194.964774449),new clb.Op(118,195.964934884),new clb.Op(119,196.967323401),new clb.Op(120,197.967876009),new clb.Op(121,198.970576213),new clb.Op(122,199.971423885),new clb.Op(123,200.974496467),new clb.Op(124,201.97574)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(92,170.991183),new clb.Op(93,171.990109),new clb.Op(94,172.986398138),new clb.Op(95,173.984325861),new clb.Op(96,174.981552),new clb.Op(97,175.980269),new clb.Op(98,176.977215),new clb.Op(99,177.975975),new clb.Op(100,178.973412),new clb.Op(101,179.972396),new clb.Op(102,180.969948),new clb.Op(103,181.968621416),new clb.Op(104,182.96762),new clb.Op(105,183.966776046),new clb.Op(106,184.965806956),new clb.Op(107,185.965997671),new clb.Op(108,186.964562),new clb.Op(109,187.965321662),new clb.Op(110,188.9642243),new clb.Op(111,189.964698757),new clb.Op(112,190.963649239),new clb.Op(113,191.964810107),new clb.Op(114,192.964131745),new clb.Op(115,193.96533889),new clb.Op(116,194.965017928),new clb.Op(117,195.966551315),new clb.Op(118,196.966551609),new clb.Op(119,197.968225244),new clb.Op(120,198.968748016),new clb.Op(121,199.970717886),new clb.Op(122,200.971640839),new clb.Op(123,201.973788431),new clb.Op(124,202.975137256),new clb.Op(125,203.977705),new clb.Op(126,204.97961)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(95,174.991411),new clb.Op(96,175.987413248),new clb.Op(97,176.986336874),new clb.Op(98,177.982476325),new clb.Op(99,178.981783),new clb.Op(100,179.978322),new clb.Op(101,180.977806),new clb.Op(102,181.97393546),new clb.Op(103,182.974561),new clb.Op(104,183.970705219),new clb.Op(105,184.971983),new clb.Op(106,185.969460021),new clb.Op(107,186.969785),new clb.Op(108,187.967511693),new clb.Op(109,188.968733187),new clb.Op(110,189.966958568),new clb.Op(111,190.96706311),new clb.Op(112,191.965921572),new clb.Op(113,192.966644169),new clb.Op(114,193.965381832),new clb.Op(115,194.966638981),new clb.Op(116,195.965814846),new clb.Op(117,196.967195333),new clb.Op(118,197.96675183),new clb.Op(119,198.968262489),new clb.Op(120,199.968308726),new clb.Op(121,200.970285275),new clb.Op(122,201.970625604),new clb.Op(123,202.972857096),new clb.Op(124,203.97347564),new clb.Op(125,204.976056104),new clb.Op(126,205.977498672),new clb.Op(127,206.982577025),new clb.Op(128,207.98594)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(96,176.996881),new clb.Op(97,177.994637),new clb.Op(98,178.991466),new clb.Op(99,179.990194),new clb.Op(100,180.986904),new clb.Op(101,181.98561),new clb.Op(102,182.982697),new clb.Op(103,183.98176),new clb.Op(104,184.9791),new clb.Op(105,185.977549881),new clb.Op(106,186.97617),new clb.Op(107,187.97592),new clb.Op(108,188.974290451),new clb.Op(109,189.974473379),new clb.Op(110,190.972261952),new clb.Op(111,191.972770785),new clb.Op(112,192.970548),new clb.Op(113,193.971053),new clb.Op(114,194.96965),new clb.Op(115,195.970515),new clb.Op(116,196.9695362),new clb.Op(117,197.970466294),new clb.Op(118,198.969813837),new clb.Op(119,199.970945394),new clb.Op(120,200.97080377),new clb.Op(121,201.972090569),new clb.Op(122,202.972329088),new clb.Op(123,203.973848646),new clb.Op(124,204.97441227),new clb.Op(125,205.976095321),new clb.Op(126,206.977407908),new clb.Op(127,207.982004653),new clb.Op(128,208.985349125),new clb.Op(129,209.990065574)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(99,180.996714),new clb.Op(100,181.992676101),new clb.Op(101,182.99193),new clb.Op(102,183.988198),new clb.Op(103,184.98758),new clb.Op(104,185.983485388),new clb.Op(105,186.98403),new clb.Op(106,187.979869108),new clb.Op(107,188.98088),new clb.Op(108,189.978180008),new clb.Op(109,190.9782),new clb.Op(110,191.975719811),new clb.Op(111,192.97608),new clb.Op(112,193.974648056),new clb.Op(113,194.975920279),new clb.Op(114,195.97271),new clb.Op(115,196.97338),new clb.Op(116,197.97198),new clb.Op(117,198.972909384),new clb.Op(118,199.97181556),new clb.Op(119,200.972846589),new clb.Op(120,201.972143786),new clb.Op(121,202.973375491),new clb.Op(122,203.973028761),new clb.Op(123,204.974467112),new clb.Op(124,205.974449002),new clb.Op(125,206.975880605),new clb.Op(126,207.97663585),new clb.Op(127,208.981074801),new clb.Op(128,209.984173129),new clb.Op(129,210.988731474),new clb.Op(130,211.991887495),new clb.Op(131,212.9965),new clb.Op(132,213.999798147)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(102,184.997708),new clb.Op(103,185.99648),new clb.Op(104,186.993458),new clb.Op(105,187.992173),new clb.Op(106,188.989505),new clb.Op(107,189.987520007),new clb.Op(108,190.986053),new clb.Op(109,191.985368),new clb.Op(110,192.983662229),new clb.Op(111,193.983430186),new clb.Op(112,194.98112697),new clb.Op(113,195.981236107),new clb.Op(114,196.978934287),new clb.Op(115,197.979024396),new clb.Op(116,198.977576953),new clb.Op(117,199.978141983),new clb.Op(118,200.976970721),new clb.Op(119,201.977674504),new clb.Op(120,202.976868118),new clb.Op(121,203.977805161),new clb.Op(122,204.977374688),new clb.Op(123,205.978482854),new clb.Op(124,206.978455217),new clb.Op(125,207.979726699),new clb.Op(126,208.980383241),new clb.Op(127,209.984104944),new clb.Op(128,210.987258139),new clb.Op(129,211.991271542),new clb.Op(130,212.994374836),new clb.Op(131,213.998698664),new clb.Op(132,215.001832349),new clb.Op(133,216.006199)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(106,189.994293888),new clb.Op(107,190.994653),new clb.Op(108,191.99033039),new clb.Op(109,192.991102),new clb.Op(110,193.988284107),new clb.Op(111,194.988045),new clb.Op(112,195.985469432),new clb.Op(113,196.985567),new clb.Op(114,197.984024384),new clb.Op(115,198.985044507),new clb.Op(116,199.981735),new clb.Op(117,200.982209),new clb.Op(118,201.980704),new clb.Op(119,202.981412863),new clb.Op(120,203.980307113),new clb.Op(121,204.981165396),new clb.Op(122,205.980465241),new clb.Op(123,206.981578228),new clb.Op(124,207.981231059),new clb.Op(125,208.982415788),new clb.Op(126,209.982857396),new clb.Op(127,210.986636869),new clb.Op(128,211.988851755),new clb.Op(129,212.992842522),new clb.Op(130,213.995185949),new clb.Op(131,214.999414609),new clb.Op(132,216.001905198),new clb.Op(133,217.006253),new clb.Op(134,218.008965773)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(108,193.000188),new clb.Op(109,193.997973),new clb.Op(110,194.996554),new clb.Op(111,195.995702),new clb.Op(112,196.993891293),new clb.Op(113,197.99343368),new clb.Op(114,198.991008569),new clb.Op(115,199.990920883),new clb.Op(116,200.988486908),new clb.Op(117,201.988448629),new clb.Op(118,202.986847216),new clb.Op(119,203.987261559),new clb.Op(120,204.986036352),new clb.Op(121,205.986599242),new clb.Op(122,206.985775861),new clb.Op(123,207.986582508),new clb.Op(124,208.986158678),new clb.Op(125,209.987131308),new clb.Op(126,210.987480806),new clb.Op(127,211.990734657),new clb.Op(128,212.99292115),new clb.Op(129,213.996356412),new clb.Op(130,214.998641245),new clb.Op(131,216.002408839),new clb.Op(132,217.004709619),new clb.Op(133,218.008681458),new clb.Op(134,219.011296478),new clb.Op(135,220.015301),new clb.Op(136,221.01814),new clb.Op(137,222.02233),new clb.Op(138,223.02534)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(110,196.001117268),new clb.Op(111,197.001661),new clb.Op(112,197.998779978),new clb.Op(113,198.998309),new clb.Op(114,199.995634148),new clb.Op(115,200.995535),new clb.Op(116,201.993899382),new clb.Op(117,202.994765192),new clb.Op(118,203.991365),new clb.Op(119,204.991668),new clb.Op(120,205.99016),new clb.Op(121,206.990726826),new clb.Op(122,207.989631237),new clb.Op(123,208.990376634),new clb.Op(124,209.989679862),new clb.Op(125,210.99058541),new clb.Op(126,211.990688899),new clb.Op(127,212.993868354),new clb.Op(128,213.995346275),new clb.Op(129,214.998729195),new clb.Op(130,216.000258153),new clb.Op(131,217.003914555),new clb.Op(132,218.005586315),new clb.Op(133,219.009474831),new clb.Op(134,220.011384149),new clb.Op(135,221.015455),new clb.Op(136,222.017570472),new clb.Op(137,223.02179),new clb.Op(138,224.02409),new clb.Op(139,225.02844),new clb.Op(140,226.03089),new clb.Op(141,227.035407),new clb.Op(142,228.038084)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(113,200.006499),new clb.Op(114,201.00458692),new clb.Op(115,202.00396885),new clb.Op(116,203.001423829),new clb.Op(117,204.001221209),new clb.Op(118,204.998663961),new clb.Op(119,205.998486886),new clb.Op(120,206.996859385),new clb.Op(121,207.997133849),new clb.Op(122,208.995915421),new clb.Op(123,209.996398327),new clb.Op(124,210.995529332),new clb.Op(125,211.996194988),new clb.Op(126,212.996174845),new clb.Op(127,213.99895474),new clb.Op(128,215.000326029),new clb.Op(129,216.003187873),new clb.Op(130,217.004616452),new clb.Op(131,218.007563326),new clb.Op(132,219.009240843),new clb.Op(133,220.012312978),new clb.Op(134,221.014245654),new clb.Op(135,222.017543957),new clb.Op(136,223.019730712),new clb.Op(137,224.023235513),new clb.Op(138,225.025606914),new clb.Op(139,226.029343423),new clb.Op(140,227.031833167),new clb.Op(141,228.034776087),new clb.Op(142,229.038426),new clb.Op(143,230.04251),new clb.Op(144,231.045407),new clb.Op(145,232.049654)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(115,203.00921),new clb.Op(116,204.006434513),new clb.Op(117,205.006187),new clb.Op(118,206.004463814),new clb.Op(119,207.005176607),new clb.Op(120,208.001776),new clb.Op(121,209.001944),new clb.Op(122,210.000446),new clb.Op(123,211.000893996),new clb.Op(124,211.999783492),new clb.Op(125,213.000345847),new clb.Op(126,214.000091141),new clb.Op(127,215.002704195),new clb.Op(128,216.003518402),new clb.Op(129,217.00630601),new clb.Op(130,218.007123948),new clb.Op(131,219.010068787),new clb.Op(132,220.011014669),new clb.Op(133,221.013907762),new clb.Op(134,222.01536182),new clb.Op(135,223.01849714),new clb.Op(136,224.020202004),new clb.Op(137,225.023604463),new clb.Op(138,226.025402555),new clb.Op(139,227.029170677),new clb.Op(140,228.031064101),new clb.Op(141,229.034820309),new clb.Op(142,230.037084774),new clb.Op(143,231.04122),new clb.Op(144,232.043693),new clb.Op(145,233.047995),new clb.Op(146,234.050547)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(118,207.012469754),new clb.Op(119,208.012112949),new clb.Op(120,209.009568736),new clb.Op(121,210.009256802),new clb.Op(122,211.007648196),new clb.Op(123,212.007811441),new clb.Op(124,213.006573689),new clb.Op(125,214.006893072),new clb.Op(126,215.006450832),new clb.Op(127,216.008721268),new clb.Op(128,217.009332676),new clb.Op(129,218.011625045),new clb.Op(130,219.012404918),new clb.Op(131,220.014752105),new clb.Op(132,221.015575746),new clb.Op(133,222.017828852),new clb.Op(134,223.01912603),new clb.Op(135,224.021708435),new clb.Op(136,225.023220576),new clb.Op(137,226.026089848),new clb.Op(138,227.027746979),new clb.Op(139,228.031014825),new clb.Op(140,229.032930871),new clb.Op(141,230.036025144),new clb.Op(142,231.038551503),new clb.Op(143,232.042022474),new clb.Op(144,233.04455),new clb.Op(145,234.04842),new clb.Op(146,235.051102),new clb.Op(147,236.055178)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(120,210.015711883),new clb.Op(121,211.016306912),new clb.Op(122,212.012916),new clb.Op(123,213.012962),new clb.Op(124,214.011451),new clb.Op(125,215.011726597),new clb.Op(126,216.011050963),new clb.Op(127,217.013066169),new clb.Op(128,218.013267744),new clb.Op(129,219.015521253),new clb.Op(130,220.015733126),new clb.Op(131,221.018171499),new clb.Op(132,222.018454131),new clb.Op(133,223.020795153),new clb.Op(134,224.02145925),new clb.Op(135,225.023941441),new clb.Op(136,226.024890681),new clb.Op(137,227.027698859),new clb.Op(138,228.028731348),new clb.Op(139,229.03175534),new clb.Op(140,230.033126574),new clb.Op(141,231.03629706),new clb.Op(142,232.03805036),new clb.Op(143,233.041576923),new clb.Op(144,234.043595497),new clb.Op(145,235.04750442),new clb.Op(146,236.04971),new clb.Op(147,237.053894),new clb.Op(148,238.056243)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(122,213.021183209),new clb.Op(123,214.02073923),new clb.Op(124,215.019097612),new clb.Op(125,216.019109649),new clb.Op(126,217.018288571),new clb.Op(127,218.020007906),new clb.Op(128,219.019880348),new clb.Op(129,220.021876493),new clb.Op(130,221.021863742),new clb.Op(131,222.023726),new clb.Op(132,223.023963748),new clb.Op(133,224.025614854),new clb.Op(134,225.026115172),new clb.Op(135,226.02793275),new clb.Op(136,227.028793151),new clb.Op(137,228.031036942),new clb.Op(138,229.032088601),new clb.Op(139,230.034532562),new clb.Op(140,231.035878898),new clb.Op(141,232.03858172),new clb.Op(142,233.040240235),new clb.Op(143,234.043302325),new clb.Op(144,235.045436759),new clb.Op(145,236.048675176),new clb.Op(146,237.05113943),new clb.Op(147,238.054497046),new clb.Op(148,239.05713),new clb.Op(149,240.06098)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(126,218.023487),new clb.Op(127,219.024915423),new clb.Op(128,220.024712),new clb.Op(129,221.026351),new clb.Op(130,222.02607),new clb.Op(131,223.027722956),new clb.Op(132,224.027590139),new clb.Op(133,225.029384369),new clb.Op(134,226.02933975),new clb.Op(135,227.031140069),new clb.Op(136,228.031366357),new clb.Op(137,229.033496137),new clb.Op(138,230.033927392),new clb.Op(139,231.036289158),new clb.Op(140,232.03714628),new clb.Op(141,233.039628196),new clb.Op(142,234.040945606),new clb.Op(143,235.043923062),new clb.Op(144,236.045561897),new clb.Op(145,237.048723955),new clb.Op(146,238.050782583),new clb.Op(147,239.054287777),new clb.Op(148,240.056585734),new clb.Op(149,241.06033),new clb.Op(150,242.062925)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(132,225.033899689),new clb.Op(133,226.035129),new clb.Op(134,227.034958261),new clb.Op(135,228.03618),new clb.Op(136,229.036246866),new clb.Op(137,230.037812591),new clb.Op(138,231.038233161),new clb.Op(139,232.040099),new clb.Op(140,233.04073235),new clb.Op(141,234.042888556),new clb.Op(142,235.044055876),new clb.Op(143,236.046559724),new clb.Op(144,237.048167253),new clb.Op(145,238.050940464),new clb.Op(146,239.052931399),new clb.Op(147,240.056168828),new clb.Op(148,241.058246266),new clb.Op(149,242.061635),new clb.Op(150,243.064273),new clb.Op(151,244.06785)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(134,228.038727686),new clb.Op(135,229.040138934),new clb.Op(136,230.039645603),new clb.Op(137,231.041258),new clb.Op(138,232.041179445),new clb.Op(139,233.04298757),new clb.Op(140,234.043304681),new clb.Op(141,235.0452815),new clb.Op(142,236.046048088),new clb.Op(143,237.048403774),new clb.Op(144,238.0495534),new clb.Op(145,239.052156519),new clb.Op(146,240.05380746),new clb.Op(147,241.056845291),new clb.Op(148,242.058736847),new clb.Op(149,243.061997013),new clb.Op(150,244.06419765),new clb.Op(151,245.067738657),new clb.Op(152,246.070198429),new clb.Op(153,247.07407)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(136,231.04556),new clb.Op(137,232.04659),new clb.Op(138,233.046472),new clb.Op(139,234.047794),new clb.Op(140,235.048029),new clb.Op(141,236.049569),new clb.Op(142,237.049970748),new clb.Op(143,238.051977839),new clb.Op(144,239.053018481),new clb.Op(145,240.055287826),new clb.Op(146,241.056822944),new clb.Op(147,242.059543039),new clb.Op(148,243.061372686),new clb.Op(149,244.064279429),new clb.Op(150,245.066445398),new clb.Op(151,246.069768438),new clb.Op(152,247.072086),new clb.Op(153,248.075745),new clb.Op(154,249.07848)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(137,233.0508),new clb.Op(138,234.05024),new clb.Op(139,235.051591),new clb.Op(140,236.051405),new clb.Op(141,237.052891),new clb.Op(142,238.053016298),new clb.Op(143,239.054951),new clb.Op(144,240.055519046),new clb.Op(145,241.057646736),new clb.Op(146,242.058829326),new clb.Op(147,243.061382249),new clb.Op(148,244.062746349),new clb.Op(149,245.065485586),new clb.Op(150,246.067217551),new clb.Op(151,247.070346811),new clb.Op(152,248.072342247),new clb.Op(153,249.075947062),new clb.Op(154,250.078350687),new clb.Op(155,251.082277873),new clb.Op(156,252.08487)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(138,235.05658),new clb.Op(139,236.05733),new clb.Op(140,237.057127),new clb.Op(141,238.058266),new clb.Op(142,239.058362),new clb.Op(143,240.059749),new clb.Op(144,241.060223),new clb.Op(145,242.06205),new clb.Op(146,243.06300157),new clb.Op(147,244.065167882),new clb.Op(148,245.066355386),new clb.Op(149,246.068666836),new clb.Op(150,247.070298533),new clb.Op(151,248.07308),new clb.Op(152,249.074979937),new clb.Op(153,250.078310529),new clb.Op(154,251.08075344),new clb.Op(155,252.084303),new clb.Op(156,253.08688),new clb.Op(157,254.0906)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(139,237.06207),new clb.Op(140,238.06141),new clb.Op(141,239.062579),new clb.Op(142,240.062295),new clb.Op(143,241.063716),new clb.Op(144,242.063688713),new clb.Op(145,243.065421),new clb.Op(146,244.06599039),new clb.Op(147,245.068039),new clb.Op(148,246.068798807),new clb.Op(149,247.070992043),new clb.Op(150,248.07217808),new clb.Op(151,249.074846818),new clb.Op(152,250.076399951),new clb.Op(153,251.079580056),new clb.Op(154,252.081619582),new clb.Op(155,253.085126791),new clb.Op(156,254.087316198),new clb.Op(157,255.091039),new clb.Op(158,256.09344)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(141,240.06892),new clb.Op(142,241.068662),new clb.Op(143,242.069699),new clb.Op(144,243.069631),new clb.Op(145,244.070969),new clb.Op(146,245.071317),new clb.Op(147,246.072965),new clb.Op(148,247.07365),new clb.Op(149,248.075458),new clb.Op(150,249.076405),new clb.Op(151,250.078654),new clb.Op(152,251.079983592),new clb.Op(153,252.082972247),new clb.Op(154,253.084817974),new clb.Op(155,254.088016026),new clb.Op(156,255.090266386),new clb.Op(157,256.093592),new clb.Op(158,257.095979)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(142,242.07343),new clb.Op(143,243.07451),new clb.Op(144,244.074077),new clb.Op(145,245.075375),new clb.Op(146,246.075281634),new clb.Op(147,247.076819),new clb.Op(148,248.077184411),new clb.Op(149,249.079024),new clb.Op(150,250.079514759),new clb.Op(151,251.081566467),new clb.Op(152,252.082460071),new clb.Op(153,253.085176259),new clb.Op(154,254.086847795),new clb.Op(155,255.089955466),new clb.Op(156,256.091766522),new clb.Op(157,257.095098635),new clb.Op(158,258.097069),new clb.Op(159,259.100588)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(144,245.081017),new clb.Op(145,246.081933),new clb.Op(146,247.081804),new clb.Op(147,248.082909),new clb.Op(148,249.083002),new clb.Op(149,250.084488),new clb.Op(150,251.084919),new clb.Op(151,252.08663),new clb.Op(152,253.08728),new clb.Op(153,254.089725),new clb.Op(154,255.091075196),new clb.Op(155,256.094052757),new clb.Op(156,257.095534643),new clb.Op(157,258.098425321),new clb.Op(158,259.100503),new clb.Op(159,260.103645)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(147,249.087823),new clb.Op(148,250.087493),new clb.Op(149,251.08896),new clb.Op(150,252.088965909),new clb.Op(151,253.090649),new clb.Op(152,254.090948746),new clb.Op(153,255.093232449),new clb.Op(154,256.094275879),new clb.Op(155,257.096852778),new clb.Op(156,258.0982),new clb.Op(157,259.101024),new clb.Op(158,260.102636),new clb.Op(159,261.105743),new clb.Op(160,262.10752)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(148,251.09436),new clb.Op(149,252.09533),new clb.Op(150,253.095258),new clb.Op(151,254.096587),new clb.Op(152,255.096769),new clb.Op(153,256.098763),new clb.Op(154,257.099606),new clb.Op(155,258.101883),new clb.Op(156,259.10299),new clb.Op(157,260.105572),new clb.Op(158,261.106941),new clb.Op(159,262.109692),new clb.Op(160,263.111394)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(149,253.100679),new clb.Op(150,254.100166),new clb.Op(151,255.101492),new clb.Op(152,256.101179573),new clb.Op(153,257.103072),new clb.Op(154,258.103568),new clb.Op(155,259.105628),new clb.Op(156,260.106434),new clb.Op(157,261.108752),new clb.Op(158,262.109918),new clb.Op(159,263.11254),new clb.Op(160,264.113978)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(150,255.107398),new clb.Op(151,256.10811),new clb.Op(152,257.107858),new clb.Op(153,258.109438),new clb.Op(154,259.109721),new clb.Op(155,260.111427),new clb.Op(156,261.112106),new clb.Op(157,262.114153),new clb.Op(158,263.115078),new clb.Op(159,264.117473),new clb.Op(160,265.118659)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(152,258.113151),new clb.Op(153,259.114652),new clb.Op(154,260.114435447),new clb.Op(155,261.116199),new clb.Op(156,262.116477),new clb.Op(157,263.118313),new clb.Op(158,264.118924),new clb.Op(159,265.121066),new clb.Op(160,266.121928)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(153,260.121803),new clb.Op(154,261.1218),new clb.Op(155,262.123009),new clb.Op(156,263.123146),new clb.Op(157,264.12473),new clb.Op(158,265.125198),new clb.Op(159,266.127009),new clb.Op(160,267.12774)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(155,263.12871),new clb.Op(156,264.128408258),new clb.Op(157,265.130001),new clb.Op(158,266.130042),new clb.Op(159,267.131774),new clb.Op(160,268.132156),new clb.Op(161,269.134114)]),oW(aW(Ykb.aY,1),hob,3,0,[new clb.Op(156,265.136567),new clb.Op(157,266.13794),new clb.Op(158,267.137526),new clb.Op(159,268.138816),new clb.Op(160,269.139106),new clb.Op(161,270.140723),new clb.Op(162,271.141229)])]);};clb.Rp=function Rp(a,b){clb.Qp();var c,d;d=b-a;for(c=0;c<clb.Pp[a].length;c++)if(clb.Pp[a][c].b==d)return clb.Pp[a][c].a;return NaN;};clb.Sp=function Sp(a,b){var c;if(a.b.length!=b.b.length)return a.b.length<b.b.length?-1:1;for(c=0;c<a.b.length;c++)if(a.b[c]!=b.b[c])return a.b[c]<b.b[c]?-1:1;return 0;};clb.Tp=function Tp(a){var b,c,d,e,f,g;c=0;for(e=a.a,f=0,g=e.length;f<g;++f){d=e[f];d&&++c;}a.b=gW(Ykb.AX,gmb,6,c,15,1);c=0;for(b=0;b<a.a.length;b++)a.a[b]&&(a.b[c++]=b);};clb.Up=function Up(a,b){var c;clb.Tp(a);for(c=0;c<a.b.length;c++)if(b[a.b[c]])return true;return false;};clb.Vp=function Vp(a){this.a=gW(Ykb.Z0,Amb,6,a,16,1);};U1(186,1,{186:1,27:1},clb.Vp);_.qb=function Wp(a){return clb.Sp(this,a);};Ykb.bY=w3(186);clb.$p=function $p(){clb.$p=W1;clb.Zp=oW(aW(Ykb.yX,1),emb,6,15,[0,1.00794,4.0026,6.941,9.0122,10.811,12.011,14.007,15.999,18.998,20.18,22.99,24.305,26.982,28.086,30.974,32.066,35.453,39.948,39.098,40.078,44.956,47.867,50.942,51.996,54.938,55.845,58.933,58.693,63.546,65.39,69.723,72.61,74.922,78.96,79.904,83.8,85.468,87.62,88.906,91.224,92.906,95.94,98.906,101.07,102.91,106.42,107.87,112.41,114.82,118.71,121.76,127.6,126.9,131.29,132.91,137.33,138.91,140.12,140.91,144.24,146.92,150.36,151.96,157.25,158.93,162.5,164.93,167.26,168.93,173.04,174.97,178.49,180.95,183.84,186.21,190.23,192.22,195.08,196.97,200.59,204.38,207.2,208.98,209.98,209.99,222.02,223.02,226.03,227.03,232.04,231.04,238.03,237.05,239.05,241.06,244.06,249.08,252.08,252.08,257.1,258.1,259.1,262.11,267.12,268.13,271.13,270.13,277.15,276.15,iob,iob,283.17,285.18,job,job,293.2,kob,kob,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2.0141,3.016,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,71.0787,156.18828,114.10364,115.0877,103.1447,128.13052,129.11458,57.05182,137.14158,113.15934,113.15934,128.17428,131.19846,147.17646,97.11658,87.0777,101.10458,186.2134,163.17546,99.13246]);clb.Xp=oW(aW(Ykb.yX,1),emb,6,15,[0,1.007825,4.0026,7.016003,9.012182,11.009305,12,14.003074,15.994915,18.998403,19.992435,22.989767,23.985042,26.98153,27.976927,30.973762,31.97207,34.968852,39.962384,38.963707,39.962591,44.95591,47.947947,50.943962,51.940509,54.938047,55.934939,58.933198,57.935346,62.939598,63.929145,68.92558,73.921177,74.921594,79.91652,78.918336,83.911507,84.911794,87.905619,88.905849,89.904703,92.906377,97.905406,89.92381,101.904348,102.9055,105.903478,106.905092,113.903357,114.90388,119.9022,120.903821,129.906229,126.904473,131.904144,132.905429,137.905232,138.906346,139.905433,140.907647,141.907719,135.92398,151.919729,152.921225,157.924099,158.925342,163.929171,164.930319,165.93029,168.934212,173.938859,174.94077,179.946545,180.947992,183.950928,186.955744,191.961467,192.962917,194.964766,196.966543,201.970617,204.974401,207.976627,208.980374,193.98818,195.99573,199.9957,201.00411,206.0038,210.00923,232.038054,216.01896,238.050784,229.03623,232.041169,237.05005,238.05302,242.06194,240.06228,243.06947,243.07446,248.08275,251.08887,253.09515,257.10295,257.10777,271.13,270.13,277.15,276.15,iob,iob,283.17,285.18,job,job,291.2,kob,kob,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2.014,3.01605,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0]);clb.Yp=oW(aW(Ykb.AX,1),gmb,6,15,[6,1,7,8]);};clb._p=function _p(a){var b,c;c=a.a;for(b=0;b<a.b.length;b++)c+=a.b[b]*clb.Xp[a.c[b]];return c;};clb.aq=function aq(a){var b,c;b=new Zkb.z5();for(c=0;c<a.b.length;c++){Zkb.y5(b,(clb.wj(),clb.qj)[a.c[c]]);a.b[c]>1&&Zkb.x5(b,a.b[c]);}return b.a;};clb.bq=function bq(a){var b,c;c=a.d;for(b=0;b<a.b.length;b++)c+=a.b[b]*clb.Zp[a.c[b]];return c;};clb.cq=function cq(a){var b,c,d,e,f,g,h,i,j,k,l;clb.Gt(a,1);e=gW(Ykb.AX,gmb,6,191,15,1);for(c=0;c<a.q;c++){switch(a.C[c]){case 171:e[1]+=5;e[6]+=3;e[7]+=1;e[8]+=1;break;case 172:e[1]+=12;e[6]+=6;e[7]+=4;e[8]+=1;break;case 173:e[1]+=6;e[6]+=4;e[7]+=2;e[8]+=2;break;case 174:e[1]+=5;e[6]+=4;e[7]+=1;e[8]+=3;break;case 175:e[1]+=5;e[6]+=3;e[7]+=1;e[8]+=1;e[16]+=1;break;case 176:e[1]+=8;e[6]+=5;e[7]+=2;e[8]+=2;break;case 177:e[1]+=7;e[6]+=5;e[7]+=1;e[8]+=3;break;case 178:e[1]+=3;e[6]+=2;e[7]+=1;e[8]+=1;break;case 179:e[1]+=7;e[6]+=6;e[7]+=3;e[8]+=1;break;case 181:case 180:e[1]+=11;e[6]+=6;e[7]+=1;e[8]+=1;break;case 182:e[1]+=12;e[6]+=6;e[7]+=2;e[8]+=1;break;case 183:e[1]+=9;e[6]+=5;e[7]+=1;e[8]+=1;e[16]+=1;break;case 184:e[1]+=9;e[6]+=9;e[7]+=1;e[8]+=1;break;case 185:e[1]+=7;e[6]+=5;e[7]+=1;e[8]+=1;break;case 186:e[1]+=5;e[6]+=3;e[7]+=1;e[8]+=2;break;case 187:e[1]+=7;e[6]+=4;e[7]+=1;e[8]+=2;break;case 188:e[1]+=10;e[6]+=11;e[7]+=2;e[8]+=1;break;case 189:e[1]+=9;e[6]+=9;e[7]+=1;e[8]+=2;break;case 190:e[1]+=9;e[6]+=5;e[7]+=1;e[8]+=1;break;case 1:switch(a.A[c]){case 0:case 1:++e[1];break;case 2:++e[151];break;case 3:++e[152];}break;default:++e[a.C[c]];}}for(d=0;d<a.q;d++)a.C[d]>=171&&a.C[d]<=190?e[1]+=2-clb.Pn(a,d):e[1]+=clb.Kn(a,d);h=0;for(j=1;j<=190;j++)e[j]!=0&&++h;this.b=gW(Ykb.AX,gmb,6,h,15,1);this.c=gW(Ykb.AX,gmb,6,h,15,1);h=0;for(i=0;i<clb.Yp.length;i++){if(e[clb.Yp[i]]!=0){this.b[h]=e[clb.Yp[i]];this.c[h]=clb.Yp[i];++h;e[clb.Yp[i]]=0;}}while(true){l='zzz';k=-1;for(g=1;g<=190;g++)if(e[g]>0&&Zkb.Z4(l,(clb.wj(),clb.qj)[g])>0){l=(clb.wj(),clb.qj)[g];k=g;}if(k==-1)break;this.b[h]=e[k];this.c[h]=k;++h;e[k]=0;}this.a=0;this.d=0;for(b=0;b<a.f;b++){if(a.C[b]!=1&&a.A[b]!=0){g=a.C[b];f=a.A[b];this.a+=clb.Rp(g,f)-clb.Xp[g];this.d+=clb.Rp(g,f)-clb.Zp[g];}}};U1(119,1,{119:1});_.ib=function dq(a){var b;if(a===this)return true;if(!mX(a,119))return false;for(b=0;b<this.b.length;b++)if(this.b[b]!=a.b[b])return false;return true;};_.a=0;_.d=0;Ykb.cY=w3(119);clb.eq=function eq(a){switch(a){case 6:return 1;case 53:return 2;case 33:return 3;case 34:return 4;case 35:return 5;case 15:return 6;case 16:return 7;case 17:return 8;case 7:return 9;case 8:return 10;case 9:return 11;}return 0;};clb.fq=function fq(a){var b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C;clb.Gt(a,7);B=0;n=gW(Ykb.Z0,Amb,6,a.f,16,1);C=gW(Ykb.AX,gmb,6,a.f,15,1);for(f=0;f<a.g;f++){c=a.D[0][f];d=a.D[1][f];g=a.s[c];h=a.s[d];if(g!=0&&h!=0&&g<0^h<0){n[c]=true;n[d]=true;}C[c]+=clb.Hk(a,f);C[d]+=clb.Hk(a,f);}for(i=0;i<a.f;i++){B+=a.s[i];if(a.s[i]==1){if(a.C[i]==7){if(!n[i]){if(C[i]<=3){B-=1;a.s[i]=0;a.T=0;if(a.j[i]!=a.e[i]){clb.Uj(a,clb.vn(a,i,a.e[i]-1));clb.Gt(a,7);}}else if(i<a.f&&clb.rr(a.p,i)){r=gW(Ykb.Z0,Amb,6,a.f,16,1);s=gW(Ykb.Z0,Amb,6,a.g,16,1);clb.dn(a,i,true,r,s);for(k=0;k<a.f;k++){if(r[k]&&a.C[k]==7&&a.s[k]==0&&C[k]==2){if(clb.iq(a,s,i,k)){B-=1;break;}}}}}}}else if(a.s[i]<0){if(a.C[i]==6||a.C[i]==7||a.C[i]==8||a.C[i]==16){if(n[i]){v=gW(Ykb.AX,gmb,6,16,15,1);v[0]=i;A=1;w=0;while(w<A){for(e=0;e<a.r;e++){b=-1;a.D[0][e]==v[w]?b=a.D[1][e]:a.D[1][e]==v[w]&&(b=a.D[0][e]);if(b==-1)continue;if(a.s[b]!=0){l=false;for(p=0;p<A;p++){if(b==v[p]){l=true;break;}}if(!l){if(A==v.length){j=gW(Ykb.AX,gmb,6,2*v.length,15,1);Zkb.P5(v,0,j,0,v.length);v=j;}v[A++]=b;}}}++w;}m=0;for(q=0;q<A;q++){m+=clb.dk(a,v[q]);}if(m<0){t=-1;u=99;for(o=0;o<A;o++){if(clb.dk(a,v[o])<0){if(u>clb.eq(clb.uk(a,v[o]))){u=clb.eq(clb.uk(a,v[o]));t=v[o];}}}if(t!=-1){B-=a.s[t];a.s[t]=0;a.T=0;}}}else {B-=a.s[i];a.s[i]=0;a.T=0;}}}}B>0&&(B=clb.gq(a,B));return B;};clb.gq=function gq(a,b){var c,d,e,f;b>0&&(b=clb.jq(a,b,9));b>0&&(b=clb.jq(a,b,17));b>0&&(b=clb.jq(a,b,35));b>0&&(b=clb.jq(a,b,53));if(b>0){for(c=0;c<a.f;c++){if(a.s[c]>0){e=false;for(f=0;f<a.j[c];f++){d=a.i[c][f];if(a.s[d]==0&&clb.gl(a,d)&&clb.Kn(a,d)>0){a.s[d]=-1;a.T=0;--b;if(b==0)return 0;e=true;break;}}if(e)continue;}}}b>0&&(b=clb.hq(a,b,8,16));b>0&&(b=clb.hq(a,b,8,15));b>0&&(b=clb.hq(a,b,8,6));b>0&&(b=clb.hq(a,b,7,16));return b;};clb.hq=function hq(a,b,c,d){var e,f,g,h,i,j,k,l;for(e=0;e<a.f;e++){if(a.C[e]==c&&a.s[e]==0&&clb.Kn(a,e)>0){h=false;for(j=0;j<a.j[e];j++){if(a.n[e][j]==1){f=a.i[e][j];if(a.C[f]==d){l=false;i=false;for(k=0;k<a.j[f];k++){g=a.i[f][k];if(a.s[g]<0){i=true;break;}g!=e&&a.C[g]==8&&a.n[f][k]==2&&(l=true);}if(!i&&l){a.s[e]=-1;a.T=0;--b;if(b==0)return 0;h=true;}}}if(h)break;}}}return b;};clb.iq=function iq(a,b,c,d){var e,f,g,h,i,j,k,l;l=gW(Ykb.AX,gmb,6,a.g,15,1);i=gW(Ykb.Z0,Amb,6,a.g,16,1);for(g=0;g<a.g;g++){l[g]=a.H[g];if(b[g]){i[g]=true;a.H[g]=1;a.T=0;}}for(e=0;e<a.f;e++){if(e!=d&&a.o[e]==0&&i[a.k[d][0]]){for(k=0;k<a.j[e];k++){h=a.k[e][k];a.H[h]=1;a.T=0;i[h]=false;}}}for(j=0;j<a.j[c];j++){h=a.k[c][j];a.H[h]=1;a.T=0;i[h]=false;}if(clb.ce(new clb.me(a),i,false)){a.s[c]=0;a.T=0;a.j[d]!=a.e[d]&&clb.Uj(a,clb.vn(a,d,a.e[d]-1));clb.Gt(a,7);return true;}for(f=0;f<a.g;f++){clb.jm(a,f,l[f]);}return false;};clb.jq=function jq(a,b,c){var d;for(d=0;d<a.f;d++){if(a.C[d]==c&&a.s[d]==0&&a.j[d]==0){a.s[d]=-1;a.T=0;--b;if(b==0)return 0;}}return b;};clb.kq=function kq(a,b){var c,d;d=Dlb.o8(a.b,b);for(c=alb.Pgb(d).length;c<10;c++)Zkb.C5(a.a,32);Zkb.G5(a.a,d);};clb.lq=function lq(a,b){var c,d,e;if(b<0||b>999){Zkb.G5(a.a,'  ?');return;}c=false;for(d=0;d<3;d++){e=b/100|0;if(e==0){d==2||c?Zkb.C5(a.a,48):Zkb.C5(a.a,32);}else {Zkb.C5(a.a,48+e&Zlb);c=true;}b=10*(b%100);}};clb.mq=function mq(a,b){Alb.v2(b,a.a.a);};clb.nq=function nq(a){clb.oq.call(this,a);};clb.oq=function oq(a){clb.qq.call(this,a,new Zkb.K5());};clb.pq=function pq(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z;this.b=new Dlb.r8((N=lob,N));clb.Gt(a,15);L=true;for(e=0;e<a.f;e++){if((a.u[e]&3)!=0&&(a.u[e]&3)!=3&&(a.u[e]&rnb)>>18!=1){L=false;break;}}O=-1;if(L){F=gW(Ykb.AX,gmb,6,32,15,1);P=0;for(f=0;f<a.f;f++){if((a.u[f]&3)!=0&&(a.u[f]&3)!=3&&(a.u[f]&rnb)>>18==1){H=(a.u[f]&rnb)>>18!=1&&(a.u[f]&rnb)>>18!=2?-1:(a.u[f]&Snb)>>20;++F[H];if(P<F[H]){P=F[H];O=H;}break;}}}this.a=!c?new Zkb.J5():c;R=a.P!=null?a.P:'';Zkb.G5(this.a,R+Klb);Zkb.G5(this.a,'Actelion Java MolfileCreator 1.0\n\n');clb.lq(this,a.q);clb.lq(this,a.r);Zkb.G5(this.a,'  0  0');clb.lq(this,L?0:1);Zkb.G5(this.a,'  0  0  0  0  0999 V2000\n');I=a.q==1;for(i=1;i<a.q;i++){if(a.J[i].a!=a.J[0].a||a.J[i].b!=a.J[0].b||a.J[i].c!=a.J[0].c){I=true;break;}}G=1;if(I){if(b!=0){G=b;}else {s=clb.wk(a,a.q,a.r,(clb.wj(),clb.vj));if(s!=0){(s<1||s>3)&&(G=1.5/s);}else {Q=Unb;for(f=1;f<a.q;f++){for(h=0;h<f;h++){B=a.J[h].a-a.J[f].a;C=a.J[h].b-a.J[f].b;D=a.J[h].c-a.J[f].c;A=B*B+C*C+D*D;Q>A&&(Q=A);}}G=3/Q;}}}for(j=0;j<a.q;j++){if(I){clb.kq(this,G*a.J[j].a);clb.kq(this,G*-a.J[j].b);clb.kq(this,G*-a.J[j].c);}else {Zkb.G5(this.a,'    0.0000    0.0000    0.0000');}if((a.v==null?null:a.v[j])!=null)Zkb.G5(this.a,' L  ');else if(z1(e1(a.B[j],1),0))Zkb.G5(this.a,' A  ');else if(a.C[j]>=129&&a.C[j]<=144||a.C[j]==154)Zkb.G5(this.a,' R# ');else {p=(clb.wj(),clb.qj)[a.C[j]];Zkb.G5(this.a,' '+p);alb.Pgb(p).length==1?Zkb.G5(this.a,'  '):alb.Pgb(p).length==2&&Zkb.G5(this.a,' ');}Zkb.G5(this.a,' 0  0  0');J=e1(Mmb,a.B[j]);j1(J,0)==0?Zkb.G5(this.a,'  0'):j1(J,384)==0?Zkb.G5(this.a,'  3'):j1(J,128)==0?Zkb.G5(this.a,'  2'):j1(J,1792)==0?Zkb.G5(this.a,'  1'):j1(J,1664)==0&&Zkb.G5(this.a,'  2');Zkb.G5(this.a,z1(e1(a.B[j],knb),0)?'  1':'  0');Z=((a.u[j]&Rnb)>>>27)-1;Z==-1?Zkb.G5(this.a,'  0'):Z==0?Zkb.G5(this.a,' 15'):clb.lq(this,Z);Zkb.G5(this.a,'  0  0  0');clb.lq(this,$wnd.Math.abs(a.w[j]));Zkb.G5(this.a,'  0  0\n');}for(t=0;t<a.r;t++){switch(a.H[t]){case 1:T=1;W=0;break;case 2:T=2;W=0;break;case 4:T=3;W=0;break;case 129:T=1;W=6;break;case 257:T=1;W=1;break;case 386:T=2;W=3;break;case 64:T=4;W=0;break;case 32:T=8;W=0;break;default:T=1;W=0;}if(L&&(W==1||W==6)){f=a.D[0][t];(a.u[f]&rnb)>>18==2?W=0:(a.u[f]&rnb)>>18==1&&((a.u[f]&rnb)>>18!=1&&(a.u[f]&rnb)>>18!=2?-1:(a.u[f]&Snb)>>20)!=O&&(W=4);}u=a.G[t]&31;u!=0&&(u==8?T=4:u==3?T=5:u==9?T=6:u==10?T=7:T=8);V=a.G[t]&384;Y=V==0?0:V==256?1:2;clb.lq(this,1+a.D[0][t]);clb.lq(this,1+a.D[1][t]);clb.lq(this,T);clb.lq(this,W);Zkb.G5(this.a,'  0');clb.lq(this,Y);Zkb.G5(this.a,'  0\n');}S=0;for(k=0;k<a.q;k++)a.s[k]!=0&&++S;if(S!=0){w=0;for(f=0;f<a.q;f++){if(a.s[f]!=0){if(w==0){Zkb.G5(this.a,'M  CHG');clb.lq(this,$wnd.Math.min(8,S));}Zkb.G5(this.a,' ');clb.lq(this,f+1);v=a.s[f];if(v<0){Zkb.G5(this.a,'  -');v=-v;}else Zkb.G5(this.a,'   ');Zkb.C5(this.a,48+v&Zlb);--S;if(++w==8||S==0){w=0;Zkb.G5(this.a,Klb);}}}}S=0;for(l=0;l<a.q;l++)a.A[l]==0||++S;if(S!=0){w=0;for(f=0;f<a.q;f++){if(a.A[f]!=0){if(w==0){Zkb.G5(this.a,'M  ISO');clb.lq(this,$wnd.Math.min(8,S));}Zkb.G5(this.a,' ');clb.lq(this,f+1);Zkb.G5(this.a,' ');clb.lq(this,a.A[f]);--S;if(++w==8||S==0){w=0;Zkb.G5(this.a,Klb);}}}}S=0;for(m=0;m<a.q;m++)(a.u[m]&48)!=0&&++S;if(S!=0){w=0;for(f=0;f<a.q;f++){if((a.u[f]&48)!=0){if(w==0){Zkb.G5(this.a,'M  RAD');clb.lq(this,$wnd.Math.min(8,S));}Zkb.G5(this.a,' ');clb.lq(this,f+1);switch(a.u[f]&48){case 16:Zkb.G5(this.a,'   1');break;case 32:Zkb.G5(this.a,'   2');break;case 48:Zkb.G5(this.a,'   3');}--S;if(++w==8||S==0){w=0;Zkb.G5(this.a,Klb);}}}}S=0;for(n=0;n<a.q;n++)(a.C[n]>=129&&a.C[n]<=144||a.C[n]==154)&&++S;if(S!=0){w=0;for(d=0;d<a.q;d++){r=a.C[d];if(r>=129&&r<=144||r==154){if(w==0){Zkb.G5(this.a,'M  RGP');clb.lq(this,$wnd.Math.min(8,S));}Zkb.G5(this.a,' ');clb.lq(this,d+1);Zkb.G5(this.a,' ');clb.lq(this,r==154?0:r>=142?r-141:r-125);--S;if(++w==8||S==0){w=0;Zkb.G5(this.a,Klb);}}}}if(a.K){S=0;for(f=0;f<a.q;f++)z1(e1(a.B[f],120),0)&&++S;if(S!=0){w=0;for(h=0;h<a.q;h++){U=e1(a.B[h],120);if(j1(U,0)!=0){if(w==0){Zkb.G5(this.a,'M  RBC');clb.lq(this,$wnd.Math.min(8,S));}Zkb.G5(this.a,' ');clb.lq(this,h+1);j1(U,112)==0?Zkb.G5(this.a,'  -1'):j1(U,8)==0?Zkb.G5(this.a,'   1'):j1(U,104)==0?Zkb.G5(this.a,'   2'):j1(U,88)==0?Zkb.G5(this.a,'   3'):j1(U,56)==0&&Zkb.G5(this.a,'   4');--S;if(++w==8||S==0){w=0;Zkb.G5(this.a,Klb);}}}}for(o=0;o<a.q;o++){q=a.v==null?null:a.v[o];if(q!=null){Zkb.G5(this.a,'M  ALS ');clb.lq(this,o+1);clb.lq(this,q.length);Zkb.G5(this.a,z1(e1(a.B[o],1),0)?' T ':' F ');for(K=0;K<q.length;K++){M=(clb.wj(),clb.qj)[q[K]];switch(alb.Pgb(M).length){case 1:Zkb.G5(this.a,M+'   ');break;case 2:Zkb.G5(this.a,M+'  ');break;case 3:Zkb.G5(this.a,M+' ');break;default:Zkb.G5(this.a,'   ?');}}Zkb.G5(this.a,Klb);}}S=0;for(g=0;g<a.q;g++)z1(e1(a.B[g],6144),0)&&++S;if(S!=0){w=0;for(d=0;d<a.q;d++){X=e1(a.B[d],6144);if(j1(X,0)!=0){if(w==0){Zkb.G5(this.a,'M  SUB');clb.lq(this,$wnd.Math.min(8,S));}Zkb.G5(this.a,' ');clb.lq(this,d+1);z1(e1(X,Imb),0)?Zkb.G5(this.a,'   '+(a.e[d]+1)):Zkb.G5(this.a,'  -2');--S;if(++w==8||S==0){w=0;Zkb.G5(this.a,Klb);}}}}}Zkb.G5(this.a,mob);};clb.qq=function qq(a,b){clb.pq.call(this,a,0,b);};U1(102,1,{},clb.nq,clb.pq);Ykb.eY=w3(102);clb.rq=function rq(a,b,c,d,e,f){var g,h,i,j;j=1;h=false;switch(e){case 1:j=257;break;case 3:j=386;break;case 4:j=257;h=true;break;case 6:j=129;break;default:switch(d){case 1:j=1;break;case 2:j=2;break;case 3:j=4;break;case 4:j=64;break;case 9:j=32;}}g=clb.Aj(a.j,b,c,j);i=0;h&&clb.Nl(a.j,b,1,-1);if(d>4){switch(d){case 5:i|=3;break;case 6:i|=9;break;case 7:i|=10;break;case 8:j!=32&&(i|=31);}}f==1&&(i|=256);f==2&&(i|=128);i!=0&&clb.im(a.j,g,i,true);return g;};clb.sq=function sq(a){var b,c,d,e,f,g,h,i,j,k,l;g=gW(Ykb.AX,gmb,6,a.j.q,15,1);for(c=0;c<a.j.q;c++)g[c]=-clb.dk(a.j,c);clb.ce(new clb.me(a.j),null,true);for(d=0;d<a.j.q;d++)g[d]+=clb.dk(a.j,d);for(b=0;b<a.j.q;b++){if(g[b]!=0){h=-g[b];for(e=0;e<a.j.r;e++){for(j=0;j<2;j++){if(h>0&&clb.Kk(a.j,e)==32&&clb.zk(a.j,1-j,e)==b){l=clb.zk(a.j,j,e);if(clb.jl(a.j,l)){k=clb.uq(a,l);f=clb.dk(a.j,l);if(f<k){i=$wnd.Math.min(h,k-f);clb.Il(a.j,l,f+i);h-=i;}}}}}}}};clb.tq=function tq(a,b){a.j=null;return clb.Lq(a,new Alb.q2(new Alb.u2(b)))?a.j:null;};clb.uq=function uq(a,b){var c,d;c=clb.uk(a.j,b);d=c<(clb.wj(),clb.sj).length?clb.sj[c]:null;return d==null?0:d[d.length-1];};clb.vq=function vq(a,b){var c;c=!a.b?null:dlb.Iab(a.b,new Zkb.h4(b));return !c?b-1:c.a;};clb.wq=function wq(a,b){var c;c=!a.c?null:dlb.Iab(a.c,new Zkb.h4(b));return !c?b-1:c.a;};clb.xq=function xq(a,b){var c,d;if(b!=null){clb.Gt(a.j,1);for(c=0;c<a.j.f;c++){if(b[c]!=0){d=clb.Ok(a.j,c,clb.Pn(a.j,c));b[c]==15?d>=0&&clb.Gl(a.j,c,0):b[c]!=clb.Pk(a.j,c)&&clb.Gl(a.j,c,b[c]-d);}}}};clb.yq=function yq(a,b){var c;if(b==-1){return -1;}for(c=b+1;c<alb.Pgb(a).length;c++){alb.Kgb(c,alb.Pgb(a).length);if(alb.Pgb(a).charCodeAt(c)!=32&&(alb.Kgb(c,alb.Pgb(a).length),alb.Pgb(a).charCodeAt(c)!=9)){return c;}}return -1;};clb.zq=function zq(a,b){var c;for(c=b;c<alb.Pgb(a).length;c++){alb.Kgb(c,alb.Pgb(a).length);if(alb.Pgb(a).charCodeAt(c)==32||(alb.Kgb(c,alb.Pgb(a).length),alb.Pgb(a).charCodeAt(c)==9)){return c;}}return -1;};clb.Aq=function Aq(a){if(alb.Pgb(a).indexOf('ATOMS=(')!=-1)return nob;if(alb.Pgb(a).indexOf('BONDS=(')!=-1)return 'BONDS';return null;};clb.Bq=function Bq(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F;p=0;q=(h=clb.zq(b,p+1),h==-1?alb.Pgb(b).length:h);d=Zkb.P3((alb.Jgb(p,q,alb.Pgb(b).length),alb.Pgb(b).substr(p,q-p)),oob,Qlb);p=clb.yq(b,q);q=(i=clb.zq(b,p+1),i==-1?alb.Pgb(b).length:i);s=(alb.Jgb(p,q,alb.Pgb(b).length),alb.Pgb(b).substr(p,q-p));A=null;e=false;r=clb.Iq(b);if(r!=0){A=clb.Cq(b);r<0&&(e=true);q=$wnd.Math.abs(r);}p=clb.yq(b,q);q=(j=clb.zq(b,p+1),j==-1?alb.Pgb(b).length:j);C=a4((alb.Jgb(p,q,alb.Pgb(b).length),alb.Pgb(b).substr(p,q-p)));p=clb.yq(b,q);q=(k=clb.zq(b,p+1),k==-1?alb.Pgb(b).length:k);D=a4((alb.Jgb(p,q,alb.Pgb(b).length),alb.Pgb(b).substr(p,q-p)));p=clb.yq(b,q);q=(l=clb.zq(b,p+1),l==-1?alb.Pgb(b).length:l);F=a4((alb.Jgb(p,q,alb.Pgb(b).length),alb.Pgb(b).substr(p,q-p)));p=clb.yq(b,q);q=(m=clb.zq(b,p+1),m==-1?alb.Pgb(b).length:m);u=Zkb.P3((alb.Jgb(p,q,alb.Pgb(b).length),alb.Pgb(b).substr(p,q-p)),oob,Qlb);c=clb.xj(a.j,C,-D,-F);c+1!=d&&(!a.b&&(a.b=new dlb.seb()),dlb.keb(a.b,new Zkb.h4(d),new Zkb.h4(c)));if(A!=null){clb._l(a.j,c,6);clb.Pl(a.j,c,A,e);}u!=0&&clb.Ql(a.j,c,u,false);if(Zkb.c5(s,'A')||Zkb.c5(s,'*')){clb.Ul(a.j,c,1,true);}else if(Zkb.c5(s,'Q')){t=gW(Ykb.AX,gmb,6,1,15,1);t[0]=6;clb.Pl(a.j,c,t,true);}else {clb._l(a.j,c,clb.Nm(s,67));}while((p=clb.yq(b,q))!=-1){q=(g=clb.zq(b,p+1),g==-1?alb.Pgb(b).length:g);v=(alb.Jgb(p,q,alb.Pgb(b).length),alb.Pgb(b).substr(p,q-p));o=Zkb.g5(v,s5(61));n=(alb.Jgb(0,o,alb.Pgb(v).length),alb.Pgb(v).substr(0,o));B=Zkb.P3((alb.Kgb(o+1,alb.Pgb(v).length+1),alb.Pgb(v).substr(o+1)),oob,Qlb);if(Zkb.c5(n,'CHG')){clb.Il(a.j,c,B);}else if(Zkb.c5(n,'RAD')){switch(B){case 1:clb.Vl(a.j,c,16);break;case 2:clb.Vl(a.j,c,32);break;case 3:clb.Vl(a.j,c,48);}}else if(Zkb.c5(n,'CFG'));else if(Zkb.c5(n,'MASS')){clb.Sl(a.j,c,B);}else if(Zkb.c5(n,'VAL')){clb.Gl(a.j,c,B==-1?0:B==0?-1:B);}else if(Zkb.c5(n,'HCOUNT')){switch(B){case 0:break;case-1:clb.Ul(a.j,c,1792,true);break;case 1:clb.Ul(a.j,c,128,true);break;case 2:clb.Ul(a.j,c,384,true);break;default:clb.Ul(a.j,c,896,true);}}else if(Zkb.c5(n,'SUBST')){if(B==-1){clb.Ul(a.j,c,lnb,true);}else if(B>0){w=0;for(f=0;f<a.j.r;f++){(clb.zk(a.j,0,f)==c||clb.zk(a.j,1,f)==c)&&++w;}B>w&&clb.Ul(a.j,c,Imb,true);}}else if(Zkb.c5(n,'RBCNT')){switch(B){case 3:case-1:clb.Ul(a.j,c,112,true);break;case 1:clb.Ul(a.j,c,8,true);break;case 2:clb.Ul(a.j,c,104,true);break;case 4:clb.Ul(a.j,c,56,true);}}}};clb.Cq=function Cq(a){var b,c,d,e,f,g,h,i;h=null;c=alb.Pgb(a).indexOf('[');d=alb.Pgb(a).indexOf(']',c);if(c>=0&&d>0){b=gW(Ykb.AX,gmb,6,16,15,1);i=(alb.Jgb(c+1,d,alb.Pgb(a).length),alb.Pgb(a).substr(c+1,d-(c+1)));e=0;g=true;while(g&&e<16){c=alb.Pgb(i).indexOf(',');f=null;if(c==-1){f=i;g=false;}else {f=(alb.Jgb(0,c,alb.Pgb(i).length),alb.Pgb(i).substr(0,c));i=(alb.Kgb(c+1,alb.Pgb(i).length+1),alb.Pgb(i).substr(c+1));}b[e++]=clb.Nm(f,1);}h=gW(Ykb.AX,gmb,6,e,15,1);Zkb.P5(b,0,h,0,e);}return h;};clb.Dq=function Dq(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t;o=0;p=(i=clb.zq(b,o+1),i==-1?alb.Pgb(b).length:i);f=Zkb.P3((alb.Jgb(o,p,alb.Pgb(b).length),alb.Pgb(b).substr(o,p-o)),oob,Qlb);o=clb.yq(b,p);p=(j=clb.zq(b,o+1),j==-1?alb.Pgb(b).length:j);g=Zkb.P3((alb.Jgb(o,p,alb.Pgb(b).length),alb.Pgb(b).substr(o,p-o)),oob,Qlb);o=clb.yq(b,p);p=(k=clb.zq(b,o+1),k==-1?alb.Pgb(b).length:k);c=clb.vq(a,Zkb.P3((alb.Jgb(o,p,alb.Pgb(b).length),alb.Pgb(b).substr(o,p-o)),oob,Qlb));o=clb.yq(b,p);p=(l=clb.zq(b,o+1),l==-1?alb.Pgb(b).length:l);d=clb.vq(a,Zkb.P3((alb.Jgb(o,p,alb.Pgb(b).length),alb.Pgb(b).substr(o,p-o)),oob,Qlb));r=0;s=0;while((o=clb.yq(b,p))!=-1){p=(h=clb.zq(b,o+1),h==-1?alb.Pgb(b).length:h);q=(alb.Jgb(o,p,alb.Pgb(b).length),alb.Pgb(b).substr(o,p-o));n=Zkb.g5(q,s5(61));m=(alb.Jgb(0,n,alb.Pgb(q).length),alb.Pgb(q).substr(0,n));t=Zkb.P3((alb.Kgb(n+1,alb.Pgb(q).length+1),alb.Pgb(q).substr(n+1)),oob,Qlb);if(Zkb.c5(m,'CFG')){switch(t){case 1:r=1;break;case 2:r=g==2?3:4;break;case 3:r=6;}}else Zkb.c5(m,'TOPO')?s=t:undefined;}e=clb.rq(a,c,d,g,r,s);e+1!=f&&(!a.c&&(a.c=new dlb.seb()),dlb.keb(a.c,new Zkb.h4(f),new Zkb.h4(e)));};clb.Eq=function Eq(a,b){var c,d,e,f,g,h;h=clb.Aq(b);if(h!=null){g=clb.Gq(b,h);if(Zkb.c5(alb.Pgb(b).substr(0,13),'MDLV30/STEABS')){if(Zkb.c5(h,nob))for(f=0;f<g.length;f++)clb.Nl(a.j,clb.vq(a,g[f]),0,-1);else for(e=0;e<g.length;e++)clb.dm(a.j,clb.wq(a,g[e]),0,-1);}else if(Zkb.c5(alb.Pgb(b).substr(0,13),'MDLV30/STERAC')){d=Zkb.P3(Zkb.p5(b,13,clb.zq(b,13)),oob,Qlb);if(Zkb.c5(h,nob))for(f=0;f<g.length;f++)clb.Nl(a.j,clb.vq(a,g[f]),1,d-1);else for(e=0;e<g.length;e++)clb.dm(a.j,clb.wq(a,g[e]),1,d-1);}else if(Zkb.c5(alb.Pgb(b).substr(0,13),'MDLV30/STEREL')){d=Zkb.P3(Zkb.p5(b,13,clb.zq(b,13)),oob,Qlb);if(Zkb.c5(h,nob))for(f=0;f<g.length;f++)clb.Nl(a.j,clb.vq(a,g[f]),2,d-1);else for(e=0;e<g.length;e++)clb.dm(a.j,clb.wq(a,g[e]),2,d-1);}else if(Zkb.c5(alb.Pgb(b).substr(0,13),'MDLV30/HILITE')){if(Zkb.c5(h,nob)){for(e=0;e<g.length;e++)clb.Jl(a.j,clb.vq(a,g[e]),448);}else {for(e=0;e<g.length;e++){c=clb.wq(a,g[e]);clb.Jl(a.j,clb.zk(a.j,0,c),448);clb.Jl(a.j,clb.zk(a.j,1,c),448);}}}}};clb.Fq=function Fq(a,b){var c,d,e;if(!a.j){if(Zkb.c5(alb.Pgb(b).substr(0,6),'COUNTS')){c=clb.yq(b,clb.zq(b,7));d=Zkb.P3(Zkb.p5(b,7,clb.zq(b,7)),oob,Qlb);e=Zkb.P3(Zkb.p5(b,c,clb.zq(b,c)),oob,Qlb);a.j=new clb.Zt(d,e);}}};clb.Gq=function Gq(a,b){var c,d,e,f,g,h;f=alb.Pgb(a).indexOf(b+'=(')+alb.Pgb(b).length+2;g=Zkb.h5(a,s5(41),f);e=clb.zq(a,f);c=Zkb.P3((alb.Jgb(f,e,alb.Pgb(a).length),alb.Pgb(a).substr(f,e-f)),oob,Qlb);h=gW(Ykb.AX,gmb,6,c,15,1);for(d=0;d<c;d++){f=clb.yq(a,e);e=clb.zq(a,f);(e==-1||e>g)&&(e=g);h[d]=Zkb.P3((alb.Jgb(f,e,alb.Pgb(a).length),alb.Pgb(a).substr(f,e-f)),oob,Qlb);}return h;};clb.Hq=function Hq(a){var b,c,d,e,f,g,h,i,j;i=gW(Ykb.AX,gmb,6,a.j.q,15,1);for(d=0;d<a.j.r;d++)if(clb.Kk(a.j,d)==64)for(g=0;g<2;g++)i[clb.zk(a.j,g,d)]=1;for(e=0;e<a.j.r;e++){j=clb.Hk(a.j,e);for(f=0;f<2;f++)i[clb.zk(a.j,f,e)]+=j;}for(c=0;c<a.j.r;c++){if(clb.Hk(a.j,c)==1){for(f=0;f<2;f++){h=clb.zk(a.j,1-f,c);if(clb.jl(a.j,h)){b=clb.zk(a.j,f,c);if(clb.gl(a.j,b)&&i[b]>clb.Pk(a.j,b)){clb.jm(a.j,c,32);continue;}}}}}};clb.Iq=function Iq(a){var b,c;if(alb.Pgb(a).indexOf('[')>=0){b=alb.Pgb(a).indexOf(' NOT[');c=alb.Pgb(a).indexOf(']',b);if(b>=0&&c>0){return -(c+1);}else {b=alb.Pgb(a).indexOf(' [');c=alb.Pgb(a).indexOf(']',b);if(b>=0&&c>0){return c+1;}}b=alb.Pgb(a).indexOf(" 'NOT[");c=alb.Pgb(a).indexOf("]'",b);if(b>=0&&c>0){return -(c+2);}else {b=alb.Pgb(a).indexOf(" '[");c=alb.Pgb(a).indexOf("]'",b);if(b>=0&&c>0){return c+2;}}Zkb.O5();}return 0;};clb.Jq=function Jq(a,b,c){a.j=b;return clb.Lq(a,c);};clb.Kq=function Kq(a){return alb.Pgb(a).length==0?0:Zkb.P3(a,oob,Qlb);};clb.Lq=function Lq(b,c){var d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X;T=null;try{b.f=null;if(b.j){clb.Nj(b.j);clb.lm(b.j,false);}D=v=Alb.p2(c);if(null==D){return false;}if(null==(v=Alb.p2(c))){return false;}if(null==(v=Alb.p2(c))){return false;}b.k=alb.Pgb(v).indexOf("From CSD data. Using bond type 'Any'")!=-1;b.e=alb.Pgb(v).indexOf('From CSD data.')!=-1;if(null==(v=Alb.p2(c))){return false;}b.g=false;b.d=b.a;try{F=Zkb.P3(Zkb.q5((alb.Jgb(0,3,alb.Pgb(v).length),alb.Pgb(v).substr(0,3))),oob,Qlb);G=Zkb.P3(Zkb.q5((alb.Jgb(3,6,alb.Pgb(v).length),alb.Pgb(v).substr(3,3))),oob,Qlb);H=clb.Kq(Zkb.q5((alb.Jgb(6,9,alb.Pgb(v).length),alb.Pgb(v).substr(6,3))));b.d=b.d|1==clb.Kq(Zkb.q5((alb.Jgb(12,15,alb.Pgb(v).length),alb.Pgb(v).substr(12,3))));b.g=alb.Pgb(v).length>=39&&Zkb.c5(alb.Pgb(v).substr(34,alb.Pgb('V3000').length),'V3000');}catch(a){a=b1(a);if(mX(a,15)){return false;}else throw c1(a);}if(b.g){K=clb.Mq(b,c);clb.rm(b.j,D);return K;}!b.j&&(b.j=new clb.Zt(F,G));clb.rm(b.j,D);b.d||(b.j.L=true);if(0==F){while(v!=null&&!(Zkb.c5(v,pob)||Zkb.c5(v,qob)||Zkb.c5((alb.Kgb(1,alb.Pgb(v).length+1),alb.Pgb(v).substr(1)),'$'))){v=Alb.p2(c);}return true;}for(q=0;q<F;q++){if(null==(v=Alb.p2(c))){return false;}V=a4(Zkb.q5((alb.Jgb(0,10,alb.Pgb(v).length),alb.Pgb(v).substr(0,10))));W=a4(Zkb.q5((alb.Jgb(10,20,alb.Pgb(v).length),alb.Pgb(v).substr(10,10))));X=a4(Zkb.q5((alb.Jgb(20,30,alb.Pgb(v).length),alb.Pgb(v).substr(20,10))));e=clb.xj(b.j,V,-W,-X);u=Zkb.q5((alb.Jgb(31,34,alb.Pgb(v).length),alb.Pgb(v).substr(31,3)));if(Zkb.c5(u,'A')||Zkb.c5(u,'*')){clb.Ul(b.j,e,1,true);}else if(Zkb.c5(u,'Q')){w=gW(Ykb.AX,gmb,6,1,15,1);w[0]=6;clb.Pl(b.j,e,w,true);}else {h=clb.Nm(u,67);clb._l(b.j,e,h);}C=clb.Kq(Zkb.q5((alb.Jgb(34,36,alb.Pgb(v).length),alb.Pgb(v).substr(34,2))));C!=0&&clb.Sl(b.j,e,(clb.wj(),clb.uj)[clb.uk(b.j,e)]+C);m=clb.Kq(Zkb.q5((alb.Jgb(36,39,alb.Pgb(v).length),alb.Pgb(v).substr(36,3))));m!=0&&(m==4?clb.Vl(b.j,e,32):clb.Il(b.j,e,4-m));A=alb.Pgb(v).length<63?0:clb.Kq(Zkb.q5((alb.Jgb(60,63,alb.Pgb(v).length),alb.Pgb(v).substr(60,3))));clb.Ql(b.j,e,A,false);o=alb.Pgb(v).length<45?0:clb.Kq(Zkb.q5((alb.Jgb(42,45,alb.Pgb(v).length),alb.Pgb(v).substr(42,3))));switch(o){case 0:break;case 1:clb.Ul(b.j,e,768,true);break;case 2:clb.Ul(b.j,e,128,true);break;case 3:clb.Ul(b.j,e,384,true);break;default:clb.Ul(b.j,e,896,true);}alb.Pgb(v).length>=48&&(alb.Kgb(47,alb.Pgb(v).length),alb.Pgb(v).charCodeAt(47)==49)&&clb.Ul(b.j,e,knb,true);S=alb.Pgb(v).length<51?0:clb.Kq(Zkb.q5((alb.Jgb(48,51,alb.Pgb(v).length),alb.Pgb(v).substr(48,3))));if(S!=0){T==null&&(T=gW(Ykb.AX,gmb,6,F,15,1));T[e]=S;}}for(r=0;r<G;r++){if(null==(v=Alb.p2(c))){return false;}f=Zkb.P3(Zkb.q5((alb.Jgb(0,3,alb.Pgb(v).length),alb.Pgb(v).substr(0,3))),oob,Qlb)-1;g=Zkb.P3(Zkb.q5((alb.Jgb(3,6,alb.Pgb(v).length),alb.Pgb(v).substr(3,3))),oob,Qlb)-1;k=Zkb.P3(Zkb.q5((alb.Jgb(6,9,alb.Pgb(v).length),alb.Pgb(v).substr(6,3))),oob,Qlb);N=alb.Pgb(v).length<12?0:clb.Kq(Zkb.q5((alb.Jgb(9,12,alb.Pgb(v).length),alb.Pgb(v).substr(9,3))));R=alb.Pgb(v).length<18?0:clb.Kq(Zkb.q5((alb.Jgb(15,18,alb.Pgb(v).length),alb.Pgb(v).substr(15,3))));k==8&&(b.k||clb.jl(b.j,f)||clb.jl(b.j,g))&&(k=9);clb.rq(b,f,g,k,N,R);}for(p=0;p<H;p++){if(null==(v=Alb.p2(c))){return false;}}if(null==(v=Alb.p2(c))){(b.i&1)!=0&&(b.f=clb.In(b.j));clb.xq(b,T);b.d||clb.Gt(b.j,15);return true;}while(v!=null&&!(Zkb.c5(v,pob)||Zkb.c5(v,qob))){if(Zkb.c5(alb.Pgb(v).substr(0,6),'M  CHG')){s=Zkb.P3(Zkb.q5((alb.Jgb(6,9,alb.Pgb(v).length),alb.Pgb(v).substr(6,3))),oob,Qlb);if(s>0){d=10;U=14;for(t=1;t<=s;++t,d+=8,U+=8){e=Zkb.P3(Zkb.q5((alb.Jgb(d,d+3,alb.Pgb(v).length),alb.Pgb(v).substr(d,d+3-d))),oob,Qlb)-1;l=Zkb.P3(Zkb.q5((alb.Jgb(U,U+3,alb.Pgb(v).length),alb.Pgb(v).substr(U,U+3-U))),oob,Qlb);clb.Il(b.j,e,l);}}}if(Zkb.c5(alb.Pgb(v).substr(0,6),'M  ISO')){s=Zkb.P3(Zkb.q5((alb.Jgb(6,9,alb.Pgb(v).length),alb.Pgb(v).substr(6,3))),oob,Qlb);if(s>0){d=10;U=14;for(t=1;t<=s;++t,d+=8,U+=8){e=Zkb.P3(Zkb.q5((alb.Jgb(d,d+3,alb.Pgb(v).length),alb.Pgb(v).substr(d,d+3-d))),oob,Qlb)-1;B=Zkb.P3(Zkb.q5((alb.Jgb(U,U+3,alb.Pgb(v).length),alb.Pgb(v).substr(U,U+3-U))),oob,Qlb);clb.Sl(b.j,e,B);}}}if(Zkb.c5(alb.Pgb(v).substr(0,6),'M  RAD')){s=Zkb.P3(Zkb.q5((alb.Jgb(6,9,alb.Pgb(v).length),alb.Pgb(v).substr(6,3))),oob,Qlb);if(s>0){d=10;U=14;for(t=1;t<=s;++t,d+=8,U+=8){e=Zkb.P3(Zkb.q5((alb.Jgb(d,d+3,alb.Pgb(v).length),alb.Pgb(v).substr(d,d+3-d))),oob,Qlb)-1;J=Zkb.P3(Zkb.q5((alb.Jgb(U,U+3,alb.Pgb(v).length),alb.Pgb(v).substr(U,U+3-U))),oob,Qlb);switch(J){case 1:clb.Vl(b.j,e,16);break;case 2:clb.Vl(b.j,e,32);break;case 3:clb.Vl(b.j,e,48);}}}}if(Zkb.c5(alb.Pgb(v).substr(0,6),'M  RBC')||Zkb.c5(alb.Pgb(v).substr(0,6),'M  RBD')){s=Zkb.P3(Zkb.q5((alb.Jgb(6,9,alb.Pgb(v).length),alb.Pgb(v).substr(6,3))),oob,Qlb);if(s>0){d=10;U=14;for(t=1;t<=s;++t,d+=8,U+=8){e=Zkb.P3(Zkb.q5((alb.Jgb(d,d+3,alb.Pgb(v).length),alb.Pgb(v).substr(d,d+3-d))),oob,Qlb)-1;L=Zkb.P3(Zkb.q5((alb.Jgb(U,U+3,alb.Pgb(v).length),alb.Pgb(v).substr(U,U+3-U))),oob,Qlb);switch(L){case 3:case-1:clb.Ul(b.j,e,112,true);break;case 1:clb.Ul(b.j,e,8,true);break;case 2:clb.Ul(b.j,e,104,true);break;case 4:clb.Ul(b.j,e,56,true);}}}}if(Zkb.c5(alb.Pgb(v).substr(0,6),'M  ALS')){e=Zkb.P3(Zkb.q5((alb.Jgb(7,10,alb.Pgb(v).length),alb.Pgb(v).substr(7,3))),oob,Qlb)-1;if(e>=0){I=Zkb.P3(Zkb.q5((alb.Jgb(10,13,alb.Pgb(v).length),alb.Pgb(v).substr(10,3))),oob,Qlb);i=(alb.Kgb(14,alb.Pgb(v).length),alb.Pgb(v).charCodeAt(14)==84);S=gW(Ykb.AX,gmb,6,I,15,1);d=16;for(t=0;t<I;++t,d+=4){Q=Zkb.q5((alb.Jgb(d,d+4,alb.Pgb(v).length),alb.Pgb(v).substr(d,d+4-d)));S[t]=clb.Nm(Q,1);}clb._l(b.j,e,6);clb.Pl(b.j,e,S,i);}}if(Zkb.c5(alb.Pgb(v).substr(0,6),'M  SUB')){s=Zkb.P3(Zkb.q5((alb.Jgb(6,9,alb.Pgb(v).length),alb.Pgb(v).substr(6,3))),oob,Qlb);if(s>0){d=10;U=14;for(t=1;t<=s;++t,d+=8,U+=8){e=Zkb.P3(Zkb.q5((alb.Jgb(d,d+3,alb.Pgb(v).length),alb.Pgb(v).substr(d,d+3-d))),oob,Qlb)-1;O=Zkb.P3(Zkb.q5((alb.Jgb(U,U+3,alb.Pgb(v).length),alb.Pgb(v).substr(U,U+3-U))),oob,Qlb);if(O==-2){clb.Ul(b.j,e,lnb,true);}else if(O>0){P=0;for(j=0;j<b.j.r;j++){(clb.zk(b.j,0,j)==e||clb.zk(b.j,1,j)==e)&&++P;}O>P&&clb.Ul(b.j,e,Imb,true);}}}}if(Zkb.c5(alb.Pgb(v).substr(0,6),'M  RGP')){s=Zkb.P3(Zkb.q5((alb.Jgb(6,9,alb.Pgb(v).length),alb.Pgb(v).substr(6,3))),oob,Qlb);if(s>0){d=10;U=14;for(t=1;t<=s;++t,d+=8,U+=8){e=Zkb.P3(Zkb.q5((alb.Jgb(d,d+3,alb.Pgb(v).length),alb.Pgb(v).substr(d,d+3-d))),oob,Qlb)-1;M=Zkb.P3(Zkb.q5((alb.Jgb(U,U+3,alb.Pgb(v).length),alb.Pgb(v).substr(U,U+3-U))),oob,Qlb);M>=1&&M<=20&&clb._l(b.j,e,clb.Nm('R'+M,2));}}}v=Alb.p2(c);}}catch(a){a=b1(a);if(mX(a,15)){n=a;Zkb._y(n,(Zkb.O5(),Zkb.N5),'');return false;}else throw c1(a);}if(b.e){clb.Hq(b);clb.sq(b);}(b.i&1)!=0&&(b.f=clb.In(b.j));clb.xq(b,T);clb.Gt(b.j,15);return true;};clb.Mq=function Mq(a,b){var c,d,e,f,g;!!a.b&&dlb.deb(a.b);!!a.c&&dlb.deb(a.c);e=0;d=Alb.p2(b);while(d!=null&&Zkb.c5(alb.Pgb(d).substr(0,7),rob)){d=Zkb.q5((alb.Kgb(7,alb.Pgb(d).length+1),alb.Pgb(d).substr(7)));while(g=alb.Pgb('-').length,Zkb.c5(alb.Pgb(d).substr(alb.Pgb(d).length-g,g),'-')){c=Alb.p2(b);if(!Zkb.c5(alb.Pgb(c).substr(0,7),rob)){return false;}d=Zkb.q5(Zkb._4(Zkb.p5(d,0,alb.Pgb(d).length-1),(alb.Kgb(7,alb.Pgb(c).length+1),alb.Pgb(c).substr(7))));}if(Zkb.c5(alb.Pgb(d).substr(0,5),'BEGIN')){f=Zkb.q5((alb.Kgb(6,alb.Pgb(d).length+1),alb.Pgb(d).substr(6)));if(Zkb.c5(alb.Pgb(f).substr(0,4),'CTAB')){e=1;}else if(Zkb.c5(alb.Pgb(f).substr(0,4),'ATOM')){e=2;}else if(Zkb.c5(alb.Pgb(f).substr(0,4),'BOND')){e=3;}else if(Zkb.c5(alb.Pgb(f).substr(0,10),'COLLECTION')){e=4;}else {return false;}}else if(Zkb.c5(alb.Pgb(d).substr(0,3),'END')){e=0;}else if(e==1){clb.Fq(a,d);}else if(e==2){clb.Bq(a,d);}else if(e==3){clb.Dq(a,d);}else if(e==4){clb.Eq(a,d);}else {return false;}d=Alb.p2(b);}while(d!=null&&!(Zkb.c5(alb.Pgb(d).substr(0,6),pob)||Zkb.c5(d,qob))){d=Alb.p2(b);}return true;};clb.Nq=function Nq(){this.i=0;};clb.Oq=function Oq(){this.i=1;};U1(101,1,{},clb.Nq,clb.Oq);_.a=false;_.d=false;_.e=false;_.g=false;_.i=0;_.k=false;Ykb.fY=w3(101);clb.Pq=function Pq(a){};clb.Qq=function Qq(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G,H,I,J;Zkb.G5(a.a,'M  V30 BEGIN CTAB\n');Zkb.G5(a.a,sob+b.q+' '+b.r+' 0 0 0'+Klb);Zkb.G5(a.a,'M  V30 BEGIN ATOM\n');for(i=0;i<b.q;i++){Zkb.G5(a.a,rob+(i+1));if((b.v==null?null:b.v[i])!=null){k=b.v==null?null:b.v[i];u=z1(e1(b.B[i],1),0);Zkb.G5(a.a,u?' NOT[':' [');for(s=0;s<k.length;s++){s>0&&Zkb.G5(a.a,',');t=(clb.wj(),clb.qj)[k[s]];switch(alb.Pgb(t).length){case 2:case 3:case 1:Zkb.G5(a.a,t);break;default:Zkb.G5(a.a,'?');}}Zkb.G5(a.a,']');}else z1(e1(b.B[i],1),0)?Zkb.G5(a.a,' A'):b.C[i]>=129&&b.C[i]<=144||b.C[i]==154?Zkb.G5(a.a,' R#'):Zkb.G5(a.a,' '+(clb.wj(),clb.qj)[b.C[i]]);if(c){Zkb.G5(a.a,' '+vX($lb*a.b*b.J[i].a)/$lb);Zkb.G5(a.a,' '+vX($lb*a.b*-b.J[i].b)/$lb);Zkb.G5(a.a,' '+vX($lb*a.b*-b.J[i].c)/$lb);}else {Zkb.G5(a.a,' 0 0 0');}Zkb.G5(a.a,' '+$wnd.Math.abs(b.w[i]));b.s[i]!=0&&Zkb.G5(a.a,' CHG='+b.s[i]);if((b.u[i]&48)!=0){Zkb.G5(a.a,' RAD=');switch(b.u[i]&48){case 16:Zkb.G5(a.a,'1');break;case 32:Zkb.G5(a.a,'2');break;case 48:Zkb.G5(a.a,'3');}}if((b.u[i]&3)==1||(b.u[i]&3)==2){Zkb.G5(a.a,' CFG=');(b.u[i]&3)==1?Zkb.G5(a.a,'1'):Zkb.G5(a.a,'2');}b.A[i]!=0&&Zkb.G5(a.a,' MASS='+b.A[i]);J=((b.u[i]&Rnb)>>>27)-1;J!=-1&&Zkb.G5(a.a,' VAL='+(J==0?'-1':Zkb.t4(J)));l=b.C[i];(l>=129&&l<=144||l==154)&&Zkb.G5(a.a,' RGROUPS=(1 '+(l==154?0:l>=142?l-141:l-125)+')');r=e1(Mmb,b.B[i]);j1(r,384)==0?Zkb.G5(a.a,' HCOUNT=2'):j1(r,128)==0?Zkb.G5(a.a,' HCOUNT=1'):j1(r,1792)==0?Zkb.G5(a.a,' HCOUNT=-1'):j1(r,1664)==0&&Zkb.G5(a.a,' HCOUNT=1');G=e1(b.B[i],6144);j1(G,0)!=0&&(z1(e1(G,Imb),0)?Zkb.G5(a.a,' SUBST='+(b.e[i]+1)):Zkb.G5(a.a,' SUBST=-1'));C=e1(b.B[i],120);j1(C,0)!=0&&(j1(C,112)==0?Zkb.G5(a.a,' RBCNT=-1'):j1(C,8)==0?Zkb.G5(a.a,' RBCNT=2'):j1(C,104)==0?Zkb.G5(a.a,' RBCNT=2'):j1(C,88)==0?Zkb.G5(a.a,' RBCNT=3'):j1(C,56)==0&&Zkb.G5(a.a,' RBCNT=4'));Zkb.G5(a.a,Klb);}Zkb.G5(a.a,'M  V30 END ATOM\n');Zkb.G5(a.a,'M  V30 BEGIN BOND\n');for(n=0;n<b.r;n++){Zkb.G5(a.a,rob+(n+1));switch(b.H[n]){case 1:A=1;F=0;break;case 2:A=2;F=0;break;case 4:A=3;F=0;break;case 129:A=1;F=3;break;case 257:A=1;F=1;break;case 386:A=2;F=2;break;case 64:A=4;F=0;break;case 32:A=9;F=0;break;default:A=1;F=0;}p=b.G[n]&31;p!=0&&(p==8?A=4:p==3?A=5:p==9?A=6:p==10?A=7:A=8);Zkb.G5(a.a,' '+A+' '+(b.D[0][n]+1)+' '+(b.D[1][n]+1));F!=0&&Zkb.G5(a.a,' CFG='+F);D=b.G[n]&384;H=D==0?0:D==256?1:2;H!=0&&Zkb.G5(a.a,' TOPO='+H);Zkb.G5(a.a,Klb);}Zkb.G5(a.a,'M  V30 END BOND\n');B=false;d=0;v=gW(Ykb.AX,gmb,6,32,15,1);f=gW(Ykb.AX,gmb,6,32,15,1);for(j=0;j<b.f;j++){if((b.u[j]&3)==1||(b.u[j]&3)==2){B=true;I=(b.u[j]&rnb)>>18;I==1?++f[(b.u[j]&rnb)>>18!=1&&(b.u[j]&rnb)>>18!=2?-1:(b.u[j]&Snb)>>20]:I==2?++v[(b.u[j]&rnb)>>18!=1&&(b.u[j]&rnb)>>18!=2?-1:(b.u[j]&Snb)>>20]:++d;}}e=0;w=gW(Ykb.AX,gmb,6,32,15,1);g=gW(Ykb.AX,gmb,6,32,15,1);for(o=0;o<b.g;o++){if(clb.Hk(b,o)!=2&&((b.F[o]&3)==1||(b.F[o]&3)==2)){B=true;I=(b.F[o]&768)>>8;I==1?++g[(b.F[o]&768)>>8!=1&&(b.F[o]&768)>>8!=2?-1:(b.F[o]&Tnb)>>10]:I==2?++w[(b.F[o]&768)>>8!=1&&(b.F[o]&768)>>8!=2?-1:(b.F[o]&Tnb)>>10]:++e;}}if(B){Zkb.G5(a.a,'M  V30 BEGIN COLLECTION\n');if(d!=0){Zkb.G5(a.a,'M  V30 MDLV30/STEABS ATOMS=('+d);for(h=0;h<b.f;h++){((b.u[h]&3)==1||(b.u[h]&3)==2)&&(b.u[h]&rnb)>>18==0&&Zkb.G5(a.a,' '+(h+1));}Zkb.G5(a.a,tob);}if(e!=0){Zkb.G5(a.a,'M  V30 MDLV30/STEABS BONDS=('+e);for(m=0;m<b.g;m++){clb.Hk(b,m)!=2&&((b.F[m]&3)==1||(b.F[m]&3)==2)&&(b.F[m]&768)>>8==0&&Zkb.G5(a.a,' '+(m+1));}Zkb.G5(a.a,tob);}for(q=0;q<32;q++){if(v[q]!=0){Zkb.G5(a.a,uob+(q+1)+' ATOMS=('+v[q]);for(h=0;h<b.f;h++){((b.u[h]&3)==1||(b.u[h]&3)==2)&&(b.u[h]&rnb)>>18==2&&((b.u[h]&rnb)>>18!=1&&(b.u[h]&rnb)>>18!=2?-1:(b.u[h]&Snb)>>20)==q&&Zkb.G5(a.a,' '+(h+1));}Zkb.G5(a.a,tob);}if(f[q]!=0){Zkb.G5(a.a,vob+(q+1)+' ATOMS=('+f[q]);for(h=0;h<b.f;h++){((b.u[h]&3)==1||(b.u[h]&3)==2)&&(b.u[h]&rnb)>>18==1&&((b.u[h]&rnb)>>18!=1&&(b.u[h]&rnb)>>18!=2?-1:(b.u[h]&Snb)>>20)==q&&Zkb.G5(a.a,' '+(h+1));}Zkb.G5(a.a,tob);}if(w[q]!=0){Zkb.G5(a.a,uob+(q+1)+' BONDS=('+w[q]);for(m=0;m<b.g;m++){clb.Hk(b,m)!=2&&((b.F[m]&3)==1||(b.F[m]&3)==2)&&(b.F[m]&768)>>8==2&&((b.F[m]&768)>>8!=1&&(b.F[m]&768)>>8!=2?-1:(b.F[m]&Tnb)>>10)==q&&Zkb.G5(a.a,' '+(m+1));}Zkb.G5(a.a,tob);}if(g[q]!=0){Zkb.G5(a.a,vob+(q+1)+' BONDS=('+g[q]);for(m=0;m<b.g;m++){clb.Hk(b,m)!=2&&((b.F[m]&3)==1||(b.F[m]&3)==2)&&(b.F[m]&768)>>8==1&&((b.F[m]&768)>>8!=1&&(b.F[m]&768)>>8!=2?-1:(b.F[m]&Tnb)>>10)==q&&Zkb.G5(a.a,' '+(m+1));}Zkb.G5(a.a,tob);}}Zkb.G5(a.a,'M  V30 END COLLECTION\n');}Zkb.G5(a.a,'M  V30 END CTAB\n');};clb.Rq=function Rq(){clb.Pq(this);this.a=new Zkb.K5();};clb.Sq=function Sq(a){clb.Tq.call(this,a);};clb.Tq=function Tq(a){clb.Uq.call(this,a,new Zkb.K5());};clb.Uq=function Uq(a,b){var c,d;clb.Pq(this);clb.Gt(a,15);this.a=b;d=a.P!=null?a.P:'';Zkb.G5(this.a,d+Klb);Zkb.G5(this.a,'Actelion Java MolfileCreator 2.0\n\n');Zkb.G5(this.a,'  0  0  0  0  0  0              0 V3000\n');this.b=1;c=clb.Wq(a);c&&(this.b=clb.Vq(a));clb.Qq(this,a,c);Zkb.G5(this.a,mob);};clb.Vq=function Vq(a){var b,c,d,e,f,g,h,i,j;j=1;d=clb.wk(a,a.q,a.r,(clb.wj(),clb.vj));if(d!=0){(d<1||d>3)&&(j=1.5/d);}else {i=wob;for(b=1;b<a.q;b++){for(c=0;c<b;c++){f=a.J[c].a-a.J[b].a;g=a.J[c].b-a.J[b].b;h=a.J[c].c-a.J[b].c;e=f*f+g*g+h*h;i>e&&(i=e);}}j=3/$wnd.Math.max(0.75,i);}return j;};clb.Wq=function Wq(a){var b;if(a.q==1)return true;for(b=1;b<a.q;b++){if(a.J[b].a!=a.J[0].a||a.J[b].b!=a.J[0].b||a.J[b].c!=a.J[0].c){return true;}}return false;};clb.Xq=function Xq(a,b){var c;c=new clb.Rq();c.b=b;clb.Gt(a,15);clb.Qq(c,a,true);return c.a.a;};U1(115,1,{},clb.Rq,clb.Sq);_.b=1;Ykb.gY=w3(115);clb.Yq=function Yq(a){var b,c;c=0;for(b=0;b<a.a.q;b++)(clb.uk(a.a,b)==7||clb.uk(a.a,b)==8)&&++c;return c;};clb.Zq=function Zq(a){var b,c;c=0;for(b=0;b<a.a.q;b++)(clb.uk(a.a,b)==7||clb.uk(a.a,b)==8)&&clb.jn(a.a,b)>0&&++c;return c;};clb.$q=function $q(b){var c;try{return mlb.rD((new mlb.tD(),b.a));}catch(a){a=b1(a);if(mX(a,15)){c=a;Zkb._y(c,(Zkb.O5(),Zkb.N5),'');return -999;}else throw c1(a);}};clb._q=function _q(a){this.a=a;clb.Eo(a);};U1(225,1,{});Ykb.hY=w3(225);clb.ar=function ar(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o,p;k=a.g.M;l=0;for(f=0;f<c;f++){if(k>b[f]){k=b[f];l=f;}}p=gW(Ykb.AX,gmb,6,c,15,1);j=l>0?l-1:c-1;m=l<c-1?l+1:0;h=b[j]<b[m];for(g=0;g<c;g++){p[g]=b[l];h?--l<0&&(l=c-1):++l==c&&(l=0);}for(e=0;e<a.i.a.length;e++){o=dlb.Bi(a.i,e);if(o.length!=c)continue;d=true;for(i=0;i<c;i++){if(o[i]!=p[i]){d=false;break;}}if(d)return;}dlb.wi(a.i,p);n=clb.mr(a,p);dlb.wi(a.j,n);clb.Dr(a,p,n);};clb.br=function br(a,b,c){var d,e,f,g,h,i,j;i=gW(Ykb.AX,gmb,6,a.f,15,1);g=gW(Ykb.AX,gmb,6,a.f,15,1);j=gW(Ykb.Z0,Amb,6,a.g.f,16,1);d=clb.zk(a.g,0,b);e=clb.zk(a.g,1,b);i[0]=d;i[1]=e;g[1]=-1;j[e]=true;h=1;while(h>=1){++g[h];if(g[h]==clb.wn(a.g,i[h])){j[i[h]]=false;--h;continue;}f=clb.vn(a.g,i[h],g[h]);if(j[f]||c[f])continue;if(f==d&&h>1){clb.ar(a,i,h+1);if(a.i.a.length>=Nmb)return;continue;}if(h+1<a.f){++h;i[h]=f;j[f]=true;g[h]=-1;}}};clb.cr=function cr(a,b,c,d,e,f,g,h){var i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D;A=dlb.Bi(a.i,b);for(l=A,m=0,n=l.length;m<n;++m){k=l[m];if(!clb.zr(a,k))return true;}B=dlb.Bi(a.j,b);C=B.length;o=0;j=0;D=false;for(v=0;v<C;v++){o<<=1;j<<=1;if(clb.Br(a,B[v])){o|=1;}else if(h&&clb.yr(a,B[v])){o|=1;j|=1;}else {i=c[b][v];if(i!=-1){if(d[i]){if(e[i]){o|=1;f[i]||(j|=1);}}else {D=true;}}}}u=false;switch(C){case 3:p=oW(aW(Ykb.AX,1),gmb,6,15,[2,1,4]);u=true;for(t=0;t<3;t++){if((o&p[t])==p[t]){if(clb.uk(a.g,A[t])==6&&clb.dk(a.g,A[t])==1||clb.uk(a.g,A[t])==5&&clb.dk(a.g,A[t])==0){e[b]=true;g[b]=t;(j&p[t])==0&&(u=false);}}}break;case 5:q=oW(aW(Ykb.AX,1),gmb,6,15,[10,5,18,9,20]);u=true;for(w=0;w<5;w++){if((o&q[w])==q[w]){switch(clb.uk(a.g,A[w])){case 6:if(clb.dk(a.g,A[w])==-1){e[b]=true;g[b]=w;(j&q[w])==0&&(u=false);}break;case 7:if(clb.dk(a.g,A[w])<=0){e[b]=true;g[b]=w;}break;case 8:e[b]=true;g[b]=w;break;case 16:case 34:case 52:if(clb.wn(a.g,A[w])==2){e[b]=true;g[b]=w;}}}}break;case 6:u=true;if((o&21)==21){e[b]=true;(j&21)==0&&(u=false);}if((o&42)==42){e[b]=true;(j&42)==0&&(u=false);}break;case 7:r=oW(aW(Ykb.AX,1),gmb,6,15,[42,21,74,37,82,41,84]);u=true;for(s=0;s<7;s++){if((o&r[s])==r[s]){if(clb.uk(a.g,A[s])==6&&(clb.dk(a.g,A[s])==1||h&&clb.pr(a,A[s]))||clb.uk(a.g,A[s])==5&&clb.dk(a.g,A[s])==0){e[b]=true;g[b]=s;(j&r[s])==0&&(u=false);}}}}e[b]&&!u&&(f[b]=true);if(e[b])return true;return !D;};clb.dr=function dr(a,b,c,d,e){var f,g,h,i,j,k,l,m,n,o,p,q;f=gW(Ykb.AX,Dnb,7,a.i.a.length,0,2);for(j=0;j<a.i.a.length;j++){f[j]=gW(Ykb.AX,gmb,6,dlb.Bi(a.i,j).length,15,1);for(k=0;k<dlb.Bi(a.i,j).length;k++)f[j][k]=-1;}p=gW(Ykb.AX,gmb,6,a.g.g,15,1);for(n=0;n<a.j.a.length;n++){o=dlb.Bi(a.j,n);if(o.length==3||o.length>=5&&o.length<=7){for(i=0;i<o.length;i++){h=o[i];if(clb.wn(a.g,clb.zk(a.g,0,h))==3&&clb.wn(a.g,clb.zk(a.g,1,h))==3){if(p[h]>0){f[p[h]>>>16][p[h]&32767]=n;f[n][i]=p[h]>>>16;}else {p[h]=(n<<16)+Ynb+i;}}}}}g=gW(Ykb.Z0,Amb,6,a.i.a.length,16,1);q=0;l=-1;while(q>l){l=q;for(m=0;m<a.i.a.length;m++){if(!g[m]){if(clb.cr(a,m,f,g,b,c,d,e)){g[m]=true;++q;}}}}};clb.er=function er(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o;e=clb.zk(a.g,0,b);f=clb.zk(a.g,1,b);i=gW(Ykb.AX,gmb,6,a.g.f,15,1);j=gW(Ykb.AX,gmb,6,a.g.f,15,1);k=gW(Ykb.AX,gmb,6,a.g.f,15,1);i[0]=e;i[1]=f;j[e]=1;j[f]=2;k[e]=-1;k[f]=e;h=1;l=1;while(h<=l){for(m=0;m<clb.wn(a.g,i[h]);m++){g=clb.vn(a.g,i[h],m);if(h>1&&g==e){o=gW(Ykb.AX,gmb,6,j[i[h]],15,1);d=i[h];for(n=0;n<o.length;n++){o[n]=d;d=k[d];}return o;}if(j[g]==0&&!c[g]){i[++l]=g;j[g]=j[i[h]]+1;k[g]=i[h];}}++h;}return null;};clb.fr=function fr(a,b,c){var d,e;e=dlb.Bi(a.i,b);for(d=0;d<e.length;d++)if(c==e[d])return d;return -1;};clb.gr=function gr(a,b){return a.a[b]&Zlb;};clb.hr=function hr(a,b,c){var d,e;e=dlb.Bi(a.j,b);for(d=0;d<e.length;d++)if(c==e[d])return d;return -1;};clb.ir=function ir(a,b){return a.b[b]&Zlb;};clb.jr=function jr(a,b){return a.c[b];};clb.kr=function kr(a,b){return dlb.Bi(a.i,b);};clb.lr=function lr(a,b){return dlb.Bi(a.j,b);};clb.mr=function mr(a,b){var c,d,e,f,g;f=b.length;g=gW(Ykb.AX,gmb,6,f,15,1);for(d=0;d<f;d++){c=d==f-1?b[0]:b[d+1];for(e=0;e<clb.wn(a.g,b[d]);e++){if(clb.vn(a.g,b[d],e)==c){g[d]=clb.xn(a.g,b[d],e);break;}}}return g;};clb.nr=function nr(a,b){return dlb.Bi(a.j,b).length;};clb.or=function or(a,b,c){var d;for(d=0;d<a.j.a.length;d++)if(clb.ur(a,d,b)&&clb.ur(a,d,c))return d;return -1;};clb.pr=function pr(a,b){var c;for(c=0;c<clb.wn(a.g,b);c++)if(clb.yn(a.g,b,c)==2&&clb.uk(a.g,clb.vn(a.g,b,c))==8)return true;return false;};clb.qr=function qr(a,b){return a.d[b];};clb.rr=function rr(a,b){return (a.a[b]&Ylb)!=0;};clb.sr=function sr(a,b){return (a.b[b]&Ylb)!=0;};clb.tr=function tr(a,b,c){var d,e;e=dlb.Bi(a.i,b);for(d=0;d<e.length;d++)if(c==e[d])return true;return false;};clb.ur=function ur(a,b,c){var d,e;e=dlb.Bi(a.j,b);for(d=0;d<e.length;d++)if(c==e[d])return true;return false;};clb.vr=function vr(a,b){return a.e[b];};clb.wr=function wr(a,b){return (a.b[b]&Gnb)!=0;};clb.xr=function xr(a,b){return (a.a[b]&tnb)!=0;};clb.yr=function yr(a,b){var c,d,e,f,g,h;for(g=0;g<2;g++){c=clb.zk(a.g,g,b);if(clb.uk(a.g,c)==7&&clb.wn(a.g,c)==2){d=clb.zk(a.g,1-g,b);if(clb.uk(a.g,d)==6){for(h=0;h<clb.wn(a.g,d);h++){e=clb.vn(a.g,d,h);f=clb.xn(a.g,d,h);if((clb.uk(a.g,e)==8||clb.uk(a.g,e)==16)&&clb.Hk(a.g,f)==2&&clb.wn(a.g,e)==1)return true;}}}}return false;};clb.zr=function zr(a,b){var c,d,e,f,g;if(a.g.K){if(z1(e1(clb.pk(a.g,b),1),0)){return true;}else {g=clb.kk(a.g,b);if(g!=null){for(d=g,e=0,f=d.length;e<f;++e){c=d[e];if(c==5||c==6||c==7||c==8||c==15||c==16||c==33||c==34)return true;}return false;}}}return clb.Hr(clb.uk(a.g,b));};clb.Ar=function Ar(a,b){var c,d,e,f,g;if(a.g.K){if(z1(e1(clb.pk(a.g,b),1),0))return false;c=clb.kk(a.g,b);if(c!=null){for(e=c,f=0,g=e.length;f<g;++f){d=e[f];if(!clb.Om(d))return false;}return true;}}return clb.Om(clb.uk(a.g,b));};clb.Br=function Br(a,b){return clb.Hk(a.g,b)>1||clb.Kk(a.g,b)==64;};clb.Cr=function Cr(a){var b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q;for(q=0;q<a.d.length;q++){if(a.d[q]){p=false;for(d=dlb.Bi(a.i,q),f=0,h=d.length;f<h;++f){b=d[f];a.a[b]|=Ylb;clb.Ar(a,b)&&(p=true);}for(k=dlb.Bi(a.j,q),m=0,o=k.length;m<o;++m){i=k[m];a.b[i]|=Ylb;}if(a.e[q]){for(c=dlb.Bi(a.i,q),e=0,g=c.length;e<g;++e){b=c[e];a.a[b]|=Gnb;}for(j=dlb.Bi(a.j,q),l=0,n=j.length;l<n;++l){i=j[l];a.b[i]|=Gnb;}}if(p){for(c=dlb.Bi(a.i,q),e=0,g=c.length;e<g;++e){b=c[e];a.a[b]|=tnb;}for(j=dlb.Bi(a.j,q),l=0,n=j.length;l<n;++l){i=j[l];a.b[i]|=tnb;}}}}};clb.Dr=function Dr(a,b,c){var d,e,f,g;g=b.length;for(f=0;f<g;f++){d=a.a[b[f]]&Zlb;if(d==0||d>g){a.a[b[f]]&=Mnb;a.a[b[f]]|=g;}}for(e=0;e<g;e++){d=a.b[c[e]]&Zlb;if(d==0||d>g){a.b[c[e]]&=Mnb;a.b[c[e]]|=g;}}};clb.Er=function Er(a,b,c){var d;d=dlb.Bi(a.j,b).length;while(c>=d)c-=d;while(c<0)c+=d;return c;};clb.Fr=function Fr(a,b){clb.Gr.call(this,a,b);};clb.Gr=function Gr(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s;this.g=a;this.f=7;this.i=new dlb.Qi();this.j=new dlb.Qi();this.a=gW(Ykb.AX,gmb,6,this.g.f,15,1);this.b=gW(Ykb.AX,gmb,6,this.g.g,15,1);this.g.wb(1);m=gW(Ykb.Z0,Amb,6,this.g.f,16,1);n=gW(Ykb.Z0,Amb,6,this.g.g,16,1);do{g=false;for(c=0;c<this.g.f;c++){if(!m[c]){q=0;for(l=0;l<clb.wn(this.g,c);l++)m[clb.vn(this.g,c,l)]||++q;if(q<2){m[c]=true;for(k=0;k<clb.wn(this.g,c);k++)n[clb.xn(this.g,c,k)]=true;g=true;}}}}while(g);s=0;while(s<this.g.f&&m[s])++s;if(s==this.g.f)return;i=gW(Ykb.AX,gmb,6,this.g.f,15,1);i[0]=s;p=gW(Ykb.AX,gmb,6,this.g.f,15,1);p[0]=-1;h=gW(Ykb.AX,gmb,6,this.g.f,15,1);h[s]=1;f=0;j=0;o=1;while(f<=j){for(k=0;k<clb.wn(this.g,i[f]);k++){e=clb.vn(this.g,i[f],k);if(e==p[i[f]])continue;if(h[e]!=0){clb.br(this,clb.xn(this.g,i[f],k),m);continue;}if(!m[e]){h[e]=o;p[e]=i[f];i[++j]=e;}}++f;if(f>j){for(c=0;c<this.g.f;c++){if(h[c]==0&&!m[c]){h[c]=++o;i[++j]=c;p[c]=-1;break;}}}}if((b&4)!=0){this.d=gW(Ykb.Z0,Amb,6,this.i.a.length,16,1);this.e=gW(Ykb.Z0,Amb,6,this.i.a.length,16,1);this.c=gW(Ykb.AX,gmb,6,this.i.a.length,15,1);clb.dr(this,this.d,this.e,this.c,(b&8)!=0);clb.Cr(this);}if((b&2)!=0){for(d=0;d<this.g.g;d++){if(!n[d]&&clb.Hk(this.g,d)!=0){r=clb.er(this,d,m);r!=null&&clb.Dr(this,r,clb.mr(this,r));}}}};clb.Hr=function Hr(a){return a==5||a==6||a==7||a==8||a==15||a==16||a==33||a==34;};U1(118,1,{},clb.Fr);_.f=0;Ykb.iY=w3(118);clb.Ir=function Ir(a,b){var c,d,e,f,g,h,i,j,k,l,m;if(b==2||b==5){dlb.wi(a.D,clb.ls(a.F,a.F.length));!!a.b&&dlb.wi(a.a,clb.ms(a.B,a.B.length));}else if(b==4){m=clb.Ur(clb.ls(a.F,a.F.length));if(!dlb.efb(a.N,m)){dlb.cfb(a.N,m);dlb.wi(a.D,clb.ls(a.F,a.F.length));!!a.b&&dlb.wi(a.a,clb.ms(a.B,a.B.length));}}else if(b==3){m=clb.Ur(clb.ls(a.F,a.F.length));if(!dlb.efb(a.N,m)){l=false;for(j=(h=new dlb.Ceb(new dlb.Heb(new dlb.Wab(a.N.a).a).b),new dlb.cbb(h));dlb.H9(j.a.a);){i=(g=dlb.Aeb(j.a),g.hc());k=0;for(d=m,e=0,f=d.length;e<f;++e){c=d[e];while(k<i.length&&i[k]<c)++k;if(k<i.length){if(c==i[k]){l=true;break;}}}if(l)break;}if(!l){dlb.cfb(a.N,m);dlb.wi(a.D,clb.ls(a.F,a.F.length));!!a.b&&dlb.wi(a.a,clb.ms(a.B,a.B.length));}}}else if(b==6){m=clb.Vr(a,clb.ls(a.F,a.F.length));if(!dlb.efb(a.N,m)){dlb.cfb(a.N,m);dlb.wi(a.D,clb.ls(a.F,a.F.length));!!a.b&&dlb.wi(a.a,clb.ms(a.B,a.B.length));}}};clb.Jr=function Jr(a,b,c){var d,e,f,g,h,i,j,k,l,m;h=clb.wn(a.G,b);d=a.n[c];if(d>h)return false;j=clb.pk(a.G,b);f=clb.pk(a.g,c);e=clb.kk(a.g,c);i=clb.kk(a.G,b);if(z1(e1(f,1),0)){if(e!=null){if(z1(e1(j,1),0)){if(i==null)return false;if(!clb.$r(e,i))return false;}else {if(i!=null){if(clb.as(i,e))return false;}else {if(clb.Zr(clb.uk(a.G,b),e))return false;}}}}else {if(z1(e1(j,1),0))return false;if(e!=null){if(i!=null){if(!clb.$r(i,e))return false;}else {if(!clb.Zr(clb.uk(a.G,b),e))return false;}}else {if(i!=null)return false;if(a.I[b]!=a.j[c])return false;}}if(z1(B1(j,f),0)){if(z1(e1(f,lnb),0)){if(a.G.K&&o1(e1(j,lnb),0))return false;else if(d!=h)return false;}if(z1(e1(f,Imb),0)){if(d>=h&&o1(e1(j,Imb),0))return false;}}if(z1(e1(a.H[b],A1(a.i[c])),0))return false;if(z1(e1(a.A[c],A1(a.L[b])),0))return false;g=e1(f,kmb);if(a.G.K){k=e1(f,kmb);if(j1(k,0)!=0&&(j1(g,0)==0||z1(e1(g,A1(k)),0)))return false;}else {if(j1(g,0)!=0&&o1(e1(g,a.L[b]),0))return false;}if(clb.dk(a.g,c)!=0&&clb.dk(a.g,c)!=clb.dk(a.G,b))return false;if(clb.nk(a.g,c)!=0&&clb.nk(a.g,c)!=clb.nk(a.G,b))return false;if(clb.qk(a.g,c)!=0&&clb.qk(a.g,c)!=clb.qk(a.G,b))return false;l=I1(D1(e1(clb.pk(a.g,c),inb),22));if(l!=0){if(a.G.K){m=I1(D1(e1(clb.pk(a.G,b),inb),22));if(l!=m)return false;}else {if(clb.qn(a.G,b)!=l)return false;}}return true;};clb.Kr=function Kr(a,b,c){var d,e,f,g,h,i,j,k,l;j=a.J[b];g=a.k[c];if((clb.Jk(a.g,c)&Lnb)!=0){i=clb.Lk(a.G,b);e=clb.Lk(a.g,c);f=clb.Jk(a.g,c)&31;if(i!=e&&!(i==1&&(f&1)!=0)&&!(i==2&&(f&2)!=0)&&!(i==4&&(f&4)!=0)&&!(i==8&&(f&32)!=0)&&!(i==16&&(f&64)!=0)&&!(i==32&&(f&16)!=0)&&!(i==64&&(f&8)!=0))return false;j&=-32;g&=-32;}if((j&~g)!=0)return false;l=(clb.Jk(a.g,c)&Ymb)>>17;if(l!=0){if(a.G.K&&l==(clb.Jk(a.G,c)&Ymb)>>17)return true;d=false;k=clb.Xn(a.G);for(h=0;h<k.i.a.length;h++){if(dlb.Bi(k.j,h).length==l){if(clb.ur(k,h,b)){d=true;break;}}}if(!d)return false;}return true;};clb.Lr=function Lr(a){var b,c;a.b=null;for(b=0;b<a.g.g;b++){if(clb.bl(a.g,b)){!a.b&&(a.b=new dlb.Qi());c=new clb.ns();c.a=clb.zk(a.g,0,b);c.b=clb.zk(a.g,1,b);c.d=clb.Bk(a.g,b);c.c=clb.Ak(a.g,b);dlb.wi(a.b,c);}}};clb.Mr=function Mr(a){var b,c,d,e,f,g,h,i,j,k,l,m;clb.Gt(a.g,a.M);i=$wnd.Math.max(a.g.f,a.g.g)+16;a.r=gW(Ykb.AX,gmb,6,i,15,1);a.t=gW(Ykb.AX,gmb,6,i,15,1);a.u=gW(Ykb.AX,gmb,6,i,15,1);a.s=gW(Ykb.Z0,Amb,6,i+1,16,1);g=gW(Ykb.Z0,Amb,6,a.g.f,16,1);h=gW(Ykb.Z0,Amb,6,a.g.g,16,1);d=0;for(c=0;c<a.g.f;c++){if(!a.C[c]&&!g[c]){a.r[d]=c;a.u[d]=-1;a.t[d]=-1;j=d;while(d<=j){for(k=0;k<clb.hn(a.g,a.r[d]);k++)j=clb.is(a,d,j,k,g,h,-1);while(a.s[++d]);}}}a.v=d;if(a.o!=0){j=a.v-1;for(f=0;f<a.d;f++){d=0;while(d<=j){for(l=0;l<clb.hn(a.g,a.r[d]);l++)j=clb.is(a,d,j,l,g,h,f);while(a.s[++d]);}}for(b=0;b<a.g.f;b++){if(a.C[b]&&!g[b]){a.r[d]=b;a.u[d]=-1;a.t[d]=-1;j=d;while(d<=j){for(l=0;l<clb.hn(a.g,a.r[d]);l++)clb.vn(a.g,a.r[d],l)<a.g.f&&(j=clb.is(a,d,j,l,g,h,a.f[b]));while(a.s[++d]);}}}a.e=gW(Ykb.AX,gmb,6,a.d,15,1);for(m=0;m<a.d;m++)a.e[m]=-1;for(k=a.v;k<d;k++){e=a.f[a.r[k]];a.e[e]==-1&&(a.e[e]=k);}}a.w=d;};clb.Nr=function Nr(a,b){var c,d,e,f,g,h,i,j;j=clb.Xn(a.G);for(h=0;h<j.i.a.length;h++){if(clb.ur(j,h,b)){i=gW(Ykb.AX,gmb,6,2,15,1);for(e=0;e<2;e++){i[e]=Qlb;d=clb.zk(a.G,e,b);for(f=0;f<clb.wn(a.G,d);f++){c=clb.vn(a.G,d,f);c!=clb.zk(a.G,1-e,b)&&i[e]>c&&(i[e]=c);}}g=0;clb.tr(j,h,i[0])&&++g;clb.tr(j,h,i[1])&&++g;if(g==2)return 2;if(g==1)return 1;return 2;}}return 0;};clb.Or=function Or(a,b,c){var d,e,f,g,h;if(a.b){a.B=gW(Ykb.Z0,Amb,6,b.length,16,1);for(e=new dlb.Obb(a.b);e.a<e.c.a.length;){d=dlb.Nbb(e);if(a.f==null||c==-1&&a.f[d.a]==-1&&a.f[d.b]==-1||c!=-1&&(a.f[d.a]==c||a.f[d.b]==c)){h=gW(Ykb.AX,gmb,6,d.c+2,15,1);f=clb.Rn(a.G,h,a.F[d.a],a.F[d.b],d.c+1,b,null)-1;if(f<d.d||f>d.c)return false;for(g=1;g<=f;g++)a.B[h[g]]=true;}}}return true;};clb.Pr=function Pr(a,b){var c,d,e,f,g,h,i,j;for(e=0;e<a.g.g;e++){if((clb.Jk(a.g,e)&Inb)!=0){f=clb.Ik(a.g,e);if(f==0)continue;c=clb.zk(a.g,0,e);d=clb.zk(a.g,1,e);if(a.f==null||b==-1&&a.f[c]==-1&&a.f[d]==-1||b!=-1&&(a.f[c]==b||a.f[d]==b)){g=a.F[c];h=a.F[d];i=clb.tn(a.G,g,h);j=clb.Ik(a.G,i);if(j==0){clb.Co(a.G,i)&&(j=clb.Nr(a,i));if(j==0)continue;}if(f==3)continue;if(j==3)continue;if(clb.Wr(a,e)==(f==j))return false;}}}return true;};clb.Qr=function Qr(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p;g=0;for(i=0;i<a.g.f;i++){if((a.f==null||a.f[i]==b)&&z1(e1(clb.pk(a.g,i),knb),0)){m=a.F[i];l=clb.ok(a.g,i);o=clb.ok(a.G,m);if(l==0)continue;if(l==3)continue;if(o==0||o==3)return false;if(clb.ik(a.g,i)==1){++g;continue;}if(clb.ik(a.G,m)==1)return false;if(clb.ik(a.g,i)==2){++g;continue;}if(clb.ik(a.G,m)==2)return false;if(clb._r(a,i)==(l==o))return false;}}if(g!=0){e=gW(Ykb.AX,gmb,6,g,15,1);f=0;for(j=0;j<a.g.f;j++){if((a.f==null||a.f[j]==b)&&z1(e1(clb.pk(a.g,j),knb),0)){l=clb.ok(a.g,j);l!=0&&l!=3&&(e[f++]=clb.hk(a.g,j)<<24|clb.ik(a.g,j)<<22|j);}}alb.jgb(e,alb.Pgb(X1(dlb.ucb.prototype.kc,dlb.ucb,[])));f=0;while(f<e.length){k=e[f]&aob;n=a.F[k];c=e[f]&-4194304;d=clb._r(a,k)^clb.ok(a.g,k)==clb.ok(a.G,n);for(++f;f<e.length&&(e[f]&-4194304)==c;f++){h=e[f]&aob;m=a.F[h];if(clb.ik(a.G,m)!=clb.ik(a.G,n)||clb.hk(a.G,m)!=clb.hk(a.G,n))return false;p=clb._r(a,h)^clb.ok(a.g,h)==clb.ok(a.G,m);if(p!=d)return false;}}}return true;};clb.Rr=function Rr(a,b,c){var d,e,f,g,h,i,j;a.O=false;a.D=new dlb.Qi();a.a=new dlb.Qi();dlb.deb(a.N.a);if(!a.G||!a.g)return 0;if(a.g.f-a.o>a.G.f||a.g.g-a.p>a.G.g)return 0;if(a.g.f==0)return 0;b==6&&(a.M=63);clb.es(a,c);d=gW(Ykb.Z0,Amb,6,a.G.f,16,1);a.F=gW(Ykb.AX,gmb,6,a.g.f,15,1);dlb.Ybb(a.F);h=gW(Ykb.AX,gmb,6,a.w,15,1);dlb.bcb(h,h.length,-1);f=0;while(!a.O){if(a.v!=0){j=a.t[f]==-1?a.G.f:clb.hn(a.G,a.F[a.t[f]]);++h[f];if(h[f]==j){h[f]=-1;if(f==0)break;--f;a.s[f]||(d[a.F[a.r[f]]]=false);continue;}if(a.t[f]==-1){if(!d[h[f]]){if(clb.Jr(a,h[f],a.r[f])){a.F[a.r[f]]=h[f];d[h[f]]=true;++f;}}}else {if(clb.vn(a.G,a.F[a.t[f]],h[f])>=a.G.f)continue;e=clb.vn(a.G,a.F[a.t[f]],h[f]);if(a.s[f]){e==a.F[a.r[f]]&&clb.Kr(a,clb.xn(a.G,a.F[a.t[f]],h[f]),a.u[f])&&++f;}else {if(!d[e]){if(clb.Jr(a,e,a.r[f])&&clb.Kr(a,clb.xn(a.G,a.F[a.t[f]],h[f]),a.u[f])){d[e]=true;a.F[a.r[f]]=e;++f;}}}}}if(f==a.v){if(clb.Qr(a,-1)&&clb.Pr(a,-1)&&clb.Or(a,d,-1)){i=false;for(g=0;g<a.d;g++){if(clb.Xr(a,d,h,g)){i=true;break;}}if(b==1&&!i)return 1;if(!i){clb.Ir(a,b);if(b==2)return 1;}}if(f==0)break;--f;a.s[f]||(d[a.F[a.r[f]]]=false);}}return a.D.a.length;};clb.Sr=function Sr(a,b){var c,d,e,f,g,h,i,j;i=0;if(a.K){b<a.f&&clb.xr(a.p,b)?i=B1(i,xob):b<a.f&&clb.rr(a.p,b)&&(i=B1(i,2));j=(e=a.u[b]&bob,e==0?0:e==Nmb?2:e==lnb?3:4);if(j!=0){i=B1(i,8);j>2&&(i=B1(i,16));j>3&&(i=B1(i,32));}c=a.s[b];c<0?i=B1(i,Rmb):c>0&&(i=B1(i,Qmb));g=a.j[b];switch(g){case 0:break;case 1:i=B1(i,Gnb);break;case 2:i=B1(i,Xmb);break;case 3:i=B1(i,Ymb);break;default:i=B1(i,Zmb);}d=clb.ln(a,b);switch(d){case 0:break;case 1:i=B1(i,enb);break;case 2:i=B1(i,fnb);break;case 3:i=B1(i,gnb);break;default:i=B1(i,hnb);}h=a.o[b];h>0&&(i=B1(i,Hmb));h>1&&(i=B1(i,Ynb));}else {b<a.f&&clb.xr(a.p,b)?i=B1(i,xob):b<a.f&&clb.rr(a.p,b)?i=B1(i,2):i=B1(i,4);(a.u[b]&Xnb)!=0?i=B1(i,Jmb):i=B1(i,Kmb);j=(e=a.u[b]&bob,e==0?0:e==Nmb?2:e==lnb?3:4);j==0?i=B1(i,112):j==2?i=B1(i,104):j==3?i=B1(i,88):i=B1(i,56);c=a.s[b];c==0?i=B1(i,Pmb):c<0?i=B1(i,Rmb):c>0&&(i=B1(i,Qmb));f=a.e[b]-clb.On(a,b)+clb.Kn(a,b);switch(f){case 0:i=B1(i,1792);break;case 1:i=B1(i,1664);break;case 2:i=B1(i,1408);break;default:i=B1(i,896);}g=a.j[b];switch(g){case 0:i=B1(i,3932160);break;case 1:i=B1(i,3801088);break;case 2:i=B1(i,Umb);break;case 3:i=B1(i,Vmb);break;default:i=B1(i,Zmb);}d=clb.ln(a,b);switch(d){case 0:i=B1(i,_mb);break;case 1:i=B1(i,anb);break;case 2:i=B1(i,bnb);break;case 3:i=B1(i,cnb);break;default:i=B1(i,hnb);}h=a.o[b];switch(h){case 0:i=B1(i,98304);break;case 1:i=B1(i,81920);break;default:i=B1(i,49152);}}return i;};clb.Tr=function Tr(a,b){var c;c=0;if(b<a.g&&(clb.wr(a.p,b)||a.H[b]==64)||a.H[b]==64)c|=8;else switch(clb.Hk(a,b)){case 4:case 0:c|=32;break;case 1:c|=1;break;case 2:c|=2;break;case 3:c|=4;break;case 5:c|=64;}(a.F[b]&64)!=0?c|=256:a.K||(c|=128);b<a.g&&clb.sr(a.p,b)?c|=Wmb:a.K||(c|=yob);return c;};clb.Ur=function Ur(a){var b,c,d,e,f,g,h,i,j,k;i=0;for(d=a,f=0,h=d.length;f<h;++f){b=d[f];b==-1&&++i;}if(i!=0){k=a;a=gW(Ykb.AX,gmb,6,k.length-i,15,1);j=0;for(c=k,e=0,g=c.length;e<g;++e){b=c[e];b!=-1&&(a[j++]=b);}}alb.jgb(a,alb.Pgb(X1(dlb.ucb.prototype.kc,dlb.ucb,[])));return a;};clb.Vr=function Vr(a,b){var c,d,e,f,g,h,i,j;g=0;for(d=b,e=0,f=d.length;e<f;++e){c=d[e];c==-1&&++g;}j=gW(Ykb.AX,gmb,6,b.length-g,15,1);i=0;for(h=0;h<b.length;h++){if(b[h]!=-1){j[i]=clb.Rt(a.g,h)<<16|clb.Rt(a.G,b[h]);++i;}}alb.jgb(j,alb.Pgb(X1(dlb.ucb.prototype.kc,dlb.ucb,[])));return j;};clb.Wr=function Wr(a,b){var c,d,e,f,g,h,i,j,k,l,m,n;f=false;for(e=0;e<2;e++){c=clb.zk(a.g,e,b);k=a.F[c];if(clb.wn(a.G,k)>2){m=clb.zk(a.g,1-e,b);i=Qlb;for(h=0;h<clb.wn(a.g,c);h++){d=clb.vn(a.g,c,h);d!=m&&i>d&&(i=d);}n=a.F[m];j=Qlb;for(g=0;g<clb.wn(a.G,k);g++){l=clb.vn(a.G,k,g);l!=n&&j>l&&(j=l);}a.F[i]!=j&&(f=!f);}}return f;};clb.Xr=function Xr(a,b,c,d){var e,f,g,h,i,j,k,l;h=a.e[d];i=h+1;while(i<a.w&&a.f[a.r[i]]==d)++i;for(k=h;k<i;k++)c[k]=-1;g=h;while(true){l=a.t[g]==-1?a.G.f:clb.hn(a.G,a.F[a.t[g]]);++c[g];if(c[g]==l){c[g]=-1;if(g==h)break;--g;if(!a.s[g]){b[a.F[a.r[g]]]=false;a.F[a.r[g]]=-1;}continue;}if(a.t[g]==-1){if(!b[c[g]]){if(clb.Jr(a,c[g],a.r[g])){a.F[a.r[g]]=c[g];b[c[g]]=true;++g;}}}else {if(clb.vn(a.G,a.F[a.t[g]],c[g])>=a.G.f){++c[g];continue;}f=clb.vn(a.G,a.F[a.t[g]],c[g]);if(a.s[g]){f==a.F[a.r[g]]&&clb.Kr(a,clb.xn(a.G,a.F[a.t[g]],c[g]),a.u[g])&&++g;}else {if(!b[f]){if(clb.Jr(a,f,a.r[g])&&clb.Kr(a,clb.xn(a.G,a.F[a.t[g]],c[g]),a.u[g])){b[f]=true;a.F[a.r[g]]=f;++g;}}}}if(g==i){if(clb.Qr(a,d)&&clb.Pr(a,d)&&clb.Or(a,b,d)){for(j=h;j<i;j++){if(!a.s[j]){e=a.r[j];b[a.F[e]]=false;a.F[e]=-1;}}return true;}--g;if(!a.s[g]){b[a.F[a.r[g]]]=false;a.F[a.r[g]]=-1;}}}return false;};clb.Yr=function Yr(a){return clb.Rr(a,1,a.c)>0;};clb.Zr=function Zr(a,b){var c;for(c=0;c<b.length;c++)if(b[c]==a)return true;return false;};clb.$r=function $r(a,b){var c,d,e;e=0;for(d=0;d<a.length;d++){c=a[d];while(b[e]<c){++e;if(e==b.length)return false;}if(b[e]>c)return false;}return true;};clb._r=function _r(a,b){var c,d,e,f,g,h,i,j;g=false;if(clb.mn(a.g,b)==0){for(f=1;f<clb.wn(a.g,b);f++){for(h=0;h<f;h++){d=clb.vn(a.g,b,f);e=clb.vn(a.g,b,h);a.F[d]>a.F[e]^d>e&&(g=!g);}}}else {for(f=0;f<clb.wn(a.g,b);f++){c=clb.vn(a.g,b,f);j=0;i=gW(Ykb.AX,gmb,6,3,15,1);for(h=0;h<clb.wn(a.g,c);h++){i[j]=clb.vn(a.g,c,h);i[j]!=b&&++j;}j==2&&a.F[i[0]]>a.F[i[1]]^i[0]>i[1]&&(g=!g);}}return g;};clb.as=function as(a,b){var c,d,e,f;e=0;f=0;while(e<a.length&&f<b.length){c=a[e];d=b[f];if(c==d)return true;c<d?++e:++f;}return false;};clb.bs=function bs(a,b){var c,d,e,f,g;if(!b||b.q==0||!b.K){a.g=null;return;}a.g=b;a.q=false;clb.Gt(a.g,1);a.M=7;for(d=0;d<a.g.f;d++)z1(e1(clb.pk(a.g,d),{l:knb,m:0,h:3}),0)&&(a.M=15);for(g=0;g<a.g.g;g++)(clb.Jk(a.g,g)&Inb)!=0&&(a.M=15);a.K&&a.M!=7&&clb.Gt(a.G,a.M);a.o=0;a.p=0;a.C=gW(Ykb.Z0,Amb,6,a.g.f,16,1);for(e=0;e<a.g.f;e++){a.C[e]=z1(e1(clb.pk(a.g,e),Bmb),0);a.C[e]&&++a.o;}a.d=0;a.f=null;if(a.o!=0){if(a.o!=0)for(f=0;f<a.g.g;f++)(a.C[clb.zk(a.g,0,f)]||a.C[clb.zk(a.g,1,f)])&&++a.p;for(c=0;c<a.g.q;c++)clb.Rl(a.g,c,a.C[c]);a.f=gW(Ykb.AX,gmb,6,a.g.q,15,1);a.d=clb.En(a.g,a.f,true,false);}};clb.cs=function cs(a,b,c){clb.ds(a,c);clb.bs(a,b);};clb.ds=function ds(a,b){if(!b||b.q==0){a.G=null;return;}a.G=b;a.K=false;clb.Gt(a.G,1);};clb.es=function es(a,b){if(!a.K){clb.hs(a,b);a.K=true;}if(!a.q){clb.fs(a,b);clb.Mr(a);clb.Lr(a);a.q=true;}};clb.fs=function fs(a,b){var c,d,e,f,g,h,i,j,k,l;f=null;i=null;g=null;clb.Gt(a.g,a.M);a.n=gW(Ykb.AX,gmb,6,a.g.f,15,1);for(d=0;d<a.g.f;d++)a.n[d]=clb.wn(a.g,d);if(a.o!=0){j=new clb.Zt(a.g.q,a.g.r);l=gW(Ykb.Z0,Amb,6,a.g.q,16,1);for(e=0;e<a.g.q;e++)l[e]=!a.C[e];clb.Zm(a.g,j,l,true,null);clb.Gt(j,a.M);clb.gs(a,j,b);f=a.i;i=a.k;g=a.j;k=0;for(c=0;c<a.g.f;c++)a.C[c]||(a.n[c]=clb.wn(j,k++));}clb.gs(a,a.g,b);if(a.o!=0){k=0;for(c=0;c<a.g.q;c++){if(!a.C[c]){a.i[c]=f[k];a.j[c]=g[k++];}}k=0;for(h=0;h<a.g.r;h++){!a.C[clb.zk(a.g,0,h)]&&!a.C[clb.zk(a.g,1,h)]&&(a.k[h]=i[k++]);}}};clb.gs=function gs(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s;p=b.f;a.i=gW(Ykb.BX,Anb,6,b.f,14,1);a.j=gW(Ykb.AX,gmb,6,b.f,15,1);for(h=0;h<p;h++){a.i[h]=K1(e1(B1(clb.Sr(b,h),b.B[h]),zob),Aob);a.j[h]=b.C[h];(c&1)!=0&&(a.j[h]+=b.s[h]+16<<8);(c&2)!=0&&(a.j[h]+=b.A[h]<<16);}a.A=gW(Ykb.BX,Anb,6,b.f,14,1);r=(clb.Gt(b,7),b.p);for(o=0;o<r.i.a.length;o++){n=false;for(j=dlb.Bi(r.j,o),k=0,l=j.length;k<l;++k){m=j[k];if((b.G[m]&nnb)!=0){n=true;break;}}if(!n){s=dlb.Bi(r.j,o).length;for(e=dlb.Bi(r.i,o),f=0,g=e.length;f<g;++f){d=e[f];s==3?a.A[d]=B1(a.A[d],mmb):s==4?a.A[d]=B1(a.A[d],nmb):s==5?a.A[d]=B1(a.A[d],omb):s==6?a.A[d]=B1(a.A[d],pmb):s==7&&(a.A[d]=B1(a.A[d],qmb));}}}q=b.g;a.k=gW(Ykb.AX,gmb,6,b.g,15,1);for(i=0;i<q;i++){a.k[i]=(clb.Tr(b,i)|b.G[i])&6291967^6291840;(c&4)!=0?(a.k[i]&2)!=0&&(a.k[i]|=8):(c&8)!=0&&(a.k[i]&2)!=0&&i<b.g&&clb.sr(b.p,i)&&(a.k[i]|=8);}};clb.hs=function hs(a,b){var c,d,e,f,g,h,i,j,k,l,m,n;clb.Gt(a.G,a.M);k=a.G.f;a.I=gW(Ykb.AX,gmb,6,k,15,1);a.H=gW(Ykb.BX,Anb,6,k,14,1);for(g=0;g<k;g++){a.H[g]=K1(e1(B1(clb.Sr(a.G,g),clb.pk(a.G,g)),zob),Aob);a.I[g]=clb.uk(a.G,g);(b&1)!=0&&(a.I[g]+=clb.dk(a.G,g)+16<<8);(b&2)!=0&&(a.I[g]+=clb.nk(a.G,g)<<16);}a.L=gW(Ykb.BX,Anb,6,k,14,1);m=clb.Xn(a.G);for(j=0;j<m.i.a.length;j++){n=dlb.Bi(m.j,j).length;for(d=dlb.Bi(m.i,j),e=0,f=d.length;e<f;++e){h=d[e];n==3?a.L[h]=B1(a.L[h],mmb):n==4?a.L[h]=B1(a.L[h],nmb):n==5?a.L[h]=B1(a.L[h],omb):n==6?a.L[h]=B1(a.L[h],pmb):n==7&&(a.L[h]=B1(a.L[h],qmb));}}for(c=0;c<k;c++){n=clb.qn(a.G,c);n==0?a.L[c]=B1(a.L[c],lmb):n>7&&(a.L[c]=B1(a.L[c],rmb));}l=a.G.g;a.J=gW(Ykb.AX,gmb,6,l,15,1);for(i=0;i<l;i++)a.J[i]=(clb.Tr(a.G,i)|clb.Jk(a.G,i))&6422527^6291840;};clb.is=function is(a,b,c,d,e,f,g){var h,i;h=clb.vn(a.g,a.r[b],d);if((!a.C[h]||a.f[h]==g)&&h!=a.t[b]){i=clb.xn(a.g,a.r[b],d);if(!f[i]&&!clb.bl(a.g,i)){a.r[++c]=h;a.t[c]=a.r[b];a.u[c]=i;f[i]=true;e[h]?a.s[c]=true:e[h]=true;}}return c;};clb.js=function js(){this.c=8;this.N=new dlb.ifb(new slb.NT());};clb.ks=function ks(){this.c=1;this.N=new dlb.ifb(new slb.NT());};clb.ls=function ls(a,b){var c;c=gW(Ykb.AX,gmb,6,b,15,1);Zkb.P5(a,0,c,0,$wnd.Math.min(a.length,b));return c;};clb.ms=function ms(a,b){var c;c=gW(Ykb.Z0,Amb,6,b,16,1);Zkb.P5(a,0,c,0,$wnd.Math.min(a.length,b));return c;};U1(63,1,{},clb.js,clb.ks);_.c=0;_.d=0;_.o=0;_.p=0;_.q=false;_.v=0;_.w=0;_.K=false;_.M=0;_.O=false;Ykb.lY=w3(63);clb.ns=function ns(){};U1(168,1,{168:1},clb.ns);_.a=0;_.b=0;_.c=0;_.d=0;Ykb.jY=w3(168);clb.qs=function qs(){clb.qs=W1;clb.os=oW(aW(Ykb.l_,1),Xlb,2,6,['QM@HzAmdqjF@','RF@Q``','qC`@ISTAlQE`','`J@H','QM@HzAmdqbF@','qC`@ISTAlQEhqPp@','sJP@DiZhAmQEb','RF@QPvR@','QM@HzA@','qC`@ISTAlQEhpPp@','qC`@Qz`MbHl','sJP@DiZhAmQEcFZF@','RFPDXH','qC`@IVtAlQE`','QM@HvAmdqfF@','sGP@DiVj`FsDVM@','`L@H','sJP@DizhAmQEcFBF@','sJP@DjvhAmQEb','sFp@DiTt@@AlqEcP','sGP@LdbMU@MfHlZ','QMHAIhD','QM@HzAy@','sJP@DkVhAmQEb','sNp@DiUjj@[\\QXu`','sJP@DiZhAmQEcFBF@','sGP@DjVj`FsDVM@','RFPDTH','RG@DXOH@','sGP@Divj`FsDVMcAC@','sGP@Dj}j`FsDVM@','qC`@Qz`MbHmFRF@','sNp@LdbJjj@[\\QXu`','QMHAIhGe@','QM@HzAyd`','QM`AIhD','qC`@ISTA@','sGP@DkUj`FsDVM@','qC`@IVtAlQEhqPp@','sNp@DiUjj@[\\QXuqea`@','KAx@@IRjuUPAlHPfES\\','QM`BN`P','sJP@DjZhAmQEcFJF@','Hid@@DjU^nBBH@FtaBXUMp`','sNp@Diujj@[\\QXuq`a`@','sJP@DjvhAmQEcFZF@','sJP@DjZhAmQEcFFF@','sOp@DjWkB@@FwDVM\\YhX@','sNp@Dj}Zj@[\\QXu`','sNp@DiWjj@[\\QXuq`a`@','sOp@DjWkB@@D','KAx@@ITouUPAlHPfES\\','KAx@@YIDTjjh@vDHSBin@','sNp@DkUZj@[\\QXu`','RFPDXOH@','QM`BN`^L`','qC`@ISTAy@','sGP@LdbMU@MfHl[FVF@','qCb@AIZ`H','KAx@@IRjuUPAlHPfES]FFa`@','KAx@@ITnuUPAlHPfES\\','HiD@@DiUVjj`AmHPfES\\H','sNp@DjUjj@[\\QXu`','sJP@DkVhAmQEcFJF@','sGP@DjVj`FsDVMcCC@','qC`@Qz`MbHmFBF@','sJP@DkfhAmQEb','qC`@IVtAlQEhsPp@','sGP@Djuj`FsDVM@','sGP@Dj}j`FsDVMcMC@','sJP@DiZhA@','KAx@@ISjuUPAlHPfES]F@a`@','sJP@DjZhAmQEcFRF@','KAx@@IRnuUPAlHPfES]F@a`@','HiD@@DjWvjj`AmHPfES\\H','QMHAIhGd@','sNp@DiUjj@[\\QXuq`a`@','KAx@@IVjmUPAlHPfES\\','sGP@DjVj`FsDVMcMC@','QM`AIhGe@','HiD@@LdbJRjjh@[RDIaTwB','qCp@AIZ`H','sGP@LdbMU@MfHl[FFF@','QMDARVA@','sNp@LdbJjj@[\\QXuqba`@','sNp@LdbJjj@[\\QXuqca`@','sGP@Dkej`FsDVM@','qCb@AIZ`OI@','HaD@@DjUZxHH@AlHPfES]FLa`@','sGP@DkYj`FsDVM@','qCb@AIV`H','sNp@LdbJjj@[\\QXuqea`@','sGP@DkUj`FsDVMcEC@','sFp@DiTt@@Axa@','Hmt@@DjU_ZxHHj@AmhPfES\\Lj','QM`BN`^P','qCb@AIZ`OH`','sFp@DiTt@@AxaP','sGP@Djuj`FsDVMcEC@','sGP@Djuj`FsDVMcIC@','sGP@DkUj`FsDVMcKC@','sJP@DkfhAmQEcFRF@','sGP@DjVj`FsDVMcIC@','HaD@@DjUZxHH@AlHPfES]FFa`@','qC`@IRtDVqDV@','sNp@Dj}Zj@[\\QXuqfa`@','KAx@@ITnuUPAlHPfES]FFa`@','HiD@@DkUUjj`AmHPfES\\H','sJQ@@dkU@H','qC`@Qz`H','KAx@@IUkmUPAlHPfES\\','KAx@@ITouUPAlHPfES]FJa`@','sJP@H~j@[TQX`','sGP@DjZj`FsDVM@','sJP@DkVhAmQEcFFF@','sJX@@eKU@H','sJP@DizhAy@','QMHAIhGbP','KAx@@ITouUPAlHPfES]FNa`@','HaD@@DjUZxHD@AlHPfES\\','HaD@@DjUZxHH@A@','sNp@LdbJjj@[\\QXuqaa`@','Hed@@LdbRQUUUP@vTHSBinFP','KAx@@ITouUPAlHPfES]FLa`@','sNp@DkUZj@[\\QXuqba`@','KAx@@ITjuUPAlHPfES]FNa`@','KAx@@YIDTjjh@vDHSBincGPp@','HaD@@DjYvxH`@AlHPfES]FLa`@','RF@QP`','qCb@AIj`H','sNp@DjUjj@[\\QXuqaa`@','sNp@DkVZj@[\\QXu`','KAx@@YIDUJjh@vDHSBin@','sGP@DkYj`FsDVMcIC@','sGP@DjVj`FsDVMcAC@','sGP@DiVj`D','sJP@DkVhAmQEcFZF@','sNp@LdbLjj@[\\QXu`','QM@HvAmdqbF@','HaD@@DjWjXHB@AlHPfES\\','sNp@DjwZj@[\\QXuqba`@','sNp@LdbJjj@[\\QXuqda`@','sFp@DiTt@@Axa`','HiD@@Djuujj`AmHPfES\\H','sNp@DkUZj@[\\QXuqca`@','sJP@DiZhAy@','KAx@@YIDTjjh@vDHSBincCPp@','KAx@@IWNmUPAlHPfES\\','KAx@@IVkMUPAlHPfES\\','sJQ@@dju@H','qCb@AIZ`OH@','qC`@ISTAxa@','sNp@DjyZj@[\\QXu`','Hid@@DjUfaBB`@FtaBXUMp`','HiD@@DiUVjj`AmHPfES\\LXBF@','KAx@@IUjmUPAlHPfES\\','HiD@@DjWvjj`AmHPfES\\LXjF@','sJP@DjVhAmQEb','qCb@AIV`OH`','HiD@@LdbJRjjh@[RDIaTwCFDa`@','KAx@@YIDTjjh@vDHSBinc@Pp@','sNp@DjUjj@[\\QXuqda`@','qC`@Qz`OED','sJP@DkfhAmQEcFZF@','KAx@@YIDbjjh@vDHSBincDPp@','sGP@Djyj`FsDVMcMC@','KAx@@IVrmUPAlHPfES\\','qCp@AIZ`OI@','sJX@@dkU@H','sJQ@@dkU@OH`','sNp@Di]ZjBBvxbqk@','Hkl@@DjU_Uk``bj`@[VDIaTwCJzX','sGP@DjZj`FsDVMcEC@','Hid@@DjU^nBBH@FtaBXUMpqcHX@','sNp@DkeZj@[\\QXu`','sNp@DjYjj@[\\QXuqca`@','sGQ@@djuT@`','HiD@@LdbJTjjh@[RDIaTwB','sOp@DjWkB@@Gd`','HeT@@LdbbRKBDQD@CYPaLJfxY@','qCr@XIKTA@','HiD@@DjW^jj`AmHPfES\\LXJF@','HeT@@DjU]k``b`@[JDIaTwCH','sGP@Djuj`FsDVMcCC@','`IH`B','sOp@DjWkB@@GdX','sJQ@@eKU@H','KAx@@YIDUJjh@vDHSBincBPp@','sJX@@eKU@OH@','KAx@@YIDTjjh@vDHSBincAPp@','sOq@@drm\\@@@`','KAx@@IUkMUPAlHPfES\\','qCp@AIj`H','Hed@@DjUUjjj@FraBXUMpr','sGX@@eJuT@`','sGP@DkUj`FsDVMcCC@','HiD@@Dj}Ujj`AmHPfES\\LXrF@','KAx@@ITouUPAlHPfES]FHa`@','Hed@@DjWujjj@FraBXUMpsFIa`@','sGP@DiUj``mfHlZ','sFp@DiTvjhAlqEcP','Hid@@DjU^nBBH@FtaBXUMpq`XX@','sJP@DkVdAmQEb','qCp@AIZ`OH`','QMhDRVA@','qC`@ISJAlQE`','qCp@BOTAyhl','sJX@@eOU@ODB','sFp@DiTt@@AyaB','sGP@DkUj`FsDVMcMC@','Hid@@DjYUaBH`@FtaBXUMpqcHX@','qC`@Qz`OH@','HiD@@DjUVjj`AmHPfES\\LXZF@','sJP@H~j@[TQXqda`@','sJX@@eKU@OI@','sNp@Djejj@[\\QXu`','sJQ@@dsU@H','sJQ@@dkU@OI`','KAx@@YIMDVjh@vDHSBin@','Hid@@DjU^nBBD@FtaBXUMp`','sNp@DkgZj@[\\QXuqca`@','qC`@IRtDVqDVcEC@','Hed@@LdbRQeUUP@vTHSBinFP','sNp@DiUjj@P','qC`@IRtDT','sNp@DkYZj@[\\QXuqca`@','KAx@@IUkmUPAlHPfES]FDa`@','KAx@@IVjmUPAlHPfES]FNa`@','sOx@@drm\\@@@`','KAx@@ITjuUPAlHPfES]FBa`@','QMDARVAyH','sJP`@dfvhA@','HeT@@DjU_k``b`@[JDIaTwCLXfF@','KAx@@IToUUPAlHPfES]FJa`@','sGP@DkYj`FsDVMcEC@','qCb@AIZ`ODH','`I@`B','KAx@@IUzmUPAlHPfES]FFa`@','sNp@DkfZj@[\\QXu`','KAx@@ITnuUPAlHPfES]F@a`@','HiD@@LddURjjh@[RDIaTwB','sNp@Dj~Zj@[\\QXuqfa`@','Hed@@Dj{uZjj@FraBXUMpr','KAx@@ITsUUPAlHPfES\\','Hid@@LdbRQk``b@AmHPfES\\LXrF@','sOp@DjWkB@@GdH','sJQ@@dkU@OH@','Hid@@DjU^nBBH@FtaBXUMpqahX@','sGP@DiYj``mfHlZ','KAx@@IToUUPAlHPfES]FLa`@','qCp@AJZ`ODH','Hmt@@DjU]ZxHHj@AmhPfES\\Lj','sGP@DkUjPFsDVM@','qC`@IVtA@','Hed@@LdbJReUUP@vTHSBinFP','sNp@DjuZj@[\\QXuqea`@','KAx@@IUkmUPAlHPfES]FNa`@','HiD@@DkVUjj`AmHPfES\\H','Hed@@DkUeZjj@FraBXUMpr','sNp@DkVZj@[\\QXuqea`@','sJP@DiVhHKZbKFLLL@','HiD@@Djuyjj`AmHPfES\\H','sNp@DjUjj@[\\QXuq`a`@','HeT@@DjYUXPbH`@[JDIaTwCH','HiD@@DjwUjj`AmHPfES\\LXRF@','sNq@@djmUPB','KAx@@YIEEZjh@vDHSBincCPp@','sGP@Di^V`dmfHlZ','Hid@@DjYUaBHP@FtaBXUMp`','sNp@DjYjj@[\\QXuqba`@','sGP@Dkej`FsDVMcKC@','HeT@@DjU^k``b`@[JDIaTwCH','qC`@Qv`MbHmFBF@','sGQ@@djmT@`','qCr@XIKTAyH','qC`@IVtAlQEhpPp@','Hid@@LdbbQxXF@@AmHPfES\\LXjF@','sGP@DkYj`FsDVMcCC@','KAx@@IVsMUPAlHPfES\\','qCp@AIj`ODl','HiD@@DkeUjj`AmHPfES\\H','deT@@DjU[k``b`@vTHSBinFP','sJP@DkVdAmQEcFRF@','HiD@@LdbJTjjh@[RDIaTwCFDa`@','HiD@@DkYyjj`AmHPfES\\H','sJP@DjZhAyH','KAx@@IVkMUPAlHPfES]FDa`@','sJX@@dkU@OI@','Hed@@LdbRQUUUP@vTHSBinFXpLL@','Hed@@DjuUZjj@FraBXUMpr','sGP@Djfj`FsDVMcKC@','sNp@DkVZj@[\\QXuqba`@','sNp@DjyZj@[\\QXuqfa`@','qCb@AIj`OH@','sNp@DjUZj@[\\QXu`','KAx@@IWOMUPAlHPfES\\','Hid@@DjU^nBBH@D','Hed@@DjuvZjj@FraBXUMpr','sJP@DiVhHKZbKFLtL@','dmt@@DjU_ZxHHj@C[PaLJfxYVLKC@','sNp@DjuZj@[\\QXuqca`@','sJP@DkfhAmQEcFJF@','sNp@LdbJZj@[\\QXu`','HeT@@DjU_k``b`@[JDIaTwCLXFF@','KAx@@IVlmUPAlHPfES]FNa`@','HeT@@LdbbRKBDQD@CYPaLJfxYcEPp@','Hid@@DjUZnBBH@FtaBXUMpqcHX@','qCa@CIKTA@','HiD@@Dj~]jj`AmHPfES\\LXFF@','sKP@Di\\Zj@[TQX`','sGP@Djfj`FsDVMcEC@','HiD@@DkgYjj`AmHPfES\\H','sNp@DjuZj@[\\QXuqaa`@','KAx@@YIMDVjh@vDHSBincDPp@','sJP@DjVhHKZbKFLTL@','Hid@@LdbRQk``b@AmHPfES\\LXZF@','HiD@@Dj}Ujj`AmHPfES\\LXzF@','HeT@@DjU_k``bP@[JDIaTwCH','sNp@DkUZi@[\\QXu`','HiD@@DjYfjj`AmHPfES\\H','sGP@DjZj`FsDVMcAC@','Hmt@@DjU_jxHHj@AmhPfES\\Lj','Hid@@LdbRQk``R@AmHPfES\\H','KAx@@YIDUJjh@vDHSBincDPp@','qCr@XIKTAyD','sOq@@drm\\@@@|`@','Hed@@DjW^jjj@FraBXUMpsFBa`@','HeT@@DjY]zXFB@@[JDIaTwCH','Hkl@@DjU_Vk``bj`@[VDIaTwCJzX','Hid@@DjY}nBHH@FtaBXUMpqcHX@','sGX@@eKuT@|d@','sGP@Dj^Y`FsDVM@','HcL@@DjU_ZnBBJh@FqaBXUMprn`','sJP@DkVdAmQEcFJF@','sOq@@drm\\@@@|b@','sNp@DjyZj@[\\QXuqaa`@','HaD@@DjUZxHH@AyD@','qC`@Qv`H','dmt@@DjU_ZxHHj@C[PaLJfxYVLYC@','sGP@Dkej`FsDVMcMC@','Hed@@DjUUjjj@FraBXUMpsFHa`@','HeT@@LdbbRkBDQD@CYPaLJfxY@','KAx@@IU{MUPAlHPfES]FLa`@','RG@DTH','sJY@DDeVhA@','KAx@@YIDUJjh@vDHSBinc@Pp@','sJX@@dkU@OI`','sJQ@@dju@OI`','HeT@@LdbbRKBDQD@CYPaLJfxYcFPp@','sFp@DiTvjhAlqEcXpPp@','HaD@@DjUZxHH@AyG@','sNx@@eJ}UPB','sNp@LddUjj@[\\QXuqca`@','HaDH@@RVU[j@@@D','sNp@DkgZi@[\\QXu`','sGY@LDeVj`D','sNp@LdbJfZBZvxbqk@','sJP`@dfvhAyL','sGX@AddQjhAxe`','Hmt@@DjU_ZxHHj@AmhPfES\\LkFIa`@','qCh@CIKTA@','sNp@LdbLjj@[\\QXuq`a`@','sOq@@drm\\@@@|a@','KAx@@IUzmUPAlHPfES]FJa`@','sNx@AddQUUPB','sGP@Di]jP`mfHlZ','sJP`@TeZhA@','KAx@@IRjmUPHKXPaLJfx','HeT@@LdbRTM\\DDT@CYPaLJfxY@','HaF@@@Rfu[j@@@D','Hid@@DjYUaBH`@FtaBXUMpqchX@','KAx@@IUjmTpAlHPfES\\','Hid@@DjU^nBBD@FtaBXUMpqcHX@','sGP@DiUj``mfHl[FFF@','KAx@@IUvmUPAlHPfES]FLa`@','Hed@@LdbQTUUUP@vTHSBinFXqDL@','sJP@DkVhA@','sOx@@drm\\@@@|b@','KAx@@IUkMUPAlHPfES]FDa`@','HeT@@LdbRQU\\DDT@CYPaLJfxY@','HiD@@Dj}Yjj`AmHPfES\\LXrF@','HiD@@Dj{ujj`AmHPfES\\LXFF@','KAx@@IWNmUPAlHPfES]FFa`@','KAx@@IRkMUPHKXPaLJfx','sJP@DjYdAmQEcFZF@','sJY@LDeZhAyL','HaDH@@RVU[f@@@D','sJP`@deVhAyB','HaD@@DjWjZjj`AlHPfES\\','sGP@DkYj`FsDVMcMC@','sNp@DkgZj@[\\QXuqea`@','sJQ@@dlu@H','HeT@@DjU]k``b`@[JDIaTwCLXrF@','sJX@@dkU@OH`','RFDDQFCr`','sJP@DiYXIKZbKFLLL@','KAx@@YIHjjjh@vDHSBincGPp@','Hk\\@@DjU^ukmLHH@@@AmXPfES\\Lki`','sGQ@@djmT@|b@','Hid@@DjUfaBB`@FtaBXUMpqahX@','sNx@@eRmUPB','Hmt@@LdbRVak``ah@FvaBXUMprh','qCr@XIJtA@','KAx@@IWMmUPAlHPfES]FNa`@','HeT@@DjYYZPbJ@@[JDIaTwCH','sNp@DkfZj@[\\QXuqea`@','Hid@@DjU^nBAHAEVtaBXUMp`','dmt@@DjUgZDHJJ@C[PaLJfxYT','sGP@DkejPFsDVM@','sNx@@eJmUPB','qCb@AIf`H','HcL@@DjU_VnBBJh@FqaBXUMprnqcXX@','Hid@@DjUZnBBH@FtaBXUMpqahX@','sNp@LdbQZjBBvxbqkcGC@','sOx@@drm\\@@@|c@','sJP@H~j@^R@','KAx@@YIDcFjhDElHPfES\\','Hid@@DjUZnBAH@FtaBXUMp`','sNp@LddUji@[\\QXu`','sGP@DjfjPFsDVM@','HeT@@DjYUXPbD`@[JDIaTwCH','KAx@@IUoMUPAlHPfES]FDa`@','sFp@DiTt@@AyaD','Hed@@DjuuZjj@FraBXUMpsFIa`@','HeT@@DjUghP`h`@[JDIaTwCLXfF@','sOp@DjWkjj`FwDVM\\YhX@','sGP@Djfj`FsDVMcIC@','KAx@@IRkmUPHKXPaLJfzL]C@','sNx@@djmUPB','QM`AIdD','sOp@DjWkB@@Gbe@','sNp@DjyZj@[\\QXuqca`@','QM@HuAmd`','sNp@LddUjj@[\\QXuqea`@','daD@@DjUZxHD@CXPaLJfzLYC@','qCb@AIZPH','HiD@@LdbJTjjh@[RDIaTwCF@a`@','Hmt@@DjU_ZxHHi@AmhPfES\\Lj','HaDH@@RYWih@H@D','HiD@@LdbJTjjh@[RDIaTwCFHa`@','sGX@@djuT@|a@','sNp@DkfZj@[\\QXuqaa`@','Hid@@DjU^nBBH@GdL','KAx@@IVkMUPAlHPfES]FJa`@','qCr@XIKTAy@','HmT@@Dj{uVjjh@[ZDIaTwCJqaXX@','dmt@@DjYWVDHbJ@C[PaLJfxYT','Hif@@@RUe^Fh@@@P','HaDH@@Rfu[j@@@GdH','KAx@@IVsMUPAlHPfES]FDa`@','sKP@Di\\Zj@[TQXq`a`@','sJX@@eMU@OH@','HeT@@DjU^k``b`@[JDIaTwCLXFF@','Hmt@@LdbbRJXPbHh@FvaBXUMprh','sJP@DjvhAmQEcFBF@','dmt@@LdbbRNXPbHh@MmBDpj[aeXplL@','sJP`@dfvhAyD','sGP@Di^V`dmfHl[FVF@','KAx@@IVsmUPAlHPfES]FBa`@','sOq@@drm\\@@@|PP','sJY@BDeZhA@','HeT@@LdbRbmBDED@CYPaLJfxY@','Hed@@Djy[Zjj@FraBXUMpr','HeT@@DjU]k``b`@[JDIaTwCLXFF@','Hid@@DjUfaBB`@D','qCa@CIJtA@','QMPARVA@','Hid@@DjUfaBB`@FtaBXUMpqcHX@','sJY@BDfZhA@','HeT@@DjUghP`hP@[JDIaTwCH','Hed@@Dj{uZjj@FraBXUMpsFIa`@','dmt@@DjYUvDHbJ@C[PaLJfxYVLUC@','sNp`@dfuZj@P','sJQ@@dmU@OH@','sJX@@dmU@H','HeT@@DjU]k``b`@[JDIaTwCLXZF@','HiD@@LdfbJZjh@[RDIaTwCFAa`@','sOx@@drm\\@@@|a@','deT@@DjUfhP`h`@vTHSBinFP','dmt@@DjU]ZxHHj@C[PaLJfxYVLKC@','sOp@DjWkjj`FwDVM\\XHX@','HcL@@LdbbRNSBDQEP@McBDpj[ae]cFpp@','HiD@@Dj}Yji`AmHPfES\\H','HaDH@@RYe[hB@@D','Hid@@DjU^njjj@FtaBXUMpq`XX@','deT@@LdbbRKBDQB@FraBXUMpr','QMPARZA@','sOq@@drm\\@@@|QX','HaD@@DjYvxH`@A@','HcL@@LdbbRNcBDQEP@McBDpj[ae]@','QMhDRZA@','RG@DXLHmP','QM`BN`XQYd','RG@DTLHmP','QMHAIXFEVd','QMDARVAaH','RFPDXLHmP','RF@Q`vRbdLEC@','RF@QpvR@','QO@HyjAmd`','`II@B','`II@CFspqJp','`II@CF[@hM@prB`','`H@[T[|B`XN@PdM@p|@bHrBcDk@','RG@DXMj}F@','QM`BN`[L~b@','RG@DTMj}D@','QMHAIXFt~j@','QMDARVA}L@','RFPDXMj}D@','sKP@Di\\YZ@[TQXqaa`@','eF`BHD']);};clb.rs=function rs(a,b){var c,d;if(!b)return null;d=gW(Ykb.AX,gmb,6,(clb.os.length+31)/32|0,15,1);b=clb.ws(b);clb.ds(a.e,b);for(c=0;c<clb.os.length;c++){clb.bs(a.e,clb.ps[c]);clb.Rr(a.e,1,4)>0&&(d[c/32|0]|=1<<31-c%32);}return d;};clb.ss=function ss(a,b){var c,d;if(!b)return null;d=gW(Ykb.BX,Anb,6,(clb.os.length+63)/64|0,14,1);b=clb.ws(b);clb.ds(a.e,b);for(c=0;c<clb.os.length;c++){clb.bs(a.e,clb.ps[c]);clb.Rr(a.e,1,4)>0&&(d[c/64|0]=B1(d[c/64|0],C1(1,63-c%64)));}return d;};clb.ts=function ts(){var a,b;if(clb.ps==null){b=new clb.mp(false);clb.ps=gW(Ykb.uY,Bob,25,clb.os.length,0,1);for(a=0;a<clb.os.length;a++){clb.ps[a]=clb.bp(b,clb.os[a]);clb.Gt(clb.ps[a],1);}}};clb.us=function us(a){var b;if(a.d!=null){for(b=0;b<a.d.length;b++)if((a.b[b]&~a.d[b])!=0)return false;}else {return false;}return clb.vs(a);};clb.vs=function vs(a){!a.c&&(a.c=(new clb.mp(false),null));!a.a&&(a.a=(new clb.mp(false),null));clb.ds(a.e,a.c);clb.bs(a.e,a.a);return clb.Yr(a.e);};clb.ws=function ws(a){var b,c;if(a.K){for(b=0;b<a.q;b++){if(z1(e1(a.B[b],Bmb),0)){a=new clb.$t(a);for(c=b;c<a.q;c++)z1(e1(a.B[c],Bmb),0)&&(a.C[c]=-1);clb.Zj(a);}}}return a;};clb.xs=function xs(a,b,c){a.a=b;c==null?a.b=clb.rs(a,b):a.b=c;};clb.ys=function ys(a,b,c){a.c=b;c==null?a.d=clb.rs(a,b):a.d=c;};clb.zs=function zs(){clb.qs();this.e=new clb.js();clb.ts();};clb.As=function As(a){clb.qs();var b,c,d,e,f,g;if(a==null)return null;b=gW(Ykb.wX,Fnb,6,a.length*8,15,1);for(d=0;d<a.length;d++){g=a[d];for(e=7;e>=0;e--){c=g&15;c>9&&(c+=7);b[d*8+e]=48+c<<24>>24;g>>=4;}}return Zkb.u5(alb.ogb(b,0,(f=b.length,alb.lgb(),f)));};clb.Bs=function Bs(a){clb.qs();var b,c,d,e;if(alb.Pgb(a).length==0||(alb.Pgb(a).length&7)!=0)return null;d=gW(Ykb.AX,gmb,6,alb.Pgb(a).length/8|0,15,1);for(c=0;c<alb.Pgb(a).length;c++){e=c/8|0;b=(alb.Kgb(c,alb.Pgb(a).length),alb.Pgb(a).charCodeAt(c)-48);b>16&&(b-=7);d[e]<<=4;d[e]+=b;}return d;};clb.Cs=function Cs(a,b){clb.qs();var c,d,e,f;f=0;d=0;e=0;for(c=0;c<a.length;c++){f+=i4(a[c]&b[c]);d+=i4(a[c]);e+=i4(b[c]);}return f/$wnd.Math.sqrt(d*e);};clb.Ds=function Ds(a,b){clb.qs();var c,d,e;e=0;c=0;for(d=0;d<a.length;d++){e+=i4(a[d]&b[d]);c+=i4(a[d]|b[d]);}return e/c;};U1(132,1,{},clb.zs);Ykb.kY=w3(132);clb.Fs=function Fs(a){a.j=1;a.k=10;a.n=400;a.f=400;a.i=true;a.d='black';a.b=new dlb.Qi();a.a=new dlb.Qi();a.c=new Zkb.J5();a.e=new ylb.j2(12);};clb.Gs=function Gs(a,b){var c,d;c=Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(3*a.j),(Blb.f8(),Blb.b8))));d='<line stroke-dasharray="'+c+','+c+tmb+'x1="'+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(b.a),Blb.b8)))+tmb+umb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(b.c),Blb.b8)))+tmb+vmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(b.b),Blb.b8)))+tmb+wmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(b.d),Blb.b8)))+tmb+xmb+a.d+tmb+'stroke-width:'+a.j+zmb;clb.Rs(a,d);};clb.Hs=function Hs(a,b){var c,d;d=new Zkb.L5('<polygon points="');for(c=0;c<b.a;c++){Zkb.E5(d,p1($wnd.Math.round(b.b[c])));d.a+=',';Zkb.E5(d,p1($wnd.Math.round(b.c[c])));d.a+=' ';}Zkb.G5(d,'" fill="'+a.d+tmb+xmb+a.d+tmb+ymb+a.j+zmb);clb.Rs(a,d.a);};clb.Is=function Is(a,b,c,d){var e,f,g,h;g=(e=(h=ylb.h2(a.e,b),new zlb.n2(h)).b,e);f='<text x="'+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(c-g/2),(Blb.f8(),Blb.b8))))+tmb+'y="'+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(d+a.k/3),Blb.b8)))+tmb+'stroke="none" '+'font-size="'+a.e.b+tmb+'fill="'+a.d+'">'+b+'<\/text>';clb.Rs(a,f);};clb.Js=function Js(a,b,c,d){var e;e='<circle cx="'+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(b+d/2),(Blb.f8(),Blb.b8))))+tmb+'cy="'+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(c+d/2),Blb.b8)))+tmb+'r="'+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(d/2),Blb.b8)))+tmb+'fill="'+a.d+zmb;clb.Rs(a,e);};clb.Ks=function Ks(a,b,c,d){var e;e='<circle id="'+(a.g!=null?a.g:'mol'+clb.Es)+':Atom:'+b+tmb+Cob+'data-atom-map-no="'+clb.mk(a.J,b)+tmb+'cx="'+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(c),(Blb.f8(),Blb.b8))))+tmb+'cy="'+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(d),Blb.b8)))+tmb+'r="'+8+tmb+Dob;dlb.wi(a.a,e);};clb.Ls=function Ls(a,b,c,d,e,f){var g;g='<line id="'+(a.g!=null?a.g:'mol'+clb.Es)+':Bond:'+b+tmb+Cob+'x1="'+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(c),(Blb.f8(),Blb.b8))))+tmb+umb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(d),Blb.b8)))+tmb+vmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(e),Blb.b8)))+tmb+wmb+Zkb.O3(Blb.g6(Blb.d6(new Blb.h6(f),Blb.b8)))+tmb+ymb+8+tmb+Dob;dlb.wi(a.b,g);};clb.Ms=function Ms(a,b){a.j=H1(p1($wnd.Math.round(100*$wnd.Math.max(b,1))))/100;};clb.Ns=function Ns(a,b){a.d='rgb('+((b&vnb)>>16)+','+((b&imb)>>8)+','+(b&255)+')';};clb.Os=function Os(a,b){if(a.k!=b){a.k=b;a.e=new ylb.j2(b);}};clb.Ps=function Ps(a,b){a.n=I1(p1($wnd.Math.round(b.b)));a.f=I1(p1($wnd.Math.round(b.a)));return clb.Nd(a,b);};clb.Qs=function Qs(a){var b,c,d,e,f,g;f='<svg id="'+(a.g!=null?a.g:'mol'+clb.Es)+tmb+'xmlns="http://www.w3.org/2000/svg" version="1.1" '+'width="'+a.n+'px" '+'height="'+a.f+'px" '+'viewBox="0 0 '+a.n+' '+a.f+'">\n';g=a.i?'<style> #'+(a.g!=null?a.g:'mol'+clb.Es)+' { pointer-events:none; }'+' #'+(a.g!=null?a.g:'mol'+clb.Es)+' .event '+' { pointer-events:all; }'+' line { stroke-linecap:round; }'+' polygon { stroke-linejoin:round; }'+' <\/style>\n':'<g style="font-size:'+a.k+'px; fill-opacity:1; stroke-opacity:1; fill:black; stroke:black;'+' font-weight:normal; text-rendering:optimizeLegibility; font-family:sans-serif;'+' stroke-linejoin:round; stroke-linecap:round; stroke-dashoffset:0;">';f+='  ';f+=g;if(a.i){for(e=new dlb.Obb(a.b);e.a<e.c.a.length;){d=dlb.Nbb(e);clb.Rs(a,d);}for(c=new dlb.Obb(a.a);c.a<c.c.a.length;){b=dlb.Nbb(c);clb.Rs(a,b);}}a.i||clb.Rs(a,'<\/g>');return f+a.c.a+'<\/svg>';};clb.Rs=function Rs(a,b){Zkb.G5(a.c,'  ');Zkb.G5(a.c,b);Zkb.G5(a.c,Klb);};clb.Ss=function Ss(a,b,c){clb.Qc();clb.Qd.call(this,a,b);clb.Fs(this);this.g=c;++clb.Es;};U1(212,244,{},clb.Ss);_.lb=function Ts(){return clb.Qs(this);};_.f=0;_.i=false;_.j=0;_.k=0;_.n=0;clb.Es=0;Ykb.mY=w3(212);clb.Us=function Us(a,b){var c;if(a.c!=null)for(c=0;c<a.c.length;c++)if(b==a.c[c]&&a.d[c])return true;return false;};clb.Vs=function Vs(a,b,c,d,e){this.a=a;this.b=b;this.g=c;this.f=d;this.e=e;};U1(140,1,{140:1},clb.Vs);_.a=0;_.b=0;_.e=false;_.f=false;_.g=0;Ykb.nY=w3(140);clb.Ws=function Ws(a,b){var c,d,e,f;f=false;a.b=b;clb.Gt(a.b,15);c=a.b.f;d=a.b.g;a.j=gW(Ykb.Z0,Amb,6,d,16,1);for(e=0;e<d;++e)a.j[e]=false;a.g=gW(Ykb.Z0,Amb,6,c,16,1);a.c=gW(Ykb.AX,gmb,6,c,15,1);for(e=0;e<c;++e){a.g[e]=false;a.c[e]=-1;}a.e=gW(Ykb.l_,Xlb,2,3*c,6,1);a.i=0;a.d=0;a.a=0;while(!f){for(e=0;e<c;++e){if(!a.g[e]){a.a>0&&(a.e[a.i++]='.');clb.Ys(a,e,-1);++a.a;break;}}e==c&&(f=true);}a.f='';for(e=0;e<a.i;++e)a.f+=''+a.e[e];return a.f;};clb.Xs=function Xs(a){switch(a){case 5:case 6:case 7:case 8:case 9:case 15:case 16:case 17:case 35:case 53:return true;default:return false;}};clb.Ys=function Ys(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o,p;d=true;i=0;p=0;m=a.i;a.c[b]=m;h=clb.uk(a.b,b);g=clb.jk(a.b,b);e=clb.dk(a.b,b);f=clb.nk(a.b,b);k=clb.wn(a.b,b);e==0&&f==0&&clb.Xs(h)&&(d=false);a.e[m]='';if(c!=-1){switch(clb.Hk(a.b,c)){case 0:a.e[m]+='~';break;case 2:a.e[m]+='=';break;case 3:a.e[m]+='#';}}d&&(a.e[m]+='[');f!=0&&(a.e[m]+=''+f);a.e[m]+=''+g;if(d){if(0<(o=clb.Kn(a.b,b))){a.e[m]+='H';1<o&&(a.e[m]+=o);}}if(e!=0){e>0?a.e[m]+='+':a.e[m]+='-';$wnd.Math.abs(e)>1&&(a.e[m]+=''+$wnd.Math.abs(e));}d&&(a.e[m]+=']');c!=-1&&(a.j[c]=true);a.g[b]=true;++a.i;for(n=0;n<k;++n)a.j[clb.xn(a.b,b,n)]||++i;for(n=0;n<k;++n){j=clb.vn(a.b,b,n);l=clb.xn(a.b,b,n);if(a.j[l]){++p;continue;}if(a.g[j]){++a.d;a.j[l]=true;switch(clb.Hk(a.b,l)){case 0:a.e[a.c[j]]+='~';a.e[m]+='~';break;case 2:a.e[a.c[j]]+='=';a.e[m]+='=';break;case 3:a.e[a.c[j]]+='#';a.e[m]+='3';}if(a.d>9){a.e[a.c[j]]+='%';a.e[m]+='%';}a.e[a.c[j]]+=''+a.d;a.e[m]+=''+a.d;continue;}n-p<i-1&&(a.e[a.i++]='(');clb.Ys(a,j,l);n-p<i-1&&(a.e[a.i++]=')');}};clb.Zs=function Zs(){};U1(211,1,{},clb.Zs);_.a=0;_.d=0;_.i=0;Ykb.oY=w3(211);clb.$s=function $s(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o;j=gW(Ykb.AX,gmb,6,a.i.f,15,1);h=gW(Ykb.AX,gmb,6,a.i.f,15,1);i=gW(Ykb.AX,gmb,6,a.i.f,15,1);k=gW(Ykb.AX,gmb,6,a.i.f,15,1);c=clb.zk(a.i,0,b);d=clb.zk(a.i,1,b);h[0]=c;h[1]=d;i[0]=-1;i[1]=b;j[c]=1;j[d]=2;k[c]=-1;k[d]=c;g=1;l=1;while(g<=l&&j[h[g]]<15){o=h[g];for(m=0;m<clb.wn(a.i,o);m++){e=clb.vn(a.i,o,m);if(e!=k[o]){f=clb.xn(a.i,o,m);if(e==c){i[0]=f;for(n=0;n<=l;n++){if(!a.f[i[m]]){a.f[i[m]]=true;++a.c;}}return;}if(clb.il(a.i,e)&&j[e]==0){++l;h[l]=e;i[l]=f;j[e]=j[o]+1;k[e]=o;}}}++g;}return;};clb._s=function _s(a){var b,c,d,e,f,g,h,i,j,k,l,m,n;clb.Gt(a.i,7);l=false;m=gW(Ykb.AX,gmb,6,2,15,1);n=gW(Ykb.AX,gmb,6,2,15,1);k=gW(Ykb.AX,gmb,6,2,15,1);for(d=0;d<a.i.g;d++){if(!clb.Co(a.i,d)&&clb.Kk(a.i,d)==2){for(g=0;g<2;g++){m[g]=-1;k[g]=-1;b=clb.zk(a.i,g,d);for(j=0;j<clb.wn(a.i,b);j++){e=clb.xn(a.i,b,j);if(e!=d){if(m[g]==-1&&(clb.Kk(a.i,e)==257||clb.Kk(a.i,e)==129)){m[g]=clb.vn(a.i,b,j);n[g]=e;}else {k[g]=clb.vn(a.i,b,j);}}}if(m[g]==-1)break;}if(m[0]!=-1&&m[1]!=-1){i=clb.Kk(a.i,n[0])==clb.Kk(a.i,n[1]);for(h=0;h<2;h++)m[h]==clb.zk(a.i,0,n[h])&&(i=!i);for(f=0;f<2;f++)k[f]!=-1&&k[f]<m[f]&&(i=!i);clb.gm(a.i,d,i?2:1,false);l=true;}}}for(c=0;c<a.i.g;c++)(clb.Kk(a.i,c)==257||clb.Kk(a.i,c)==129)&&clb.jm(a.i,c,1);return l;};clb.at=function at(a){return a==61?2:a==35?4:a==36?32:a==58?8:a==62?16:a==126?31:1;};clb.bt=function bt(a,b){var c,d,e,f,g,h,i,j,k,l,m;for(c=0;c<a.i.f;c++){if(clb.il(a.i,c)){i=gW(Ykb.AX,gmb,6,a.i.f,15,1);h=gW(Ykb.AX,gmb,6,a.i.f,15,1);j=gW(Ykb.AX,gmb,6,a.i.f,15,1);h[0]=c;i[c]=1;j[c]=-1;g=0;k=0;while(g<=k){e=(i[h[g]]&1)==1?1:2;for(l=0;l<clb.wn(a.i,h[g]);l++){d=clb.xn(a.i,h[g],l);if(clb.Hk(a.i,d)==e&&b[d]){f=clb.vn(a.i,h[g],l);if(i[f]==0){if(e==1&&clb.il(a.i,f)){m=h[g];while(m!=-1){clb.jm(a.i,clb.tn(a.i,f,m),e==1?2:1);e=3-e;f=m;m=j[m];}clb.Rl(a.i,c,false);clb.Rl(a.i,f,false);a.b-=2;return true;}h[++k]=f;j[f]=h[g];i[f]=i[h[g]]+1;}}}++g;}}}return false;};clb.ct=function ct(a){var b,c,d,e;for(b=0;b<a.i.f;b++){if(clb.uk(a.i,b)==7&&clb.dk(a.i,b)==0&&clb.Pn(a.i,b)>3&&clb.mn(a.i,b)>0){for(e=0;e<clb.wn(a.i,b);e++){c=clb.vn(a.i,b,e);d=clb.xn(a.i,b,e);if(clb.Hk(a.i,d)>1&&clb.gl(a.i,c)){clb.Kk(a.i,d)==4?clb.jm(a.i,d,2):clb.jm(a.i,d,1);clb.Il(a.i,b,clb.dk(a.i,b)+1);clb.Il(a.i,c,clb.dk(a.i,c)-1);clb.Gl(a.i,b,-1);break;}}}}};clb.dt=function dt(a){return !a.n?'':'Unresolved SMARTS features:'+a.n;};clb.et=function et(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G,H,I,J,K;clb.Gt(a.i,1);a.f=gW(Ykb.Z0,Amb,6,a.i.g,16,1);a.c=0;for(k=0;k<a.i.g;k++){if(clb.Kk(a.i,k)==64){clb.jm(a.i,k,1);a.f[k]=true;++a.c;}}w=gW(Ykb.Z0,Amb,6,a.i.f,16,1);K=new clb.Fr(a.i,3);v=gW(Ykb.Z0,Amb,6,K.i.a.length,16,1);for(G=0;G<K.i.a.length;G++){I=dlb.Bi(K.i,G);v[G]=true;for(q=0;q<I.length;q++){if(!clb.il(a.i,I[q])){v[G]=false;break;}}if(v[G]){for(r=0;r<I.length;r++)w[I[r]]=true;J=dlb.Bi(K.j,G);for(s=0;s<J.length;s++){if(!a.f[J[s]]){a.f[J[s]]=true;++a.c;}}}}for(l=0;l<a.i.g;l++){!a.f[l]&&(K.b[l]&Zlb)!=0&&clb.il(a.i,clb.zk(a.i,0,l))&&clb.il(a.i,clb.zk(a.i,1,l))&&clb.$s(a,l);}for(m=0;m<a.i.g;m++){if(!a.f[m]){e=clb.zk(a.i,0,m);f=clb.zk(a.i,1,m);if(!w[e]&&!w[f]&&clb.il(a.i,e)&&clb.il(a.i,f)){a.f[m]=true;++a.c;}}}clb.Gt(a.i,7);u=gW(Ykb.Z0,Amb,6,a.i.g,16,1);for(t=0;t<a.i.g;t++)u[t]=a.f[t];for(H=0;H<K.i.a.length;H++){if(v[H]){I=dlb.Bi(K.i,H);for(p=0;p<I.length;p++){if(!clb.lt(a,I[p])){if(clb.il(a.i,I[p])){clb.Rl(a.i,I[p],false);--a.b;}for(B=0;B<clb.wn(a.i,I[p]);B++){o=clb.xn(a.i,I[p],B);if(a.f[o]){a.f[o]=false;--a.c;}}}}}}clb.kt(a);for(F=0;F<K.i.a.length;F++){if(v[F]&&dlb.Bi(K.j,F).length==6){J=dlb.Bi(K.j,F);A=true;for(h=J,i=0,j=h.length;i<j;++i){g=h[i];if(!a.f[g]){A=false;break;}}if(A){clb.jt(a,J[0]);clb.jt(a,J[2]);clb.jt(a,J[4]);clb.kt(a);}}}for(D=5;D>=4;D--){do{C=false;for(g=0;g<a.i.g;g++){if(a.f[g]){c=0;for(p=0;p<2;p++){n=clb.zk(a.i,p,g);for(B=0;B<clb.wn(a.i,n);B++)a.f[clb.xn(a.i,n,B)]&&++c;}if(c==D){clb.jt(a,g);clb.kt(a);C=true;break;}}}}while(C);}while(a.b>=2)if(!clb.bt(a,u))break;if(b){if(a.b!=0){for(d=0;d<a.i.f;d++){if(clb.il(a.i,d)){clb.Rl(a.i,d,false);clb.Ul(a.i,d,2,true);--a.b;}}}if(a.c!=0){for(g=0;g<a.i.g;g++){if(a.f[g]){a.f[g]=false;clb.jm(a.i,g,64);--a.c;}}}}else {for(d=0;d<a.i.f;d++){if(clb.il(a.i,d)&&clb.Kn(a.i,d)!=0){clb.Rl(a.i,d,false);clb.Vl(a.i,d,32);--a.b;}}}if(a.b!=0)throw c1(new Zkb.rz(Eob));if(a.c!=0)throw c1(new Zkb.rz(Eob));};clb.ft=function ft(a,b,c,d,e,f,g){var h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z,$,ab,bb,cb,db,eb,fb,gb,hb,ib,jb,kb,lb,mb,nb,ob,pb,qb,rb,sb,tb,ub,vb,wb,xb,yb,zb,Ab;a.i=b;clb.Nj(a.i);!!a.n&&Zkb.B2(a.n,0);a.b=0;i=a.k!=0;fb=null;p=gW(Ykb.AX,gmb,6,32,15,1);p[0]=-1;lb=gW(Ykb.AX,gmb,6,16,15,1);ob=gW(Ykb.AX,gmb,6,16,15,1);nb=gW(Ykb.AX,gmb,6,16,15,1);mb=gW(Ykb.AX,gmb,6,16,15,1);for(M=0;M<16;M++)lb[M]=-1;m=0;H=-1;rb=false;P=false;qb=false;u=0;s=1;r=0;l=new slb.WT();gb=new clb.yt(c);while(c[d]<=32)++d;while(d<e){tb=c[d++]&Zlb;if(e3(tb)||tb==42||tb==63||tb==33&&i&&rb||tb==35&&i&&rb){o=-1;w=0;W=0;h=-1;F=-1;eb=false;O=false;n=0;if(rb){if(tb==42){o=6;n=I1(B1(Ykb.m1(n),1));}else if(tb==63){o=0;}else if(tb==35){Z=0;while(d<e&&d3(c[d]&Zlb)){Z=10*Z+c[d]-48;++d;}if(Z<1||Z>=(clb.wj(),clb.qj).length)throw c1(new Zkb.rz('SmilesParser: Atomic number out of range.'));o=Z;}else {Q=tb==33;if(Q){qb=true;n=I1(B1(Ykb.m1(n),1));++d;}if(c[d-1]==82&&i&&(d3(c[d]&Zlb)||a.a&&c[d]==123)){o=6;n=I1(B1(Ykb.m1(n),1));--d;Q&&--d;}else {R=h3(c[d]&Zlb)==(c[d]&Zlb)&&e3(c[d]&Zlb)?2:1;o=(clb.wj(),clb.Nm(Zkb.u5(alb.ogb(c,d-1,(T=R,alb.lgb(),T))),321));if(o==-1){o=6;n=I1(B1(Ykb.m1(n),1));--d;}else {d+=R-1;F=9;if(i&&(c[d]==44||Q)){ub=false;V=false;sb=d-R;for(bb=sb;bb<c.length;bb++){if(!e3(c[bb]&Zlb)){Y=clb.Nm(Zkb.u5(alb.ogb(c,sb,(S=bb-sb,S))),321);if(Y!=0){slb.RT(l,Zkb.t4(Y));j3(c[sb]&Zlb)==(c[sb]&Zlb)&&e3(c[sb]&Zlb)?ub=true:V=true;}sb=bb+1;if(c[bb]!=44)break;if(c[bb+1]==33){if(!Q)throw c1(new Zkb.rz("SmilesParser: inconsistent '!' in atom list."));++bb;++sb;}}}if(l.d.a.length>1){F=-1;ub?V||(n=I1(B1(Ykb.m1(n),4))):n=I1(B1(Ykb.m1(n),2));}d=sb-1;}}}}while(rb){if(c[d]==64){++d;if(c[d]==64){O=true;++d;}eb=true;continue;}if(c[d]==58){++d;while(d3(c[d]&Zlb)){W=10*W+c[d]-48;++d;}continue;}if(c[d]==91)throw c1(new Zkb.rz('SmilesParser: nested square brackets found'));if(c[d]==93){++d;rb=false;continue;}if(c[d]==43){w=1;++d;while(c[d]==43){++w;++d;}if(w==1&&d3(c[d]&Zlb)){w=c[d]-48;++d;}w==0&&(n=I1(B1(Ykb.m1(n),Pmb)));continue;}if(c[d]==45){w=-1;++d;while(c[d]==45){--w;++d;}if(w==-1&&d3(c[d]&Zlb)){w=48-c[d];++d;}w==0&&(n=I1(B1(Ykb.m1(n),Pmb)));continue;}Q=c[d]==33;Q&&++d;if(c[d]==72){++d;d+=clb.vt(gb,c,d,1);F=gb.c;G=0;gb.c<=0&&gb.b>=0&&(G=I1(B1(Ykb.m1(G),128)));gb.c<=1&&gb.b>=1&&(G=I1(B1(Ykb.m1(G),256)));gb.c<=2&&gb.b>=2&&(G=I1(B1(Ykb.m1(G),512)));gb.c<=3&&gb.b>=3&&(G=I1(B1(Ykb.m1(G),Nmb)));if(Q){n|=G;F=-1;}else {if(gb.b==gb.c){F=gb.c;}else {n=I1(B1(Ykb.m1(n),e1(Mmb,Ykb.m1(~G))));F=-1;}}continue;}if(c[d]==68){++d;d+=clb.vt(gb,c,d,1);G=0;gb.c<=0&&gb.b>=0&&(G=B1(G,Gnb));gb.c<=1&&gb.b>=1&&(G=B1(G,tnb));gb.c<=2&&gb.b>=2&&(G=B1(G,snb));gb.c<=3&&gb.b>=3&&(G=B1(G,Inb));gb.c<=4&&gb.b>=4&&(G=B1(G,Wmb));if(j1(G,0)!=0){Q||(G=K1(G,Tmb));n=I1(B1(Ykb.m1(n),G));}continue;}if(c[d]==122&&a.a){++d;d+=clb.vt(gb,c,d,4);G=0;gb.c<=0&&gb.b>=0&&(G=B1(G,enb));gb.c<=1&&gb.b>=1&&(G=B1(G,Fob));gb.c<=2&&gb.b>=2&&(G=B1(G,Gob));gb.c<=3&&gb.b>=3&&(G=B1(G,Hob));gb.c<=4&&gb.b>=4&&(G=B1(G,dnb));if(j1(G,0)!=0){Q||(G=K1(G,$mb));n=I1(B1(Ykb.m1(n),G));}continue;}if(c[d]==88){++d;d+=clb.vt(gb,c,d,1);Ab=(clb.wj(),clb.rj)[o];if(Ab==null)continue;wb=Ab[0];G=0;wb-gb.c<=0&&wb-gb.b>=0&&(G=B1(G,Hmb));wb-gb.c<=1&&wb-gb.b>=1&&(G=B1(G,Ynb));wb-gb.c<=2&&wb-gb.b>=2&&(G=B1(G,Ylb));if(j1(G,0)!=0){Q||(G=K1(G,Smb));n=I1(B1(Ykb.m1(n),G));}continue;}if(c[d]==65||c[d]==97){++d;n=I1(B1(Ykb.m1(n),Q^c[d]==65?4:2));continue;}if(c[d]==82){++d;d+=clb.vt(gb,c,d,3);G=0;gb.c<=0&&gb.b>=0&&(G=B1(G,8));gb.c<=1&&gb.b>=1&&(G=B1(G,16));gb.c<=2&&gb.b>=2&&(G=B1(G,32));gb.c<=3&&gb.b>=3&&(G=B1(G,64));gb.b>3&&clb.nt(a,(Q?'!R':'R')+gb.b);if(j1(G,0)!=0){Q||(G=K1(G,120));n=I1(B1(Ykb.m1(n),G));}continue;}if(c[d]==114){++d;d+=clb.vt(gb,c,d,1);if(gb.a){Q?n=I1(B1(Ykb.m1(n),384)):n=I1(B1(Ykb.m1(n),8));continue;}pb=gb.c;gb.b>gb.c&&clb.nt(a,(Q?'!r':'r')+('{'+gb.c+'-'+gb.b+'}'));!Q&&pb>=3&&pb<=7?n|=pb<<22:gb.b>gb.c||clb.nt(a,(Q?'!r':'r')+pb);continue;}if(c[d]==118){++d;d+=clb.vt(gb,c,d,1);wb=gb.c;gb.b>gb.c&&clb.nt(a,(Q?'!v':'v')+('{'+gb.c+'-'+gb.b+'}'));!Q&&wb<=14?h=wb:gb.b>gb.c||clb.nt(a,(Q?'!v':'v')+wb);continue;}if(i&&(c[d]==59||c[d]==38)){qb=true;++d;continue;}throw c1(new Zkb.rz("SmilesParser: unexpected character inside brackets: '"+String.fromCharCode(c[d]&Zlb)+"'"));}}else if(tb==42){o=6;n=I1(B1(Ykb.m1(n),1));}else if(tb==63){o=0;}else if((tb==65||tb==97)&&i){o=6;n=I1(B1(Ykb.m1(n),1));n=I1(B1(Ykb.m1(n),tb==65?4:2));qb=true;}else {switch(j3(tb)){case 66:if(d<e&&c[d]==114){o=35;++d;}else o=5;break;case 67:if(d<e&&c[d]==108){o=17;++d;}else o=6;break;case 70:o=9;break;case 73:o=53;break;case 78:o=7;break;case 79:o=8;break;case 80:o=15;break;case 83:o=16;}}if(o==-1&&tb!=63)throw c1(new Zkb.rz('SmilesParser: unknown element label found'));k=clb.yj(a.i,o);clb.Il(a.i,k,w);clb.Ql(a.i,k,W,false);clb.Gl(a.i,k,h);if(n!=0){qb=true;if(z1(e1(Ykb.m1(n),2),0)){n=I1(e1(Ykb.m1(n),-3));clb.Rl(a.i,k,true);++a.b;}else {clb.Rl(a.i,k,false);}clb.Ul(a.i,k,Ykb.m1(n),true);}if(l.d.a.length!=0){qb=true;U=gW(Ykb.AX,gmb,6,l.d.a.length,15,1);for(L=0;L<l.d.a.length;L++)U[L]=(L<0?null:dlb.Bi(l.d,L)).a;clb.Ol(a.i,k,U);alb.igb(l.d.a,0);}else {if(h3(tb)==tb&&e3(tb)){if(o!=5&&o!=6&&o!=7&&o!=8&&o!=15&&o!=16&&o!=33&&o!=34)throw c1(new Zkb.rz('SmilesParser: atomicNo '+o+' must not be aromatic'));clb.Rl(a.i,k,true);++a.b;}else {clb.Rl(a.i,k,false);}}if(F!=-1&&o!=1){v=gW(Ykb.wX,Fnb,6,1,15,1);v[0]=(F==9?0:F)<<24>>24;clb.Ml(a.i,k,v);}H=p[u];if(p[u]!=-1&&s!=512){q=clb.Aj(a.i,p[u],k,s);if(r!=0){qb=true;clb.im(a.i,q,r,true);}}s=1;r=0;p[u]=k;if(m!=0){clb.Sl(a.i,k,m);m=0;}if(g){cb=!fb?null:dlb.Iab(fb,Zkb.t4(H));!!cb&&clb.rt(cb,k,d);if(eb){!fb&&(fb=new dlb.seb());K=F==9?0:F;dlb.keb(fb,Zkb.t4(k),new clb.ut(k,d-2,H,K,O));}}continue;}if(tb==46){p[u]=-1;s=512;continue;}if(tb==45||tb==61||tb==35||tb==36||tb==58||tb==47||tb==92||tb==60||tb==126||tb==33||tb==64){if(rb)throw c1(new Zkb.rz("SmilesParser: unexpected bond symbol inside square brackets: '"+String.fromCharCode(tb)+"'"));C=0;while(tb==45||tb==61||tb==35||tb==36||tb==58||tb==47||tb==92||tb==60||tb==126||tb==33||tb==64){if(tb==33){tb=c[d++]&Zlb;tb==64&&(r|=128);if(tb==45&&c[d]==62||tb==60&&c[d]==45){C|=32;++d;}else if(tb==45)C|=1;else if(tb==61)C|=2;else if(tb==35)C|=4;else if(tb==36)C|=32;else if(tb==58)C|=8;else throw c1(new Zkb.rz("SmilesParser: bond symbol '"+String.fromCharCode(tb)+"' not allowed after '!'."));}else {if(tb==64)r|=256;else if(tb==61)s=2;else if(tb==35)s=4;else if(tb==36)s=8;else if(tb==58)s=64;else if(tb==126)r|=31;else if(tb==47){g&&(s=257);}else if(tb==92){g&&(s=129);}else if(tb==45&&c[d]==62||tb==60&&c[d]==45){s=32;++d;}if(c[d]==44){r|=(s==32?62:tb)==61?2:(s==32?62:tb)==35?4:(s==32?62:tb)==36?32:(s==32?62:tb)==58?8:(s==32?62:tb)==62?16:(s==32?62:tb)==126?31:1;while(c[d]==44){if(c[d+1]==60&&c[d+2]==45||c[d+1]==45&&c[d+2]==62){r|=16;d+=3;}else {r|=clb.at(c[d+1]&Zlb);d+=2;}}}}if(c[d]==59){++d;tb=c[d++]&Zlb;continue;}C!=0&&(r|=31&~C);break;}continue;}if(tb<=32){d=e;continue;}if(d3(tb)){Z=tb-48;if(rb){while(d<e&&d3(c[d]&Zlb)){Z=10*Z+c[d]-48;++d;}m=Z;}else {t=P?d-3:d-2;J=c[t]==45||c[t]==47||c[t]==92||c[t]==61||c[t]==35||c[t]==36||c[t]==58||c[t]==62||c[t]==126;if(P&&d<e&&d3(c[d]&Zlb)){Z=10*Z+c[d]-48;P=false;++d;}if(Z>=lb.length){if(Z>=100)throw c1(new Zkb.rz('SmilesParser: ringClosureAtom number out of range'));$=lb.length;X=lb.length;while(X<=Z)X=$wnd.Math.min(100,X+16);lb=(alb.Agb(X),dlb.Wbb(lb,gW(Ykb.AX,gmb,6,X,15,1),X));ob=(alb.Agb(X),dlb.Wbb(ob,gW(Ykb.AX,gmb,6,X,15,1),X));nb=(alb.Agb(X),dlb.Wbb(nb,gW(Ykb.AX,gmb,6,X,15,1),X));mb=(alb.Agb(X),dlb.Wbb(mb,gW(Ykb.AX,gmb,6,X,15,1),X));for(L=$;L<X;L++)lb[L]=-1;}if(lb[Z]==-1){lb[Z]=p[u];ob[Z]=d-1;nb[Z]=J?s:-1;mb[Z]=J?r:0;}else {if(lb[Z]==p[u])throw c1(new Zkb.rz('SmilesParser: ring closure to same atom'));if(g&&!!fb){cb=dlb.Iab(fb,Zkb.t4(lb[Z]));!!cb&&clb.rt(cb,p[u],ob[Z]);cb=dlb.Iab(fb,Zkb.t4(p[u]));!!cb&&clb.rt(cb,lb[Z],d-1);}nb[Z]!=-1?s=nb[Z]:s==257?s=129:s==129&&(s=257);q=clb.Aj(a.i,lb[Z],p[u],s);mb[Z]!=0&&(r=mb[Z]);if(r!=0){qb=true;clb.im(a.i,q,mb[Z],true);}lb[Z]=-1;}s=1;r=0;}continue;}if(tb==43){throw c1(new Zkb.rz("SmilesParser: '+' found outside brackets"));}if(tb==40){if(p[u]==-1)throw c1(new Zkb.rz('Smiles with leading parenthesis are not supported'));++u;p.length==u&&(p=dlb.Ubb(p,p.length+32));p[u]=p[u-1];continue;}if(tb==41){--u;continue;}if(tb==91){rb=true;continue;}if(tb==93){throw c1(new Zkb.rz('SmilesParser: closing bracket at unexpected position'));}if(tb==37){P=true;continue;}throw c1(new Zkb.rz("SmilesParser: unexpected character outside brackets: '"+String.fromCharCode(tb)+"'"));}if(s!=1)throw c1(new Zkb.rz('SmilesParser: dangling open bond'));for(ib=lb,jb=0,kb=ib.length;jb<kb;++jb){hb=ib[jb];if(hb!=-1)throw c1(new Zkb.rz('SmilesParser: dangling ring closure'));}I=clb.In(a.i);clb.nm(a.i,true);clb.Gt(a.i,1);for(j=0;j<a.i.q;j++){if(clb.fk(a.i,j)!=null){D=clb.gk(a.i,j)[0];if(qb||a.k==2){if(a.g){for(L=0;L<D;L++)clb.Aj(a.i,j,clb.yj(a.i,1),1);}else {D==0&&clb.Ul(a.i,j,1792,true);D==1&&clb.Ul(a.i,j,1664,true);D==2&&clb.Ul(a.i,j,1408,true);D==3&&clb.Ul(a.i,j,896,true);}}else {if(!clb.jl(a.i,j)&&(!clb.il(a.i,j)||clb.uk(a.i,j)==6&&clb.dk(a.i,j)==0)){Ab=clb.Km(clb.uk(a.i,j));A=false;vb=clb.Pn(a.i,j);vb-=clb.Ok(a.i,j,vb);vb+=D;clb.il(a.i,j)&&++vb;for(xb=Ab,yb=0,zb=xb.length;yb<zb;++yb){wb=xb[yb];if(vb<=wb){A=true;wb==vb+2?clb.Vl(a.i,j,48):wb==vb+1?clb.Vl(a.i,j,32):(wb!=vb||wb!=Ab[0])&&clb.Gl(a.i,j,vb);break;}}A||clb.Gl(a.i,j,vb);}if(a.g||!clb.Ro(a.i,j))for(L=0;L<D;L++)clb.Aj(a.i,j,clb.yj(a.i,1),1);}}else if(!a.g&&(qb||a.k==2)){D=clb.An(a.i,j);D>=1&&clb.Ul(a.i,j,128,true);D>=2&&clb.Ul(a.i,j,256,true);D>=3&&clb.Ul(a.i,j,512,true);D>=4&&clb.Ul(a.i,j,Nmb,true);}}!a.g&&(qb||a.k==2)&&clb.Jo(a.i,true);clb.Gt(a.i,1);clb.ct(a);clb.et(a,i);a.i.t=null;clb.nm(a.i,false);if(g){clb._s(a);if(fb){for(db=(ab=new dlb.hab(fb).a.dc().rb(),new dlb.oab(ab));db.a.ec();){cb=(B=db.a.fc(),B.ic());clb.Tl(a.i,cb.a,clb.st(cb,I),false);}clb.Mo(a.i,0);}}clb.Mo(a.i,0);if(f){N=new glb.Rx(a.d);z1(a.j,0)&&glb.Nx(N,a.j);glb.yx(N,a.i);g&&clb.Tt(a.i);}(qb||a.k==2)&&clb.lm(a.i,true);};clb.gt=function gt(a,b,c,d,e){clb.ft(a,b,c,0,c.length,d,e);};clb.ht=function ht(a,b){var c;return b==null?null:clb.it(a,alb.qgb((c=b,alb.lgb(),c)));};clb.it=function it(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o;h=slb.AT(b,0);i=h==-1?-1:slb.AT(b,h+1);if(i==-1)throw c1(new Zkb.rz("Missing one or both separators ('>')."));if(slb.AT(b,i+1)!=-1)throw c1(new Zkb.rz("Found more than 2 separators ('>')."));n=new nlb.TE();o=0;for(f=o;f<h-1;f++){if(b[f]==46&&b[f+1]==46){if(f>o){l=new clb.Yt();clb.ft(a,l,b,o,f,true,true);dlb.wi(n.g,l);n.d=-1;}o=f+2;}}m=new clb.Yt();clb.ft(a,m,b,o,h,true,true);dlb.wi(n.g,m);n.d=-1;if(i-h>1){o=h+1;for(g=o;g<i-1;g++){if(b[g]==46&&b[g+1]==46){if(g>o){c=new clb.Yt();clb.ft(a,c,b,o,g,true,true);dlb.wi(n.a,c);}o=g+2;}}d=new clb.Yt();clb.ft(a,d,b,o,i,true,true);dlb.wi(n.a,d);}o=i+1;for(e=o;e<b.length-1;e++){if(b[e]==46&&b[e+1]==46){if(e>o){j=new clb.Yt();clb.ft(a,j,b,o,e,true,true);dlb.wi(n.f,j);n.d=-1;}o=e+2;}}k=new clb.Yt();clb.ft(a,k,b,o,b.length,true,true);dlb.wi(n.f,k);n.d=-1;return n;};clb.jt=function jt(a,b){var c,d,e,f;clb.Kk(a.i,b)==1&&clb.jm(a.i,b,2);for(e=0;e<2;e++){c=clb.zk(a.i,e,b);if(clb.il(a.i,c)){clb.Rl(a.i,c,false);--a.b;}for(f=0;f<clb.wn(a.i,c);f++){d=clb.xn(a.i,c,f);if(a.f[d]){a.f[d]=false;--a.c;}}}};clb.kt=function kt(a){var b,c,d,e,f,g,h;do{h=false;for(c=0;c<a.i.g;c++){if(a.f[c]){f=false;for(e=0;e<2;e++){b=false;d=clb.zk(a.i,e,c);for(g=0;g<clb.wn(a.i,d);g++){if(c!=clb.xn(a.i,d,g)&&a.f[clb.xn(a.i,d,g)]){b=true;break;}}if(!b){f=true;break;}}if(f){h=true;clb.jt(a,c);}}}}while(h);};clb.lt=function lt(a,b){var c,d;if(!clb.Hr(clb.uk(a.i,b)))return false;if(clb.uk(a.i,b)==6){if(!clb.il(a.i,b))return false;if(clb.dk(a.i,b)>0)return false;}c=clb.fk(a.i,b)==null?0:clb.gk(a.i,b)[0];d=clb.Gn(a.i,b)-c;if(d<1)return false;if(clb.uk(a.i,b)==16||clb.uk(a.i,b)==34||clb.uk(a.i,b)==52){if(clb.wn(a.i,b)==2&&clb.dk(a.i,b)<=0)return false;if(d==2)return false;}return true;};clb.mt=function mt(a,b){a.j=b;};clb.nt=function nt(a,b){if(a.e){!a.n&&(a.n=new Zkb.J5());Zkb.G5(a.n,' ');Zkb.G5(a.n,b);}};clb.ot=function ot(){clb.pt.call(this,0,false);};clb.pt=function pt(a,b){this.k=a&3;this.a=(a&16)==0;this.e=b;this.g=(a&8)!=0;this.d=2;(a&4)!=0&&(this.d|=1);this.g&&(this.d&=-3);};U1(116,1,{},clb.ot,clb.pt);_.a=false;_.b=0;_.c=0;_.d=0;_.e=false;_.g=false;_.j=0;_.k=0;Ykb.rY=w3(116);clb.qt=function qt(a,b){this.a=a;this.b=b;};U1(139,1,{139:1},clb.qt);_.a=0;_.b=0;Ykb.pY=w3(139);clb.rt=function rt(a,b,c){if(!a.c){if(a.e.a.length==4){a.c=true;return;}dlb.wi(a.e,new clb.qt(b,c));}};clb.st=function st(a,b){var c,d,e;if(a.c)return 3;for(d=new dlb.Obb(a.e);d.a<d.c.a.length;){c=dlb.Nbb(d);c.a!=2147483646&&c.a!=Qlb&&(c.a=b[c.a]);}if(a.e.a.length==3)dlb.wi(a.e,new clb.qt(Qlb,a.b));else if(a.e.a.length!=4)return 3;e=a.d^clb.tt(a)?1:2;return e;};clb.tt=function tt(a){var b,c,d;c=false;for(b=1;b<a.e.a.length;b++){for(d=0;d<b;d++){dlb.Bi(a.e,d).a>dlb.Bi(a.e,b).a&&(c=!c);dlb.Bi(a.e,d).b>dlb.Bi(a.e,b).b&&(c=!c);}}return c;};clb.ut=function ut(a,b,c,d,e){if(d!=0&&d!=1){this.c=true;}else {this.a=a;this.b=b;this.d=e;this.e=new dlb.Qi();c!=-1&&clb.rt(this,c,b-1);c!=-1&&d==1&&clb.rt(this,2147483646,b+1);}};U1(169,1,{169:1},clb.ut);_.a=0;_.b=0;_.c=false;_.d=false;Ykb.qY=w3(169);clb.vt=function vt(a,b,c,d){a.a=false;a.d=c;if(d3(b[c]&Zlb)){a.c=a.b=clb.wt(a);return a.d-c;}if(b[c]==123&&d3(b[c+1]&Zlb)){++a.d;a.c=clb.wt(a);if(b[a.d++]!=45)return 0;if(!d3(b[a.d]&Zlb))return 0;a.b=clb.wt(a);if(b[a.d++]!=125)return 0;return a.d-c;}a.c=1;a.b=d;a.a=true;return 0;};clb.wt=function wt(a){var b;b=a.e[a.d++]-48;d3(a.e[a.d]&Zlb)&&(b=10*b+(a.e[a.d++]-48));return b;};clb.xt=function xt(a){return '{'+a.c+'-'+a.b+'}';};clb.yt=function yt(a){this.e=a;};U1(232,1,{},clb.yt);_.lb=function zt(){return clb.xt(this);};_.a=false;_.b=0;_.c=0;_.d=0;Ykb.sY=w3(232);clb.At=function At(a){a.c=new dlb.Qi();};clb.Bt=function Bt(a,b){var c,d,e,f;f=a.c.a.length;if(f==0){dlb.vi(a.c,0,b);return 0;}e=1;while(2*e<=f)e<<=1;d=e;--e;while(d!=0){d>>=1;if(e>=f){e-=d;continue;}c=Zkb.Z4(b,dlb.Bi(a.c,e));if(c==0)return -1;if(d==0)break;c<0?e-=d:e+=d;}e<f&&Zkb.Z4(b,dlb.Bi(a.c,e))>0&&++e;dlb.vi(a.c,e,b);return e;};clb.Ct=function Ct(a,b){var c,d,e,f;f=a.c.a.length;if(f==0)return -1;e=1;while(2*e<=f)e<<=1;d=e;--e;while(d!=0){d>>=1;if(e>=f){e-=d;continue;}c=Zkb.Z4(b,dlb.Bi(a.c,e));if(c==0)return e;if(d==0)break;c<0?e-=d:e+=d;}return -1;};clb.Dt=function Dt(){clb.At(this);};U1(77,1,{77:1,4:1},clb.Dt);_.zb=function Et(a){return clb.Ct(this,a);};Ykb.tY=w3(77);clb.Ft=function Ft(a,b){clb.Tj(a,b);!!a.d&&(b.T=0);};clb.Gt=function Gt(a,b){var c,d,e,f;clb._m(a,b);if((b&~a.T)==0)return;(a.T&15)!=0&&a.q>1&&clb.th(a.J[0],a.J[1])&&glb.yx(new glb.Rx(0),a);a.c&&(b|=128);for(c=0;c<a.q;c++)a.u[c]&=-67223560;for(d=0;d<a.g;d++)a.F[d]&=-64;e=0;f=0;if((b&32)!=0){e=32;f=1;}else if((b&64)!=0){e=64;f=3;}if((b&128)!=0){e|=128;f|=32;}a.d=new clb.bg(a,f);clb.Yf(a.d);clb.Zf(a.d);clb.Xf(a.d);clb.Xt(a)&&(a.d=new clb.bg(a,f));a.T|=24|e;};clb.Ht=function Ht(a,b){return clb.Lf(a.d,b);};clb.It=function It(a,b){return clb.Cf(a.d,b);};clb.Jt=function Jt(a){var b;clb.Gt(a,31);b=a.I&Zlb;switch(a.I&Mnb){case Ylb:return null;case Gnb:return b==1?'meso':''+b+' meso diastereomers';case 0:return 'unknown chirality';case 196608:return 'both enantiomers';case tnb:return 'this enantiomer';case 327680:return 'this or other enantiomer';case Xmb:return 'two epimers';default:return b==1?'one stereo isomer':''+b+' stereo isomers';}};clb.Kt=function Kt(a){var b;b=new clb.Zt(a.q,a.r);clb.Sj(a,b);return b;};clb.Lt=function Lt(a){var b,c,d,e,f,g,h;clb.Gt(a,15);g=gW(Ykb.AX,gmb,6,3,15,1);for(c=0;c<a.f;c++){if((a.u[c]&Xnb)!=0){h=(a.u[c]&rnb)>>18;h!=0&&(g[h]=$wnd.Math.max(g[h],(a.u[c]&rnb)>>18!=1&&(a.u[c]&rnb)>>18!=2?-1:(a.u[c]&Snb)>>20));}}for(e=0;e<a.g;e++){if(((a.F[e]&3)==1||(a.F[e]&3)==2)&&a.H[e]==1){h=(a.F[e]&768)>>8;h!=0&&(g[h]=$wnd.Math.max(g[h],(a.F[e]&768)>>8!=1&&(a.F[e]&768)>>8!=2?-1:(a.F[e]&Tnb)>>10));}}f=gW(Ykb.AX,Dnb,7,3,0,2);f[1]=gW(Ykb.AX,gmb,6,1+g[1],15,1);f[2]=gW(Ykb.AX,gmb,6,1+g[2],15,1);for(b=0;b<a.f;b++){if((a.u[b]&Xnb)!=0){h=(a.u[b]&rnb)>>18;h!=0&&++f[h][(a.u[b]&rnb)>>18!=1&&(a.u[b]&rnb)>>18!=2?-1:(a.u[b]&Snb)>>20];}}for(d=0;d<a.g;d++){if(((a.F[d]&3)==1||(a.F[d]&3)==2)&&a.H[d]==1){h=(a.F[d]&768)>>8;h!=0&&++f[h][(a.F[d]&768)>>8!=1&&(a.F[d]&768)>>8!=2?-1:(a.F[d]&Tnb)>>10];}}return f;};clb.Mt=function Mt(a){var b,c;b=gW(Ykb.AX,gmb,6,a.q,15,1);c=clb.En(a,b,false,false);return clb.Nt(a,b,c);};clb.Nt=function Nt(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o,p,q,r;q=gW(Ykb.uY,Bob,25,c,0,1);g=gW(Ykb.AX,gmb,6,c,15,1);j=gW(Ykb.AX,gmb,6,c,15,1);f=gW(Ykb.AX,gmb,6,a.q,15,1);for(e=0;e<a.q;e++)b[e]!=-1&&(f[e]=g[b[e]]++);for(i=0;i<a.r;i++){o=b[a.D[0][i]];p=b[a.D[1][i]];o==p&&o!=-1&&++j[o];}for(r=0;r<c;r++){q[r]=new clb.Zt(g[r],j[r]);clb.Ft(a,q[r]);}for(d=0;d<a.q;d++)b[d]!=-1&&clb.Pj(a,q[b[d]],d,0,0);for(h=0;h<a.r;h++){o=b[a.D[0][h]];p=b[a.D[1][h]];o==p&&o!=-1&&clb.Rj(a,q[o],h,0,0,f,false);}for(l=q,m=0,n=l.length;m<n;++m){k=l[m];clb.Cl(k,1);clb.Cl(k,2);}return q;};clb.Ot=function Ot(a){clb.Gt(a,15);!a.d&&(a.f<2||!clb.th(a.J[0],a.J[1]))&&(a.d=new clb.ag(a));return !a.d?null:clb.Gf(a.d);};clb.Pt=function Pt(a){clb.Gt(a,15);!a.d&&(a.f<2||!clb.th(a.J[0],a.J[1]))&&(a.d=new clb.ag(a));return !a.d?null:clb.Df(a.d);};clb.Qt=function Qt(a){var b,c;clb.Gt(a,31);c=0;for(b=0;b<a.f;b++)(a.u[b]&3)!=0&&(a.u[b]&4)==0&&++c;return c;};clb.Rt=function Rt(a,b){return clb.Kf(a.d,b);};clb.St=function St(a,b){a.c=b;a.T&=-144;};clb.Tt=function Tt(a){clb.Gt(a,31);!!a.d&&clb.$f(a.d);};clb.Ut=function Ut(a){var b,c;clb.Gt(a,15);a.L=false;for(b=0;b<a.q;b++){a.u[b]&=$nb;(a.u[b]&3)!=0?a.u[b]|=Wnb:a.u[b]&=Znb;}for(c=0;c<a.r;c++)(a.F[c]&3)!=0&&clb.Hk(a,c)==2?a.H[c]=386:a.H[c]&=-385;a.T&=-249;};clb.Vt=function Vt(a,b,c){var d,e,f,g,h,i,j,k,l;l=a.u[b]&3;if(l==1||l==2){h=false;if(a.o[b]==2&&a.j[b]==2&&a.n[b][0]==2&&a.n[b][1]==2&&a.C[b]<=7){for(g=0;g<a.j[b];g++){d=a.i[b][g];k=0;j=gW(Ykb.AX,gmb,6,3,15,1);for(i=0;i<a.j[d];i++){j[k]=a.i[d][i];j[k]!=b&&++k;}k==2&&j[0]<j[1]^c[j[0]]<c[j[1]]&&(h=!h);}}else {for(g=1;g<a.j[b];g++){for(i=0;i<g;i++){e=a.i[b][g];f=a.i[b][i];e<f^c[e]<c[f]&&(h=!h);}}}h&&(l=l==1?2:1);}return l;};clb.Wt=function Wt(a){var b,c,d,e,f,g;clb.So(a);clb.Gt(a,31);for(d=0;d<a.f;d++){if(((a.u[d]&rnb)>>18==1||(a.u[d]&rnb)>>18==2)&&((a.u[d]&Xnb)==0||(a.u[d]&3)==3))throw c1(new Zkb.rz(Iob));if((a.u[d]&Ylb)!=0)throw c1(new Zkb.rz(Job));if(((a.u[d]&3)==1||(a.u[d]&3)==2)&&a.o[d]==0){b=gW(Ykb.yX,emb,6,a.j[d],15,1);for(f=0;f<a.j[d];f++)b[f]=clb.yk(a,d,a.i[d][f]);for(e=1;e<a.j[d];e++)if(!clb.ql(a,a.k[d][e],d))for(g=0;g<e;g++)if(!clb.ql(a,a.k[d][g],d)){c=$wnd.Math.abs(clb.Mm(b[e],b[g]));if(c<0.08||c>eob)throw c1(new Zkb.rz(Kob));}}}};clb.Xt=function Xt(a){var b,c,d,e,f,g,h;h=false;for(c=0;c<a.f;c++)((a.u[c]&Xnb)==0||(a.u[c]&3)==3)&&(a.u[c]&=$nb);for(f=0;f<a.g;f++)(clb.Hk(a,f)!=1||(a.F[f]&3)==0||(a.F[f]&3)==3)&&(a.F[f]&=-32513);if(a.L){if((a.I&Mnb)!=Gnb){g=gW(Ykb.Z0,Amb,6,a.f,16,1);for(d=0;d<a.f;d++)(a.u[d]&Xnb)!=0&&(a.u[d]&3)!=3&&(a.u[d]&rnb)>>18==1&&(g[d]=true);for(e=0;e<a.f;e++){if((a.u[e]&Xnb)!=0&&(a.u[e]&3)!=3){clb.Nl(a,e,1,0);h=true;}}for(b=0;b<a.f;b++){if(g[b]){clb.Tl(a,b,1,false);clb.Nl(a,b,1,-1);h=true;}}}a.L=false;}clb.Cl(a,1);clb.Cl(a,2);return h;};clb.Yt=function Yt(){clb.wj();clb.Uo.call(this);};clb.Zt=function Zt(a,b){clb.wj();clb.Vo.call(this,a,b);};clb.$t=function $t(a){clb.wj();clb.Wo.call(this,a);};U1(25,91,Lob,clb.Yt,clb.Zt,clb.$t);_.ub=function _t(a){clb.Ft(this,a);};_.wb=function au(a){clb.Gt(this,a);};_.c=false;Ykb.uY=w3(25);clb.cu=function cu(a,b){var c,d,e,f,g,h,i,j,k,l,m;h=new dlb.Qi();clb.Gt(b,1);j=gW(Ykb.Z0,Amb,6,b.f,16,1);for(c=0;c<b.f;c++){if(a.f[c]&&(clb.uk(a.i,c)==7||clb.uk(a.i,c)==8||clb.uk(a.i,c)==16||clb.uk(a.i,c)==34||clb.uk(a.i,c)==52)){j[c]=true;for(i=0;i<b.j[c];i++){d=b.i[c][i];f=b.k[c][i];l=b.n[c][i];if(b.o[d]!=0&&b.o[c]<l){j[d]=true;dlb.wi(h,Zkb.t4(f));for(k=0;k<b.j[d];k++){e=b.i[d][k];if(!j[e]){j[e]=true;g=b.k[d][k];m=b.n[d][k];if(b.o[d]+2==l+m){dlb.wi(h,Zkb.t4(g));l>=m&&(b.o[e]<m?clb.lu(b,e)&&clb.fu(a,b,e,true,false,j,h):clb.fu(a,b,e,true,true,j,h));m>=l&&clb.lu(b,c)&&clb.fu(a,b,e,false,false,j,h);if(a.f[e]&&(clb.uk(a.i,e)==5||clb.uk(a.i,e)==6||clb.uk(a.i,e)==7||clb.uk(a.i,e)==8||clb.uk(a.i,e)==16||clb.uk(a.i,e)==34||clb.uk(a.i,e)==52)&&b.o[e]<m){l<=2&&m>=2&&clb.lu(b,c)&&clb.du(a,b,f,g);l>=2&&m<=2&&clb.lu(b,e)&&clb.du(a,b,g,f);}dlb.Ii(h,h.a.length-1);}j[e]=false;}}dlb.Ii(h,h.a.length-1);j[d]=false;}}j[c]=false;}}};clb.du=function du(a,b,c,d){var e;e=new clb.ru(a,b);clb.qu(e,c,clb.Hk(b,c)==1?2:3);clb.qu(e,d,clb.Hk(b,d)==2?1:2);a.g[c]=true;a.g[d]=true;dlb.cfb(a.e,e)&&(dlb.hbb(a.d,e),true);};clb.eu=function eu(a,b){dlb.cfb(a.e,b)&&(dlb.hbb(a.d,b),true);};clb.fu=function fu(a,b,c,d,e,f,g){var h,i,j,k,l,m,n,o,p,q,r,s;for(n=0;n<b.j[c];n++){h=b.i[c][n];if(!f[h]){k=b.k[c][n];r=clb.Hk(b,k);if(d&&r>=2||!d&&r<=2){f[h]=true;g.add(Zkb.t4(k));for(o=0;o<b.j[h];o++){i=b.i[h][o];if(!f[i]){l=b.k[h][o];s=clb.Hk(b,l);if(b.o[h]+2==r+s&&(d&&s<=2||!d&&s>=2)){f[i]=true;g.add(Zkb.t4(l));if(a.f[i]&&(clb.uk(a.i,i)==5||clb.uk(a.i,i)==6||clb.uk(a.i,i)==7||clb.uk(a.i,i)==8||clb.uk(a.i,i)==16||clb.uk(a.i,i)==34||clb.uk(a.i,i)==52)&&(!d||clb.lu(b,i))){m=new clb.ru(a,b);for(p=0;p<g.a.length;p++){j=(alb.Dgb(p,g.a.length),g.a[p]).a;q=p<2?d^(p&1)==0:e^(p&1)==0;q?clb.qu(m,j,clb.Hk(b,j)==1?2:3):clb.qu(m,j,clb.Hk(b,j)==2?1:2);a.g[j]=true;}dlb.cfb(a.e,m)&&(dlb.hbb(a.d,m),true);}else {clb.fu(a,b,i,d,e,f,g);}dlb.Ii(g,g.a.length-1);f[i]=false;}}}dlb.Ii(g,g.a.length-1);f[h]=false;}}}return false;};clb.gu=function gu(a){var b,c,d,e,f,g,h,i,j,k,l;a.b=gW(Ykb.AX,gmb,6,a.i.f,15,1);h=gW(Ykb.AX,gmb,6,a.i.f,15,1);d=gW(Ykb.Z0,Amb,6,a.i.g,16,1);l=0;for(c=0;c<a.i.g;c++){if(!d[c]&&a.g[c]){++l;a.b[clb.zk(a.i,0,c)]=l;a.b[clb.zk(a.i,1,c)]=l;d[c]=true;for(j=0;j<2;j++){b=clb.zk(a.i,j,c);a.b[b]=l;g=0;i=0;h[0]=b;while(g<=i){for(k=0;k<clb.wn(a.i,h[g]);k++){f=clb.xn(a.i,h[g],k);if(!d[f]&&a.g[f]){d[f]=true;e=clb.vn(a.i,h[g],k);if(a.b[e]==0){a.b[e]=l;h[++i]=e;}}}++g;}}}}a.j=l;};clb.hu=function hu(a){var b,c,d;a.n=gW(Ykb.AX,gmb,6,a.j,15,1);a.k=gW(Ykb.AX,gmb,6,a.j,15,1);a.o=gW(Ykb.AX,gmb,6,a.j,15,1);for(b=0;b<a.i.f;b++){if(a.b[b]!=0){d=a.b[b]-1;a.a!=null&&(a.k[d]+=a.a[b]);a.c!=null&&(a.o[d]+=a.c[b]);}}for(c=0;c<a.i.g;c++){a.g[c]&&clb.Hk(a.i,c)==2&&(a.n[a.b[clb.zk(a.i,0,c)]-1]+=2);}};clb.iu=function iu(a){var b,c,d,e;for(d=0;d<a.i.r;d++){for(e=0;e<2;e++){b=clb.zk(a.i,e,d);c=clb.zk(a.i,1-e,d);if(clb.uk(a.i,b)==1&&clb.nk(a.i,b)>1&&clb.uk(a.i,c)>1&&a.b[c]!=0){if(clb.nk(a.i,b)==2){a.a==null&&(a.a=gW(Ykb.AX,gmb,6,a.i.q,15,1));++a.a[c];}else {a.c==null&&(a.c=gW(Ykb.AX,gmb,6,a.i.q,15,1));++a.c[c];}clb.sl(a.i,b);}}}(a.a!=null||a.c!=null)&&clb.Zj(a.i);};clb.ju=function ju(a){var b;a.e=new dlb.hfb();a.d=new dlb.tbb();clb.eu(a,new clb.ru(a,a.i));b=clb.Kt(a.i);while(!dlb.lbb(a.d)){clb.pu(dlb.nbb(a.d),b);clb.cu(a,b);if(a.e.a.c>=clb.bu){Zkb.O5();'Tautomer count exceeds maximum: '+clb.Gf(new clb.ag(a.i));break;}}};clb.ku=function ku(a){var b,c,d,e,f,g,h,i,j,k;if(a.e.a.c==1)return a.i;j=clb.Kt(a.i);clb.lm(j,true);clb.Gt(j,7);for(e=0;e<j.g;e++){if(a.g[e]){j.H[e]=1;j.T=0;clb.im(j,e,3,true);}}for(c=0;c<j.f;c++){if(a.b[c]!=0&&clb.On(a.i,c)<4){clb.Ym(j,c);j.u[c]&=Znb;j.T&=7;clb.Nl(j,c,0,-1);}}h=gW(Ykb.AX,gmb,6,a.j,15,1);i=gW(Ykb.AX,gmb,6,a.j,15,1);d=new clb.ag(j).d;for(b=0;b<j.f;b++){if(a.b[b]!=0){k=a.b[b]-1;if(i[k]<d[b]){i[k]=d[b];h[k]=b;}}}for(f=0;f<a.j;f++){g=''+a.n[f]+'|'+a.k[f]+'|'+a.o[f];clb.Ll(j,h[f],g);}return j;};clb.lu=function lu(a,b){if(a.e[b]-clb.On(a,b)+clb.Kn(a,b)<=0)return false;if(clb.gl(a,b))return true;if(a.o[b]!=0)return false;return true;};clb.mu=function mu(a){var b,c,d,e,f,g,h,i;clb.Gt(a.i,1);h=a.i.f;do--h;while(h>=0&&clb.uk(a.i,h)==1);for(b=0;b<h;b++){if(clb.uk(a.i,b)==1){clb.wm(a.i,b,h);do--h;while(clb.uk(a.i,h)==1);}}if(h==a.i.f-1)return;g=gW(Ykb.Z0,Amb,6,a.i.g,16,1);for(f=0;f<a.i.g;f++){c=clb.zk(a.i,0,f);d=clb.zk(a.i,1,f);(clb.uk(a.i,c)==1||clb.uk(a.i,d)==1)&&(g[f]=true);}i=a.i.g;do--i;while(i>=0&&g[i]);for(e=0;e<i;e++){if(g[e]){clb.xm(a.i,e,i);g[e]=false;do--i;while(g[i]);}}};clb.nu=function nu(a){var b,c;this.i=clb.Kt(a);clb.mu(this);clb.Gt(this.i,7);this.g=gW(Ykb.Z0,Amb,6,this.i.g,16,1);this.f=gW(Ykb.Z0,Amb,6,this.i.f,16,1);for(b=0;b<this.i.f;b++){c=clb.Km(clb.uk(this.i,b))[0];this.f[b]=clb.On(this.i,b)<c;}clb.ju(this);clb.gu(this);clb.iu(this);clb.hu(this);};U1(188,1,{},clb.nu);_.j=0;clb.bu=Mob;Ykb.wY=w3(188);clb.ou=function ou(a,b){return slb.MT(a.a,b.a);};clb.pu=function pu(a,b){var c,d;for(d=0;d<a.b.i.g;d++){if(a.b.g[d]){c=3&a.a[d>>4]>>2*(d&15);clb.jm(b,d,c==1?1:c==2?a.b.g[d]&&!clb.Co(a.b.i,d)?386:2:c==3?4:32);}}};clb.qu=function qu(a,b,c){var d,e;d=b>>4;e=2*(b&15);a.a[d]&=~(3<<e);a.a[d]|=c<<e;};clb.ru=function ru(a,b){var c;this.b=a;this.a=gW(Ykb.AX,gmb,6,(a.i.g+15)/16|0,15,1);for(c=0;c<a.i.g;c++)this.a[c>>4]|=$wnd.Math.min(3,clb.Hk(b,c))<<2*(c&15);};U1(127,1,{127:1,27:1},clb.ru);_.qb=function su(a){return clb.ou(this,a);};Ykb.vY=w3(127);clb.tu=function tu(a){var b,c,d,e,f;c=Zkb.g5(a,s5(38));if(c==-1)return a;e=0;f=new Zkb.z5();while(c!=-1){Zkb.y5(f,(alb.Jgb(e,c,alb.Pgb(a).length),alb.Pgb(a).substr(e,c-e)));alb.Kgb(c+1,alb.Pgb(a).length);if(alb.Pgb(a).charCodeAt(c+1)==38){f.a+='&';e=c+2;}else {b=(alb.Kgb(c+1,alb.Pgb(a).length),alb.Pgb(a).charCodeAt(c+1));b=b-(b<65?48:b<97?65:97);d=(alb.Kgb(c+2,alb.Pgb(a).length),alb.Pgb(a).charCodeAt(c+2));d=d-(d<65?48:d<97?65:97);Zkb.w5(f,16*b+d&Zlb);e=c+3;}c=Zkb.h5(a,s5(38),e);}Zkb.y5(f,(alb.Kgb(e,alb.Pgb(a).length+1),alb.Pgb(a).substr(e)));return f.a;};clb.uu=function uu(a){var b,c;c=new Zkb.z5();for(b=0;b<alb.Pgb(a).length;b++){switch(alb.Kgb(b,alb.Pgb(a).length),alb.Pgb(a).charCodeAt(b)){case 38:c.a+='&&';break;case 9:c.a+='&09';break;case 10:c.a+='&0A';break;case 32:c.a+='&20';break;default:Zkb.w5(c,(alb.Kgb(b,alb.Pgb(a).length),alb.Pgb(a).charCodeAt(b)));}}return c.a;};clb.vu=function vu(a,b,c){a.e[0].a=b;a.e[0].b=c;};clb.wu=function wu(b,c){try{b.a=a4(c);}catch(a){a=b1(a);if(!mX(a,35))throw c1(a);}};clb.xu=function xu(b,c){try{b.b=Zkb.P3(c,oob,Qlb);}catch(a){a=b1(a);if(!mX(a,35))throw c1(a);}};clb.yu=function yu(a,b,c,d){a.c=b;a.a=c;a.b=d;};clb.zu=function zu(b,c){try{b.e[0].a=a4(c);}catch(a){a=b1(a);if(!mX(a,35))throw c1(a);}};clb.Au=function Au(b,c){try{b.e[0].b=a4(c);}catch(a){a=b1(a);if(!mX(a,35))throw c1(a);}};clb.Bu=function Bu(){clb.Du.call(this,new plb.OF());};clb.Cu=function Cu(a){var b,c,d,e;clb.Bu.call(this);b=0;while(b!=-1){c=alb.Pgb(a).indexOf('="',b);if(c==-1)break;d=(alb.Jgb(b+1,c,alb.Pgb(a).length),alb.Pgb(a).substr(b+1,c-(b+1)));b=alb.Pgb(a).indexOf('"',c+2);e=b==-1?(alb.Kgb(c+1,alb.Pgb(a).length+1),alb.Pgb(a).substr(c+1)):(alb.Jgb(c+1,b,alb.Pgb(a).length),alb.Pgb(a).substr(c+1,b-(c+1)));Zkb.c5(d,'text')?this.c=clb.tu(e):Zkb.c5(d,'x')?clb.zu(this,e):Zkb.c5(d,'y')?clb.Au(this,e):Zkb.c5(d,'size')?clb.wu(this,e):Zkb.c5(d,'style')&&clb.xu(this,e);}};clb.Du=function Du(a){this.c='';this.a=9;this.b=0;this.e=gW(Ykb.QZ,Ulb,50,1,0,1);this.e[0]=a;};U1(129,154,{154:1},clb.Bu,clb.Cu);_.mb=function Eu(){var a;a=new clb.Bu();clb.yu(a,this.c,this.a,this.b);clb.vu(a,this.e[0].a,this.e[0].b);a.d=this.d;return a;};_.nb=function Fu(){var a;a=new Zkb.J5();Zkb.G5(a,' text="'+clb.uu(this.c)+'"');Zkb.G5(a,' x="'+this.e[0].a+'"');Zkb.G5(a,' y="'+this.e[0].b+'"');this.a!=9&&Zkb.G5(a,' size="'+this.a+'"');this.b!=0&&Zkb.G5(a,' style="'+this.b+'"');return a.a;};_.ob=function Gu(){return 'text';};_.a=0;_.b=0;Ykb.xY=w3(129);clb.Hu=function Hu(a){a.b=new dlb.Qi();a.a=new dlb.Qi();};clb.Iu=function Iu(a,b){var c,d;c=clb.Bt(a,b);if(c==-1)return -1;d=a.b.a.length;dlb.wi(a.b,b);dlb.vi(a.a,c,new Zkb.h4(d));return d;};clb.Ju=function Ju(){clb.Dt.call(this);clb.Hu(this);};U1(231,77,{77:1,4:1},clb.Ju);_.zb=function Ku(a){var b;b=clb.Ct(this,a);if(b==-1)return -1;return dlb.Bi(this.a,b).a;};Ykb.yY=w3(231);elb.Lu=function Lu(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G,H,I,J,K,L,M,N;K=clb.Xn(a.e);L=dlb.Bi(K.j,b).length;I=dlb.Bi(K.i,b);J=dlb.Bi(K.j,b);C=true;for(r=1;r<L;r++){if(elb.$u(a.b,J[r])!=elb.$u(a.b,J[0])){C=false;break;}}if(C){f=(L-2)*Nob/L;for(s=0;s<L;s++)elb.Qu(a,I[s],J[s],J[s==0?L-1:s-1],f);return;}G=gW(Ykb.zX,cob,6,L,15,1);e=0;for(t=0;t<L;t++){G[t]=clb.mn(a.e,I[t])==0?1.9106119386631804:clb.mn(a.e,I[t])==1?2.094499897810209:Nob;e+=G[t];}d=((L-2)*Nob-e)/L;for(u=0;u<L;u++)G[u]+=d;k=gW(Ykb.zX,cob,6,L,15,1);for(v=1;v<L;v++)k[v]=k[v-1]+Nob-G[v];h=gW(Ykb.zX,cob,6,L,15,1);for(g=0;g<100;g++){M=0;N=0;for(s=0;s<L;s++){M+=elb.$u(a.b,J[s])*$wnd.Math.sin(k[s]);N+=elb.$u(a.b,J[s])*$wnd.Math.cos(k[s]);}n=clb.Lm(0,0,M,N);p=$wnd.Math.sqrt(M*M+N*N);F=-1;D=0;for(w=0;w<L;w++){A=w==0?L-1:w-1;B=w+1==L?0:w+1;i=clb.Mm(k[w],k[A]);j=clb.Mm(k[B],k[w]);H=clb.Mm(G[w],G[B]);h[w]=2*i-2*j+2*H;o=$wnd.Math.cos(k[w]-Oob-n);m=p*o-Pob*h[w];if($wnd.Math.abs(m)>$wnd.Math.abs(D)){D=m;F=w;}}l=$wnd.Math.exp(-5*g/100);k[F]+=l*D;}for(q=0;q<L;q++){A=q==0?L-1:q-1;c=k[A]+Nob-k[q];c>Emb&&(c-=Emb);elb.Qu(a,I[q],J[A],J[q],c);}};elb.Mu=function Mu(a,b){var c,d,e,f,g,h,i,j,k;i=clb.Xn(a.e);j=dlb.Bi(i.j,b).length;h=dlb.Bi(i.j,b);k=false;for(e=0;e<j;e++){if(a.f[h[e]]==0){k=true;break;}}if(k){c=(180*j-360)/j*0.01745329238474369;g=dlb.Bi(i.i,b);for(f=0;f<j;f++){elb.Qu(a,g[f],h[f==0?j-1:f-1],h[f],c);}if(j<=4){for(d=0;d<j;d++)a.f[h[d]]+=j;}}};elb.Nu=function Nu(a,b,c,d){var e,f,g,h;f=-1;g=-1;for(h=0;h<clb.gn(a.e,b);h++){e=clb.vn(a.e,b,h);if(e==c||e==d){if(g==-1){g=h;}else {f=h;break;}}}return a.a[b][f][g];};elb.Ou=function Ou(a,b,c,d){return c<d?a.a[b][d][c]:a.a[b][c][d];};elb.Pu=function Pu(a,b){var c,d,e,f,g,h,i;d=gW(Ykb.Z0,Amb,6,clb.wn(a.e,b),16,1);i=0;for(e=0;e<clb.wn(a.e,b);e++){h=0;g=-1;for(f=0;f<clb.wn(a.e,b);f++){if(!d[f]){c=clb.xn(a.e,b,f);if(h<a.f[c]){h=a.f[c];g=f;}}}if(h==0)return i;i<<=8;i+=h;d[g]=true;}return i;};elb.Qu=function Qu(a,b,c,d,e){var f,g,h,i;f=-1;g=-1;for(i=0;i<clb.gn(a.e,b);i++){h=clb.xn(a.e,b,i);if(h==c||h==d){if(f==-1){f=i;}else {g=i;break;}}}if(a.a[b][g][f]==0){a.a[b][g][f]=e;a.d[b]+=e;++a.c[b];}};elb.Ru=function Ru(a,b,c,d,e){var f,g,h,i,j,k;f=clb.gn(a.e,b);i=clb.wn(a.e,b);for(j=1;j<f;j++){g=j<i?a.f[clb.xn(a.e,b,j)]:0;for(k=0;k<j;k++){if(a.a[b][j][k]==0){h=k<i?a.f[clb.xn(a.e,b,k)]:0;(g==c&&h==d||g==d&&h==c)&&(a.a[b][j][k]=e);}}}};elb.Su=function Su(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A;this.b=b;this.e=a;this.a=gW(Ykb.zX,Llb,343,this.e.f,0,3);for(e=0;e<this.e.f;e++){this.a[e]=gW(Ykb.zX,{343:1,4:1,10:1,5:1,8:1},36,clb.gn(this.e,e),0,2);for(i=1;i<clb.gn(this.e,e);i++)this.a[e][i]=gW(Ykb.zX,cob,6,i,15,1);}this.c=gW(Ykb.AX,gmb,6,this.e.f,15,1);this.d=gW(Ykb.zX,cob,6,this.e.f,15,1);this.f=gW(Ykb.AX,gmb,6,this.e.g,15,1);w=clb.Xn(this.e);m=gW(Ykb.Z0,Amb,6,w.i.a.length,16,1);clb.dr(w,m,gW(Ykb.Z0,Amb,6,w.i.a.length,16,1),gW(Ykb.AX,gmb,6,w.i.a.length,15,1),true);for(h=3;h<=7;h++){for(r=0;r<w.i.a.length;r++){A=dlb.Bi(w.j,r).length;A==h&&(m[r]?elb.Lu(this,r):A<=4&&elb.Mu(this,r));}}l=gW(Ykb.Z0,Amb,6,this.e.f,16,1);for(q=0;q<w.i.a.length;q++)if(m[q])for(t=dlb.Bi(w.i,q),u=0,v=t.length;u<v;++u){s=t[u];l[s]=true;}f=oW(aW(Ykb.AX,1),gmb,6,15,[0,0,1,3,6,10,15,21]);for(d=0;d<this.e.f;d++){g=clb.gn(this.e,d);if(g>4){for(i=1;i<g;i++)for(o=0;o<i;o++)this.a[d][i][o]=Oob;this.c[d]=f[g];continue;}if(this.c[d]==f[g])continue;if(clb.Bo(this.e,d)&&(l[d]||clb.qn(this.e,d)<=4&&clb.mn(this.e,d)>0)){if(g>2){if(this.c[d]==1){clb.uk(this.e,d)<=14?c=(Qob-this.d[d])/2:c=Rob+(Rob-this.d[d])*0.18000000715255737;}else {c=Qob-this.d[d];if(g>3){if(this.c[d]==2){n=gW(Ykb.Z0,Amb,6,clb.gn(this.e,d),16,1);for(j=1;j<g;j++){for(p=0;p<j;p++){if(this.a[d][j][p]!=0){n[j]=!n[j];n[p]=!n[p];}}}for(k=0;k<g;k++){if(n[k]){for(p=k+1;p<g;p++){if(n[p]){this.a[d][p][k]=c;break;}}break;}}}c=Oob;}}for(i=1;i<g;i++)for(o=0;o<i;o++)this.a[d][i][o]==0&&(this.a[d][i][o]=c);}}else if(clb.Bo(this.e,d)&&clb.qn(this.e,d)<=4){switch(elb.Pu(this,d)){case 771:elb.Ru(this,d,0,3,2.0653998851776123);elb.Ru(this,d,0,0,1.9814722631346626);break;case 1028:elb.Ru(this,d,0,4,1.9797999858856201);elb.Ru(this,d,0,0,1.94691481878138);break;case 393987:elb.Ru(this,d,0,3,Sob);elb.Ru(this,d,0,6,Sob);elb.Ru(this,d,3,3,1.7229016938441077);break;case 459779:elb.Ru(this,d,0,3,Tob);elb.Ru(this,d,0,4,Tob);elb.Ru(this,d,0,7,Tob);elb.Ru(this,d,3,4,1.9322539839360076);break;case 525316:elb.Ru(this,d,0,4,Uob);elb.Ru(this,d,0,8,Uob);elb.Ru(this,d,4,4,1.99944913298566);case 394758:elb.Ru(this,d,0,6,2.526099920272827);break;case 460550:elb.Ru(this,d,0,6,Vob);elb.Ru(this,d,0,7,Vob);break;case 526087:elb.Ru(this,d,0,7,Wob);elb.Ru(this,d,0,8,Wob);break;case 526344:elb.Ru(this,d,0,8,2.186300039291382);break;case 50529027:elb.Ru(this,d,3,3,2.4189000129699707);break;case 67371779:elb.Ru(this,d,3,4,2.2298998832702637);break;case 67372036:elb.Ru(this,d,4,4,2.094399929046631);break;case 101057283:elb.Ru(this,d,3,6,1.839926051241747);elb.Ru(this,d,3,3,2.9061476191098734);break;case 117834755:elb.Ru(this,d,3,4,2.812249087174905);elb.Ru(this,d,3,7,1.7910569124592968);elb.Ru(this,d,4,6,2.1224948975613245);break;case 134677507:elb.Ru(this,d,3,4,2.642428360523752);elb.Ru(this,d,3,8,2.027723514585844);elb.Ru(this,d,4,7,2.251474717631936);break;case 117900035:elb.Ru(this,d,3,7,2.109753935530918);elb.Ru(this,d,3,3,3.1052897491356646);break;case 117900292:elb.Ru(this,d,4,7,2.090729910747413);elb.Ru(this,d,4,4,2.551671293386306);break;case 134743044:elb.Ru(this,d,4,8,2.139250042271712);elb.Ru(this,d,4,4,2.3520055858942612);}}else {c=clb.uk(this.e,d)>10?Xob:clb.mn(this.e,d)==2?Nob:clb.so(this.e,d,true)?Yob:clb.mn(this.e,d)==0?Xob:Yob;for(i=1;i<g;i++)for(o=0;o<i;o++)this.a[d][i][o]=c;}}};U1(277,1,{},elb.Su);Ykb.zY=w3(277);elb.Zu=function Zu(){elb.Zu=W1;elb.Xu=oW(aW(Ykb.Z0,1),Amb,6,16,[false,false,false,false,false,true,true,true,true,false,false,false,false,false,false,true,true]);};elb.$u=function $u(a,b){return a.a[b];};elb._u=function _u(a){elb.Zu();var b,c;clb.Gt(a,7);this.a=gW(Ykb.zX,cob,6,a.r,15,1);this.b=gW(Ykb.zX,cob,6,a.r,15,1);for(b=0;b<a.r;b++){c=elb.cv(a,b);if(c==-1){this.a[b]=elb.dv(a,b);this.b[b]=elb.ev(a,b);}else {this.a[b]=c==-1?2.000499963760376:elb.Vu[c];this.b[b]=c==-1?1:elb.Wu[c];}}};elb.av=function av(a,b){if(b>=a.f)return 0;if(b<a.f&&clb.rr(a.p,b)&&a.C[b]==6&&a.s[b]!=0)return 1;return a.o[b];};elb.bv=function bv(a,b,c,d,e,f,g){var h,i,j,k,l;k=d<elb.Xu.length&&elb.Xu[d]?f<<8:0;l=e<elb.Xu.length&&elb.Xu[e]?g<<8:0;h=k+d;i=l+e;j=c?0:b?4+a:a;return (j<<24)+(h<i?(h<<12)+i:(i<<12)+h);};elb.cv=function cv(a,b){var c,d,e,f;c=a.D[0][b];d=a.D[1][b];e=a.C[c];f=a.C[d];return elb.gv(elb.bv(clb.Hk(a,b),b<a.g&&clb.sr(a.p,b),b<a.g&&(clb.wr(a.p,b)||a.H[b]==64),e,f,elb.av(a,c),elb.av(a,d)));};elb.dv=function dv(a,b){var c,d;c=clb.uk(a,a.D[0][b]);d=clb.uk(a,a.D[1][b]);return (c<(elb.Fw(),elb.Dw).length?elb.Dw[c]:c<elb.Ew.length?Zob*elb.Ew[c]:$ob)+(d<elb.Dw.length?elb.Dw[d]:d<elb.Ew.length?Zob*elb.Ew[d]:$ob);};elb.ev=function ev(a,b){var c,d;c=clb.uk(a,a.D[0][b]);d=clb.uk(a,a.D[1][b]);return (c<(elb.Fw(),elb.Dw).length?_ob:0.125)+(d<elb.Dw.length?_ob:0.125);};elb.fv=function fv(){var b,c,d,e,f,g,h;if(!elb.Yu){b=(h=Zkb.n5('2312\n4099\t2.403\t0.282\t466\n4100\t1.407\t0.2\t28\n4103\t1.561\t0.023\t5\n4104\t1.42\t0.092\t491\n4105\t1.313\t0.149\t32\n4107\t2.677\t0.401\t190\n4108\t2.118\t0.244\t325\n4109\t1.978\t0.26\t968\n4113\t1.819\t0.033\t4\n4115\t3.194\t0.482\t381\n4116\t2.771\t0.32\t198\n4117\t2.398\t0.235\t145\n4118\t2.317\t0.22\t208\n4119\t2.034\t0.212\t34\n4120\t2.033\t0.286\t103\n4121\t1.959\t0.264\t122\n4122\t1.918\t0.267\t664\n4123\t1.893\t0.257\t185\n4124\t1.877\t0.218\t259\n4125\t2.05\t0.257\t556\n4126\t2.012\t0.239\t129\n4127\t1.979\t0.292\t196\n4133\t3.305\t0.429\t34\n4134\t2.593\t0.367\t83\n4135\t2.74\t0.174\t706\n4136\t2.462\t0.196\t611\n4137\t2.207\t0.264\t78\n4138\t2.16\t0.225\t359\n4140\t2.004\t0.188\t2204\n4141\t1.916\t0.256\t610\n4142\t1.95\t0.234\t126\n4143\t2.3\t0.213\t81\n4144\t2.187\t0.116\t6\n4145\t2.103\t0.153\t21\n4146\t2.031\t0.308\t83\n4147\t1.752\t0.443\t21\n4151\t3.49\t0.4\t83\n4152\t3.017\t0.331\t40\n4153\t2.932\t0.276\t176\n4154\t2.39\t0.34\t24\n4155\t3.124\t0.377\t16\n4156\t2.907\t0.232\t198\n4158\t2.857\t0.237\t142\n4159\t2.687\t0.244\t49\n4160\t2.787\t0.359\t29\n4161\t2.785\t0.306\t37\n4162\t2.623\t0.298\t175\n4163\t2.812\t0.154\t70\n4164\t2.745\t0.281\t100\n4165\t2.719\t0.184\t37\n4166\t2.683\t0.361\t231\n4167\t2.655\t0.253\t198\n4168\t2.546\t0.208\t37\n4169\t2.259\t0.231\t190\n4170\t2.043\t0.289\t251\n4171\t2.001\t0.221\t391\n4172\t1.984\t0.164\t885\n4173\t1.904\t0.228\t1074\n4174\t2.036\t0.224\t250\n4175\t1.955\t0.184\t6\n4176\t2.35\t0.15\t12\n4177\t2.367\t0.216\t7\n4178\t2.47\t0.186\t11\n4179\t0.95\t-1.0\t1\n4186\t2.88\t0.309\t39\n4188\t2.804\t0.289\t136\n4189\t2.172\t0.082\t12\n4190\t2.321\t0.0\t2\n4359\t1.503\t0.106\t24\n4360\t1.425\t0.052\t40\n12291\t2.861\t0.27\t1069\n12292\t2.773\t0.086\t4\n12293\t2.507\t0.251\t27\n12294\t2.769\t0.373\t370\n12299\t3.1\t0.221\t116\n12300\t2.844\t0.146\t9\n12301\t3.636\t0.002\t3\n12302\t2.779\t0.318\t189\n12307\t3.639\t0.518\t25\n12308\t3.205\t0.245\t16\n12317\t3.036\t0.064\t4\n12318\t2.88\t-1.0\t1\n12319\t2.615\t0.864\t3\n12320\t2.857\t0.129\t247\n12325\t3.557\t0.41\t18\n12326\t3.273\t0.208\t23\n12330\t3.496\t0.025\t2\n12333\t3.012\t0.276\t2\n12334\t2.679\t0.0\t2\n12338\t2.886\t0.196\t80\n12339\t2.871\t0.221\t18\n12343\t3.628\t0.266\t9\n12344\t3.37\t0.145\t35\n12346\t2.859\t0.0\t4\n12352\t2.722\t0.017\t4\n12354\t3.317\t0.016\t4\n12355\t2.714\t0.006\t2\n12357\t2.703\t0.005\t2\n12365\t2.615\t-1.0\t1\n12367\t2.729\t0.0\t2\n12368\t2.841\t0.0\t2\n12369\t2.889\t0.082\t5\n12370\t2.913\t0.126\t64\n12549\t3.003\t0.175\t18\n12550\t2.797\t0.21\t1156\n12805\t2.63\t0.0\t2\n12806\t2.939\t0.243\t85\n16388\t2.29\t0.104\t57\n16389\t2.022\t0.097\t6\n16390\t2.097\t0.127\t21\n16391\t1.771\t0.395\t281\n16392\t1.648\t0.242\t634\n16393\t1.567\t0.555\t264\n16395\t2.926\t0.104\t14\n16397\t2.368\t-1.0\t1\n16398\t3.269\t-1.0\t1\n16399\t2.211\t0.15\t6\n16400\t2.1\t-1.0\t1\n16401\t2.065\t0.622\t37\n16403\t3.355\t0.087\t11\n16404\t2.9\t0.136\t2\n16416\t2.399\t0.154\t3\n16417\t2.06\t0.0\t2\n16418\t2.195\t-1.0\t1\n16419\t2.167\t0.95\t16\n16421\t3.378\t-1.0\t1\n16422\t2.886\t0.031\t2\n16429\t2.375\t0.124\t6\n16435\t2.635\t-1.0\t1\n16436\t2.399\t-1.0\t1\n16437\t2.417\t0.96\t23\n16439\t3.716\t0.078\t2\n16442\t3.052\t0.0\t4\n16463\t2.64\t-1.0\t1\n16466\t2.23\t-1.0\t1\n16474\t3.061\t0.0\t4\n16476\t3.017\t0.004\t8\n16645\t1.954\t-1.0\t1\n16646\t2.276\t0.281\t56\n16647\t1.966\t0.14\t51\n16648\t1.843\t0.124\t41\n16902\t1.739\t0.003\t2\n16903\t2.003\t-1.0\t1\n20491\t2.681\t-1.0\t1\n20492\t2.402\t0.287\t12\n20493\t2.373\t0.17\t6\n20499\t3.054\t0.395\t11\n20500\t3.076\t0.081\t2\n20501\t2.3\t1.168\t20\n20502\t2.221\t0.057\t3\n20503\t1.964\t-1.0\t1\n20504\t2.515\t0.236\t21\n20505\t1.97\t0.231\t70\n20506\t2.056\t0.352\t138\n20507\t2.553\t0.302\t81\n20508\t2.489\t0.321\t24\n20509\t2.215\t0.363\t36\n20510\t2.786\t0.026\t6\n20511\t2.418\t0.106\t10\n20517\t3.193\t0.063\t3\n20519\t2.598\t0.187\t9\n20520\t2.376\t0.309\t9\n20522\t2.708\t0.265\t154\n20524\t2.526\t0.319\t123\n20525\t2.262\t0.289\t122\n20526\t2.502\t0.287\t18\n20527\t2.365\t0.284\t11\n20528\t2.966\t0.038\t6\n20529\t2.584\t0.061\t7\n20530\t2.771\t0.387\t5\n20531\t1.29\t0.001\t12\n20535\t3.368\t0.154\t5\n20536\t3.023\t0.074\t6\n20537\t2.913\t0.0\t2\n20538\t3.021\t0.331\t2\n20540\t2.651\t0.201\t5\n20543\t2.735\t0.344\t5\n20546\t2.531\t0.277\t7\n20549\t3.267\t-1.0\t1\n20550\t2.329\t0.34\t7\n20552\t2.499\t0.02\t6\n20553\t2.703\t0.218\t20\n20554\t2.693\t0.292\t46\n20555\t2.639\t0.27\t40\n20556\t2.066\t0.059\t39\n20557\t2.599\t0.324\t183\n20558\t2.048\t0.149\t134\n20559\t2.327\t0.386\t34\n20560\t2.179\t-1.0\t1\n20561\t2.619\t-1.0\t1\n20562\t2.967\t-1.0\t1\n20570\t2.665\t0.007\t2\n20572\t2.63\t0.19\t9\n20742\t1.87\t0.155\t40\n24587\t3.525\t0.393\t28\n24588\t2.763\t0.313\t380\n24589\t2.462\t0.308\t5373\n24595\t4.077\t0.356\t19\n24596\t3.17\t0.362\t45\n24597\t2.829\t0.525\t432\n24598\t2.656\t0.164\t627\n24599\t2.654\t0.158\t57\n24600\t2.57\t0.26\t309\n24601\t2.625\t0.288\t208\n24602\t2.45\t0.223\t1004\n24603\t2.182\t0.257\t1071\n24604\t2.355\t0.185\t1159\n24605\t2.384\t0.162\t130\n24606\t2.479\t0.188\t1375\n24607\t2.547\t0.23\t805\n24613\t3.789\t0.188\t2\n24614\t3.484\t0.291\t8\n24615\t3.089\t0.34\t499\n24616\t2.809\t0.177\t912\n24617\t2.665\t0.147\t106\n24618\t2.632\t0.3\t598\n24620\t2.419\t0.207\t1127\n24621\t2.466\t0.217\t582\n24622\t2.456\t0.168\t1672\n24623\t2.573\t0.135\t12\n24624\t2.753\t0.503\t34\n24625\t2.695\t0.487\t478\n24626\t2.644\t0.444\t4321\n24627\t2.655\t0.961\t518\n24631\t3.712\t0.709\t3\n24632\t3.745\t0.575\t6\n24633\t3.382\t0.306\t128\n24634\t3.417\t0.336\t41\n24635\t3.236\t0.278\t27\n24636\t3.365\t0.272\t72\n24638\t3.236\t0.316\t52\n24639\t3.097\t0.0\t2\n24640\t2.718\t0.258\t39\n24641\t3.353\t0.103\t6\n24642\t3.087\t0.178\t51\n24643\t2.988\t0.348\t31\n24644\t2.995\t0.182\t58\n24645\t3.221\t0.798\t58\n24646\t3.104\t0.353\t86\n24647\t3.019\t0.515\t320\n24648\t2.735\t0.176\t341\n24649\t2.703\t0.204\t299\n24650\t2.595\t0.331\t829\n24651\t2.536\t0.58\t227\n24652\t2.472\t0.25\t206\n24653\t2.534\t0.168\t933\n24654\t2.491\t0.326\t1889\n24655\t2.445\t0.168\t254\n24656\t2.51\t0.162\t95\n24657\t3.004\t0.801\t27\n24658\t2.961\t0.516\t71\n24659\t3.105\t0.444\t106\n24666\t3.114\t0.326\t123\n24668\t3.098\t0.303\t230\n28685\t2.353\t0.307\t3006\n28693\t2.684\t0.241\t703\n28694\t2.452\t0.242\t3992\n28695\t2.409\t0.319\t1209\n28696\t2.464\t0.534\t2219\n28697\t2.577\t0.289\t2590\n28698\t2.456\t0.2\t6911\n28699\t2.41\t0.36\t7053\n28700\t2.487\t0.231\t7446\n28701\t2.406\t0.194\t9772\n28702\t2.479\t0.227\t5502\n28703\t2.471\t0.309\t929\n28711\t2.921\t0.239\t1714\n28712\t2.679\t0.232\t2798\n28713\t2.442\t0.272\t911\n28714\t2.445\t0.293\t2412\n28716\t2.475\t0.298\t2904\n28717\t2.428\t0.335\t1207\n28718\t2.458\t0.222\t3289\n28719\t2.487\t0.247\t1033\n28720\t2.81\t0.231\t768\n28721\t2.785\t0.35\t616\n28722\t2.606\t0.37\t1703\n28723\t2.599\t0.29\t531\n28729\t3.125\t0.329\t626\n28730\t3.082\t0.337\t728\n28731\t3.179\t0.249\t153\n28732\t3.022\t0.208\t458\n28734\t3.032\t0.245\t890\n28735\t3.194\t0.258\t616\n28736\t3.148\t0.29\t455\n28737\t3.124\t0.266\t301\n28738\t3.028\t0.263\t602\n28739\t2.987\t0.306\t159\n28740\t2.919\t0.28\t496\n28741\t3.182\t0.365\t119\n28742\t2.892\t0.229\t1179\n28743\t2.821\t0.212\t549\n28744\t2.607\t0.225\t683\n28745\t2.503\t0.227\t1194\n28746\t2.395\t0.326\t1012\n28747\t2.447\t0.267\t941\n28748\t2.383\t0.233\t326\n28749\t2.511\t0.279\t970\n28750\t2.457\t0.24\t1884\n28751\t2.393\t0.172\t533\n28752\t2.849\t0.285\t194\n28753\t2.973\t0.272\t62\n28754\t2.876\t0.236\t326\n28755\t2.753\t0.232\t424\n28762\t3.088\t0.249\t588\n28764\t2.972\t0.34\t2780\n28765\t3.016\t0.335\t10\n28766\t3.297\t0.204\t7\n32781\t2.145\t0.448\t7124\n32789\t2.625\t0.845\t799\n32790\t2.338\t0.282\t13095\n32791\t2.352\t0.77\t18035\n32792\t2.299\t0.427\t5228\n32793\t2.387\t0.292\t15567\n32794\t2.358\t0.225\t12153\n32795\t2.38\t0.29\t13623\n32796\t2.421\t0.301\t14996\n32797\t2.272\t0.223\t19019\n32798\t2.378\t0.357\t12982\n32799\t2.317\t0.208\t831\n32807\t2.796\t0.315\t3153\n32808\t2.497\t0.249\t4631\n32809\t2.375\t0.365\t1523\n32810\t2.347\t0.467\t31965\n32812\t2.419\t0.158\t3311\n32813\t2.436\t0.193\t2109\n32814\t2.4\t0.154\t2649\n32815\t2.661\t0.256\t865\n32816\t2.694\t0.218\t2847\n32817\t2.616\t0.276\t949\n32818\t2.579\t0.438\t4702\n32819\t2.309\t0.553\t1993\n32825\t2.994\t0.343\t2113\n32826\t2.856\t0.3\t2621\n32827\t2.93\t0.228\t1218\n32828\t2.905\t0.207\t2518\n32830\t2.869\t0.237\t2353\n32831\t2.827\t0.209\t3697\n32832\t2.834\t0.197\t5222\n32833\t2.78\t0.177\t4383\n32834\t2.738\t0.205\t8482\n32835\t2.747\t0.193\t1707\n32836\t2.742\t0.193\t2196\n32837\t2.798\t0.21\t502\n32838\t2.734\t0.235\t2716\n32839\t2.767\t0.212\t885\n32840\t2.498\t0.29\t774\n32841\t2.373\t0.261\t1221\n32842\t2.285\t0.417\t9618\n32843\t2.218\t0.348\t3304\n32844\t2.411\t0.2\t303\n32845\t2.462\t0.304\t1297\n32846\t2.393\t0.203\t1953\n32847\t2.305\t0.24\t286\n32848\t2.736\t0.309\t162\n32849\t2.822\t0.336\t202\n32850\t2.624\t0.233\t1404\n32851\t2.579\t0.268\t1906\n32858\t2.759\t0.291\t759\n32860\t2.611\t0.412\t7083\n32861\t2.503\t0.425\t287\n32862\t2.802\t0.399\t255\n32863\t2.837\t0.483\t20\n32864\t3.097\t0.448\t5\n32865\t2.94\t0.02\t3\n32866\t2.916\t0.021\t3\n36877\t1.811\t0.461\t1163\n36885\t2.022\t0.295\t129\n36886\t2.262\t0.492\t1106\n36887\t2.576\t0.889\t536\n36888\t1.937\t0.267\t474\n36889\t2.093\t0.73\t296\n36890\t1.929\t0.743\t373\n36891\t2.283\t0.257\t113\n36892\t2.221\t0.196\t116\n36893\t2.345\t0.817\t110\n36894\t2.065\t0.336\t75\n36895\t2.412\t0.358\t76\n36903\t2.125\t0.259\t44\n36904\t2.154\t1.055\t667\n36905\t2.12\t0.459\t502\n36906\t2.031\t0.453\t512\n36908\t2.395\t0.388\t43\n36909\t2.339\t0.338\t54\n36910\t2.361\t0.307\t101\n36911\t2.57\t0.191\t9\n36912\t2.427\t0.207\t26\n36913\t2.059\t1.008\t121\n36914\t2.126\t0.626\t419\n36915\t2.193\t0.262\t8674\n36921\t2.731\t0.286\t10\n36922\t2.995\t1.207\t51\n36923\t2.406\t0.044\t8\n36924\t2.742\t0.246\t33\n36926\t2.795\t0.182\t52\n36927\t2.799\t0.303\t24\n36928\t2.454\t0.018\t4\n36929\t1.96\t0.0\t6\n36930\t2.434\t0.192\t19\n36931\t2.857\t-1.0\t1\n36932\t2.747\t0.211\t25\n36934\t2.687\t0.139\t19\n36935\t2.806\t0.003\t4\n36936\t2.107\t0.444\t90\n36937\t2.149\t0.225\t250\n36938\t1.882\t0.247\t232\n36939\t2.0\t0.93\t274\n36940\t2.276\t0.144\t56\n36941\t2.293\t1.188\t69\n36942\t2.356\t0.364\t53\n36943\t1.893\t0.555\t149\n36944\t2.373\t0.0\t2\n36945\t2.015\t0.261\t45\n36946\t2.333\t0.203\t37\n36947\t2.152\t0.196\t94\n36954\t2.666\t0.268\t30\n36955\t2.205\t0.007\t16\n36956\t2.285\t0.379\t153\n36957\t2.26\t0.017\t10\n45067\t3.369\t0.477\t389\n45068\t3.242\t-1.0\t1\n45069\t3.524\t0.425\t2\n45070\t3.558\t0.0\t2\n45075\t3.592\t0.346\t36\n45076\t3.383\t0.133\t22\n45081\t3.221\t0.182\t3\n45082\t2.923\t0.336\t4\n45083\t3.382\t-1.0\t1\n45084\t2.961\t0.097\t3\n45087\t3.136\t-1.0\t1\n45088\t3.161\t0.174\t9\n45093\t3.645\t0.249\t17\n45094\t3.529\t0.167\t10\n45101\t3.618\t-1.0\t1\n45106\t3.243\t0.311\t72\n45107\t3.33\t0.219\t17\n45111\t3.704\t0.248\t22\n45112\t3.585\t0.155\t9\n45134\t3.136\t-1.0\t1\n45136\t3.234\t0.09\t7\n45137\t3.405\t0.105\t12\n45138\t3.441\t0.118\t15\n45139\t3.281\t0.068\t7\n45317\t3.245\t0.017\t2\n45318\t3.261\t0.178\t294\n45573\t2.685\t-1.0\t1\n45574\t3.187\t0.261\t35\n49164\t3.052\t0.123\t490\n49165\t3.401\t-1.0\t1\n49166\t2.887\t0.569\t39\n49171\t4.275\t0.055\t2\n49172\t3.412\t0.019\t8\n49177\t3.408\t-1.0\t1\n49178\t3.072\t0.063\t8\n49181\t3.334\t0.086\t3\n49182\t3.217\t0.061\t2\n49183\t2.836\t0.772\t13\n49184\t2.807\t0.438\t17\n49190\t3.648\t0.307\t28\n49191\t2.187\t0.0\t6\n49194\t2.466\t0.0\t2\n49197\t2.818\t0.099\t91\n49202\t2.927\t0.036\t9\n49203\t2.862\t0.432\t19\n49207\t3.807\t0.0\t2\n49208\t3.659\t0.045\t20\n49209\t3.53\t0.075\t16\n49210\t3.447\t0.003\t12\n49211\t3.506\t0.0\t3\n49212\t3.54\t0.0\t3\n49214\t3.463\t0.0\t3\n49215\t3.48\t0.014\t8\n49216\t3.364\t0.0\t3\n49221\t3.144\t0.0\t12\n49229\t2.7\t0.086\t48\n49230\t3.087\t0.019\t2\n49233\t3.145\t0.004\t2\n49413\t2.826\t0.154\t5\n49414\t2.811\t0.216\t411\n49670\t2.681\t0.238\t49\n53261\t3.147\t0.471\t69\n53262\t3.263\t0.176\t31\n53263\t3.143\t0.346\t218\n53264\t2.983\t0.385\t264\n53265\t2.601\t0.322\t2017\n53268\t3.669\t-1.0\t1\n53272\t2.557\t-1.0\t1\n53273\t2.309\t-1.0\t1\n53274\t2.908\t0.179\t18\n53275\t2.828\t0.234\t10\n53276\t2.655\t0.245\t6\n53277\t2.352\t0.06\t13\n53278\t3.3\t0.187\t3\n53279\t3.414\t0.37\t3\n53280\t2.499\t0.185\t12\n53281\t2.448\t0.051\t41\n53282\t2.875\t0.469\t72\n53283\t2.741\t0.288\t381\n53286\t3.495\t0.045\t15\n53292\t2.999\t-1.0\t1\n53293\t3.023\t0.354\t19\n53294\t2.951\t0.089\t21\n53295\t3.08\t-1.0\t1\n53297\t3.715\t-1.0\t1\n53298\t3.418\t0.0\t2\n53299\t2.655\t0.502\t19\n53300\t2.915\t0.495\t30\n53301\t3.049\t0.382\t137\n53303\t2.804\t1.394\t2\n53304\t3.582\t0.06\t4\n53305\t3.584\t0.347\t3\n53308\t3.56\t0.086\t2\n53322\t3.218\t0.048\t2\n53325\t3.468\t0.243\t2\n53326\t3.202\t0.139\t4\n53331\t3.74\t0.255\t4\n53340\t4.01\t0.006\t2\n53509\t2.605\t0.31\t8\n53510\t2.407\t0.249\t1700\n53511\t2.374\t0.163\t1982\n53512\t2.216\t0.23\t533\n53519\t2.935\t0.196\t5\n53520\t2.843\t0.186\t40\n53766\t2.468\t0.199\t96\n53767\t2.448\t0.135\t44\n53768\t1.978\t0.199\t4\n57363\t4.548\t0.464\t19\n57364\t3.083\t0.417\t13\n57366\t3.671\t0.019\t4\n57367\t3.246\t0.035\t4\n57368\t2.795\t0.193\t8\n57369\t2.811\t0.292\t27\n57370\t2.847\t0.192\t233\n57371\t2.715\t0.262\t77\n57372\t2.749\t0.228\t147\n57373\t2.884\t0.306\t43\n57374\t3.288\t0.273\t42\n57375\t3.561\t0.36\t4\n57382\t3.347\t0.097\t2\n57384\t3.775\t0.176\t18\n57385\t3.436\t0.115\t26\n57386\t3.224\t0.255\t49\n57388\t2.956\t0.338\t151\n57389\t2.78\t0.227\t106\n57390\t2.921\t0.275\t97\n57391\t3.357\t0.302\t20\n57393\t3.19\t0.085\t14\n57394\t3.662\t0.527\t210\n57395\t3.917\t0.191\t58\n57399\t3.91\t0.0\t4\n57400\t3.327\t0.062\t5\n57402\t3.01\t0.585\t8\n57406\t4.511\t0.25\t17\n57407\t4.503\t0.08\t6\n57409\t3.926\t0.003\t2\n57411\t3.905\t0.012\t2\n57414\t4.362\t0.205\t19\n57416\t3.87\t0.205\t13\n57417\t3.437\t0.24\t5\n57418\t3.085\t0.21\t66\n57419\t2.96\t0.12\t14\n57420\t3.028\t0.125\t7\n57421\t2.797\t0.286\t150\n57422\t2.978\t0.215\t175\n57423\t2.761\t0.465\t12\n57424\t3.53\t0.211\t22\n57426\t3.874\t0.316\t17\n57427\t4.031\t0.321\t9\n61461\t3.38\t0.299\t100\n61462\t3.21\t0.369\t276\n61463\t3.131\t0.207\t110\n61464\t2.873\t0.244\t730\n61465\t2.696\t0.32\t774\n61466\t2.697\t0.243\t4802\n61467\t2.679\t0.235\t3056\n61468\t2.676\t0.196\t4702\n61469\t2.64\t0.179\t5253\n61470\t2.912\t0.244\t119\n61471\t3.023\t0.242\t152\n61479\t3.617\t0.27\t57\n61480\t3.41\t0.235\t240\n61481\t3.284\t0.297\t129\n61482\t3.002\t0.261\t2058\n61484\t2.758\t0.203\t6616\n61485\t2.714\t0.205\t4052\n61486\t2.713\t0.193\t6710\n61487\t2.863\t0.16\t1964\n61488\t3.199\t0.271\t42\n61489\t3.285\t0.255\t93\n61490\t3.243\t0.31\t221\n61491\t3.183\t0.277\t77\n61497\t3.201\t0.305\t27\n61498\t2.934\t0.476\t9\n61500\t3.451\t0.1\t14\n61502\t3.794\t0.117\t26\n61506\t3.579\t0.083\t13\n61507\t3.584\t0.109\t8\n61508\t3.774\t0.0\t2\n61510\t3.577\t0.217\t22\n61511\t3.739\t0.336\t7\n61512\t3.408\t0.222\t72\n61513\t3.244\t0.257\t147\n61514\t3.003\t0.256\t1665\n61515\t2.906\t0.239\t1623\n61516\t2.798\t0.241\t1057\n61517\t2.754\t0.215\t2863\n61518\t2.714\t0.201\t6668\n61519\t2.668\t0.172\t4216\n61520\t2.879\t0.203\t76\n61521\t3.471\t0.204\t33\n61522\t3.487\t0.164\t39\n61523\t3.141\t0.234\t30\n61530\t3.726\t0.298\t60\n61532\t3.891\t0.328\t80\n65557\t3.412\t0.368\t35\n65558\t2.901\t0.267\t387\n65559\t2.852\t0.348\t489\n65560\t2.881\t0.289\t268\n65561\t2.726\t0.281\t883\n65562\t2.718\t0.226\t7921\n65563\t2.724\t0.272\t1489\n65564\t2.606\t0.234\t5975\n65565\t2.755\t0.225\t5038\n65566\t2.788\t0.225\t1360\n65567\t2.767\t0.214\t227\n65575\t3.418\t0.184\t159\n65576\t3.376\t0.277\t123\n65577\t2.954\t0.528\t373\n65578\t2.911\t0.288\t3355\n65580\t2.816\t0.192\t1907\n65581\t2.839\t0.173\t765\n65582\t2.775\t0.192\t2485\n65583\t3.093\t0.232\t4438\n65584\t3.087\t0.238\t609\n65585\t3.111\t0.393\t484\n65586\t2.949\t0.477\t1247\n65587\t2.995\t0.415\t696\n65593\t3.611\t0.276\t65\n65594\t3.5\t0.164\t59\n65595\t3.551\t0.145\t18\n65596\t3.459\t0.169\t45\n65598\t3.453\t0.18\t175\n65599\t3.683\t0.232\t44\n65600\t3.412\t0.05\t10\n65601\t3.114\t0.282\t6\n65602\t3.516\t0.333\t73\n65603\t3.018\t0.572\t5\n65604\t3.488\t0.196\t81\n65605\t3.266\t0.272\t10\n65606\t3.254\t0.188\t179\n65607\t3.336\t0.194\t34\n65608\t3.554\t0.326\t21\n65609\t2.461\t0.31\t329\n65610\t2.919\t0.288\t2082\n65611\t2.8\t0.267\t1996\n65612\t2.475\t0.252\t240\n65613\t2.833\t0.153\t655\n65614\t2.73\t0.196\t2208\n65615\t2.776\t0.277\t3697\n65616\t2.944\t0.23\t538\n65617\t3.031\t0.277\t17\n65618\t3.147\t0.26\t222\n65619\t3.099\t0.284\t350\n65626\t3.319\t0.35\t170\n65628\t3.382\t0.265\t290\n65629\t3.399\t0.077\t8\n65630\t2.931\t0.387\t17\n65631\t3.438\t0.046\t3\n65632\t3.441\t0.047\t3\n69653\t3.008\t0.308\t233\n69654\t2.799\t0.246\t2597\n69655\t2.789\t0.215\t490\n69656\t2.8\t0.199\t1394\n69657\t2.875\t0.267\t1182\n69658\t2.712\t0.238\t3474\n69659\t2.694\t0.227\t2713\n69660\t2.758\t0.28\t2082\n69661\t2.701\t0.25\t5780\n69662\t2.642\t0.425\t3822\n69663\t2.661\t0.254\t1485\n69671\t3.218\t0.274\t409\n69672\t2.991\t0.248\t1900\n69673\t2.903\t0.356\t1449\n69674\t2.907\t0.475\t2267\n69676\t2.885\t0.203\t5377\n69677\t2.863\t0.235\t2604\n69678\t2.776\t0.213\t6900\n69679\t3.032\t0.245\t617\n69680\t2.974\t0.221\t1026\n69681\t2.957\t0.377\t932\n69682\t2.928\t0.391\t2452\n69683\t2.872\t0.46\t1745\n69689\t3.393\t0.345\t120\n69690\t3.542\t0.471\t133\n69691\t3.384\t0.328\t54\n69692\t3.319\t0.289\t122\n69694\t3.354\t0.248\t151\n69695\t3.179\t0.349\t113\n69696\t3.251\t0.372\t116\n69697\t3.069\t0.3\t85\n69698\t3.114\t0.336\t295\n69699\t3.273\t0.344\t35\n69700\t3.214\t0.336\t160\n69701\t2.947\t0.43\t25\n69702\t3.224\t0.207\t183\n69703\t3.182\t0.198\t73\n69704\t2.972\t0.302\t357\n69705\t2.911\t0.327\t1000\n69706\t2.885\t0.369\t1787\n69707\t2.801\t0.257\t2221\n69708\t2.851\t0.255\t681\n69709\t2.879\t0.222\t2186\n69710\t2.757\t0.265\t4336\n69711\t2.675\t0.201\t2687\n69712\t2.804\t0.27\t1229\n69713\t2.554\t0.473\t192\n69714\t3.224\t0.457\t625\n69715\t3.107\t0.371\t1402\n69722\t3.417\t0.306\t157\n69723\t2.64\t0.0\t4\n69724\t3.21\t0.343\t893\n69725\t3.181\t0.284\t122\n69726\t3.088\t0.296\t154\n69727\t2.915\t-1.0\t1\n69728\t2.915\t-1.0\t1\n69729\t2.465\t0.0\t6\n77843\t3.904\t0.444\t476\n77844\t3.931\t0.219\t13\n77847\t3.213\t0.001\t2\n77848\t3.318\t0.114\t5\n77849\t3.574\t0.313\t3\n77850\t3.205\t-1.0\t1\n77851\t3.463\t0.411\t4\n77852\t3.491\t0.534\t2\n77853\t3.822\t0.039\t3\n77854\t3.511\t0.765\t6\n77856\t3.502\t0.647\t78\n77861\t3.9\t0.078\t12\n77862\t3.806\t0.091\t8\n77864\t3.807\t-1.0\t1\n77865\t3.535\t0.137\t7\n77870\t3.386\t0.218\t17\n77871\t3.245\t0.006\t2\n77874\t3.754\t0.595\t67\n77875\t3.655\t0.42\t25\n77879\t3.899\t0.365\t31\n77880\t4.729\t0.676\t2\n77898\t4.496\t0.606\t3\n77902\t3.48\t0.0\t4\n77905\t3.736\t0.08\t11\n77906\t3.724\t0.099\t26\n77907\t3.562\t0.045\t4\n77917\t4.592\t-1.0\t1\n78085\t3.76\t0.113\t8\n78086\t3.713\t0.29\t1287\n78342\t3.557\t0.28\t73\n81940\t3.661\t0.289\t176\n81943\t3.019\t-1.0\t1\n81944\t2.85\t-1.0\t1\n81945\t3.324\t0.0\t2\n81951\t3.151\t-1.0\t1\n81952\t3.185\t0.116\t25\n81957\t3.75\t0.247\t3\n81958\t3.579\t0.106\t3\n81967\t3.517\t0.128\t5\n81969\t3.26\t0.128\t3\n81970\t3.346\t0.13\t71\n81971\t3.246\t0.132\t128\n81975\t3.895\t0.219\t5\n81976\t3.719\t0.202\t10\n81997\t3.133\t0.007\t2\n81999\t3.088\t0.086\t20\n82000\t3.26\t0.098\t4\n82001\t3.332\t-1.0\t1\n82002\t3.427\t0.083\t10\n82003\t3.25\t0.171\t45\n82012\t3.805\t-1.0\t1\n82182\t3.212\t0.212\t411\n82438\t2.973\t0.227\t13\n86044\t2.357\t-1.0\t1\n86050\t3.301\t0.106\t5\n86051\t3.223\t0.408\t15\n86053\t3.906\t-1.0\t1\n86062\t2.711\t0.034\t2\n86068\t3.534\t0.111\t4\n86069\t3.014\t0.266\t86\n86277\t3.132\t0.206\t3\n86278\t3.08\t0.205\t1002\n86279\t2.704\t0.168\t460\n86280\t2.561\t0.163\t44\n86287\t3.292\t0.078\t26\n86288\t3.128\t0.068\t7\n86534\t2.902\t0.101\t13\n86535\t2.446\t0.18\t5\n90134\t3.158\t0.093\t9\n90138\t2.576\t0.185\t3\n90139\t2.835\t0.161\t13\n90140\t2.925\t0.174\t8\n90141\t3.761\t-1.0\t1\n90143\t3.058\t0.0\t2\n90144\t2.522\t0.784\t3\n90145\t2.482\t0.209\t46\n90146\t3.164\t0.558\t44\n90147\t2.774\t0.281\t113\n90150\t3.233\t0.034\t7\n90156\t3.193\t-1.0\t1\n90157\t2.921\t-1.0\t1\n90161\t3.271\t0.0\t2\n90162\t3.869\t0.023\t3\n90163\t3.573\t0.143\t28\n90164\t3.347\t0.022\t18\n90165\t2.62\t0.414\t54\n90168\t3.427\t0.036\t8\n90194\t3.897\t-1.0\t1\n90373\t3.171\t0.268\t3\n90374\t2.926\t0.185\t13105\n90375\t2.587\t0.178\t1875\n90376\t2.456\t0.185\t917\n90383\t3.113\t0.322\t22\n90384\t3.044\t0.167\t14\n90630\t2.624\t0.183\t73\n90631\t2.431\t0.217\t59\n90632\t2.541\t0.214\t13\n94231\t2.269\t0.138\t9\n94234\t2.503\t0.095\t6\n94235\t2.637\t0.592\t3\n94236\t3.236\t0.203\t2\n94242\t2.529\t0.487\t29\n94243\t2.969\t0.254\t17\n94264\t3.486\t-1.0\t1\n94286\t2.784\t0.083\t10\n94470\t2.664\t0.196\t1656\n94471\t2.46\t0.141\t1730\n94472\t2.373\t0.21\t563\n94479\t3.002\t0.084\t9\n94480\t2.809\t0.211\t72\n94726\t2.339\t0.204\t93\n94727\t2.461\t0.173\t28\n94728\t2.22\t0.033\t36\n98328\t2.585\t0.33\t139\n98329\t3.026\t0.483\t6\n98330\t3.053\t0.116\t7\n98331\t2.861\t0.157\t7\n98332\t3.016\t0.06\t2\n98333\t2.906\t-1.0\t1\n98334\t3.171\t-1.0\t1\n98335\t2.778\t0.078\t6\n98336\t2.83\t0.006\t4\n98337\t2.984\t0.301\t63\n98338\t3.557\t0.536\t97\n98339\t2.852\t0.31\t66\n98341\t3.47\t0.104\t3\n98349\t3.572\t-1.0\t1\n98350\t3.259\t0.092\t4\n98354\t3.11\t0.137\t19\n98355\t3.017\t0.193\t20\n98356\t3.203\t0.219\t43\n98357\t3.129\t0.376\t67\n98378\t3.04\t-1.0\t1\n98381\t3.568\t-1.0\t1\n98382\t3.15\t0.188\t5\n98383\t3.133\t0.037\t3\n98384\t3.045\t0.0\t2\n98386\t3.121\t0.097\t12\n98387\t3.325\t0.016\t2\n98565\t2.688\t0.12\t18\n98566\t2.619\t0.153\t6878\n98567\t2.404\t0.141\t2515\n98568\t2.41\t0.174\t638\n98575\t3.098\t0.146\t259\n98576\t2.876\t0.25\t37\n98822\t2.158\t0.152\t4143\n98823\t2.42\t0.131\t56\n98824\t2.468\t0.236\t5\n102425\t3.087\t0.258\t19\n102426\t2.867\t0.103\t4\n102427\t3.03\t0.131\t2\n102428\t2.886\t-1.0\t1\n102431\t3.326\t0.375\t7\n102432\t2.775\t0.168\t35\n102433\t2.737\t0.092\t14\n102434\t3.052\t0.275\t320\n102435\t2.947\t0.279\t501\n102438\t3.136\t0.442\t2\n102442\t3.198\t-1.0\t1\n102444\t2.998\t0.081\t3\n102445\t2.848\t0.318\t2\n102447\t3.116\t0.312\t4\n102449\t2.668\t0.007\t12\n102450\t2.65\t0.156\t37\n102451\t2.804\t0.128\t97\n102452\t3.71\t0.389\t143\n102453\t3.196\t0.352\t77\n102476\t2.993\t0.038\t4\n102478\t3.256\t-1.0\t1\n102479\t3.089\t0.272\t5\n102480\t2.61\t0.003\t4\n102481\t3.397\t-1.0\t1\n102482\t2.754\t0.035\t4\n102483\t2.878\t0.096\t25\n102661\t2.718\t0.111\t3\n102662\t2.482\t0.226\t2788\n102663\t2.511\t0.177\t8370\n102664\t2.493\t0.179\t2602\n102671\t2.643\t0.184\t45\n102672\t2.962\t0.176\t53\n102918\t2.052\t0.149\t4796\n102919\t2.51\t0.179\t433\n102920\t2.374\t0.161\t19\n106522\t2.941\t0.371\t219\n106523\t2.892\t0.261\t5\n106524\t2.877\t0.111\t7\n106525\t2.863\t0.149\t85\n106526\t2.98\t0.096\t34\n106527\t2.834\t0.242\t89\n106528\t2.743\t0.335\t128\n106529\t2.701\t0.254\t143\n106530\t2.739\t0.223\t715\n106531\t2.904\t0.242\t866\n106536\t3.002\t0.349\t8\n106537\t2.799\t0.229\t2\n106538\t3.086\t0.144\t4\n106540\t2.735\t0.302\t14\n106541\t2.768\t0.387\t2\n106542\t3.159\t0.157\t17\n106543\t2.781\t0.205\t11\n106545\t3.031\t0.266\t33\n106546\t3.013\t0.266\t96\n106547\t2.844\t0.229\t38\n106548\t2.92\t0.185\t202\n106549\t3.146\t0.267\t200\n106551\t3.701\t0.004\t2\n106552\t3.508\t0.08\t2\n106554\t3.692\t-1.0\t1\n106556\t3.882\t-1.0\t1\n106566\t3.665\t0.215\t7\n106570\t3.257\t0.114\t4\n106571\t2.863\t0.015\t4\n106572\t2.976\t0.164\t5\n106574\t3.224\t0.085\t11\n106575\t2.779\t0.247\t4\n106576\t2.981\t0.124\t18\n106577\t3.014\t0.072\t10\n106579\t3.124\t0.117\t28\n106757\t2.221\t0.408\t15\n106758\t2.401\t0.141\t81624\n106759\t2.351\t0.184\t21226\n106760\t2.431\t0.13\t2185\n106767\t2.782\t0.218\t230\n106768\t2.742\t0.183\t221\n107014\t2.077\t0.157\t13871\n107015\t2.286\t0.144\t1126\n107016\t2.261\t0.186\t6\n107023\t2.555\t-1.0\t1\n110619\t2.657\t0.367\t240\n110620\t2.816\t0.234\t12\n110621\t2.849\t0.093\t2\n110622\t2.914\t0.068\t12\n110623\t2.683\t0.337\t23\n110624\t2.349\t0.547\t34\n110625\t2.914\t0.287\t44\n110626\t2.37\t0.334\t254\n110627\t2.823\t0.245\t593\n110629\t3.216\t-1.0\t1\n110632\t3.168\t0.262\t18\n110633\t3.517\t-1.0\t1\n110634\t3.188\t-1.0\t1\n110636\t2.935\t0.025\t5\n110637\t2.659\t0.073\t4\n110638\t2.964\t0.14\t43\n110641\t2.808\t0.245\t6\n110642\t2.669\t0.36\t18\n110643\t2.899\t0.004\t2\n110644\t2.907\t0.266\t28\n110645\t3.111\t0.233\t239\n110654\t3.746\t0.042\t4\n110664\t3.213\t0.095\t2\n110665\t3.535\t-1.0\t1\n110666\t3.211\t-1.0\t1\n110669\t2.652\t-1.0\t1\n110670\t3.108\t0.335\t20\n110671\t3.078\t0.114\t48\n110672\t2.505\t0.007\t4\n110673\t2.66\t0.009\t3\n110674\t2.75\t0.014\t4\n110675\t2.821\t0.241\t50\n110682\t3.786\t-1.0\t1\n110684\t3.602\t0.211\t2\n110853\t2.51\t0.032\t24\n110854\t2.424\t0.18\t7855\n110855\t2.35\t0.165\t15280\n110856\t2.397\t0.151\t2600\n110863\t2.753\t0.315\t114\n110864\t2.718\t0.212\t256\n111110\t2.057\t0.162\t5916\n111111\t2.347\t0.183\t580\n111120\t3.119\t-1.0\t1\n114716\t2.861\t0.204\t423\n114717\t2.956\t0.144\t62\n114718\t3.07\t0.105\t55\n114719\t2.884\t0.235\t61\n114720\t2.67\t0.388\t26\n114721\t2.959\t0.219\t18\n114722\t2.832\t0.233\t173\n114723\t2.869\t0.229\t1269\n114727\t2.635\t0.109\t4\n114728\t2.753\t-1.0\t1\n114730\t2.796\t0.0\t2\n114733\t2.529\t0.017\t3\n114737\t2.923\t0.325\t25\n114738\t3.191\t0.145\t154\n114739\t3.085\t0.122\t9\n114740\t3.439\t0.421\t52\n114741\t3.061\t0.179\t190\n114743\t3.288\t-1.0\t1\n114745\t2.617\t0.062\t2\n114759\t3.289\t0.325\t3\n114760\t2.798\t-1.0\t1\n114762\t2.961\t-1.0\t1\n114765\t2.702\t-1.0\t1\n114766\t3.089\t0.135\t10\n114767\t3.047\t0.066\t62\n114768\t3.431\t0.011\t4\n114769\t3.198\t-1.0\t1\n114770\t3.331\t0.009\t16\n114771\t3.287\t0.091\t62\n114780\t3.048\t-1.0\t1\n114949\t2.438\t0.289\t13\n114950\t2.447\t0.207\t5143\n114951\t2.359\t0.153\t15318\n114952\t2.422\t0.153\t2635\n114959\t2.635\t0.231\t43\n114960\t2.669\t0.201\t795\n115206\t2.167\t0.159\t1651\n115207\t2.384\t0.147\t685\n115208\t2.377\t-1.0\t1\n118813\t2.913\t0.463\t3054\n118814\t2.839\t0.079\t11\n118815\t2.711\t0.001\t4\n118816\t2.916\t0.195\t36\n118817\t2.906\t0.257\t48\n118818\t3.003\t0.19\t1185\n118819\t2.89\t0.233\t2162\n118821\t4.015\t-1.0\t1\n118826\t2.96\t-1.0\t1\n118828\t2.952\t0.11\t39\n118829\t2.507\t0.024\t3\n118830\t2.938\t0.19\t22\n118831\t2.849\t0.2\t37\n118834\t2.765\t0.134\t305\n118835\t3.108\t0.155\t31\n118836\t3.39\t0.219\t189\n118837\t3.139\t0.235\t3644\n118839\t3.839\t-1.0\t1\n118858\t2.994\t-1.0\t1\n118861\t2.937\t0.024\t4\n118862\t2.749\t0.231\t11\n118863\t3.089\t0.14\t128\n118864\t2.73\t0.419\t10\n118867\t4.236\t-1.0\t1\n119046\t2.301\t0.205\t1784\n119047\t2.304\t0.132\t28601\n119048\t2.278\t0.16\t3943\n119055\t2.752\t0.18\t205\n119056\t2.764\t0.209\t1501\n119302\t2.425\t0.207\t1326\n119303\t2.302\t0.163\t1333\n119304\t2.514\t0.012\t2\n122910\t2.933\t0.511\t46\n122911\t2.702\t0.368\t7\n122912\t2.663\t0.513\t47\n122913\t2.561\t0.197\t22\n122914\t2.985\t0.238\t269\n122915\t2.799\t0.235\t1020\n122917\t3.448\t-1.0\t1\n122920\t3.428\t0.0\t2\n122922\t3.262\t0.063\t13\n122924\t3.141\t0.257\t36\n122925\t3.024\t0.038\t68\n122926\t3.08\t0.273\t30\n122929\t3.163\t0.018\t2\n122930\t2.751\t0.402\t11\n122932\t3.359\t0.441\t18\n122933\t3.021\t0.24\t382\n122935\t3.714\t-1.0\t1\n122955\t3.014\t0.026\t6\n122957\t3.238\t0.02\t4\n122958\t3.092\t0.105\t29\n122960\t3.074\t0.0\t2\n122961\t2.928\t0.007\t10\n122962\t3.518\t0.023\t8\n122963\t2.553\t0.0\t2\n123142\t2.737\t0.301\t850\n123143\t2.41\t0.137\t13630\n123144\t2.395\t0.157\t2260\n123151\t2.989\t0.176\t11\n123152\t2.86\t0.169\t504\n123398\t2.392\t0.233\t92\n123399\t2.348\t0.155\t241\n127007\t3.02\t0.246\t86\n127008\t2.974\t0.088\t8\n127009\t3.494\t0.451\t21\n127010\t2.829\t0.38\t37\n127011\t2.708\t0.245\t196\n127014\t3.469\t0.079\t7\n127016\t3.23\t0.0\t2\n127018\t3.049\t0.131\t23\n127020\t2.953\t0.101\t22\n127021\t3.009\t0.238\t45\n127022\t3.086\t0.158\t56\n127023\t3.058\t0.009\t4\n127025\t3.335\t0.196\t5\n127026\t3.283\t0.062\t7\n127027\t2.651\t0.769\t24\n127028\t3.434\t0.203\t18\n127029\t3.123\t0.373\t261\n127031\t3.789\t0.084\t6\n127032\t4.457\t-1.0\t1\n127033\t3.667\t-1.0\t1\n127036\t4.074\t0.0\t2\n127039\t4.048\t-1.0\t1\n127046\t4.093\t-1.0\t1\n127050\t2.953\t0.101\t7\n127052\t3.076\t0.218\t4\n127053\t3.176\t0.156\t3\n127054\t2.924\t0.124\t38\n127055\t2.909\t0.082\t10\n127059\t4.205\t0.525\t4\n127068\t3.948\t0.013\t2\n127237\t2.513\t0.281\t7\n127238\t2.422\t0.173\t417\n127239\t2.418\t0.176\t782\n127240\t2.39\t0.178\t153\n127247\t2.978\t0.075\t57\n127248\t2.775\t0.184\t61\n127494\t2.47\t0.44\t42\n127495\t2.406\t0.044\t2\n131109\t3.618\t0.424\t54\n131110\t3.321\t0.053\t36\n131111\t2.973\t0.025\t4\n131112\t3.771\t0.94\t5\n131113\t3.619\t0.341\t9\n131114\t3.143\t0.38\t30\n131116\t2.916\t0.159\t157\n131117\t2.917\t0.159\t121\n131118\t3.04\t0.268\t107\n131119\t2.922\t0.222\t15\n131120\t3.307\t0.038\t4\n131122\t3.411\t0.477\t35\n131123\t3.351\t-1.0\t1\n131127\t3.814\t0.114\t37\n131128\t3.49\t0.107\t29\n131130\t2.988\t0.0\t6\n131137\t2.864\t-1.0\t1\n131138\t3.615\t0.013\t2\n131144\t3.909\t0.169\t5\n131146\t3.079\t0.227\t59\n131147\t2.946\t0.309\t17\n131148\t2.938\t0.152\t48\n131149\t2.889\t0.075\t105\n131150\t2.932\t0.142\t86\n131151\t2.965\t0.315\t19\n131154\t4.158\t0.0\t3\n131155\t3.469\t0.0\t2\n135208\t3.392\t0.193\t9\n135209\t2.553\t0.506\t113\n135210\t2.846\t0.341\t42\n135212\t2.866\t0.212\t135\n135213\t2.927\t0.123\t16\n135214\t2.871\t0.163\t78\n135215\t2.95\t0.206\t41\n135216\t2.799\t0.488\t10\n135217\t2.858\t0.374\t47\n135218\t3.171\t0.414\t88\n135219\t3.525\t0.292\t6\n135226\t2.999\t0.0\t6\n135230\t3.926\t0.069\t11\n135234\t3.555\t0.069\t7\n135237\t4.014\t0.007\t2\n135240\t2.589\t0.032\t8\n135241\t2.464\t0.036\t10\n135242\t2.986\t0.141\t77\n135243\t2.924\t-1.0\t1\n135244\t2.773\t0.037\t5\n135245\t3.046\t0.0\t2\n135246\t2.825\t0.185\t175\n135247\t2.784\t0.162\t65\n135248\t3.475\t0.422\t13\n135249\t3.243\t0.492\t4\n135250\t3.627\t0.385\t15\n135251\t3.822\t0.36\t16\n135258\t3.001\t0.0\t2\n135260\t3.608\t0.228\t9\n135430\t2.312\t0.051\t4\n139303\t3.535\t0.292\t31\n139304\t3.38\t0.183\t24\n139305\t2.623\t0.529\t104\n139306\t3.083\t0.33\t321\n139308\t2.96\t0.162\t229\n139309\t2.923\t0.274\t63\n139310\t2.882\t0.149\t259\n139311\t3.27\t0.202\t438\n139312\t2.668\t0.417\t260\n139313\t3.241\t0.429\t63\n139314\t3.163\t0.399\t546\n139315\t3.191\t0.461\t290\n139321\t3.855\t0.226\t50\n139322\t3.709\t0.138\t100\n139323\t3.684\t0.123\t46\n139324\t3.633\t0.072\t70\n139326\t3.545\t0.123\t112\n139327\t3.991\t0.038\t4\n139328\t3.786\t0.526\t8\n139329\t3.979\t0.001\t4\n139330\t3.537\t0.014\t6\n139331\t3.355\t0.108\t12\n139332\t3.159\t0.173\t21\n139333\t3.624\t0.136\t27\n139334\t3.334\t0.167\t126\n139336\t3.239\t0.487\t10\n139337\t2.614\t0.35\t62\n139338\t3.123\t0.251\t218\n139339\t3.229\t0.309\t1334\n139340\t3.562\t0.717\t14\n139341\t2.945\t0.19\t49\n139342\t2.914\t0.165\t139\n139343\t2.866\t0.183\t165\n139344\t3.14\t0.274\t105\n139345\t3.078\t0.295\t50\n139346\t3.558\t0.371\t43\n139347\t3.512\t0.445\t86\n139354\t3.623\t0.348\t57\n139356\t3.581\t0.414\t207\n139357\t3.553\t0.26\t12\n139358\t3.738\t0.14\t26\n139526\t2.278\t0.056\t6\n143399\t2.881\t0.269\t29\n143400\t3.289\t0.207\t165\n143401\t2.903\t0.415\t136\n143402\t2.928\t0.263\t822\n143404\t2.981\t0.274\t225\n143405\t3.002\t0.373\t123\n143406\t2.929\t0.211\t1350\n143407\t3.15\t0.245\t392\n143408\t3.115\t0.214\t390\n143409\t2.892\t0.454\t277\n143410\t3.152\t0.327\t288\n143411\t3.118\t0.344\t421\n143417\t3.489\t0.306\t26\n143418\t3.66\t0.441\t102\n143419\t2.889\t0.02\t3\n143420\t3.311\t0.239\t14\n143422\t3.519\t0.117\t10\n143423\t3.405\t0.182\t14\n143424\t3.622\t0.201\t10\n143425\t2.902\t0.279\t14\n143426\t3.441\t0.397\t31\n143427\t2.869\t0.248\t16\n143428\t2.769\t0.111\t12\n143430\t3.342\t0.101\t8\n143433\t3.029\t0.413\t218\n143434\t2.63\t0.358\t237\n143435\t2.974\t0.223\t787\n143436\t2.871\t0.256\t91\n143437\t3.02\t0.255\t120\n143438\t2.97\t0.262\t730\n143439\t2.839\t0.219\t570\n143440\t2.939\t0.303\t600\n143441\t2.709\t0.226\t130\n143442\t3.393\t0.358\t470\n143443\t3.237\t0.326\t869\n143450\t3.569\t0.067\t21\n143452\t3.3\t0.463\t144\n143453\t2.771\t0.0\t6\n143454\t3.655\t0.021\t3\n143455\t2.882\t0.023\t3\n151589\t4.027\t0.433\t171\n151590\t3.818\t0.355\t2\n151594\t3.871\t0.0\t2\n151598\t3.586\t0.162\t20\n151599\t3.353\t0.049\t2\n151601\t3.937\t0.0\t2\n151602\t3.839\t0.296\t15\n151603\t3.859\t0.378\t36\n151607\t4.188\t0.029\t2\n151631\t3.626\t0.064\t26\n151633\t3.814\t0.025\t4\n151634\t3.849\t0.071\t10\n151635\t4.057\t0.0\t2\n151814\t3.815\t0.247\t64\n152069\t3.392\t0.0\t2\n152070\t3.728\t0.185\t7\n155686\t3.715\t0.263\t197\n155692\t3.291\t0.0\t2\n155693\t3.275\t0.0\t2\n155695\t3.371\t-1.0\t1\n155696\t3.544\t0.083\t4\n155697\t3.415\t0.077\t36\n155698\t3.446\t0.074\t26\n155699\t3.346\t0.137\t70\n155703\t4.039\t0.114\t2\n155704\t3.785\t-1.0\t1\n155725\t3.3\t0.0\t4\n155726\t3.174\t0.064\t8\n155727\t3.236\t0.051\t4\n155728\t3.411\t0.02\t2\n155729\t3.492\t0.006\t3\n155730\t3.53\t0.066\t10\n155731\t3.424\t0.132\t88\n155740\t3.534\t-1.0\t1\n155910\t3.584\t0.272\t112\n156166\t2.793\t0.019\t4\n159783\t4.713\t0.009\t2\n159790\t3.627\t0.388\t4\n159795\t3.832\t0.039\t12\n159797\t3.719\t0.347\t56\n159799\t4.168\t0.0\t2\n159822\t3.558\t0.003\t2\n160005\t3.476\t0.074\t35\n160006\t3.258\t0.191\t4054\n160007\t2.913\t0.142\t1412\n160008\t2.796\t0.249\t708\n160015\t3.636\t0.026\t3\n160016\t3.367\t0.408\t27\n160262\t2.99\t0.127\t72\n160263\t3.031\t0.264\t24\n163884\t3.712\t0.084\t3\n163885\t3.713\t0.26\t5\n163889\t3.399\t0.0\t2\n163890\t3.989\t0.377\t5\n163892\t3.476\t0.0\t2\n163893\t3.302\t0.424\t87\n163917\t3.364\t0.045\t5\n163918\t3.314\t0.355\t6\n163922\t4.034\t-1.0\t1\n164101\t3.255\t0.125\t9\n164102\t3.029\t0.219\t13290\n164103\t2.812\t0.186\t1007\n164104\t2.599\t0.231\t718\n164111\t3.355\t0.275\t19\n164112\t3.184\t0.119\t22\n164358\t2.805\t0.151\t103\n164359\t2.642\t0.21\t22\n164360\t2.844\t0.216\t9\n167977\t2.746\t0.433\t12\n167986\t3.166\t-1.0\t1\n167988\t3.668\t0.819\t15\n167989\t2.936\t0.216\t20\n168198\t2.975\t0.237\t953\n168199\t2.749\t0.24\t450\n168200\t2.532\t0.296\t44\n168207\t3.165\t0.13\t49\n168208\t3.318\t0.08\t14\n168454\t2.601\t0.169\t111\n168455\t2.727\t0.161\t25\n172074\t2.912\t0.373\t1298\n172076\t3.157\t0.34\t9\n172078\t3.301\t0.025\t5\n172079\t3.222\t0.067\t8\n172082\t3.28\t0.259\t30\n172083\t3.177\t0.165\t15\n172084\t3.327\t0.193\t23\n172085\t3.272\t0.292\t557\n172087\t3.799\t-1.0\t1\n172088\t3.528\t-1.0\t1\n172106\t2.727\t0.462\t6\n172107\t3.735\t-1.0\t1\n172109\t3.252\t0.082\t43\n172110\t3.239\t0.183\t9\n172111\t3.197\t0.132\t22\n172112\t3.584\t0.076\t4\n172114\t3.693\t0.232\t12\n172115\t3.359\t0.28\t40\n172124\t3.744\t0.013\t2\n172293\t3.03\t0.256\t14\n172294\t2.789\t0.167\t9278\n172295\t2.577\t0.18\t3098\n172296\t2.467\t0.259\t1296\n172303\t2.908\t0.239\t150\n172304\t2.957\t0.217\t165\n172550\t2.341\t0.159\t4663\n172551\t2.511\t0.149\t218\n172559\t2.202\t0.279\t10\n180268\t3.063\t0.299\t1102\n180269\t2.945\t0.515\t10\n180270\t3.082\t0.36\t14\n180271\t3.086\t-1.0\t1\n180272\t3.242\t0.131\t2\n180273\t3.439\t0.268\t6\n180274\t3.072\t0.196\t129\n180275\t3.213\t0.211\t24\n180276\t3.091\t0.153\t98\n180277\t3.22\t0.208\t173\n180295\t3.709\t0.109\t4\n180296\t3.674\t0.024\t2\n180298\t3.338\t0.368\t8\n180299\t3.08\t0.02\t2\n180300\t3.051\t0.136\t6\n180301\t3.2\t0.237\t31\n180302\t3.182\t0.186\t59\n180303\t2.975\t0.164\t24\n180304\t3.255\t-1.0\t1\n180306\t2.931\t0.041\t12\n180307\t2.734\t0.077\t20\n180485\t2.755\t0.204\t14\n180486\t2.611\t0.146\t28221\n180487\t2.363\t0.139\t11820\n180488\t2.408\t0.153\t1326\n180495\t2.75\t0.202\t77\n180496\t2.828\t0.175\t621\n180742\t2.163\t0.16\t10524\n180743\t2.394\t0.13\t880\n180744\t2.447\t0.224\t6\n180751\t2.688\t0.012\t5\n180752\t2.464\t0.284\t5\n184365\t2.871\t0.285\t392\n184366\t3.302\t0.52\t4\n184367\t2.634\t0.029\t2\n184368\t2.701\t-1.0\t1\n184369\t3.216\t0.427\t13\n184370\t3.333\t0.264\t124\n184371\t3.063\t0.086\t29\n184372\t3.343\t0.188\t5\n184373\t3.193\t0.194\t327\n184396\t2.794\t0.148\t26\n184397\t2.962\t0.816\t2\n184398\t2.985\t0.39\t19\n184399\t3.255\t0.176\t61\n184400\t3.215\t0.059\t6\n184402\t3.402\t0.003\t2\n184403\t3.348\t0.247\t21\n184412\t3.283\t0.005\t3\n184581\t2.634\t0.295\t6\n184582\t2.568\t0.171\t12855\n184583\t2.441\t0.153\t3081\n184584\t2.416\t0.166\t1225\n184591\t2.739\t0.094\t61\n184592\t2.805\t0.202\t148\n184837\t2.886\t-1.0\t1\n184838\t2.196\t0.199\t2670\n184839\t2.45\t0.148\t279\n184848\t2.287\t0.009\t6\n188462\t3.197\t0.284\t549\n188463\t3.567\t0.174\t71\n188465\t3.129\t0.275\t2\n188466\t3.378\t0.343\t81\n188467\t3.278\t0.49\t122\n188468\t3.121\t0.318\t140\n188469\t3.118\t0.179\t936\n188472\t3.155\t0.189\t11\n188486\t2.788\t-1.0\t1\n188487\t3.697\t0.043\t2\n188490\t3.361\t-1.0\t1\n188491\t3.319\t0.01\t2\n188492\t3.071\t0.101\t16\n188494\t3.253\t0.286\t17\n188495\t3.308\t0.347\t126\n188496\t3.082\t0.313\t5\n188497\t3.342\t0.379\t39\n188498\t3.685\t0.035\t11\n188499\t2.981\t0.028\t91\n188508\t3.265\t0.257\t3\n188677\t2.545\t0.218\t11\n188678\t2.381\t0.169\t6266\n188679\t2.365\t0.135\t7580\n188680\t2.446\t0.147\t1073\n188687\t2.778\t0.159\t82\n188688\t2.732\t0.177\t615\n188934\t2.405\t0.21\t1341\n188935\t2.38\t0.131\t281\n188936\t2.152\t0.004\t2\n188944\t2.657\t0.082\t9\n192559\t3.554\t0.226\t4083\n192561\t2.716\t-1.0\t1\n192562\t3.443\t0.292\t14\n192563\t3.163\t0.241\t12\n192564\t3.698\t0.229\t62\n192565\t3.522\t0.275\t796\n192572\t3.827\t0.068\t3\n192587\t3.3\t0.096\t6\n192588\t3.119\t0.06\t30\n192589\t3.417\t0.237\t27\n192590\t3.436\t0.273\t279\n192591\t3.326\t0.24\t399\n192592\t2.823\t0.436\t7\n192774\t2.472\t0.2\t1611\n192775\t2.535\t0.173\t5301\n192776\t2.731\t0.17\t305\n192783\t2.898\t0.163\t18\n192784\t3.194\t0.23\t847\n193030\t2.719\t0.257\t1011\n193031\t2.571\t0.187\t351\n196656\t2.962\t0.143\t4\n196659\t2.984\t0.064\t32\n196660\t3.488\t0.2\t53\n196661\t3.212\t0.24\t422\n196664\t3.568\t0.009\t4\n196686\t3.302\t0.12\t162\n196687\t3.375\t0.136\t15\n196690\t3.639\t0.028\t8\n196691\t3.016\t0.052\t32\n196870\t2.546\t0.218\t32\n196871\t2.669\t0.125\t3379\n196872\t2.711\t0.152\t719\n196880\t3.123\t0.225\t349\n197126\t2.828\t0.381\t77\n197127\t2.606\t0.119\t56\n197128\t2.751\t-1.0\t1\n200753\t2.968\t0.291\t109\n200754\t3.781\t0.18\t17\n200755\t2.926\t0.006\t4\n200756\t3.55\t0.394\t50\n200757\t3.215\t0.314\t179\n200759\t3.813\t0.152\t8\n200760\t3.68\t0.079\t15\n200778\t3.2\t0.021\t2\n200779\t2.798\t0.024\t24\n200781\t2.816\t0.38\t2\n200782\t3.146\t0.138\t51\n200783\t3.783\t-1.0\t1\n200784\t3.608\t0.06\t2\n200787\t3.701\t0.063\t13\n200966\t2.737\t0.248\t164\n200967\t2.638\t0.193\t666\n200968\t2.735\t0.196\t128\n200975\t3.61\t0.145\t5\n200976\t2.787\t0.336\t60\n201222\t2.754\t0.18\t12\n201223\t2.897\t0.149\t12\n204850\t3.629\t0.476\t976\n204851\t2.793\t0.054\t34\n204852\t3.367\t0.645\t98\n204853\t3.325\t0.463\t310\n204855\t3.996\t0.344\t33\n204856\t3.682\t0.08\t11\n204857\t3.947\t0.023\t6\n204858\t3.186\t0.0\t6\n204863\t3.44\t0.0\t11\n204866\t3.929\t-1.0\t1\n204870\t3.525\t0.118\t8\n204872\t4.135\t0.14\t3\n204874\t3.301\t0.205\t57\n204875\t3.121\t0.234\t55\n204876\t3.203\t0.168\t70\n204877\t3.061\t0.08\t42\n204878\t3.284\t0.173\t281\n204879\t4.309\t0.589\t23\n204881\t3.669\t0.346\t5\n204882\t3.46\t0.055\t10\n204883\t3.636\t0.704\t18\n204892\t4.537\t-1.0\t1\n205061\t2.753\t0.308\t17\n205062\t2.528\t0.15\t3869\n205063\t2.708\t0.199\t1070\n205064\t2.716\t0.2\t545\n205071\t3.421\t0.246\t38\n205072\t3.123\t0.212\t212\n205318\t2.574\t0.174\t88\n205319\t2.626\t0.158\t25\n208947\t2.969\t0.506\t259\n208948\t3.77\t0.671\t12\n208949\t3.392\t0.45\t229\n208951\t3.952\t0.118\t44\n208952\t3.545\t0.115\t138\n208953\t3.197\t0.0\t6\n208954\t3.176\t0.0\t6\n208962\t3.825\t0.039\t12\n208968\t3.44\t-1.0\t1\n208970\t3.273\t0.166\t30\n208971\t3.245\t0.214\t83\n208972\t2.968\t0.115\t113\n208973\t3.43\t0.067\t4\n208974\t3.1\t0.205\t80\n208975\t3.122\t0.204\t60\n208976\t3.551\t0.081\t6\n208977\t4.668\t0.032\t6\n208978\t4.088\t0.033\t12\n208979\t2.917\t0.271\t11\n209158\t2.495\t0.15\t1844\n209159\t2.721\t0.28\t225\n209160\t2.668\t0.436\t78\n209167\t3.017\t0.046\t5\n209168\t3.149\t0.165\t38\n209414\t2.509\t0.24\t10\n209415\t2.427\t0.146\t6\n213050\t4.433\t0.045\t6\n213054\t4.024\t0.099\t10\n213065\t5.027\t-1.0\t1\n213066\t2.704\t0.455\t23\n213067\t3.276\t0.286\t165\n213068\t3.025\t0.034\t20\n213070\t3.155\t0.284\t48\n213071\t3.03\t0.209\t38\n213072\t3.343\t0.249\t92\n213073\t4.446\t0.01\t2\n213074\t4.01\t0.314\t16\n213075\t3.489\t0.653\t32\n213084\t3.85\t0.333\t22\n213086\t4.355\t0.043\t6\n217145\t3.893\t0.312\t115\n217146\t4.057\t0.272\t72\n217147\t3.309\t0.409\t38\n217148\t3.875\t0.23\t104\n217150\t3.913\t0.338\t122\n217151\t4.078\t0.166\t14\n217152\t3.772\t0.324\t18\n217153\t3.606\t0.456\t25\n217154\t3.192\t0.524\t27\n217156\t3.103\t0.413\t22\n217157\t3.863\t0.489\t46\n217158\t3.761\t0.157\t82\n217159\t3.66\t0.413\t6\n217160\t3.35\t0.322\t22\n217161\t2.816\t0.4\t52\n217162\t2.801\t0.247\t341\n217163\t2.814\t0.353\t94\n217164\t2.999\t0.191\t26\n217165\t3.222\t0.232\t233\n217166\t3.234\t0.277\t811\n217167\t3.066\t0.296\t281\n217168\t3.131\t0.252\t665\n217169\t2.89\t0.413\t19\n217170\t3.801\t0.427\t565\n217171\t3.582\t0.409\t827\n217178\t3.927\t0.242\t20\n217180\t3.819\t0.264\t406\n217182\t3.899\t0.189\t7\n217183\t3.278\t-1.0\t1\n225335\t4.276\t0.49\t265\n225336\t4.479\t0.154\t3\n225338\t4.3\t0.0\t2\n225345\t4.243\t-1.0\t1\n225346\t4.182\t-1.0\t1\n225354\t3.789\t-1.0\t1\n225359\t3.687\t0.153\t5\n225360\t4.965\t0.0\t3\n225361\t4.086\t0.077\t5\n225362\t3.938\t0.124\t17\n225363\t4.209\t0.153\t5\n225542\t4.026\t0.331\t148\n225797\t3.377\t0.162\t3\n225798\t3.864\t0.248\t33\n229432\t4.077\t0.334\t194\n229450\t3.552\t0.0\t2\n229455\t3.61\t0.0\t2\n229458\t3.779\t0.076\t5\n229459\t3.62\t0.105\t15\n229638\t3.726\t0.142\t169\n229893\t2.88\t0.148\t17\n233547\t3.663\t0.041\t4\n233733\t3.661\t0.127\t9\n233734\t3.511\t0.169\t1320\n233735\t3.103\t0.143\t699\n233736\t2.952\t0.191\t544\n233743\t4.137\t0.779\t6\n233744\t3.541\t0.191\t21\n233990\t3.356\t0.17\t18\n233991\t3.128\t0.157\t55\n237830\t3.517\t0.262\t866\n237831\t3.053\t0.238\t780\n237832\t2.942\t0.272\t364\n237839\t3.058\t0.078\t3\n237840\t3.557\t0.208\t14\n238086\t3.309\t0.197\t15\n238087\t3.084\t0.184\t40\n241926\t3.477\t0.124\t197\n241927\t3.016\t0.163\t300\n241928\t2.871\t0.151\t320\n241936\t3.545\t0.074\t6\n242182\t3.213\t0.142\t3\n242183\t3.034\t0.049\t17\n246021\t3.749\t-1.0\t1\n246022\t3.442\t0.199\t803\n246023\t3.027\t0.153\t733\n246024\t2.83\t0.16\t737\n246031\t3.715\t0.509\t10\n246032\t3.489\t0.117\t10\n246278\t3.07\t0.175\t7\n246279\t3.018\t0.113\t65\n254014\t3.621\t0.145\t11\n254027\t3.568\t0.017\t3\n254214\t3.39\t0.158\t2671\n254215\t2.996\t0.161\t998\n254216\t2.805\t0.192\t556\n254223\t3.737\t0.252\t40\n254224\t3.439\t0.148\t13\n254470\t3.227\t0.142\t6\n254471\t3.139\t0.173\t24\n254472\t2.911\t0.206\t20\n258111\t2.215\t0.23\t2\n258310\t3.466\t0.262\t271\n258311\t2.927\t0.187\t1239\n258312\t2.76\t0.166\t1083\n258320\t3.383\t0.05\t12\n258566\t3.457\t0.042\t4\n258567\t2.819\t0.112\t11\n262406\t3.329\t0.213\t453\n262407\t2.926\t0.184\t889\n262408\t2.796\t0.186\t1231\n262416\t3.355\t0.381\t10\n262662\t2.919\t0.044\t2\n262663\t2.999\t0.226\t11\n266502\t3.401\t0.179\t388\n266503\t2.89\t0.17\t992\n266504\t2.734\t0.193\t1159\n266511\t3.732\t-1.0\t1\n266512\t3.445\t0.0\t2\n266758\t2.926\t-1.0\t1\n266759\t2.857\t0.231\t31\n270597\t3.404\t0.076\t3\n270598\t3.222\t0.253\t1595\n270599\t2.866\t0.193\t2042\n270600\t2.707\t0.189\t2073\n270607\t3.718\t-1.0\t1\n270608\t3.41\t0.38\t13\n270854\t2.9\t-1.0\t1\n270855\t2.794\t0.192\t30\n274510\t4.001\t0.0\t2\n274694\t3.388\t0.171\t354\n274695\t2.87\t0.172\t416\n274696\t2.724\t0.185\t439\n274950\t2.925\t0.039\t8\n274951\t2.479\t0.253\t12\n278789\t3.409\t0.069\t2\n278790\t3.158\t0.169\t1145\n278791\t2.849\t0.175\t801\n278792\t2.672\t0.179\t577\n278799\t3.625\t-1.0\t1\n278800\t3.474\t0.092\t7\n279046\t2.934\t0.097\t12\n279047\t2.89\t0.09\t12\n282693\t3.553\t0.0\t4\n282886\t3.443\t0.178\t536\n282887\t2.879\t0.209\t168\n282888\t2.725\t0.147\t129\n282895\t3.631\t0.142\t21\n282896\t3.222\t0.01\t8\n283143\t2.527\t0.136\t9\n286981\t3.507\t0.084\t5\n286982\t3.184\t0.155\t3390\n286983\t2.859\t0.153\t1245\n286984\t2.682\t0.159\t499\n286991\t3.54\t0.155\t13\n286992\t3.365\t0.159\t9\n287238\t3.019\t0.138\t24\n287239\t2.855\t0.076\t16\n287240\t2.979\t0.21\t26\n290891\t3.455\t0.011\t2\n290894\t3.514\t-1.0\t1\n291077\t3.476\t0.16\t11\n291078\t3.284\t0.204\t878\n291079\t2.84\t0.187\t460\n291080\t2.635\t0.193\t132\n291088\t3.528\t0.062\t2\n291334\t2.883\t0.06\t12\n291335\t2.948\t0.137\t14\n294994\t3.999\t-1.0\t1\n295173\t3.165\t0.193\t2\n295174\t3.107\t0.177\t2432\n295175\t2.774\t0.182\t341\n295176\t2.652\t0.204\t104\n295184\t3.109\t0.166\t9\n295430\t2.767\t0.112\t12\n295431\t2.657\t0.278\t12\n299081\t2.935\t0.369\t17\n299085\t3.119\t0.214\t10\n299270\t2.918\t0.218\t1400\n299271\t2.737\t0.199\t305\n299272\t2.492\t0.248\t40\n299279\t2.559\t0.037\t4\n299526\t2.488\t0.241\t28\n299527\t2.804\t0.155\t6\n303178\t2.675\t0.417\t434\n303181\t3.222\t0.078\t41\n303182\t3.654\t-1.0\t1\n303183\t3.21\t0.023\t4\n303186\t3.733\t0.044\t8\n303187\t3.128\t0.192\t8\n303365\t2.968\t0.028\t2\n303366\t2.8\t0.213\t3774\n303367\t2.584\t0.227\t2258\n303368\t2.49\t0.297\t312\n303375\t2.904\t0.202\t124\n303376\t3.053\t0.272\t32\n303622\t2.342\t0.159\t6180\n303623\t2.471\t0.154\t65\n307275\t3.127\t0.383\t1161\n307276\t3.076\t0.401\t28\n307277\t3.191\t0.02\t2\n307278\t3.567\t0.117\t38\n307279\t3.269\t0.094\t25\n307280\t3.228\t0.038\t20\n307281\t3.587\t0.03\t2\n307283\t3.205\t0.081\t30\n307292\t3.713\t0.164\t4\n307462\t2.629\t0.197\t1542\n307463\t2.457\t0.127\t3999\n307464\t2.435\t0.206\t207\n307471\t2.732\t0.251\t11\n307472\t2.825\t0.122\t121\n307718\t2.178\t0.135\t8471\n307719\t2.383\t0.156\t157\n307720\t2.299\t0.121\t3\n307728\t2.409\t0.014\t6\n311372\t3.106\t0.207\t804\n311373\t3.181\t-1.0\t1\n311374\t3.548\t0.146\t32\n311375\t3.12\t0.036\t62\n311379\t2.887\t0.06\t22\n311558\t2.597\t0.187\t2089\n311559\t2.357\t0.157\t1187\n311560\t2.486\t0.163\t95\n311567\t3.048\t0.26\t4\n311568\t3.082\t0.291\t44\n311814\t2.108\t0.152\t4572\n311815\t2.428\t0.139\t86\n311824\t2.543\t0.001\t4\n315469\t3.151\t0.278\t365\n315470\t3.549\t0.122\t63\n315471\t3.157\t0.118\t31\n315475\t3.22\t0.061\t39\n315653\t2.65\t0.215\t20\n315654\t2.552\t0.195\t16080\n315655\t2.382\t0.126\t6084\n315656\t2.483\t0.127\t418\n315663\t2.762\t0.14\t37\n315664\t2.816\t0.196\t162\n315910\t2.215\t0.168\t2203\n315911\t2.436\t0.105\t204\n315920\t2.977\t-1.0\t1\n319566\t3.225\t0.248\t552\n319567\t3.367\t0.293\t115\n319568\t3.169\t0.205\t20\n319569\t3.36\t0.238\t50\n319570\t3.392\t0.286\t42\n319571\t2.929\t0.286\t8\n319580\t2.758\t-1.0\t1\n319749\t2.528\t0.434\t19\n319750\t2.374\t0.187\t4743\n319751\t2.364\t0.145\t6282\n319752\t2.404\t0.169\t399\n319759\t2.743\t0.15\t63\n319760\t2.674\t0.189\t638\n320005\t2.585\t0.095\t3\n320006\t2.331\t0.173\t2612\n320007\t2.357\t0.121\t135\n320015\t2.781\t0.006\t2\n320016\t2.898\t0.124\t6\n323663\t3.245\t0.336\t4562\n323664\t3.526\t0.142\t2\n323665\t3.286\t0.102\t22\n323666\t3.306\t0.022\t2\n323667\t2.881\t0.196\t25\n323846\t2.35\t0.15\t3014\n323847\t2.354\t0.137\t1158\n323848\t2.403\t0.253\t6\n323855\t2.769\t0.169\t45\n323856\t2.739\t0.213\t222\n324102\t2.337\t0.19\t1691\n324103\t2.388\t0.156\t45\n327760\t2.694\t0.474\t53\n327941\t2.577\t-1.0\t1\n327942\t2.266\t0.136\t922\n327943\t2.741\t0.157\t953\n327944\t2.741\t0.235\t37\n327951\t2.904\t0.093\t8\n327952\t2.866\t0.242\t158\n328198\t2.38\t0.168\t94\n328199\t2.875\t0.15\t3\n331857\t3.111\t0.21\t60\n332038\t2.542\t0.227\t19\n332039\t2.984\t0.13\t175\n332040\t2.942\t0.295\t20\n332048\t3.399\t0.21\t18\n332294\t2.174\t0.0\t4\n335954\t3.231\t0.429\t436\n336134\t2.776\t0.248\t252\n336135\t2.833\t0.135\t693\n336136\t2.76\t0.196\t207\n336143\t3.678\t0.123\t15\n336144\t3.263\t0.218\t66\n336390\t2.874\t0.122\t4\n336391\t2.699\t0.147\t7\n340051\t3.126\t0.27\t404\n340229\t2.797\t-1.0\t1\n340230\t2.623\t0.24\t807\n340231\t2.807\t0.169\t491\n340232\t2.771\t0.212\t269\n340239\t3.206\t0.012\t2\n340240\t3.325\t0.293\t98\n340486\t2.701\t0.167\t16\n340487\t3.129\t0.34\t2\n368902\t3.528\t0.229\t2516\n368903\t3.077\t0.237\t337\n368904\t2.966\t0.304\t84\n368911\t3.616\t0.121\t7\n368912\t3.535\t0.376\t64\n369158\t3.14\t0.113\t14\n369159\t3.146\t0.323\t8\n369160\t3.179\t0.006\t2\n376924\t3.747\t0.0\t2\n377094\t3.44\t0.227\t3394\n377095\t2.982\t0.201\t1971\n377096\t2.826\t0.242\t770\n377103\t2.998\t0.426\t10\n377104\t3.462\t0.179\t110\n377350\t3.258\t0.302\t74\n377351\t3.02\t0.219\t96\n377352\t3.011\t0.211\t9\n381190\t3.595\t0.186\t49\n381191\t3.016\t0.171\t33\n381192\t3.071\t0.23\t47\n381200\t3.429\t0.053\t8\n385286\t3.676\t0.046\t15\n385287\t3.005\t0.218\t31\n385288\t3.065\t0.263\t47\n385296\t3.84\t0.251\t6\n389383\t3.107\t0.032\t5\n389384\t2.858\t0.234\t18\n389392\t3.517\t0.038\t3\n393479\t3.128\t0.008\t2\n393488\t3.419\t0.064\t3\n397575\t3.05\t0.029\t3\n397576\t2.942\t0.008\t3\n401671\t3.038\t0.025\t3\n401672\t2.931\t0.016\t3\n1073414\t1.594\t0.077\t2000853\n1073415\t1.527\t0.071\t91806\n1073423\t2.001\t0.161\t74\n1073424\t1.981\t0.067\t42\n1073679\t2.05\t0.093\t4\n1073680\t1.992\t0.039\t7\n1077511\t1.504\t0.087\t791\n1077519\t1.839\t0.106\t1862\n1077520\t1.811\t0.097\t38\n1077776\t1.753\t0.11\t23\n1110287\t2.325\t0.221\t8\n16781317\t1.299\t0.138\t2655\n16781318\t1.157\t0.073\t2154155\n16781319\t1.027\t0.087\t120477\n16781320\t1.0\t0.102\t99234\n16781321\t1.229\t0.768\t39\n16781326\t1.698\t0.206\t492\n16781327\t1.491\t0.16\t461\n16781328\t1.414\t0.148\t260\n16781329\t1.46\t0.267\t16\n16781344\t1.768\t0.207\t170\n16781345\t1.64\t0.233\t13\n16781346\t1.184\t0.24\t11\n16781347\t1.193\t0.14\t10\n16781365\t1.612\t0.001\t2\n16781573\t1.266\t-1.0\t1\n16781574\t1.083\t0.054\t1399983\n16781575\t1.026\t0.08\t10086\n16781576\t1.035\t0.083\t62\n16781583\t1.555\t0.169\t170\n16781830\t1.082\t0.064\t1503\n16781831\t1.012\t0.075\t9\n16797701\t2.055\t0.175\t200\n16797702\t1.917\t0.136\t1968\n16797703\t1.74\t0.145\t4307\n16797704\t1.627\t0.111\t7838\n16797705\t1.579\t0.095\t5410\n16797710\t2.643\t0.184\t32\n16797711\t2.367\t0.191\t736\n16797712\t2.279\t0.266\t207\n16797713\t2.22\t0.188\t513\n16797728\t2.564\t0.128\t21\n16797729\t2.481\t0.101\t5\n16797730\t2.577\t0.148\t48\n16797731\t2.401\t0.231\t244\n16797748\t2.725\t0.14\t4\n16797749\t2.87\t0.374\t77\n16797958\t1.838\t0.106\t11969\n16797959\t1.825\t0.108\t1915\n16797967\t2.268\t0.255\t20\n16798214\t1.868\t0.127\t268\n16798215\t1.772\t0.141\t42\n16798224\t2.259\t-1.0\t1\n16801798\t1.819\t0.111\t650683\n16801799\t1.721\t0.104\t153277\n16801800\t1.674\t0.089\t194202\n16801801\t1.483\t0.083\t37441\n16801806\t2.363\t0.237\t31159\n16801807\t2.243\t0.189\t5173\n16801808\t2.128\t0.132\t11654\n16801809\t2.024\t0.124\t15529\n16801824\t2.527\t0.248\t999\n16801825\t2.422\t0.325\t206\n16801826\t2.378\t0.18\t872\n16801827\t2.279\t0.155\t2704\n16801844\t2.666\t0.308\t172\n16801845\t2.522\t0.166\t717\n16802054\t1.762\t0.092\t352183\n16802055\t1.72\t0.097\t14388\n16802056\t1.688\t0.108\t6\n16802063\t2.207\t0.172\t3307\n16802064\t2.105\t0.131\t3350\n16802310\t1.696\t0.091\t7665\n16802311\t1.656\t0.128\t75\n16802320\t2.082\t0.116\t4919\n16805895\t1.623\t0.108\t3208\n16805896\t1.666\t0.126\t2100\n16805897\t1.415\t0.162\t17\n16805902\t2.205\t0.191\t1967\n16805903\t2.079\t0.152\t1682\n16805904\t1.93\t0.103\t249\n16805905\t1.958\t0.111\t24\n16805920\t2.362\t0.195\t1315\n16805921\t2.241\t0.173\t128\n16805922\t2.3\t0.193\t96\n16805923\t2.162\t0.118\t32\n16805940\t2.674\t0.201\t118\n16805941\t2.473\t0.194\t38\n16806150\t1.59\t0.082\t164495\n16806151\t1.574\t0.081\t7627\n16806159\t1.986\t0.139\t3197\n16806160\t2.009\t0.09\t401\n16806406\t1.512\t0.069\t153\n16806407\t1.394\t0.086\t533\n16806416\t1.9\t0.093\t9234\n16809992\t1.741\t0.264\t647\n16809998\t1.995\t0.155\t7813\n16809999\t1.925\t0.144\t1208\n16810000\t1.916\t0.201\t51\n16810001\t1.673\t0.087\t998\n16810016\t2.152\t0.242\t1021\n16810017\t1.796\t0.244\t670\n16810018\t2.006\t0.2\t174\n16810019\t1.965\t0.381\t4\n16810036\t2.404\t0.302\t460\n16810037\t2.386\t0.22\t205\n16810246\t1.562\t0.08\t163577\n16810247\t1.393\t0.102\t21110\n16810255\t1.861\t0.129\t9068\n16810256\t1.926\t0.104\t123\n16810502\t1.408\t0.07\t41\n16810503\t1.354\t0.073\t7\n16810512\t1.734\t0.114\t5958\n16814089\t1.446\t0.064\t5\n16814094\t1.979\t0.162\t679\n16814095\t1.82\t0.095\t9307\n16814096\t1.773\t0.108\t625\n16814097\t1.615\t0.213\t20\n16814112\t2.054\t0.303\t209\n16814113\t1.845\t0.169\t415\n16814114\t2.218\t0.193\t16\n16814115\t1.836\t0.098\t23\n16814132\t1.837\t0.254\t287\n16814133\t2.14\t0.294\t84\n16814342\t1.478\t0.072\t44091\n16814343\t1.246\t0.169\t3\n16814351\t1.618\t0.194\t150\n16814352\t1.613\t0.103\t16\n16814608\t1.556\t0.127\t44\n16834574\t3.378\t0.364\t2682\n16834575\t2.882\t0.272\t162\n16834576\t2.626\t0.23\t157\n16834577\t2.549\t0.274\t1011\n16834592\t3.473\t0.286\t507\n16834593\t3.314\t0.371\t24\n16834594\t2.897\t0.327\t42\n16834595\t2.87\t0.389\t169\n16834612\t3.665\t0.536\t15\n16834613\t3.09\t0.417\t78\n16834822\t2.235\t0.149\t6897\n16834823\t2.299\t0.166\t545\n16835078\t2.237\t0.123\t1405\n16835079\t2.102\t0.162\t46\n16838671\t2.751\t0.246\t664\n16838672\t2.368\t0.224\t165\n16838673\t2.447\t0.27\t425\n16838688\t3.18\t0.313\t89\n16838689\t2.773\t0.119\t26\n16838690\t2.582\t0.333\t127\n16838691\t2.563\t0.288\t58\n16838708\t3.027\t0.178\t12\n16838709\t2.915\t0.394\t101\n16838918\t2.115\t0.115\t8657\n16838919\t1.855\t0.183\t439\n16838927\t2.715\t0.169\t135\n16838928\t2.658\t0.069\t6\n16839174\t1.936\t0.185\t23\n16839175\t2.101\t0.064\t2\n16839184\t2.948\t-1.0\t1\n16842768\t2.281\t0.201\t1234\n16842769\t2.015\t0.03\t13\n16842784\t2.754\t0.331\t616\n16842785\t2.241\t0.25\t917\n16842786\t2.475\t0.266\t49\n16842787\t2.694\t0.214\t14\n16842804\t3.261\t0.399\t44\n16842805\t3.241\t0.251\t46\n16843014\t2.01\t0.115\t20813\n16843015\t1.834\t0.133\t156\n16843023\t2.464\t0.209\t339\n16843024\t2.494\t0.161\t19\n16843270\t1.935\t0.13\t225\n16843280\t2.489\t0.19\t50\n16846865\t1.992\t0.399\t44\n16846880\t2.745\t0.286\t511\n16846881\t2.728\t0.235\t235\n16846882\t2.384\t0.337\t109\n16846900\t3.03\t0.369\t277\n16846901\t2.906\t0.468\t87\n16847110\t1.969\t0.095\t20992\n16847111\t1.77\t0.177\t16\n16847119\t2.289\t0.187\t1133\n16847120\t2.181\t0.113\t8\n16847366\t1.923\t0.203\t4\n16847376\t2.231\t0.165\t28\n16908320\t3.119\t0.561\t1100\n16908321\t2.481\t0.4\t70\n16908322\t2.624\t0.585\t344\n16908323\t2.911\t0.375\t127\n16908340\t3.181\t0.424\t124\n16908341\t3.271\t0.469\t73\n16908550\t2.342\t0.169\t2233\n16908551\t2.432\t0.175\t414\n16908552\t2.284\t0.062\t14\n16908559\t3.148\t0.384\t31\n16908806\t2.273\t0.193\t233\n16912417\t2.568\t0.286\t226\n16912418\t2.384\t0.277\t52\n16912419\t2.383\t0.526\t37\n16912436\t2.868\t0.102\t3\n16912437\t3.175\t0.376\t43\n16912646\t2.247\t0.155\t563\n16912647\t2.196\t0.137\t13\n16912655\t2.8\t0.063\t13\n16912902\t1.902\t0.429\t4\n16912903\t2.164\t0.088\t7\n16916514\t2.705\t0.288\t257\n16916515\t2.826\t0.329\t129\n16916532\t3.054\t0.385\t17\n16916533\t3.596\t0.24\t25\n16916742\t2.215\t0.127\t1635\n16916743\t1.989\t0.141\t55\n16916751\t2.686\t0.173\t226\n16916752\t2.64\t-1.0\t1\n16916998\t2.197\t0.154\t196\n16920611\t3.015\t0.264\t187\n16920628\t3.279\t0.255\t239\n16920629\t3.195\t0.403\t63\n16920838\t2.164\t0.108\t13670\n16920839\t2.524\t0.134\t43\n16920847\t2.176\t0.207\t50\n16920848\t2.785\t0.214\t9\n16921094\t2.117\t0.097\t16\n16990260\t3.228\t0.382\t40\n16990261\t3.606\t0.35\t107\n16990470\t2.49\t0.154\t812\n16990471\t2.273\t0.267\t50\n16990472\t3.042\t-1.0\t1\n16990479\t3.31\t0.124\t16\n16990726\t2.535\t0.253\t17\n16994357\t3.54\t0.331\t863\n16994566\t2.373\t0.134\t5123\n16994567\t2.597\t0.154\t114\n16994575\t3.258\t0.143\t18\n16994822\t2.308\t0.108\t265\n16994823\t2.683\t0.0\t2\n17846534\t1.807\t0.004\t6\n17850630\t1.686\t0.082\t194786\n17850631\t1.634\t0.082\t26774\n17850632\t1.542\t0.034\t5\n17850639\t2.101\t0.105\t7379\n17850640\t2.077\t0.073\t1123\n17850886\t1.624\t0.087\t18128\n17850887\t1.587\t0.111\t90\n17850896\t2.041\t0.093\t13784\n17854727\t1.605\t0.077\t739\n17854735\t1.988\t0.193\t481\n17854736\t2.01\t0.157\t103\n17854982\t1.518\t0.05\t118\n17854983\t1.299\t0.035\t2\n17854991\t2.079\t0.0\t2\n17854992\t1.872\t0.081\t564\n17858824\t1.212\t0.0\t2\n17887503\t2.816\t0.232\t70\n17887504\t2.775\t-1.0\t1\n17887750\t2.038\t0.159\t42\n17887760\t2.72\t0.033\t2\n17891600\t2.75\t0.187\t12\n17891856\t2.984\t-1.0\t1\n18899462\t1.586\t0.08\t708\n18899472\t2.099\t0.117\t10\n18940432\t2.57\t0.156\t5\n33611790\t2.862\t0.219\t107\n33611809\t3.023\t-1.0\t1\n33611810\t1.697\t0.952\t3\n33611828\t3.382\t-1.0\t1\n33612038\t2.267\t0.06\t19\n33612039\t2.076\t0.084\t9\n33612040\t2.213\t0.116\t7\n33612047\t3.299\t0.356\t32\n33612048\t2.829\t-1.0\t1\n33612294\t2.498\t0.086\t4\n33624117\t2.68\t0.0\t2\n33624326\t2.051\t0.166\t7\n33624328\t1.644\t0.085\t2970\n33685536\t3.587\t0.192\t22\n33685537\t3.362\t0.618\t7\n33685539\t2.768\t-1.0\t1\n33685766\t2.418\t0.096\t23\n33685767\t2.3\t-1.0\t1\n33685768\t1.911\t0.307\t75\n33685775\t3.061\t0.334\t74\n33685776\t3.159\t0.258\t11\n33686022\t2.244\t-1.0\t1\n33689633\t2.268\t0.368\t3\n33689634\t3.2\t0.0\t2\n33689653\t3.142\t0.113\t4\n33689862\t1.874\t0.13\t10\n33689863\t1.999\t-1.0\t1\n33689864\t2.138\t0.163\t58\n33689871\t2.766\t0.099\t11\n33689872\t2.702\t0.904\t6\n33693731\t3.211\t0.049\t4\n33693748\t3.96\t0.381\t8\n33693749\t3.32\t0.198\t7\n33693958\t2.081\t0.047\t6\n33693959\t2.112\t0.21\t9\n33693960\t1.88\t0.205\t162\n33693967\t2.503\t0.176\t332\n33697844\t3.872\t0.0\t2\n33698055\t1.967\t-1.0\t1\n33698056\t1.612\t0.028\t8\n33767476\t2.657\t-1.0\t1\n33767477\t3.446\t-1.0\t1\n33767686\t2.131\t0.005\t3\n33767687\t2.1\t-1.0\t1\n33767688\t2.267\t0.518\t6\n33767695\t2.857\t0.194\t7\n33767696\t3.719\t0.957\t3\n33771573\t3.614\t0.457\t10\n33771783\t2.249\t0.088\t5\n33771784\t2.127\t0.16\t106\n33771791\t3.098\t-1.0\t1\n33771792\t3.166\t0.428\t3\n34623750\t1.78\t0.012\t7\n34627846\t1.55\t0.083\t65623\n34627847\t1.486\t0.077\t27424\n34627848\t1.404\t0.071\t156637\n34627855\t2.044\t0.135\t373\n34627856\t1.945\t0.103\t4751\n34628102\t1.526\t0.109\t716\n34628112\t1.965\t0.141\t8\n34631943\t1.436\t0.08\t1641\n34631944\t1.371\t0.063\t17326\n34631951\t1.879\t0.175\t1347\n34631952\t1.901\t0.158\t89\n34632198\t1.396\t0.123\t200\n34632199\t1.374\t0.136\t116\n34632207\t2.095\t0.0\t2\n34632208\t1.812\t0.114\t109\n34636040\t1.131\t0.253\t79\n34636047\t1.751\t0.123\t5003\n34636048\t1.76\t0.092\t2467\n34636294\t1.228\t0.157\t96\n34636295\t1.111\t0.035\t20\n34636304\t1.661\t0.085\t34493\n34664719\t2.605\t0.159\t86\n34664720\t2.299\t0.162\t912\n34664966\t1.951\t0.174\t35\n34664967\t1.804\t0.217\t28\n34664975\t2.749\t0.0\t2\n34664976\t2.399\t-1.0\t1\n34668816\t2.417\t0.111\t4\n34669062\t1.893\t0.17\t143\n34669071\t2.291\t0.138\t2\n35676678\t1.475\t0.093\t37\n52453894\t1.376\t0.081\t8518\n52453895\t1.293\t0.068\t14577\n52453896\t1.593\t0.165\t45\n52453903\t1.768\t0.204\t5\n52457991\t1.263\t0.085\t581\n52458000\t1.392\t0.156\t3\n83914759\t1.547\t0.085\t5\n83915013\t1.739\t0.204\t7\n83915014\t1.572\t0.079\t50584\n83915015\t1.539\t0.074\t8699\n83915023\t1.977\t0.137\t53\n83919110\t1.558\t0.068\t8984\n83919111\t1.575\t0.101\t961\n83919119\t2.014\t0.019\t9\n83951650\t2.389\t0.04\t4\n83951878\t1.973\t0.109\t22593\n83951879\t1.799\t0.11\t991\n83951887\t2.464\t-1.0\t1\n83951888\t2.672\t0.158\t11\n84025378\t2.575\t0.005\t2\n84025606\t2.151\t0.135\t549\n84025607\t2.077\t0.132\t184\n84959494\t1.626\t0.085\t32317\n84959495\t1.575\t0.081\t14689\n84959503\t2.111\t0.074\t20\n84959504\t2.015\t0.127\t36\n84963591\t1.557\t0.073\t2345\n84963599\t1.935\t0.256\t2\n84963600\t2.2\t0.296\t11\n100802822\t2.071\t0.051\t5\n100802823\t1.97\t0.021\t4\n101732615\t1.731\t0.197\t7\n101736710\t1.567\t0.082\t49304\n101736711\t1.502\t0.079\t23379\n101736719\t2.028\t0.119\t39\n101736720\t1.978\t0.107\t31\n101740807\t1.481\t0.072\t2974\n101740815\t1.989\t0.139\t38\n101740816\t1.737\t0.078\t11\n101773584\t2.915\t0.094\t4',Klb),h);d=b[0];c=Zkb.P3(d,oob,Qlb);elb.Uu=gW(Ykb.AX,gmb,6,c,15,1);elb.Vu=gW(Ykb.zX,cob,6,c,15,1);elb.Wu=gW(Ykb.zX,cob,6,c,15,1);elb.Tu=gW(Ykb.AX,gmb,6,c,15,1);for(e=0;e<c;e++){g=b[e+1];f=Zkb.n5(g,'\t');if(f.length==4){try{elb.Uu[e]=Zkb.P3(f[0],oob,Qlb);elb.Vu[e]=a4(f[1]);elb.Wu[e]=a4(f[2]);elb.Tu[e]=Zkb.P3(f[3],oob,Qlb);}catch(a){a=b1(a);if(mX(a,35)){break;}else throw c1(a);}}}elb.Yu=true;}};elb.gv=function gv(a){var b,c,d,e;elb.Yu||elb.fv();e=lnb;d=Nmb;for(c=0;c<12;c++){b=e>=elb.Uu.length||a<elb.Uu[e]?-1:a==elb.Uu[e]?0:1;if(b==0)return e;e=b<0?e-d:e+d;d=d/2|0;}return -1;};U1(276,1,{},elb._u);elb.Yu=false;Ykb.AY=w3(276);elb.hv=function hv(a,b){a.q=elb.ew(new elb.hw(a.o,b),a);};elb.iv=function iv(a,b){var c,d,e,f,g,h,i,j,k;c=elb.ov(a,b[0]);d=elb.ov(a,b[1]);e=elb.ov(a,b[2]);f=elb.ov(a,b[3]);i=new clb.Dh(d.a-c.a,d.b-c.b,d.c-c.c);j=new clb.Dh(e.a-d.a,e.b-d.b,e.c-d.c);k=new clb.Dh(f.a-e.a,f.b-e.b,f.c-e.c);g=new clb.Dh(i.b*j.c-i.c*j.b,-(i.a*j.c-i.c*j.a),i.a*j.b-i.b*j.a);h=new clb.Dh(j.b*k.c-j.c*k.b,-(j.a*k.c-j.c*k.a),j.a*k.b-j.b*k.a);return -$wnd.Math.atan2($wnd.Math.sqrt(j.a*j.a+j.b*j.b+j.c*j.c)*(i.a*h.a+i.b*h.b+i.c*h.c),g.a*h.a+g.b*h.b+g.c*h.c);};elb.jv=function jv(a,b){elb.mv(a,b);return elb.Uv(a.q,b.q);};elb.kv=function kv(a,b){var c;for(c=0;c<b.q;c++)clb.yh(a.k[c],b.J[c]);};elb.lv=function lv(a,b){var c;for(c=0;c<b.k.length;c++)clb.yh(a.k[c],b.k[c]);b.j==null?a.j=null:a.j=dlb.Vbb(b.j,b.j.length);};elb.mv=function mv(a,b){var c;if(!a.q||!b.q){c=new elb.gw(a.o);!a.q&&(a.q=elb.ew(c,a));!b.q&&(b.q=elb.ew(c,b));}};elb.nv=function nv(a,b){return a.j==null?-1:a.j[b];};elb.ov=function ov(a,b){return a.k[b];};elb.pv=function pv(a){return a.p==null?a.o.P:a.p;};elb.qv=function qv(a,b){return a.k[b].a;};elb.rv=function rv(a,b){return a.k[b].b;};elb.sv=function sv(a,b){return a.k[b].c;};elb.tv=function tv(a,b,c){if(a.j==null){a.j=gW(Ykb.Y0,znb,6,a.o.r,15,1);dlb.$bb(a.j);}while(c<0)c=c+360<<16>>16;while(c>=360)c=c-360<<16>>16;a.j[b]=c;};elb.uv=function uv(a,b,c){clb.yh(a.k[b],c);};elb.vv=function vv(a,b,c){a.k[b]=c;};elb.wv=function wv(a,b){a.p=b;};elb.xv=function xv(a,b,c){a.k[b].a=c;};elb.yv=function yv(a,b,c){a.k[b].b=c;};elb.zv=function zv(a,b,c){a.k[b].c=c;};elb.Av=function Av(a,b){var c;!b&&(b=clb.Kt(a.o));for(c=0;c<b.q;c++)clb.yh(b.J[c],a.k[c]);a.p!=null&&clb.rm(b,a.p);return b;};elb.Bv=function Bv(a){var b;this.o=a;this.k=gW(Ykb.TX,Vnb,24,a.q,0,1);for(b=0;b<a.q;b++)this.k[b]=new clb.Eh(a.J[b]);this.n=NaN;};elb.Cv=function Cv(a){elb.Dv.call(this,a,a.o);};elb.Dv=function Dv(a,b){var c;this.o=b;this.k=gW(Ykb.TX,Vnb,24,a.k.length,0,1);for(c=0;c<this.k.length;c++)this.k[c]=new clb.Eh(a.k[c]);a.j!=null&&(this.j=dlb.Vbb(a.j,a.j.length));this.p=a.p==null||Zkb.b5(a.p)?a.p:Zkb._4(a.p,Wlb);this.n=NaN;};U1(58,1,{58:1,27:1},elb.Cv);_.qb=function Ev(a){return elb.jv(this,a);};_.n=0;Ykb.BY=w3(58);elb.Gv=function Gv(a,b){var c,d,e,f,g;if(b==null)return null;g=dlb.Iab(a.c,b);if(g)return g;d=alb.Pgb('<').length;if(Zkb.c5(alb.Pgb(b).substr(alb.Pgb(b).length-d,d),'<')||(e=alb.Pgb('-').length,Zkb.c5(alb.Pgb(b).substr(alb.Pgb(b).length-e,e),'-'))){g=dlb.Iab(a.c,(f=alb.Pgb('<').length,Zkb.c5(alb.Pgb(b).substr(alb.Pgb(b).length-f,f),'<')?Zkb.p5(b,0,alb.Pgb(b).length-1)+'>':(c=alb.Pgb('-').length,Zkb.c5(alb.Pgb(b).substr(alb.Pgb(b).length-c,c),'-')?Zkb.p5(b,0,alb.Pgb(b).length-1)+'+':b)));if(g){g=new elb.Bw(g);dlb.keb(a.c,b,g);return g;}}return null;};elb.Hv=function Hv(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C;a.b|=b;A=(m=Zkb.n5('daD@h@\\H\\D\\L\\B\\Djfdrjj`Cj`XZV^[lgl|WjBp^C~RQdp\ndaDD`HP@cIICISKUT@]LCbURss\\bCPVCp_rPmV@\ndaDH@@RfzaJjjbHGWPhxdtl|yXEGDfgf}HDoTE`|G|dC]`<\ndaDH@@RfzaJjjbHGWPhxdtl|yqGDf}HDoTE`|G|dC]`<\ndaDH@@RfzaJjjbHGWPhxdtl|yqGDf}HDoTE`|G|dC]`>\ndaT@`@\\DjfjZn[jjjkJcKhGP`phxdtl|wY@xD`uyo]{|lKUfp\ndax@@DiU[zh@zHfegfzLG``\ndax@@DiYn`@@wHmumm}l=\ndax@@DiYn`@@wHmumm}t=\ndax@@DiYn`@@wHmumn}t=\ndax@@DiYn`@@wHmuum}t\ndax@@DiYn`@@wHmuun}t=\ndax@@DiYn`@@wHnuun}t=\ndax@@DiYn`h@zsEgfyEnmlG``=\ndax@@DiYnf@@zaJyEnnmom`=\ndax@@DiYnf@@zaJyEvnmom`=\ndax@@DiYnf@@zqDffyEv`mom`=\ndax@@DiYnf@@zqDffyEv`mon`\ndax@@DiYnf@@zqDff~TEm}l=\ndax@@DiYnf@@zqDff~Uyn}t=\ndax@@DiYnf@@zqDfjyEv`mom`=\ndax@@DiYnf@@zqDfj~TEm}l=\ndax@@Djfjjh@zDFEGDfegf{HG@dF`lG``\ndax@@Djfjjh@zDFEGDfeggI@phdwY@xD`tE`|D\ndax@@Djfjjh@zDFEGDfeggM@phdtwY@xD`tE`|D\ndax@@Djfjjh@zDFEGDfeggN@pdwY@xD`tE`|D\ndax@@Djfjjh@zDFEGDfeggN@plwY@xD`tE`}x\ndax@@Djfjjh@zDFEGDjegj{HG@dF`lG``\ndax@@DjfjjjHP]BCBcbSRssd`XRV[l`\\BPZBp^|>\ndax@@DjfjjjHP]BCBcbSRsug@XR[l`\\BPZBp^B<\ndax@@DjfjjjHP]BCBcbSRsug@XR[l`\\BPZBp^B>\ndax@D@bH\\DbL\\B\\JbFbN\\Dfnjjh@zRGGNHxlwPo]x\ndax@H@\\H\\D\\J\\Djfjjh@zXFGDegf{I{@dFoLG``\ndax@H@\\H\\D\\J\\Djfjjh@zXFGDeggN@pdwYOXD`uy`|D\ndax@H@\\H\\D\\L\\Djfjjh@zXFDfegf{I{ODF`lG``\ndax@H@\\H\\J\\F\\Djfjjh@zXFEGDgj{HG@dFoM{``\ndax@H@\\J\\F\\N\\Djfjjh@zhFEGDf{HG@dFoM{o@\ndax@H@\\J\\F\\N\\Djfjjh@zhFEGDf}HG@dFoMx\ndax@H@dDdJdFdDfnjjh@zJGDgfzDGo@\ndax@H@dDdJdFdDfnjjh@zJGDgfzE{o@\ndax@H@dDdJdFdDfnjjh@zJGDggNHxlwP`|D\ndax@H@dDdJdFdDfnjjh@zJGDggNHxlwPo]x\ndax@H@dDdJdFdDfnjjh@zJGDkfzDGo@\ndax@H@dDdJdFdDfnjjh@zJGDkgNHxlwP`}x\ndax@H@dDdJdFdDfnjjh@zJGDkjzDG``\ndax@H@dDdLdJdLbdLeUT@]EBRss]F}w`\ndax@H@dDdLdJdLbdLeUUAPNbaIZyncA{p<\ndax@H@dDdLdJdLbdLeUUAPNbaIZyncA{p>\ndax@P@BFBDiuZ{h@zHEEgfzHG``\ndax@P@QFQDiuZ{h@zHEEgfzHG``\ndax@P@\\H\\Djfjjh@zDFEGDfegf{HG@dF`lG``\ndax@P@\\H\\Djfjjh@zDFEGDjegj{HG@dF`lG``\ndax@P@\\H\\Djnjjh@zxEGDfegf{Q{@dF`lG``\ndax@P@\\H\\Djnjjh@zxEGDfegf{Q{OEz`lG``\ndax@P@\\H\\Djnjjh@zxEGDfegf}YxoTE`|D\ndax@P@\\H\\Djnjjj@P]\\BcbSRss]h}`R}PVCpP<\ndax@P@\\H\\Djnjjj@P]\\BcbSRss]h}`R}PVCpP>\ndax@P@\\H\\Djnjjj@P]\\BcbSRss^lBWjBp^B<\ndax@P@\\H\\Djnjjj@P]\\BcbSRss^lBWjBp^B>\ndax@Q@|Bh@dnRjZjj`Ck`XT\\ZV^[t`\\CPVCpP\ndax@R@BH|HeIijjj@NnaQqIiYyoV^KuAXOA@\ndax@R@QH|HeIijjj@NnaQqIiYyoV^KuAXOA@\ndax@R@\\H\\HyJkjjj@NnAQqIiYyoV^KuAXOA@\ndax@X@\\H\\D\\L\\B\\J\\Djfjjh@zHFEgf{I{OEzoLG``\ndax@X@\\H\\D\\L\\B\\J\\Djfjjh@zHFEggI@phdwYOYxoUy`|D\ndax@X@\\H\\D\\L\\B\\J\\Djfjjh@zHFEggN@pdwYOYxoUy`|D\ndax@X@kDdLdJkFdNdLbdLeUT@]IBR\ndax@`@BDf]j^@@zbJyAoMmom`=\ndax@`@BDf]j^@@zbJyAoNmom`=\ndax@`@BDf]j^@@zbJyAoNmwn`=\ndax@`@\\Df]j^@@zRGFyA{Nmom`=\ndax@`@\\Djfjjh@zDFEGDfegf{HG@dF`lG``\ndax@`@\\Djfjjh@zDFEGDfegf{HG@ez`lG``\ndax@`@\\Djfjjh@zDFEGDjegf{HG@dF`lG``\ndax@`@\\Djfjjh@zDFEGHjegf{HG@dF`lG``\ndax@`@\\Djfjjh@zDFEKHjegf{HG@dF`lG``\ndax@`@\\LddUUUr@]LBcbRss\\dC`RCwP\ndax@`@dDffjjjHP]]BcbSRssgHTR[u`RCPVCpP<\ndax@b@|@eJijjj@NaAaQqIiYynrApI^hKAxH\ndax@b@|@eJijjj@NaAaQqIiYynrAsq^hKAxH\ndax@b@|@eJijjj`DGP`phyDtl|wY@xDoTE`|D<\ndax@b@|@eJijjj`DGP`phyDtl|wY@xDoTE`|D>\ndax@h@BDdLdJdFdLbdLeUT@]YBSs]@}w`\ndax@h@\\H\\D\\L\\B\\Djfjjh@zhFFegf{I{OEz`lG``\ndax@h@\\H\\D\\L\\B\\Djfjjh@zhFFegf{I{OEz`lG`\x7FddEB\ndax@h@\\H\\D\\L\\B\\Djfjjh@zhFFegf}I{OTE`|D\ndax@h@\\H\\D\\L\\J\\Djfjjh@zhFDegf{I{ODFoLG``\ndax@h@\\H\\D\\L\\J\\Djfjjh@zhFDeggI@phdwYOYx`uy`|D\ndax@h@\\H\\D\\L\\J\\Djfjjj@P]TCBRssg@XR[lgl|PZ|p^B<\ndax@h@\\H\\D\\L\\J\\Djfjjj@P]TCBRssg@XR[lgl|PZ|p^B>\ndax@h@dDdLdJdFdLbdLeUT@]YBSs^NB\ndax@h@dDdLdJdFdLbdLeUT@]YBSs^N|\ndax@h@dDdLdJdFdLbdLeUT@]YBSu^NB\ndax@h@kDdLdJdFdLbdLeUT@]YBSs^N|\ndax@p@\\H\\D\\Djfjjh@zxFGDfegf{I{@dF`lG``\ndax@p@\\H\\D\\Djfjjh@zxFGDfegj{I{@dF`lG``\ndax@p@\\J\\F\\Djfjjh@zXFEGDgf{HG@dFoM{``\ndax@p@\\J\\F\\Djfjjh@zXFEGDgj{HG@dFoM{``\ndax@p@\\J\\F\\DjfjjjHP]LCBcbSs^dC`RCWnB<\ndax@p@\\J\\F\\DjfjjjHP]LCBcbSs^dC`RCWnB>\ndax@p@dDdLdLbdLeUT@]UBSRss_JBp^B\ndax@p@dDdLdLbdLeUT@]UBSRss_JBp^|\ndax@p@dDdLdLbdLeUT@]UBSRsu_JBp^B\ndax@p@dDdLdLbdLeUT@]UBSRuu_JBp^B\ndax@p@dDdLdLbdLeUT@]UBSTus_JBp^|\ndax@p@|D\\L\\DffjjjHP]MBbSRss^l|PZBp^B<\ndax@p@|D\\L\\DffjjjHP]MBbSRss^l|PZBp^B>\ndaxB@@RfRZzjjdaX`zJGDggN@hdwP`|D<\ndaxB@@RfRZzjjdaX`zJGDggN@hdwP`|D>\ndaxBRHSFCpkpslddlcUT`HdGV@d|wRo\\D>\ndaxB`HSJCprRRrMUPAtPIKOMtXOA@\ndaxD@@QIkjjj@NfaqIiYysbNIMrHMAXOA@\ndaxD@@QIkjjjbDGSPxdtl|yHEGDfyDF`lG``<\ndaxD@@QImYk`@Nhanc[{X=\ndaxD@@iIijjj@NfaQqIYynVAHKAxH\ndaxD@@iIijjj@NfaQqIYysTJNMKMrpIAXOA@\ndaxD@@iIijjjRDbCihT\\RV^\\yBcS\\lBPVCpP\ndaxD@@iIijjjRDdCihT\\RV^\\yBbs\\lBPVCw`>\ndaxD@@iIijjjRDdCihT\\RV^\\yBcS\\lBPVCpP<\ndaxD@@yIUVnz@NdaY@\ndaxDHHP@biAiCiCIICHmU@GV@xdw```\ndaxDPHP@b`cIICHmU@GU@xeL|wH`uy`|D\ndaxD`HP@cIICHmU@GS@xdtl|wH`tE`|D\ndaxD`HP@cIICHmU@GS@xeTl|wH`tE`|D\ndaxD`HPGCIICIUU@GS@xdtl|wHoTE`|D\ndaxDpJXIAICICHiCIUU@GVPd|wc``\ndaxDpJXIAICICHiCIUU@GVPd|wco@\ndaxH@@RYvjxHaAtdNM|pK[{X+\ndaxH@@RZZjj`CkhT\\RZV^[u`RCPVCpP\ndaxH@@RZZjj`CkhT\\RZV^\\lCBcbSS^lBPZBp^B\ndaxH@@RZZjj`CkhT\\RZV^\\uBcbSS^lBPZBp^B\ndaxH@@RZZjj`CkhT\\RZV^lmBcbSRs^lBPZBp^B\ndaxH@@RZZjjhQAutJNIMKONZaQqIYoVAHMAXO^@<\ndaxH@@RZZjjhaAutJNIMKONVAaQqIioVAKuAXOA@<\ndaxH@@RZZjjhaAutJNIMKONZAaQIioVAHMAXOA@<\ndaxH@@RZZjjhaAutJNIMKONZaQqIioVAKuAXOA@>\ndaxH@@RZZjjhaAutJNIMKON\\aQIoVAHMAXOA@<\ndaxH@@RZZjjhaAutJNIMKON\\aQIoVAHMAXOA@>\ndaxH@@RZZjjhaAutJNIMKON\\aQYoVAHMAXO^@>\ndaxH@@RZZjjhaAutJNIMKON\\aqIoVAKuAXOA@<\ndaxH@@RZZjjhaAutJNIMKON\\aqIoVAKuAXOA@>\ndaxH@@RZZjjhaAutJNIMKON\\aqYoVAKuAXO^@<\ndaxHHBApapQpqpRjZjj`Cj`XZV^[tgl}PVCpP\ndaxHPJBPRPRZzjjhrAuTNIKWM|KsA{p<\ndaxHPJBPRPRZzjjhrAuTNIKWM|KsA{p>\ndaxH`HApRjzjj`Ck`T\\RZV^[u`RCPVCpP\ndaxH`HApRjzjj`Ck`T\\RZV^[ugb}PVCpP\ndaxH`HApRjzjj`Ck`T\\bjV^[u`RCPVCpP\ndaxH`HApRjzjjhAAupJNIMKOMzpI^hKAxH<\ndaxH`HApRjzjjhAAupJNIMKOMzpI^hKAxH>\ndaxH`JBHRZZjjhaAttJNIKONRaQiYnVAHKAxH>\ndaxHpJBHRHrHrJPrUUPAtTIKOMtXOA@\ndaxHpJBPRPrPrJPrUUPAtTIKOMtXOA@\ndaxHpJBPRPrPrJPrUUPAtTIKOMt[w^@\ndaxHpJBPRPrPrJPrUUTE@zJDegfzLGo@<\ndaxHpJBPRPrPrJPrUUTE@zJDegfzLGo@>\ndaxHpJBPRPrPrJPrUUTE@zJDegjzLG``<\ndaxHpJBPRPrPrJPrUUTE@zJDegjzLG``>\ndaxHpJBPRPrPrJPrUUTE@zJDekfzLGo@<\ndaxHpJBPRPrPrJPrUUTE@zJDekfzLGo@>\ndaxL@@RdfnjjjHP]UCbRsse`T\\RZV[xPVCpP<\ndaxLHHS@BJdFdNdLddlbuT@]HBR\ndaxLJHS@BJdFdNdL{IIKHmU@GR@d`\ndaxL`HS@\\LddleUT@]TBSRss_JBp^B\ndaxLhJ[`\\H\\D\\L\\B\\Djfjjh@zPFF~I{OEx\nday@@@QIkjjj@NfaqIiYysPLJIMMrHMAXOA@\ndayDaLJD@HrR{IICHmU@GU@xtl|wr`lG``\ndaz@@@RYvHx@C\\`wfvwvp=\ndaz@@@RYvHx@C\\`wfvwwP\ndaz@@@RYvHx@C\\`wgVwvp=\ndaz@@@RYvix@CjHkdF|zv~v=\ndaz@@@RYvix@CjHkdG\\zv~v=\ndaz@B@BTf]bN@@wHMymm}t\ndaz@HBApapQpqpRjZjj`Cj`XZV^[tgl}PVCpP\ndaz@bHCpBTjnjjh@zxEGDfegf}YxoTE`|D\ndaz@pJBPRPrPrJPrUUPAtTIKOMtXOA@\ndaz@pJBPRPrPrJPrUUTE@zJDegjzLG``>\ndazDHLa@BJdFdNdLddlbuT@]HBR\ndazDJLa@BJdFdNdL{IIKHmU@GR@d`\ndazD`La@BLddlbuT@]TBSRss_JBp^B\ndazH`D`OCIICHuUPBCi`\\RZV^[dWjBp^B<\ndazH`D`OCIICHuUPBCi`\\RZV^[dWjBp^B>\ndazHpFhIAICICHiCIUUPRCkHR^[qpP<\ndazHpFhIAICICHiCIUUPRCkHR^[qpP>\ndazLQFaLCpkpsfgIIKHuUHBIAu`IOMtkwA@<\ndazLQFaLCpkpsfgIIKHuUHBIAu`IOMtkwA@>\ndctD@@gHiDTeIU]uPAttNIHjnmrpIATNa@\ndctD@@gHiDTeIU]uPAttNQPjvurpIATNa@\nded@@DiUfoh@@Mr[_[G\\{@=\nded@@DiUfoh@@Mr[_]G\\}@\nded@P@\\F\\LddUTeUuPAtHJNIKOHlmvPNAHOADLa@\ndedD@@{HiDUIU]T@]MCdTrMM\\lBPQCHP\ndiD@@DiYkhJ`ChlV^Q[tVzvp^BHP=\ndiD@@DiYkhJ`ChlV^Q[tVzzp^BHP\ndiD@@DiYkhJ`ChlV^aktVzvp^BHP=\ndiD@@DiYkhJ`ChlVnaktVzvp^BHP=\ndiD@@DiYkhJ`ChlVnaktVzzp^BHP\ndiD@H@\\H\\D\\L\\LddjTjn@@z`F}QyOY{nct=\ndiD@`@\\LddUTjn@@zHEGDf}HG@dGmcl=\ndiD@`@\\LddUTjn@@zHEGDf}HG@dGmct\ndiD@`@\\LddUTjn@@zHEGDf}HG@dGnct=\ndiD@`@\\LddUTjnX@zhEGDej}HG@dGnct\ndiD@`@\\LddUTjnX@zxEGDegdV}HG@dGnbD\ndiD@`@\\LddUTjnX@zxEGDegdZ}HG@dGnbD\ndiDH@@rJQERjx@CkH\\R[e`RCvqv=\ndiDH@@rJQERjx@CkH\\R[e`RCvqz\ndiDH@@rJQERjx@CkH\\bke`RCvqv=\ndiDH@@rJQERjx@CkH\\bke`RCvqz\ndiDH@@rJQERjxHaAudNIMrpI^{X{@+\ndiDH@@rJQERjxHaAudNIMrpI^{X{@-\ndiDH@@rJQERjxHaAudNIMrpI^{X}@<\ndiDH@@rJQERjy`Cih\\RV^Q[y`RBO`\ndiDH@@rJQERjy`Cih\\bf^Q[e`RCwQB\ndiF@@@rJQERjx@CkH\\R[e`RCvqv=\ndiF@`NAprRQURjx@Ch`T\\R[t`\\BP^vNp\ndiF@a@b`BX{HiDUJk`@NlarJnVAHO[Gh\ndiFH@NCHiDUJk`@NlaqInVAHO[GX\ngC`@Die@zHXir\ngC`@Die@zHXis]Knz\ngC`@Die@zHXis^Kh\ngC`@Die@zHXisgAbd\ngC`@Die@zHXisgAbfzW]t\ngC`@Die@zHXisgAbf|WP\ngC`@Dij@zHXis]HNB\ngC`@Dij@zHXis]HN|\ngC`@Dij@zHXis]Kv|\ngC`@Dij@zHXisgAbfzP\\D\ngC`@Dij@zHXisgAbfzP]x\ngC`@Dij@zHXisgAbfzWmx\ngC`@Dij@zHXiu]HNB\ngC`@Dij@zHXiugAbfzP\\D\ngC`@Dij@zHXjs]HN|\ngC`@Dij@zHXjsgAbfzP]x\ngC`@Dij@zHXju]HNB\ngC`@Dij@zHXjugAbfzP\\D\ngC`@DkZ@zHXis]SnB\ngC`@DkZ@zHXis]Sn|\ngC`@DkZ@zHXis^XH\ngC`@DkZ@zHXis^[p\ngC`@DkZ@zHXisgAbfzg\\D\ngC`@DkZ@zHXisgAbfzg]x\ngC`@DkZ@zHXisgAbf|pP\ngC`@DkZ@zHXisgAbf|w`\ngC`@DkZ@zHXiu]SnB\ngC`@DkZ@zHXiu^XH\ngC`@DkZ@zHXiugAbfzg\\D\ngC`@DkZ@zHXiugAbf|pP\ngC`B@DPHPQ`aJZ`NdFH\ngC`B@DPHPQ`aJZ`NdFN\\FJP\ngC`B@DPHWaoAJZ`NdFMto[p\ngC`D@DPHRfhChabgMt`xH\ngC`D@DPHRfhChabgN\\FJ[iApP\ngC`D@DPHRfhChabgN\\FJ[i^w`\ngC`D@DPHRfhChabkUt`xH\ngC`D@DPHRnhCkASf|pP\ngC`D@DPHRnhCkASj|pP\ngC`D@DXHRVhCiQR\ngC`D@DXHRVhCiQSgAbd\ngC`D@DXHRfhCkAbf|PP\ngC`D@DXHRfhCkAbgNCEMx``\ngC`D@DXHRfhCkAbj|PP\ngC`D@DYpRVhCiQS]Cv|\ngC`D@VPlRfhChabkUt`xH\ngC`D@VYpRfhCkAbfzP]x\ngC`D@bQDRfhChabgMt`xH\ngC`D@bQDRfhChabkUt`xH\ngC`D@bSpRnhCkASfzglD\ngC`D@xYpRVhCiQS]Cv|\ngC`D@xYpRVhCiQSgAbfzGmx\ngC`DABPHRVhCkQSj|pP\ngC`DADZHRVhCiQR\ngC`DAb[DRVhCiQR\ngC`DAx[pRVhCiQR\ngC`DAx[pRVhCiQS]Cv|\ngC`Dax[pDzTej@zTTwP}o@\ngC`H@DIKRAuhir\ngC`H@DIKTAuhis]CvB\ngC`H@DIKTAuhis^XH\ngC`H@DIKTAuhis^[p\ngC`H@DIKTAuhisgAbfzGlD\ngC`H@DIKTAuhisgAbf|pP\ngC`H@DIKTAuhisgAbf|w`\ngC`H@DIKTAuhiu]CvB\ngC`H@DIKTAuhiu^XH\ngC`H@DISRAtPqSfzP]t\ngC`H@DISRAtPqSf|PP\ngC`H@DISRAtPqSgNCEMt`{h\ngC`H@DISRAtPqSgNCEMx``\ngC`H@DISRAtPqUfzP]t\ngC`H@DISRAtPqUgNCEMt`{h\ngC`H@DISTAtPqSfzP\\D\ngC`H@DISTAtPqSfzP]x\ngC`H@DISTAtPqSfzWlD\ngC`H@DISTAtPqSgNCEMt`xH\ngC`H@DISTAtPqSgNCEMt`{p\ngC`H@DISTAtPqSgNCEMtoXH\ngC`H@DISTAtPqSjzP\\D\ngC`H@DISTAtPqSjzWlD\ngC`H@DISTAtPqSkNCEMt`xH\ngC`H@DISTAtPqUfzP\\D\ngC`H@DISTAtPqUfzP]x\ngC`H@DISTAtPqUgNCEMt`xH\ngC`H@DISTAtPqUjzP\\D\ngC`H@VIKTAuhis]CvB\ngC`H@bIKTAuhis^XH\ngC`H@bISRAtPqSf|PP\ngC`H@bISTAtPqSfzP\\D\ngC`H@bISTAtPqSgNCEMt`xH\ngC`H@bISTAtPqSjzP\\D\ngC`H@bISTAtPqUfzP\\D\ngC`H@bISTAtPqUjzP\\D\ngC`H@xIKRAuhis^Cp\ngC`H@xIKTAuhis]CvB\ngC`H@xIKTAuhis]Cv|\ngC`H@xIKTAuhis^XH\ngC`H@xIKTAuhisgAbfzGlD\ngC`H@xIKTAuhiu]CvB\ngC`HADIKTAuhis^XH\ngC`HAVIKTAuhis^XH\ngC`HAbIKTAuhis^XH\ngC`HAxIKTAuhis]CvB\ngC`HAxIKTAuhis^XH\ngC`HAxIKTAuhisgAbfzGlD\ngC`HAxIKTAuhiu]CvB\ngC`HMPISTAu`qS]HN|\ngC`HMPISTAu`qS^HH\ngC`IAVBTii@zHXjs]HNz\ngC`IAxBTej@ztTyna{A@\ngC`IAxBTej@ztTys`qS]CvB\ngC`IMP[dij@zpXindG^@\ngC`L@DPHPPeMPGVCGMy``\ngC`L@DPHPPeMPGVCGMyo@\ngC`L@DPHPPeMPGVCGUy``\ngC`L@DPHPPeMPGVCGV\\FJ[sA@\ngC`L@VPHPPeMPGVCGMy``\ngC`L@bPHPPeMPGVCGMy``\ngC`PAEdij@zPXypXi@\ngC``@deZ@ztTyoLD\ngC``ADij@zHXis]HN|\ngC``ADij@zHXis]Kv|\ngC``ADij@zHXisgAbfzP\\D\ngC``ADij@zHXisgAbfzP]x\ngC``ADij@zHXisgAbfzWmx\ngC``Adej@zTT`\ngC``Adej@zTTypXi@\ngC``Adij@zpXioDD\ngC``Adij@zpXioEx\ngC``Adij@zpXis`qS^HH\ngC``Adij@zpXjoDD\ngC``Adij@zpXjs`qS^HH\ngC`hH`xIKTAuhis]Cv|\ngCa@@dkHGVbgH\ngCa@@dkHGVbgMyn`\ngCa@@dkPGVbgMy``\ngCa@@dmHGVbgH\ngCa@@dmHGVbgMyn`\ngCa@@dmHGVbgN\\FJP\ngCa@@dmHGVbgN\\FJ[s]@\ngCa@@dmPGVbgMy``\ngCa@@dmPGVbgMyo@\ngCa@@dmPGVbgN\\FJ[sA@\ngCa@@dmPGVbgN\\FJ[s^@\ngCa@@dmPGVbgUy``\ngCa@@dmPGVbgV\\FJ[sA@\ngCa@@eMHGQCEN[iAwP\ngCa@@eMHGQCEN[qA@\ngCa@@eMHGQCEN[q^@\ngCa@@eMHGQCEN\\xLTwRCn`\ngCa@@eMHGQCEN\\xLTwbB\ngCa@@eMHGQCEV[iAwP\ngCa@@eMHGQCEV\\xLTwRCn`\ngCa@@eMHGQCEV\\xLTwbB\ngCa@@eMPGQCEN[iApP\ngCa@@eMPGQCEN[iAw`\ngCa@@eMPGQCEN[i^pP\ngCa@@eMPGQCEN[i^w`\ngCa@@eMPGQCEN\\xLTwRC``\ngCa@@eMPGQCEN\\xLTwRCo@\ngCa@@eMPGQCEN\\xLTwR}``\ngCa@@eMPGQCEN\\xLTwR}o@\ngCa@@eMPGQCENkiApP\ngCa@@eMPGQCENki^pP\ngCa@@eMPGQCENlxLTwRC``\ngCa@@eMPGQCENlxLTwR}``\ngCa@@eMPGQCEV[iApP\ngCa@@eMPGQCEV[iAw`\ngCa@@eMPGQCEV\\xLTwRC``\ngCa@@eMPGQCEV\\xLTwRCo@\ngCa@@eMPGQCEVkiApP\ngCa@@eMPGQCEVlxLTwRC``\ngCaH@jAJZ`NlFN[i^pP\ngCaH@jAJZ`NlFN\\xLTwR}``\ngCaH@jAJZ`NlFN\\xLTwfB\ngCaH@jAJZ`NlFN\\xLTwf|\ngCaHDGAIZ`NmEN[h^pP\ngCaHH@aIZ`NmEN[h^pP\ngCaHH@aIZ`NmEN[h^w`\ngCaHH@aIZ`NmEN\\xLTwP}``\ngCaHHGAIZ`NmEN[h^pP\ngCaHHGAIZ`NmEN[h^w`\ngCaHHGAIZ`NmEN\\xLTwP}``\ngCaHHGAIZ`NmENkh^pP\ngCaHHOAIZ`NmEN[h^pP\ngCaHHOAIZ`NmEN[h^w`\ngCaHHOAIZ`NmEN[sA@\ngCaHHOAIZ`NmEN\\xLTwP}``\ngCaHHOAIZ`NmEN\\xLTwP}o@\ngCaHHOAIZ`NmEN\\xLTwf|\ngCaHHOAIZ`NmENkh^pP\ngCaHHOAIZ`NmENlxLTwP}``\ngCaHL@aIZ`NeEH\ngCaHL@aIZ`NeEN\\FJP\ngCaHLDQIZ`NeEH\ngCaHLGAIZ`NeEMxO@\ngCaHLHaIZ`NeEH\ngCaHLLQIZ`NeEH\ngCaHLOAIZ`NeEMxO@\ngCaI@jA\\eMPGVCGMtoXH\ngCaIHO@RdmPGVbgMtOXH\ngCaIHO@RdmPGVbgN\\FJ[h^pP\ngCaIL@`RdmPGRbd\ngCd@@deZ@ztTyoLG}h`\ngCd@@deZ@ztTys`qS^XO{Q@\ngCd@@deZ@ztTzoLG}h`\ngCd@@deZ@ztTzs`qS^XO{Q@\ngCd@ADie@zHXis]Kn{~rD@\ngCd@ADie@zHXis^Ko{HP\ngCd@ADie@zHXisgAbfzW]w}dH\ngCd@ADie@zHXis~rD@\ngCd@ADif@zHXis]KnC~rD@\ngCd@ADif@zHXis^XO{HP\ngCd@ADif@zHXisgAbfzW\\G}dH\ngCd@ADif@zHXisgAbf|p_vP`\ngCd@ADif@zHXiu]KnC~rD@\ngCd@ADif@zHXiu^XO{HP\ngCd@ADij@zHXis]HNC~rD@\ngCd@ADij@zHXis]HNC~t@\ngCd@ADij@zHXiu]HNC~rD@\ngCd@ADij@zHXju]HNC~rD@\ngCd@ADkj@zpTzoLD\ngCd@AdeY@zTT`\ngCd@Adej@zTT`\ngCd@Adej@zTTypXi@\ngCd@Adij@zpXioDG}h@\ngCd@Adij@zpXis`qS^HO{P@\ngCd@Adij@zpXjoDG}h@\ngCd@Adij@zpXjs`qS^HO{P@\ngCd@aAteJz`NlEN[sA\x7FZ@\ngCd@aAteJz`NlEN[s^\x7FZ@\ngCd@aaNeIZ`NeEH\ngCd@aaNeIZ`NeEN\\FJP\ngCd@aaNeIZ`NeEN\\FJ[h^w`\ngCd@aaNeIZ`NeEN\\FJ[p^@\ngCdAAIrTs@]DLTznewA\x7FYB@\ngCdAAaJRu@]JJP\ngCdAAaJRu@]JJ[p^@\ngCdAAaJRu@]JJ\\xLT`\ngCdAAaJRu@]JJ\\xLTw`|\ngCdDE`DPHRfhCiAb\ngCdHH`DIKRAuhis]Cv{~rb@\ngCdHH`DIKRAuhis^Cw{JH\ngCdHI`DIKTAthis`qS^Cw{R@\ngCe@E`dkPGRbg}h`\ngCh@@dkHGVbgH\ngCh@@dkPGVbgMy``\ngCh@@dmHGVbgH\ngCh@@dmHGVbgMyn`\ngCh@@dmHGVbgN\\FJP\ngCh@@dmHGVbgN\\FJ[s]@\ngCh@@dmPGVbgMtOXH\ngCh@@dmPGVbgMy``\ngCh@@dmPGVbgMyo@\ngCh@@dmPGVbgN\\FJ[h^pP\ngCh@@dmPGVbgN\\FJ[sA@\ngCh@@dmPGVbgN\\FJ[s^@\ngCh@@dmPGVbgUy``\ngCh@@dmPGVbgV\\FJ[sA@\ngCh@@eLhGQCEN\\xLTwR{n\x7Fm@\ngCh@@eLhGQCEN\\xLTwb{~t@\ngCh@@eMHGQCEN[iAw_v`@\ngCh@@eMHGQCEN[i^w_v`@\ngCh@@eMHGQCEN[qA\x7FZ@\ngCh@@eMHGQCEN\\xLTwRCn\x7Fm@\ngCh@@eMHGQCEN\\xLTwbC~t@\ngCh@@eMHGQCEV[iAw_v`@\ngCh@@eMHGQCEV[qA\x7FZ@\ngCh@@eMPGQCEN[iApP\ngCh@@eMPGQCEN[iAp_v`@\ngCh@@eMPGQCEN[iAw`\ngCh@@eMPGQCEN[iAwov`@\ngCh@@eMPGQCEN[i^pP\ngCh@@eMPGQCEN\\xLTwRC``\ngCh@@eMPGQCEN\\xLTwRC`\x7Fm@\ngCh@@eMPGQCEN\\xLTwRCo@\ngCh@@eMPGQCEN\\xLTwRCo_m@\ngCh@@eMPGQCEN\\xLTwR}``\ngCh@@eMPGQCENkiApP\ngCh@@eMPGQCENkiAp_v`@\ngCh@@eMPGQCENki^pP\ngCh@@eMPGQCENlxLTwRC``\ngCh@@eMPGQCEV[iApP\ngCh@@eMPGQCEV[iAp_v`@\ngCh@@eMPGQCEV[iAwov`@\ngCh@@eMPGQCEV\\xLTwRC``\ngCh@@eMPGQCEV\\xLTwRC`\x7Fm@\ngCh@@eMPGQCEVkiApP\ngCh@@eMPGQCEVkiAp_v`@\ngCh@@e[PGQCEN[j]p_v`@\ngCh@@e[PGQCEN[sA\x7FZ@\ngCh@@e[PGQCEN[s^\x7FZ@\ngCh@@e[PGQCEN\\xLTwT{`\x7Fm@\ngCh@@e[PGQCENkj]p_v`@\ngCh@@e[PGQCENksA\x7FZ@\ngCh@@e[PGQCENlxLTwT{`\x7Fm@\ngChA@IRUdCkQSf|GP\ngChA@IRVdCkQSd\ngChA@IRVhCkQSfzGlD\ngChA@IRVhCkQSf|pP\ngChA@IRVhCkQSf|w`\ngChA@IRVhCkQSgNCEMtOXH\ngChA@IRVhCkQSgNCEMy``\ngChA@IRVhCkQSgNCEMyo@\ngChA@IRVhCkQSj|pP\ngChA@IRVhCkQSkNCEMy``\ngChA@IRfhChabgMt`xH\ngChA@IRfhChabgMt`{p\ngChA@IRfhChabgMtoXH\ngChA@IRfhChabgN\\FJ[iApP\ngChA@IRfhChabgUt`xH\ngChA@IRfhChabgUtoXH\ngChA@IRfhChabgV\\FJ[iApP\ngChA@IRfhChabkUt`xH\ngChA@IRmhChabgMuNxO{P@\ngChA@IRmhChabgMy`\x7Fm@\ngChA@IRmhChabgN\\FJ[j]p_v`@\ngChA@IRmhChabgUuNxO{P@\ngChDD@bABUt`]XJ\\wf{~tP\ngChDDDRHbUt`]XJ\\wf{~tP\ngChHD@aIZ`NmEN[h^p_vb@\ngChHDOAIZ`NmENkh^p_vb@\ngChHH@aIZPNmEN[h^w_vd@\ngChHH@aIZ`NmEN[h^p_vd@\ngChHH@aIZ`NmEN[h^wovd@\ngChHH@aIZ`NmEN\\xLTwP}`\x7FmH\ngChHH@aIZ`NmENkh^p_vd@\ngChHH@aJZPNbFJlypXindG]\x7FZP\ngChHHOAIZ`NmEN[h^p_vd@\ngChHHOAIZ`NmEN\\xLTwP}`\x7FmH\ngChHHOAIZ`NmENkh^p_vd@\ngChHL@aIZ`NeEH\ngChHL@aIZ`NeEMxO@\ngChHL@aIZ`NeEN\\FJP\ngChHL@aJZ`NlFJ[qA@\ngChHL@aJZ`NlFJ\\xLTwbB\ngChHLHaIZ`NeEH\ngChHLLQIZ`NeEH\ngChHLOAIZ`NeEH\ngChIDOARdmPGVbgMtOXH\ngChIHOBRdkPGVbgMy`\x7FmH\ngChIL@cRdmPGRbd\ngChIL@cRdmPGRbf|G`\ngChILLSRdmPGRbd\ngCh`LHe]PGRBd\ngCi@DDeZ@ztTyoLG}h`\ngCi@DDeZ@ztTyoM{}h`\ngCi@DDeZ@ztTzoLG}h`\ngCi@HDii@zHXis]HN{~t`\ngCi@HDii@zHXis^HO{R@\ngCi@HDii@zHXisgAbfzP]w}i@\ngCi@HDii@zHXjs]HN{~t`\ngCi@HDij@zHXis]HNB\ngCi@HDij@zHXis]HNC~t`\ngCi@HDkj@zpTyoLD\ngCi@HDkj@zpTyoMx\ngCi@HDkj@zpTys`qS^XH\ngCi@HDkj@zpTzoLD\ngCi@LDej@zTT`\ngCi@LDej@zTTypXi@\ngCi@LDej@zTTypXioMx\ngCi@LDij@zpXioDD\ngCi@LDij@zpXis`qS^HH\ngCi@LDij@zpXjs`qS^HH\ngCiALMJRu@]JJP\ngCiALMJRu@]JJ[s^@\ngCiALMJRu@]JJ\\xLT`\ngCiALMJRu@]JJ\\xLTwf|\ngCl@ADe[PGVBgUy`\x7Fl``\ngClAADnRmhCkASj|p_vPP\ngFp@DjYZXHCkASfyW]x{n\x7FrTrp=\ngFp@DjYZjjQCiabgIZyHXis\\kv|_WwyJYX<\ngFp@DjxujhCiabgIZwL{`dMC~RvN@\ngFp@LdaahUPGVrVmsMkYCP\x7Fdmc`=\ngFp@LdaahUPGVrVmsMkY}__dmc`=\ngFp@LdaahUPGVrVmsMkiCP\x7Fdmc`\ngFp@LdaahUTrGVrVmsMkYC__dmc`+\ngFp@LdaahUTrGVrVmsMkYC__dmc`-\ngFp@LdaahUTrGVrVmsMkiC__dmc`<\ngFp@LdaahUTrGVrVmsMkiC__dmc`>\ngFp@LddLUUPGSCENRusdyK\\pJBPtOyHZX\ngFp@LddLUUPGSCENRusdyK\\sr|PtOyHZX\ngFp@LddLUUTBGSCENRurPqRVy`Uxah_rPtp>\ngFp@LddLUUTBGSCENRus`iK\\sr|PtOyHZX>\ngFp@LddLUUTBGSCENRusdyK\\pJ|PtOyHZX<\ngFp@LddLUUTBGSCENRusdyK\\pJ|PtOyHZX>\ngFp@LddLUUTBGSCENRushiK\\pJ|PtOyHZX<\ngFp`@TfXujjJChqSfnSENRwVCP\x7Fdmc`<\ngFp`@TizJjiRYChqSfn\\dm[iAh_rPup<\ngFp`@TizJjiRZChqSfmtoTOyHZx<\ngFp`@TizJjiRZChqSfmtoTOyHZx>\ngFp`@TizJjiRZChqSfn\\dm[iAh_rPup<\ngFp`@TizJjiRZChqSfn\\dm[iAh_rPup>\ngFp`@dfxujhChqrVmtPtOyKXx\ngFp`@dfxujhChqrVmt_WwyKXx\ngFp`@dfxujjYChqrVmtPwwyKXx<\ngFp`@dfxujjYChqrVmtPwwyKXx>\ngFq@@dmXuU@]VJ\\ek_XICP\x7Fdem`\ngFq@@dsFmU@]VJ\\ek_XICP\x7Fdmc`\ngFq@@dsFmU@]VJ]Ek_XICP\x7Fdmc`\ngFq@@dsFmUQH]VJ]Ek_XIC__dmc`<\ngFq@@dsFmUQH]VJ]Ek_XIC__dmc`>\ngFq@@dsFuURH]VJ\\ek_XICP\x7Fdmc`<\ngFq@@dsFuURH]VJ\\ek_XICP\x7Fdmc`>\ngFq@@eMXuURH]LLTyKVyP\\D~h_rRvp<\ngFq@@eMqUURH]VJ\\ek_HICP\x7Fdak`<\ngFq@@eMqUURH]VJ\\ek_HICP\x7Fdak`>\ngFq@@eMqUURH]VJ\\ek_KqCP\x7Fdak`<\ngFq@@eMqUURH]VJ\\ekdaRVm|oDMC~RFn@>\ngFq@@eMqUURH]VJ\\ekgIKV~WbFa\x7FICW@<\ngFq@@eMqUURH]VJ\\ekgIKV~WbFa\x7FICW@>\ngFq@@eMqUURH]VJ\\ekgIrV~PRFa\x7FICW@<\ngFq@@eMqUURH]VJ\\ekgIrV~PRFa\x7FICW@>\ngFq@@eMqUURH]VJ\\ekgIrV~PSza\x7FICW@<\ngFq@@eOQUARP]JJ[yAN{o|dM\\+\ngFq@@eOQUARP]JJ[yAN{o|dM\\-\ngFq@@eOQUARP]JJ[y^N{o|dM\\+\ngFq@@eOQUARP]JJ[y^N{o|dM\\-\ngFq`@bdwFmUSP]ZNZweC~RvN@>\ngFq`ALe\\qUU@]ENRunbFa\x7FISW@\ngFx@@eMXuU@]LLTyKVyP\\Dah_rRvuh@\ngFx@@eOQMA@]JJ[y^N{o|dM\\=\ngFx@@eOQUARP]JJ[yAN{o|dM\\+\ngFx@@eOQUARP]JJ[yAN{o|dM\\-\ngFx@@eOQUARP]JJ[y^N{o|dM\\+\ngFx@@eOQUARP]JJ[y^N{o|dM\\-\ngFx@@eSFuU@]LLTyKVyP\\Dah_rVquh@=\ngFx@@eSFuU@]LLTzKVyP\\Dah_rVquh@\ngFx@@eSFuU@]LLUZKVyP\\Dah_rVqp\ngFxAAIRicZ`@NbFR\\wJC`gm{~RvN@=\ngFxAAYRicZ`@NbFR\\wJC`gm{~RvNm@=\ngFx`DBdwFmUSP]ZNZweC~RvN@<\ngFy@DDfxujhChqrVmtPtOyKXx\ngFy@DDfxujjYChqrVmtPwwyKXx<\ngFy@DDfxujjYChqrVmtPwwyKXx>\ngGP@DiWj`NbgIZwQCP`\ngGP@DjZ@@Mrm{Yw]`=\ngGP@DjZ@@Mrm{Yw^`=\ngGP@DjZ@@Mrm{Y{^`=\ngGP@DjZ@@Mrm{iw^`\ngGP@DjZ@@Mrm{i{^`=\ngGP@DjZ@@Mrn{i{^`=\ngGP@DjZ@@NZFJ\\enUw]O[t=\ngGP@DjZ@@N\\EI[e[wSn}@\ngGP@DjZ@@N\\EN[e[wSv}@\ngGP@DjZ@@N\\FN[e]wSv}@\ngGP@DjZX@NhJyV}l{np=\ngGP@DjZX@NhJyV}l{oP\ngGP@DjZX@NhJyV}l}oP=\ngGP@DjZX@NhJyV}t{np=\ngGP@DjZX@NhJyV}t{oP\ngGP@DjZX@NhJyW]l{np=\ngGP@DjZX@NhJyW]l{oP\ngGP@DjZX@NhJyW]l}oP=\ngGP@DjZX@NhJyW]t{np=\ngGP@DjZX@NhJyW]t{oP\ngGP@DjZX@NhJyW]t}oP=\ngGP@DjZX@NhKNBdmrn{iw^`\ngGP@DjZX@NhKNCDmrn{Yw^`\ngGP@DjZX@NhKNCDmrn{iw^`\ngGP@DjZX@NlEN[e]pSn{@=\ngGP@DjZX@NlEN[e]pSn{\x7FIPh`=\ngGP@DjZX@NlEN[e]pSn}@\ngGP@DjZX@NlEN[e]pSv}@=\ngGP@DjZX@NlEN[e]wcn{@=\ngGP@DjZX@NlEN[e]wcn{\x7FIPh`=\ngGP@DjZX@NlEN[e]wcn}@\ngGP@DjZX@NlEN[e]wcv}@=\ngGP@DjZX@NlEN[{AN{l=\ngGP@DjZX@NlEN[{AN{t\ngGP@DjZX@NlEN[{AO[t=\ngGP@DjZX@NlEN[{^N{l=\ngGP@DjZX@NlEN[{^N{t\ngGP@DjZX@NlEN\\xJRwJ{`g]z\ngGP@DjZX@NlEN\\xJRwJ{oG]z\ngGP@DjZX@NlEN\\xJRwvB]wh\ngGP@DjZX@NlEN\\xJRwv|]wh\ngGP@DjZX@NlEN\\xJ\\wJ{`gmz\ngGP@DjZX@NlEN\\xJ\\wvB^wh\ngGP@DjZX@NlEN\\xLRwJ{`g]z\ngGP@DjZX@NlEN\\xLRwvB]wh\ngGP@DjZX@NlEN\\xLRwv|]wh\ngGP@DjZX@NlEN\\xL\\wJ{`gmz\ngGP@DjZX@NlEN\\xL\\wvB^wh\ngGP@DjZX@NlENke]pSn{@=\ngGP@DjZX@NlENke]pSn}@\ngGP@DjZX@NlENke]pSv}@=\ngGP@DjZX@NlENk{AN{l=\ngGP@DjZX@NlENk{AN{t\ngGP@DjZX@NlENk{AO[t=\ngGP@DjZX@NlENlxJRwJ{`g]z\ngGP@DjZX@NlENlxJRwvB]wh\ngGP@DjZX@NlENlxLRwJ{`g]z\ngGP@DjZX@NlENlxLRwvB]wh\ngGP@DjZX@NlENlxL\\wJ{`gmz\ngGP@DjZX@NlENlxL\\wvB^wh\ngGP@DjZY`NbFR\\wJ{`g]z\ngGP@DjZY`NbFR\\wJ{`gmv\ngGP@DjZY`NbFR\\wJ{`gmz\ngGP@DjZY`NbFR\\wJ{oGmv\ngGP@DjZY`NbFR\\wJ{oGmz\ngGP@DjZY`NbFR\\wvB]wX\ngGP@DjZY`NbFR\\wvB^wh\ngGP@DjZY`NbFR]WJ{`gmv\ngGP@DjZY`NbFR]WJ{`gmz\ngGP@DjZY`NdJUrm{Yw]`\ngGP@DjZY`NdJUrm{iw^`\ngGP@DjZY`NdJUrn{Y{]`\ngGP@DjZY`NdJUrn{i{^`\ngGP@DjZY`NfFJ\\ek\\knB^tH\ngGP@DjZY`NfFJ\\ek]XMB\ngGP@DjZY`NfFJ\\ek_KnCP`\ngGP@DjZY`NfFJ\\ek_XI{_@\ngGP@DjZY`NfFJ\\ekfabgI[e]pSva@\ngGP@DjZY`NfFJ\\ekfabgI[kAhP\ngGP@DjZY`NfFJ\\ekfabgI[y]pZD\ngGP@DjZY`NfFJ\\ekgARVyW\\D}hP\ngGP@DjZY`NfFJ\\ekgARV~W\\Fa@\ngGP@DjZY`NfFJ\\ekgASf~W\\Fa@\ngGP@DjZY`NfFJ\\ekgAbVzpZD\ngGP@DjZY`NfFJ\\ekgAbV~W\\Fa@\ngGP@DjZY`NfFJ\\ekgAcfyW\\D}hP\ngGP@DjZY`NfFJ\\ekgAcf~W\\Fa@\ngGP@DjZY`NfFJ\\em\\knB^tH\ngGP@DjZY`NfFJ\\em]XMB\ngGP@DjZY`NfFJ\\em_KnCP`\ngGP@DjZY`NfFJ\\em_XI{P`\ngGP@DjZY`NfFJ\\emgAcfyW\\D}hP\ngGP@DjZY`NfFJ\\emgAcf~W\\Fa@\ngGP@DjZY`NfFJ]Em\\knB^tH\ngGP@DjZY`NfFJ]Em]XMB\ngGP@DjZY`NfFJ]Em_KnCP`\ngGP@DjZY`NfFJ]EmgAcfyW\\D}hP\ngGP@DjZj`NfFJ\\ek\\hNBPtH\ngGP@DjZj`NfFJ\\ekfabgI[eApRFa@\ngGP@DjZj`NfFJ\\fm\\hNBPtH\ngGP@DjZj`NfFJmFm\\hNBPtH\ngGP@DjZjdEDNfFJ\\ekdacdmr`xIC_@<\ngGP@DjZjdEDNfFJ\\ekdacdmr`xIC_@>\ngGP@DjZjdEDNfFJ\\ekfabgI[eAwbF~@<\ngGP@DjZjdEDNfFJ\\ekfabgI[eAwbF~@>\ngGP@DjZjdEDNfFJ\\ekgARVyP]xao`<\ngGP@DjZjdEDNfFJ\\ekgARVyP]xao`>\ngGP@DjZjdEDNfFJ\\ekgAbVyP\\Dao`<\ngGP@DjZjdEDNfFJ\\ekgAbVyP\\Dao`>\ngGP@DjZjdEDNfFJ\\ekgAcfyP\\DahP<\ngGP@DjZjdEDNfFJ\\ekgAcfyP\\DahP>\ngGP@DjZjdEDNfFJ\\ekgAcfyP\\Dao`<\ngGP@DjZjdEDNfFJ\\ekgAcfyP\\Dao`>\ngGP@DjZjdEDNfFJ\\emgAbVyP\\DahP<\ngGP@DjZjdEDNfFJ\\emgAbVyP\\DahP>\ngGP@DjZjdEDNfFJ\\emgAcfyP\\DahP<\ngGP@DjZjdEDNfFJ\\emgAcfyP\\DahP>\ngGP@DjZjdEDNfFJ\\fmgAcfyP\\DahP<\ngGP@DjZjdEDNfFJ\\fmgAcfyP\\DahP>\ngGP@DjZjdEDNfFJ]EkfabgI[eApRF~@<\ngGP@DjZjdEDNfFJ]EkfabgI[eApRF~@>\ngGP@DjZjdEDNfFJ]Em\\hNBPtH<\ngGP@DjZjdEDNfFJ]Em\\hNBPtH>\ngGP@DjZjdEDNfFJ]EmgAcfyP\\DahP<\ngGP@DjZjdEDNfFJ]EmgAcfyP\\DahP>\ngGP@DjZjdEDNfFJ]FmgAcfyP\\DahP<\ngGP@DjZjdEHNfFJ\\ekfabgI[eAwbF~@\ngGP@DjZjdEHNfFJ\\ekgARVyP]xao`\ngGP@DjZjdEHNfFJ\\ekgAbVyP\\Dao`<\ngGP@DjZjdEHNfFJ\\ekgAbVyP\\Dao`>\ngGP@DjZjdEHNfFJ\\ekgAcfyP\\DahP\ngGP@DjZjdEHNfFJ\\emgAbVyP\\DahP<\ngGP@DjZjdEHNfFJ\\emgAbVyP\\DahP>\ngGP@DjZjdEHNfFJ\\emgAcfyP\\DahP<\ngGP@DjZjdEHNfFJ\\emgAcfyP\\DahP>\ngGP@DjZjdEHNfFJ\\fkgAbVyP\\Dao`<\ngGP@DjZjdEHNfFJ\\fkgAbVyP\\Dao`>\ngGP@DjZjdEHNfFJ\\fmgAcfyP\\DahP<\ngGP@DjZjdEHNfFJ\\fmgAcfyP\\DahP>\ngGP@DjZjdEHNfFJ]EkfabgI[eApRF~@>\ngGP@DjZjdEHNfFJ]EkgAbVyP\\Dao`<\ngGP@DjZjdEHNfFJ]EkgAbVyP\\Dao`>\ngGP@DjZjdEHNfFJ]Em\\hNBPtH\ngGP@DjZjdEHNfFJ]EmgAbVyP\\DahP<\ngGP@DjZjdEHNfFJ]EmgAbVyP\\DahP>\ngGP@DjZjhDNfFJ\\fmdacdmr`xICP`<\ngGP@DjZjhDNfFJ\\fmdacdmr`xICP`>\ngGP@DjZjhDNfFJ]Fm\\hNBPtH>\ngGP@DjZjiDNfFJ\\ek\\hNBPwp<\ngGP@DjZjiDNfFJ\\ek\\hNBPwp>\ngGP@DjZjiDNfFJ\\ekdabdmr`xIC_@<\ngGP@DjZjiDNfFJ\\ekdabdmr`xIC_@>\ngGP@DjZjiDNfFJ\\ekdabgMr`xICP`<\ngGP@DjZjiDNfFJ\\ekdabgMr`xICP`>\ngGP@DjZjiDNfFJ\\ekfabgI[eApRF~@<\ngGP@DjZjiDNfFJ\\ekfabgI[eApRF~@>\ngGP@DjZjiDNfFJ\\em\\hNBPtH<\ngGP@DjZjiDNfFJ\\em\\hNBPtH>\ngGP@DjZjiDNfFJ\\emdabgMr`xICP`<\ngGP@DjZjiDNfFJ\\emdabgMr`xICP`>\ngGP@DjZjiDNfFJ\\emfabgI[eApRFa@<\ngGP@DjZjiDNfFJ\\emfabgI[eApRFa@>\ngGP@Djfj`NfFJ\\ek\\hNBPtH\ngGP@Djfj`NfFJ\\ek\\hNBPtOyJED\ngGP@Djfj`NfFJ\\ek\\hNBPwp\ngGP@Djfj`NfFJ\\ek\\hNB_TH\ngGP@Djfj`NfFJ\\ek\\hNB_Wp\ngGP@Djfj`NfFJ\\ek\\hN|_TH\ngGP@Djfj`NfFJ\\ekdaSdmr`{q}P`\ngGP@Djfj`NfFJ\\ekdaSdmr`{q}_@\ngGP@Djfj`NfFJ\\ekdabdmr`xICP`\ngGP@Djfj`NfFJ\\ekdabdmr`xIC_@\ngGP@Djfj`NfFJ\\ekdabdmr`xI}P`\ngGP@Djfj`NfFJ\\ekgAbVyP\\DahP\ngGP@Djfj`NfFJ\\ekgAbVyP\\Dao`\ngGP@Djfj`NfFJ\\ekgArVyP\\Dah_rTJH\ngGP@Djfj`NfFJ\\ekgArVyP\\D~hP\ngGP@Djfj`NfFJ\\ekgArVyP\\D~o`\ngGP@Djfj`NfFJ\\em\\hNBPtH\ngGP@Djfj`NfFJ\\em\\hNB_TH\ngGP@Djfj`NfFJ\\emgAbVyP\\DahP\ngGP@Djfj`NfFJ\\emgArVyP\\D~hP\ngGP@Djfj`NfFJ\\fk\\hNBPtH\ngGP@Djfj`NfFJ\\fk\\hNBPwp\ngGP@Djfj`NfFJ\\fkdabdmr`xICP`\ngGP@Djfj`NfFJ\\fkdabdmr`xIC_@\ngGP@Djfj`NfFJ\\fkgArVyP\\DahP\ngGP@Djfj`NfFJ\\fkgArVyP\\Dao`\ngGP@Djfj`NfFJ\\fm\\hNBPtH\ngGP@Djfj`NfFJ]Fk\\hNBPtH\ngGP@Djfj`NfFJ]Fk\\hNBPwp\ngGP@Djfj`NfFJ]FkgAbVyP\\DahP\ngGP@Djfj`NfFJ]Fm\\hNBPtH\ngGP@Djfj`NfFJmEk\\hNB_TH\ngGP@Djfj`NfFJmFk\\hNBPtH\ngGP@DjfjhDNfFJ\\ekdabdmr`{q}P`<\ngGP@DjfjhDNfFJ\\ekdabdmr`{q}P`>\ngGP@DjfjhDNfFJ\\ekdacdmr`xI}P`<\ngGP@DjfjhDNfFJ\\ekdacdmr`xI}P`>\ngGP@DjfjhDNfFJ\\ekdacdmr`xI}_@<\ngGP@DjfjhDNfFJ\\ekdacdmr`xI}_@>\ngGP@DjfjhDNfFJ\\ekgARVyP]x~hP<\ngGP@DjfjhDNfFJ\\ekgARVyP]x~hP>\ngGP@DjfjhDNfFJ\\ekgAbVyP\\D~hP<\ngGP@DjfjhDNfFJ\\ekgAbVyP\\D~hP>\ngGP@DjfjhDNfFJ\\fkgAbVyP\\DahP<\ngGP@DjfjhDNfFJ\\fkgAbVyP\\DahP>\ngGP@DjfjhDNfFJ]Ek\\hNB_TH<\ngGP@DjfjhDNfFJ]Ek\\hNB_TH>\ngGP@DjfjhDNfFJ]EkgAbVyP\\D~hP<\ngGP@DjfjhDNfFJ]EkgArVyP\\D~hP<\ngGP@DjfjhDNfFJ]EkgArVyP\\D~hP>\ngGP@DjfjhDNfFJ]FkgARVyP\\DahP<\ngGP@DjfjhDNfFJ]FkgARVyP\\DahP>\ngGP@DjfjhDNfFJ]FkgARVyP\\Dao`<\ngGP@DjfjhDNfFJ]FkgARVyP\\Dao`>\ngGP@Djyj`NbIIZwLwmdMB\ngGP@Djyj`NbIIZwLwndMB\ngGP@Djyj`NbIIZwL{mdMB\ngGP@Djyj`NbIIZwL{ndMB\ngGP@Djyj`NbIIkWLwmdMB\ngGP@Djyj`NbIIkWLwndMB\ngGP@Djyj`NbIIkWL{ndMB\ngGP@Djyj`NbIIkYLTyK\\s^zPtH\ngGP@Djyj`NfFJ\\ek\\snBPtH\ngGP@Djyj`NfFJ\\ek_XICP`\ngGP@Djyj`NfFJ\\ek_XICP\x7FdlRP\ngGP@Djyj`NfFJ\\ekdacdmsNxICP`\ngGP@Djyj`NfFJ\\ekdacdm}`dMB\ngGP@Djyj`NfFJ\\ekdqSdmsNxICP`\ngGP@Djyj`NfFJ\\ekdqSdmsN{qCP`\ngGP@Djyj`NfFJ\\ekdqSdm}`dMB\ngGP@Djyj`NfFJ\\ekfabgI[f]pRFa@\ngGP@Djyj`NfFJ\\ekfabgI[{AHZD\ngGP@Djyj`NfFJ\\ekfabgI[{^HZD\ngGP@Djyj`NfFJ\\fm\\snBPtH\ngGP@Djyj`NfFJ\\fm_XICP`\ngGP@Djyj`NfFJ\\fmdacdmsNxICP`\ngGP@Djyj`NfFJ]Ek\\snBPtH\ngGP@Djyj`NfFJ]Ek_XICP`\ngGP@Djyj`NfFJ]Ekdacdm}`dMB\ngGP@Djyj`NfFJ]EkfabgI[f]pRFa@\ngGP@Djyj`NfFJ]EkfabgI[{AHZD\ngGP@Djyj`NfFJ]FmdacdmsNxICP`\ngGP@DjyjhdNbIIZwLwmdM|>\ngGP@DjyjhdNbIIZwLwndM|<\ngGP@DjyjhdNbIIZypXynYw[HZD<\ngGP@DjyjhdNbIIZypXynYw[HZD>\ngGP@DjyjhdNbIIZypXynYw]HZD<\ngGP@DjyjhdNbIIZypXynYw]HZD>\ngGP@DjyjhdNbII[WLwndMB<\ngGP@DjyjhdNbII[WLwndMB>\ngGP@DjyjhdNbII[WL{ndMB<\ngGP@DjyjhdNbII[WL{ndMB>\ngGP@DjyjhdNbII[YpXynYw]HZD<\ngGP@DjyjhdNbII[YpXynYw]HZD>\ngGP@DjyjhdNbII[YtTynYw]HZD<\ngGP@DjyjhdNbIIjypXenYw]H[x<\ngGP@DjyjhdNfFJ\\ek_XIC_@<\ngGP@DjyjhdNfFJ\\ek_XIC_@>\ngGP@DjyjhdNfFJ\\ekdacdm}`dM|<\ngGP@DjyjhdNfFJ\\ekdacdm}`dM|>\ngGP@DjyjhdNfFJ\\ekdacdm}`dM}~RqI@>\ngGP@DjyjhdNfFJ\\ekfabgI[f]pRF~@>\ngGP@DjyjhdNfFJ\\ekfabgI[{AH[x<\ngGP@DjyjhdNfFJ\\ekfabgI[{AH[x>\ngGP@DjyjhdNfFJ\\ekfabgI[{^H[x<\ngGP@DjyjhdNfFJ\\ekfabgI[{^H[x>\ngGP@DjyjhdNfFJ\\ekgAbVyg\\Dao`<\ngGP@DjyjhdNfFJ\\ekgAbVyg\\Dao`>\ngGP@DjyjhdNfFJ\\ekgAbV~pRF~@<\ngGP@DjyjhdNfFJ\\ekgAbV~pRF~@>\ngGP@DjyjhdNfFJ\\ekgAcfyg\\DahP<\ngGP@DjyjhdNfFJ\\ekgAcfyg\\DahP>\ngGP@DjyjhdNfFJ\\ekgAcf~pRFa@<\ngGP@DjyjhdNfFJ\\ekgAcf~pRFa@>\ngGP@DjyjhdNfFJ\\ekgQRV~pRF~@<\ngGP@DjyjhdNfFJ\\ekgQRV~pRF~@>\ngGP@DjyjhdNfFJ\\ekgQRV~wbF~@<\ngGP@DjyjhdNfFJ\\ekgQRV~wbF~@>\ngGP@DjyjhdNfFJ\\ekgQSfyg\\DahP<\ngGP@DjyjhdNfFJ\\ekgQSfyg\\DahP>\ngGP@DjyjhdNfFJ\\ekgQSf~pRFa@<\ngGP@DjyjhdNfFJ\\ekgQSf~pRFa@>\ngGP@DjyjhdNfFJ\\ekgQSf~wbFa@<\ngGP@DjyjhdNfFJ\\ekgQSf~wbFa@>\ngGP@DjyjhdNfFJ\\em\\snBPtH<\ngGP@DjyjhdNfFJ\\em\\snBPtH>\ngGP@DjyjhdNfFJ\\em_XICP`<\ngGP@DjyjhdNfFJ\\em_XICP`>\ngGP@DjyjhdNfFJ\\emdacdmsNxICP`<\ngGP@DjyjhdNfFJ\\emdacdmsNxICP`>\ngGP@DjyjhdNfFJ\\emgAbVyg\\DahP<\ngGP@DjyjhdNfFJ\\emgAbVyg\\DahP>\ngGP@DjyjhdNfFJ\\emgAbV~pRFa@<\ngGP@DjyjhdNfFJ\\emgAcfyg\\DahP<\ngGP@DjyjhdNfFJ\\emgAcfyg\\DahP>\ngGP@DjyjhdNfFJ\\emgAcf~pRFa@<\ngGP@DjyjhdNfFJ\\emgAcf~pRFa@>\ngGP@DjyjhdNfFJ\\emgQSfyg\\DahP<\ngGP@DjyjhdNfFJ\\emgQSf~pRFa@>\ngGP@DjyjhdNfFJ\\fkgAbVyg\\Dao`<\ngGP@DjyjhdNfFJ\\fkgAbVyg\\Dao`>\ngGP@DjyjhdNfFJ\\fkgAbV~pRF~@<\ngGP@DjyjhdNfFJ\\fmgAcfyg\\DahP<\ngGP@DjyjhdNfFJ\\fmgAcfyg\\DahP>\ngGP@DjyjhdNfFJ]EkgAcfyg\\DahP<\ngGP@DjyjhdNfFJ]EkgAcfyg\\DahP>\ngGP@DjyjhdNfFJ]EkgAcf~pRFa@<\ngGP@DjyjhdNfFJ]EkgQSfyg\\DahP<\ngGP@DjyjhdNfFJ]EkgQSfyg\\DahP>\ngGP@DjyjhdNfFJ]EmgAcf~pRFa@>\ngGP@Dkij`NfFJ\\ek\\snBPtH\ngGP@Dkij`NfFJ\\ek_XICP`\ngGP@Dkij`NfFJ\\ek_XIC_@\ngGP@Dkij`NfFJ\\ekdabgMsNxICP`\ngGP@Dkij`NfFJ\\ekdabgM}`dMB\ngGP@Dkij`NfFJ\\ekgAbVyg\\Dao`\ngGP@Dkij`NfFJ\\ekgAbV~pRF~@\ngGP@Dkij`NfFJ\\ekgAbfyg\\DahP\ngGP@Dkij`NfFJ\\ekgAbf~pRFa@\ngGP@Dkij`NfFJ\\em_XICP`\ngGP@Dkij`NfFJ\\fmgAbfyg\\DahP\ngGP@Dkij`NfFJ\\fmgAbf~pRFa@\ngGP@DkijhdNfFJ\\ekdabdm}`dM|<\ngGP@DkijhdNfFJ\\ekgAbfyg\\Dao`>\ngGP@DkijhdNfFJ\\ekgAbf~pRF~@<\ngGP@DkijhdNfFJ\\ekgAbf~pRF~@>\ngGP@DkijhdNfFJ\\emgAbfyg\\DahP<\ngGP@DkijhdNfFJ\\emgAbfyg\\DahP>\ngGP@DkijhdNfFJ\\emgAbf~pRFa@<\ngGP@DkijhdNfFJ\\emgAbf~pRFa@>\ngGP@Lda`U@][IZwLvmdMB=\ngGP@Lda`U@][IZwLvmdMC~RqI@=\ngGP@Lda`U@][IZwLvmgu|=\ngGP@Lda`U@][IZwLvmgu}~RqI@=\ngGP@Lda`U@][IZwLvndMB\ngGP@Lda`U@][IZwLvndMC~RqI@\ngGP@Lda`U@][IZwLzndMB=\ngGP@Lda`U@][IZwLzndMC~RqI@=\ngGP@Lda`U@][IZyHTyK\\sjzPtH\ngGP@Lda`U@][IZyLTyK\\sZzPtH\ngGP@Lda`U@][IZyhXirVygUtahP=\ngGP@Lda`U@][IkWLvmdMB=\ngGP@Lda`U@][IkWLvndMB\ngGP@Lda`U@][IkWLzndMB=\ngGP@Lda`U@][IkYHTyK\\sjzPtH\ngGP@Lda`U@][IkYLTyK\\sZzPtH\ngGP@Lda`USH][IZwLvmdM|+\ngGP@Lda`USH][IZwLvmdM|-\ngGP@Lda`USH][IZwLvmdM}~RqI@+\ngGP@Lda`USH][IZwLvmdM}~RqI@-\ngGP@Lda`USH][IZwLvndM|<\ngGP@Lda`USH][IZwLvndM|>\ngGP@Lda`USH][IZyHTyK\\sjzPwp>\ngGP@Lda`USH][IZyLTyK\\sZzPwp>\ngGP@Lda`USH][IZyLTyK\\sZzPwwyKDd>\ngGP@Lda`USH][IZypTynYu]HZD<\ngGP@Lda`USH][IZypTynYu]HZD>\ngGP@Lda`USH][IZytTenYm]H[x<\ngGP@Lda`USH][IZytTenYm]H[x>\ngGP@Lda`USH][IZytTenYm]H[{|ebR<\ngGP@Lda`USH][IZytTenYm]H[{|ebR>\ngGP@Lda`USH][IZytTynYm]HZD<\ngGP@Lda`USH][IZytTynYm]HZD>\ngGP@Lda`USH][IZytTynYm]HZG|ebR<\ngGP@Lda`USH][IZytTynYm]HZG|ebR>\ngGP@Lda`USH][IZytTynYm]H[x<\ngGP@Lda`USH][IZytTynYm]H[x>\ngGP@Lda`USH][IZytTynYm]Okx<\ngGP@Lda`USH][IZytTynYm]Okx>\ngGP@Lda`USH][I[WLvmdMB+\ngGP@Lda`USH][I[WLvmdMB-\ngGP@Lda`USH][I[WLvndMB<\ngGP@Lda`USH][I[WLvndMB>\ngGP@Lda`USH][I[WLzndMB+\ngGP@Lda`USH][I[WLzndMB-\ngGP@Lda`USH][I[YHTyK\\sjzPtH<\ngGP@Lda`USH][I[YHTyK\\sjzPtH>\ngGP@Lda`USH][I[YLTyK\\sZzPtH<\ngGP@Lda`USH][I[YLTyK\\sZzPtH>\ngGP@Lda`USH][I[YpTenYu]HZD<\ngGP@Lda`USH][I[YpTenYu]HZD>\ngGP@Lda`USH][I[YpTynYu]HZD<\ngGP@Lda`USH][I[YpTynYu]HZD>\ngGP@Lda`USH][I[YtTenYm]HZD<\ngGP@Lda`USH][I[YtTenYm]HZD>\ngGP@Lda`USH][I[YtTynYm]HZD<\ngGP@Lda`USH][I[YtTynYm]HZD>\ngGP@Lda`USH][IjwLvmdM|+\ngGP@Lda`USH][IjwLvmdM|-\ngGP@Lda`USH][IjwLvndM|<\ngGP@Lda`USH][IjwLvndM|>\ngGP@Lda`USH][IjyHTyK\\sjzPwp<\ngGP@Lda`USH][IjyHTyK\\sjzPwp>\ngGP@Lda`USH][IjyLTyK\\sZzPwp<\ngGP@Lda`USH][IjyLTyK\\sZzPwp>\ngGP@Lda`USH][IjytTenYm]H[x<\ngGP@Lda`USH][IjytTenYm]H[x>\ngGP@Lda`USH][IjytTynYm]H[x<\ngGP@Lda`USH][IjytTynYm]H[x>\ngGP@Lda`USH][IkYpTynYu]HZD<\ngGP@Lda`USH][IkYpTynYu]HZD>\ngGP@Lda`USH][IkYtTynYm]HZD<\ngGP@Lda`USH][IkYtTynYm]HZD>\ngGPAEJU\\uPGSCENRusPqSdmsNxICP`\ngGPAEJU\\uPGSCENRusPqSdm}`dMB\ngGPAKrUM@@FyV}l}oP=\ngGPAMJUML@GVBgN\\EI[{AN{t\ngGPAMNRPpJ`Nmdm[f]WRFa@=\ngGPAMNRPpJ`Nmdukf[VrFa@=\ngGPAMNRPpJ`Nmdukf[WRFa@\ngGPAMNRPpJ`Nmdukf]WRFa@=\ngGPAMNRPpJ`NmdultLTyK\\sjzPtH=\ngGPAMNRPpJ`NmdulxJ\\wLzndMB>\ngGPAMNRPpJ`NmdulzJ\\wLvndMB>\ngGPAMvRPpJ`Nijyful}oP=\ngGPB@DZPLaYAJZjhCkAbf|PP\ngGPB@DZPLaYAJZjhCkAbj|PP\ngGPBABRDKaWAJnjhCkASf~pSz~@>\ngGPBADJHLQXaInjhCiQr\ngGPD@DDHRYjY@zTeWHwmg]v\ngGPD@DDHRYjY@zTeWHwmg]z\ngGPD@DDHRYjY@zTeWHwng]z\ngGPD@DDHRYjY@zTeYtTenQo]N{t\ngGPD@DDHRYjY@ztdunao[@\ngGPD@DDHRYjjTR`zLTykgAcfzpZD>\ngGPD@DFPRYfi@zLTykgQRVzp[t\ngGPD@DGpRYjY@ztduoao[oP\ngGPD@DHHRZzj@zL\\ek]DMB\ngGPD@DHHRZzj@zL\\ekgIrVyGexahP\ngGPD@DHHRZzj@zL\\ekgIrVzHZD\ngGPD@DHHR[f`@zd[h{np=\ngGPD@DHHR[ff@zL\\ek]GmB\ngGPD@DHHR[j`@zd[h{np=\ngGPD@DHHR[j`@zd[h{oP\ngGPD@DKpRYjZ@zLdfm\\c^vPtH\ngGPD@DSpRZVj@zlTyKV~pRFa@\ngGPD@DXHRfjj@zhXiKV~PRFa@\ngGPD@DXHRfjj@zhXiKWNCEM|`dMB\ngGPD@DXHRfjj@zhXjKV~PRFa@\ngGPD@DXHRfjjdPzhXiK[NCEM|`dMB<\ngGPD@DXHRfjjdPzhXiK[NCEM|`dMB>\ngGPD@DZ`R[ij@zLlfm\\cZvPtH\ngGPD@VIpRVjj@zlTyKV~pRFa@\ngGPD@bSpRZVj@zlTzMV~pRFa@\ngGPD@xIpR[j`@zd[d^Wcn{@=\ngGPD@xIpR[j`@zd[d^Wcn}@\ngGPD@xQpRjzj@zhTyKVyglDahP\ngGPD@xQpRkf`@zP\\wL{`gmz+\ngGPD@xQpRkf`@zP]WL{`g]v+\ngGPD@xQpRkf`@zP]WL{`gmz+\ngGPD@xUpRjZj@zhXirVyP\\Dao`\ngGPDADFHRYjY@zLTykgQRVzw[t\ngGPDADFHRYjjTRPzLTyk]XMB\ngGPDAHFPRYjjTRPzLTykgQRVzpZD\ngGPDAHFPRYjjTRPzLTykgQRVzp[x<\ngGPDAHFPRYjjTRPzLTykgQRVzp[x>\ngGPDAHJPRZzj@zL\\ek]DMB\ngGPDAHJPRZzj@zL\\ek]DM|\ngGPDAHJPRZzj@zL\\ek]GuB\ngGPDAbGDRYjjTRPzLTyk]XMB\ngGPDAbGDRYjjTRPzLTym]XMB>\ngGPDAbR`RYj`@zT]YtTeolD{oP>\ngGPDAxKpRYfj@zlTyKV~pRFa@\ngGPDAxSpRijj@zXXirVmr`xICP`\ngGPDAxSpRkj``PzP]WL}`g]v+\ngGPDAxSpRkj``PzP]WL}`g]v-\ngGPDAxSpRkj``PzP]WvB]wX+\ngGPDAxSpRkj``PzP]WvB]wX-\ngGPDAxSpRkjj`PzhTyKV~pRFa@<\ngGPDAxSpRkjj`PzhTyKV~pRFa@>\ngGPDaxF`Dgdjfj`NjFJ\\unTGAOjD\ngGPDaxF`Dgdjfj`NjFJ\\uodGAhP\ngGPDaxF`DgdjfjhDNjFJ]UodGAhP<\ngGPDaxF`DgdjfjhDNjFJ]UodGAhP>\ngGPEAxSpdiUuPPH]HNkf^pSn{@+\ngGPEAxSpdiUuPPH]HNkf^pSn{@-\ngGPFAVRDTIhPueaDfZj`NeEN]EIP>\ngGPH@DIJm]@]ZIZweB\ngGPH@DIKUU@]VJ\\ek\\cvBPtH\ngGPH@DIKUU@]VJ\\ek\\cvBPwp\ngGPH@DIKUU@]VJ\\ek_XICP`\ngGPH@DIKUU@]VJ\\ekgAbf~pRFa@\ngGPH@DILsP@]JNlzJRwvB]wh\ngGPH@DILuH@]JN[d^wSn{@=\ngGPH@DILuH@]JN[h{np=\ngGPH@DILuH@]JN[x^N{l=\ngGPH@DILuH@]JN[{]N{l=\ngGPH@DILuH@]RUrM{Yw]`=\ngGPH@DILuH@]RUrM{Yw^`\ngGPH@DILuH@]RUrM{Y{^`=\ngGPH@DILuH@]RUrM{iw]`=\ngGPH@DILuH@]RUrM{iw^`\ngGPH@DILuH@]RV]EI[d[wSn}@\ngGPH@DILuK@]FRRunQo[OZD\ngGPH@DILuK@]FRRunQo]OZD\ngGPH@DILuK@]FRRunQo]O[x\ngGPH@DILuK@]FRRuoao[hP\ngGPH@DILuK@]FRRvnQo[OZD\ngGPH@DILuK@]JRkd[vsn}@\ngGPH@DILuK@]JRkd[vsv}@\ngGPH@DILuPRH]JN[d^pSn{@+\ngGPH@DILuPRH]JN[d^pSn{@-\ngGPH@DILuPRH]JN[{AN{l+\ngGPH@DILuPRH]JN[{AN{l-\ngGPH@DILuPRH]JN[{AN{t>\ngGPH@DILuPRH]JNk{AN{l-\ngGPH@DIMMU@]VJ\\ekdqSdm}`dMB\ngGPH@DIMMU@]VJ\\ekgAbV~pRFa@\ngGPH@DIMMURH]VJ\\ekgQRV~pRFa@<\ngGPH@DIMMURH]VJ\\ekgQRV~pRFa@>\ngGPH@DIMtu@]FVRunQm[HZD\ngGPH@DIMtu@]FVRunQm]HZD\ngGPH@DISUU@]LLTyKVyP\\DahP\ngGPH@DISUU@]LLTyKWNCDmr`xIC_@\ngGPH@DISUU@]LLTyKWNCEMr`xICP`\ngGPH@DISUU@]LLTzMZyP\\DahP\ngGPH@DISUU@]LLUYKVyP\\DahP\ngGPH@DISUU@]LLUYKWNCEMr`xICP`\ngGPH@DISUU@]LLUYKZyP\\DahP\ngGPH@DISm]@]DJRundFa@\ngGPH@VILuH@]JN[h{np=\ngGPH@VILuH@]JN[x^N{l=\ngGPH@VILuH@]JN[{]N{l=\ngGPH@bILuH@]JN[h{np=\ngGPH@bILuH@]JN[{]N{l=\ngGPH@bILuH@]RUrM{Yw]`=\ngGPH@bILuH@]RUrM{iw]`=\ngGPH@bISUU@]LLUYKVyP\\DahP\ngGPH@xIKUU@]VJ\\ek\\cvBPtH\ngGPH@xILuH@]JN[d^wSn{@=\ngGPH@xILuH@]JN[x^N{l=\ngGPH@xIMMU@]VJ\\ek\\cvBPtH\ngGPH@xITuP@]XJ\\wJC`g]z\ngGPH@xITuP@]XJmWJC`g]v=\ngGPH@xITuP@]XJmWJC`g]z\ngGPH@xITuPPH]XJ]WJC`g]v+\ngGPH@xITuPPH]XJ]WJC`g]v-\ngGPH@xITuU@]LLTyKVyP\\DahP\ngGPH@xIUMT`]LLTyKVyP\\DaoP\ngGPH@xIUMT`]LLTyKV~P\\Da@\ngGPH@xIUMT`]LLTyMV~P\\Da@\ngGPH@xIUMT`]LLTzMV~P\\Da@\ngGPH@xIUMU@]LLTyKVyP\\DahP\ngGPH@xIUMU@]LLTyKVyP\\Dao`\ngGPH@xIUMU@]LLTyKVyP\\D~hP\ngGPH@xIUMU@]LLTyKWNCDmr`xICP`\ngGPH@xIUMU@]LLTyKZyP\\DahP\ngGPH@xIUMU@]LLTyMVyP\\DahP\ngGPH@xIUMU@]LLTzMVyP\\DahP\ngGPH@xIUMU@]LLTzMWNCDmr`xICP`\ngGPH@xIUMU@]LLTzMZyP\\DahP\ngGPHABILuH@]JN[h{np=\ngGPHABITuP@]XJmWJC`g]v=\ngGPHABITuP@]XJmWJC`g]z\ngGPHABITuP@]XJmWJC`gmz=\ngGPHABITuS@]LLTyKWNCGMr`xI{P`>\ngGPHADILuH@]JN[h{np=\ngGPHADILuH@]JN[{]N{l=\ngGPHADILuH@]JN\\zJRwvz]wh\ngGPHADILuPRH]JN[{AN{l+\ngGPHADILuPRH]JN[{AN{l-\ngGPHADILuUJIP]VJ\\ekgQRV~pRF~@<\ngGPHADIMMU@]VJ\\ek_XICP`\ngGPHADIMMU@]VJ\\ekdqSdm}`dMB\ngGPHADIMMURH]VJ\\ekgQRV~pRFa@<\ngGPHADIMMURH]VJ\\ekgQRV~pRFa@>\ngGPHADIMMURH]VJ\\ekgQrV~pSza@>\ngGPHAHILuH@]JN[{]N{l=\ngGPHAHILuK@]VJ\\ekgQRVzOZD\ngGPHAHILuK@]VJ\\ekgQRV~wSva@\ngGPHAHILuPRH]JN[{AN{l-\ngGPHAHIMMU@]VJ\\ekdqSdm}`dMB\ngGPHAHIMMURH]VJ\\ekgQRV~pRFa@<\ngGPHAHIMMURH]VJ\\ekgQRV~pRFa@>\ngGPHAVILuH@]JN[{]N{l=\ngGPHAVILuH@]JN\\zJRwvz]wh\ngGPHAVIMMU@]VJ\\ekdqSdm}`dMB\ngGPHAbIKUU@]VJ\\ek_XICP`\ngGPHAbILuH@]JN[{]N{l=\ngGPHAbILuPRH]JN[{AN{l+\ngGPHAbILuPRH]JN[{AN{l-\ngGPHAbILuPRH]JN\\zJ\\wvB^wh<\ngGPHAbILuUJIH]VJ]EmgQSf~pRFa@>\ngGPHAbIMMU@]VJ\\ekdqSdm}`dM|\ngGPHAxILsP@]JNk{AN{l=\ngGPHAxILuH@]JN[d^wSn{@=\ngGPHAxILuH@]JN[h{np=\ngGPHAxILuH@]JN[x^N{l=\ngGPHAxILuH@]JN[x^N{t\ngGPHAxILuH@]JN[{]N{l=\ngGPHAxILuPRH]JN[d^pSn{@+\ngGPHAxILuPRH]JN[d^pSn{@-\ngGPHAxILuUJIH]VJ\\ekgQSfyGlDahP<\ngGPHAxIMMU@]VJ\\ekdqSdmrOXICP`\ngGPHAxIMMU@]VJ\\ekdqSdm}`dMB\ngGPHAxITuP@]XJ\\wJC`g]v=\ngGPHAxITuP@]XJ\\wJC`g]z\ngGPHAxITuP@]XJ\\wJC`gmz=\ngGPHAxITuP@]XJmWJC`g]v=\ngGPHAxITuP@]XJmWJC`g]z\ngGPHAxITuP@]XJmWJC`gmz=\ngGPHAxITuP@]XJmYHXiK\\hNB]wh\ngGPHAxITuP@]XJmYhXirVyP\\D}oP=\ngGPHAxITuPPH]XJ]WJC`g]v+\ngGPHAxITuPPH]XJ]WJC`g]v-\ngGPHAxITuPPH]XJ]WJC`g]z<\ngGPHAxITuPPH]XJ]WJC`g]z>\ngGPHAxITuPPH]XJ]WJC`gmz+\ngGPHAxITuPPH]XJ]WJC`gmz-\ngGPHAxITuPPH]XJlwJCoG]v+\ngGPHAxITuPPH]XJlwJCoG]v-\ngGPHAxITuS@]LLUZKVyP\\D}hP\ngGPHAxITuU@]LLTyKVyP\\DahP\ngGPHAxITuU@]LLUZKVyP\\DahP\ngGPHAxITuUPH]LLTzKVyP\\DahP<\ngGPHAxITuUPH]LLTzKVyP\\DahP>\ngGPHKPITuURH]TLTyM\\hNBPwp<\ngGPHKPYIC@jfPzVRwtvmdH+\ngGPHKPYIC@jfPzVRwtvmdH-\ngGPHKPYIC@jfPzVRytTenYm]H[x>\ngGPHMPITtp@]HJ[e]wcn{@=\ngGPHMPITtp@]HJ[e]wcv}@=\ngGPHMPITtp@]HJ[h{np=\ngGPHMPITtp@]HJ[y]N{l=\ngGPHMPITtp@]HJ[y]O[t=\ngGPHMPYIC@j@zvRunYu]HZD=\ngGPHMPYIC@j@zvRvnYu]HZD+\ngGPHMPYIC@j@zvRvshis\\sZzPtH>\ngGPHMPYIC@j@zvSVnYm[HZD=\ngGPHMPYIC@j@zvSVnYm]HZD\ngGPHMPYIC@j@zvSVnYu]HZD=\ngGPHMPYIC@j@zvSVsPqSdmsNkiCP`=\ngGPHMPYIC@j@zvSVshis\\sZzPtH>\ngGPHMPYICFj@zXXjrVv\\EN[f]PRFa@>\ngGPHMPYICFj@zXXjrZusNhICP`\ngGPHMPYICJj@zXXirVnRFJ\\wLB`dMB>\ngGPHaxCeJSLuPGUbgI[YtTynQwAHZD>\ngGPI@DBTjZh@NlEVkeApSn{@=\ngGPI@DBTjZhHDNlENkeApSn}@<\ngGPI@DBTjZhHDNlENlxJRwJC`g]z<\ngGPI@DBTjZhHDNlENlxJRwJC`g]z>\ngGPI@DZTfzZ`NcKIkWHvmdMB\ngGPI@VBTjZh@NlEVkeApSn{@=\ngGPIAxBTfZd@NeGMrO[iw]`=\ngGPIAxBTfZhIDNeGMrOXIw]`+\ngGPIAxBTfZhIDNeGMrOXIw]`-\ngGPIAxBTffj`NkENRurXirVyGlDahP\ngGPIAxBTffj`NkENRurXirV~pRFa@\ngGPIAxBTijj`NfFJ\\ek\\kvBPtH\ngGPIAxBTjZh@NlEN[eApSn}@\ngGPIAxBTjZh@NlEVkeApSn{@=\ngGPIAxBTjZh@NlEVkeApSn}@\ngGPIAxBTjZh@NlEVkeApSv}@=\ngGPIAxBTjZhHDNlENkeApSv}@+\ngGPIAxBTjZhHDNlENkeApSv}@-\ngGPIAxBTjZj`NfFJ\\ek\\hNBPtH\ngGPIAxBTjZjhDNfFJ]Ek\\hNBPtH<\ngGPIAxBTjZjhDNfFJ]Ek\\hNBPtH>\ngGPIAxBTjfjPNfFJmFk\\hNBPwh\ngGPIAxBTjfj`NfFJ\\ek\\hNBPtH\ngGPIAxBTjfj`NfFJ\\em\\hNBPtH\ngGPIAxBTjfj`NfFJ\\fk\\hNBPtH\ngGPIAxBTjfj`NfFJ]Fk\\hNBPtH\ngGPIAxBTjfj`NfFJ]FkgAbVyP\\DahP\ngGPIAxBTjfj`NfFJmFk\\hNBPtH\ngGPIAxBTjfj`NfFJmFm\\hNBPtH\ngGPIEPKdkij`NfFJ]Fm\\snBPtH\ngGPIEPKdkjj`NfFJ\\em\\pNBPtH\ngGPIEPKdkjj`NfFJ\\fm\\pNBPtH\ngGPIEPKdkjj`NfFJ\\fmgAbfy`\\DahP\ngGPIEPKdkjj`NfFJ]Fm\\pNBPtH\ngGPIMP[djZX@NdEMrn{qw]`=\ngGPIMP[djZX@NdEMrn{q{^`=\ngGPIMP[lda`U@][I[WLzndMB+\ngGPIMP[lda`U@][IkWLvndMB\ngGPIMP[lda`U@][IkWLzndMB=\ngGPIMP[ldaeU@]LLTyK[ICEN[fAPRFa@>\ngGPIMP[ldaeU@]LLTyMZy`TDahP\ngGPJ@DQpSa``aBTuUPGVCFvRFJ\\wR}P`\ngGPJ@xQpSagBnFRRVj`NdDmsOKv}_@\ngGPL@DXHHPeMUTAtPqSWICEN[i^hP\ngGPL@xIpsadTajhCkQKWNSdm|OKuB\ngGPL@xQpSaddLZ@CjAnYu^O[t+\ngGPL@xQpSaddajhCharVmsOKqCP`\ngGPL@xQpSaddajhCharVmsOKqC__d`XP\ngGPLADHHhPdtuTAtXirVzwc{|dcb\ngGPLAHJPtadTajdCkQKT\ngGPLAHJPtadTajdCkQKV|oP\ngGPLAHJPtadTajhCkQKV|hP\ngGPLAHJPtadTajhCkQKV|o`\ngGPLAHJPtadTajhCkQKZ|hP\ngGPP@cTfyi`NeGH\ngGPPAcTijj`NlFJ\\xLTwbB\ngGPP`cUuyInZXCiQr\ngGPQ@c[rS\\tpGRcd\ngGPT@cYPZ`R[jj@zT\\`\ngGPTHlPxUpRjZj@zPXwe|\ngGPTHlPxUpRjZj@zPXypXeoKx\ngGPTHlQxUpRjvj@zPTwe|\ngGPTHlQxWpRjvj@zPTwe|\ngGPTIcQxIpRVjj@zTTw`|\ngGPUHlQxWpOIU[UPH]HJ[r~@<\ngGPUHlQxWpOIU[UPH]HJ[r~@>\ngGPXHlPDYIHUj@zp\\uoJD\ngGPXHlPDYIHUj@zp\\usdyK^TH\ngGPXHlPxIUMU@]XLZweB\ngGPXHlPxIUMU@]XL[WeB\ngGPXHlQxIU[U@]XJZweB\ngGPXHlQxIU[U@]XJZyLTyK^TH\ngGPXHlQxIU[U@]XJ[WeB\ngGPXHlQxIU[UPH]XJZytTeoJD<\ngGPXHlQxIU[UPH]XJZytTeoJD>\ngGPXHlQxIU[UPH]XJ[YtTeoJD<\ngGPXHlQxIU[UPH]XJ[YtTeoJD>\ngGPXIcPVIKUU@]JJP\ngGPXhlQx[crUVuPGVBfmyP`\ngGPYAcUPKdkjj`NlFJ[rA@\ngGPYAcUPKdkjj`NlFJ\\xLTwdB\ngGPYAcUPKdkjj`NlFR\\xLTwdB\ngGPYHlPDGlddJu@]XNZweB\ngGPYHlQxGdjmjhDNlEM[ra@<\ngGPYHlQxGdjmjhDNlEM[ra@>\ngGPYHlQxGdjmjhDNlEM\\zJRweB<\ngGPYHlQxGdjmjhDNlEM\\zJRweB>\ngGPYHlQxGdjmjhDNlEMkra@<\ngGPYHlQxGdjmjhDNlEMkra@>\ngGPYHlQxGdjmjhDNlEMlzJRweB<\ngGPYHlQxGdjmjhDNlEMlzJRweB>\ngGP`@TfYi`NcENZytTenlFa@\ngGP`@TfYi`NcEN[YtTenlFa@\ngGP`@TfYi`NcENkWVCP`\ngGP`@TfYi`NcENkYtTenlFa@\ngGP`@TfYjPNcENZytTenlF}@\ngGP`@TfYjPNcENZytTenmz}@\ngGP`@TfYjPNcENZytTeoLD\ngGP`@TfYjPNcENjytTenlF}@\ngGP`@TfYjPNcENjytTeoLD\ngGP`@TfYjPNmEV[{AN{l\ngGP`@TfYjPNmEV[{AN{t\ngGP`@TfYjPNmEVk{AN{l\ngGP`@TfYjPNmEVk{AN{t\ngGP`@TfYjPNmEVlzJRwvB]wh\ngGP`@TfYjhhNcENZwVCP`<\ngGP`@TfYjhhNcENZwVCP`>\ngGP`@TfYjhhNcENZwV}P`<\ngGP`@TfYjhhNcENZyLTyK]XMB<\ngGP`@TfYjhhNcENZyLTyK]XMB>\ngGP`@TfYjhhNcENZytTenlFa@<\ngGP`@TfYjhhNcENZytTenlFa@>\ngGP`@TfYjhhNcENZytTenlF~@<\ngGP`@TfYjhhNcENZytTenlF~@>\ngGP`@TfYjhhNcENZytTenmza@<\ngGP`@TfYjhhNcENjwVCP`<\ngGP`@TfYjhhNcENjwVCP`>\ngGP`@TfZfPNeIUrM{Yw]`\ngGP`@TfZfPNeIV]EI[d[wSn}@\ngGP`@TfZjeDdNcENZwVCP`\ngGP`@TfZjeDdNcENZwVC_@<\ngGP`@TfZjeDdNcENZyHXiK]XMB<\ngGP`@TfZjeDdNcENZyHXiK]XMB>\ngGP`@TfZjeDdNcENZyHXiK]XM|<\ngGP`@TfZjeDdNcENZyhXirVzpZD\ngGP`@TfZjeDdNcENZypXenlFa@<\ngGP`@TfZjeDdNcENZypXenlFa@>\ngGP`@TfZjeDdNcENZypXenlF~@>\ngGP`@TfZjeDdNcENZytTenlFa@\ngGP`@TfZjeDdNcENZytTenlF~@<\ngGP`@TfZjeDdNcENZytTenlF~@>\ngGP`@TfZjeDdNcEN[WVCP`<\ngGP`@TfZjeDdNcEN[WVCP`>\ngGP`@TfZjeDdNcEN[YtTynlFa@<\ngGP`@TfZjeDdNcEN[YtTynlFa@>\ngGP`@TfZjeDdNcENkWVCP`\ngGP`@TfZjeDhNcENZwVCP`<\ngGP`@TfZjeDhNcENZwVCP`>\ngGP`@TfZjeDhNcENZwVC_@<\ngGP`@TfZjeDhNcENZwVC_@>\ngGP`@TfZjeDhNcENZyHXiK]XMB<\ngGP`@TfZjeDhNcENZyHXiK]XMB>\ngGP`@TfZjeDhNcENZyhXirVzpZD<\ngGP`@TfZjeDhNcENZyhXirVzpZD>\ngGP`@TfZjeDhNcENZypXenlFa@<\ngGP`@TfZjeDhNcENZypXenlFa@>\ngGP`@TfZjeDhNcENZypXynlFa@>\ngGP`@TfZjeDhNcENZytTenlFa@<\ngGP`@TfZjeDhNcENZytTenlFa@>\ngGP`@TfZjeDhNcENZytTenlF~@<\ngGP`@TfZjeDhNcENZytTenlF~@>\ngGP`@TfZjeDhNcENZytTenmz~@<\ngGP`@TfZjeDhNcEN[WVCP`<\ngGP`@TfZjeDhNcEN[WVCP`>\ngGP`@TfZjeDhNcEN[YpXenlFa@<\ngGP`@TfZjeDhNcENkWVCP`<\ngGP`@TfZjeDhNcENkWVCP`>\ngGP`@TfzZihNcENZweB>\ngGP`@TfzZihNcENZytTeneva@>\ngGP`@TfzZihNmKM[x[VzD<\ngGP`@TfzZihNmKM[x[VzD>\ngGP`@dfnjPNcGIZyr\\enbF}@\ngGP`@dfnjPNcGIZyr\\eoBD\ngGP`@dfnj`NcGIZwQCP`\ngGP`@dfnj`NcGIZyHXiK]DMB\ngGP`@dfnj`NcGIZyHXiK]DM|\ngGP`@dfnj`NcGIZyr\\enbFa@\ngGP`@dfnj`NcGIZyr\\enbF~@\ngGP`@dfnj`NcGIZyr\\encza@\ngGP`@dfnj`NcGI[WQCP`\ngGP`@dfnj`NcGIjyHXiK]DMB\ngGP`@dfnjiDNcGIZyHTyK]DMB<\ngGP`@dfnjiDNcGIZyHTyK]DMB>\ngGP`@dfnjiDNcGIZypTenbFa@<\ngGP`@dfnjiDNcGIZypTenbFa@>\ngGP`@dfnjiDNcGIZypTenbF~@<\ngGP`@dfnjiDNcGIZypTencza@<\ngGP`@dfnjiDNcGIZypTencza@>\ngGP`@dfyh@NiFzN{l=\ngGP`@dfyh@NiFzN{t\ngGP`@dfyh@NiFzO[t=\ngGP`@dfyh@NiGNbdmt]wh\ngGP`@dfyh@NiGNbgMt^wh\ngGP`@dfyi`NcGIZwQ{P`\ngGP`@dfyi`NcGIZwQ{P\x7FdlRP\ngGP`@dfyi`NcGIZwQ{_@\ngGP`@dfyi`NcGIZweB\ngGP`@dfyi`NcGIZwe|\ngGP`@dfyi`NcGIZytTencva@\ngGP`@dfyi`NcGIZytTeoJD\ngGP`@dfyi`NcGIZytTyncva@\ngGP`@dfyi`NcGIZytTyncv~@\ngGP`@dfyi`NcGIZytTyoJD\ngGP`@dfyi`NcGI[WQ{P`\ngGP`@dfyi`NcGI[WeB\ngGP`@dfyi`NcGI[YtTyncva@\ngGP`@dfyi`NcGI[YtTyoJD\ngGP`@dfyi`NeGUt]wX\ngGP`@dfyi`NeGUt]wh\ngGP`@dfyi`NeGUt^wX\ngGP`@dfyi`NeGUt^wh\ngGP`@dfyi`NeGV]EN[h}oP\ngGP`@dfyj`NcGIZwQCP`\ngGP`@dfyj`NcGIZwQCP\x7FdlRP\ngGP`@dfyj`NcGIZwQ}_@\ngGP`@dfyj`NcGIkWQCP`\ngGP`@dfyjidNcGIZwQC_@<\ngGP`@dfyjidNcGIZwQC_@>\ngGP`@dfyjidNcGIZyLTyK]DM|>\ngGP`@dfyjidNcGIZytTenbF~@<\ngGP`@dfyjidNcGIZytTenbF~@>\ngGP`@dfyjidNcGIZytTynbFa@<\ngGP`@dfyjidNcGIZytTynbFa@>\ngGP`@dfyjidNcGIZytTynbF~@<\ngGP`@dfyjidNcGIZytTynbF~@>\ngGP`@dfyjidNcGI[WQCP`<\ngGP`@dfyjidNcGI[WQCP`>\ngGP`@dfyjidNcGI[YtTynbFa@>\ngGP`@dfyjidNcGIjwQC_@<\ngGP`@dfyjidNcGIjwQC_@>\ngGP`@dfzh@NiFzN{l=\ngGP`@dfzh@NiFzN{t\ngGP`@dfzh@NiGICEI[h{oP\ngGP`@dfzhIDNiGNBdmt]wh<\ngGP`@dfzhIDNiGNBdmt]wh>\ngGP`@dfzj`NcGIZwQCP`\ngGP`@dfzj`NcGIZyhXirVzHZD\ngGP`@dfzjeEdNcGIZypTynbFa@<\ngGP`@dfzjeEdNcGIZypTynbFa@>\ngGP`@dfzjeEhNcGIZypTynbFa@>\ngGP`ADkjj`NjENRuolDahP\ngGP`ADkjj`NjENRurPqSf~pRFa@\ngGP`ADkjj`NjENRus`qK_XIC_@\ngGP`ADkjj`NjENRus`qS_XICP`\ngGP`ADkjj`NjENRvolDahP\ngGP`ADkjj`NjENcVolDahP\ngGP`ADkjj`NjENcVrPqSf~pRFa@\ngGP`ATeVn`NeDh\ngGP`ATffj`NcENRwVBP`\ngGP`ATffjiDNcENRwVB_@<\ngGP`ATffjiDNcENRwVB_@>\ngGP`ATffjiDNcENRytTenlDa@<\ngGP`ATffjiDNcENRytTenlDa@>\ngGP`ATffjiDNcENSWVBP`>\ngGP`Adeij`NcEIZwQCP`\ngGP`Adijj`NjFJRuodDahP\ngGP`Adijj`NjFJRuodD~o`\ngGP`Adijj`NjFJRurPqrV~WbFa@\ngGP`Adijj`NjFJRus`qS_HICP`\ngGP`Adijj`NjFJRus`qS_KqCP`\ngGP`Adijj`NjFJSVs`qS_HICP`\ngGP`Adijj`NjFJbus`qS_HICP`\ngGP`AdijjiDNjFJRuodDao`<\ngGP`AdijjiDNjFJRuodDao`>\ngGP`AdijjiDNjFJRurPqSf~PRFa@>\ngGP`AdijjiDNjFJRurPqSf~WbFa@<\ngGP`AdijjiDNjFJRurPqSf~WbFa@>\ngGP`AdijjiDNjFJRurPqrV~PRF~@>\ngGP`AdijjiDNjFJRus`qK_HIC_@<\ngGP`AdijjiDNjFJRus`qK_HIC_@>\ngGP`AdijjiDNjFJRus`qK_KqC_@>\ngGP`AdijjiDNjFJRus`qS_HIC_@<\ngGP`AdijjiDNjFJRus`qs_HICP`<\ngGP`AdijjiDNjFJRus`qs_HICP`>\ngGP`AdijjiDNjFJRus`qs_HIC_@<\ngGP`AdijjiDNjFJRus`qs_HIC_@>\ngGP`AdijjiDNjFJRus`qs_KqCP`<\ngGP`AdijjiDNjFJRus`qs_KqCP`>\ngGP`AdijjiDNjFJRvodDahP<\ngGP`AdijjiDNjFJRvodDahP>\ngGP`AdijjiDNjFJRvs`qS_HICP`<\ngGP`AdijjiDNjFJRvs`qS_HICP`>\ngGP`AdijjiDNjFJRvs`qs_HICP`<\ngGP`AdijjiDNjFJRvs`qs_HICP`>\ngGP`AdijjiDNjFJSUs`qK_HIC_@<\ngGP`AdijjiDNjFJSUs`qK_HIC_@>\ngGP`AdijjiDNjFJbus`qK_HIC_@<\ngGP`AdijjiDNjFJbus`qs_HICP`<\ngGP`AdijjiDNjFJbus`qs_HICP`>\ngGP`AdijjiDNjFJbvs`qs_HICP`<\ngGP`AdijjiDNjFJbvs`qs_HICP`>\ngGPa@SrSLuHGQbgM\\zJRwVC^`\ngGPa@SrSMSHGQbgM\\zJRwV{^`\ngGPa@erS\\t@GTc]G]v=\ngGPa@erS\\t@GTc]G]z\ngGPa@erS\\t@GTc]Gmz=\ngGPa@erS\\tpGQcdm[ra@\ngGPa@erS\\uPGQcdm[hahP\ngGPa@erS\\uPGQcdm[hah_rVIH\ngGPa@erS\\uTrGQcdmkhahP<\ngGPa@iJS]T@GTc]G]v=\ngGPa@krS\\t@GTc]Gmz\ngGPa@mrS\\uPGRcjzO[t\ngGPdCPVZ`R[ij@ztTyoEt\ngGPdE`DRPrRRrtAu`ek^TH\ngGPdH`DTHrRPkTAu`yK]DM|\ngGPdH`DWprRPkTAu`yK]DM|\ngGPdH`VTlRjZj@zHXzM_XIC_@\ngGPdH`VUpRjZj@zHXzM_XIC_@\ngGPdH`xUpRjZj@zHXyK_XIC_@\ngGPdH`xUpRjZj@zHXyKgAbV~pRF~@\ngGPdH`xUpRjZj@zHXzM_XIC_@\ngGPdH`xUpRjZj@zHXzMgAbV~pRF~@\ngGPdH`xUpRjZj`PzHXyM_XIC_@<\ngGPdH`xUpRjZj`PzHXyM_XIC_@>\ngGPdH`xV`RjZj@zHXzM]XIB\ngGPdI`VIpRVjj@zLTfm_CqCP`\ngGPeE`DSpGIM\\uRH]FNSUnbFa@>\ngGPeH`VUDliUMU@]DL]FnlDa@\ngGPh@iPIMuP@]RMt]wX=\ngGPh@iPIMuP@]RMt]wh\ngGPh@iPIMuP@]RMt^wh=\ngGPh@iPIMuP@]RN\\EI[h{oP>\ngGPh@iPIMuS@]FNRuncva@\ngGPh@iPIMuS@]FNRuoJD\ngGPh@iPIMuS@]FNRvncva@\ngGPh@iPIMuS@]FNRvoJD\ngGPh@iPIMuS@]JNkh{oP\ngGPh@iPIMuU@]FNRunbFa@\ngGPh@iPIMuUSH]FNRvnbFa@>\ngGPhCPDILuK@]JR[h[vp\ngGPhCPDILuK@]JR[h[wP\ngGPhCPDILuK@]ZJ\\`\ngGPhCPDILuK@]ZJ\\wfz\ngGPhCPDILuSRH]ZJ\\wP}``>\ngGPhCPDILuSRH]ZJ\\wfB<\ngGPhCPDILuSRH]ZJ\\wfB>\ngGPhCQBILuK@]ZJ\\wfz\ngGPhCQDILuSRH]ZJ\\wfB>\ngGPhCQbILuSRH]ZJ\\wfB>\ngGPhCQxILsS@]ZJ\\wfB\ngGPhCQxILuK@]ZJ\\wP}n`\ngGPhCQxILuK@]ZJ\\wfz\ngGPhDPDIMuUJKH]ZNZytTeoJD<\ngGPhDPDIMuUJKH]ZNZytTeoJD>\ngGPhH`DYIHUi@zH\\ek^DH\ngGPhH`DYIHUi@zH\\ekgIrVzH[t\ngGPhH`DYIHUi@zH\\fk]DMz\ngGPhH`DYIHUi@zH\\fk^DH\ngGPhH`DYIHUj@zH\\ek]DMB\ngGPhH`DYIHUj@zH\\ekgIrVzHZD\ngGPhH`DYIHUj@zH\\em]DMB\ngGPhH`DYIHUj@zH\\fk]DMB\ngGPhH`DYIHUj@zH\\fk]DM|\ngGPhH`DYIHUj@zH\\fm]DMB\ngGPhH`xIUMU@]TL\\ek_XICP`\ngGPhH`xIUMU@]TL\\ek_[q}P`\ngGPhH`xIUMU@]TL\\ekgAbV~pRF~@\ngGPhH`xIUMU@]TL\\ekgAbV~wcza@\ngGPhH`xIUMU@]TL\\em_XICP`\ngGPhH`xIUMU@]TL]Fm_XICP`\ngGPhH`xYIHZj@zH\\ek]DMB\ngGPhHaVYICE`@z`[h{oP\ngGPhHaVYICJ`@z`[h{np=\ngGPhHaxIU[U@]TJ\\ek_XICP`\ngGPhHaxIU[U@]TJ]Fm_XICP`\ngGPhHaxIU[UPH]TJ\\fk_XICP`<\ngGPhHaxYICJ`@z`[h{oP\ngGPhI`xIKUU@]FJRuoaxahP\ngGPhaePRUrUuUPGUCEIkWtBPtH\ngGPhaePRUrUuUPGUCEIkYpXiohDahP\ngGPiAePKdkjj`NjFJSVs`qS_PICP`\ngGPiCPDWdfZe`NeIMtM{X\ngGPllQHR`TaNliM]U@]ZNZyr\\eoJD\ngGPmLQHR`TaNRZzj@zt\\usdyK^TH\ngGQ@@dmMTAuXirVm}`dMB\ngGQ@@dmMTAuXirVm}`dM|\ngGQ@@dmMTAuXirVu}`dMB\ngGQ@@dmMTAuXirZu}`dMB\ngGQ@@dmUTAuXirVm}`dMB\ngGQ@@dmUTAuXirVm}`dM|\ngGQ@@dmUTAuXirVnRFJ\\wvBPtH\ngGQ@@dmUTAuXirVn\\FJ[{AHZD\ngGQ@@dmUTAuXirVu}`dMB\ngGQ@@dsM@AthyolD{np=\ngGQ@@dsM@AthyolD{oP\ngGQ@@dsM@AthyolD}oP=\ngGQ@@dsM@Athyomx{np=\ngGQ@@dsM@Athyomx{oP\ngGQ@@dsM@AthyshiK_XIw^`\ngGQ@@dsM@AthyshiK_[qw^`\ngGQ@@dsM@Athyshis_XI{^`\ngGQ@@dsM@Athyshis_[q{^`\ngGQ@@dsM@AthzolD{np=\ngGQ@@dsM@AthzolD{oP\ngGQ@@dsM@AthzolD}oP=\ngGQ@@dsM@AthzshiK_XIw^`\ngGQ@@dsM@Athzshis_XI{^`\ngGQ@@dsMLAuXirVmu`tH\ngGQ@@dsMLAuXirVmu`wp\ngGQ@@dsMLAuXirVmuoTH\ngGQ@@dsMLAuXirVm}`gmB\ngGQ@@dsMLAuXirVm}`gm|\ngGQ@@dsMLAuXirVn]EI[kAhP\ngGQ@@dsMLAuXirVn]EI[kAo`\ngGQ@@dsMLAuXirVn]EI[k^hP\ngGQ@@dsMLAuXirVn]EI[{AOZD\ngGQ@@dsMLAuXirVn]EI[{AO[x\ngGQ@@dsMLAuXirVn]EI[{^OZD\ngGQ@@dsMLAuXirVn]EN[kAhP\ngGQ@@dsMLAuXirVn]EN[kAo`\ngGQ@@dsMLAuXirVn]EN[k^hP\ngGQ@@dsMLAuXirVn]EN[{AOZD\ngGQ@@dsMLAuXirVn]EN[{AO[x\ngGQ@@dsMLAuXirVn]EN[{^OZD\ngGQ@@dsMLAuXirVu}`gmB\ngGQ@@dsMLAuXirVv]EI[{AOZD\ngGQ@@dsMLAuXirVv]EN[kAhP\ngGQ@@dsMLAuXirVv]EN[{AOZD\ngGQ@@dsMLAuXitVmu`tH\ngGQ@@dsMLAuXitVmu`wp\ngGQ@@dsMLAuXitVm}`gmB\ngGQ@@dsMLAuXitVm}`gm|\ngGQ@@dsMLAuXitVn]EI[kAhP\ngGQ@@dsMLAuXitVn]EI[kAo`\ngGQ@@dsMLAuXitVn]EI[{AOZD\ngGQ@@dsMLAuXitVn]EI[{AO[x\ngGQ@@dsMLAuXitVn]EN[kAhP\ngGQ@@dsMLAuXitVn]EN[kAo`\ngGQ@@dsMLAuXitVn]EN[{AOZD\ngGQ@@dsMLAuXitVn]EN[{AO[x\ngGQ@@dsMLAuXitVuu`tH\ngGQ@@dsMLAuXitVu}`gmB\ngGQ@@dsMLAuXitVv]EN[kAhP\ngGQ@@dsMLAuXitVv]EN[{AOZD\ngGQ@@dsMLAuhjs_XIw]`\ngGQ@@dsMLAuhjs_XIw^`\ngGQ@@dsMLAuhjs_XI{]`\ngGQ@@dsMLAuhjs_XI{^`\ngGQ@@dsMLAuhjs_[qw^`\ngGQ@@dsMLAuhjsgQSf~pSv{@\ngGQ@@dsMLAuhjsgQSf~pSv}@\ngGQ@@dsMLAuhju_XIw^`\ngGQ@@dsMLAuhju_XI{]`\ngGQ@@dsMLAuhju_XI{^`\ngGQ@@dsMLAuhjugQSf~pSv{@\ngGQ@@dsMLAuhjugQSf~pSv}@\ngGQ@@dsMTAuXirVm}`dMB\ngGQ@@dsMTAuXirVm}`dMC~RqI@\ngGQ@@dsMTAuXirVm}oDMB\ngGQ@@dsMTAuXirVnSENRwvBPtH\ngGQ@@dsMTAuXirVnSENRwv|PtH\ngGQ@@dsMTAuXirZvSENRwvBPtH\ngGQ@@dsMTAuXitVm}`dMB\ngGQ@@dsMTAuXitVm}`dMC~RqI@\ngGQ@@dsMTAuXitVm}`gu|\ngGQ@@dsMTAuXitZu}`dMB\ngGQ@@dsMUDauXirVm}`dM|<\ngGQ@@dsMUDauXirVm}`dM|>\ngGQ@@dsMUDauXirVnSENRwvBPwp<\ngGQ@@dsMUDauXirVnSENRwvBPwp>\ngGQ@@dsMUDauXirVnSENRwv|Pwp>\ngGQ@@dsMUDauXirVn]EI[{AH[x<\ngGQ@@dsMUDauXirVn]EI[{AH[x>\ngGQ@@dsMUDauXirVn]EI[{AH[{|ebR>\ngGQ@@dsMUDauXirVn]EN[{AHZD<\ngGQ@@dsMUDauXirVn]EN[{AHZD>\ngGQ@@dsMUDauXirVn]EN[{AHZG|ebR<\ngGQ@@dsMUDauXirVn]EN[{AHZG|ebR>\ngGQ@@dsMUDauXirVn]EN[{AH[x<\ngGQ@@dsMUDauXirVn]EN[{AH[x>\ngGQ@@dsMUDauXirVn]EN[{AOkx<\ngGQ@@dsMUDauXirVn]EN[{AOkx>\ngGQ@@dsMUDauXirVn]EN[{^HZD<\ngGQ@@dsMUDauXirVn]EN[{^HZD>\ngGQ@@dsMUDauXirVv]EN[{AHZD<\ngGQ@@dsMUDauXirVv]EN[{AHZD>\ngGQ@@dsMUDauXitVm}`dM|<\ngGQ@@dsMUDauXitVm}`dM|>\ngGQ@@dsMUDauXitVn]EI[{AH[x<\ngGQ@@dsMUDauXitVn]EN[{AHZD<\ngGQ@@dsMUDauXitVn]EN[{AHZD>\ngGQ@@dsMUDauXitVu}`dMB<\ngGQ@@dsMUDauXitVu}`dMB>\ngGQ@@dsT`Athyncn{@=\ngGQ@@dsT`Athyncn}@\ngGQ@@dsT`Athyncv}@=\ngGQ@@dsT`Athyomt{np=\ngGQ@@dsT`Athyomt{oP\ngGQ@@dsT`Athys`qK]G]z\ngGQ@@dsT`Athys`qK_[iw^`\ngGQ@@dsT`AthyshiK]G]z\ngGQ@@dsT`AthyshiK_[iw^`\ngGQ@@dsT`Athyshis_[i{^`\ngGQ@@dsT`AuIWHwmg]v=\ngGQ@@dsT`AuIWHwmg]z\ngGQ@@dsT`AuIWHwmgmz=\ngGQ@@dsT`AuIWHwng]v=\ngGQ@@dsT`AuIWHwng]z\ngGQ@@dsT`AuIYtTenQo]N{t\ngGQ@@dsTlAtYIKV~F}na@\ngGQ@@dsTlAtYIKZyF}l}hP\ngGQ@@dsTlAuXirVnZFJ\\encva@\ngGQ@@dsTlAuXirVn]EN[{]OZD\ngGQ@@dsUAHathyolD{np+\ngGQ@@dsUAHathyolD{np-\ngGQ@@dsUAHathyolD{oP<\ngGQ@@dsUAHathyolD{oP>\ngGQ@@dsUAHathyolD}oP+\ngGQ@@dsUAHathyolD}oP-\ngGQ@@dsUAHathyomx{np+\ngGQ@@dsUAHathyomx{np-\ngGQ@@dsUAHathyomx{oP<\ngGQ@@dsUAHathyomx{oP>\ngGQ@@dsUAHathyrPqRV~pSn}@<\ngGQ@@dsUAHathyrPqRV~pSn}@>\ngGQ@@dsUAHathys`qK_XIw^`<\ngGQ@@dsUAHathys`qK_XIw^`>\ngGQ@@dsUAHathyshiK_XIw^`<\ngGQ@@dsUAHathyshiK_XIw^`>\ngGQ@@dsUAHathyshiK_[qw^`<\ngGQ@@dsUAHathyshiK_[qw^`>\ngGQ@@dsUAHathyshis_XI{^`<\ngGQ@@dsUAHathyshis_XI{^`>\ngGQ@@dsUAHathyshis_[q{^`<\ngGQ@@dsUAHathyshis_[q{^`>\ngGQ@@dsUAHathzolD{np+\ngGQ@@dsUAHathzolD{np-\ngGQ@@dsUAHathzolD{oP<\ngGQ@@dsUAHathzolD{oP>\ngGQ@@dsUAHathzolD}oP-\ngGQ@@dsUAHathzs`qK_XIw^`<\ngGQ@@dsUAHathzs`qK_XIw^`>\ngGQ@@dsUMHauXirVmu`tH<\ngGQ@@dsUMHauXirVmu`tH>\ngGQ@@dsUMHauXirVm}`gmB<\ngGQ@@dsUMHauXirVm}`gmB>\ngGQ@@dsUMHauXirVm}`gm|>\ngGQ@@dsUMHauXirVnRFJ\\wVCP`<\ngGQ@@dsUMHauXirVnZFJ\\enlFa@>\ngGQ@@dsUMHauXirVn\\FN[{AOZD<\ngGQ@@dsUMHauXirVn\\FN[{AOZD>\ngGQ@@dsUMHauXirVn]EI[kAhP<\ngGQ@@dsUMHauXirVn]EI[kAhP>\ngGQ@@dsUMHauXirVn]EI[kAo`<\ngGQ@@dsUMHauXirVn]EI[kAo`>\ngGQ@@dsUMHauXirVn]EI[k^hP>\ngGQ@@dsUMHauXirVn]EI[{AO[x>\ngGQ@@dsUMHauXirVn]EI[{^OZD<\ngGQ@@dsUMHauXirVn]EN[kAhP<\ngGQ@@dsUMHauXirVn]EN[kAhP>\ngGQ@@dsUMHauXirVn]EN[{AOZD<\ngGQ@@dsUMHauXirVn]EN[{AOZD>\ngGQ@@dsUMHauXirVuu`tH<\ngGQ@@dsUMHauXitVmu`tH<\ngGQ@@dsUMHauXitVmu`tH>\ngGQ@@dsUMHauhjs_XIw]`<\ngGQ@@dsUMHauhjs_XIw]`>\ngGQ@@dsUMHauhjs_[qw]`<\ngGQ@@dsUMHauhjs_[qw]`>\ngGQ@@dsUThdauXirVm}`dM|<\ngGQ@@dsUThdauXirVm}`dM|>\ngGQ@@dsUThdauXirVnRFJRwvBPwp<\ngGQ@@dsUThdauXirVnRFJ\\wvBPtH>\ngGQ@@dsUThdauXirVnSENRwvBPwp>\ngGQ@@dsUThdauXirVn\\FN[{AHZD<\ngGQ@@dsUThdauXirVn\\FN[{AHZD>\ngGQ@@dsUThdauXirVn]EI[{AH[x<\ngGQ@@dsUThdauXirVn]EI[{AH[x>\ngGQ@@dsUThdauXirVn]EN[{AHZD<\ngGQ@@dsUThdauXirVn]EN[{AHZD>\ngGQ@@dsUThdauXirVn]EN[{AH[x<\ngGQ@@dsUThdauXirVn]EN[{AH[x>\ngGQ@@dsUThdauXirVn]EN[{AOkx<\ngGQ@@dsUThdauXirVn]EN[{AOkx>\ngGQ@@dsUThdauXirVn]EN[{^HZD<\ngGQ@@dsUThdauXirVn]EN[{^HZD>\ngGQ@@dsUThdauXirVn]EN[{^Okx<\ngGQ@@dsUThdauXirVu}`dMB<\ngGQ@@dsUThdauXirVv]EN[{AHZD<\ngGQ@@dsUThdauXirVv]EN[{AHZD>\ngGQ@@dsUThdauXitVn]EN[{AHZD<\ngGQ@@dsUThdauXitVn]EN[{AHZD>\ngGQ@@dsUTheAuXirVm}`dM|<\ngGQ@@dsUTheAuXirVm}`dM|>\ngGQ@@dsUTheAuXirVm}oDM|<\ngGQ@@dsUTheAuXirVnRFJRwvBPwp>\ngGQ@@dsUTheAuXirVnRFJ\\wvBPtH<\ngGQ@@dsUTheAuXirVnRFJ\\wvBPtH>\ngGQ@@dsUTheAuXirVn\\FN[{AHZD<\ngGQ@@dsUTheAuXirVn\\FN[{AHZD>\ngGQ@@dsUTheAuXirVn]EI[{AH[x<\ngGQ@@dsUTheAuXirVn]EI[{AH[x>\ngGQ@@dsUTheAuXirVn]EI[{^H[x>\ngGQ@@dsUTheAuXirVn]EN[{AHZD<\ngGQ@@dsUTheAuXirVn]EN[{AHZD>\ngGQ@@dsUTheAuXirVn]EN[{AH[x<\ngGQ@@dsUTheAuXirVn]EN[{AH[x>\ngGQ@@dsUTheAuXirVn]EN[{AOkx<\ngGQ@@dsUTheAuXirVn]EN[{AOkx>\ngGQ@@dsUTheAuXirVu}`dMB<\ngGQ@@dsUTheAuXirVu}`dMB>\ngGQ@@dsUTheAuXirVv]EN[{AHZD<\ngGQ@@dsUTheAuXitVm}`dM|>\ngGQ@@dsUTiDauXirVn]EN[{^HZD<\ngGQ@@dsUTiDauXirVn]EN[{^HZD>\ngGQ@@dsUTiDauXitVn\\FN[{AHZD<\ngGQ@@dsUTiDauXitVn\\FN[{AHZD>\ngGQ@@dsUTiDauXitVn]EN[{AHZD>\ngGQ@@dsUUHauXirVm}`dMB<\ngGQ@@dsUUHauXirVm}`dMB>\ngGQ@@dsUUHauXirVm}`dMC~RqI@<\ngGQ@@dsUUHauXirVm}`gu|>\ngGQ@@dsUUHauXirVm}oDMB<\ngGQ@@dsUUHauXirVm}oDMB>\ngGQ@@dsUUHauXirVm}oGu|<\ngGQ@@dsUUHauXirVnSENRwvBPtH<\ngGQ@@dsUUHauXirVnSENRwvBPtH>\ngGQ@@dsUUHauXirVnSENRwv|PtH<\ngGQ@@dsUUHauXirVnZFJ\\eolDahP<\ngGQ@@dsUUHauXirVnZFJ\\eolDahP>\ngGQ@@dsUUHauXirVnZFJ\\eomxahP<\ngGQ@@dsUUHauXitVm}`dMB<\ngGQ@@dsUUHauXitVm}`dMB>\ngGQ@@dtuRAuXirVmu`dH\ngGQ@@dtuRAuXirVnSENRwVBP`\ngGQ@@dtuRAuXirVn\\FI[kAHP\ngGQ@@dtuRAuXirVn\\FI[{AH[t\ngGQ@@dtuRAuXitZn\\FI[kAHP\ngGQ@@dtuSHauXirVmu`gp>\ngGQ@@dtuSHauXirVnRFJRwVBP`<\ngGQ@@dtuSHauXirVnRFNRwVB_@<\ngGQ@@dtuSHauXirVnSENRwVB_@>\ngGQ@@dtuSHauXirVn]EI[kAHP<\ngGQ@@dtuSHauXirVn]EI[kAHP>\ngGQ@@dtuSHauXirVn]EI[{AH[t<\ngGQ@@dtuSHauXirVn]EI[{AH[t>\ngGQ@@dtuSHauXirVn]GI[kAO`<\ngGQ@@dtuSHauXirZn]EI[kAHP<\ngGQ@@dtuSHauXirZn]EI[kAHP>\ngGQ@@dtuTAuXirVm}`dMB\ngGQ@@dtuTAuXirVm}oGuB\ngGQ@@dtuTAuXirVnSENRwvBPtH\ngGQ@@dtuTAuXirVnSENRwvBPwp\ngGQ@@dtuTAuXirVn\\FI[{AHZD\ngGQ@@dtuTAuXirVn\\FI[{AH[x\ngGQ@@dtuTAuXirVu}`dMB\ngGQ@@dtuTAuXitZm}`dMB\ngGQ@@dtuUHauXirVm}`guB<\ngGQ@@dtuUHauXirVm}`guB>\ngGQ@@dtuUHauXirVnRFJRwvBPtH<\ngGQ@@dtuUHauXirVnRFJRwvBPtH>\ngGQ@@dtuUHauXirVnRFNRwvB_TH<\ngGQ@@dtuUHauXirVnRFNRwvB_TH>\ngGQ@@dtuUHauXirVnSENRwvB_TH<\ngGQ@@dtuUHauXirVn]EI[{AHZD<\ngGQ@@dtuUHauXirVn]EI[{AHZD>\ngGQ@@dtuUHauXirVn]EI[{AHZG|dcb>\ngGQ@@dtuUHauXirVn]EI[{AH[x<\ngGQ@@dtuUHauXirVn]EI[{AH[x>\ngGQ@@dtuUHauXirVn]EI[{AOjD<\ngGQ@@dtuUHauXirVn]EI[{AOjD>\ngGQ@@dtuUHauXirVn]EI[{^OjD<\ngGQ@@dtuUHauXirVn]EI[{^OjD>\ngGQ@@dtuUHauXirVn]GI[{AOjD<\ngGQ@@dtuUHauXirVn]GI[{AOjD>\ngGQ@@dtuUHauXirVn]GI[{AOkx<\ngGQ@@dtuUHauXirVn]GI[{AOkx>\ngGQ@@dtuUHauXirVv]EI[{AHZD<\ngGQ@@dtuUHauXirZm}`dMB<\ngGQ@@dtuUHauXirZm}`dMB>\ngGQ@@dtuUHauXirZm}`dM|<\ngGQ@@dtuUHauXirZn\\FI[{AHZD<\ngGQ@@dtuUHauXirZn\\FI[{AHZD>\ngGQ@@dtuUHauXirZn]EI[{AHZD<\ngGQ@@dtuUHauXirZn]EI[{AHZD>\ngGQ@@dtuUHauXirZu}`dMB<\ngGQ@@dtuUHauXirZu}`dMB>\ngGQ@@dtuUHauXitVm}`guB<\ngGQ@@dtuUHauXitVm}`guB>\ngGQ@@dtuUHauXitVn]GI[{AOjD>\ngGQ@@dwSTAtYYKVyFulahP\ngGQ@@dwSTAuXirVmtPtH\ngGQ@@dwSTAuXirVm|ndMB\ngGQ@@dwSULauXirVn]EN[hahP>\ngGQ@@dwSULauXirVn]EN[y]HZD<\ngGQ@@eMUTAtpqSdm[eApRFa@\ngGQ@@eMUTAtpqSdm[eApRFa\x7FIHx`\ngGQ@@eMUTAtpqSdm[eApRF~@\ngGQ@@eMUTAtpqSdm[eApSz~@\ngGQ@@eMUTAtpqSdm\\dLTynTGAHZD\ngGQ@@eMUTAtpqSdm\\dLTynU{AHZD\ngGQ@@eMUTAtpqSdm\\xLRwJC`dM|\ngGQ@@eMUTAtpqSdm\\xLRwJ}`dM|\ngGQ@@eMUTAtpqSdm\\xLTwJC`dMB\ngGQ@@eMUTAtpqSdm\\xLTwJ}`dMB\ngGQ@@eMUTAtpqSdmkeApRFa@\ngGQ@@eMUTAtpqSdmkeApRFa\x7FIHx`\ngGQ@@eMUTAtpqSdukeApRFa@\ngGQ@@eMUTAtpqShukeApRFa@\ngGQ@@eMUTAtpqShulxLTwJ}`dMB\ngGQ@@eMUTAtpqUdm[eApRFa@\ngGQ@@eMUTAtpqUdm\\xLRwJC`dM|\ngGQ@@eMUTAtpqUdm\\xLTwJC`dMB\ngGQ@@eMUTAtpqUdulxLTwJC`dMB\ngGQ@@eMUUHatpqSdm\\dLTenU{AH[x>\ngGQ@@eMUUHatpqSdm\\xLTwJC`dM|<\ngGQ@@eMUUHatpqSdm\\xLTwJC`dM|>\ngGQ@@eMUUHatpqSdmlxLTwJC`dMB<\ngGQ@@eMUUHatpqSdmlxLTwJC`dMB>\ngGQ@@eMUUHatpqSdu[eApRF~@<\ngGQ@@eMUUHatpqSdu[eApRF~@>\ngGQ@@eMUUHatpqUdmlxLTwJC`dMB>\ngGQA@NRYjP@zT\\wQw]`=\ngGQA@NRYjP@zT\\wvz]wX=\ngGQA@NRYjP@zT\\ytTeomt{oP\ngGQAAIRYj`@zT\\wvB]wX+\ngGQAAIRYjf@zlTyK[Nbdm}`gmB>\ngGQBBGBNB\\LxYIIZj@zpRunYy^wjD\ngGQDHGBnBUSUPGUCENRwJC`dM|\ngGQDHGBnBUSUPGUCENRwJC`gu|\ngGQDHGBnBUSUPGUCENRypXenTGAH[x\ngGQDHGBnBUSUPGUCENSWJC`dM|\ngGQDHGBnBUSUPGUCEVcWJC`dM|\ngGQDJ@aABSWUPGVcdmxP`\ngGQDJIARBSWUPGVcdmx_@\ngGQDJIARBSWUPGVcdn\\gI[p~@\ngGQDLOA^FQRFj`NmDm[x^WjD\ngGQHAJAIfj@CiQs_XIw]`+\ngGQHAJAIfj@CiQs_XI{^`+\ngGQHAJAIfj@CiQu_XIw^`>\ngGQHAJAIfj@CiQu_XI{^`+\ngGQHAJAIfj@CiQugQRV~pSn}@>\ngGQHAJAIfj@CiQugQSf~pSv}@>\ngGQHAJAIfjXCjqShmk{AOZD>\ngGQHAJAIfjhCjqSdm[{AHZD>\ngGQHAjAInfhChrrZurMkYCP`\ngGQHB@aIfiXChqSfn]EI[k]hP\ngGQHB@aIfiXChqSfuyP`\ngGQHB@aIfiXChqSfv]EI[k]hP\ngGQHB@aIfiXCkRSV~F}na@\ngGQHB@aIfiXCkRSV~F}va@\ngGQHB@aIfiXCkRSWNbdm|M{mB\ngGQHB@aIfiXCkRSZ~F}na@\ngGQHB@aIfiXCkRSZ~F}va@\ngGQHB@aIfiXCkRS[Nbdm|M{mB\ngGQHB@aIfidCiRU\\c^v]wX\ngGQHB@aIfjiQJChqSjn\\FI[kAhP>\ngGQHB@aInfjZCkRsV~Fuva@<\ngGQHBGAIfiXChqSfn]EI[h^hP\ngGQHBHaIfiXChqSfn]EI[k]hP\ngGQHBHaIfiXChqSfn]EI[k]o`\ngGQHBHaIfiXChqSfn]EI[ra@\ngGQHBHaIfiXChqSfv]EI[k]hP\ngGQHBHaIfjiQIChqSfmu`tH<\ngGQHBHaIfjiQJChqSfmu`tH>\ngGQHBHaIfjiQJChqSfn]EI[kAhP<\ngGQHBHaIfjiQJChqSfn]EI[kAhP>\ngGQHBIAIfiXChqSfn]EI[k]hP\ngGQHBIAIfjiQIChqSfnSENRwVCP`>\ngGQHBIAIfjiQIChqSfn]EI[kAhP>\ngGQHBIAIfjiQJChqSfn]EI[kAhP<\ngGQHBIAIfjiQJChqSfn]EI[kAhP>\ngGQHBJqIfiXChqSfn]EI[k]hP\ngGQHBJqIfiXChqSfn]EI[ra@\ngGQHBJqIfjiQJChqSfn]EI[kAhP<\ngGQHBLQIfiXChqSfn]EI[k]hP\ngGQHBLQIfiXChqSfn]EI[ra@\ngGQHBLQIfiXChqSfv]EI[k]hP\ngGQHBLQIfjZQChqSfuu`tH<\ngGQHBLQIfjZQChqSfuu`tH>\ngGQHBLQIfjiQIChqSfmu`tH>\ngGQHBLQIfjiQJChqSfmu`tH>\ngGQHBLQInfjZChqSfn]EI[ra@>\ngGQHD@aInZ@CjQshiK]G]z\ngGQHD@aInf@CjQncn{@=\ngGQHD@aInfhChqrVmtPtH\ngGQHDHaInf@CjQncn{@=\ngGQHDOAIijjQCjqSdm\\dLTenQ{AH[x<\ngGQHDOAIijjQCjqSdm\\dLTeolDao`<\ngGQHDOAIkjjQChqrVnRFJRwQC_@<\ngGQHDOAIkjjQChqrVnRFJRwp|Pwp<\ngGQHDOAInf@CjQncn{@=\ngGQHDOAInjBQCjQoax{np+\ngGQHDOAInjBQCjQoax{np-\ngGQHH@aJnZBACiAs_XIw]`+\ngGQHH@aJnZBACiAs_XIw]`-\ngGQHH@aJnZBACiAs_XIw^`>\ngGQHH@aJnZBACiAs_[qw]`-\ngGQHH@aJnZBACiAu_XIw]`+\ngGQHH@aJnZBACiAu_XIw]`-\ngGQHH@aJnZBACiAu_XIw^`<\ngGQHH@aJnZBACiAu_XIw^`>\ngGQHH@aJnZBACiAugQRV~pSn}@<\ngGQHH@aJnZBACiAugQRV~pSn}@>\ngGQHH@aJnZZACkAUf~pSv}@<\ngGQHH@aJnZZACkAUf~pSv}@>\ngGQHH@aJnZZACkAUj~pSv}@<\ngGQHH@aJnZZACkAUj~pSv}@>\ngGQHH@aJnZjACjaShm[{AHZD>\ngGQHHDQJnZ@CiAu_XIw^`>\ngGQHHGAIZjhCjqSdm[d^pRFa@\ngGQHHGAIZjhCjqSdm[d^pRF~@\ngGQHHGAIZjhCjqSdm\\xLTwH}`dMB\ngGQHHGAIZjhCjqSdmkd^pRFa@\ngGQHHGAIZjhCjqSdukd^pRFa@\ngGQHHGAJijhCiabgIZwJC`dMB\ngGQHHGAJijhCiabgIZwJC`dM|\ngGQHHGAJijhCiabgIZwJC`guB\ngGQHHGAJijhCiabgIZwJC`gu|\ngGQHHGAJijhCiabgI[WJC`dMB\ngGQHHGAJijhCiabgI[WJC`guB\ngGQHHGAJijhCiabkQZwJC`guB\ngGQHHGAJijhCiabkQ[WJC`guB\ngGQHHGAJijhCiabkQjwJC`dMB\ngGQHHGAJkjdCjaSdm[kAHP\ngGQHHGAJkjhCjaSdm[{AHZD\ngGQHHOAJkZhCjaSdm[{AHZD\ngGQHHOAJkZhCjaShu[{AHZD\ngGQHHOAJkZhCjaShuk{AHZD\ngGQHJGAJijhCjabgI[yApRD\ngGQH`jBRnRnjj@zXXitZus@xICP`\ngGQI@jA\\e]UTAtpqSdukfApRFa@\ngGQI@jA\\e]UTAtpqSdulxLTwLC`dMB\ngGQI@jA\\e]UTAtpqShukfApRFa@\ngGQIAJB\\dsU@AthzolD}oP+\ngGQIAJB\\dtuTAuXirVm}`dMB\ngGQIAJB\\dtuTAuXitZn\\FI[{AHZD\ngGQIB@`|dsTrAuiIkgQRV~F}v}@\ngGQIHBpReWU@At`zolD{oP>\ngGQIHO@ReUuTAuPirVm}`dMB\ngGQIJO@ReTuTAuPqSdm|`xIB\ngGQLBIARFdLbdMU@]ZIZweB\ngGQLBIARFdLbdMU@]ZI[WeB\ngGQLJHaQFbLbdMU@]JIP\ngGQLJIARFdLbdMU@]JIP\ngGQLL@b^BBDfmjiDNcGIjwQCP`<\ngGQ`@ZdsMTAuhisdqSdmy``\ngGQ`@ZdwSTAtiYnam[@\ngGQ`@bdwMLAuhyk^TH\ngGQ`@bdwMLAuhym^TH\ngGQ`@bdwMRAthzncn{@\ngGQ`@bdwMRAthzncn}@\ngGQ`@bdwMRAuhyj\ngGQ`@bdwMRAuhyk^Wh\ngGQ`@bdwMUMAuhyk^TH<\ngGQ`@bdwMUMAuhyk^TH>\ngGQ`@bdwMUMAuhyk^Wp<\ngGQ`@bdwMUMAuhyk^Wp>\ngGQ`@bdwMUMAuhykgQSf|hP<\ngGQ`@bdwMUMAuhykgQSf|hP>\ngGQ`@bdwMUMAuhym^TH<\ngGQ`@bdwMUMAuhym^TH>\ngGQ`@bdwUThlauhykgARV|hP<\ngGQ`@bdwUThlauhykgARV|hP>\ngGQ`@bdwUThmAuhykgARV|hP<\ngGQ`@bdwUThmAuhykgARV|hP>\ngGQ`@bdwUThmAuhykgARV|o`<\ngGQ`@bdwUUMAuhykdabdmyP`<\ngGQ`@bdwUUMAuhykdabdmyP`>\ngGQ`@jduuTAuhyK^DH\ngGQ`@jduuTAuhyKgIrV|HP\ngGQ`@jduuTAuhyM^DH\ngGQ`ALe]UTAtPiKVzHZD\ngGQ`ALe]UTAtPiKWNCEMtPtH\ngGQ`ALe]UUDatPiKWICEN[hahP<\ngGQ`AbeMUTAtPqSVzPZD\ngGQ`AbeMUTAtPqSWICEN[iAhP\ngGQ`AbeMUTAtPqS[ICEN[iAhP\ngGQa@bnR[fjf`zt\\uoJD<\ngGQa@bnR[fjf`zt\\uoJD>\ngGQa@bnR[fjf`zt\\voJD<\ngGQa@bnR[fjf`zt\\voJD>\ngGQdEb@b^BSRuPGVbfmyP`\ngGQdEb@b^BSRuPGVbfuyP`\ngGQdEbGBNBUWUPGVBfmuOTH\ngGQdHl@btFRREZ`NlGI[h~o`\ngGQdHlGBnBUSUPGVCDmtPwp\ngGQdHlGBnBUSUPGVCDmt_Wp\ngGQdHlGBnBUSUPGVCDutPwp\ngGQdHlGBtBUSUPGVCDuxP`\ngGQdHlOB~BUVuTBGVBdutPwp>\ngGQdHlOB~BUVuTBGVBdv]EI[hao`<\ngGQdHlOB~BUVuTBGVBdv]EI[hao`>\ngGQdIbBqNBRuUPGVbfmtOWp\ngGQdLZ@a^BRuSPGRbf|G`\ngGQdhlOBt@f|eTuTAu`qM]DM|\ngGQdibOAT@e\\dmUTAuhim]CuB\ngGQeEb@bN@yIijhCkQSV|o`\ngGQeEb@bN@yIijhCkQSZ|hP\ngGQhHl@cIIBmPGQCdm[hahP\ngGQhHl@cIIBmPGQCdm[h~hP\ngGQhHl@cIIBmPGQCdmkhahP\ngGQhHl@cIIBmPGQCdmkh~hP\ngGQhHl@cIIBmPGQCdu[hahP\ngGQhHl@cIIBmPGQCdukhahP\ngGQhHl@cIIJmPGVBVmy_@\ngGQhHlBqJijhChabZv\\GI[hah_rTJH\ngGQhHlGAJijhChabVmtPtH\ngGQhHlGAJijhChabVmtPwp\ngGQhHlGCIIKUHGVBVh\ngGQhHlGCIIKUPGVBVmyP`\ngGQhHlOAJkZjAChaRVmtPtH<\ngGQhHlOAJkZjAChaRVmtPtH>\ngGQhHlOAJkZjAChaRVmt_TH<\ngGQhHlOAJkZjAChaRVmt_TH>\ngGQhHlOAJkZjAChaRVn]EI[hahP<\ngGQhHlOAJkZjAChaRVn]EI[hahP>\ngGQhHlOAJkZjAChaRVn]EI[h~hP<\ngGQhHlOAJkZjAChaRVn]EI[h~hP>\ngGQhHlOAJkZjAChaRVutPtH<\ngGQhHlOAJkZjAChaRVutPtH>\ngGQhHlOAJkZjAChaRZmtPtH<\ngGQhHlOAJkZjAChaRZmtPtH>\ngGQhHlOAJkZjAChaRZutPtH<\ngGQhHlOAJkZjAChaRZutPtH>\ngGQhHlOCIIJuHGVBVmy^`\ngGQhHlOCIIJuPGVBVmyP`\ngGQhHlOCIIJuPGVBVuyP`\ngGQiAbjA\\e]UTAtPqSZz`ZD\ngGQiHl@c]ddeVhCkAKV|hP\ngGQiHl@c]ddeVhCkAKV|o`\ngGQiHlOC]ddeZjACkAKV|hP<\ngGQiHlOC]ddeZjACkAKV|hP>\ngGR@@cTfxH@MrMkYw]`=\ngGR@@cTfyi`NeKUrMkYw]`\ngGR@@cTfyi`NeKUrMkYw^`\ngGR@@cTfyi`NeKUrMkiw^`\ngGR@@cTfzj`NeGNZFJ\\e@\ngGR@@lTfYj`NeEUt]wo{Q@\ngGR@@lTfYj`NeIUrM{Yw^\x7FmD\ngGR@@lTfxJ`NijyFul{n\x7Fvf@=\ngGR@@lTfxJ`NijyFul{o_vf@=\ngGR@@m\\bdMU@]JIP\ngGR@ACTjzj`NdIMuM{_{P@\ngGR@ACTjzj`NdIMuM{o{P@\ngGRA@l]rSLuPGRdjyF}l{o_vb@\ngGRD@cYPZ`R[jj@zT\\`\ngGRDHlQxWpRjYi@zPX\x7FmH\ngGREHlQxWpTiULtpH]HL\\xJR\x7FmH<\ngGREHlQxWpTiULtpH]HL\\xJR\x7FmH>\ngGREHlQxWpWIU[U@]HJ\\xLRwe}~tP\ngGREIcQxKpTiKSU@]JJ\\xLT\x7FmH\ngGRHHlQxIU[U@]XJZweC~tP\ngGRHHlQxYIHPj@zVZwtvmtO{S@\ngGRHHlQxYIHPj@zVZwtvmww{S@\ngGRHHlQxYIHPj@zVZyr\\eoim[h_vf@\ngGRHHlQxYIHPj@zV[WtvmtO{S@\ngGRIHlQxBTjfj`NlFM[ra@\ngGRIHlQxRTjmj`NlEM[ra\x7FZH\ngGT@@TfX`@MrM{Yw]`\ngGT@@TfX`@MrM{Yw^`\ngGT@@TfX`@MrM{Y{]`\ngGT@@TfX`@MrM{iw^`\ngGT@@TfX`@N]EI[d[wSn}@\ngGT@@TfXa`NdfmrM{Y{P`\ngGT@@TfXa`Ndfm|M{]B\ngGT@@TfXa`NdfurM{Y{P`\ngGT@@TfXa`Ndfu|M{]B\ngGT@@TfXbPNdfmtM{X\ngGT@@TfXbPNdfm|M{]z\ngGT@@TfXbPNhjyF}l{np\ngGT@@TfXbPNhjyF}l{oP\ngGT@@TfXbPNhjyF}l}np\ngGT@@TfXbPNhjyF}t{np\ngGT@@TfXbPNhjyF}t{oP\ngGT@@TfXbPNhkNbdmrM{iw^`\ngGT@@TfYh@NiJyF}l{np\ngGT@@TfYh@NiJyF}t{np\ngGT@@TfYi`NcENZwVCP`\ngGT@@TfYi`NcENkWH{`gmB\ngGT@@TfYjPNcENZytTeoLD\ngGT@@TfYjPNmEV[{AN{l\ngGT@@TfYjPNmEV[{AN{t\ngGT@@TfZfPNeIUrM{Yw]`\ngGT@@TfZfPNeIUrM{Yw^`\ngGT@@TfZfPNeIUrM{Y{]`\ngGT@@TfZfPNeIUrM{iw^`\ngGT@@TfZfPNeIUrN{Y{]`\ngGT@@TfZfPNeIUrN{i{^`\ngGT@@TfZjeDdNcENZwVCP`\ngGT@@TfZjeDdNcENZytTenlFa@\ngGT@@TfZjeDdNcEN[WVCP`<\ngGT@@TfZjeDdNcEN[YtTynlFa@>\ngGT@@TfZjeDdNcENkWVCP`\ngGT@@TfZjeDhNcENZwVCP`<\ngGT@@TfZjeDhNcENZwVCP`>\ngGT@@TfZjeDhNcENZyhXirVzpZD<\ngGT@@TfZjeDhNcENZytTenlFa@<\ngGT@@TfZjeDhNcENZytTenlFa@>\ngGT@@TfZjeDhNcEN[WVCP`<\ngGT@@TfZjeDhNcEN[WVCP`>\ngGT@@TfZjeDhNcEN[YpXynlFa@>\ngGT@@TfZjeDhNcENkWVCP`<\ngGT@@TfZjeDhNcENkWVCP`>\ngGT@@TfZjeDhNcENkYpXynlFa@>\ngGT@@TfxJihNefm|Mk]B<\ngGT@@TfxJihNefm|Mk]B>\ngGT@@TfxJihNefm|Mk]|>\ngGT@@TfzZihNmKM\\zJ\\wpvntH<\ngGT@@TfzZihNmKM\\zJ\\wpvntH>\ngGT@@TfzZihNmKM\\zJ\\wpzntH>\ngGT@@TfzZihNmKMlzJ\\wpvntH<\ngGT@@TfzZihNmKMlzJ\\wpvntH>\ngGT@@TjZjPNbFR\\wJC`g]z=\ngGT@@TjZjPNbFR\\wJC`gmz=\ngGT@@TjZjPNbFR\\ypXenTGAN{w}h@\ngGT@@TjZjPNbFR\\ypXenTGAO[t\ngGT@@TjZjPNbFR\\ypXenTGAO[w}h@\ngGT@@TjZjPNjFJ\\undGA\x7FZ@=\ngGT@@TjZjPNjFJ\\uodGAo_v`@=\ngGT@@TjZjPNjFJ\\usPqSdm|`xM{~t@=\ngGT@@TjZjPNjFJ\\us`qK]HNC~t@\ngGT@@TjZjPNjFJ\\us`qK_HNC^\x7Fm@\ngGT@@TjZjPNjFJ]Us`is_HNC^\x7Fm@\ngGT@@TjZjPNjFJ]Us`qK_HNC^\x7Fm@\ngGT@@TjZjdEDNjFJ\\vs`qs_HNCP`<\ngGT@@TjZjiDNjFJ\\uodGAh_v`@+\ngGT@@TjZjiDNjFJ\\urPqrV~P\\Fa\x7FZ@<\ngGT@@TjZjiDNjFJ\\usPqSdm|`xMB<\ngGT@@TjZjiDNjFJ\\usPqSdm|`xMB>\ngGT@@TjZjiDNjFJ\\usPqSdm|`xMC~t@-\ngGT@@TjZjiDNjFJ\\us`qK_HNC__m@<\ngGT@@TjZjiDNjFJ\\us`qK_HNC__m@>\ngGT@@TjZjiDNjFJ\\us`qs_HNCP\x7Fm@>\ngGT@@TjZjiDNjFJ\\vodGAhP>\ngGT@@TjZjiDNjFJ\\vrPqSf~P\\Fa@<\ngGT@@TjZjiDNjFJ\\vrPqSf~P\\Fa@>\ngGT@@TjZjiDNjFJ\\vs`qs_HNCP\x7Fm@<\ngGT@@TjZjiDNjFJ]Vs`qs_HNCP\x7Fm@<\ngGT@@TjZjiDNjFJ]Vs`qs_HNCP\x7Fm@>\ngGT@@TjZjiDNlJM\\xJRwrwntO{P@<\ngGT@@TjZjiDNlJM\\xJRwrwntO{P@>\ngGT@@TjZjiDNlJMlxL\\wr{ntO{P@<\ngGT@@TjZjiDNlJMlxL\\wr{ntO{P@>\ngGT@@dfXb`NhjyF}l{n\x7Fvb@=\ngGT@@dfXb`NhjyF}l{o_vb@\ngGT@@dfXb`NhjyF}l}o_vb@=\ngGT@@dfXb`NhjyF}t{n\x7Fvb@=\ngGT@@dfXb`NhjyF}t{o_vb@\ngGT@@dfXb`Nldm[d[vrFa\x7FZH=\ngGT@@dfXb`Nldm[d[wRFa@\ngGT@@dfXb`Nldm[d[wRFa\x7FZH=\ngGT@@dfXb`Nldm\\zJ\\wHwndMC~tP\ngGT@@dfXb`Nldmkd[vrFa\x7FZH\ngGT@@dfXb`Nldmkd[wRFa\x7FZH\ngGT@@dfXb`Nldukd[vrFa\x7FZH=\ngGT@@dfXb`Nldukd[wRFa\x7FZH=\ngGT@@dfXbhdNldm\\zJ\\wHwndMB<\ngGT@@dfXbhdNldmlzJRwHwndMB<\ngGT@@dfXbhdNldmlzJRwHwndMB>\ngGT@@dfYj`NcIIZwHwndMC~tP=\ngGT@@dfYj`NkENRuolDah_vb@=\ngGT@@dfYj`NkENRuomxah_rPJMh`=\ngGT@@dfYj`NkENRusPqSdm}`dMC~tP=\ngGT@@dfYj`NkENRus`qs_XICP\x7FmD\ngGT@@dfYj`NkENRushis_XICP\x7FmD\ngGT@@dfYj`NkENRvs`qs_XICP\x7FmD\ngGT@@dfYj`NkENRvshiK_XICP\x7FmD\ngGT@@dfYj`NkENRvshiK_[qCP\x7FmD\ngGT@@dfYj`NkENRvshis_XICP\x7FmD\ngGT@@dfYj`NkENbuolDah_vb@=\ngGT@@dfYj`NkENbusPqSdm}`dMC~tP=\ngGT@@dfYj`NkENbus`qs_XICP\x7FmD\ngGT@@dfYj`NkENbvs`qs_XICP\x7FmD\ngGT@@dfnjPNcGIZyr\\eoBD\ngGT@@dfnj`NcGIZwQCP`\ngGT@@dfnj`NcGIZyHXiK]DMB\ngGT@@dfnj`NcGIZyr\\enbFa@\ngGT@@dfnj`NcGI[WQCP`\ngGT@@dfxH@MrMkYw]`=\ngGT@@dfxH@MrMkYw^`=\ngGT@@dfxH@MrMkY{^`=\ngGT@@dfyh@NiFzN{l=\ngGT@@dfyh@NiFzN{t\ngGT@@dfyh@NiFzO[t=\ngGT@@dfyh@NiF~GSn{@=\ngGT@@dfyh@NiF~GSn{\x7FI@p`=\ngGT@@dfyh@NiF~GSn}@\ngGT@@dfyh@NiGNBdmt]wh\ngGT@@dfyh@NiGNbdmt]wh\ngGT@@dfyh@NiJyFul{np=\ngGT@@dfyh@NiJyFul{oP\ngGT@@dfyh@NiJyFul}oP=\ngGT@@dfyh@NiJyFut{np=\ngGT@@dfyh@NiJyFut{oP\ngGT@@dfyh@NiJyFut}oP=\ngGT@@dfyh@NiKNbdmrMkiw^`\ngGT@@dfyi`NcGIZytTyncva@\ngGT@@dfyi`NeGV\\EN[h}np\ngGT@@dfyi`NeKUrMkiw^`\ngGT@@dfyj`NcGIZwQCP`\ngGT@@dfyj`NcKIZwHvndMB\ngGT@@dfyjidNcGI[WQCP`<\ngGT@@dfzh@NiFzN{l=\ngGT@@dfzh@NiFzN{t\ngGT@@dfzhIDNiGNBdmt]wh<\ngGT@@dfzhIDNiGNBdmt]wh>\ngGT@@dfzi`NeGUt]wh\ngGT@ADjZj`NbJIZwJ{ndMC~t@=\ngGT@ADjZj`NfFJ\\ek\\hNBPtO{HP=\ngGT@ADjZj`NfFJ\\ekgAcfyP\\Dah_vP`\ngGT@ADjZj`NfFJ\\em\\hNBPtO{HP=\ngGT@ADjZjiDNfFJ\\ekgAcfyP\\Dah_v`@<\ngGT@ADjzh@NdGM}`g]w~t@=\ngGT@ADjzh@NdGM}`g]{~t@\ngGT@ADjzh@NdGM}`gm{~t@=\ngGT@ADjzh@NdGM}oG]w~t@=\ngGT@ADjzh@NdGU}`g]w~t@=\ngGT@ADjzh@NhJyf}l{n\x7Fv`@=\ngGT@ADjzh@NhJyf}l{o_v`@\ngGT@ADjzh@NhJyf}l}o_v`@=\ngGT@ADjzh@NhJyf}t{n\x7Fv`@=\ngGT@ADjzh@NhJyf}t{o_v`@\ngGT@ADjzh@NhJyf}t}o_v`@=\ngGT@ADjzh@NhKNbdmsM{iw^\x7Fm@\ngGT@ADjzi`NbIIZwLwmgmC~t@\ngGT@ADjzi`NbIIZwtwmtO{P@\ngGT@ADjzi`NjENRushis_XI{P\x7Fm@\ngGT@ADjzj`NbIIZwLwmdMC~t@\ngGT@ADjzj`NbIIZwLwndMC~t@\ngGT@ADjzj`NjENRuolDah_v`@\ngGT@ADjzj`NjENRurPqrV~pRFa\x7FZ@\ngGT@ADjzjdDhNjENRus`qs_XICP`<\ngGT@ADjzjhdNbII[WLwndMC~t@>\ngGT@ADjzjhdNbII[YtTynYo]HZG}h@>\ngGT@ADjzjhdNjENRurPqrV~pRF~\x7FZ@<\ngGT@ADjzjhdNjENRurPqrV~pRF~\x7FZ@>\ngGT@ADjzjhdNjENRus`qs_XICP\x7Fm@<\ngGT@ADjzjhdNjENRus`qs_XICP\x7Fm@>\ngGT@ADjzjhdNjENRvolDah_v`@<\ngGT@ADjzjhdNjENRvolDah_v`@>\ngGT@ADjzjhdNjENRvshis_XICP\x7Fm@<\ngGT@ADjzjhdNjENRvshis_XICP\x7Fm@>\ngGT@ADkij`NjENRuolDah_v`@\ngGT@ATeVn`NeDh\ngGT@ATffj`NcENRwVBP`\ngGT@ATffj`NcENRyLTyK]XIB\ngGT@ATffjiDNcENRytTenlDa@<\ngGT@ATffjiDNcENRytTenlDa@>\ngGT@Adijj`NjFJRuodDah_v`@\ngGT@Adijj`NjFJRus`qS_HICP\x7Fm@\ngGT@Adijj`NjFJbus`qS_HICP\x7Fm@\ngGT@`QIeIfH@C\\c^v]wX\ngGT@`QIeIfH@CgAcfyG]l}np\ngGT@`QIeIfjiQJChqSfn]EI[kAhP<\ngGT@`QIeIfjiQJChqSjuu`tH<\ngGT@`QIeIfjiQJChqSjuu`tH>\ngGT@`aJyInZ@CjRnQu[N{l=\ngGT@aAteJzjhCjaSdm[{AHZG}h@\ngGTA@QJSLP@FyF}l{np\ngGTA@QJSLP@FyF}l{oP\ngGTA@QJSLPpGRSV~F}na@\ngGTA@QJSLuHGVbkM}`g]v\ngGTA@QJSLuHGVbkV]EN[{AO[l\ngGTA@QJSMURbTGQbgM\\zJRwVCP`<\ngGTA@aJSLuPGUbgIZwH{`dMC~tP=\ngGTA@aJSLuPGUbgIZyhXirV~pRFa\x7FZH=\ngGTA@aJS\\D@FyFul{np=\ngGTA@aJS\\t@GTc]G]v=\ngGTA@aJS\\t@GTc]G]z\ngGTA@aJS\\t@GTc_Ciw]`=\ngGTA@aJS\\t@GTc_Ciw]\x7Fd`XP=\ngGTA@aJS\\t@GTe\\cZv]wX=\ngGTA@aJS\\t@GTe\\cjz]wX=\ngGTA@erS\\t@GTe\\cZv]wX=\ngGTAAAJU\\t@GTE\\s^z^wo{P@=\ngGTAAAJU]R@GTE\\s^v]w_{P@=\ngGTAAAJU]R@GTE\\s^z]w_{P@=\ngGTAAIJTuMPGSCENRus`qS\\knBPtO{P@\ngGTAAQJSSUPGQbgI[kAHP\ngGTAAQJUSUPGUCENRyHXiK_HNBP`\ngGTBLQDSpTQ_AIkjTCiQs~tp\ngGTCLQDSpTQ_@}dTaihCiQKgIrV|oova@\ngGTD@UPZ`Rkjj@zHYImgQSfz`ZG}h@>\ngGTD@]PV`rRFUTAtPqSfz`TD>\ngGTDCPDZ`R[ij@zTlwPvm`\ngGTDEPDDHR[ff@zT\\`\ngGTDEPDDHR[ii@zTmWHvmg]v\ngGTDEaxSpRkjj`PzHTek]DMB<\ngGTDEaxSpRkjj`PzHTek]DMB>\ngGTDQMPV`Dr]uyJffXChabdnZFJ\\enmz~\x7FYB@\ngGTDcPDHHWFTfyi`NeGUt^wh\ngGTEIaxKpTiKSU@]FJSVs`qS]DMC~t`\ngGTH@]PYICJj@zhXisV~`TFa@>\ngGTH@]PYICJj@zhXisZ~`TFa@>\ngGTH@iPIMuP@]RMt]wX=\ngGTH@iPIMuP@]RMt^wh=\ngGTHAMPIUuP@]PMt]w_{P@=\ngGTHAMPIUuP@]PM}oG]w~t@=\ngGTHCPDILsS@]ZJ\\ytTenlD}@\ngGTHCPDILuH@]RUrM{Yw]`=\ngGTHCPDILuK@]JR[h[vp\ngGTHCPDILuK@]JRkd[vsn{@\ngGTHCPDILuK@]JRkd[vsn}@\ngGTHCQHILuK@]ZJ\\ytTy@\ngGTHCQxITuS@]DLeZnTGAN{t\ngGTHDPDIMtp@]RUrMkYw]`\ngGTHDPDIMtuSP]ZVZwpvmtH>\ngGTHE`DILsU@]FJRunbFa\x7FZH=\ngGTHE`DILsU@]FJRushis]DMC~tP\ngGTHE`DILsU@]FJRvnbFa\x7FZH\ngGTHE`DILsU@]FJRvshis]DMC~tP\ngGTHE`DIMtu@]FNRunbFa\x7FZX=\ngGTHE`DIMtu@]FNRushis]DMC~tp\ngGTHE`DIMtu@]FVRunQm[HZG}i`=\ngGTHHPxILuS@]FJ\\voa{Ah_vd@\ngGTHHPxILuS@]FJ\\voa{^h_vd@\ngGTHHaxITuUPH]TL]Ek_XICP`<\ngGTHHaxITuUPH]TL]Ek_XICP`>\ngGTHHaxYICJ`@z`[h{np=\ngGTH`iPBYrSWUTbGQcdm[hahP<\ngGTH`iPBYrSWUTbGQcdm[hahP>\ngGTHaMPB]rU\\t@GTC_[qw]\x7Fm@=\ngGTHdPDCeJS]L@GTc]G]v\ngGTHe`DCeJS]MPGQcdm\\zJ\\wQCP\x7FmL\ngGTHe`DCeJS]MPGQcdmlzJ\\wQCP\x7FmL\ngGTICQHFTfZe`NmEN\\zJR`\ngGTICQxFTjZi`NbFRmWJC`gmz\ngGT`CPdfyi`NeGH\ngGT`CPdfyj`NeGH\ngGT`EPTfyi`NeGH\ngGT`EPTfyi`NeGN]EIP\ngGT`EPTfzZPNeKUrMkYw]`\ngGT`E`TfYjhhNmEM[ra@<\ngGT`LPdfyj`NmGM[ra\x7FZX\ngGT`LPdfyj`NmGM[r~\x7FZX\ngGT`LPdfyj`NmGMkra\x7FZX\ngGT`hPiJyInZ@CjQncn}\x7FZP\ngGT`hPiJyInZXCiQu]G]w~t`\ngGT`hPiJyInZXCiQu]G]{~t`\ngGT`hPiJyInZdCiQu]G]w~t`\ngGT`hPiJyInZdCiQu]G]{~t`\ngGT`hPiJyInZdCiQu]Gmw~t`\ngGT`hPiJyInZdCiQu]Gm{~t`\ngGT`hPiJyInZdCkQsV|o_vd@\ngGT`hPiJyInZjYCkQsZ|h_vd@<\ngGT`hPiJyInZjYCkQsZ|h_vd@>\ngGT`i`iJyInZhChqrVmtPtO{JX=\ngGT`i`iJyInZhChqrVutPtO{JX\ngGTahPiJx|dwMRAthzncn}\x7FZP\ngGTdLXaxWpRjvj@zPTwe|\ngGTdlX`DTHwF\\ddJu@]HN[h~oovf@\ngGTeI\\QxKpTiKSU@]JJ\\xLR\x7FmH\ngGTeLXaxWpOYIIZZ@zPRyr\\eoK{}hP\ngGThLX`DYIHUj@zp\\uoJG}i`\ngGThLX`DYIHUj@zp\\voJG}i`\ngGThLXaxIUMA@]JM[{[NzD\ngGThLXaxIUMA@]JM\\xLRwvv]tH\ngGThLXaxIUMA@]JMk{[NzD\ngGThLXaxIUMA@]JMlxLRwvv]tH\ngGThLXaxIU[U@]XJ[WeB\ngGThLXaxIU[U@]XJ[WeC~RQq@\ngGThLXaxYIHVj`Pzp\\voJG}i`<\ngGThLXaxYIHVj`Pzp\\voJG}i`>\ngGThMX`DYIHUj@zp\\foBG}i`\ngGThmX`D[kNRREZ`NlGIkpa\x7FZX\ngGTiCQePKdkjj`NlFJ[rA@\ngGTiCQePKdkjjhdNlFR\\xL\\wdB<\ngGTiLXaxGdjffhDNlFMkra@<\ngGTiLXaxGdjffhDNlFMkra@>\ngGU@CPdsMLAuhiu^XH\ngGU@CPdsMLAuhjs_XIw^`\ngGU@CPdsMLAuhju_XIw^`\ngGU@CPdsTlAtiJnQo[N{t\ngGU@DPdsMTAtXisVzpZG}h`\ngGU@DPdsMTAtXisVzp[{}h`\ngGU@DPdsMTAtXisWNbdmu`tO{Q@\ngGU@DPdsMTAtXisWNbgMu`tO{Q@\ngGU@DPdsMTAtXisZzpZG}h`\ngGU@DPdsMTAtXis[NbgMu`tO{Q@\ngGU@DPdsMTAtXiuVzpZG}h`\ngGU@DPdsMTAtXiuVzp[{}h`\ngGU@DPdsMTAtXiuWNbdmu`tO{Q@\ngGU@DPdsMTAtXiuWNbgMu`tO{Q@\ngGU@DPdsMTAtXiu[NbgMu`tO{Q@\ngGU@DPdsMTAuhjs_XIw]\x7FmD\ngGU@DPdsMTAuhjs_XIw^\x7FmD\ngGU@DPdsMTAuhjsgQRV~pSn}\x7FZH\ngGU@DPdsMTAuhju_XIw^\x7FmD\ngGU@DPdsUUHauhjs_XIw]\x7FmD<\ngGU@DPdsUUHauhjs_XIw^\x7FmD<\ngGU@DPdsUUHauhjs_XIw^\x7FmD>\ngGU@DPdwM@AuHwQw]`\ngGU@DPdwM@AuHwQw^`\ngGU@DPdwM@AuHytTencn}@\ngGU@DPdwMLAthzncn{@\ngGU@DPdwMLAthzncn}@\ngGU@DPdwMLAuhyk]GmB\ngGU@DPdwMLAuhyk^TH\ngGU@DPdwMLAuhykgQRVzOZD\ngGU@DPdwMLAuhykgQRV|hP\ngGU@DPdwMLAuhykgQSf|hP\ngGU@DPdwMLAuhym^TH\ngGU@DPdwMLAuhymgQSf|hP\ngGU@DPdwMRAthzncn{@\ngGU@DPdwMRAthzncn}@\ngGU@DPdwMRAthzncv{@\ngGU@DPdwMRAthzncv}@\ngGU@DPdwMRAthzshiK]G]z\ngGU@DPdwMRAthzshiK]Gmz\ngGU@DPdwMRAthzshis]Gmv\ngGU@DPdwMRAuhyj\ngGU@DPdwMRAuhyk^Wh\ngGU@DPdwMRAuhykgQRT\ngGU@DPdwMRAuhykgQRV|oP\ngGU@DPdwMRAuhykgQSd\ngGU@DPdwMUMAuhyk^TH<\ngGU@DPdwMUMAuhyk^TH>\ngGU@DPdwMUMAuhyk^Wp<\ngGU@DPdwMUMAuhyk^Wp>\ngGU@DPdwMUMAuhykgQRV|hP<\ngGU@DPdwMUMAuhykgQRV|hP>\ngGU@DPdwMUMAuhykgQSf|hP<\ngGU@DPdwMUMAuhykgQSf|hP>\ngGU@DPdwMUMAuhym^TH<\ngGU@DPdwMUMAuhym^TH>\ngGU@DPdwS@AuHwQw]`\ngGU@DPdwS@AuIWHvmg]v\ngGU@DPdwSRAtiZnQm[N{t\ngGU@DPdwSUMAuhykgQSf|hP<\ngGU@DPdwSUMAuhykgQSf|hP>\ngGU@E`dsMTAtXiKVzHZG}h`=\ngGU@E`dsMTAtXiKVzH[{}h`\ngGU@E`dsMTAtXiKWNbdmtPww{Q@\ngGU@E`dsMTAtXiKWNbgMtPtO{Q@\ngGU@E`dsMTAtXiKWNbgMtPww{Q@\ngGU@E`dsMTAtXiKZzHZG}h`\ngGU@E`dsMTAtXiK[NbdmtPtO{Q@\ngGU@E`dsMTAtXiK[NbgMtPtO{Q@\ngGU@E`dsMTAtXiMZzHZG}h`=\ngGU@E`dsMTAthjshiK]G]{~tP\ngGU@E`dsMTAthjshis]Gm{~tP\ngGU@E`dwSTAtXyKVzHZG}i`=\ngGU@E`dwSTAtXyKWNbgMtPtO{S@\ngGU@E`dwSTAtXyK[NbgMtPtO{S@\ngGU@LPdmUTAuhik^TH\ngGU@h`NdiMtp@]RMt]w_{R@=\ngGUACPYRYjV@ztTynmt}@\ngGUADPYR[fi@zT]YtTencn}@\ngGUADPYR[fi@zT]YtTencv}@\ngGUADPYR[fjf`zt\\uoJD<\ngGUADPYR[fjf`zt\\uoJD>\ngGUADP^R[fi@zT]WQw^`\ngGUAE`iRYff@zLTekgQSfzOZG}h`\ngGUAE`iR[ij@zL\\ek]DMC~tp=\ngGUAE`iR[ij@zL\\fm]DMC~tp=\ngGUAIQIRZZj@zLTyKdqSdmu`dH\ngGUDLT@b^BSRuPGVbfmyP\x7Fdd\\P\ngGUDLT@b^BSRuPGVbfuyP`\ngGUDLTHb^BSSPPGRSV~vsna@\ngGUDLTHb^BSSPPGRSZ~vsna@\ngGUHEjICHiCUPGRbT\ngGUHeaZCS^RYfj@ztTfshiK]DM}~tP\ngGX@@dmMTAuXirVm}`dMB\ngGX@@dmUTAuXirVm}`dMB\ngGX@@dmUTAuXirVnRFJ\\wvBPtH\ngGX@@dmUTAuXirVn\\FI[{AH[x\ngGX@@dmUTAuXirVn\\FJ[{AHZD\ngGX@@dmUTAuXirVu}`dMB\ngGX@@dmUTAuXirVv\\FI[{AHZD\ngGX@@dmUTAuXirZu}`dMB\ngGX@@dmUUDauXirVn\\FJ[{AH[x<\ngGX@@dmUUDauXirVn\\FJ[{AH[x>\ngGX@@dmUUDauXirVv\\FJ[{AHZD>\ngGX@@dsD@AnQo[N{l=\ngGX@@dsD@AnQo[N{t\ngGX@@dsD@AnQo[O[t=\ngGX@@dsD@AnQo]N{l=\ngGX@@dsD@AnQo]N{t\ngGX@@dsD@AnQo]O[t=\ngGX@@dsD@AnQw[N{l=\ngGX@@dsD@AnQw]N{l=\ngGX@@dsD@As`qK\\cnv]wh\ngGX@@dsD@AshiK\\c^z]wh\ngGX@@dsD@Ashis\\c^z^wh\ngGX@@dsDLAuEWHwng]z\ngGX@@dsDLAudek\\c^v^tH\ngGX@@dsDLAudek\\cnv^wp\ngGX@@dsDLAudek_C^wP`\ngGX@@dsDLAudem\\c^v^tH\ngGX@@dsDLAudemgAcfyG]l}hP\ngGX@@dsDLAudemgQRVyF}t}hP\ngGX@@dsM@AthynQwAN{l=\ngGX@@dsM@AthynQwAN{t\ngGX@@dsM@AthynQw^N{l=\ngGX@@dsM@AthyolD{np=\ngGX@@dsM@AthyolD{oP\ngGX@@dsM@AthyolD}oP=\ngGX@@dsM@Athyomx{np=\ngGX@@dsM@Athys`qK\\cnB]wh\ngGX@@dsM@Athys`qK_XIw^`\ngGX@@dsM@AthyshiK\\cnB]wh\ngGX@@dsM@AthyshiK_XIw^`\ngGX@@dsM@AthyshiK_[qw^`\ngGX@@dsM@Athyshis_XI{^`\ngGX@@dsM@AthznQwAN{l=\ngGX@@dsM@AthznQwAN{t\ngGX@@dsM@AthzolD{np=\ngGX@@dsM@AthzolD{oP\ngGX@@dsM@Athzs`qK\\cnB]wh\ngGX@@dsM@Athzs`qK_XIw^`\ngGX@@dsM@AthzshiK\\cnB]wh\ngGX@@dsM@AthzshiK_XIw^`\ngGX@@dsM@AuIWHwmg]v=\ngGX@@dsM@AuIWHwmg]z\ngGX@@dsM@AuIWHwmgmz=\ngGX@@dsM@AuIWHwng]v=\ngGX@@dsM@AuIWHwng]z\ngGX@@dsM@AuIWHwngmz=\ngGX@@dsM@AuIYtTenQo]N{t\ngGX@@dsMLAuXirVmu`tH\ngGX@@dsMLAuXirVm}`gmB\ngGX@@dsMLAuXirVn]EN[kAhP\ngGX@@dsMLAuXirVn]EN[{AOZD\ngGX@@dsMLAuXirVn]EN[{^OZD\ngGX@@dsMLAuXirVu}`gmB\ngGX@@dsMLAuXitVmrNxI{P`\ngGX@@dsMLAuXitVn\\FN[kAhP\ngGX@@dsMLAuhjs_XIw^`\ngGX@@dsMTAtYIKVyF}lahP\ngGX@@dsMTAtYIKVyF}tahP\ngGX@@dsMTAtYIM[IbgI[d[wRFa@\ngGX@@dsMTAuXirVmrNxICP`\ngGX@@dsMTAuXirVm}`dMB\ngGX@@dsMTAuXirVnSENRwH{`dMB\ngGX@@dsMTAuXirVnSENRwvBPtH\ngGX@@dsMUDauXirVn]EN[{AHZD<\ngGX@@dsMUDauXirVn]EN[{AHZD>\ngGX@@dsT`Athyncn{@=\ngGX@@dsT`Athyncn}@\ngGX@@dsT`Athyomt{np=\ngGX@@dsT`Athyomt{oP\ngGX@@dsT`Athys`qK]G]z\ngGX@@dsT`Athys`qK_[iw^`\ngGX@@dsT`AthyshiK_[iw^`\ngGX@@dsT`AuIWHwmg]v=\ngGX@@dsT`AuIWHwmg]z\ngGX@@dsT`AuIWHwmgmz=\ngGX@@dsT`AuIWHwng]v=\ngGX@@dsT`AuIWHwng]z\ngGX@@dsT`AuIWHwngmz=\ngGX@@dsT`AuIWH{mg]v=\ngGX@@dsT`AuIWH{mg]z\ngGX@@dsT`AuIWH{ng]v=\ngGX@@dsT`AuIWH{ng]z\ngGX@@dsT`AuIYpXenQw[N{t\ngGX@@dsT`AuIYpXenQw]N{t\ngGX@@dsT`AuIYtTenQo]N{t\ngGX@@dsT`AuIYtTenQw]N{t\ngGX@@dsTlAtYIKVyF}l}hP\ngGX@@dsTlAtYIKVyF}t}o`\ngGX@@dsTlAtYIKV~F}na@\ngGX@@dsTlAtYIKV~F}va@\ngGX@@dsTlAtYIKWNCGMrN{Y{P`\ngGX@@dsTlAtYIKZyF}l}hP\ngGX@@dsTlAtYIKZyF}t}hP\ngGX@@dsTlAtYIKZyG]l}hP\ngGX@@dsTlAtYIK[NCDm|N{]B\ngGX@@dsTlAtYIK[NCDm|N{mB\ngGX@@dsTlAtiJnQo]O[l\ngGX@@dsTlAtiJnQw]N{t\ngGX@@dsUAHathyolD{np+\ngGX@@dsUAHathyolD{np-\ngGX@@dsUAHathyolD{n\x7FrPJH+\ngGX@@dsUAHathyolD{n\x7FrPJH-\ngGX@@dsUAHathyolD{oP<\ngGX@@dsUAHathyolD{oP>\ngGX@@dsUAHathyolD}oP+\ngGX@@dsUAHathyolD}oP-\ngGX@@dsUAHathyomx{np+\ngGX@@dsUAHathyomx{np-\ngGX@@dsUAHathyomx{n\x7FrPJH+\ngGX@@dsUAHathyomx{n\x7FrPJH-\ngGX@@dsUAHathyomx{oP<\ngGX@@dsUAHathyomx{oP>\ngGX@@dsUAHathys`qK_XIw^`<\ngGX@@dsUAHathys`qK_XIw^`>\ngGX@@dsUAHathys`qK_[qw^`<\ngGX@@dsUAHathys`qK_[qw^`>\ngGX@@dsUAHathys`qs_XI{^`<\ngGX@@dsUAHathys`qs_XI{^`>\ngGX@@dsUAHathyshiK_XIw^`<\ngGX@@dsUAHathyshiK_XIw^`>\ngGX@@dsUAHathyshiK_[qw^`<\ngGX@@dsUAHathyshiK_[qw^`>\ngGX@@dsUAHathzolD{np+\ngGX@@dsUAHathzolD{np-\ngGX@@dsUAHathzolD{oP<\ngGX@@dsUAHathzolD{oP>\ngGX@@dsUAHathzolD}oP+\ngGX@@dsUAHathzolD}oP-\ngGX@@dsUAHathzs`qK_XIw^`<\ngGX@@dsUAHathzs`qK_XIw^`>\ngGX@@dsUAHathzs`qs_XI{^`<\ngGX@@dsUAHathzs`qs_XI{^`>\ngGX@@dsUMHauXirVmu`tH<\ngGX@@dsUMHauXirVmu`tH>\ngGX@@dsUMHauXirVm}`gmB<\ngGX@@dsUMHauXirVn\\FN[{AOZD<\ngGX@@dsUMHauXirVn\\FN[{AOZD>\ngGX@@dsUMHauXirVv\\FN[{AOZD>\ngGX@@dsUMHauXitVmu`tH>\ngGX@@dsUMHauXitVn\\FN[{AOZD<\ngGX@@dsUMHauXitVn\\FN[{AOZD>\ngGX@@dsUMHauhjs_XIw^`<\ngGX@@dsUMHauhjs_XIw^`>\ngGX@@dsUThdauXirVnRFJ\\wvBPtH>\ngGX@@dsUThdauXirVn\\FN[{AHZD<\ngGX@@dsUThdauXirVn\\FN[{AHZD>\ngGX@@dsUThdauXirVn]EN[{AHZD<\ngGX@@dsUThdauXirVn]EN[{AHZD>\ngGX@@dsUThdauXirVu}`dMB<\ngGX@@dsUThdauXirVu}`dMB>\ngGX@@dsUThdauXirVv]EN[{AHZD<\ngGX@@dsUThdauXirVv]EN[{AHZD>\ngGX@@dsUThdauXirVv]EN[{^HZD<\ngGX@@dsUThdauXitVn\\FN[{AHZD<\ngGX@@dsUThdauXitVn\\FN[{AHZD>\ngGX@@dsUThdauXitVu}`dMB<\ngGX@@dsUThdauXitVu}`dMB>\ngGX@@dsUTheAuXirVnRFJRwvBPwp<\ngGX@@dsUTheAuXirVnRFJRwvBPwp>\ngGX@@dsUTheAuXirVnRFJ\\wvBPtH<\ngGX@@dsUTheAuXirVnRFJ\\wvBPtH>\ngGX@@dsUTheAuXirVn\\FN[{AHZD<\ngGX@@dsUTheAuXirVn\\FN[{AHZD>\ngGX@@dsUTheAuXirVn]EN[{AHZD<\ngGX@@dsUTheAuXirVn]EN[{AHZD>\ngGX@@dsUTheAuXirVu}`dMB<\ngGX@@dsUTheAuXirVu}`dMB>\ngGX@@dsUTheAuXirVvZFJ\\eolDahP>\ngGX@@dsUTheAuXirVv]EI[{AHZD<\ngGX@@dsUTheAuXirVv]EN[{AHZD>\ngGX@@dsUTheAuXirZn]EI[{AH[x<\ngGX@@dsUTheAuXitVv\\FN[{AHZD<\ngGX@@dsUTheAuXitVv\\FN[{AHZD>\ngGX@@dsUTiDauXitVn\\FN[{AHZD<\ngGX@@dsUTiDauXitVn\\FN[{AHZD>\ngGX@@dsUTiDauXitVn]EN[{AHZD<\ngGX@@dsUUHauXirVm}`dMB<\ngGX@@dsUUHauXirVm}`dMB>\ngGX@@dsUUHauXirVm}oDMB<\ngGX@@dsUUHauXirVm}oDMB>\ngGX@@dsUUHauXirVnSENRwvBPtH>\ngGX@@dsUUHauXirVnZFJ\\eolDahP<\ngGX@@dsUUHauXirVnZFJ\\eolDahP>\ngGX@@dsUUHauXirVnZFJ\\eomxahP<\ngGX@@dsUUHauXirZu}`dMB<\ngGX@@dsUUHauXirZu}`dMB>\ngGX@@dsUUHauXitVm}`dMB<\ngGX@@dsUUHauXitVm}`dMB>\ngGX@@dsUUHauXitVnRFNRwvBPtH<\ngGX@@dsUUHauXitVnRFNRwvBPtH>\ngGX@@dtuRAuXirVmu`dH\ngGX@@dtuRAuXirVn\\FI[{AH[t\ngGX@@dtuSHauXirVn]EI[kAHP<\ngGX@@dtuSHauXirVn]EI[kAHP>\ngGX@@dtuSHauXirZn]EI[{AH[t>\ngGX@@dtuTAuXirVm}`dMB\ngGX@@dtuTAuXirVm}`dM|\ngGX@@dtuTAuXirVnSENRwvBPtH\ngGX@@dtuTAuXirVnSENRwvBPwp\ngGX@@dtuTAuXirVn\\FI[{AHZD\ngGX@@dtuTAuXirVn\\FI[{AH[x\ngGX@@dtuTAuXirVu}`dMB\ngGX@@dtuTAuXirVv\\FI[{AHZD\ngGX@@dtuUHauXirVm}`guB<\ngGX@@dtuUHauXirVm}`guB>\ngGX@@dtuUHauXirVnRFJRwvBPtH<\ngGX@@dtuUHauXirVnRFJRwvBPtH>\ngGX@@dtuUHauXirVn]EI[{AHZD<\ngGX@@dtuUHauXirVn]EI[{AHZD>\ngGX@@dtuUHauXirVn]EI[{AOjD<\ngGX@@dtuUHauXirVn]EI[{AOjD>\ngGX@@dtuUHauXirVn]GI[{AOjD<\ngGX@@dtuUHauXirVn]GI[{AOjD>\ngGX@@dtuUHauXirZm}`dMB<\ngGX@@dtuUHauXirZm}`dMB>\ngGX@@dtuUHauXirZn\\FI[{AHZD<\ngGX@@dtuUHauXirZn\\FI[{AHZD>\ngGX@@dtuUHauXirZn]EI[{AHZD<\ngGX@@dtuUHauXirZn]EI[{AHZD>\ngGX@@dwATAulek\\cZvPtH\ngGX@@dwATAulek\\cZvPtOyKDd\ngGX@@dwATAulek\\cZzPtH\ngGX@@dwATAulfm\\cZvPtH\ngGX@@dwAULaulekgQSfyFutahP<\ngGX@@dwAULaulekgQSfyFutahP>\ngGX@@dwAULaulem\\cZvPtH<\ngGX@@dwSTAtYYKVyFutahP\ngGX@@dwSTAtYYKVyGUlahP\ngGX@@dwSTAtYYMZyFulahP\ngGX@@dwSTAtYYMZyFutahP\ngGX@@dwSTAtYYMZyGUlahP\ngGX@@dwSTAuXirVmtPtH\ngGX@@dwSULatYYKWNbgMrMkiCP`<\ngGX@@dwSULatYYKWNbgMrMkiCP`>\ngGX@@dwSULatYYKWNbgMrNkiCP`>\ngGX@@dwSULatYYKZyFulahP<\ngGX@@dwSULatYYKZyFulahP>\ngGX@@dwSULauXirVn\\EN[hahP>\ngGX@@dwSULauXirVv]EN[y]HZD<\ngGX@@eMUTAtpqSdm[eApRFa@\ngGX@@eMUTAtpqSdm[eApRFa\x7FIHxv`@\ngGX@@eMUTAtpqSdm[eApRFa\x7FZ@\ngGX@@eMUTAtpqSdm[eApRF~\x7FZ@\ngGX@@eMUTAtpqSdm\\dLTynTGAHZG}h@\ngGX@@eMUTAtpqSdm\\xLTwJC`dMB\ngGX@@eMUTAtpqSdm\\xLTwJC`dMC~t@\ngGX@@eMUTAtpqSdm\\xLTwJ}`dMB\ngGX@@eMUTAtpqSdmkeApRFa@\ngGX@@eMUTAtpqSdmkeApRFa\x7FZ@\ngGX@@eMUTAtpqSdmlxLRwJC`dMC~t@\ngGX@@eMUTAtpqSdukeApRFa\x7FZ@\ngGX@@eMUTAtpqSdulxLTwJC`dMC~t@\ngGX@@eMUTAtpqShukeApRFa@\ngGX@@eMUTAtpqShukeApRFa\x7FZ@\ngGX@@eMUTAtpqUdm[eApRFa@\ngGX@@eMUTAtpqUdm[eApRFa\x7FZ@\ngGX@@eMUTAtpqUdm\\xLTwJC`dMB\ngGX@@eMUTAtpqUdm\\xLTwJC`dMC~t@\ngGX@@eMUTAtpqUdmkeApRFa\x7FZ@\ngGX@@eMUUHatpqSdu[eApRF~\x7FZ@<\ngGX@@eMUUHatpqSdu[eApRF~\x7FZ@>\ngGX@@eSU@AuAWJwmg]w~t@=\ngGX@@eSU@AuAWJwmg]{~t@=\ngGX@@eSU@AuAWJwmgm{~t@=\ngGX@@eSU@AuAWJwng]w~t@=\ngGX@@eSU@AuAWJwng]{~t@\ngGX@@eSU@AuAWJwngm{~t@=\ngGX@@eSU@AuAWJ{ng]w~t@=\ngGX@@eSU@AuAWJ{ng]{~t@=\ngGX@@eSU@AuAWJ{ngm{~t@=\ngGX@@eSU@AuAYpTenUo]N{w}h@\ngGX@@eSU@AuAYpXenUw]N{w}h@\ngGX@@eSU@Au`is\\hNB]w_yJEFt@=\ngGX@@eSU@Au`is\\hNB]w_{P@=\ngGX@@eSU@Au`is\\hNB]wh\ngGX@@eSU@Au`is\\hNB]woyJEFt@=\ngGX@@eSU@Au`is\\hNB]wo{P@=\ngGX@@eSU@Au`is\\hNB^wh=\ngGX@@eSU@Au`is\\hNB^wo{P@=\ngGX@@eSU@Au`is\\hN|]w_yJEFt@=\ngGX@@eSU@Au`is\\hN|]w_{P@=\ngGX@@eSU@Au`is\\hN|]wo{P@\ngGX@@eSU@Au`is\\hN|^wo{P@=\ngGX@@eSU@Au`isfabgI[eApSv}@=\ngGX@@eSU@Au`isfabgI[eApSv}\x7FZ@=\ngGX@@eSU@Au`isgARVyP]x{o_v`@\ngGX@@eSU@Au`isgAbVyP\\D{o_v`@\ngGX@@eSU@Au`isgAcfyP\\D}o_v`@\ngGX@@eSU@Au`iu\\hNB]w_{P@=\ngGX@@eSU@Au`iu\\hNB]wo{P@\ngGX@@eSU@Au`iu\\hNB^wo{P@=\ngGX@@eSU@Au`iugARVyP\\D{o_v`@\ngGX@@eSU@Au`iugAbVyP\\D{o_v`@\ngGX@@eSU@Au`js\\hN|]w_{P@=\ngGX@@eSU@Au`ju\\hNB]w_{P@=\ngGX@@eSU@Au`ju\\hNB]wh\ngGX@@eSU@Au`ju\\hNB]wo{P@=\ngGX@@eSU@Au`ju\\hNB^wh=\ngGX@@eSU@Au`ju\\hNB^wo{P@=\ngGX@@eSU@Au`jufabgI[eApSv}@=\ngGX@@eSU@Au`jugAbVyP\\D{o_v`@\ngGX@@eSU@Au`jugAcfyP\\D}o_v`@\ngGX@@eSUA@au`is\\hN|^wh-\ngGX@@eSUA@au`isgARVyP]x{oP<\ngGX@@eSUA@au`isgARVyP]x{oP>\ngGX@@eSUA@au`isgAbVyP\\D{oP<\ngGX@@eSUA@au`isgAbVyP\\D{oP>\ngGX@@eSUA@au`isgAcfyP\\D}oP<\ngGX@@eSUA@au`isgAcfyP\\D}oP>\ngGX@@eSUA@au`iugARVyP\\D{oP<\ngGX@@eSUA@au`iugARVyP\\D{oP>\ngGX@@eSUA@au`iugASfyP\\D}oP<\ngGX@@eSUA@au`iugASfyP\\D}oP>\ngGX@@eSUA@au`jugAbVyP\\D{oP<\ngGX@@eSUA@au`jugAbVyP\\D{oP>\ngGX@@eSULAtPrSfyP\\D}o_v`@=\ngGX@@eSULAtaRnUw]N{w}h@=\ngGX@@eSULAtpqSdm[eApSva\x7FZ@=\ngGX@@eSULAtpqSdm[yApZG}h@=\ngGX@@eSULAtpqSdm[yAwjG}h@\ngGX@@eSULAtpqSdm\\dLTenTGAOZG}h@=\ngGX@@eSULAtpqSdm\\tLTyK_HNCP\x7Fm@=\ngGX@@eSULAtpqSdm\\xLRwJC`gmC~t@\ngGX@@eSULAtpqSdm\\xLRwrC`tO{P@\ngGX@@eSULAtpqSdm\\xL\\wJC`gmC~t@\ngGX@@eSULAtpqSdm\\xL\\wrC`tO{P@\ngGX@@eSULAtpqSdmkeApSva\x7FZ@=\ngGX@@eSULAtpqSdmkyApZG}h@=\ngGX@@eSULAtpqSdmltLTyK\\hNB^tO{P@=\ngGX@@eSULAtpqSdmlxL\\wJC`gmC~t@\ngGX@@eSULAtpqSdmlxL\\wrC`tO{P@\ngGX@@eSULAtpqShm[yApZG}h@\ngGX@@eSULAtpqShm\\xL\\wJC`gmC~t@\ngGX@@eSULAtpqShm\\xL\\wrC`tO{P@\ngGX@@eSULAtpqShmkeApSva\x7FZ@\ngGX@@eSULAtpqShmkyApZG}h@\ngGX@@eSULAtpqShmlxL\\wJC`gmC~t@\ngGX@@eSULAtpqShmlxL\\wrC`tO{P@\ngGX@@eSULAtpqUdm\\xJ\\wJCoGmC~t@\ngGX@@eSUTAtQQKVyV}lah_v`@=\ngGX@@eSUTAtQQKVyV}tah_v`@\ngGX@@eSUTAtQQKVyW]tah_v`@=\ngGX@@eSUTAtpqSdm[eApRFa@\ngGX@@eSUTAtpqSdm[eApRFa\x7FIPhv`@=\ngGX@@eSUTAtpqSdm[eApRFa\x7FIXdv`@=\ngGX@@eSUTAtpqSdm[eApRFa\x7FZ@=\ngGX@@eSUTAtpqSdm[eAwbFa\x7FZ@\ngGX@@eSUTAtpqSdm\\dL\\enTGAHZG}h@\ngGX@@eSUTAtpqSdm\\tLTyK\\hNBPtH\ngGX@@eSUTAtpqSdm\\tLTyK\\hNBPtO{P@=\ngGX@@eSUTAtpqSdukeApRFa@\ngGX@@eSUTAtpqSdukeApRFa\x7FZ@=\ngGX@@eSUTAtpqShm[eApRFa\x7FZ@\ngGX@@eSUTAtpqShm\\dL\\enTGAHZG}h@\ngGX@@eSUT`hatpqSdm\\dL\\enTGAH[x>\ngGX@@eSUT`hatpqSdm\\xLRwJC`dM|>\ngGX@@eSUT`hatpqSdm\\xL\\wJC`dMB<\ngGX@@eSUT`hatpqSdm\\xL\\wJC`dMB>\ngGX@@eSUT`hatpqSdmlxL\\wJC`dMB<\ngGX@@eSUT`hatpqSdmlxL\\wJC`dMB>\ngGX@@eSUT`hatpqSdulxL\\wJC`dMB<\ngGX@@eSUT`hatpqSdulxL\\wJC`dMB>\ngGX@@eSUT`hatpqShm\\xJ\\wJC`dMB>\ngGX@@eSUT`hatpqShmlxJ\\wJC`dMB<\ngGX@@eSUT`iAtpqSdm\\xL\\wJC`dMB<\ngGX@@eSUT`iAtpqSdm\\xL\\wJC`dMB>\ngGX@@eSUT`iAtpqSdmldL\\enTGAHZD>\ngGX@@eSUT`iAtpqSdmlxLRwJC`dMB<\ngGX@@eSUT`iAtpqSdmlxLRwJC`dMB>\ngGX@@eSUT`iAtpqSdmlxL\\wJC`dMB<\ngGX@@eSUT`iAtpqSdu\\xLRwJC`dM|<\ngGX@@eSUT`iAtpqSdu\\xLRwJC`dM|>\ngGX@@eSUT`iAtpqShm\\xJ\\wJC`dMB<\ngGX@@eSUU@atpqSdm\\dL\\enTGAHZD<\ngGX@@eSUU@atpqSdm\\dL\\enTGAHZD>\ngGX@@eSUU@atpqShm[eApRFa@<\ngGX@@eSUU@atpqShm[eApRFa@>\ngGX@@eSUUHatQQKWNCGMrn{iCP\x7Fm@<\ngGX@@eSUUHatQQKZyV}lah_v`@+\ngGX@@eSUUHatpqSdm[eApRF~\x7FZ@+\ngGX@@eSUUHatpqSdm[eApRF~\x7FZ@-\ngGX@@eSUUHatpqSdm\\dLTynTGAHZD<\ngGX@@eSUUHatpqSdm\\dLTynTGAHZD>\ngGX@@eSUUHatpqSdm\\dL\\enTGAH[{}h@<\ngGX@@eSUUHatpqSdm\\tLTyK\\hNBPwp<\ngGX@@eSUUHatpqSdm\\tLTyK\\hNBPwp>\ngGX@@eSUUHatpqSdm\\xJ\\wJCoDMC~t@<\ngGX@@eSUUHatpqSdm\\xJ\\wJCoDMC~t@>\ngGX@@eSUUHatpqSdm\\xLRwJC`dM}~t@<\ngGX@@eSUUHatpqSdm\\xLRwJC`dM}~t@>\ngGX@@eSUUHatpqSdm\\xL\\wJC`dMC~t@<\ngGX@@eSUUHatpqSdm\\xL\\wJC`dMC~t@>\ngGX@@eSUUHatpqSdm\\xL\\wJC`dM}~t@<\ngGX@@eSUUHatpqSdmkeApRFa@<\ngGX@@eSUUHatpqSdmkeApRFa@>\ngGX@@eSUUHatpqSdmkeApRFa\x7FZ@+\ngGX@@eSUUHatpqSdmkeApRFa\x7FZ@-\ngGX@@eSUUHatpqSdmldLTynTGAHZD<\ngGX@@eSUUHatpqSdmldLTynTGAHZD>\ngGX@@eSUUHatpqSdmltLTyK\\hNBPtH<\ngGX@@eSUUHatpqSdmltLTyK\\hNBPtH>\ngGX@@eSUUHatpqSdmltLTyK\\hNBPtO{P@+\ngGX@@eSUUHatpqSdmltLTyK\\hNBPtO{P@-\ngGX@@eSUUHatpqSdmlxLRwJC`dMC~t@<\ngGX@@eSUUHatpqSdmlxLRwJC`dMC~t@>\ngGX@@eSUUHatpqSdmlxL\\wJC`dMC~t@<\ngGX@@eSUUHatpqSdmlxL\\wJC`dMC~t@>\ngGX@@eSUUHatpqSdu\\tLTyK\\hNBPwp>\ngGX@@eSUUHatpqSdu\\xLRwJC`dM}~t@<\ngGX@@eSUUHatpqSdulxL\\wJC`dMC~t@>\ngGX@@eSUUHatpqShm\\xJ\\wJC`dMC~t@<\ngGX@@eSUUHatpqShm\\xJ\\wJC`dMC~t@>\ngGX@@eSUUHatpqShm\\xL\\wJC`dMC~t@<\ngGX@@eSUUHatpqShm\\xL\\wJC`dMC~t@>\ngGX@@eSUUHatpqShmkeApRFa\x7FZ@>\ngGX@@eSUUHatpqShmlxJ\\wJC`dMC~t@<\ngGX@@eSUUHatpqShmlxJ\\wJC`dMC~t@>\ngGX@@eSUUHatpqShmlxLRwJC`dMC~t@<\ngGX@@eSUUHatpqShmlxLRwJC`dMC~t@>\ngGX@@eSUUHatpqShmlxL\\wJC`dMC~t@<\ngGX@@eSUUHatpqShmlxL\\wJC`dMC~t@>\ngGX@@eSUUHatpqShulxL\\wJC`dMC~t@<\ngGX@@eSUUHatpqShulxL\\wJC`dMC~t@>\ngGX@@e]MTAtpqSdm[f]pRFa\x7FZ@\ngGX@@e]MTAtpqSdm[{AHZG}h@\ngGX@@e]MTAtpqSdm\\xLTwL{`dMC~t@\ngGX@@e]MTAtpqSdmk{AHZG}h@\ngGX@`IWITtp@]PUrm{Y{^\x7Fm@=\ngGX@`IWITtp@]PUrm{i{^\x7Fm@=\ngGX@`IWITtp@]XJ\\wvB^wo{P@=\ngGX@`NtiMtu@]FVSVnQm[HZD\ngGXA@IRVjj@zlTyKV~pRFa@\ngGXA@IRVjj@zlTyKWICEN[{AHZD\ngGXA@IRVjj@zlTyKWNCEM}`dMB\ngGXA@IRYb@@wH{mg]v=\ngGXA@IRYb@@wH{ng]v=\ngGXA@IRYb@@ypXenQw[N{t\ngGXA@IRYb@@ypXynQw[O[t\ngGXA@IRYb@@ypXynQw]O[t\ngGXA@IRYf`@zT\\wH{`g]v=\ngGXA@IRYf`@zdkd[vsn{@=\ngGXA@IRYjP@zdkd[vsn{@=\ngGXA@IRYjP@zdkd[wSn{@=\ngGXA@IRYjP@zdkd]vsn{@=\ngGXA@IRYjP@zdkd]wSn{@=\ngGXA@IRYj`dPzT\\wvB]wX+\ngGXA@IRYj`dPzT\\wvB]wX-\ngGXA@IRYj`dPzT\\wvB]wh<\ngGXA@IRYj`dPzT\\wvB]wh>\ngGXA@IRYj`dPzT\\ypXeolD{oP<\ngGXA@IRYj`dPzT\\ypXeolD{oP>\ngGXA@IRYj`dPzT]WvB]wX+\ngGXA@IRYj`dPzT]WvB]wX-\ngGXA@IRYjfdPzlTzKWNCGM}`gmB<\ngGXA@IRYjfdPzlTzKWNCGM}`gmB>\ngGXA@IRYjjTR`zlTyKWNCGM}`dMB>\ngGXA@IRYjjdPzlTyKV~pRFa@<\ngGXA@IRYjjdPzlTyKV~pRFa@>\ngGXA@IRZZi@zlTyKWNCDm}`dMz\ngGXA@IRZZj@zlTyKV~pRFa@\ngGXA@IRZZj@zlTyKV~pRF~@\ngGXA@IRZZj@zlTyKWIbgI[d^pRF~@\ngGXA@IRZZj@zlTyKWIbgI[{AHZD\ngGXA@IRZZj@zlTyKWNCDm}`dMB\ngGXA@IRZZjdPzlTyKWICEI[{AHZD<\ngGXA@IRZZjdPzlTyKWICEI[{AHZD>\ngGXA@IRZZjdPzlTyKWNbdm}`dMB<\ngGXA@IRZZjdPzlTyKWNbdm}`dMB>\ngGXA@IRfjj@zXXirVmr`xICP`\ngGXA@IRfjj@zXXirVn\\FJ[e^pRFa@\ngGXA@IRih@@wJwmg]w~t@=\ngGXA@IRih@@wJwng]w~t@=\ngGXA@IRih@@wJ{ng]w~t@=\ngGXA@IRihF@ztRunUo[OZG}h@=\ngGXA@IRii`@z`ke[vsn{\x7FZ@=\ngGXA@IRii`@z`ke[vsn}\x7FZ@\ngGXA@IRii`@z`ke[vsv}\x7FZ@=\ngGXA@IRii`@z`ke]vsv}\x7FZ@=\ngGXA@IRii`@z`ke]wSn{\x7FZ@=\ngGXA@IRii`@z`ke]wSv}\x7FZ@=\ngGXA@IRii`@zpTynUwAN{o}h@=\ngGXA@IRii`@zpTynUwAO[w}h@=\ngGXA@IRii`@zpTynUw^O[w}h@=\ngGXA@IRii`@zpTyolD{o_v`@\ngGXA@IRii`@zpTyolD}o_v`@=\ngGXA@IRii`@zpTznUwAN{o}h@=\ngGXA@IRij`@zpTynTGAN{l=\ngGXA@IRij`@zpTynTGAN{t\ngGXA@IRijj@zXXirVmr`xICP`\ngGXA@IRijj@zXXirVnZFJ\\enTGAHZD\ngGXA@IRijjPTPzXXirVn\\FN[eApRFa@<\ngGXA@IRijjPT`zXXirVn\\FN[eApRFa@>\ngGXA@IRijjdPzXXirVnRFJ\\wJC`dMB<\ngGXA@IRijjdPzXXirVur`xICP`>\ngGXA@IRjZj@zXXirVmr`xICP`\ngGXA@IRjZj@zXXirVnRFJRwJC`dMB\ngGXA@IRjZj@zXXirVnRFJRwJC`dM|\ngGXA@IRjZj@zXXirVn\\FI[eApRFa@\ngGXA@IRjZj@zXXirVur`xICP`\ngGXA@IRjZj@zXXirVv\\FI[eApRFa@\ngGXA@IRkfj@zHdek\\s^vPtO{P@\ngGXA@IRkfj@zHdek\\s^zPtO{P@\ngGXA@IRkfj@zHdek\\snvPtO{P@\ngGXA@IRkfj@zHdek\\snzPtO{P@\ngGXA@IRkfj@zXXirVmsNxICP\x7Fm@\ngGXA@IRkfj@zXXirVm}`dMC~t@\ngGXA@IRnfj@zXXirVn\\FJ[f]pRFa\x7FZ@\ngGXA@NRYjP@zdkd[vsn{@=\ngGXA@NRYjP@zdkd[wSn{@=\ngGXA@NRYjV@zLdem\\c^v^tH\ngGXA@NRZZj@zlTyKWIbgI[{AHZD\ngGXAAiR[ij@zLlemgARVyGUlahP>\ngGXAAiR[ij@zLlemgARVyGUtahP>\ngGXAAiR[ij@zLlfkgASfyGUlao`>\ngGXAAiR[ij@zLlfm\\cZvPtH\ngGXAAiR[ij@zLlfm\\cZzPtH\ngGXAAiR[ij@zLlfmgASfyGUlahP>\ngGXAAiR[ij@zLlfmgASfyGUtahP>\ngGXD@jCTBUMT@GTC]G]w~t@=\ngGXDAjBtFRPrj`NjFJ\\eohEAHP>\ngGXDD@`aBS]MHGRejyFul{np\ngGXDD@`aBS]MHGRejyFul{oP\ngGXDD@b^BSRuPGUbgQjwvBPtO{Q@\ngGXDH@aABS]T@GTc\\cr|]w_{R@=\ngGXDH@aABS]T@GTc\\cr|]wo{R@=\ngGXDHGANBS]T@GTc\\cr|^wh=\ngGXDHGANBS]T@GTc\\cr|^woyHFD=\ngGXDHHQPbS]T@GTc]Gmz=\ngGXDHHQPbS]T@GTc]Gm{~RAa@=\ngGXDHO@~BUMUTbGUCEVjwrC`tH<\ngGXDHO@~BUMUTbGUCEVjwrC`tH>\ngGXDHOANBRtuPGUbgIZwvBPtO{R@\ngGXDHOA^BS]T@GTc]G]w~RAamH=\ngGXDHOA^BS]T@GTc]G]w~t`=\ngGXDHOA^BS]T@GTc]Gmz=\ngGXDHOA^BS]T@GTc]Gm{~RAa@=\ngGXDHOA^BS]UPGQcdm[d^WbFa\x7FI@pvd@=\ngGXDJDR^BSRuPGQbgI[kAHP\ngGXDJIARBSWUPGVcdmx_@\ngGXDL@aABS\\uPGQcdm[hah_vf@=\ngGXDL@bABUuUTRGQBdm\\dLTynbFa@<\ngGXDL@bABUuUTRGQBdm\\dLTynbFa@>\ngGXEHOA^BeIZZhCjqShuk{AHZG}i@\ngGXEHOA^DeInZ@CjQoat}o_rPLMi@=\ngGXEL@aAByInZhChqrVmtPtO{S@=\ngGXEaJAT@f\\nRfjj@zhXzMZyWlDahP\ngGXHAJAIfj@CiQs_XIw]`+\ngGXHAJAIfj@CiQs_XI{^`+\ngGXHAJAIfj@CiQu_XIw]`+\ngGXHAJAIfj@CiQu_XI{^`+\ngGXHAJAIfj@CiQugAbV~pSn}@>\ngGXHAJAIfj@CiQugAcf~pSv}@>\ngGXHAJAIfjXCkQUkNCGM}`gmv>\ngGXHAJAIfjhCjqSdm\\fJ\\eolDahP>\ngGXHAjAJfj@CiAS\\hN|]w_{P@=\ngGXHAjAJfj@CiAS\\hN|^wo{P@=\ngGXHAjAJfj@CiAS_HIw]\x7Fm@=\ngGXHAjAJfj@CiAS_HI{^\x7Fm@=\ngGXHAjAJfj@CiAU_HIw]\x7Fm@=\ngGXHAjAJfjBACiAS_HI{^`+\ngGXHAjAJfjBACiAS_HI{^`-\ngGXHAjAJfjBACiAU_HI{^`+\ngGXHAjAJfjBACiAU_HI{^`-\ngGXHAjAJfjXCjabhmlxJ\\wrCoTO{P@\ngGXHAjAJfjjACjabdm[yAHZD<\ngGXHAjAJfjjACjabdm[yAHZD>\ngGXHAjCIHYUPGSCENRunXEAHZD\ngGXHAjCIHYUPGSCENRusPqSdms@hICP\x7Fm@=\ngGXHB@aIfi@CjRnQo[N{l\ngGXHB@aIfi@CjRnQo[N{t\ngGXHB@aIfi@CjRnQo]N{l\ngGXHB@aIfiXCiRU\\c^v]wh\ngGXHB@aIfiXCkRSV~F}na@\ngGXHB@aIfidCiRU\\c^v^wX\ngGXHB@aIfidCiRU\\c^v^wh\ngGXHB@aIfidCkRSV~F}n}@\ngGXHB@aIfjBQCiQsgAbV~pSn}@>\ngGXHB@aIfjiQJChqSfn]EN[kAhP<\ngGXHB@aInfjZCkRsV~Funa@<\ngGXHB@aInfjZCkRsV~Funa@>\ngGXHBOAJfj@CkAUjyP\\D{np\ngGXHBOAJfjdCjabgM\\dLTeodGAoP\ngGXHD@aIfZhCjqSdm[{AHZG}h`=\ngGXHD@aIfZhCjqSdm\\zJ\\wvBPtO{Q@\ngGXHD@aIfZhCjqShm[{AHZG}h`=\ngGXHD@aIfZhCjqShm\\zJ\\wvBPtO{Q@\ngGXHD@aIfZhCjqShmk{AHZG}h`\ngGXHD@aIfihChrRVmrM{YCP\x7FmD=\ngGXHD@aIfihChrRVmrM{iCP`=\ngGXHD@aIfihChrRZurM{YCP\x7FmD=\ngGXHD@aIfihCiRU\\c^v]w_{Q@=\ngGXHD@aIfjjQCjqShmlxL\\wvBPtO{Q@>\ngGXHD@aIkjjQChqrVn\\gI[hahP<\ngGXHD@aIkjjQChqrVn\\gI[hahP>\ngGXHD@aInZ@CjQncn{@=\ngGXHD@aInZ@CjQncn}@\ngGXHD@aInZ@CjQshiK]G]z\ngGXHD@aInZXChqrVmt^tH\ngGXHD@aInZXChqrVmyP`\ngGXHD@aInZhChqrVmtPtH\ngGXHD@aInf@CjQncn{@=\ngGXHD@aInf@CjQncn}@\ngGXHD@aInf@CjRnQm[N{l=\ngGXHD@aInf@CjRnQm[N{t\ngGXHD@aInf@CjRnQm[O[t=\ngGXHD@aInf@CjRshiK\\cZz]wh\ngGXHD@aInfXChrrVm|Mk]B\ngGXHD@aInfXCiRu\\cZv^wh\ngGXHD@aInjBQCjQncn{@+\ngGXHD@aInjBQCjQncn{@-\ngGXHD@aInjBQCjQncn}@>\ngGXHDDQInf@CjRnQm[N{l=\ngGXHDOAInjBQCjQoax{np+\ngGXHDOAInjBQCjQoax{np-\ngGXHH@aIZjhCjqSdm[d^pRFa\x7FZP\ngGXHH@aIZjhCjqSdmk{AHZG}i@\ngGXHH@aIfj@CiQs\\cvB]w_{R@=\ngGXHH@aIfj@CiQs\\cvB]wo{R@\ngGXHH@aIfj@CiQsgAbVyGlD{o_vd@\ngGXHH@aIfj@CiQsgQRVyGlD{o_vd@\ngGXHH@aIfj@CiQsgQSfyGlD}o_vd@\ngGXHH@aIfj@CiQu\\cvB]w_{R@=\ngGXHH@aIfjXCjqSdm[d^pSva\x7FZP\ngGXHH@aIfjXCjqSdm\\xL\\wH}`gmC~t`\ngGXHH@aIfjXCjqSdmlzJ\\wp}`tO{R@\ngGXHH@aIfjXCkQUgNCDmrOXI{^\x7FmH\ngGXHH@aIfjXCkQUgNbgMrOXI{^\x7FmH\ngGXHH@aIfjhCjqSdm[d^pRFa\x7FZP\ngGXHH@aIfjhCjqSdm[{AHZG}i@\ngGXHH@aIfjhCjqSdm\\fJ\\enQ{AHZG}i@\ngGXHH@aIfjjICjqSdm\\zJ\\wH}`dMC~t`<\ngGXHH@aIfjjICjqSdm\\zJ\\wH}`dMC~t`>\ngGXHH@aIfjjICjqSdmlzJRwH}`dMC~t`>\ngGXHH@aIfjjICjqSdmlzJ\\wH}`dMC~t`<\ngGXHH@aIfjjICjqSdmlzJ\\wH}`dMC~t`>\ngGXHH@aIfjjICjqSdulzJ\\wH}`dMC~t`>\ngGXHH@aIfjjICjqShm\\zJ\\wH}`dMC~t`<\ngGXHH@aIfjjICjqShm\\zJ\\wH}`dMC~t`>\ngGXHH@aJnZBACiAu_XIw]`+\ngGXHH@aJnZBACiAu_XIw]`-\ngGXHHGAIfj@CiQs\\cvB]w_{R@=\ngGXHHGAIfj@CiQs\\cvB^wo{R@=\ngGXHHGAIfj@CiQs_XI{^\x7FmH=\ngGXHHGAIfjXCjqShm\\xLRwp}`tO{R@\ngGXHHGAIfjXCjqShm\\xL\\wVCP\x7FmH\ngGXHHGAIfjXCjqShm\\xL\\wp}`tO{R@\ngGXHHGAIfjhCjqSdm[d^pRFa\x7FZP\ngGXHHGAIfjhCjqSdm[{AHZG|dBcZP\ngGXHHOAIZZhCjqSdm[{AHZG}i@\ngGXHHOAIZjhCjqSdm[d^pRFa\x7FZP\ngGXHHOAIZjhCjqSdm[{AHZD\ngGXHHOAIfj@CiQs\\cvB]w_{R@=\ngGXHHOAIfj@CiQs\\cvB^wo{R@=\ngGXHHOAIfj@CiQs_XIw]\x7FmH=\ngGXHHOAIfj@CiQs_XI{^\x7FmH=\ngGXHHOAIfjBQCiQs_XI{^`+\ngGXHHOAIfjBQCiQs_XI{^`-\ngGXHHOAIfjhCjqSdm[d^pRFa\x7FZP\ngGXHHOAIfjhCjqSdm[{AHZG}i@\ngGXHHOAIfjjICjqSdmkd^pRFa\x7FZP<\ngGXHHOAIfjjQCjqSdm[{AHZD<\ngGXHHOAIfjjQCjqSdm[{AHZD>\ngGXHHOAJkZhCjaSdm[f]pRFa@\ngGXHHOAJkZhCjaSdm[{AHZD\ngGXHHOAJnjBACiAu_XIw]`+\ngGXHHOAJnjBACiAu_XIw]`-\ngGXHHOAJnjjACjaSdm[{AHZD<\ngGXHHOAJnjjACjaSdm[{AHZD>\ngGXHL@aJZjhCjabdm[yAHZD\ngGXH`Z@R^RjZj@zhXisV~P\\Fa@\ngGXH`Z@R^RjZj@zhXisWICEI[yApZD\ngGXHaJ@SNRYj`@zT]WvB^wh+\ngGXHaJ@SNRZZj@zlTyKV~pRFa@\ngGXHaJ@SNRZZjdPzlTyMV~pRFa@<\ngGXHaJ@SNRZZjdPzlTyMV~pRFa@>\ngGXHaj@SnRii`@zPTwJ{oG]w~t@=\ngGXHaj@SnRii`@zPTwJ{oGm{~t@=\ngGXHaj@SnRii`@zPTwv|]w_{P@=\ngGXHaj@SnRii`@zPTwv|]wo{P@\ngGXHaj@SnRii`@zPTwv|^wo{P@=\ngGXHaj@SnRii`@zPTypTeomx{o_v`@\ngGXHaj@SnRkfj@zhXiKVyg]xah_rPJMh@\ngGXHaj@SnRkfj@zhXiKV~wbFa\x7FZ@\ngGXHhG@]IR[ij@zlTyKV~WRFa\x7FI@pvd@\ngGXI@Z@ReTuTAuPqSfm|`xMB\ngGXIAjC\\eSU@At`inTG^N{o}h@=\ngGXIDHaRdmUTAuXirVm}`dMB\ngGXIHDPReWU@At`zolD{np+\ngGXIHO@ReUuTAuPirVm}`dMB\ngGXIHOBRdmMTAuXirVm}`dMC~t`\ngGXIHOBRdsMTAuXirVm}`dMC~t`\ngGXLJIARFdLbdMU@]JIP\ngGX`BDdwM@AuHwQw]`\ngGX`BDdwM@AuHwQw^`\ngGX`BDdwMLAthzncn{@\ngGX`BDdwMLAthzncn}@\ngGX`BDdwMLAuhyk]GmB\ngGX`BDdwMLAuhyk^TH\ngGX`BDdwMLAuhym]GmB\ngGX`BDdwMLAuhym^TH\ngGX`BDdwMRAthzncn{@\ngGX`BDdwMRAthzncn}@\ngGX`BDdwMRAthzncv{@\ngGX`BDdwMRAthzncv}@\ngGX`BDdwMRAthzshiK]Gmz\ngGX`BDdwMRAuhyj\ngGX`BDdwMRAuhyk^Wh\ngGX`BDdwMRAuhykgQRT\ngGX`BDdwMRAuhykgQRV|oP\ngGX`BDdwMUMAuhyk^TH<\ngGX`BDdwMUMAuhyk^TH>\ngGX`BDdwMUMAuhyk^Wp<\ngGX`BDdwMUMAuhyk^Wp>\ngGX`BDdwMUMAuhykgQRV|hP>\ngGX`BDdwMUMAuhykgQSf|hP<\ngGX`BDdwMUMAuhykgQSf|hP>\ngGX`BDdwMUMAuhym^TH<\ngGX`BDdwMUMAuhym^TH>\ngGX`BDdwULAuhykdabdmyP`\ngGX`BDdwUThlauhykgARV|hP>\ngGX`BDdwUThmAuhykgARV|hP<\ngGX`DBdsMTAtXisVzpZG}h`\ngGX`DBdsMTAtXisWNbdmu`tO{Q@\ngGX`DBdsMTAtXiuVzpZG}h`\ngGX`DBdsMTAtXiuWNbdmu`tO{Q@\ngGX`DBdsMTAtXiuZzpZG}h`\ngGX`DBdwMLAuhyk^TH\ngGX`DBdwMLAuhym^TH\ngGX`DBdwMRAthzncn{@\ngGX`DBdwMRAthzncn}@\ngGX`DBdwMRAthzshiK]G]z\ngGX`DBdwMRAuhyj\ngGX`DBdwMRAuhykgQRT\ngGX`DBdwMRAuhykgQRV|oP\ngGX`DBdwMUMAuhyk^TH<\ngGX`DBdwMUMAuhyk^TH>\ngGX`DBdwMUMAuhykgQRV|hP<\ngGX`DBdwMUMAuhykgQRV|hP>\ngGX`DBdwMUMAuhykgQSf|hP>\ngGX`DBdwMUMAuhym^TH<\ngGX`DBdwMUMAuhym^TH>\ngGX`DBdwSRAtiZnQm[N{l\ngGX`DBdwUThmAuhykgARV|hP<\ngGX`DBdwUThmAuhykgARV|hP>\ngGX`JDduuTAuhyK^DH\ngGX`JDduuTAuhyM^DH\ngGX`LDdwMTAtXyKVzHZG|ebSZX=\ngGX`LDdwMTAtXyKVzHZG}i`=\ngGX`LDdwMTAtXyKVzH[{|ebSZX\ngGX`LDdwMTAtXyKVzH[{}i`\ngGX`LDdwMTAtXyKWNbgMtPtO{S@\ngGX`LDdwMTAtXyKZzHZG}i`\ngGX`LDdwMTAtXyK[NbgMtPtO{S@\ngGX`LDdwMTAtXyMVzH[{}i`\ngGX`LDdwMTAtXyMZzHZG}i`=\ngGX`LDdwMTAthzncn{\x7FZX=\ngGX`LDdwMTAthzncn}\x7FZX\ngGX`LDdwMTAthzncv}\x7FZX=\ngGX`bDnLiMsP@]RMt]wX\ngGX`bDnLiMsT`]ZNZ`\ngGX`bDnLiMsUSP]ZNZweB<\ngGX`bDnLiMsUSP]ZNZweB>\ngGX`hEIWIMsP@]RMt]w_{R@=\ngGX`hEIWIMsP@]RMt]wo{R@\ngGX`hEIWIMsP@]RMt^wo{R@=\ngGX`hEIWIMsS@]FNRuncva\x7FZP\ngGX`hEIWIMsS@]FNRuncv~\x7FZP\ngGX`hEIWIMsS@]FNRuoJG}i@\ngGX`hEIWIMsS@]JNkh{n\x7Fvd@\ngGX`hEIWIMsS@]JNkh{o_vd@\ngGX`hEIWIMsS@]JNkh}n\x7Fvd@\ngGX`hEIWIMsS@]JNkh}o_vd@\ngGX`hEIWIMsU@]FNRunbFa\x7FZP\ngGX`hEIWIMsUSH]FNRunbF~\x7FZP<\ngGX`hEIWIMsUSH]FNRunbF~\x7FZP>\ngGXaBDYR[f`@zd[h{np\ngGXaBDYR[fi@zt\\uoKt\ngGXaBDYR[fjf`zt\\uoJD<\ngGXaBDYR[fjf`zt\\uoJD>\ngGXaBDYR[fjf`zt\\voJD<\ngGXaBDnR[f`@zd[h{np\ngGXaBDnR[f`@zd[h{oP\ngGXaBDnR[ff@zT]WQw^`\ngGXaBDnR[fi@zT]WQw]`\ngGXaBDnR[fi@zT]WQw^`\ngGXaBDnR[fi@zt\\u@\ngGXaBDnR[fi@zt\\uoKt\ngGXaBDnR[fjf`zt\\uoJD<\ngGXaBDnR[fjf`zt\\uoJD>\ngGXaLDnR[fj@zL\\ek]DMC~tp=\ngGXdBl@b^BSRuTbGVbfmyP`<\ngGXdBl@b^BSRuTbGVbfmyP`>\ngGXdBl@b^BSRuTbGVbfuyP`<\ngGXdBl@b^BSRuTbGVbfuyP`>\ngGXdBl@b^FQREj`NmDm[ra\x7FZD\ngGXdMD@baFRREZPNlGIkhao_vf@\ngGXdMD@baFRREZPNlGIkpa\x7FZX\ngGXdMD@baFRREZ`NlGI[haoovf@\ngGXdMD@baFRREZ`NlGIkhaoovf@\ngGXeMD@baF{IIBmPGVCdmtPww{S@\ngGXeMD@baF{IIBmPGVCdmt_Ww{S@\ngGXeMD@baF{IIBmPGVCdutPww{S@\ngGXhHZ@aIfjXCkQSfzGlG}i@\ngGXhHZ@aIfjXCkQSgNbdmtOXO{R@\ngGXhLEJAInjhChqrVmtPtO{S@=\ngGXhLEJAInjhChqrVutPtO{S@\ngGXhMD@cIIBmHGQCdu[hao_vf@\ngGXhMD@cIIBmHGQCdu[pa\x7FZX\ngGXhMD@cIIBmHGQCdu\\yNRwQC^\x7FmL\ngGXhMD@cIIBmHGQCdu\\yNRwaC~tp\ngGXhMD@cIIBmPGQCdm[hah_vf@\ngGXhMD@cIIBmPGQCdm[h~h_vf@\ngGXhMD@cIIBmPGQCdmkhah_vf@\ngGXhMD@cIIBmPGQCdu[hah_vf@\ngGXhMD@cIIBmPGQCdu[haoovf@\ngGXhMD@cIIBmPGQCdu\\yNRwQCP\x7FmL\ngGXhMD@cIIBmPGQCdukhah_vf@\ngGXhMD@cIIJmPGVBVmyP`\ngGXhMD@cIIJmPGVBVmy_@\ngGXhMD@cIIJmPGVBVn\\gI[ra@\ngGXhMD@cIIJmPGVBVuyP`\ngGXhMDOCIHYUPGQCdm[hahP\ngGXhbLjA\\YRnjjbPzHYImgAcfz`ZD<\ngGXhbLjA\\YRnjjbPzHYImgAcfz`ZD>\ngGXhdZ@aS^RYjV@zTdwPwm\x7FmD\ngGXiMD@c]ddaVhCharZmtPtO{S@\ngGXiMD@c]ddaVhCharZutPtO{S@\ngGY@BDfYh@NeGM}`g]v\ngGY@BDfYh@NeGN]EI[{AN{t\ngGY@BDfYh@NeGU}`g]v\ngGY@BDfYh@NeGU}`g]z\ngGY@BDfYh@NeGV]EI[{AN{t\ngGY@BDfYi`NcENZwVCP`\ngGY@BDfYi`NcENZwvB^tH\ngGY@BDfYi`NcENZytTenlFa@\ngGY@BDfYi`NcEN[YtTeolD}hP\ngGY@BDfYi`NcENjwVCP`\ngGY@BDfYi`NcENkWvB^tH\ngGY@BDfYi`NmEV[{AN{t\ngGY@BDfYi`NmEVk{AN{t\ngGY@BDfYi`NmEVlzJRwvB]wh\ngGY@BDfYjPNcENZytTenlF}@\ngGY@BDfYjPNcENZytTeoLD\ngGY@BDfYjPNcENZytTyoLD\ngGY@BDfYjPNcENjwVC^`\ngGY@BDfYjPNcENjwfB\ngGY@BDfYjPNcENjytTenlF}@\ngGY@BDfYjPNcENjytTeoLD\ngGY@BDfYjPNmEV[{AN{l\ngGY@BDfYjPNmEV[{AN{t\ngGY@BDfYjPNmEV[{AO[l\ngGY@BDfYjPNmEV\\zJRwvB]wh\ngGY@BDfYjPNmEV\\zJRwvB^wh\ngGY@BDfYjPNmEVk{AN{l\ngGY@BDfYjPNmEVk{AN{t\ngGY@BDfYjPNmEVk{AO[l\ngGY@BDfYjPNmEVk{AO[t\ngGY@BDfYjPNmEVlzJRwvB]wh\ngGY@BDfYjPNmEVlzJRwvB^wh\ngGY@BDfYjhhNcENZwVCP`>\ngGY@BDfYjhhNcENjwVCP`<\ngGY@BDfYjhhNcENjwVCP`>\ngGY@BDfZd@NiJyF}l{oP\ngGY@BDfZe`NmIM[x[vzD\ngGY@BDfZfPNeIUrM{Yw]`\ngGY@BDfZfPNmEV[h{np\ngGY@BDfZfPNmEV[h{oP\ngGY@BDfZfPNmIM[x[v{t\ngGY@BDfZhIDNeGM}`g]v>\ngGY@BDfZhIDNeGN]EI[{AO[t>\ngGY@BDfZjeDdNcENZwVCP`<\ngGY@BDfZjeDdNcENZwVCP`>\ngGY@BDfZjeDdNcENZypXenlFa@<\ngGY@BDfZjeDdNcENZypXenlFa@>\ngGY@BDfZjeDdNcENZytTenlFa@<\ngGY@BDfZjeDdNcENZytTenlFa@>\ngGY@BDfZjeDdNcENZytTynlFa@<\ngGY@BDfZjeDdNcENZytTynlFa@>\ngGY@BDfZjeDdNcEN[WVCP`<\ngGY@BDfZjeDdNcEN[YtTynlFa@<\ngGY@BDfZjeDdNcEN[YtTynlFa@>\ngGY@BDfZjeDdNcENkWVCP`>\ngGY@BDfZjeDhNcENZwVCP`<\ngGY@BDfZjeDhNcENZwVCP`>\ngGY@BDfZjeDhNcENZyLTyK]XMB<\ngGY@BDfZjeDhNcENZyLTyK]XMB>\ngGY@BDfZjeDhNcENZytTenlFa@<\ngGY@BDfZjeDhNcENZytTenlFa@>\ngGY@BDfZjeDhNcENZytTynlFa@<\ngGY@BDfZjeDhNcENZytTynlFa@>\ngGY@BDfZjeDhNcEN[WVCP`<\ngGY@BDfZjeDhNcEN[WVCP`>\ngGY@BDfZjeDhNcENjwVCP`<\ngGY@BDfZjeDhNcENjwVCP`>\ngGY@BDfZjeHhNcENjwVCP`<\ngGY@BDfZjeHhNcENjwVCP`>\ngGY@BDfZjeHhNcENjypXynlFa@>\ngGY@BDfzZihNmKM[x[VzD<\ngGY@BDfzZihNmKM[x[VzD>\ngGY@DDfYj`NkENRuolDah_vb@=\ngGY@DDfYj`NkENRuolDaoovb@\ngGY@DDfYj`NkENRuomxah_vb@=\ngGY@DDfYj`NkENRushiK_XIC__mD\ngGY@DDfYj`NkENRushiK_[qC__mD\ngGY@DDfYj`NkENRushis_XICP\x7FmD\ngGY@DDfYj`NkENRushis_XIC__mD\ngGY@DDfYj`NkENRushis_[qCP\x7FmD\ngGY@DDfYj`NkENRvolDah_vb@\ngGY@DDfYj`NkENRvomxah_vb@\ngGY@DDfYj`NkENRvshiK_XICP\x7FmD\ngGY@DDfYj`NkENRvshiK_[qCP\x7FmD\ngGY@DDfYj`NkENRvshis_XICP\x7FmD\ngGY@DDfYj`NkENRvshis_[qCP\x7FmD\ngGY@DDfYj`NkENSUolDaoovb@\ngGY@DDfYj`NkENSUshiK_XIC__mD\ngGY@DDfYj`NkENSUshiK_[qC__mD\ngGY@DDfYj`NkENSVolDah_vb@=\ngGY@DDfYj`NkENSVshis_XICP\x7FmD\ngGY@DDfYj`NkENbuolDah_vb@=\ngGY@DDfYj`NkENbuolDaoovb@\ngGY@DDfYj`NkENbushiK_XIC__mD\ngGY@DDfYj`NkENbushis_XICP\x7FmD\ngGY@DDfYj`NkENbushis_XIC__mD\ngGY@DDfYj`NkENbvolDah_vb@\ngGY@DDfYj`NkENbvshiK_XICP\x7FmD\ngGY@DDfYj`NkENbvshis_XICP\x7FmD\ngGY@DDfYj`NkENcVolDah_vb@=\ngGY@DDfYj`NkENcVshis_XICP\x7FmD\ngGY@DDfYj`NmEV[{AN{w}h`\ngGY@DDfYj`NmEV[{AO[w}h`=\ngGY@DDfYj`NmEV\\zJRwvB]wo{Q@\ngGY@DDfYj`NmEV\\zJ\\wvB^wo{Q@\ngGY@DDfYj`NmEVk{AN{w}h`\ngGY@DDfYj`NmEVk{AO[w}h`=\ngGY@DDfYj`NmEVlzJ\\wvB^wo{Q@\ngGY@DDfZf`NcIIZwHwndMB=\ngGY@DDfZf`NkENRuomtah_vb@=\ngGY@DDfZf`NkENRushis_[iCP\x7FmD\ngGY@DDfZjiDNkENRuolDah_vb@+\ngGY@DDfZjiDNkENRuolDah_vb@-\ngGY@DDfZjiDNkENRushis_XICP\x7FmD<\ngGY@DDfZjiDNkENRvolDah_vb@<\ngGY@DDfZjiDNmEV[{AN{w}h`<\ngGY@DDfZjiDNmEV[{AN{w}h`>\ngGY@DDfZjiDNmEV[{AO[w}h`-\ngGY@DDffj`NkENRuolDah_vb@\ngGY@DDffjiDNkENRushiK_XICP\x7FmD>\ngGY@DDfnjYDNcGIZypTeoCx<\ngGY@DDfnjYDNcGIZypTeoCx>\ngGY@DDfnjiDNcGIZwQCP`<\ngGY@DDfnjiDNcGIZwQCP`>\ngGY@DDfnjiDNcGIZyHXiK]DMB>\ngGY@DDfnjiDNcGIZyr\\enbFa@<\ngGY@DDfnjiDNcGIZyr\\enbFa@>\ngGY@DDfnjiDNcGIZytTenbFa@<\ngGY@DDfnjiDNcGIZytTenbFa@>\ngGY@DDfyh@NiFzN{l=\ngGY@DDfyh@NiFzN{t\ngGY@DDfyh@NiFzO[t=\ngGY@DDfyh@NiGNbdmt]wh\ngGY@DDfyh@NiGNbgMt^wh\ngGY@DDfyi`NcGIZwQ{P`\ngGY@DDfyi`NcGIZweB\ngGY@DDfyi`NcGIZytTencva@\ngGY@DDfyi`NcGIZytTeoJD\ngGY@DDfyi`NcGIZytTyncva@\ngGY@DDfyi`NcGIZytTyncv~@\ngGY@DDfyi`NcGIZytTyoJD\ngGY@DDfyi`NcGI[WQ{P`\ngGY@DDfyi`NcGI[WeB\ngGY@DDfyi`NcGI[YtTyncva@\ngGY@DDfyi`NcGI[YtTyoJD\ngGY@DDfyi`NeGUt]wh\ngGY@DDfyi`NeGUt^wX\ngGY@DDfyi`NeGUt^wh\ngGY@DDfyi`NeGV]EI[h}oP\ngGY@DDfyi`NeGV]EN[h}np\ngGY@DDfyi`NeGV]EN[h}oP\ngGY@DDfyj`NcGIZwQCP`\ngGY@DDfyj`NcGIZwQCP\x7FdlRP\ngGY@DDfyj`NcGIZyLTyK]DMB\ngGY@DDfyj`NcGIkWQCP`\ngGY@DDfyjidNcGIZwQC_@<\ngGY@DDfyjidNcGIZwQC_@>\ngGY@DDfyjidNcGIZytTenbF~@<\ngGY@DDfyjidNcGIZytTenbF~@>\ngGY@DDfyjidNcGIZytTynbFa@<\ngGY@DDfyjidNcGIZytTynbFa@>\ngGY@DDfyjidNcGIZytTynbF~@>\ngGY@DDfyjidNcGI[WQCP`<\ngGY@DDfyjidNcGI[WQCP`>\ngGY@DDfyjidNcGI[YtTynbFa@<\ngGY@DDfyjidNcGI[YtTynbFa@>\ngGY@DDfzX@NiFzN{l=\ngGY@DDfzX@NiFzN{t\ngGY@DDfzX@NiGNBdmt]wh\ngGY@DDfzX@NiJyFul{np=\ngGY@DDfzX@NiJyFul{oP\ngGY@DDfzX@NiJyFul}oP=\ngGY@DDfzX@NiKNbdmrMkiw^`\ngGY@DDfzY`NcGIZypTyoJD\ngGY@DDfzY`NcKIZwpvmtH\ngGY@DDfzZ`NcKIZwHvmdMB\ngGY@DDfzZ`NcKIZwHvmdMC~RqI@\ngGY@DDfzhIDNiFzN{l+\ngGY@DDfzhIDNiFzN{l-\ngGY@DDfzhIDNiFzN{t<\ngGY@DDfzhIDNiGNbdmt]wh<\ngGY@DDfzhIDNiGNbdmt]wh>\ngGY@HDfZh@NeGM}`g]w~t`=\ngGY@HDfZh@NeGN]EI[{AN{w}i@\ngGY@HDfZhIDNeGM}`g]v+\ngGY@HDfZhIDNeGM}`g]v-\ngGY@HDfZhIDNeGM}oG]v-\ngGY@HDfZhIDNeGM}oG]z<\ngGY@HDfZhIDNeGM}oG]z>\ngGY@HDfZhIDNeGNRFJRwvB]wh<\ngGY@HDfZhIDNeGNRFJRwvB]wh>\ngGY@HDfZi`NkENRushis]XMC~t`\ngGY@HDfZj`NkENRurPqrV~pRFa\x7FZP\ngGY@HDkjj`NjENRuolDahP\ngGY@HDkjj`NjENRus`qS_XICP`\ngGY@JDffj`NcENRwVBP`\ngGY@JDffjiDNcENRytTenlDa@<\ngGY@JDffjiDNcENRytTenlDa@>\ngGY@JDffjiDNcENRyt\\enlD~@>\ngGY@JDffjiDNcENSWVBP`<\ngGY@JDffjiDNcENSWVBP`>\ngGY@LDejj`NcEIZwQCP`\ngGY@LDejj`NcEIZypXinbFa@\ngGY@LDejjhhNcEIZwQC_@>\ngGY@LDejjhhNcEIZypXynbFa@<\ngGY@LDejjhhNcEIZypXynbFa@>\ngGY@LDijj`NjFJRuodDahP\ngGY@LDijj`NjFJRus`qS_HICP`\ngGY@LDijjiDNjFJRus`qs_HICP`<\ngGY@LDijjiDNjFJRus`qs_HICP`>\ngGY@LDijjiDNjFJbus`qs_HICP`<\ngGY@LDijjiDNjFJbus`qs_HICP`>\ngGY@LDijjiDNjFJbus`qs_HIC_@<\ngGY@LDijjiDNjFJbus`qs_HIC_@>\ngGY@bAqeIfiXChqSfn]EI[ra@\ngGY@dAreInf@CjQshiK]G]z\ngGY@hAteIfi@CiQs]G]w~t`=\ngGY@hAteIfi@CiQs_[iw]\x7FmH=\ngGY@hAteIijhCjqSdm[{AHZD\ngGY@hAteIijjQCjqSdm\\zJRwvBPtH<\ngGY@hAteIijjQCjqSdm\\zJRwvBPtH>\ngGYABCJSLuTTGQbgU[kAhP<\ngGYABCJSLuTTGQbgU[kAhP>\ngGYABCJSMURbRGQbgM\\zJRwVCP`<\ngGYABCJSMURbRGQbgUkkAhP<\ngGYABCJSMURbTGQbgM[kAhP<\ngGYABCJSMURdTGQbgU[kAhP<\ngGYABCJSMURdTGQbgU[kAhP>\ngGYABIJSMUHGVbkM}`g]v>\ngGYABIJSMUHGVbkM}`g]z>\ngGYABIJSMUHGVbkV]EN[{AO[l>\ngGYADArSMSPGUbgIZytTyomtah_vb@\ngGYADArS]L@GTc]G]v=\ngGYADEJSMTDbGRcf~pSn}\x7FZH<\ngGYADEJS]L@GTc_Ki{^`=\ngGYAJKJSSUPGQbgI[kAHP\ngGYALMJRuUPGQbdm[hahP\ngGYDJQDJHR[jf@zT\\`\ngGYHBaxIMtp@]RMt]wX\ngGYHDIPIMuP@]RN]EI[h{oP>\ngGYHDPDIMts@]ZVZwpvmtH\ngGYHDQxILuUJIP]FJ\\uoa{^o`>\ngGYHE@DIUsUPH]TJ\\ek_[qCP\x7FmD-\ngGYHE@DYICF``Pz`[h{np+\ngGYHEAxIU[U@]TJ]Fk_XICP\x7FmD\ngGYHEAxIU[U@]TJ]Fm_XICP\x7FmD\ngGYHHPDILuS@]FJ\\uoa{Ah_vd@\ngGYHHPDILuS@]FJ\\ushiK_CvCP\x7FmH\ngGYHHPDILuS@]FJ\\voa{Ah_vd@\ngGYHHPDILuS@]FJ\\vshiK_CvCP\x7FmH\ngGYHHPDILuS@]FJ]Uoa{Ah_vd@\ngGYHHPDILuS@]FJ]UshiK_CvCP\x7FmH\ngGYHHPDILuS@]FJ]UshiK_CvC__mH\ngGYHHPDILuT`]FJ\\uoa{Ao_vd@\ngGYHHPDILuUQP]FJ\\ushiK_CvCP\x7FmH<\ngGYHHPxILuS@]FJ\\ushiK_CvCP\x7FmH\ngGYHJPDILuK@]JR[h[vp\ngGYHJPDILuK@]JR[h[wP\ngGYHJPDILuK@]JR\\zJRwPwn`\ngGYHJPDILuK@]ZJ\\`\ngGYHJPDILuK@]ZJ\\wfz\ngGYHJPDILuK@]ZJ\\ypXe@\ngGYHJPDILuL`]JRkd[vsn{@\ngGYHJPDILuL`]JRkd[wSn{@\ngGYHJPDILuSRH]ZJ\\wfB<\ngGYHJQDILuK@]ZJ\\ytTeoMt\ngGYHJQHILuK@]ZJ\\ytTe@\ngGYHJQHILuSRH]ZJ\\wfB>\ngGYHK@xIUMU@]TLTyK_HNB_@\ngGYHKAxIU[U@]DJ\\enlDa@\ngGYHKAxIU[U@]DJ\\erXirVzpRD\ngGYHKAxIU[U@]DJ]FnlDa@\ngGYHL`DIMsU@]FNRunbFa\x7FZX=\ngGYHL`DIMtu@]FNRunbFa\x7FZX=\ngGYHdIPSeJSWUTbGQcdm[hahP<\ngGYHdIPSeJSWUTbGQcdm[hahP>\ngGYHlEPKmJUuUPGUCEIkYpXiohDahP\ngGYHlEPKmJUuUPGUCIIkYpXiohDahP\ngGYIHEPKdkjj`NjENcVolDahP\ngGYILEPKdkjj`NjFJSVs`qS_PICP`\ngGYLcaHR`TaNLiM]U@]ZNZyr\\eoJD\ngGYLcaHR`TaNLiM]U@]ZN[Yr\\eoJD\ngGY`JDTfyi`NeGH\ngGY`LDTfyj`NmGM[ra\x7FZX\ngGY`hDYJyInZdCiQu]G]w~t`\ngGY`hDYJyInZjZCkQsV|h_vd@>\ngGYhCE`DYIHUj@zp\\uoJD\ngGYhCE`DYIHUj@zp\\usdyK^TH\ngGYhCE`DYIHUj@zp\\voJD\ngGYhCE`DYIHUj@zp\\vsdyK^TH\ngGYhCE`DYIIUi@zpRusdyK^Wo{P`\ngGYhCE`DYIIUj@zpRuoJG}hP\ngGYhCE`DYIIUj@zpRusdyK^TO{P`\ngGYhCE`DYIIUj@zpRusdyK^Ww{P`\ngGYhCEaxIU[UPH]XJZweB<\ngGYhCEaxIU[UPH]XJZweB>\ngGYhCEaxIU[UPH]XJZytTeoJD<\ngGYhCEaxIU[UPH]XJZytTeoJD>\ngGYhCEaxIU[UPH]XJ[WeB<\ngGYhCEaxIU[UPH]XJ[WeB>\ngGYhCEaxYIIVj@zpRuoJG}hP\ngGYhCEaxYIIVj@zpRvoJG}hP\ngGYhKE`DYIHUj@zp\\foBD\ngGYhjLUPKkJUuUPGVCEMy@`\ngGYhjLUPKkJUuUPGVCIMy@`\ngGYhjLUPKkJUuUPGVCIN\\FI[rA@\ngGYhkEax[kNRRUjhDNdDh<\ngGYhkEax[kNRRUjhDNdDh>\ngGYiKE`D[lddju@]HIP\ngG\\@@ZdsDLAuDwPwm`\ngG\\@@ZdsMLAtiInao]@\ngG\\@@ZdwATAuLwPvm`\ngG\\@@bdsDTAtduoao[h_vb@\ngG\\@@bdsDTAuEWHwmg]w~tP\ngG\\@@bdsDTAuEWHwmg]{~tP\ngG\\@@bdsDTAuEWHwng]{~tP\ngG\\@@bdsMTAtXisWNCDmu`tO{Q@\ngG\\@@bdsMTAtXisWNCGMu`tO{Q@\ngG\\@@bdsMTAtXiuWNCGMu`tO{Q@\ngG\\@@bdwA@AnQm[N{l=\ngG\\@@bdwM@AuIWHvmg]v\ngG\\@@bdwM@AuIWHvng]v\ngG\\@@bdwMLAtiZnQm[N{t\ngG\\@@bdwMLAtiZnQm]N{t\ngG\\@@bdwMUMAuiYk_CZ{P`>\ngG\\@@ldsMTAtXiKVzHZG}h`=\ngG\\@@ldsMTAtXiKWMCENRwQCP\x7FmD=\ngG\\@@ldsMTAtXiKWMCENRwpzPtO{Q@=\ngG\\@@ldsMTAtXiKWNCGMtPtO{Q@\ngG\\@@ldsMTAtXiKWNbgMtPtO{Q@\ngG\\@@ldsMTAtXiK[NCGMtPtO{Q@\ngG\\@@ldsMTAtXiK[NbgMtPtO{Q@\ngG\\@@ldsMTAtYIKVyF}lah_vb@=\ngG\\@@ldsMTAthjoat}o_vb@=\ngG\\@@ldwATAuMWHvmg]w~tp=\ngG\\@@ldwATAuMWHvmgm{~tp=\ngG\\@@ldwATAulek\\cZvPtO{S@=\ngG\\@@ldwATAulem\\cZvPtO{S@=\ngG\\@@ldwATAulfm\\cZvPtO{S@=\ngG\\@ABeWURAuaIk_S^{^\x7Fm@\ngG\\@ABeWUUDatPisWIbgI[kAh_v`@<\ngG\\@ABeWUUDatPisWIbgI[kAh_v`@>\ngG\\@ABeWUUDauaIk_S^{P\x7Fm@<\ngG\\@ABeWUUDauaIk_S^{P\x7Fm@>\ngG\\@ABeWUUDauaIm_S^wP\x7Fm@<\ngG\\@ABeWUUDauaIm_S^wP\x7Fm@>\ngG\\@ABeWUUDauaIm_S^{P\x7Fm@<\ngG\\@ABeWUUDauaIm_S^{P\x7Fm@>\ngG\\@AEddLj@CjBnYm[N{o}h@=\ngG\\@AEddLj@CjBnYm[N{w}h@=\ngG\\A@ZIRYb@@wHwmg]v=\ngG\\A@lIRYfj@zLTek]DMC~tP=\ngG\\A@lIRYfj@zLTek_CiCP\x7FmD=\ngG\\A@lIRYfj@zLTekfabgI[hah_vb@=\ngG\\A@lIRYfj@zLTekgAcf~GRFa\x7FZH\ngG\\DEb@b^BSRuPGVbfmy__dd\\[Q@\ngG\\DEb@b^BSRuPGVbfuyP\x7FmD\ngG\\EebDR^@yRYRZyjdPzt\\unev~\x7FIPxvf@>\ngG\\H@[jCIHYUPGQCEN[jAPP\ngG\\HEb@aIfZhCkQSV|h_vb@\ngG\\HEb@aInfhCkRsV~Funa\x7FZX\ngG\\HHlOAJfjhChabVmtPtH\ngG\\HHlOAJfjhChabVutPtO{R@\ngG\\IHl@`ReSUTAtPqKVzHZD\ngG\\`hZEIWIMsS@]JN_vd@\ngG\\`hZEIWIMsS@]JNkh{n\x7Fvd@\ngG\\`hZEIWIMsS@]JNkh{o_vd@\ngG\\ahZEIWWdfyi`NeGUt]w_{R@\ngG]@DZDfyi`NeGUt]wX\ngG]@DZDfyi`NeGUt]wh\ngG]@EbDfYj`NmEM[ra\x7FZH\ngG]@EbDfYj`NmEM\\zJ\\weC~tP\ngG]@LZDejj`NeEH\ngG]HEcAxIULE@]JM[y[vzD\ngG]HEcAxIULE@]JM\\xNRwrwmtH\ngG]HEcAxIULE@]JMlxNRwrwmtH\ngG]HEcAxIU[U@]XJZweC~tP\ngG]HEcAxIU[U@]XJ[WeC~tP\ngG]HEcAxYIIXJ@zQZyp\\eoeo[h_va@\ngG]HlZEPKmJUuUPGVCIMy@`\ngJP@DjXDCiQK]K^v=\ngJP@DjXDCiQK]K^z\ngJP@DjXDCiQK]Knz=\ngJP@DjXDCiQK_K^v^`=\ngJP@DjXDCiQK_K^z^`\ngJP@DjXDCiQK_Knz^`=\ngJP@DjXDCiQKgASfzV}t\ngJP@DjXDCiQKgASf~V}t}@\ngJP@DjXDCiQKgAcfzW]t\ngJP@DjXDCiQKgAcf~W]t}@\ngJP@DjYdCjabgI[i]pP\ngJP@DjYdCjabgI[i]w`\ngJP@DjYdCjabgI[kAOP\ngJP@DjYdCjabgI[sA@\ngJP@DjYdCjabgI[y]pSt\ngJP@DjYdCjabgI\\xJ\\wR{``\ngJP@DjYdCjabgI\\xJ\\wR{o@\ngJP@DjYdCjabgI\\xJ\\wVB^`\ngJP@DjYdCjabgI\\xJ\\wV|^`\ngJP@DjYdCjabgI\\xJ\\wfB\ngJP@DjYdCjabgI\\xJ\\wf|\ngJP@DjYdCjabgI\\xJ\\wr{`gh\ngJP@DjYdCjabgI\\xJ\\wr{oGh\ngJP@DjYdCjabgI\\xL\\wR{``\ngJP@DjYdCjabgI\\xL\\wR{o@\ngJP@DjYdCjabgI\\xL\\wVB^`\ngJP@DjYdCjabgI\\xL\\wV|^`\ngJP@DjYdCjabgI\\xL\\wfB\ngJP@DjYdCjabgI\\xL\\wf|\ngJP@DjYdCjabgI\\xL\\wr{`gh\ngJP@DjYdCjabgI\\xL\\wr{oGh\ngJP@DjYdCjabgQ[i]pP\ngJP@DjYdCjabgQ[sA@\ngJP@DjYdCjabgQ[y]pSt\ngJP@DjYdCjabgQ\\xJ\\wR{``\ngJP@DjYdCjabgQ\\xJ\\wr{`gh\ngJP@DjYdCjabgQ\\xL\\wVB^`\ngJP@DjYdCjabgQ\\xL\\wr{`gh\ngJP@DjYdCkBbVzV}l\ngJP@DjYdCkBbVzV}t\ngJP@DjYdCkBbVzW]l\ngJP@DjYdCkBbVzW]t\ngJP@DjYdCkBbV~V}t}@\ngJP@DjYdCkBbV~W]t}@\ngJP@DjZhCjabgI[yApRD\ngJP@DjZhCjabgI[yApRG|eBb\ngJP@DjZhCjabgI[yApSx\ngJP@DjZhCjabgI[y^wbD\ngJP@DjZhCjabgI\\dLTyodGAHP\ngJP@DjZhCjabgI\\dLTyodGAO`\ngJP@DjZhCjabgI\\dLTyoe{^HP\ngJP@DjZhCjabgIkyApRD\ngJP@DjZhCjabgIldLTyodGAHP\ngJP@DjZhCjabkQ[yApRD\ngJP@DjZhCjabkQ\\dLTyodGAHP\ngJP@DjZhCjabkQ\\dLTyodGAO`\ngJP@DjZhCjabkQkyApRD\ngJP@DjZjACjabgI[yAwbD<\ngJP@DjZjACjabgI[yAwbD>\ngJP@DjZjACjabgI[yAwbG|eBb>\ngJP@DjZjACjabgI[yAwcx<\ngJP@DjZjACjabgI\\dLTyodG^HP<\ngJP@DjZjACjabgI\\dLTyodG^HP>\ngJP@DjZjACjabgI\\dLTyodG^H_rTJH<\ngJP@DjZjACjabgI\\dLTyodG^H_rTJH>\ngJP@DjZjACjabgI\\dLTyodG^O`<\ngJP@DjZjACjabgI\\dLTyodG^O`>\ngJP@DjZjACjabgI\\xJ\\wrCoDH<\ngJP@DjZjACjabgI\\xJ\\wrCoDH>\ngJP@DjZjACjabgI\\xJ\\wrCoDOyJED<\ngJP@DjZjACjabgI\\xJ\\wrCoDOyJED>\ngJP@DjZjACjabgI\\xJ\\wrCoGp<\ngJP@DjZjACjabgI\\xJ\\wrCoGp>\ngJP@DjZjACjabgI\\xL\\wrC`dH<\ngJP@DjZjACjabgI\\xL\\wrC`dH>\ngJP@DjZjACjabgI\\xL\\wrC`dOyJED<\ngJP@DjZjACjabgI\\xL\\wrC`dOyJED>\ngJP@DjZjACjabgI\\xL\\wrC`gp<\ngJP@DjZjACjabgI\\xL\\wrC`gp>\ngJP@DjZjACjabgI\\xL\\wrCoDH<\ngJP@DjZjACjabgI\\xL\\wrCoDH>\ngJP@DjZjACjabgI\\xL\\wrCoDOyJED<\ngJP@DjZjACjabgI\\xL\\wrCoGp<\ngJP@DjZjACjabgI\\xL\\wrCoGp>\ngJP@DjZjACjabgI\\xL\\wr}oDH<\ngJP@DjZjACjabgI\\xL\\wr}oDH>\ngJP@DjZjACjabgI\\xL\\wr}oGp<\ngJP@DjZjACjabgI\\xL\\wr}oGp>\ngJP@DjZjACjabgIkyAwbD<\ngJP@DjZjACjabgIkyAwbD>\ngJP@DjZjACjabgIldLTyodG^H_rTJH<\ngJP@DjZjACjabgIlxJ\\wrCoDH<\ngJP@DjZjACjabgIlxJ\\wrCoDH>\ngJP@DjZjACjabgIlxL\\wrC`dH<\ngJP@DjZjACjabgIlxL\\wrC`dH>\ngJP@DjZjACjabgIlxL\\wrCoDH<\ngJP@DjZjACjabgIlxL\\wr}oDH<\ngJP@DjZjACjabgIlxL\\wr}oDH>\ngJP@DjZjACjabgQ[yApRD<\ngJP@DjZjACjabgQ[yApRD>\ngJP@DjZjACjabgQ[yApSx>\ngJP@DjZjACjabgQ\\dLTyodGAHP<\ngJP@DjZjACjabgQ\\dLTyodGAHP>\ngJP@DjZjACjabgQ\\dLTyodGAO`>\ngJP@DjZjACjabgQ\\xJ\\wrC`dH<\ngJP@DjZjACjabgQ\\xJ\\wrC`dH>\ngJP@DjZjACjabgQ\\xJ\\wrC`gp>\ngJP@DjZjACjabgQ\\xL\\wrC`dH<\ngJP@DjZjACjabgQ\\xL\\wrC`dH>\ngJP@DjZjACjabgQ\\xL\\wrC`gp<\ngJP@DjZjACjabgQ\\xL\\wrC`gp>\ngJP@DjZjACjabgQkyApRD<\ngJP@DjZjACjabgQkyApRD>\ngJP@DjZjACjabgQlxJ\\wrC`dH<\ngJP@DjZjACjabgQlxL\\wrC`dH<\ngJP@DjZjACjabgQlxL\\wrC`dH>\ngJP@DjZjACjabkI[yAwbD<\ngJP@DjZjACjabkI[yAwbD>\ngJP@DjZjACjabkI\\xJ\\wrCoDH<\ngJP@DjZjACjabkI\\xJ\\wrCoDH>\ngJP@DjZjACjabkI\\xJ\\wrCoGp<\ngJP@DjZjACjabkI\\xJ\\wrCoGp>\ngJP@DjZjACjabkQ\\xL\\wrC`dH<\ngJP@DjZjACjabkQ\\xL\\wrC`dH>\ngJP@DjZjACjabkQ\\xL\\wrC`gp<\ngJP@DjZjACjabkQ\\xL\\wrC`gp>\ngJP@DjvhCjabgI[kAHP\ngJP@DjvhCjabgI[kAO`\ngJP@DjvhCjabgI[k^HP\ngJP@DjvhCjabgI[z]pRD\ngJP@DjvhCjabgI[z]pSx\ngJP@DjvhCjabgI[z]wbD\ngJP@DjvhCjabgI\\xL\\wVBP`\ngJP@DjvhCjabgI\\xL\\wVB_@\ngJP@DjvhCjabgI\\xL\\wV|P`\ngJP@DjvhCjabgI\\xL\\wt{`dH\ngJP@DjvhCjabgI\\xL\\wt{`gp\ngJP@DjvhCjabgI\\xL\\wt{oDH\ngJP@DjvhCjabgI\\zJ\\wVBP`\ngJP@DjvhCjabgI\\zJ\\wVB_@\ngJP@DjvhCjabgI\\zJ\\wV|P`\ngJP@DjvhCjabgI\\zJ\\wV|_@\ngJP@DjvhCjabgI\\zJ\\wt{`dH\ngJP@DjvhCjabgI\\zJ\\wt{`gp\ngJP@DjvhCjabgI\\zJ\\wt{oDH\ngJP@DjvhCjabgI\\zJ\\wt{oGp\ngJP@DjvhCjabgIkkAHP\ngJP@DjvhCjabgIkz]pRD\ngJP@DjvhCjabgIlxL\\wt{`dH\ngJP@DjvhCjabgQ[kAHP\ngJP@DjvhCjabgQ[z]pRD\ngJP@DjvhCjabgQ\\xL\\wVBP`\ngJP@DjvhCjabgQ\\xL\\wVB_@\ngJP@DjvhCjabgQ\\xL\\wt{`dH\ngJP@DjvhCjabgQ\\xL\\wt{`gp\ngJP@DjvhCjabgQ\\zJ\\wt{`dH\ngJP@DjvhCjabgQkz]pRD\ngJP@DjvhCkBRV~f}la@\ngJP@DjvhCkBRV~f}ta@\ngJP@DjvhCkBRV~f}t~@\ngJP@DjvhCkBRV~g]la@\ngJP@DjvhCkBRV~g]ta@\ngJP@DjvhCkBRWNCGM}N{YB\ngJP@DjvhCkBRWNCGM}N{Y|\ngJP@DjvhCkBRWNCGM}N{iB\ngJP@DjvhCkBRWNCGM}N{i|\ngJP@DjvhCkBRWNbgM}M{iB\ngJP@DjvhCkBRWNbgM}M{i|\ngJP@DjvhCkBRWNbgM}N{iB\ngJP@DjvhCkBRZ~f}ta@\ngJP@DjvhCkBRZ~g]ta@\ngJP@DkfhCjabgI[kAHP\ngJP@DkfhCjabgI[kAH_rRNH\ngJP@DkfhCjabgI[z]pRD\ngJP@DkfhCjabgI\\dLTynlDa@\ngJP@DkfhCjabgI\\dLTyoiwAHP\ngJP@DkfhCjabgQkkAHP\ngJP@DkfhCjabgQkz]pRD\ngJP@DkfjICjabgI[kAO`<\ngJP@DkfjICjabgI[kAO`>\ngJP@DkfjICjabgI[z]pSx<\ngJP@DkfjICjabgI[z]pSx>\ngJP@DkfjICjabgI\\dLTynlD~@<\ngJP@DkfjICjabgI\\dLTynlD~@>\ngJP@DkfjICjabgI\\dLTyoiwAO`<\ngJP@DkfjICjabgI\\dLTyoiwAO`>\ngJP@DkfjICjabgI\\xLTwVBP`<\ngJP@DkfjICjabgI\\xLTwVBP`>\ngJP@DkfjICjabgI\\xLTwVB_@<\ngJP@DkfjICjabgI\\xLTwVB_@>\ngJP@DkfjICjabgI\\xLTwV|_@<\ngJP@DkfjICjabgI\\xLTwV|_@>\ngJP@DkfjICjabgI\\xLTwt{`dH<\ngJP@DkfjICjabgI\\xLTwt{`dH>\ngJP@DkfjICjabgI\\xLTwt{`gp<\ngJP@DkfjICjabgI\\xLTwt{`gp>\ngJP@DkfjICjabgI\\xLTwt{oGp<\ngJP@DkfjICjabgI\\xL\\wVB_@<\ngJP@DkfjICjabgI\\xL\\wVB_@>\ngJP@DkfjICjabgI\\xL\\wt{`gp<\ngJP@DkfjICjabgI\\xL\\wt{`gp>\ngJP@DkfjICjabgIkkAHP<\ngJP@DkfjICjabgIkkAHP>\ngJP@DkfjICjabgIkz]pRD<\ngJP@DkfjICjabgIkz]pRD>\ngJP@DkfjICjabgIldLTynlDa@<\ngJP@DkfjICjabgIldLTynlDa@>\ngJP@DkfjICjabgIlxLTwVBP`<\ngJP@DkfjICjabgIlxLTwVBP`>\ngJP@DkfjICjabgIlxLTwt{`dH<\ngJP@DkfjICjabgIlxLTwt{`dH>\ngJP@DkfjICjabgQ[kAO`<\ngJP@DkfjICjabgQ[kAO`>\ngJP@DkfjICjabgQ\\xL\\wt{`gp<\ngJP@DkfjICjabgQ\\xL\\wt{`gp>\ngJP@DkfjICjabgQlxLTwVBP`<\ngJP@DkfjICjabgQlxLTwVBP`>\ngJP@LdaB`Nedm}MkYB=\ngJP@LdaB`Nedm}MkY|=\ngJP@LdaB`Nedm}MkiB\ngJP@LdaB`Nedm}Mki|\ngJP@LdaB`Nedm}NkiB=\ngJP@LdaB`Nedm}Nki|=\ngJP@LdaB`Nedn\\EN[z]WRD\ngJP@LdaB`Nedn\\EN[z]WSx\ngJP@LdaB`Nedn]EN[z[WRD\ngJP@LdaB`Nedn]EN[z[WSx\ngJP@LdaB`Nedu}MkYB=\ngJP@LdaB`Nedu}MkiB\ngJP@LdaB`Nedu}NkiB=\ngJP@LdaB`Nedv\\EN[z]WRD\ngJP@LdaB`Nedv]EN[z[WRD\ngJPAEJUsTAuPqSdv\\FJ[kAHP>\ngJPAMJULrAuPqSdn\\EN[sA@\ngJPBABPHPQ`aJfj@zpXeoBD\ngJPBABRHPQ`aJnj@zpTeoBD>\ngJPD@DHHRYZ`NcENRwVBP`\ngJPD@DHHRYZ`NcENbwVBP`\ngJPD@DHHR[j`NmGI[pa@\ngJPD@DHHR[j`NmGI[x^WbD\ngJPD@DJ`Rfh@NhFzvsl=\ngJPD@DPHRnh@NhFzvsl=\ngJPD@DPHRnh@NhFzvst\ngJPD@DPHRnh@NhFzwSt=\ngJPD@DPHRnh@NhGNCGMumgh\ngJPD@DPHRni`NdEUungh\ngJPD@DPHRni`NdEV\\FN[k]OP\ngJPD@DPHRnj`NbENRwVBP`\ngJPD@DSpRnh@NhF~gml{@=\ngJPD@DXHRfjPNbFJRwRB^`\ngJPD@DXHRfjPNbFJRwbB\ngJPD@DXHRfjPNbFJRypXyndD}@\ngJPD@DXHRfjPNbFJbwRB^`\ngJPD@DXHRfjPNbFJbypXyndD}@\ngJPD@DXHRfjPNlFR[yAvsl\ngJPD@DXHRfjPNlFR[yAvst\ngJPD@DXHRfjPNlFRkyAvsl\ngJPD@DXHRfjPNlFRkyAvst\ngJPD@DXHRfjPNlFRlxL\\wrCmgh\ngJPD@DXHRfjiDNbFJRypXindDa@<\ngJPD@DXHRfjiDNbFJRypXindDa@>\ngJPD@DXHRfjiDNbFJSYpXindDa@<\ngJPD@DXHRfjiDNbFJSYpXindDa@>\ngJPD@VPlRnh@NhFzvst\ngJPD@bQDRnh@NhFzvsl=\ngJPD@bQDRnh@NhFzvst\ngJPD@bSpRnh@NhF~gml{@=\ngJPDAxGpRij`NbFJmWRC``\ngJPDAxSpRnX@NhFzwSt=\ngJPE@bSpdiWT@GTC_Svv]`=\ngJPH@DIKT@GTc][Yv=\ngJPH@DIKT@GTc][Yz\ngJPH@DIKT@GTc][iz=\ngJPH@DIKT@GTc_Cvv]`=\ngJPH@DIKT@GTc_Cvv^`\ngJPH@DIKT@GTcgAcfzvst\ngJPH@DIKTpGQbgI\\xLTwVzP`\ngJPH@DIKTpGQbgIkpa@\ngJPH@DIKUPGQbgI[kAHP\ngJPH@DIKUPGQbgI[x^pRD\ngJPH@DIKUTRGQbgI\\xLTwVBP`<\ngJPH@DIKUTRGQbgI\\xLTwVBP`>\ngJPH@DILmHGQbgI\\zJ\\wVB^`\ngJPH@DILmHGQbgI\\zJ\\wfB\ngJPH@DILthGVddmtM{X\ngJPH@DILthGVddmtM{h\ngJPH@DILthGVddm|M{Yz\ngJPH@DILthGVddm|M{iz\ngJPH@DILuTbGQbgI[kAHP<\ngJPH@DILuTbGQbgI[kAHP>\ngJPH@DILuTbGQbgI[x^pRD<\ngJPH@DILuTbGQbgI\\xL\\wVBP`<\ngJPH@DILuTbGQbgI\\xL\\wVBP`>\ngJPH@DILuTbGQbgI\\zJ\\wVBP`<\ngJPH@DILuTbGQbgI\\zJ\\wVBP`>\ngJPH@DILuTbGQbgI\\zJ\\wV|P`<\ngJPH@DILuTbGQbgI\\zJ\\wV|P`>\ngJPH@DILuTbGQbgI\\zJ\\wp}`dH<\ngJPH@DILuTbGQbgI\\zJ\\wp}`dH>\ngJPH@DILuTbGQbgQ[kAHP>\ngJPH@DILuTbGQbgQ\\xL\\wVBP`<\ngJPH@DILuTbGQbgQ\\xL\\wVBP`>\ngJPH@DIMsPGQbgI\\zJ\\wRzP`\ngJPH@DIMsPGVedm|MkYB\ngJPH@DIMsPGVedm|MkiB\ngJPH@DIMsPGVedn]EN[x[WRD\ngJPH@DIMsPGVedu|MkiB\ngJPH@DIST@GRBf~P]l{@=\ngJPH@DIST@GRBf~P]l}@\ngJPH@DIST@GRBf~P]t}@=\ngJPH@DIST@GRBf~Wml{@=\ngJPH@DIST@GRBf~Wml}@\ngJPH@DIST@GRBgNCEM|`{iz\ngJPH@DIST@GRBgNCGM|`{Yz\ngJPH@DIST@GRBgNCGM|o[Yz\ngJPH@DIST@GRBj~P]l{@=\ngJPH@DIST@GRBj~P]l}@\ngJPH@DIST@GRBj~P]t}@=\ngJPH@DIST@GRBkNCEM|`{iz\ngJPH@DIST@GRBkNCGM|`{Yz\ngJPH@DISTpGUCENRwRBP`\ngJPH@DISTpGUCENRwrCndH\ngJPH@DISTpGUCENRypXiodG]HP\ngJPH@DISTpGUCENRypXioe{]HP\ngJPH@DISTpGUCENSWrCndH\ngJPH@DISTpGUCENSYpXindDa@\ngJPH@DISTpGUCENSYpXiodG]HP\ngJPH@DISTpGUCEVRwRBP`\ngJPH@DISTpGUCEVRwrCndH\ngJPH@DISTpGUCEVRypXiodG]HP\ngJPH@DISTpGUCEVRypXyodG]HP\ngJPH@DISTpGUCEVSWrCndH\ngJPH@DISTpGVCIM|`{Yz\ngJPH@DISTpGVCIM|`{iv\ngJPH@DISTpGVCIM|`{iz\ngJPH@DISTpGVCIN\\FN[yAwSt\ngJPH@DISTpGVCIU|`{Yz\ngJPH@DISTpGVCIU|`{iz\ngJPH@DISUPGUCENRwrC`dH\ngJPH@DISUPGUCEVRwrC`dH\ngJPH@DISUTbGUCENRypXiodGAHP<\ngJPH@DISUTbGUCENRypXiodGAHP>\ngJPH@DISUTbGUCENSWrC`dH<\ngJPH@DISUTbGUCENSWrC`dH>\ngJPH@DISUTbGUCENSYHXis_HNBP`<\ngJPH@DISUTbGUCENSYpXiodGAHP<\ngJPH@DISUTbGUCENSYpXiodGAHP>\ngJPH@DISUTbGUCEVRwrC`gp>\ngJPH@DISUTbGUCEVRypXiodGAHP<\ngJPH@DISUTbGUCEVSWrC`dH<\ngJPH@DISUTbGUCEVSWrC`dH>\ngJPH@DISUTbGUCEVSYpXiodGAHP<\ngJPH@DISUTbGUCEVSYpXiodGAHP>\ngJPH@VIST@GRBj~P]l{@=\ngJPH@VIST@GRBj~P]l}@\ngJPH@VIST@GRBj~P]t}@=\ngJPH@VISTpGUCENSYpXiodG]HP\ngJPH@bIKT@GTc][Yv=\ngJPH@bIKT@GTc][Yz\ngJPH@bIKT@GTc][iz=\ngJPH@bIMsPGVedm|MkiB\ngJPH@bIST@GRBf~P]l{@=\ngJPH@bIST@GRBf~P]l}@\ngJPH@bIST@GRBf~Wml{@=\ngJPH@bIST@GRBj~P]l{@=\ngJPH@bIST@GRBj~P]l}@\ngJPH@bIST@GRBj~P]t}@=\ngJPH@bIST@GRBkNCGM|`{Yz\ngJPH@bISTpGUCEVRwrCndH\ngJPH@bISTpGUCEVSWrCndH\ngJPH@bISTpGVCIU|`{iz\ngJPH@bISUPGUCEVRwrC`dH\ngJPH@xIKT@GTc][iz=\ngJPH@xIKT@GTc_Cvv]`=\ngJPH@xIKT@GTc_Cvz^`=\ngJPH@xIKUPGQbgI[x^pRD\ngJPH@xILuTbGQbgI[x^pRD<\ngJPH@xILuTbGQbgI[x^pRD>\ngJPH@xILuTbGQbgI\\zJ\\wp}`dH<\ngJPH@xILuTbGQbgI\\zJ\\wp}`dH>\ngJPH@xIMsPGQbgI[x^WRD\ngJPH@xITuPGUCENRwrC`dH\ngJPH@xITuPGUCENSWrC`dH\ngJPHABIKT@GTcgAcfzvst\ngJPHADIKT@GTc][Yv=\ngJPHADIKT@GTc][Yz\ngJPHADIKUPGQbgI[kAHP\ngJPHADILthGQbgI\\zJ\\`\ngJPHADILuTbGQbgI[kAHP<\ngJPHADILuTbGQbgI[kAHP>\ngJPHADILuTbGQbgI\\zJ\\wVBP`<\ngJPHADILuTbGQbgI\\zJ\\wVBP`>\ngJPHADILuTbGQbgI\\zJ\\wV|P`<\ngJPHADILuTbGQbgI\\zJ\\wV|P`>\ngJPHAHILuLbGQbgI[sA@>\ngJPHAHILuTbGQbgI[kAHP<\ngJPHAHILuTbGQbgI[kAHP>\ngJPHAHILuTbGQbgI\\zJ\\wVBP`<\ngJPHAHILuTbGQbgI\\zJ\\wVBP`>\ngJPHAVIKUPGQbgI[kAHP\ngJPHAVILuTbGQbgI\\zJ\\wVBP`<\ngJPHAVILuTbGQbgI\\zJ\\wVBP`>\ngJPHAbIKT@GTc][Yv=\ngJPHAbIKT@GTc][Yz\ngJPHAbIKT@GTc][iz=\ngJPHAbIKTpGQbgI[k]HP\ngJPHAbIKTpGQbgI[pa@\ngJPHAbILuTbGQbgI[kAHP<\ngJPHAbILuTbGQbgI[kAHP>\ngJPHAbILuTbGQbgI\\zJ\\wVBP`<\ngJPHAbILuTbGQbgI\\zJ\\wVBP`>\ngJPHAbILuTbGQbgI\\zJ\\wVB_@>\ngJPHAbILuTbGQbgI\\zJ\\wV|P`<\ngJPHAbILuTbGQbgI\\zJ\\wV|P`>\ngJPHAxIKT@GTc][Yv=\ngJPHAxIKT@GTc][Yz\ngJPHAxIKT@GTc_Cvv]`=\ngJPHAxIKT@GTc_Cvv^`\ngJPHAxIKT@GTc_Cvz^`=\ngJPHAxIKTpGQbgI\\xLTwVzP`\ngJPHAxIKTpGQbgI\\xLTwp}ndH\ngJPHAxIKUPGQbgI[x^pRD\ngJPHAxILuTbGQbgI[x^pRD<\ngJPHAxILuTbGQbgI\\xL\\wVBP`<\ngJPHAxILuTbGQbgI\\xL\\wVBP`>\ngJPHAxILuTbGQbgI\\xL\\wp}`dH>\ngJPHAxILuTbGQbgI\\zJ\\wVBP`<\ngJPHAxILuTbGQbgI\\zJ\\wVBP`>\ngJPHAxILuTbGQbgI\\zJ\\wp}`dH<\ngJPHAxILuTbGQbgI\\zJ\\wp}`dH>\ngJPHAxILuTbGQbgQ[x^pRD<\ngJPHAxISR@GRBfzwSt=\ngJPHAxISR@GRBf~W]t}@=\ngJPHAxITuPGUCENRwrC`dH\ngJPHAxITuPGUCENSWrC`dH\ngJPHAxITuPGUCENSWr}oDH\ngJPHAxITuPGUCEVbwrC`dH\ngJPHAxITuPGUCEVcWrC`dH\ngJPHAxITuTBGUCENbwrC`dH<\ngJPHAxITuTBGUCENbwrC`dH>\ngJPHCPITuPGQCEN\\dLTyodGAO`\ngJPHEPIWUPGUCENcWtC`dH\ngJPHMPITsHGQCEI[i]worTJH\ngJPHMPITuTBGQCEI\\xJ\\wRBP`<\ngJPHMPITuTBGQCEI\\xJ\\wRBP`>\ngJPHMPITuTBGQCEI\\xJ\\wrCoDH<\ngJPHMPITuTBGQCEI\\xJ\\wrCoDH>\ngJPHMPITuTBGQCEI\\xL\\wRBP`<\ngJPHMPITuTBGQCEI\\xL\\wRBP`>\ngJPHMPITuTBGQCEI\\xL\\wrCoDH<\ngJPHMPITuTBGQCEI\\xL\\wrCoDH>\ngJPHMPYIBE@]KIkz[WRD\ngJPI@DBTjZhCjabgI[yApRD\ngJPIAVBTij@CiAS_HNv]`=\ngJPIAVBTij@CiAS_Kvv^`\ngJPIAVBTij@CiAU_HNv]`=\ngJPIAVBTij@CiAU_HNv^`\ngJPIAVBTij@CiAU_HNz^`=\ngJPIAxBTej@CjQoa{[Np=\ngJPIAxBTej@CjQoa{[OP\ngJPIAxBTfZjQChqSdn]EN[kAHP<\ngJPIAxBTfZjQChqSdn]EN[kAHP>\ngJPIAxBTfZjQChqSdn]EN[x^pRD<\ngJPIAxBTfZjQChqSdn]EN[x^pRD>\ngJPIAxBTjZhCjabkQ[yApRD\ngJPIMPZTjZjAChabdn\\EN[yAwbD<\ngJPIMPZTjZjAChabdn\\EN[yAwbD>\ngJPIMP[djZjAChabdn\\EN[iAHP<\ngJPIMP[djZjAChabdn\\EN[iAHP>\ngJPIMP[djZjAChabdn\\EN[yAwbD<\ngJPIMP[djZjAChabdn\\EN[yAwbD>\ngJPIMP[djZjAChabdn\\FN[yAwbD>\ngJPL@DHHpPdru@]ZJRwaB\ngJP`@TfVhCkQSf|pP\ngJP`@TfVhCkQSf|w`\ngJP`@TfVhCkQSgNbgMy``\ngJP`@TfVhCkQSj|pP\ngJP`@TfZjQCkQSf|pP<\ngJP`@TfZjQCkQSf|pP>\ngJP`@TfZjQCkQSf|w`<\ngJP`@TfZjQCkQSf|w`>\ngJP`@TfZjQCkQSgICEN[sA@>\ngJP`@TfZjQCkQSgNCGMy``<\ngJP`@TfZjQCkQSgNCGMy``>\ngJP`@TfZjQCkQSgNbgMy``<\ngJP`@TfZjQCkQSgNbgMy``>\ngJP`@TfZjQCkQSj|pP>\ngJP`@TfyhCiRs]CZv\ngJP`@TfyhCiRs]CZz\ngJP`@dfVhChqSdmu`dH\ngJP`@dfVhChqSdmu`gp\ngJP`@dfVhChqSdmuoDH\ngJP`@dfVhChqSdmuoGp\ngJP`@dfVhChqSdn]EN[kAHP\ngJP`@dfVhChqSdn]EN[kAO`\ngJP`@dfVhChqSdn]EN[k^HP\ngJP`@dfVhChqSdn]EN[k^O`\ngJP`@dfVhChqSduu`dH\ngJP`@dfVhChqSduuoDH\ngJP`@dfVhChqSdv]EN[kAHP\ngJP`@dfVhChqSdv]EN[k^HP\ngJP`@dfVhChqShmu`dH\ngJP`@dfVhChqShmu`gp\ngJP`@dfVhChqShn]EN[kAHP\ngJP`@dfVhChqShn]EN[kAO`\ngJP`@dfVhChqShuu`dH\ngJP`@dfVhChqShv]EN[kAHP\ngJP`@dfvdCkQrT\ngJP`@dfvdCkQrV|OP\ngJP`@dfvdCkQrWNbgH\ngJP`@dfvdCkQrWNbgMx^`\ngJP`@dfvhCkQrV|HP\ngJP`@dfvhCkQrV|O`\ngJP`@dfvhCkQrWNbgMxP`\ngJP`@dfvhCkQrWNbgMx_@\ngJP`@dfvhCkQrZ|HP\ngJP`@dfzhCkQrV|HP\ngJP`@dfzhCkQrWICEN[pa@\ngJP`@dfzjQCkQrWNBgMxP`<\ngJP`@dfzjQCkQrWNBgMxP`>\ngJP`@dfzjQCkQrWNBgMx_@<\ngJP`@dfzjQCkQrWNBgMx_@>\ngJP`ADkjhChaSdnRFJ\\wVBP`\ngJP`ADkjjIChaSdn\\FJ[kAHP<\ngJP`AdefdCiQU][Yv\ngJP`AdijdChabdmt`gh\ngJP`AdijdChabdn\\FN[iAOP\ngJP`AdijdCkAdf~P]l}@\ngJP`AdijjQChabdmt`dH<\ngJP`AdijjQChabdmt`dH>\ngJP`AdijjQChabdmt`gp<\ngJP`AdijjQChabdmt`gp>\ngJP`AdijjQChabdmtoDH<\ngJP`AdijjQChabdmtoDH>\ngJP`AdijjQChabdnRFJ\\wRBP`<\ngJP`AdijjQChabdnRFJ\\wRBP`>\ngJP`AdijjQChabdn\\FJ[iAHP<\ngJP`AdijjQChabdn\\FJ[iAHP>\ngJP`AdijjQChabdn\\FJ[iAO`<\ngJP`AdijjQChabdn\\FJ[iAO`>\ngJP`AdijjQChabdn\\FN[iAHP<\ngJP`AdijjQChabdn\\FN[iAHP>\ngJP`AdijjQChabdn\\FN[iAO`<\ngJP`AdijjQChabdn\\FN[iAO`>\ngJP`AdijjQChabdn\\FN[i^O`<\ngJP`AdijjQChabdut`dH<\ngJP`AdijjQChabdut`dH>\ngJP`AdijjQChabdv\\FJ[iAHP<\ngJP`AdijjQChabdv\\FJ[iAHP>\ngJP`AdijjQChabdv\\FN[iAHP>\ngJP`AdijjQChabhmt`dH<\ngJP`AdijjQChabhmt`dH>\ngJP`AdijjQChabhn\\FN[iAHP<\ngJP`AdijjQChabhn\\FN[iAHP>\ngJPa@erS[RAuhyJ\ngJPa@erS[RAuhyK^Gh\ngJPa@erS[TAuhyK^DH\ngJPa@erS[TAuhyK^Gp\ngJPa@erS[TAuhyM^DH\ngJPa@mrSKTAtXitVzpRD\ngJPaAiJTuTAtPqRVzPRD>\ngJPdAePF`Rnj`NlFJ\\xLTwdB>\ngJPdAiPJ`Rfj`NlFI\\xLTwa|>\ngJPdAiPJ`Rfj`NlFIlxLTwR|P`>\ngJPdAiPJ`Rfj`NlFIlxLTwaB>\ngJPdHaBFDRij`NlFN\\dLTyoLD>\ngJPdHaVFlRij`NlFNksA@>\ngJPdI`xJ`RVj`NmEIkh^HP>\ngJPeI`VIDTiKUPGVbdutODH>\ngJPh@iPIMuHGVcdh\ngJPh@iPIMuHGVcdmx^`\ngJPh@iPIMuPGVcdmxP`\ngJPhAePIWUPGQCEIkjAHP>\ngJPhAePIWUPGQCEIlxLTwTBP`>\ngJPhAePIWUPGQCIIkjAHP>\ngJPhAePIWUPGQCIIlxLTwTBP`>\ngJPhAePIWUPGQCIIlxL\\wTBP`>\ngJPhDPDIMuTbGRcd<\ngJPhE`DIMsPGVcdmxP`\ngJPhHaVITuPGQCGQ[kAHP>\ngJPhI`xIKTpGVbdmtODH\ngJPhIaVIKTpGVbdmxP`\ngJPhIaVIKTpGVbdmx_@\ngJPhLPDIKTpGRbd\ngJPhLQDIKTpGRbd\ngJPhLQxIKTpGRbf|G`\ngJPhaePRUrTuTAu`qK]KqB>\ngJPhaePRUrTuTAu`qM]KqB>\ngJPhaePRUrTuTAu`qMgAbfzWbD>\ngJPi@cPGdfVhCkQSkNbgMu`gp\ngJPiLPDGdejXCiQR\ngJQ@@dlp@]RMumgX=\ngJQ@@dlp@]RMumgh\ngJQ@@dlp@]RMungh=\ngJQ@@dls@]FJ\\enmta@\ngJQ@@dls@]FJ\\eoBD\ngJQ@@dls@]FJ\\foBD\ngJQ@@dls@]JJkk[OP\ngJQ@@dls@]JJkk]Np\ngJQ@@dls@]JJkk]OP\ngJQ@@dlu@]FJ\\enlDa@\ngJQ@@dluQH]FJ\\enlD~@<\ngJQ@@dluQH]FJ\\enlD~@>\ngJQ@@dmP@]RMumgX=\ngJQ@@dmP@]RMumgh\ngJQ@@dmP@]RMungh=\ngJQ@@dmP@]RN\\FJ[k]OP\ngJQ@@dmP@]RN\\FN[k[OP\ngJQ@@dmS@]FJ\\enmta@\ngJQ@@dmS@]FJ\\eoBD\ngJQ@@dmS@]FJ\\eoCx\ngJQ@@dmS@]FJ\\es`qS][iB\ngJQ@@dmS@]FJ\\es`qs][iB\ngJQ@@dmS@]FJ\\es`qs^DH\ngJQ@@dmS@]FJ\\es`qs^Gp\ngJQ@@dmS@]FJ\\fnmta@\ngJQ@@dmS@]FJ\\foBD\ngJQ@@dmS@]JJkk[OP\ngJQ@@dmS@]JJkk]OP\ngJQ@@dmS@]JJlxL\\wVz^`\ngJQ@@dmU@]FJ\\enlDa@\ngJQ@@dmU@]FJ\\enlDa\x7FIHx`\ngJQ@@dmU@]FJ\\enmx~@\ngJQ@@dmU@]FJ\\erPqSfzpRD\ngJQ@@dmU@]FJ\\erPqSfzpRG|dcb\ngJQ@@dmU@]FJ]FnlDa@\ngJQ@@dmUQH]FJ\\enlD~@<\ngJQ@@dmUQH]FJ\\enlD~@>\ngJQ@@dmUQH]FJ\\enlD~\x7FIHx`>\ngJQ@@dmUQH]FJ\\es`qS]XIB<\ngJQ@@dmUQH]FJ\\es`qS]XIB>\ngJQ@@dmUQH]FJ\\es`qS]XI|<\ngJQ@@dmUQH]FJ\\es`qS]XI|>\ngJQ@@dmUQH]FJ\\es`qs]XI|<\ngJQ@@dmUQH]FJ\\es`qs]XI|>\ngJQ@@dmUQH]FJ\\fnlDa@<\ngJQ@@dmUQH]FJ\\fnlDa@>\ngJQ@@dmUQH]FJ\\fs`qS]XIB<\ngJQ@@dmUQH]FJ\\fs`qS]XIB>\ngJQ@@drt`]FJ\\enlD}@\ngJQ@@drt`]FJ\\enmx}@\ngJQ@@drt`]FJ\\eoLD\ngJQ@@drt`]FJ\\eoMx\ngJQ@@drt`]FJ\\eshis]XIz\ngJQ@@drt`]FJ\\eshis][qz\ngJQ@@drt`]FJ\\eshis^XH\ngJQ@@drt`]FJ\\eshis^[p\ngJQ@@drt`]FJ]EnlD}@\ngJQ@@drt`]FJ]EoLD\ngJQ@@drt`]FJ]Eshis]XIz\ngJQ@@drt`]FJ]Eshis^XH\ngJQ@@dru@]FJ\\enlDa@\ngJQ@@dru@]FJ\\enlD~@\ngJQ@@dru@]FJ\\enmxa@\ngJQ@@dru@]FJ\\eshis]XIB\ngJQ@@dru@]FJ\\eshis]XI|\ngJQ@@dru@]FJ\\eshis][qB\ngJQ@@dru@]FJ\\eshis][q|\ngJQ@@dru@]FJ\\fnlDa@\ngJQ@@dru@]FJ]EnlDa@\ngJQ@@dru@]FJ]EnlD~@\ngJQ@@dru@]FJ]Eshis]XIB\ngJQ@@dru@]FJ]Eshis]XI|\ngJQ@@dru@]FJ]FnlDa@\ngJQ@@dsR`]FJ\\e@\ngJQ@@dsR`]FJ\\eoCt\ngJQ@@dsR`]FJ\\eoMt\ngJQ@@dsR`]FJ\\eshir\ngJQ@@dsR`]FJ\\eshis][iz\ngJQ@@dsR`]FJ\\eshis^Gh\ngJQ@@dsR`]FJ\\eshis^[h\ngJQ@@dsR`]ZRRwPwm`\ngJQ@@dsR`]ZRRwpwmgh\ngJQ@@dsTrH]FJ\\enlD}@<\ngJQ@@dsTrH]FJ\\enlD}@>\ngJQ@@dsTrH]FJ\\eoLD<\ngJQ@@dsTrH]FJ\\eoLD>\ngJQ@@dsTrH]FJ\\eoMx<\ngJQ@@dsTrH]FJ\\eoMx>\ngJQ@@dsTrH]FJ\\erPqSfzpSt>\ngJQ@@dsTrH]FJ\\erPqSf|pP<\ngJQ@@dsTrH]FJ\\erPqSf|pP>\ngJQ@@dsTrH]FJ\\eshis]XIz<\ngJQ@@dsTrH]FJ\\eshis]XIz>\ngJQ@@dsTrH]FJ\\eshis][qz<\ngJQ@@dsTrH]FJ\\eshis][qz>\ngJQ@@dsTrH]FJ\\eshis^XH<\ngJQ@@dsTrH]FJ\\eshis^XH>\ngJQ@@dsTrH]FJ\\eshis^[p<\ngJQ@@dsTrH]FJ\\eshis^[p>\ngJQ@@dsURH]FJ\\enlDa@<\ngJQ@@dsURH]FJ\\enlDa@>\ngJQ@@dsURH]FJ\\enlD~@<\ngJQ@@dsURH]FJ\\enlD~@>\ngJQ@@dsURH]FJ\\enmxa@<\ngJQ@@dsURH]FJ\\enmxa@>\ngJQ@@dsURH]FJ\\enmx~@>\ngJQ@@dsURH]FJ\\erPqSfzpRD<\ngJQ@@dsURH]FJ\\erPqSfzpRD>\ngJQ@@dsURH]FJ\\erPqSfzpSx<\ngJQ@@dsURH]FJ\\erPqSfzpSx>\ngJQ@@dsURH]FJ\\erPqSfzwbD>\ngJQ@@dsURH]FJ\\erPqSfzwcx>\ngJQ@@dsURH]FJ\\es`qs]XIB<\ngJQ@@dsURH]FJ\\es`qs]XIB>\ngJQ@@dsURH]FJ\\es`qs]XI|<\ngJQ@@dsURH]FJ\\es`qs]XI|>\ngJQ@@dsURH]FJ\\es`qs][qB<\ngJQ@@dsURH]FJ\\es`qs][qB>\ngJQ@@dsURH]FJ\\eshis]XIB<\ngJQ@@dsURH]FJ\\eshis]XIB>\ngJQ@@dsURH]FJ\\eshis]XI|<\ngJQ@@dsURH]FJ\\eshis]XI|>\ngJQ@@dsURH]FJ\\eshis][qB<\ngJQ@@dsURH]FJ\\eshis][qB>\ngJQ@@dsURH]FJ\\eshis][qC~RAQ@>\ngJQ@@dsURH]FJ\\eshis][q|<\ngJQ@@dsURH]FJ\\eshis][q|>\ngJQ@@dsURH]FJ\\fnlDa@<\ngJQ@@dsURH]FJ\\fnlDa@>\ngJQ@@dsURH]FJ\\frPqSfzpRD<\ngJQ@@dsURH]FJ\\frPqSfzpRD>\ngJQ@@dsURH]FJ\\fs`qs]XIB<\ngJQ@@dsURH]FJ\\fs`qs]XIB>\ngJQ@@dsURH]FJ\\fshis]XIB<\ngJQ@@dsURH]FJ\\fshis]XIB>\ngJQ@@dsURH]FJ\\fshis][qB<\ngJQ@@dsURH]FJ]EnlDa@<\ngJQ@@dsURH]FJ]EnlDa@>\ngJQ@@dsURH]FJ]Es`qs]XIB<\ngJQ@@dsURH]FJ]Es`qs]XIB>\ngJQ@@dsURH]FJ]Es`qs]XI|<\ngJQ@@dsURH]FJ]Es`qs]XI|>\ngJQ@@dsURH]FJ]Eshis]XIB<\ngJQ@@dsURH]FJ]Eshis]XIB>\ngJQ@@dsURH]FJ]Eshis]XI|<\ngJQ@@dsURH]FJ]FnlDa@>\ngJQ@@dwM@]FJ\\eneta@\ngJQ@@dwM@]FJ\\eoBD\ngJQ@@dwM@]FJ\\es`is]KiB\ngJQ@@dwM@]FJ\\eshis]KiB\ngJQ@@dwM@]FJ\\eshis]Ki|\ngJQ@@dwM@]FJ\\eshis^DH\ngJQ@@dwM@]FJ\\eshis^Gp\ngJQ@@dwM@]FJ\\foBD\ngJQ@@dwM@]ZVRwpvmdH\ngJQ@@dwM@]ZVRwpvndH\ngJQ@@dwM@]ZVRytTyoam]HP\ngJQ@@dwM@]ZVRytTyoam]O`\ngJQ@@eMP@]HJ[yAvsl=\ngJQ@@eMP@]HJ[yAvst\ngJQ@@eMP@]HJ[yAwSt=\ngJQ@@eMP@]HJ[y^vsl=\ngJQ@@eMP@]HJ[y^vst\ngJQ@@eMP@]HJ[y^wSt=\ngJQ@@eMP@]HJ\\xLTwrCngh\ngJQ@@eMP@]HJ\\xLTwr}ngh\ngJQ@@eMP@]HJ\\xL\\wrCmgh\ngJQ@@eMP@]HJ\\xL\\wr}mgh\ngJQ@@eMP@]HJkyAvsl=\ngJQ@@eMP@]HJkyAvst\ngJQ@@eMP@]HJkyAwSt=\ngJQ@@eMP@]HJlxLTwrCngh\ngJQ@@eMP@]HJlxL\\wrCmgh\ngJQ@@eMS@]TLTyK]HIB\ngJQ@@eMS@]TLTyK]HI|\ngJQ@@eMS@]TLTyK_HNzP`\ngJQ@@eMS@]TLTyK_HNzP\x7Fdd\\P\ngJQ@@eMS@]TLTyK_HNz_@\ngJQ@@eMS@]TLTyKgAbfzPRD\ngJQ@@eMS@]TLTyKgAbfzPSx\ngJQ@@eMS@]TLTyKgAbfzWbD\ngJQ@@eMS@]TLTyKgAbf~P]ta@\ngJQ@@eMS@]TLTyKgAbf~P]t~@\ngJQ@@eMS@]TLTyKgAbf~Wmta@\ngJQ@@eMS@]TLTyKgAbf~Wmt~@\ngJQ@@eMS@]TLTyKgAcfzPRD\ngJQ@@eMS@]TLTyKgAcf~P]ta@\ngJQ@@eMS@]TLTyKgAcf~Wmt~@\ngJQ@@eMS@]TLTyM]HIB\ngJQ@@eMS@]TLTyM_HNzP`\ngJQ@@eMS@]TLTyMgAbfzPRD\ngJQ@@eMS@]TLTyMgAbfzWbD\ngJQ@@eMS@]TLTyMgAbf~P]ta@\ngJQ@@eMS@]TLTyMgAbf~Wmta@\ngJQ@@eMS@]TLTyMgAcf~P]ta@\ngJQ@@eMS@]TLUYK]HIB\ngJQ@@eMS@]TLUYK_HNzP`\ngJQ@@eMS@]TLUYKgAbfzPRD\ngJQ@@eMS@]TLUYKgAbf~P]ta@\ngJQ@@eMS@]TLUYKgAbf~P]t~@\ngJQ@@eMS@]TLUYKgAcfzPRD\ngJQ@@eMS@]TLUYKgAcf~P]ta@\ngJQ@@eMS@]TLUYM_HNzP`\ngJQ@@eMS@]TLUYMgAbfzPRD\ngJQ@@eMS@]TLUYMgAbf~P]ta@\ngJQ@@eMS@]XLdwrCmgh\ngJQ@@eMS@]XLdwrCngX\ngJQ@@eMS@]XLdwrCngh\ngJQ@@eMS@]XLdypXiodG]OP\ngJQ@@eMS@]XLdypXyodG[OP\ngJQ@@eMS@]XLdypXyodG]OP\ngJQ@@eMS@]XLeYpXiodG]OP\ngJQ@@eMS@]XLeYpXyodG[OP\ngJQ@@eMU@]TLTyK_HNBP`\ngJQ@@eMU@]TLTyK_HNBP\x7Fdd\\P\ngJQ@@eMU@]TLTyK_HN|_@\ngJQ@@eMU@]TLTyK_KvBP`\ngJQ@@eMU@]TLTyKdabgM|`xIB\ngJQ@@eMU@]TLTyKdabgM|oXIB\ngJQ@@eMU@]TLTzM_HNBP`\ngJQ@@eMU@]TLUYK_HNBP`\ngJQ@@eMU@]TLUYK_HNBP\x7Fdd\\P\ngJQ@@eMURH]TLTyK_HNB_@<\ngJQ@@eMURH]TLTyK_HNB_@>\ngJQ@@eMURH]TLTyK_HNB__dd\\P<\ngJQ@@eMURH]TLTyK_HNB__dd\\P>\ngJQ@@eMURH]TLTyK_KvB_@<\ngJQ@@eMURH]TLTyKdabgM|`xI|<\ngJQ@@eMURH]TLTyKdabgM|`xI|>\ngJQ@@eMURH]TLTyKgAbf~P\\Da@<\ngJQ@@eMURH]TLTyKgAbf~P\\Da@>\ngJQ@@eMURH]TLTyKgAbf~P\\D~@<\ngJQ@@eMURH]TLTyKgAbf~P\\D~@>\ngJQ@@eMURH]TLTyKgAbf~WlDa@<\ngJQ@@eMURH]TLTyKgAbf~WlDa@>\ngJQ@@eMURH]TLTyKgAcf~P\\D~@<\ngJQ@@eMURH]TLTyKgAcf~P\\D~@>\ngJQ@@eMURH]TLTyKgAcf~WlD~@<\ngJQ@@eMURH]TLTyKgAcf~WlD~@>\ngJQ@@eMURH]TLTyM_HNBP`<\ngJQ@@eMURH]TLTyM_HNBP`>\ngJQ@@eMURH]TLTyMgAbf~P\\Da@<\ngJQ@@eMURH]TLTyMgAbf~P\\Da@>\ngJQ@@eMURH]TLTyMgAbf~WlDa@<\ngJQ@@eMURH]TLTyMgAbf~WlDa@>\ngJQ@@eMURH]TLTyMgAcf~P\\Da@<\ngJQ@@eMURH]TLTyMgAcf~P\\Da@>\ngJQ@@eMURH]TLTzK_HNB_@<\ngJQ@@eMURH]TLTzK_HNB_@>\ngJQ@@eMURH]TLTzKgAcf~P\\D~@<\ngJQ@@eMURH]TLTzKgAcf~P\\D~@>\ngJQ@@eMURH]TLTzMgAbf~P\\Da@<\ngJQ@@eMURH]TLTzMgAbf~P\\Da@>\ngJQ@@eMURH]TLUYKgAbf~P\\Da@<\ngJQ@@eMURH]TLUYKgAbf~P\\Da@>\ngJQ@@eMURH]TLUYKgAbf~P\\D~@<\ngJQ@@eMURH]TLUYKgAcf~P\\D~@<\ngJQ@@eMURH]TLUYKgAcf~P\\D~@>\ngJQ@@eMURH]TLUYM_HNBP`<\ngJQ@@eMURH]TLUYM_HNBP`>\ngJQ@@eMURH]TLUYMgAbf~P\\Da@<\ngJQ@@eMURH]TLUYMgAbf~P\\Da@>\ngJQ@@eMURH]TLUZKgAcf~P\\D~@<\ngJQ@@eMURH]TLUZKgAcf~P\\D~@>\ngJQAAIRYjPNcENRytTyoLD>\ngJQAAIRYjPNcENbwVB^`>\ngJQAAIRYjPNcENbypXynlD}@>\ngJQDAJATBTuTAtPqtZzpRD\ngJQDHHPpbU]TAu`isdabgMy``>\ngJQDL@aABSKTAuhiK^DH\ngJQDL@aABS[TAuhyK^DH\ngJQH@jAJZ`@z`[k[OP\ngJQH@jAJZ`@z`[k]OP=\ngJQH@jAJZ`@z`[y^vsl=\ngJQH@jAJZ`@z`[y^vst\ngJQH@jAJZ`@z`[y^wSt=\ngJQH@jAJZ`@z`\\xLTwr}ngh\ngJQH@jAJZ`@z`\\xL\\wVv^`\ngJQH@jAJZ`@z`\\xL\\wr}mgh\ngJQH@jAJZf@zHXyKgAbfzWbD\ngJQH@jAJZf@zHXyMgAbfzWbD\ngJQH@jAJZf@zHXyMgAbf~Wmta@\ngJQH@jAJZj@zHXyK]XIB\ngJQH@jAJZjdPzHXyKgAbfzpRD<\ngJQH@jAJzj@zhXitZ~`\\Da@\ngJQHB@aIfe@zTdwPwm`\ngJQHB@aInZ@zTlwPvm`\ngJQHB@aInZ@ztTyoEt\ngJQHBDQIfjdPztTyoLD<\ngJQHBHaIfjdPztTyoLD<\ngJQHBHaIfjdPztTyoLD>\ngJQHBIAIfjdPztTyoLD>\ngJQHBOAIfjdPztTyna{A@<\ngJQHD@aIej@zLTzKgQSfzpRD\ngJQHD@aIff@zLTyKgQSfzwRD\ngJQHD@aIff@ztdeoao[HP\ngJQHD@aIfjdPzLTyKgQSfzpRD<\ngJQHD@aIfjdPzLTyKgQSfzpRD>\ngJQHDIAIfjdPzLTyKgQSfzpRD<\ngJQHH@aIZ`@zd[x^vsl=\ngJQHH@aIZ`@zd[x^vst\ngJQHH@aIZ`@zd[x^wSt=\ngJQHH@aIZ`@zd\\xL\\wp}mgh\ngJQHH@aIZf@zLTyK]CqB\ngJQHH@aIZf@zLTyK_CvzP`\ngJQHH@aIZf@zLTyKgAbfzGbD\ngJQHH@aIZf@zLTyM_CvzP`\ngJQHH@aIZj@zLTyK_CvBP`\ngJQHH@aIZjbPzLTyK_CvB_@<\ngJQHH@aJmj`PzHTyK]XIB<\ngJQHH@aJmj`PzHTyK]XIB>\ngJQHH@aJmj`PzHTyKgQSfzpRD<\ngJQHH@aJmj`PzHTyKgQSfzpRD>\ngJQHH@aJmj`PzHTyM]XIB<\ngJQHH@aJmj`PzHTyM]XIB>\ngJQHH@aJmj`PzHTzK]XIB<\ngJQHH@aJmj`PzHTzK]XIB>\ngJQHH@aJmj`PzHTzM]XIB>\ngJQHHBqIZ`@zd\\xLTwp}ngh\ngJQHHGAIZ`@zd[x^vsl=\ngJQHHGAIZ`@zd[x^vst\ngJQHHGAIZ`@zd[x^wSt=\ngJQHHGAIZ`@zd\\xLTwVz^`\ngJQHHGAIZ`@zd\\xL\\wVv^`\ngJQHHGAIZf@zLTyK]CqB\ngJQHHGAIZf@zLTyK_CvzP`\ngJQHHGAIZj@zLTyK_CvBP`\ngJQHHGAIZjbPzLTyK_CvB_@<\ngJQHHGAIZjbPzLTyK_CvB_@>\ngJQHHGAIZjbPzLTyKgAbf~GlDa@>\ngJQHHGAIZjbPzLTyM_CvBP`<\ngJQHHGAIZjbPzLTyM_CvBP`>\ngJQHHOAIZ`@zd[k[Np=\ngJQHHOAIZ`@zd[k[OP\ngJQHHOAIZ`@zd[k]OP=\ngJQHHOAIZ`@zd[x^vsl=\ngJQHHOAIZ`@zd[x^vst\ngJQHHOAIZ`@zd[x^wSt=\ngJQHHOAIZ`@zd\\xLTwVz^`\ngJQHHOAIZ`@zd\\xLTwp}ngh\ngJQHHOAIZ`@zd\\xL\\wVv^`\ngJQHHOAIZ`@zd\\xL\\wp}mgh\ngJQHHOAIZf@zLTyM_CvzP`\ngJQHHOAIZj@zLTyK]XIB\ngJQHHOAIZj@zLTyK_CvBP`\ngJQHHOAIZjbPzLTyKgAbf~GlDa@<\ngJQHHOAIZjbPzLTyKgAbf~GlDa@>\ngJQHHOAIZjbPzLTyMgAbf~GlDa@>\ngJQHHOAIZjbPzLTzKgAcf~GlD~@>\ngJQHL@aIZf@ztTeoBD\ngJQHL@aIZf@ztTfnaxa@\ngJQHL@aIZf@ztTfoBD\ngJQHL@aIZjb`ztTeoBD<\ngJQHL@aIZjb`ztTeoBD>\ngJQHL@aIZjb`ztTes`qs^DH<\ngJQHL@aIZjb`ztTes`qs^DH>\ngJQHL@aJZf@zHXiK]HIB\ngJQHL@aJZf@zHXiK]HI|\ngJQHL@aJZf@zHXiK]KqB\ngJQHL@aJZf@zHXiM]HIB\ngJQHL@aJZf@zHXjK]HIB\ngJQHL@aJZf@zHXjK]HI|\ngJQHL@aJZf@zHXjM]HIB\ngJQHL@aJZjdPzHXiK]HIB<\ngJQHL@aJZjdPzHXiK]HIB>\ngJQHL@aJZjdPzHXjK]HIB<\ngJQHL@aJZjdPzHXjK]HIB>\ngJQHLHaIZf@ztTeoBD\ngJQHLHaIZf@ztTfoBD\ngJQHLHaIZjb`ztTeoBD<\ngJQHLHaIZjb`ztTeoBD>\ngJQHLJqIZjb`ztTeoBD>\ngJQHLLQIZf@ztTfoBD\ngJQH`jBRnRfj`NbFNSYpXioe{AHP>\ngJQI@jA\\eMP@]PN\\FJ[y^wSt\ngJQI@jA\\eMP@]PN\\FN[y^vst\ngJQI@jA\\eMS@]DL\\fs`qS]KqB\ngJQI@jA\\eMS@]DL\\fs`qS_KvzP`\ngJQIHO@RdmP@]RM|O[Yv=\ngJQ`@bdvu@]JNP\ngJQ`@ldru@]ZJRwaB\ngJQ`@ldru@]ZJRwa|\ngJQ`@ldru@]ZJRytTyoBD\ngJQ`@ldru@]ZJRytTyoCx\ngJQ`@ldru@]ZJSWaB\ngJQ`AbeMU@]XLTyHXis^HH\ngJQa@bnR[Z`NeGH\ngJQdAcJATBTuTAt`qs`qR>\ngJQeAcJATByJZj@zPXypXioEx>\ngJQhAbjAJzj@zpXioHD\ngJQhAbjAJzj@zpYIoHD\ngJQhAbjAJzj@zpYIs`qS^PH>\ngJQhHl@aJmj`PzpTeshis^DH<\ngJQhHl@aJmj`PzpTeshis^DH>\ngJQhHlOAJfj@zpXeoBD\ngJQhHlOAJfj@zpXerPqSf|HP\ngJQhHlOAJfj@zpXfoBD\ngJQhHlOAJfj`PzpXfs`qs^DH<\ngJQhHlOAJfj`PzpXfs`qs^DH>\ngJR@@lTfVhCiRS]C^w~tP\ngJR@@lTfphCjYnam[\x7FZX=\ngJR@ALTkfXCiAU][Yw~t@\ngJR@ALTkfXCiAU][Y{~t@\ngJR@`lQJyIej@zTdwPwm\x7FmD\ngJR@`lQJyIej@zTdwPwn\x7FmD\ngJR@`lQJyIej@zTdwP{n\x7FmD\ngJR@`lUqeIej@zTdwPwm\x7FmD\ngJR@`l]qeIlJ@zf[h[V\x7Fvf@=\ngJRA@lQJSKTAthi\x7FZH\ngJRA@lUrSKTAtiInao[\x7FZH\ngJRA@lUrSKTAtiInao]\x7FZH\ngJRAALSrUsLAt`jnml{\x7FZ@\ngJRAAL]JUsLAt`jnmt}\x7FZ@\ngJT@@TfRDCjInao[@\ngJT@@TfVhCkQSf|pP\ngJT@@TfVhCkQSkNbgMtNxH\ngJT@@TfZjQCkQSf|pP<\ngJT@@TfZjQCkQSf|pP>\ngJT@@TfZjQCkQSgNCGMy``<\ngJT@@TfZjQCkQSgNCGMy``>\ngJT@@TfZjQCkQSgNbgMy``<\ngJT@@TfZjQCkQSgNbgMy``>\ngJT@@TfZjQCkQSkNCGMy``<\ngJT@@TfZjQCkQSkNCGMy``>\ngJT@@TfphCjYnam[@\ngJT@@TfphCjYnam]@\ngJT@@TfyhCiRs]CZv\ngJT@@TfyhCiRs]CZz\ngJT@@TfyhCiRs]Cjv\ngJT@@TfyhCiRs]Cjz\ngJT@@TfyhCiRsgASfzGUl\ngJT@@TfyhCiRsgQSfzGUt\ngJT@@TjZhChabgMt`xH\ngJT@@TjZhChabgMt`xO{P@=\ngJT@@TjZhChabgMt`{w{P@\ngJT@@TjZhChabgNRFJ\\wRC``\ngJT@@TjZhChabgNRFJ\\wrC`gp\ngJT@@TjZhChabgN\\EN[iAwov`@\ngJT@@TjZhChabgN\\FN[iAp_v`@\ngJT@@TjZhChabgUt`xO{P@\ngJT@@TjZhChabgV\\FN[iAp_v`@\ngJT@@TjZhCiBc]K^w~t@=\ngJT@@TjZhCiBc]K^{~t@\ngJT@@TjZhCiBcgASfzV}w}h@\ngJT@@TjZjAChabgN\\FN[iApP<\ngJT@@TjZjAChabgN\\FN[iApP>\ngJT@@TjZjAChabgN\\FN[iAw`<\ngJT@@TjZjAChabgN\\FN[iAw`>\ngJT@@TjZjAChabgVRFJ\\wRC``<\ngJT@@TjZjAChabgVRFJ\\wRC``>\ngJT@@TjZjAChabgV\\FN[iApP>\ngJT@@defhChqSdmu`dO{Q@=\ngJT@@defhChqSdn\\FJ[kAH_vb@\ngJT@@defhChqSdv\\FJ[kAH_vb@\ngJT@@dfRHCiIK_C^vP\x7FmD\ngJT@@dfRHCiIK_C^zP\x7FmD\ngJT@@dfRHCiIK_CnvP\x7FmD\ngJT@@dfRHCiIKgQSf~F}ta\x7FZH\ngJT@@dfRHCiIM_C^vP\x7FmD\ngJT@@dfRHCiIM_C^zP\x7FmD\ngJT@@dfRHCiIMgQSf~F}ta\x7FZH\ngJT@@dfVhChqSdmu`dO{Q@\ngJT@@dfVhChqSdn\\FN[kAH_vb@\ngJT@@dfVhChqSdn\\FN[k^H_vb@\ngJT@@dfVhChqSdn]EN[x]pRG}h`\ngJT@@dfVhChqSduu`dO{Q@\ngJT@@dfVhChqSduuoDO{Q@\ngJT@@dfVhChqSdu|NxIC~tP\ngJT@@dfVhChqSdv\\FN[kAH_vb@\ngJT@@dfVhChqShmu`dO{Q@\ngJT@@dfVhChqShmu`gw{Q@\ngJT@@dfVhChqShn\\FN[kAH_vb@\ngJT@@dfVhChqShuu`dO{Q@\ngJT@@dfVhChqShu|NxIC~tP\ngJT@@dfVhChqShv\\FN[kAH_vb@\ngJT@@dfVhCkRRV~F}la\x7FZH\ngJT@@dfVhCkRRV~F}ta\x7FZH\ngJT@@dfVhCkRRWNbgM|M{iC~tP\ngJT@@dfVhCkRRZ~F}ta\x7FZH\ngJT@@dfphCiYK_CZvP`=\ngJT@@dfvdCkQrWNBgH\ngJT@@dfvdCkQrWNbgH\ngJT@@dfvdCkRrVzFut\ngJT@@dfvhCkQrV|HP\ngJT@@dfvhCkQrWNbgMxP`\ngJT@@dfvhCkQrZzGRD\ngJT@@dfvhCkQrZ|HP\ngJT@@dfvhCkRrV~Fula@\ngJT@@dfvhCkRrV~Futa@\ngJT@@dfvhCkRrZ~Fula@\ngJT@@dfvhCkRrZ~Futa@\ngJT@@dfzhCkQrV|HP\ngJT@@dfzhCkQrWICEN[pa@\ngJT@@dfzjQCkQrWNBgMxP`<\ngJT@@dfzjQCkQrWNBgMxP`>\ngJT@ADiihCjabgI[kAH_vP`=\ngJT@ADiihCjabgI[kAOovP`\ngJT@ADiihCjabgI[y]pRG}dH=\ngJT@ADiihCjabgI\\xLTwVBP\x7Fla@\ngJT@ADiihCjabgI\\xLTwr{`dO{HP\ngJT@ADiihCjabgIkkAH_vP`\ngJT@ADiihCjabgIlxLTwr{`dO{HP\ngJT@ADiihCjabgQkkAH_vP`=\ngJT@ADiihCkAdfzvso}dH=\ngJT@ADiihCkAdfzwSw}dH=\ngJT@ADiihCkAdgNCEM|n{i{~rD@\ngJT@ADiihCkAdgNCGM|n{Y{~rD@\ngJT@ADjZhCjabgI[yApRG}dH=\ngJT@ADjZhCjabgI[yApRG}h@=\ngJT@ADjZhCjabgI[yApRG}i@\ngJT@ADjZhCjabgI[yAwbG}dH\ngJT@ADjZhCjabgI\\xL\\wrC`dO{P@\ngJT@ADjZhCjabgIkyApRG}dH=\ngJT@ADjZhCjabgQ[yApRG}dH\ngJT@ADjZhCjabgQkyApRG}dH\ngJT@ADjZhCkBbV~W]ta\x7FYB@=\ngJT@ADjzhChaSdmu`dO{P@\ngJT@ADjzhChaSdn\\FN[kAH_v`@\ngJT@ADjzhChaSdn]EN[kAH_v`@\ngJT@ADjzhChaSduu`dO{P@\ngJT@ADjzhChaShmu`dO{P@\ngJT@ADjzhCkBRV~f}la\x7FZ@\ngJT@ADjzhCkBRV~f}l~\x7FZ@\ngJT@ADjzhCkBRV~f}ta\x7FZ@\ngJT@ADjzhCkBRWNbgM}M{iC~t@\ngJT@ADjzhCkBRZ~f}la\x7FZ@\ngJT@ADjzhCkBRZ~f}ta\x7FZ@\ngJT@ADjzjAChaSdmu`dH<\ngJT@ADjzjAChaSdmu`dH>\ngJT@ADjzjAChaSdn]EN[kAHP<\ngJT@ADjzjAChaSdn]EN[kAHP>\ngJT@ADjzjAChaSduu`dH<\ngJT@ADjzjAChaSduu`dH>\ngJT@ADkf@CjAnml{\x7FZ@=\ngJT@ADkf@CjAnml}\x7FZ@\ngJT@ADkf@CjAnmt}\x7FZ@=\ngJT@ADkf@CjAoiw[N\x7Fv`@=\ngJT@ADkf@CjAoiw[O_v`@\ngJT@ADkf@CjAoiw]O_v`@=\ngJT@ADkfXChaSdmundO{P@\ngJT@ADkfXChaSduundO{P@\ngJT@ADkfXCiAU][i{~t@\ngJT@ADkj@CjAnml{\x7FZ@=\ngJT@ADkj@CjAnml}\x7FZ@\ngJT@ADkj@CjAnmt}\x7FZ@=\ngJT@ADkjXChaSdmundO{P@\ngJT@AdefdCiQU][Yv\ngJT@AdefdCiQU][Yz\ngJT@AdefdCiQU][iv\ngJT@AdefdCiQUgAbf~G]t}@\ngJT@Adii@CiAS][Yw~t@\ngJT@Adii@CiAS_Knv]\x7Fm@\ngJT@Adii@CiASgAbf~W]t{\x7FZ@\ngJT@Adii@CiASgAcf~W]l}\x7FZ@\ngJT@AdiiXChabdmtngw{P@\ngJT@AdiiXChabdv\\FJ[y]wRG}h@\ngJT@AdiiXChabdv\\FN[y]wRG}h@\ngJT@AdiidChabdn\\FN[i]O_v`@\ngJT@AdiidChabdn\\FN[q]\x7FZ@\ngJT@AdiidCkAdfzwSo}h@\ngJT@AdiidCkAdfzwSw}h@\ngJT@AdiidCkAdgNCEM|n{i{~t@\ngJT@AdiidCkAdgNCGMumgo{P@\ngJT@AdiidCkAdgNCGMungo{P@\ngJT@AdiidCkAdgNCGM|n{Y{~t@\ngJT@AdiidCkAdgNCGM|n{i{~t@\ngJT@AdijdChabdmt`go{P@\ngJT@AdijdChabdn\\FJ[iAO_v`@\ngJT@AdijdChabdn\\FN[iAO_v`@\ngJT@AdijdChabdn\\FN[qA\x7FZ@\ngJT@AdijdCkAdf~P]t{\x7FZ@\ngJT@AdijdCkAdf~P]t}@\ngJT@AdijdCkAdf~Wmt}@\ngJT@AdijdCkAdgNCEM|`{iz\ngJT@AdijdCkAdgNCGM|`{Y{~t@\ngJT@AdijdCkAdgNCGM|`{iz\ngJT@AdijjQChabdmt`dO{P@<\ngJT@AdijjQChabdmt`dO{P@>\ngJT@AdijjQChabdnRFJ\\wRBP`>\ngJT@AdijjQChabdv\\FJ[iAHP<\ngJT@AdijjQChabdv\\FJ[iAH_v`@<\ngJT@AdijjQChabdv\\FJ[iAH_v`@>\ngJT@AdijjQChabhmt`dO{P@<\ngJT@AdijjQChabhv\\FJ[iAH_v`@<\ngJT@AdijjQChabhv\\FJ[iAH_v`@>\ngJT@`QIeIfjdPztTys`qs^XH>\ngJT@`QIeIlJ@zf[h[Vp\ngJT@`aJyIdb@zRRypXyoaw[H_vb@\ngJT@`aJyIdb@zRRytTyoaw]H_vb@\ngJT@aAteJz`@z`[k[N\x7Fv`@=\ngJT@aAteJz`@z`[k[O_v`@\ngJT@aAteJz`@z`[k]O_v`@=\ngJT@aAteJzj@zHTyK]XIC~t@\ngJTA@QJSIBAuDwPwm`\ngJTA@QJSMUHauhis^XH<\ngJTA@QJSMUHauhis^XH>\ngJTA@QJSXTAuLwPvm`\ngJTA@QJUMTAtPqSgICEN[iApP\ngJTA@SJSXTAuLwPvm`\ngJTA@SJUMTAtPqSgICEN[iApP\ngJTA@SJUMTAtPqSgICEN[yApSx\ngJTA@aJRsTAtXirWNCEM|NxIC~tP\ngJTA@aJRsTAtXir[NCEM|NxIC~tP\ngJTA@aJSIDAtdeoao[H_vb@\ngJTA@aJSIDAtdeoaw[H_vb@\ngJTA@aJSIDAtdfoao[H_vb@\ngJTA@aJSKTAtXirWNbgMu`dO{Q@\ngJTA@aJS[RAuhyKgQSd\ngJTA@aJS[TAuiYK_CZvP`\ngJTA@aJS[TAuiYM_CjzP`\ngJTAAAJU[TAuaIK_S^vP\x7Fm@\ngJTAAaJRuRAthjnml{@\ngJTAAaJRuUEAuhiK^DH>\ngJTD@UPZ`Rkj`NlFR\\zJ\\wdC~t@\ngJTDAePF`Rnj`NlFR\\xL\\wdC~t@>\ngJTDAiPJ`Rfj`NlFI\\xLTwaB>\ngJTDE`DGpRYZ`NeEMx__mD\ngJTDEaxR`RYj`NmEIlzJ\\waC~tP>\ngJTDLPDHHR[Z`NeGO{S@\ngJTDLPDPHRnh@NhFzvsl=\ngJTDLPDPHRni`NdEUumgX\ngJTDLPDPHRni`NdEUumgh\ngJTD`UPZ`DkdjzjACkAbgNbgMyO@<\ngJTD`UPZ`DkdjzjACkAbgNbgMyO@>\ngJTDe`DDHT{dfyhCiRs_CZv__mL\ngJTDlQVPHGZTejXCiQR\ngJTELPDPHtiWTpGRBd\ngJTHACPISSPGQCENlxL\\wr{`gw{HP\ngJTHAePIWUPGQCII\\xLTwTBP\x7Fm@>\ngJTHDPDIMsPGRefzFul\ngJTHE`DILmHGVbdmx^\x7FmD\ngJTHE`DILmHGVbdn]EN[p}\x7FZH\ngJTHE`DILmPGVbdmxP\x7FmD\ngJTHE`DILmPGVbdmx__mD\ngJTHE`DILmPGVbdn]EN[pa\x7FZH\ngJTHE`DILmPGVbduxP\x7FmD\ngJTHE`DILmPGVbdv]EN[pa\x7FZH\ngJTHE`DILthGVddmtM{_{Q@\ngJTHE`DILthGVddm|M{Y{~tP\ngJTHE`DILthGVddn]EN[x[wSw}h`\ngJTHE`DIMsPGVcdmxP\x7FmL\ngJTHE`DIMsPGVcdn]EN[pa\x7FZX\ngJTHE`DIMsPGVcduxP\x7FmL\ngJTHE`DIMsPGVedm|MkYC~tp\ngJTHE`DIMsPGVedu|MkYC~tp\ngJTHEaDILthGVbdn]EN[p}\x7FZH\ngJTHHPDILuPGVbgN]EN[h^p_vd@\ngJTHH`xIKUPGQbgI[x^pRD\ngJTHHaxILuHGQbgI[h^p_vTP\ngJTHI`DIKT@GTc_Cvv]\x7FmH\ngJTHI`DIKTpGRbj~Gml{\x7FZP\ngJTHI`DIKUHGRbj~Gmt}\x7FZP\ngJTHIaxIKT@GTc_Cvv]\x7FmH\ngJTHLPDIST@GRBf~P]l{@=\ngJTHLPDIST@GRBj~P]l{@=\ngJTHLPDISTpGVCEMx``\ngJTHLPDISTpGVCEN\\FJ[qA@\ngJTHLPDISTpGVCEN\\FN[iAwP\ngJTHLPDISTpGVCIM|`{Yv\ngJTHLPDISTpGVCIM|`{Yz\ngJTHLPDISTpGVCIN\\FN[yAvst\ngJTH`mPB]rS[TAuiYK_CjzP`\ngJTHe`DCeJS\\tAuhyKgQSf|H_vf@\ngJTHe`DJ]rS\\tAuiYKgQSf~Futa\x7FZX\ngJTHe`bCeJS\\tAuhyK]KiC~tp\ngJTHi`DSmJRu@AuHwp}mg_{R@\ngJTHlQxCmJTuLAu`rU_HNz^`\ngJTIE`DJTfyhCkRrV~Fula\x7FZX\ngJTILPDZTijXCkAbf|PP\ngJTIhaVCiJeJZ`@z`[k[N\x7Fvd@=\ngJTIhaVCiJeJZ`@z`[k]O_vd@=\ngJTIhabCiJeJZ`@z`[k[N\x7Fvd@=\ngJTIhabCiJeJZ`@z`[k]O_vd@=\ngJT`E`TfVhCiQR\ngJT`LPdfVhCiQR\ngJT`LPdfvhCiQs~tp\ngJT`i`iJyImi@zt\\eoCw}eL\ngJT`i`iJyImj@zt\\eoBG}eL\ngJT`i`iJyImj@zt\\foBG}eL\ngJTai`iJ{\\dvu@]ZNRwaC~rf@\ngJTai`iJ{\\dvu@]ZNSWaC~rf@\ngJU@DPdru@]ZJ\\wfC~tP\ngJU@DPdru@]ZJ\\wf}~tP\ngJU@DPdru@]ZJ\\ytTyoLG}h`\ngJU@DPdru@]ZJ]WfC~tP\ngJU@DPdru@]ZJ]YtTyoLG}h`\ngJU@DPdvt`]JN\\zJ\\`\ngJU@DPdvu@]JNP\ngJU@DPdvu@]JN\\zJ\\`\ngJU@E`drt`]ZJRwa{~tP\ngJU@E`drt`]ZJRytTyoCw}h`\ngJU@E`dru@]ZJRwaC~tP\ngJU@E`dru@]ZJRwa}~tP\ngJU@E`dru@]ZJRytTyoBG}h`\ngJU@E`dru@]ZJRytTyoC{}h`\ngJU@E`dru@]ZJSWaC~tP\ngJU@E`dru@]ZJSYtTyoBG}h`\ngJU@E`dwM@]ZVSWpvmdO{S@\ngJU@H`dlu@]FJ\\enlDa\x7FYQ@=\ngJU@H`dlu@]FJ\\fnlDa\x7FYQ@\ngJU@I`eMU@]XLdwrCmgo{R@\ngJU@LPdmS@]JJkk[Np\ngJU@LPdmS@]JJkk[OP\ngJU@LPdmS@]JJlxL\\wVv^`\ngJU@LPeMP@]HJ[yAvsl=\ngJU@LPeMP@]HJkyAvsl=\ngJU@LPeMS@]XLTwbB\ngJU@LPeMS@]XLUWbB\ngJU@LPeMU@]XLTwbB\ngJU@e`NTiMsPGVcdn]EN[pa\x7FZX\ngJUADPYRYZ`NmENksA\x7FZH\ngJUADPYR[Z`NeGH\ngJUAE`nRYZ`NmEI\\zJ\\waC~tP\ngJUAE`nRYZ`NmEIlzJ\\waC~tP\ngJUAEanRYZ`NmEI[pa\x7FZH\ngJUAEanRYZ`NmEI\\zJ\\waC~tP\ngJUDEhO@~BUMTAt`q\x7FIPh`\ngJUHEhOAJfj@zpXfoBG|eBb\ngJUHH\\@aIZf@zTTw`}~t`\ngJUHLPjAJzj@zpXioHD\ngJUIH\\@b\\dmS@]JJ[p^\x7FZP\ngJX@@dlp@]RMumgX=\ngJX@@dlp@]RMumgh\ngJX@@dlp@]RMungh=\ngJX@@dlp@]RM|N{Yv=\ngJX@@dlp@]RM|N{Yz\ngJX@@dlp@]RN\\FJ[x]wSt\ngJX@@dlp@]RN\\FN[k[OP\ngJX@@dlp@]RN\\FN[x]vst\ngJX@@dls@]FJ\\enmta@\ngJX@@dls@]FJ\\eoBD\ngJX@@dls@]FJ\\foBD\ngJX@@dls@]JJkk[OP\ngJX@@dls@]JJkk]OP\ngJX@@dlu@]FJ\\enlDa@\ngJX@@dmP@]RMumgX=\ngJX@@dmP@]RMumgh\ngJX@@dmP@]RMungh=\ngJX@@dmP@]RN\\FJ[k]OP\ngJX@@dmP@]RN\\FN[k[OP\ngJX@@dmP@]RN\\FN[x^vst\ngJX@@dmS@]FJ\\enmta@\ngJX@@dmS@]FJ\\eoBD\ngJX@@dmS@]FJ\\es`qS][iB\ngJX@@dmS@]FJ\\es`qS^DH\ngJX@@dmS@]FJ\\es`qs][iB\ngJX@@dmS@]FJ\\es`qs^DH\ngJX@@dmS@]FJ\\foBD\ngJX@@dmS@]FJ\\fs`qs][iB\ngJX@@dmS@]JJlxLTwVz]`\ngJX@@dmS@]JJlxLTwVz^`\ngJX@@dmU@]FJ\\enlDa@\ngJX@@dmU@]FJ\\erPqSfzpRD\ngJX@@dmU@]FJ]FnlDa@\ngJX@@dmUQH]FJ\\enlD~@<\ngJX@@dmUQH]FJ\\es`qS]XIB<\ngJX@@dmUQH]FJ\\es`qS]XIB>\ngJX@@dmUQH]FJ\\es`qS]XI|<\ngJX@@dmUQH]FJ\\es`qS]XI|>\ngJX@@dmUQH]FJ\\es`qs]XI|<\ngJX@@dmUQH]FJ\\es`qs]XI|>\ngJX@@dmUQH]FJ\\fnlDa@<\ngJX@@dmUQH]FJ\\fnlDa@>\ngJX@@dmUQH]FJ\\frPqSfzpRD>\ngJX@@dmUQH]FJ\\fs`qS]XIB<\ngJX@@dmUQH]FJ\\fs`qS]XIB>\ngJX@@dmUQH]FJ\\fs`qs]XIB<\ngJX@@dmUQH]FJ]EnlD~@<\ngJX@@dmUQH]FJ]EnlD~@>\ngJX@@drP`]II[h[vp\ngJX@@drP`]II[h[wP\ngJX@@drP`]II[x[vst\ngJX@@drP`]II\\xL\\wp{mgh\ngJX@@drt`]FJ\\enlD}@\ngJX@@drt`]FJ\\enmx}@\ngJX@@drt`]FJ\\eoLD\ngJX@@drt`]FJ\\eoMx\ngJX@@drt`]FJ\\es`qs]XIz\ngJX@@drt`]FJ\\es`qs_CnB^`\ngJX@@drt`]FJ\\eshis]CnB\ngJX@@drt`]FJ\\eshis]XIz\ngJX@@drt`]FJ\\eshis^XH\ngJX@@drt`]FJ\\eshis_CnB^`\ngJX@@drt`]FJ]EnawA@\ngJX@@drt`]FJ]Es`qs]XIz\ngJX@@drt`]FJ]Eshis_CnB^`\ngJX@@dru@]FJ\\enlDa@\ngJX@@dru@]FJ\\enlD~@\ngJX@@dru@]FJ\\eoawAHP\ngJX@@dru@]FJ\\eoaw^HP\ngJX@@dru@]FJ\\es`qs]XIB\ngJX@@dru@]FJ\\eshis]XIB\ngJX@@dru@]FJ\\eshis][qB\ngJX@@dru@]FJ\\eshis_CnBP`\ngJX@@dru@]FJ\\eshis_Cn|P`\ngJX@@dru@]FJ\\fnlDa@\ngJX@@dru@]FJ]EnlDa@\ngJX@@dru@]FJ]EoawAHP\ngJX@@dru@]FJ]Es`qs]XIB\ngJX@@dru@]FJ]Es`qs]XI|\ngJX@@dru@]FJ]Eshis_CnBP`\ngJX@@dru@]ZRRwpwmdH\ngJX@@dru@]ZRRwpwndH\ngJX@@dru@]ZRRytTyoao]HP\ngJX@@dsR`]FJ\\e@\ngJX@@dsR`]FJ\\es`qs^Gh\ngJX@@dsR`]FJ\\es`qs^[h\ngJX@@dsR`]FJ\\eshir\ngJX@@dsR`]FJ\\eshis][iz\ngJX@@dsR`]FJ\\eshis^Gh\ngJX@@dsR`]ZRRwPwm`\ngJX@@dsR`]ZRRwPwn`\ngJX@@dsR`]ZRRwP{m`\ngJX@@dsR`]ZRRwP{n`\ngJX@@dsR`]ZRRwpwmgh\ngJX@@dsR`]ZRRwpwngh\ngJX@@dsR`]ZRRwp{mgh\ngJX@@dsR`]ZRRytTyoaw]OP\ngJX@@dsTrH]FJ\\enlD}@>\ngJX@@dsTrH]FJ\\eoLD<\ngJX@@dsTrH]FJ\\eoLD>\ngJX@@dsTrH]FJ\\erPqSf|pP<\ngJX@@dsTrH]FJ\\erPqSf|pP>\ngJX@@dsTrH]FJ\\erPqSf|w`<\ngJX@@dsTrH]FJ\\erPqSf|w`>\ngJX@@dsTrH]FJ\\es`qs^XH<\ngJX@@dsTrH]FJ\\es`qs^XH>\ngJX@@dsTrH]FJ\\eshis]XIz<\ngJX@@dsTrH]FJ\\eshis^XH<\ngJX@@dsTrH]FJ\\eshis^XH>\ngJX@@dsTrH]FJ\\eshis^[p<\ngJX@@dsTrH]FJ]EoLD<\ngJX@@dsURH]FJ\\enlDa@<\ngJX@@dsURH]FJ\\enlDa@>\ngJX@@dsURH]FJ\\enlD~@<\ngJX@@dsURH]FJ\\enlD~@>\ngJX@@dsURH]FJ\\enmxa@<\ngJX@@dsURH]FJ\\enmxa@>\ngJX@@dsURH]FJ\\erPqSfzpRD<\ngJX@@dsURH]FJ\\erPqSfzpRD>\ngJX@@dsURH]FJ\\erPqSfzwbD<\ngJX@@dsURH]FJ\\erPqSfzwbD>\ngJX@@dsURH]FJ\\es`qs]XIB<\ngJX@@dsURH]FJ\\es`qs]XIB>\ngJX@@dsURH]FJ\\es`qs]XI|<\ngJX@@dsURH]FJ\\es`qs]XI|>\ngJX@@dsURH]FJ\\es`qs][qB<\ngJX@@dsURH]FJ\\es`qs][qB>\ngJX@@dsURH]FJ\\eshis]XIB<\ngJX@@dsURH]FJ\\eshis]XIB>\ngJX@@dsURH]FJ\\eshis]XI|<\ngJX@@dsURH]FJ\\eshis]XI|>\ngJX@@dsURH]FJ\\eshis][qB<\ngJX@@dsURH]FJ\\eshis][qB>\ngJX@@dsURH]FJ\\fnlDa@<\ngJX@@dsURH]FJ\\fnlDa@>\ngJX@@dsURH]FJ\\fnmxa@<\ngJX@@dsURH]FJ\\fnmxa@>\ngJX@@dsURH]FJ\\fs`qs]XIB<\ngJX@@dsURH]FJ\\fs`qs]XIB>\ngJX@@dsURH]FJ\\fshis]XIB<\ngJX@@dsURH]FJ\\fshis]XIB>\ngJX@@dsURH]FJ\\fshis][qB>\ngJX@@dsURH]FJ]EnlDa@<\ngJX@@dsURH]FJ]EnlDa@>\ngJX@@dsURH]FJ]ErPqSfzpRD<\ngJX@@dsURH]FJ]Es`qs]XIB<\ngJX@@dsURH]FJ]Es`qs]XIB>\ngJX@@dsURH]FJ]Es`qs]XI|<\ngJX@@dsURH]FJ]Es`qs]XI|>\ngJX@@dsURH]FJ]Eshis]XIB<\ngJX@@dsURH]FJ]Eshis]XIB>\ngJX@@dsURH]FJ]FnlDa@<\ngJX@@dsURH]FJ]FnlDa@>\ngJX@@dsURH]FJ]Fs`qs]XIB<\ngJX@@dsURH]FJ]Fs`qs]XIB>\ngJX@@dvE@]KI[x[VrD\ngJX@@dvE@]KI[x[Vsx\ngJX@@dvE@]KI[x[WRD\ngJX@@dvE@]KI[x]VrD\ngJX@@dvE@]KI\\zJ\\wpvndH\ngJX@@dvE@]KI\\zJ\\wpvngp\ngJX@@dvE@]KIkx[VrD\ngJX@@dvE@]KIkx[WRD\ngJX@@dwM@]FJ\\eneta@\ngJX@@dwM@]FJ\\eoBD\ngJX@@dwM@]FJ\\es`is]KiB\ngJX@@dwM@]FJ\\es`is^DH\ngJX@@dwM@]FJ\\eshis]KiB\ngJX@@dwM@]FJ\\eshis]Ki|\ngJX@@dwM@]FJ\\eshis^DH\ngJX@@dwM@]FJ\\eshis^Gp\ngJX@@dwM@]FJ\\fneta@\ngJX@@dwM@]ZVRwpvmdH\ngJX@@dwM@]ZVRwpvndH\ngJX@@dwM@]ZVRwpzmdH\ngJX@@dwM@]ZVRwpzndH\ngJX@@dwM@]ZVRypTyoau[HP\ngJX@@dwM@]ZVRypTyoau]HP\ngJX@@dwM@]ZVRytTyoam]HP\ngJX@@dwM@]ZVRytTyoau]HP\ngJX@@dwM@]ZVRytTyoau]O`\ngJX@@dwM@]ZVSWpvmdH\ngJX@@dwM@]ZVSWpvndH\ngJX@@dwM@]ZVSWpzmdH\ngJX@@dwM@]ZVSWpzndH\ngJX@@eMH@]HJ[k[N\x7Fv`@=\ngJX@@eMH@]HJ[k[O_v`@\ngJX@@eMH@]HJ[k]O_v`@=\ngJX@@eMH@]HJ[y]vso}h@=\ngJX@@eMH@]HJ[y]vsw}h@\ngJX@@eMH@]HJ[y]wSw}h@=\ngJX@@eMH@]HJ\\xLTwVz^\x7Fm@\ngJX@@eMH@]HJ\\xLTwr{ngo{P@\ngJX@@eMH@]HJ\\xL\\wVv^\x7Fm@\ngJX@@eMH@]HJ\\xL\\wr{mgo{P@\ngJX@@eMK@]TLTyK][iC~t@\ngJX@@eMK@]TLTyK_KnzP\x7Fm@\ngJX@@eMK@]TLTyKgAbfzWRG}h@\ngJX@@eMK@]TLTyKgAbf~W]ta\x7FZ@\ngJX@@eMK@]XLdypXioew]O_v`@\ngJX@@eMP@]HJ[yAvso}h@=\ngJX@@eMP@]HJ[yAvsw}h@\ngJX@@eMP@]HJ[yAwSt=\ngJX@@eMP@]HJ[yAwSw}h@=\ngJX@@eMP@]HJ[y^vso}h@=\ngJX@@eMP@]HJ[y^vsw}h@\ngJX@@eMP@]HJ\\xLTwrCngh\ngJX@@eMP@]HJ\\xLTwrCngo{P@\ngJX@@eMP@]HJ\\xLTwr}ngh\ngJX@@eMP@]HJ\\xL\\wrCmgo{P@\ngJX@@eMP@]HJ\\xL\\wr}mgo{P@\ngJX@@eMP@]HJkyAvso}h@=\ngJX@@eMP@]HJkyAvsw}h@\ngJX@@eMP@]HJkyAwSt=\ngJX@@eMP@]HJkyAwSw}h@=\ngJX@@eMP@]HJlxLTwrCngh\ngJX@@eMP@]HJlxLTwrCngo{P@\ngJX@@eMP@]HJlxL\\wrCmgo{P@\ngJX@@eMS@]TLTyK]HIC~t@\ngJX@@eMS@]TLTyK_HNzP\x7Fdd\\[P@\ngJX@@eMS@]TLTyK_HNzP\x7Fm@\ngJX@@eMS@]TLTyKgAbfzPRG}h@\ngJX@@eMS@]TLTyKgAbf~P]ta\x7FZ@\ngJX@@eMS@]TLTyKgAbf~Wmta\x7FZ@\ngJX@@eMS@]TLTyKgAcf~P]ta\x7FZ@\ngJX@@eMS@]TLTyM_HNzP\x7Fm@\ngJX@@eMS@]TLTyMgAbfzPRG}h@\ngJX@@eMS@]TLTyMgAbf~P]ta\x7FZ@\ngJX@@eMS@]TLUYK]HIC~t@\ngJX@@eMS@]TLUYK_HNzP\x7Fdd\\[P@\ngJX@@eMS@]TLUYK_HNzP\x7Fm@\ngJX@@eMS@]TLUYKgAbfzPRG}h@\ngJX@@eMS@]TLUYKgAbf~P]ta\x7FZ@\ngJX@@eMS@]TLUYKgAcf~P]ta\x7FZ@\ngJX@@eMS@]TLUYM_HNzP\x7Fm@\ngJX@@eMS@]TLUYMgAbf~P]ta\x7FZ@\ngJX@@eMS@]XLdwrCng_{P@\ngJX@@eMS@]XLdwrCngo{P@\ngJX@@eMS@]XLeWrCmgo{P@\ngJX@@eMS@]XLeWrCngo{P@\ngJX@@eMU@]TLTyK_HNBP`\ngJX@@eMU@]TLTyK_HNBP\x7Fdd\\[P@\ngJX@@eMU@]TLTyK_HNBP\x7Fm@\ngJX@@eMU@]TLTyK_KvBP`\ngJX@@eMU@]TLTzM_HNBP`\ngJX@@eMU@]TLTzM_HNBP\x7Fm@\ngJX@@eMU@]TLUYK_HNBP`\ngJX@@eMU@]TLUYK_HNBP\x7Fm@\ngJX@@eMU@]TLUZM_HNBP\x7Fm@\ngJX@@eMURH]TLTyK_HNB__m@<\ngJX@@eMURH]TLTyK_HNB__m@>\ngJX@@eMURH]TLTyKgAbf~P\\Da@<\ngJX@@eMURH]TLTyKgAbf~P\\Da@>\ngJX@@eMURH]TLTyKgAbf~P\\Da\x7FZ@<\ngJX@@eMURH]TLTyKgAbf~P\\Da\x7FZ@>\ngJX@@eMURH]TLTyKgAbf~WlDa@<\ngJX@@eMURH]TLTyM_HNBP`<\ngJX@@eMURH]TLTyM_HNBP`>\ngJX@@eMURH]TLTyM_HNBP\x7Fm@<\ngJX@@eMURH]TLTyM_HNBP\x7Fm@>\ngJX@@eMURH]TLTyMgAbf~P\\Da@<\ngJX@@eMURH]TLTyMgAbf~P\\Da@>\ngJX@@eMURH]TLTyMgAbf~P\\Da\x7FZ@<\ngJX@@eMURH]TLTyMgAbf~P\\Da\x7FZ@>\ngJX@@eMURH]TLTzK_HNB__m@<\ngJX@@eMURH]TLTzK_HNB__m@>\ngJX@@eMURH]TLTzKgAcf~P\\D~@<\ngJX@@eMURH]TLTzKgAcf~P\\D~@>\ngJX@@eMURH]TLTzMgAbf~P\\Da@<\ngJX@@eMURH]TLUYK_HNB__m@>\ngJX@@eMURH]TLUYKgAbf~P\\Da@<\ngJX@@eMURH]TLUYKgAbf~P\\Da@>\ngJX@@eMURH]TLUYKgAbf~P\\Da\x7FZ@<\ngJX@@eMURH]TLUYKgAbf~P\\Da\x7FZ@>\ngJX@@eMURH]TLUYM_HNBP\x7Fm@<\ngJX@@eMURH]TLUYM_HNBP\x7Fm@>\ngJX@@eMURH]TLUYMgAbf~P\\Da\x7FZ@<\ngJX@@eMURH]TLUYMgAbf~P\\Da\x7FZ@>\ngJX@@eMURH]TLUZK_HNB__m@<\ngJX@@eMURH]TLUZK_HNB__m@>\ngJX@@eST`]TLTyK]HNC~t@=\ngJX@@eST`]TLTyK_HNB^\x7Fm@=\ngJX@@eST`]TLTyKgASfzP]{}h@\ngJX@@eST`]TLTyKgASf~P]x}\x7FZ@\ngJX@@eST`]TLTyKgAcfzP\\G}h@\ngJX@@eST`]TLTyKgAcf~P\\D}\x7FZ@\ngJX@@eST`]TLTzK]HNC~t@\ngJX@@eST`]TLTzK_HNB^\x7Fm@\ngJX@@eST`]TLTzKgASf~P\\D}\x7FZ@\ngJX@@eST`]TLTzKgAcfzP\\G}h@\ngJX@@eST`]TLTzKgAcf~P\\D}\x7FZ@\ngJX@@eST`]XTRwRwn\x7Fm@\ngJX@@eST`]XTRwR{n\x7Fm@=\ngJX@@eSU@]TLTyK_HNBP`\ngJX@@eSU@]TLTyK_HNBP\x7FdhT[P@=\ngJX@@eSU@]TLTyK_HNBP\x7Fm@=\ngJX@@eSU@]TLTyK_HNB_@\ngJX@@eSU@]TLTyK_HNB__m@=\ngJX@@eSU@]TLTyK_HN|P\x7Fm@\ngJX@@eSU@]TLTyKdabgM|`xIB\ngJX@@eSU@]TLTyKdabgM|`xIC~t@=\ngJX@@eSU@]TLTyKdabgM|`xI|\ngJX@@eSU@]TLTyKgASf~P]xa\x7FZ@\ngJX@@eSU@]TLTyKgAcf~P\\Da\x7FZ@\ngJX@@eSU@]TLTyKgAcf~P\\D~\x7FZ@\ngJX@@eSU@]TLTyKgAcf~P]xa\x7FZ@\ngJX@@eSU@]TLTyM_HNBP`\ngJX@@eSU@]TLTyM_HNBP\x7FdhT[P@=\ngJX@@eSU@]TLTyM_HNBP\x7Fm@=\ngJX@@eSU@]TLTyM_HN|P\x7Fm@\ngJX@@eSU@]TLTyMgASf~P]xa\x7FZ@\ngJX@@eSU@]TLTyMgAcf~P\\Da\x7FZ@\ngJX@@eSU@]TLTzK_HNBP\x7Fm@\ngJX@@eSU@]TLTzKgASf~P\\Da\x7FZ@\ngJX@@eSU@]TLTzKgAcf~P\\Da\x7FZ@\ngJX@@eSU@]TLTzKgAcf~P\\D~\x7FZ@\ngJX@@eSU@]TLTzM_HNBP\x7Fm@\ngJX@@eSU@]TLTzMgASf~P\\Da\x7FZ@\ngJX@@eSU@]TLTzMgAcf~P\\Da\x7FZ@\ngJX@@eSU@]TLUZK_HNBP`\ngJX@@eSU@]TLUZK_HNBP\x7Fm@=\ngJX@@eSU@]TLUZM_HNBP\x7Fm@=\ngJX@@eSU@]XTRwrwmdO{P@=\ngJX@@eSU@]XTRwrwmgw{P@=\ngJX@@eSU@]XTRwrwndO{P@\ngJX@@eSU@]XTRwrwngw{P@\ngJX@@eSU@]XTRwr{ndO{P@=\ngJX@@eSU@]XTRypTyoeo]H_v`@\ngJX@@eSU@]XTRypXyoew]H_v`@\ngJX@@eSU@]XTSWrwmdO{P@=\ngJX@@eSU@]XTSWrwndO{P@\ngJX@@eSU@]XTSWr{ndO{P@=\ngJX@@eSU@]XTSYpXyoew]H_v`@\ngJX@@eSUPH]TLTyK_HN|P`<\ngJX@@eSUPH]TLTyK_HN|P`>\ngJX@@eSUPH]TLTyKgASf~P]xa@<\ngJX@@eSUPH]TLTyKgASf~P]xa@>\ngJX@@eSUPH]TLTyKgAcf~P\\Da@<\ngJX@@eSUPH]TLTyKgAcf~P\\Da@>\ngJX@@eSUPH]TLTyKgAcf~P\\D~@<\ngJX@@eSUPH]TLTyKgAcf~P\\D~@>\ngJX@@eSUPH]TLTyKgAcf~P]xa@<\ngJX@@eSUPH]TLTyKgAcf~P]xa@>\ngJX@@eSUPH]TLTyM_HN|P`<\ngJX@@eSUPH]TLTyM_HN|P`>\ngJX@@eSUPH]TLTyMgAcf~P\\Da@<\ngJX@@eSUPH]TLTyMgAcf~P\\Da@>\ngJX@@eSUPH]TLTzK_HNBP`<\ngJX@@eSUPH]TLTzK_HNBP`>\ngJX@@eSUPH]TLTzKdabgM|`xIB<\ngJX@@eSUPH]TLTzKgASf~P\\Da@<\ngJX@@eSUPH]TLTzKgASf~P\\Da@>\ngJX@@eSUPH]TLTzKgAcf~P\\Da@<\ngJX@@eSUPH]TLTzKgAcf~P\\Da@>\ngJX@@eSUPH]TLTzM_HNBP`<\ngJX@@eSUPH]TLTzM_HNBP`>\ngJX@@eSUPH]TLTzMgAcf~P\\Da@<\ngJX@@eSUPH]TLTzMgAcf~P\\Da@>\ngJX@@eSUPH]TLUYK_HN|P`<\ngJX@@eSUPH]TLUYK_HN|P`>\ngJX@@eSUPH]TLUYM_HN|P`<\ngJX@@eSUPH]TLUYM_HN|P`>\ngJX@@e\\u@]TLTyK]XIC~t@\ngJX@@e\\u@]TLTyK_SnBP\x7Fm@\ngJX@@e\\u@]TLTzM]XIC~t@\ngJX@@e\\uQH]TLTyK]XI}~t@>\ngJX@@e\\uQH]TLTyKgAbf~g\\Da\x7FZ@<\ngJX@@e\\uQH]TLTyKgAbf~g\\Da\x7FZ@>\ngJX@@e\\uQH]TLTyM]XIC~t@<\ngJX@@e\\uQH]TLTyM]XIC~t@>\ngJX@@e\\uQH]TLTyMgAbf~g\\Da\x7FZ@<\ngJX@@e\\uQH]TLTyMgAbf~g\\Da\x7FZ@>\ngJXA@IRVX@NiFzvst\ngJXA@IRVX@NiGNCGM|N{Yz\ngJXA@IRVh@NiFzvsl=\ngJXA@IRVh@NiFzvst\ngJXA@IRVh@NiFzwSt=\ngJXA@IRVh@NiF~Gml{@=\ngJXA@IRVh@NiF~Gml}@\ngJXA@IRVh@NiF~Gmt}@=\ngJXA@IRVh@NiGNCEMungh\ngJXA@IRVh@NiGNCEM|O[iz\ngJXA@IRVh@NiGNCGMumgh\ngJXA@IRVi`NcENRwaB\ngJXA@IRVi`NcENRypXynmta@\ngJXA@IRVi`NcENRypXyoBD\ngJXA@IRVj`NcENRwVBP`\ngJXA@IRVjhdNcENRypXinlDa@<\ngJXA@IRVjhdNcENRypXinlDa@>\ngJXA@IRVjhdNcENRypXioa{AHP<\ngJXA@IRVjhdNcENSWVBP`>\ngJXA@IRVjhdNcENSYpXinlDa@<\ngJXA@IRYHPNddmtN{X\ngJXA@IRYZPNcENRwP{o@\ngJXA@IRYZPNcENRwVB^`\ngJXA@IRYZPNcENRwp{`gh\ngJXA@IRYZPNcENRypXyoawAOP\ngJXA@IRYZPNcENRytTyoawAOP\ngJXA@IRYjiDNcENRwVBP`<\ngJXA@IRYjiDNcENRwVBP`>\ngJXA@IRYjiDNcENRwVB_@<\ngJXA@IRYjiDNcENRwVB_@>\ngJXA@IRYjiDNcENRyHXis]XIB>\ngJXA@IRYjiDNcENRyHXis][qB<\ngJXA@IRYjiDNcENRyHXis_CvBP`<\ngJXA@IRYjiDNcENRyHXis_CvBP`>\ngJXA@IRYjiDNcENRypXynlDa@<\ngJXA@IRYjiDNcENRypXynlDa@>\ngJXA@IRYjiDNcENRytTynlDa@<\ngJXA@IRYjiDNcENRytTynlDa@>\ngJXA@IRYjiDNcENSWVBP`<\ngJXA@IRYjiDNcENSWVBP`>\ngJXA@IRYjiDNcENSYpXynlDa@<\ngJXA@IRYjiDNcENSYtTynlDa@>\ngJXA@IRYjiDNcENbwVBP`>\ngJXA@IRYjiDNcENbypXynlDa@<\ngJXA@IRYjiDNcENbypXynlDa@>\ngJXA@IR[B`Nedm|MkYB\ngJXA@IR[B`Nedm|MkiB\ngJXA@IRfd@NdEMumg_{P@=\ngJXA@IRfd@NdEMumgo{P@\ngJXA@IRfd@NdEM|n{Yw~t@=\ngJXA@IRfd@NdEM|n{Y{~t@\ngJXA@IRfd@NdEM|n{i{~t@=\ngJXA@IRfd@NdEN\\FN[y]vsw}h@\ngJXA@IRfe`NjFJ\\es`qS]KiC~t@\ngJXA@IRfh@NdEM|`{Yv=\ngJXA@IRfj`NjFJ\\eodGAHP\ngJXA@IRfjiDNjFJ\\es`qS_HNBP`<\ngJXA@IRfjiDNjFJ\\es`qS_HNBP`>\ngJXA@IRfjiDNjFJ\\fodGAHP<\ngJXA@IRfjiDNjFJ\\fodGAHP>\ngJXA@IRij`NjFJ\\eodGAHP\ngJXA@IRij`NjFJ\\eodGAO`\ngJXA@IRij`NjFJ\\erPqSf~P\\Da@\ngJXA@IRij`NjFJ\\erPqSf~P\\D~@\ngJXA@IRij`NjFJ\\fodGAHP\ngJXA@IRijhDNjFJ\\es`qs_HNBP`<\ngJXA@IRijhDNjFJ\\es`qs_HNBP`>\ngJXA@IRijhDNjFJ\\fs`qs_HNBP`<\ngJXA@IRijhDNjFJ\\fs`qs_HNBP`>\ngJXA@IRkZ`NjFJ\\enlDa\x7FZ@\ngJXA@IRkZ`NjFJ\\eoiwAH_v`@\ngJXA@IRkZ`NjFJ\\es`qs]XIC~t@\ngJXA@IRkZ`NjFJ\\es`qs_SnBP\x7Fm@\ngJXA@IRkZ`NjFJ\\eshis]XIC~t@\ngJXA@IRkZ`NjFJ\\eshis_SnBP\x7Fm@\ngJXA@IRkZ`NjFJ\\fnlDa\x7FZ@\ngJXA@IRkZ`NjFJ\\foiwAH_v`@\ngJXA@IRkZ`NjFJ]EoiwAH_v`@\ngJXA@IRkZ`NjFJ]Es`qs]XIC~t@\ngJXA@IRkZ`NlII[z[vrG}h@\ngJXA@IRkZ`NlII[z[wRG}h@\ngJXA@IRkZ`NlII[z]vrG}h@\ngJXA@IRkZ`NlII[z]wRG}h@\ngJXA@IRkZ`NlIIkz[vrG}h@\ngJXA@IRkZ`NlIIkz[wRG}h@\ngJXA@IRkZ`NlIIkz]vrG}h@\ngJXA@IRkZ`NlIIkz]wRG}h@\ngJXA@IRnZ`NjFJ\\eoiwAH_v`@\ngJXA@IRnZhdNjFJ\\fs`qS_SnBP\x7Fm@<\ngJXA@IRnZhdNjFJ\\fs`qS_SnBP\x7Fm@>\ngJXA@IrRDJ@zVRwtvmdO{P@=\ngJXA@IrRDJ@zVRwtvndO{P@\ngJXA@IrRDJ@zVRwtzndO{P@=\ngJXA@IrRDJ@zVRypTyoiu]H_v`@\ngJXA@IrRDJ@zVRytTyoim]H_v`@\ngJXA@IrRDJ@zVSWtvmdO{P@=\ngJXA@IrRDJ@zVSWtvndO{P@\ngJXA@NRfh@NdEM|`{Yw~t@=\ngJXA@NRfi`NjFJles`qS_HNzP\x7Fm@\ngJXAAnR[f`NmKIkx[WRD\ngJXDB@cABTuRAu`qS^HH\ngJXDB@cABTuRAu`rS_HNv]`\ngJXDD@bABUuTAtPirVzpRG}h`=\ngJXDHOA^BS]TAuhyK^DH\ngJXDHOA^BS]TAuhyK_Cr|P\x7FmH=\ngJXDL@aABSKTAuhiK^DH\ngJXDL@aABS[TAuhyK^DO{S@\ngJXDL@bABUu@Au@wVv]`\ngJXH@jAJZ`@z`[k[N\x7Fv`@=\ngJXH@jAJZ`@z`[k]OP=\ngJXH@jAJZ`@z`\\xLTwVz^`\ngJXH@jAJZ`@z`\\xL\\wVv^\x7Fm@\ngJXH@jAJzj@zhYIr[NCEM}@xIC~t@>\ngJXH@jAJzj@zhYIt[NCEM}@xIB>\ngJXH@jAJzj@zhYIt[NCEM}@xIC~t@>\ngJXHAJAIfi@zLTyKgAcf|pP>\ngJXHAJAIfi@zLTzKgAcf|pP>\ngJXHAjAJfi@zHXiKgASf|P_v`@\ngJXHAjAJfi@zHXiKgAcfzPSw}h@\ngJXHAjAJfi@zHXiKgAcf|P_v`@\ngJXHAjAJfi@zHXjK]HI{~t@\ngJXHAjAJfj@zHXiKgAcf~P]xa\x7FZ@\ngJXHAjAJfj`PzHXjK]HIB<\ngJXHAjAJfj`PzHXjK]HIB>\ngJXHB@aIfe@zTdwPwm`\ngJXHB@aInZ@zTlwPvm`\ngJXHB@aInZ@zTlwPvn`\ngJXHB@aInZ@zTlytTynam]@\ngJXHBOAJfj@zHXis]HNB\ngJXHBOAJfj@zHXisdabgMt`xH\ngJXHBOAJfj@zHXju]HNB\ngJXHBOAJfj`PzHXiu]HNB<\ngJXHBOAJfj`PzHXiu]HNB>\ngJXHD@aIZjbPzLTyKgAbfzpRD<\ngJXHD@aIZjbPzLTyKgAbfzpRD>\ngJXHD@aIej@zLTyK]XIC~tP\ngJXHD@aIej@zLTyKgQSfzpRG}h`\ngJXHD@aIej@zLTyM]XIC~tP\ngJXHD@aIej@zLTyMgQSfzpRG}h`\ngJXHD@aIej@zLTzK]XIC~tP\ngJXHD@aIej@zLTzKgQSfzpRG}h`\ngJXHD@aIej@zLTzM]XIC~tP\ngJXHD@aIfe@ztdenao]\x7FZH\ngJXHD@aIfe@ztdeshis_C^z^\x7FmD\ngJXHD@aIff@zLTyK][iC~tP\ngJXHD@aIff@zLTyM][iC~tP\ngJXHD@aIff@ztdeoao]H_vb@\ngJXHD@aIff@ztdfoao]H_vb@\ngJXHD@aIff@ztdfshis_C^zP\x7FmD\ngJXHD@aImi@zt\\eshir\ngJXHD@aImj@zt\\eshis^DH\ngJXHD@aInZ@ztleoam[HP\ngJXHD@aInZ@ztlfoam[HP\ngJXHDHaIfe@zLTyKgQSf|O_vb@\ngJXHDOAIZj@zLTyK]XIB\ngJXHDOAIZj@zLTyK_CvBP`\ngJXHDOAIZj@zLTyKdabgMu`dH\ngJXHDOAIZj@zLTyKdabgM|OXIB\ngJXHDOAIZj@zLTyM]XIC~tP\ngJXHDOAIfjdPzLTzM_CvBP\x7FmD>\ngJXHH@aIYj@zLTyK]XIC~t`\ngJXHH@aIZ`@zd[x^vso}i@=\ngJXHH@aIZ`@zd[x^vsw}i@\ngJXHH@aIZ`@zd[x^wSw}i@=\ngJXHH@aIZ`@zd\\xL\\wp}mgo{R@\ngJXHH@aIZf@zLTyK_CvzP\x7FmH\ngJXHH@aIZf@zLTyKgAbf~Gmta\x7FZP\ngJXHH@aIZf@zTUWp}ngo{R@\ngJXHH@aIZj@zLTyK]XIC~t`\ngJXHH@aIZj@zLTyK_CvBP\x7FmH\ngJXHH@aIZj@zLTzM]XIC~t`\ngJXHH@aIZj@zLTzM_CvBP\x7FmH\ngJXHH@aIZjbPzLTyK]XI}~t`<\ngJXHH@aIZjbPzLTyK]XI}~t`>\ngJXHH@aIZjbPzLTyK_CvB__mH<\ngJXHH@aIZjbPzLTyK_CvB__mH>\ngJXHH@aIZjbPzLTyKgAbf~GlDa\x7FZP<\ngJXHH@aIZjbPzLTyKgAbf~GlDa\x7FZP>\ngJXHH@aIZjbPzLTyM]XIC~t`<\ngJXHH@aIZjbPzLTyM]XIC~t`>\ngJXHH@aIZjbPzLTyM_CvBP\x7FmH<\ngJXHH@aIZjbPzLTyM_CvBP\x7FmH>\ngJXHH@aIZjbPzLTzK]XI}~t`<\ngJXHH@aIZjbPzLTzK_CvB__mH<\ngJXHH@aIZjbPzLTzK_CvB__mH>\ngJXHH@aIfi@zLTyK_CvB^\x7FmH\ngJXHH@aIfi@zLTyKgQSfzGlG}i@\ngJXHH@aIfi@zLTyKgQSf~GlD}\x7FZP\ngJXHH@aIfj@zLTyK_CvBP\x7FmH\ngJXHH@aIfj@zLTyKgAcf~GlDa\x7FZP\ngJXHH@aIfj@zLTyKgQSf~GlDa\x7FZP\ngJXHH@aIfj@zLTyKgQSf~GlD~\x7FZP\ngJXHH@aIfj@zLTyKgQSf~Gmxa\x7FZP\ngJXHH@aIfj@zLTyM_CvBP\x7FmH\ngJXHH@aIfj@zLTyMgQSf~GlDa\x7FZP\ngJXHH@aIfj@zLTzK_CvBP\x7FmH\ngJXHH@aIfj@zLTzKgQSf~GlDa\x7FZP\ngJXHH@aIfj@zLTzKgQSf~GlD~\x7FZP\ngJXHH@aIfj@zLTzM_CvBP\x7FmH\ngJXHH@aJz`@z`[k[OP\ngJXHH@aJz`@z`\\xL\\wVv^`\ngJXHHGAIZ`@zd[x^vsw}i@\ngJXHHGAIZ`@zd[x^wSt=\ngJXHHGAIfj@zLTyKgQSf~GlDa\x7FZP\ngJXHHGAIfjdPzLTzK_CvB_@<\ngJXHHGAIfjdPzLTzK_CvB_@>\ngJXHHOAIY`@zd[k[N\x7Fvd@=\ngJXHHOAIY`@zd[k[O_vd@\ngJXHHOAIY`@zd[k]O_vd@=\ngJXHHOAIZ`@zd[k[O_vd@\ngJXHHOAIZ`@zd[x^vso}i@=\ngJXHHOAIZ`@zd[x^vsw}i@\ngJXHHOAIZ`@zd[x^wSw}i@=\ngJXHHOAIZ`@zd\\xL\\wp}mgo{R@\ngJXHHOAIZj@zLTyK_CvBP\x7FmH\ngJXHHOAIZjbPzLTyM_CvBP\x7FmH<\ngJXHHOAIZjbPzLTyM_CvBP\x7FmH>\ngJXHHOAIfj@zLTyK_CvBP\x7FmH\ngJXHHOAIfj@zLTyKgAcf~GlDa\x7FZP\ngJXHHOAIfj@zLTyKgAcf~GlD~\x7FZP\ngJXHHOAIfj@zLTyKgQSf~GlDa\x7FZP\ngJXHHOAIfj@zLTyM_CvBP\x7FmH\ngJXHHOAIfj@zLTyMgAcf~GlDa\x7FZP\ngJXHHOAIfj@zLTzK]XIC~t`\ngJXHHOAIfjdPzLTyK]XIB<\ngJXHHOAIfjdPzLTyK]XIB>\ngJXHHOAIfjdPzLTyK_CvBP`>\ngJXHHOAJfj@zhXjtZ~P\\Da\x7FZP\ngJXHL@aIZ`@zd[k[Np\ngJXHL@aIZ`@zd[k[OP\ngJXHL@aIZf@ztTfs`qS^DH\ngJXHL@aIZf@ztTfs`qs_CvzP`\ngJXHL@aIZjb`ztTeoBD<\ngJXHL@aIZjb`ztTeoBD>\ngJXHL@aJZ`@zPTwrCmgX\ngJXHL@aJZ`@zPTwrCmgh\ngJXHL@aJZ`@zPTwrCngX\ngJXHL@aJZ`@zPTypXyodG[OP\ngJXHL@aJZ`@zPUWrCmgX\ngJXHL@aJZ`@zPUWrCmgh\ngJXHL@aJZ`@zPUYpXyodG[OP\ngJXHL@aJZf@zHXiK]HIB\ngJXHL@aJZf@zpYIodG[OP\ngJXHL@aJZf@zpYIs`qs_HNv^`\ngJXHL@aJZi@zHXiK]HIz\ngJXHL@aJZi@zHXjK]HIz\ngJXHL@aJZi@zpYIodG[OP\ngJXHL@aJZjdPzHXjMgAbfzPRD<\ngJXHL@aJZjdPzHXjMgAbfzPRD>\ngJXHLDQJZ`@zPTwrCmgX\ngJXHLJqIZjb`ztTeoBD<\ngJXHLLQIZ`@zd[k[OP\ngJXHLLQIZ`@zd[k]OP\ngJXHLLQIZjb`ztTeoBD<\ngJXHLOAIZ`@zd[x^vsl\ngJXHLOAIZi@zTUWp}mgX\ngJXHaj@SnRkZ`NbFJRwV|P\x7Fm@\ngJXIB@`rdwM@]JV[h[Vp\ngJXID@aRdwL`]ZVRwPvn`\ngJXIDOARdmU@]FJ\\eoa{AHP\ngJXIH@b\\dmP@]RM|O[Yw~t`=\ngJXIHOBRdlp@]RMungo{R@=\ngJXIHOBRdlu@]FJ\\enlDa\x7FZP\ngJXIHOBRdru@]FJ\\enlDa\x7FZP\ngJXIL@cRdmP@]RMumgX\ngJXIL@cRdmUQP]ZJRwaB<\ngJXIL@cRdmUQP]ZJRwaB>\ngJXLB@bAFBDkjdCiAU][Yv\ngJXLL@aAABDfVhCiQR\ngJX`BDdru@]ZJ\\wfB\ngJX`BDdru@]ZJ\\wf|\ngJX`BDdru@]ZJ]WfB\ngJX`BDdvu@]JNP\ngJX`BDdwU@]JNP\ngJX`BLeMT`]XLTwbB\ngJX`DBdru@]ZJ\\wfC~tP\ngJX`DBdru@]ZJ\\wf}~tP\ngJX`DBdru@]ZJ]WfC~tP\ngJX`DBdvu@]JNP\ngJX`DBdvu@]JN\\zJ\\`\ngJX`DBdwM@]JV[h[Vp\ngJX`LDdru@]ZJRwaB\ngJX`LDdru@]ZJRwa|\ngJX`LDdru@]ZJRytTyoBD\ngJX`LDdru@]ZJRytTyoCx\ngJX`LDdru@]ZJSWaB\ngJX`LDdru@]ZJSYtTyoBD\ngJX`LDdvt`]ZNRwa{~tp\ngJX`LDdvu@]ZNRwaC~tp\ngJX`LDdvu@]ZNRwa}~tp\ngJX`LDdvu@]ZNRytTyoBG}i`\ngJX`LDdvu@]ZNRytTyoC{}i`\ngJX`LDdvu@]ZNSWaC~tp\ngJX`LDdvu@]ZNSYtTyoBG}i`\ngJX`bDnLiMmPGRcd\ngJX`bDnLiMmPGRcf|O`\ngJX`hEIWIMmHGVcdmx^\x7FmH\ngJX`hEIWIMmHGVcdo{R@\ngJX`hEIWIMmPGVcdmxP\x7FmH\ngJX`hEIWIMmPGVcdmx__mH\ngJXaBDYR[Z`NeGH\ngJXaBDYR[Z`NeGMx_@\ngJXaBDnR[Z`NeGH\ngJXaLDnR[Z`NmGI[pa\x7FZX\ngJXhMDOAJfj`PzpXfoBD<\ngJXhMDOAJfj`PzpXfoBD>\ngJXhMDOAJfj`PzpXfs`qs^DH<\ngJXhMDOAJfj`PzpXfs`qs^DH>\ngJY@BDfVhCkQSf|pP\ngJY@BDfVhCkQSj|pP\ngJY@BDfZTCiRS]C^v\ngJY@BDfZjQCkQSf|pP<\ngJY@BDfZjQCkQSf|pP>\ngJY@BDfZjQCkQSgNCGMy``<\ngJY@BDfZjQCkQSgNCGMy``>\ngJY@BDfZjQCkQSgNbgMy``<\ngJY@BDfZjQCkQSgNbgMy``>\ngJY@BDfZjQCkQSj|pP<\ngJY@BDfZjQCkQSj|pP>\ngJY@BDfZjQCkQSkNCGMy``>\ngJY@BDfyhCiRs]CZv\ngJY@DDefhChqSdmu`dO{Q@=\ngJY@DDefhChqSduu`dO{Q@\ngJY@DDejhChqSdmu`dO{Q@=\ngJY@DDejhChqSdn\\FN[kAOovb@\ngJY@DDejhChqSduu`dO{Q@\ngJY@DDejhChqSdv\\FJ[kAH_vb@\ngJY@DDejhCiQU][Y{~tP\ngJY@DDejjIChqSdn\\FJ[kAHP<\ngJY@DDejjIChqSdn\\FJ[kAHP>\ngJY@DDfVdChqSdn]EN[kAO_vb@\ngJY@DDfVdChqShmu`go{Q@\ngJY@DDfVdChqShn]EN[kAO_vb@\ngJY@DDfVhChqSdmu`dO{Q@\ngJY@DDfVhChqSdmu`gw{Q@\ngJY@DDfVhChqSdmuoDO{Q@\ngJY@DDfVhChqSdmuoGw{Q@\ngJY@DDfVhChqSdn]EN[kAH_vb@\ngJY@DDfVhChqSdn]EN[kAOovb@\ngJY@DDfVhChqSdn]EN[k^H_vb@\ngJY@DDfVhChqSdn]EN[k^Oovb@\ngJY@DDfVhChqSduu`dO{Q@\ngJY@DDfVhChqSduuoDO{Q@\ngJY@DDfVhChqSdv]EN[kAH_vb@\ngJY@DDfVhChqSdv]EN[k^H_vb@\ngJY@DDfVhChqShmu`dO{Q@\ngJY@DDfVhChqShmu`gw{Q@\ngJY@DDfVhChqShn]EN[kAH_vb@\ngJY@DDfVhChqShn]EN[kAOovb@\ngJY@DDfVhChqShuu`dO{Q@\ngJY@DDfVhChqShv]EN[kAH_vb@\ngJY@DDfZTCkRRVzF}w}h`\ngJY@DDfZXChqSdmundO{Q@\ngJY@DDfZXChqSduundO{Q@\ngJY@DDfZjQChqSdmu`dO{Q@<\ngJY@DDfZjQChqSdmu`dO{Q@>\ngJY@DDfZjQChqSdn]EN[k^H_vb@<\ngJY@DDfZjQChqSduu`dO{Q@<\ngJY@DDfZjQChqShuu`dO{Q@<\ngJY@DDfZjQChqShuu`dO{Q@>\ngJY@DDfvdCkQrT\ngJY@DDfvdCkQrV|OP\ngJY@DDfvdCkQrWNbgH\ngJY@DDfvdCkQrWNbgMx^`\ngJY@DDfvhCkQrV|HP\ngJY@DDfvhCkQrV|O`\ngJY@DDfvhCkQrWNbgMxP`\ngJY@DDfvhCkQrWNbgMx_@\ngJY@DDfvhCkQrZ|HP\ngJY@DDfvhCkQr[NbgMxP`\ngJY@DDfydCkRrVzFul\ngJY@DDfyhCkRrV~Fula@\ngJY@DDfyhCkRrZ~Fula@\ngJY@DDfzjQCkQrWNBgMxP`<\ngJY@DDfzjQCkQrWNBgMxP`>\ngJY@DDfzjQCkQrWNbgMxP`<\ngJY@DDfzjQCkQrWNbgMxP`>\ngJY@HDef@CjQnmt}\x7FZP=\ngJY@HDfZjQChqSdn]EN[kAHP<\ngJY@HDfZjQChqSdn]EN[kAHP>\ngJY@HDfZjQChqSduu`dH<\ngJY@HDfZjQChqSduu`dH>\ngJY@HDfZjQChqShn\\FN[kAHP<\ngJY@HDijhCjabgI[yApRD\ngJY@HDijhCjabgI[yApRG}i@=\ngJY@HDijhCjabgI[yApS{}i@\ngJY@HDijhCjabgI[yAwcx\ngJY@HDijhCjabgI\\xLTwrC`dO{R@\ngJY@HDijhCjabgIkyApRG}i@\ngJY@HDijjQCjabgI[yApSx<\ngJY@HDijjQCjabgI[yApSx>\ngJY@HDijjQCjabgI\\xLTwrC`dH<\ngJY@HDijjQCjabgI\\xLTwrC`dH>\ngJY@HDijjQCjabgIlxLTwrC`dH<\ngJY@HDijjQCjabgIlxLTwrC`dH>\ngJY@HDkjhChaSdmu`dH\ngJY@HDkjhChaSdnRFJ\\wVBP`\ngJY@HDkjjIChaSdn\\FJ[kAHP<\ngJY@HDkjjIChaSdn\\FJ[kAHP>\ngJY@HDkjjIChaSduu`dH<\ngJY@HDkjjIChaSduu`dH>\ngJY@HDkjjIChaSdv\\FJ[kAHP<\ngJY@HDkjjIChaSdv\\FJ[kAHP>\ngJY@LDef@CjQnml{@\ngJY@LDefdCiQU][Yv\ngJY@LDefdCiQU][Yz\ngJY@LDefdCiQU][iv\ngJY@LDefdCiQU][iz\ngJY@LDej@CjQnml{@\ngJY@LDejXCkQRV|HP\ngJY@LDejdCiQU][Yv\ngJY@LDejdCiQU][Yz\ngJY@LDejdCiQU][iz\ngJY@LDejdCiQUgAbfzwSl\ngJY@LDejjJCkQRV|HP<\ngJY@LDejjJCkQRV|HP>\ngJY@LDejjJCkQRWNCEMxP`<\ngJY@LDejjJCkQRWNCEMxP`>\ngJY@LDejjJCkQRWNCGMxP`<\ngJY@LDejjJCkQRWNCGMxP`>\ngJY@LDejjJCkQRZ|HP<\ngJY@LDejjJCkQRZ|HP>\ngJY@LDejjJCkQR[NCEMxP`<\ngJY@LDejjJCkQR[NCEMxP`>\ngJY@LDij@CiAS_HNv]`\ngJY@LDij@CiAS_HNv^`\ngJY@LDij@CiASgAcf~P]l}@\ngJY@LDij@CiAU_HNv]`\ngJY@LDij@CiAU_HNv^`\ngJY@LDij@CiAUgAcf~P]l}@\ngJY@LDijXChabdmt`dH\ngJY@LDijXChabdmt`gp\ngJY@LDijXChabdn\\FJ[iAHP\ngJY@LDijXChabdut`dH\ngJY@LDijXChabdv\\FJ[iAHP\ngJY@LDijXChabdv\\FN[yAwRD\ngJY@LDijXChabhn\\FN[yAwRD\ngJY@LDijXCkAdf~P]l}@\ngJY@LDijXCkAdgNCGM|`{Yz\ngJY@LDijXCkAdj~P]l}@\ngJY@LDijdChabdmx``\ngJY@LDijdChabdn\\FN[iAOP\ngJY@LDijdChabdn\\FN[i^OP\ngJY@LDijdChabhn\\FN[iAOP\ngJY@LDijdCkAdf~P]t{@\ngJY@LDijdCkAdf~P]t}@\ngJY@LDijdCkAdgNCGM|`{Yz\ngJY@LDijdCkAdgNCGM|`{iz\ngJY@LDijdCkAdj~P]t}@\ngJY@LDijjQChabdmt`dH<\ngJY@LDijjQChabdmt`dH>\ngJY@LDijjQChabdn\\FJ[iAHP<\ngJY@LDijjQChabdn\\FJ[iAHP>\ngJY@LDijjQChabdn\\FN[iAHP<\ngJY@LDijjQChabdn\\FN[iAHP>\ngJY@LDijjQChabdut`dH<\ngJY@LDijjQChabdut`dH>\ngJY@LDijjQChabdv\\FJ[iAHP<\ngJY@LDijjQChabdv\\FJ[iAHP>\ngJY@LDijjQChabhv\\FJ[iAHP<\ngJY@LDijjQChabhv\\FJ[iAHP>\ngJY@dAreInZ@zt\\eshis^DH\ngJYABCJSKTAuhiu^XH\ngJYABCJSMUHauhis]XI|<\ngJYABCJSMUHauhis^XH<\ngJYABCJSMUHauhis^XH>\ngJYABCJSMUHauhiu^XH<\ngJYABCJSMUHauhiu^XH>\ngJYABCJS\\tAtiYnam[@\ngJYADArSMLAtXirWNbgMxP\x7FmD\ngJYADEJS[RAuhyKgQSf|OP\ngJYALMJRuUEAuhiK^DH<\ngJYALMJRuUEAuhiK^DH>\ngJYALMJTu@At`iodG[Np\ngJYDC`DPHRni`NdEH\ngJYHC`DIKTpGRbd\ngJYHC`DIKTpGRbgNCGH\ngJYHC`DISTpGVCEUx``\ngJYHC`DISUHGVCIM|`{Yv\ngJYHC`VIKTpGRbf|G`\ngJYHCaDIKTpGRbd\ngJYHCaxIKTpGRbf|G`\ngJYHDPDIMsPGRefzFul\ngJYHE@DIUmLBGQBgI[k^O_vb@<\ngJYHE@DIUmTBGQBgI[k^H_vb@<\ngJYHE@DIUmTBGQBgI[k^H_vb@>\ngJYHE@DIUmTBGQBgI[k^Oovb@<\ngJYHE@DIUmTBGQBgI[k^Oovb@>\ngJYHE@DIUmTBGQBgQ[kAH_vb@>\ngJYHI`DIKTpGVbdmtODO{R@\ngJYHI`DIKTpGVbdutODO{R@\ngJYHIaxIKTpGVbdmtOGw{R@\ngJYHIaxIKTpGVbdutODO{R@\ngJYHLEPISTpGVCDv\\FJ[i^HP\ngJYHL`DILmPGVbdmxP`\ngJYHL`DILmPGVbduxP`\ngJYHL`DILtpGVbdmxP`\ngJYHL`DILtpGVddm|M{YB\ngJYHL`DIMmPGVcdmxP\x7FmL\ngJYHL`DIMmPGVcduxP\x7FmL\ngJYHM@DIKT@GTc_Cvv^`\ngJYHlEPKmJTuLAu`qMgAbf~Wmta@\ngJY`BEdfVhCiQR\ngJY`LDTfvhCiQs~tp\ngJY`hEiNyIej@ztTeoBG}i@\ngJYieLPxAeIyIZf@zTT\x7FmD\ngJ\\@@bdrQ@]QMtM{_{Q@\ngJ\\@@bdrQ@]QMtM{o{Q@\ngJ\\@@bdru@]JR[h[w_vb@\ngJ\\@@bdru@]ZJ]YpXyoLG}h`\ngJ\\@@bdru@]ZJ]YtTynawA\x7FZH\ngJ\\@@bdvt`]JV[h[Vp\ngJ\\@@bdvt`]JV[h[WP\ngJ\\@@bdvu@]JNP\ngJ\\@@bdvu@]JV[h[Vp\ngJ\\@@bdvu@]JV[h[WP\ngJ\\@@ldru@]ZJRwPzP\x7FmD\ngJ\\@@ldru@]ZJRwaC~tP\ngJ\\@@ldru@]ZJRypXyoBG}h`\ngJ\\@@ldru@]ZJRytTyoBG}h`\ngJ\\@@ldru@]ZJSWPzP\x7FmD\ngJ\\@@ldru@]ZJSWaC~tP\ngJ\\@@ldru@]ZRRwpwmdO{Q@\ngJ\\@@ldru@]ZRRwpwndO{Q@\ngJ\\@@ldru@]ZRRytTyoao]H_vb@\ngJ\\@@ldru@]ZRSWpwmdO{Q@\ngJ\\@@ldru@]ZRSWpwndO{Q@\ngJ\\@@ldvE@]KI[x[VrG}i`=\ngJ\\@@ldvE@]KI[x[Vs{}i`=\ngJ\\@@ldvE@]KIkx[VrG}i`=\ngJ\\@ABeWU@]HR[j[v\x7Fv`@\ngJ\\@ABeWU@]HR[j[w_v`@\ngJ\\@ABeWU@]XJ\\wfC~t@\ngJ\\@ABeWU@]XJ\\ytTyoLG}h@\ngJ\\@ADeSU@]XTSWrwndO{HP\ngJ\\@ADe\\u@]DJ\\enlDa\x7FYA@=\ngJ\\@ADe\\u@]DJ\\es`qS]XIC~rB@\ngJ\\@AEddMTAuaYK_SZvP\x7Fm@=\ngJ\\@AEddMTAuaYM_SZvP\x7Fm@=\ngJ\\@ALe\\p@]PMumg_{P@\ngJ\\@ALe\\s@]HJkk[O_v`@\ngJ\\@ALe\\s@]XJSYpXinita\x7FZ@\ngJ\\@ALe\\t`]HJkk[N\x7Fv`@\ngJ\\@ALe\\t`]HJlxLTwVz^\x7Fm@\ngJ\\@AbeMK@]XLTwb{~t@\ngJ\\@AbeMK@]XLTypXioEw}h@\ngJ\\@AbeMK@]XLTypXyoEw}h@\ngJ\\@`bnLiLmPGRdfzF}o}h`\ngJ\\A@bIR[Z`NeKMtMkX\ngJ\\A@bnR[Z`NeKMtMkX\ngJ\\A@lIRYZ`NmEI[h]H_vb@\ngJ\\A@lIRYZ`NmEI[pa\x7FZH\ngJ\\A@lIRYZ`NmEI\\xL\\wPzP\x7FmD\ngJ\\A@lIRYZ`NmEI\\xL\\waC~tP\ngJ\\A@lIRYZ`NmEI\\zJ\\waC~tP\ngJ\\A@lIRYZ`NmEIkh]H_vb@\ngJ\\A@lIRYZ`NmEIkpa\x7FZH\ngJ\\A@lIRYZ`NmII[x[vrG}h`\ngJ\\A@lIR[B`Nedm|MkYC~tp\ngJ\\AAciRfe`NlFJ[i]w_v`@\ngJ\\AAciRfe`NlFJ[q]\x7FZ@\ngJ\\DAcJATBTuTAt`qs`qR>\ngJ\\HEb@aIej@zTT\x7FmD\ngJ\\HEb@aIfe@zTdwPwm\x7FmD\ngJ\\HEb@aInZ@zTlwPvm\x7FmL\ngJ\\HHlOAJfj@zpXeoC{|eBb\ngJ\\HHlOAJfj@zpXfoBG|eBcZP\ngJ\\HIb@aIZ`@zd[x^vso}i@=\ngJ\\HIbOAIY`@zd[k[N\x7Fvd@=\ngJ\\H`cj@SnR[Z`NeKMtNkh\ngJ\\Hib@b]iRVh@NiF~Gml{\x7FZP\ngJ\\IIb@b\\dmP@]RM|O[Yw~t`=\ngJ\\aibEIW[dfvhCiQs~rf@\ngJ]@EbDfVhCiQS~tP\ngJ]@ebEqeIej@zTT\x7FmD\ngJ]AEbCJSKTAthi\x7FZH\ngKP@DklVj@zhXirVzpRG|dml\ngKP@DklVj@zhXirWICEN[kAH_rRvp\ngKP@DklVj@zhXirWICEN[z]pRG|dml\ngKP@DklVjbPzhXirV~g\\D~\x7FIK[@<\ngKP@DklVjbPzhXirV~g\\D~\x7FIK[@>\ngKP@DklVjbPzhXirWICEN[kAOorRvp<\ngKP@DklVjbPzhXirWICEN[kAOorRvp>\ngKP@LdabjhCjabgI[zAPRG|dML\ngKP@LdabjjACjabgI[zAWbG|dML<\ngKP@LdabjjACjabgI[zAWbG|dML>\ngKP@LdabjjACjabgI\\dLTyohE^H_rPtp<\ngKP@LdabjjACjabgI\\dLTyohE^H_rPtp>\ngKP@LdabjjACjabgI\\xJ\\wtBoDOyHZX<\ngKP@LdabjjACjabgI\\xJ\\wtBoDOyHZX>\ngKP@LdabjjACjabgI\\zJ\\wtBoDOyHZX<\ngKP@LdabjjACjabgI\\zJ\\wtBoDOyHZX>\ngKP`@TixjjdPztTyoDG|dL\\<\ngKQ@@dmcUPGQbgI[kAH_rRvp\ngKQ@@eOEUTbGQbgI[iAH_rPqp<\ngKQ@@eOEUTbGQbgI[iAH_rPqp>\ngKQ@@eOEUTbGQbgI[i^H_rPqp<\ngKQ@@eOEUTbGQbgI[i^H_rPqp>\ngKQ@@eOEUTbGQbgI\\yNRwRBP\x7Fdac`<\ngKQ@@eOEUTbGQbgI\\yNRwRBP\x7Fdac`>\ngKQ@@eOEUTbGQbgI\\yNRwR|P\x7Fdac`<\ngKQ@@eOEUTbGQbgI\\yNRwR|P\x7Fdac`>\ngKX@@dmcUPGQbgI[kAH_rRvp\ngNp@DiYzA@zVVwQw]`=\ngNp@DiYzA@zVVwqw]oh=\ngNp@DiYzB@zVVwqw]lH=\ngNp@DiYzB@zVVwqw^lH\ngNp@DiYzB@zVVwq{^lH=\ngNp@Djfjj@zxXirVk[uApRFaXP\ngNp@Djfjj@zxXirVk\\dLRuoTGAHZEa@\ngNp@Djfjj@zxXirVk\\dNRuoTGAOjEa@\ngNp@Djfjj@zxXirVk\\lLTyKV}P\\DahVD\ngNp@Djfjj@zxXirVk\\lLTyKV}P\\Daogx\ngNp@Djfjj@zxXirVk\\lLTyKV}P\\D~hVD\ngNp@Djfjj@zxXirVk\\tLTek^hNBPtKB\ngNp@Djfjj@zxXirVk\\tLTek^hNB_TKB\ngNp@Djfjj@zxXirVskuApRFaXP\ngNp@Djfjj@zxXirVsldNRuoTGAOjEa@\ngNp@Djfjj@zxXirZk[uApRFaXP\ngNp@Djfjj@zxXirZk\\lLTyKV}P\\DahVD\ngNp@Djfjj@zxXirZk\\tLTek^hNBPtKB\ngNp@Djfjj@zxXitZk[uApRFaXP\ngNp@Djfjj@zxXitZskuApRFaXP\ngNp@DjfjjPTPzxXirVk\\tL\\ek^hNB_TK|<\ngNp@DjfjjPTPzxXirVk\\tL\\ek^hNB_TK|>\ngNp@DjfjjPTPzxXirZk\\tL\\ek^hNBPtK|<\ngNp@DjfjjPTPzxXirZk\\tL\\ek^hNBPtK|>\ngNp@DjfjjPTPzxXirZk\\xLRwjC`dMBp`<\ngNp@DjfjjPTPzxXirZk\\xLRwjC`dMBp`>\ngNp@DjfjjPTPzxXirZklxLRwjC`dMBp`<\ngNp@DjfjjPT`zxXirVk\\dL\\eoTGAOjEa@>\ngNp@DjfjjPT`zxXirVk\\tL\\ek^hNB_TK|>\ngNp@DjfjjPT`zxXirZk\\xLRwjC`dMBp`<\ngNp@DjfjjPT`zxXirZk\\xLRwjC`dMBp`>\ngNp@DjfjjPT`zxXirZklxLRwjC`dMBp`<\ngNp@DjfjjPT`zxXirZklxLRwjC`dMBp`>\ngNp@Djfjj`PzxXirVk\\tL\\ek^hNB_TKB<\ngNp@Djfjj`PzxXirVk\\tL\\ek^hNB_TKB>\ngNp@Djfjj`PzxXirZk\\dLRuoTGAHZEa@<\ngNp@Djfjj`PzxXirZk\\tL\\ek^hNBPtKB<\ngNp@Djfjj`PzxXirZk\\tL\\ek^hNBPtKB>\ngNp@DjfjjdPzxXirVk[uApRFa_`>\ngNp@DjfjjdPzxXirVk\\dLTeoTGAHZEa@<\ngNp@DjfjjdPzxXirVk\\dLTeoTGAHZEa@>\ngNp@DjfjjdPzxXirVk\\dLTuoTGAHZE~@<\ngNp@DjfjjdPzxXirVk\\dLTuoTGAHZE~@>\ngNp@DjfjjdPzxXirVk\\lLTyKV}P\\DahWx<\ngNp@DjfjjdPzxXirVk\\lLTyKV}P\\DahWx>\ngNp@DjfjjdPzxXirVk\\lLTyKV}P\\D~hWx<\ngNp@DjfjjdPzxXirVk\\tLTek^hNBPtK|<\ngNp@DjfjjdPzxXirVk\\tLTek^hNBPtK|>\ngNp@DjfjjdPzxXirVk\\xLRwjC`dMBp`<\ngNp@DjfjjdPzxXirVk\\xLRwjC`dMBp`>\ngNp@DjfjjdPzxXirVk\\xLZwjC`dMB\x7F@<\ngNp@DjfjjdPzxXirVk\\xLZwjC`dMB\x7F@>\ngNp@DjfjjdPzxXirVk\\xNRwjC`guBp`<\ngNp@DjfjjdPzxXirVk\\xNRwjC`guBp`>\ngNp@DjfjjdPzxXirVk\\xNZwjC`guB\x7F@<\ngNp@DjfjjdPzxXirVk\\xNZwjC`guB\x7F@>\ngNp@DjfjjdPzxXirVkkuApRFaXP<\ngNp@DjfjjdPzxXirVkkuApRFaXP>\ngNp@DjfjjdPzxXirVkldLTeoTGAHZEa@>\ngNp@DjfjjdPzxXirVkltLTek^hNBPtKB<\ngNp@DjfjjdPzxXirVklxLRwjC`dMBp`<\ngNp@DjfjjdPzxXirVklxLRwjC`dMBp`>\ngNp@DjfjjdPzxXirVklxLZwjC`dMBp`<\ngNp@DjfjjdPzxXirVklxLZwjC`dMBp`>\ngNp@DjfjjdPzxXirVslxLRwjC`dMBp`>\ngNp@DjfjjdPzxXirZk\\xNRwjC`dMBp`<\ngNp@DjfjjdPzxXirZk\\xNRwjC`dMBp`>\ngNp@DjfjjdPzxXirZkkuApRFaXP<\ngNp@DjfjjdPzxXirZkkuApRFaXP>\ngNp@DjfjjdPzxXitZk\\dJ\\eoTGAHZEa@>\ngNp@DjzZj@zhdejv}f}tahVD\ngNp@DjzZj@zhdejwNCGM{N{iCPlH\ngNp@DjzZj@zhdejwNbgM{M{iCPlH\ngNp@DjzZj@zhdejz}f}tahVD\ngNp@DjzZj@zhdelz}f}tahVD\ngNp@DjzZj@zxXirVk[gAHZEa@\ngNp@DjzZj@zxXirVk[v]pRFaXP\ngNp@DjzZj@zxXirVk\\fJ\\en]xahVD\ngNp@DjzZj@zxXirVk\\lLTyKVywbFaXP\ngNp@DjzZj@zxXirVk\\lLTyKV}g\\DahVD\ngNp@DjzZj@zxXirVk\\tLTyK\\xICPlH\ngNp@DjzZj@zxXirVk\\tLTyK\\{qCPlH\ngNp@DjzZj@zxXirVk\\tLTyK^snBPtKB\ngNp@DjzZj@zxXirVk\\tLTyK^sn|PtKB\ngNp@DjzZj@zxXirVk\\xLZwl{`dMB\x7F@\ngNp@DjzZj@zxXirVk\\xL\\wNBPtKB\ngNp@DjzZj@zxXirVk\\xL\\wl{`dMBp`\ngNp@DjzZj@zxXirVk\\zJZwNBPtK|\ngNp@DjzZj@zxXirVk\\zJ\\wNBPtKB\ngNp@DjzZj@zxXirVk\\zJ\\wN|PtKB\ngNp@DjzZj@zxXirVk\\zJ\\wl{oDMBp`\ngNp@DjzZj@zxXirVkkgAHZEa@\ngNp@DjzZj@zxXirVsldLRuoYwAHZEa@\ngNp@DjzZj@zxXitVk[gAHZEa@\ngNp@DjzZj@zxXitVk[v]pRFaXP\ngNp@DjzZj@zxXitVk\\tLTyK^snBPtKB\ngNp@DjzZj@zxXitVk\\xL\\wNBPtKB\ngNp@DjzZj@zxXitVkldL\\eoYwAHZEa@\ngNp@DjzZjbPzhdej{NCGM{N{iCPlH<\ngNp@DjzZjbPzxXirVk\\tLTyk\\xICPop<\ngNp@DjzZjbPzxXirVk\\tLTyk\\xICPop>\ngNp@DjzZjbPzxXirVk\\tLTyk^snBPtK|>\ngNp@DjzZjbPzxXirVklxL\\wl{`dMBp`<\ngNp@DjzZjbPzxXirVklxL\\wl{`dMBp`>\ngNp@DjzZjbPzxXirVslxLRwl{`dMBp`<\ngNp@DjzZjbPzxXirVslxLRwl{`dMBp`>\ngNp@LdadBj@zNRu[^sZvPtKB=\ngNp@LdadBj@zNRu[^sZvPtKC~RqI@=\ngNp@LdadBj@zNRu[^sZvPtKC~VqIi@=\ngNp@LdadBj@zNRu[^sZvPtK|=\ngNp@LdadBj@zNRu[^sZvPtK}~VqIi@=\ngNp@LdadBj@zNRu[^sZzPtKB\ngNp@LdadBj@zNRu[^sjzPtKB=\ngNp@LdadBj@zNRu[^sjzPtKC~RqI@=\ngNp@LdadBj@zNRu[dqSdm{MkiCPlH\ngNp@LdadBj@zNRu[gASV}gUtahWx\ngNp@LdadBj@zNRu[gASf}gUtahVD\ngNp@LdadBj@zNRu[gQSV}futahWx\ngNp@LdadBj@zNRu[gQSf}futahVD\ngNp@LdadBj@zNRu]^sZvPtKB=\ngNp@LdadBj@zNRu]^sZvPtKC~RqI@=\ngNp@LdadBj@zNRu]^sZzPtKB\ngNp@LdadBj@zNRu]dqSdm{MkiCPlH\ngNp@LdadBj@zNRu]gQSV}futahVD\ngNp@LdadBj@zNRu]gQSV}futahVG|ebR\ngNp@LdadBj@zNRv]^sZvPtKB=\ngNp@LdadBj@zNRv]^sZzPtKB\ngNp@LdadBj@zNRv]daRVm{NkiCPlH\ngNp@LdadBj@zNRv]dqRVm{MkiCPlH\ngNp@LdadBj@zNRv]gQSf}futahVD\ngNp@LdadBj@zNSU[^sZvPws|=\ngNp@LdadBj@zNSV[^sZvPtK|=\ngNp@LdadBj@zNSV[gQSV}futahWx\ngNp@LdadBj@zNSV]^sZvPtKB=\ngNp@LdadBj@zNSV]^sZzPtKB\ngNp@LdadBj@zNSV]dqSdm{MkiCPlH\ngNp@LdadBj@zNSV]gQSf}futahVD\ngNp@LdadBjfPzNRu[^sZvPtK}~Rqi@-\ngNp@LdadBjfPzNRu[gQSf}futahWx>\ngNp@LdadBjfPzNRu]dqSfm{MkiCPlH<\ngNp@LdadBjfPzNRu]dqSfm{MkiCPlH>\ngNp@LdadBjfPzNRu]gQSf}futahVD<\ngNp@LdadBjfPzNRu]gQSf}futahVD>\ngNp@LdadBjfPzNRv[^sZvPtK|+\ngNp@LdadBjfPzNRv[^sZvPtK|-\ngNp@LdadBjfPzNRv[^sZvPtK}~Rqi@+\ngNp@LdadBjfPzNRv[^sZvPtK}~Rqi@-\ngNp@LdadBjfPzNRv[gQRV}futahW{|ecR<\ngNp@LdadBjfPzNRv[gQRV}futahW{|ecR>\ngNp@LdadBjfPzNRv]gQRV}futahVD<\ngNp@LdadBjfPzNRv]gQRV}futahVD>\ngNp@LdadBjfPzNSV[gQSf}futahWx<\ngNp@LdadBjfPzNSV[gQSf}futahWx>\ngNpB@xQpSagCIIKJj`NbDmVwl|o[uBp\x7Fe`XTP\ngNpB@xQpk`wAJkjj`NbENRwNBPws|\ngNpBADFPl`yAInij`NmENP\ngNpCAHR`TaiB]dTaeT@GTc]W[z\ngNpD@DHHRZzj@CiQK_DMv}`=\ngNpD@DHHRZzj@CiQK_Guv}`=\ngNpD@DHHRZzj@CiQM_DMv}`=\ngNpD@DHHRZzjhCjqrVk\\eNRuobFaXP\ngNpD@DIpRYjfhCiqSdmVwH|PtK|\ngNpD@DIpRYjfhCjrRVk[t[vrFaXP\ngNpD@DIpRYjfhCjrRVk[t[vrFa_`\ngNpD@DIpRYjfhCjrRVk[t[wRFaXP\ngNpD@DSpRZYj@CkQrVypRF{^p=\ngNpD@DSpRZYj@CkQtZypRF{^p=\ngNpD@DSpRZYj@CkQtZypRF{_P\ngNpD@DSpRZYj@CkQtZypRF}_P=\ngNpD@DSpRZYj@CkQt[MbgIZwNBPwkz=\ngNpD@DSpRZYjBQCkQrZypRF{^p+\ngNpD@DSpRZYjBQCkQrZypRF{^p-\ngNpD@DSpRZYjhCiqSdmVwNBPtKB\ngNpD@DSpRZYjjQCiqSduVwNBPtKB<\ngNpD@DSpRZYjjQCiqSduVwNBPtKB>\ngNpD@bIpRYjfhCjrRVk[t[vrFaXP\ngNpD@bQpRZZj@CkQtZypRF{^p=\ngNpD@bSpRZYj@CkQtZypRF{^p=\ngNpD@bSpRZYj@CkQtZypRF{_P\ngNpD@bSpRZYjBQCkQrZypRF{^p+\ngNpD@bSpRZYjBQCkQrZypRF{^p-\ngNpD@bSpRZYjhCiqSdmVwNBPtKB\ngNpD@xN`RjZjXCiabgIZwJC`dMz\ngNpD@xQpRjzj@CkArV}glDanwl=\ngNpD@xQpRjzj@CkArV}glDanwt\ngNpD@xQpRjzj@CkAtZ}glDanwl=\ngNpD@xQpRjzj@CkAt[IbgM[v^pRF{_P\ngNpD@xQpRjzjBACkArZ}glDanwl-\ngNpD@xQpRjzjhCiaSdmVwNBPtKB\ngNpD@xQpRjzjhCiaSdmVwl}`dMBp`\ngNpD@xRPRjzj@CkAtZypRF{^p=\ngNpD@xRPRjzj@CkAtZypRF{_P\ngNpD@xUpRjZjdCiabgIVwJC`dM|\ngNpD@xUpRjZjjQCiabgIWWjC`dM|p`<\ngNpD@xUpRjZjjQCiabgIWWjC`dM|p`>\ngNpDADFHR[jZhCjqSfk\\fJRuoevaXP\ngNpDAHJPRZzj@CiQK_DMv~`\ngNpDAHJPRZzj@CiQK_Guv}`=\ngNpDAHJPRZzj@CiQK_Guv~`\ngNpDAHJPRZzj@CiQK_Guz~`=\ngNpDAHJPRZzjXCjqrVk[xaoVD\ngNpDAxKpR[ijhCjqrVk[xahVD\ngNpDAxSpRjyj@CkAtZypRF{^p=\ngNpDAxSpRjyjBACkArZypRF{^p+\ngNpDAxSpRjyjBACkArZypRF{^p-\ngNpD`DR`Dsdffj`@zt]Fn\\DaoWt=\ngNpDaxF`Dgdjfj`@zpTynTGAnwl=\ngNpDaxF`Dgdjfj`@zpUZnTGAnwl=\ngNpDaxF`Dgdjfj`@zpUZoTGAOkm{@=\ngNpDaxF`Dgdjfj``PzpTznTGAnwl+\ngNpDaxF`Dgdjfj``PzpTznTGAnwl-\ngNpDaxF`Dgdjfj``PzpTznTGAnwt<\ngNpDaxF`Dgdjfj``PzpTzoTGAOkm{\x7FIPx`+\ngNpDaxF`Dgdjfj``PzpTzoTGAOkm{\x7FIPx`-\ngNpDaxF`Dgdjfjj@zXXisUmr`xMBp`\ngNpDaxF`Dgdjfjj@zXXisUmz`xI}PlH\ngNpDaxF`Dgdjfjj@zXXjuUmr`xMBp`\ngNpDaxF`Dgdjfjj`PzXXiuUmr`xMBp`<\ngNpDaxF`Dgdjfjj`PzXXiuUmr`xMBp`>\ngNpDaxR`Dsdffj`@zt]Fn\\DaoWt=\ngNpDaxR`Dsdffj`@zt]FoQ{AH[u}@=\ngNpDaxR`Dsdffj`dPzt\\foQ{AH[u}\x7FI@h`+\ngNpDaxR`Dsdffj`dPzt\\foQ{AH[u}\x7FI@h`-\ngNpE@DSpdiMMU@AuhzM\\xIC]oX=\ngNpE@bSpdiMMU@AuhzM\\xIC]oX=\ngNpE@bSpdiMMUAHauhyM\\xIC]oX+\ngNpE@bSpdiMMUAHauhyM\\xIC]oX-\ngNpE@bSpdiMMUTAtxirVk[gAHZEa@\ngNpEADR`gIMMU@AuhzM\\xIC^oh=\ngNpEAHR`gIMMU@AuhzM\\xIC]oX=\ngNpEAHR`gIMMU@AuhzM\\xIC^oh=\ngNpEAHR`gIMMU@AuhzMfqSdm[gAH[u}@=\ngNpEAVRDdiMMU@AuhzM\\xIC]oX=\ngNpEAVSpdiMMU@AuhzM\\xIC]oX=\ngNpEAVSpdiMMU@AuhzM\\xIC]oh\ngNpEAVSpdiMMUTAtxirVk[gAHZEa@\ngNpEAbSpdiMMU@AuhzM\\xIC]oX=\ngNpEAxF`DiUMU@Au`ju\\hNC]oX=\ngNpEAxF`DiUMUTAtpqSfk[eApZEa@\ngNpEAxRPDiU]U@Au`zM\\xIC]oX=\ngNpEAxRPDiU]U@Au`zM\\xIC^oh=\ngNpEAxR`gIMMU@AuhzM\\xIC^oh=\ngNpEAxSpDiUMUTAupqSdmgWjC`dMBp`\ngNpEAxSpDiU]U@Au`zM\\xIC]oX=\ngNpEAxSpDiU]UA@au`yM\\xIC]oX+\ngNpEAxSpDiU]UA@au`yM\\xIC]oX-\ngNpEAxSpDiU]UTAtpirVk[gAHZEa@\ngNpH@DIMMU@AuhyK\\xIC]oX=\ngNpH@DIMMU@AuhzM\\xIC]oX=\ngNpH@DIMMU@AuhzMdqSfms`dMv~`\ngNpH@DIMMUAHauhyK^cvBPw[w~RAQ@-\ngNpH@DIMMUAHauhyMdqSfms`dMv~`<\ngNpH@DIMMUAHauhyMdqSfms`dMv~`>\ngNpH@DIMuMTAuYYKUmzMkYCPlH\ngNpH@DIMuMTAuYYKUuzMkYCPlH\ngNpH@DIMuMTAuYYKYuzMkYCPlH\ngNpH@DISmW@At`iodF{_P\ngNpH@bIMMU@AuhzMdqSfms`dMv~`\ngNpH@bISmW@At`iodF{_P\ngNpH@xIUMU@AtPirV}P\\Danwl=\ngNpH@xIUMU@AtPirV}P\\Danwt\ngNpH@xIUMU@AtPirV}P\\DaoWt=\ngNpH@xIUMU@AtPirV}P\\D~nwl=\ngNpH@xIUMU@AtPirWNCFmz`xIC]oh\ngNpH@xIUMU@AtPirZ}P\\Danwl=\ngNpH@xIUMU@AtPirZ}P\\Danwt\ngNpH@xIUMU@AtPirZ}P\\DaoWt=\ngNpH@xIUMU@AtPir[NCfmz`xIC]oh\ngNpH@xIUMU@AtPitZ}P\\Danwl=\ngNpH@xIUMU@AtPitZ}P\\Danwt\ngNpH@xIUMU@AtPjtV}P\\D~nwl=\ngNpH@xIUMU@AtPjtZ}P\\Danwl=\ngNpH@xIUMU@AtPjtZ}P\\Danwt\ngNpH@xIUMU@AtPjt[NCFmz`xIC]oh\ngNpH@xIUMUA@atPitV}P\\D~nwl+\ngNpH@xIUMUA@atPitV}P\\D~nwl-\ngNpH@xIUMULAuPrSdmz`xIC^oX\ngNpH@xIUMULAupqSdmVwJC`dKB\ngNpH@xIUMULAupqSdmVwjC`dMzp`\ngNpH@xIUMULAupqSdmVwjC`dMzp\x7FdbZP\ngNpH@xIUMULAupqSdmWWjC`dMzp`\ngNpH@xIUMULAupqSduVwJC`dKB\ngNpH@xIUMUTAupqSdmVwjC`dMBp`\ngNpH@xIUMUTAupqSdmVwjC`guBp`\ngNpH@xIUMUTAupqSduVwjC`dMBp`\ngNpH@xIUMUTAupqShuVwjC`dMBp`\ngNpHABIUMM@AtPitZ}W\\Danwl=\ngNpHADIMMULAtxirVk\\vJ\\ek\\xIC^op\ngNpHAHILuUUHatxirVk\\zJ\\wNBPtKB<\ngNpHAHIMMU@AuhyK\\xIC]oX=\ngNpHAHIMMUUHatxirVk\\vJ\\ek\\xI}PlH<\ngNpHAbILuUUHatxirVk\\zJ\\wNBPtKB>\ngNpHAxIMMU@AuhzM\\xIC]oX=\ngNpHAxIMMU@AuhzM^cvBPw[v=\ngNpHAxITuUTAupqUhmVwjC`dMBp`\ngNpHAxITuUU@aupqSdmVwjCoDMBp`<\ngNpHAxITuUU@aupqSdmVwjCoDMBp`>\ngNpHAxITuUU@aupqUdmVwjCoDMBp`<\ngNpHAxITuUU@aupqUdmVwjCoDMBp`>\ngNpHAxIUMA@AoUw]H[m{@=\ngNpHAxIUMM@AtPitZypRF{^p=\ngNpHAxIUMM@AtPitZ}W\\Danwl=\ngNpHAxIUMMA@atPirZ}W\\Danwl+\ngNpHAxIUMMA@atPirZ}W\\Danwl-\ngNpHGPYICHETAulfm\\sZvPtH=\ngNpIABBTjfj`@zHTzM^hNBPw[v=\ngNpIABBTjfj`@zHUZM^hNBPw[v=\ngNpIAxBTjZjj@zxXirVk[u^wbFaXP\ngNpIAxBTjZjj`PzxXirVk[uAwbFaXP<\ngNpIAxBTjZjj`PzxXirVk[uAwbFaXP>\ngNpIAxBTjfj`@zHTyK^hNBPwkz=\ngNpIAxBTjfj`@zHTyM^hNBPw[v=\ngNpIAxBTjfj`@zHTyM^hNBPwkz=\ngNpIAxBTjfj`@zHTzM^hNBPw[v=\ngNpIAxBTjfj`@zHTzM^hNBPw[z\ngNpIAxBTjfj`@zHTzM^hNBPwkz=\ngNpIAxBTjfj`@zHTzMgAcV}P\\Danwt\ngNpIAxBTjfj`@zHUZK^hNB_W[v=\ngNpIAxBTjfj`@zHUZM^hNBPw[v=\ngNpIAxBTjfj`@zHUZM^hNBPw[z\ngNpIAxBTjfjf@zxXjtZk[eApREa@\ngNpIAxBTjfjj@zxXirVk[uApRFaXP\ngNpIAxBTjfjj@zxXirZk[uApRFaXP\ngNpIMP[ldadBj@zNRu[^sZvPtKB=\ngNpIMP[ldadBj@zNRu]^sjzPtKB=\ngNpIMP[ldadBj@zNRv]^sZvPtKB=\ngNpIMP[ldadBj@zNRv]^sjzPtKB=\ngNpIMP[ldadBj@zNSV]^sZvPtKB=\ngNpIMP[ldadBj@zNSV]^sjzPtKB=\ngNpIMP[ldadBj@zNSV]dqSdm{MkiCPlH\ngNpL@DIpK`dsUMPGQdfk[t[vszaXP\ngNpL@VSDVIddaeT@GRBZ~H[m{@=\ngNpL@VSDVIddaeT@GRBZ~H[m}@\ngNpL@xIpsadTaeT@GTc^cr}oW[v=\ngNpL@xQpSaddaeT@GRBZ}gexanwl=\ngNpL@xQpSaddaeT@GRBZ}gexaoWw|dCB=\ngNpL@xQpSaddaeUPGUCdmVwl|oDMBp\x7Fd`XP\ngNpL@xUp[`eTuUPGUCENRwjC`dM|\x7F@\ngNpLABIps`dsUUTbGUbdmVwN|PtKB<\ngNpLABIps`dsUUTbGUbdmVwN|PtKB>\ngNpLADJHtQdTaeUPGQbVskjaXP\ngNpLAHJPtadTaeT@GTc]W[v=\ngNpLAHJPtadTaeT@GTc]W[z\ngNpLAHJPtadTaeT@GTc]Wkz=\ngNpLAHJPtadTaeTpGQbVk[j}XP\ngNpLAHJPtadTaeTpGQbVk[qa@\ngNpLAHJPtadTaeTpGQbVkkqa@\ngNpLAHJPtadTaeTpGRbZzoWl\ngNpLAHJPtadTaeTpGRbZzoWt\ngNpLAHJPtadTaeUPGQbVk[jaXP\ngNpLAHJPtadTaeUTJGQbVk[ja_`<\ngNpLAHJPtadTaeUTJGQbVkkjaXP<\ngNpLAHJPtadTaeUTJGQbVkkjaXP>\ngNpLAxIps`dsUUTbGUbdmVwN|PtKB<\ngNpLAxIps`dsUUTbGUbdmVwN|PtKB>\ngNpLaxKpw`itiLtuTAuXiMYusoDMBp`\ngNpMAxZ`M@IRjZjhCjabfk[uAwczaX_rRNH\ngNpMAxZ`M@IRjZjjACjabfk[eAwjEa\x7FIHx`<\ngNpMAxZ`M@IRjZjjACjabfk[eAwjEa\x7FIHx`>\ngNpP@cTfzZj@zt\\moFD\ngNpXHmQxYIIXuUBau`e[^LH<\ngNpXHmQxYIIXuUBau`e[^LH>\ngNpXHmQxYIIXuUBau`e]^LH<\ngNpXHmQxYIIXuUBau`e]^LH>\ngNp`@TfZZj@zlTyjv~pZEa@\ngNp`@TfZZj@zlTzjv~pZEa@\ngNp`@TfZZjb`zlTyjv~pZE~@<\ngNp`@TfZZjb`zlTyjv~pZE~@>\ngNp`@TfZZjb`zlTyjwIbgI[{AhVD>\ngNp`@TfZZjb`zlTyjwNbdm}`tKB<\ngNp`@TfZZjb`zlTyjwNbdm}`tKB>\ngNp`@TfZZjb`zlTyjwNbdm}`tK|>\ngNp`@TfZZjb`zlTyjwNbdm}oTKB<\ngNp`@TfZZjb`zlTyjwNbdm}oTKB>\ngNp`@TfZZjb`zlTyjwNbfm}`tK|<\ngNp`@TfZZjb`zlTyjwNbfm}`tK|>\ngNp`@TfZZjb`zlTyj{Nbfm}`tKB<\ngNp`@TfZZjb`zlTzjwNbdm}`tKB<\ngNp`@TfZZjb`zlTzjwNbdm}`tKB>\ngNp`@TfZZjb`zlTzjwNbfm}`tK|<\ngNp`@Tfzfjf`zlTyjwNbdmuPlH>\ngNp`@dfnj`@zTRwqC]oX=\ngNp`@dfnj`@zTRwqC]oh\ngNp`@dfnj`@zTRwq}]oX=\ngNp`@dfnj`@zTRyr\\uobF{_P\ngNp`@dfnj`@zTRyr\\uocz{_P\ngNp`@dfnj`@zTSWqC]oX=\ngNp`@dfnj`dPzTRypTuobF{_P>\ngNp`@dfnjf@zl\\ejwNSdmtPlH\ngNp`@dfnjj@zl\\ejv~HZEa@\ngNp`@dfnjj@zl\\ejwISdm[xahVD\ngNp`@dfnjjTV`zl\\ejwNBdm|PtKB<\ngNp`@dfnjjTV`zl\\ejwNBdm|PtKB>\ngNp`@dfnjjdPzl\\ejwMBgIZwqCPlH<\ngNp`@dfnjjdPzl\\ejwMBgIZwqCPlH>\ngNp`@dfnjjfPzl\\ejwICEM[xahWx<\ngNp`@dfnjjfPzl\\ejwNSdm|PtKB<\ngNp`@dfnjjfPzl\\ejwNSdm|PtKB>\ngNp`@dfzZj@zl\\ejv~HZEa@\ngNp`@dfzZj@zl\\ejv~HZEa\x7FIXd`\ngNp`@dfzZj@zl\\ejv~HZEa\x7FKXdt`\ngNp`@dfzZj@zl\\ejv~HZE~@\ngNp`@dfzZj@zl\\ejv~H[y~@\ngNp`@dfzZj@zl\\ejwIbgI[xahVD\ngNp`@dfzZj@zl\\ejwNbgM|PtKB\ngNp`@dfzZj@zl\\ejz~HZEa@\ngNp`@dfzZj@zl\\elz~HZEa@\ngNp`@dfzZjfPzl\\ejv~HZE~\x7FIXt`<\ngNp`@dfzZjfPzl\\elv~HZE~@<\ngNp`@dfzZjfPzl\\elv~HZE~@>\ngNp`@dfzjj@zl\\ejv~HZEa@\ngNp`@dfzjjdPzl\\ejwNBgM|PtKB>\ngNp`ATffjjTRPzlTyJv~pSya@<\ngNp`ATffjjTRPzlTyJwMCEIZwvBPlH<\ngNp`ATffjjTRPzlTyJwMCEIZwvBPlH>\ngNp`ATffjjTRPzlTyJwNbfm}`dKB<\ngNp`ATffjjTRPzlTyJwNbfm}`dKB>\ngNp`ATffjjTRPzlTyJwNbfm}`dK|<\ngNp`ATffjjTRPzlTyJwNbfm}`dK|>\ngNp`ATffjjTRPzlTyJwNbfm}`gsB>\ngNp`ATffjjTRPzlTyJwNbfm}oGsB>\ngNp`ATffjjTRPzlTyJwNcfm}`gsB<\ngNp`ATffjjTRPzlTyJwNcfm}`gsB>\ngNp`ATffjjTR`zlTyJwICEM[{AHVD>\ngNp`ATffjjTR`zlTyJwNbdm}`dKB<\ngNp`ATffjjTR`zlTyJwNbfm}`dKB<\ngNp`ATffjjTR`zlTyJwNbfm}`dKB>\ngNp`ATffjjTR`zlTyJwNbfm}`dK|<\ngNp`ATffjjTR`zlTyJwNcfm}`gsB<\ngNp`ATffjjTR`zlTyLv~pREa@<\ngNp`ATffjjTR`zlTyLz~pREa@>\ngNp`ATffjjb`zlTyJv~pREa@<\ngNp`ATffjjb`zlTyJv~pREa@>\ngNp`ATffjjb`zlTyJv~wcya@<\ngNp`ATffjjb`zlTyJwIbgM[{AHVD>\ngNp`ATffjjb`zlTyJwNCFm}`dKB<\ngNp`ATffjjb`zlTyJwNCFm}`dKB>\ngNp`ATffjjb`zlTyJz~pREa@>\ngNp`ATffjjb`zlTzLv~pREa@<\ngNp`ATffjjb`zlTzLv~pREa@>\ngNpa@erS]MU@]VNRu[_DMBp`\ngNpa@erS]MU@]VNRu[_DMBp\x7FdlRP\ngNpa@erS]MU@]VNSV]_DMBp`\ngNpdH`DTHrRPqZjYCharYm|PwsB<\ngNpdH`DTHrRPqZjYCharYm|PwsB>\ngNpdJqHJPRZzjXCkQrV|HP\ngNpdJqHJPRZzjXCkQrV|O`\ngNpdJqHJPRZzjXCkQrZ|HP\ngNpeE`DSpGYEHYMAHauHwUv}`+\ngNphH`DYIHXm@At`eobF{^p=\ngNphH`DYIHXm@At`eobF{_P\ngNphH`DYIHXm@At`eocz{^p=\ngNphH`DYIHXm@At`eocz}_P=\ngNphH`DYIHXm@At`fobF{^p=\ngNphH`DYIHXm@At`fobF{_P\ngNphH`DYIHXm@At`fobF}_P=\ngNphH`DYIHXm@At`fsdyk_DMv~`\ngNphH`DYIHXmLAuPyMUmtPlH\ngNphH`DYIHXmLAuPyMUm|PwkB\ngNphH`DYIHXmLAuPyMUutPlH\ngNphH`DYIHXmLAuPyMUu|PwkB\ngNphH`DYIHXmLAu`zK_DMz~`\ngNphH`DYIHXmLAu`zM_DMz~`\ngNphH`DYIHXmTAuPyKUm|PtKB\ngNphH`DYIHXmTAuPyMUm|PtKB\ngNphH`DYIHXmULauPyKUn\\gI[xahVD<\ngNphH`DYIHXmULauPyKUn\\gI[xahVD>\ngNphH`DYIHXmULauPyMUm|PtK|<\ngNphH`DYIHXmULauPyMUu|PtKB<\ngNphH`DYIHXmULauPyMUu|PtKB>\ngNphH`VYIHYU@At`fobF{^p=\ngNphH`xYIHYU@At`eobF{^p=\ngNphH`xYIHYU@At`fobF{^p=\ngNphH`xYIHYU@At`fobF{_P\ngNphH`xYIHYU@At`fobF}_P=\ngNphH`xYIHYUTAuPyKUm|PtKB\ngNphHaxYIHXuA@at`eobF{^p+\ngNphHaxYIHXuA@at`eobF{^p-\ngNphHaxYIHXuA@at`fobF{^p+\ngNphHaxYIHXuA@at`fobF{^p-\ngNphJpDIMMULAtXirVzpRD\ngNphJqHIMMULAtXirVzpRD\ngNphJqbIMMULAtXirVzpRD\ngNpi@iPSdfnj`@zTSWqC]oX=\ngNpi@iPSdfnj`@zTSWqC^oh=\ngNplJqDJHtQdTaeTpGRbT\ngNplJqHJPtadTaeTpGRbT\ngNpmJqDJHtP~rJPrjXCiQJ\ngNpmJqHJPt`~rJPrjXCiQJ\ngNq@@dju\\@GTc]W[v=\ngNq@@dju\\@GTc]W[z\ngNq@@dsSUPGSbgIZmn\\DahVD\ngNq@@dsSUPGSbgIZmn\\DahWx\ngNq@@dsSUPGSbgIZmn]xahVD\ngNq@@dsSUPGSbgIZmrXirVypRFaXP\ngNq@@dsSUPGSbgIZmrXirVywbFaXP\ngNq@@dsSUPGSbgIZmshik\\xICPop\ngNq@@dsSUPGSbgIZmshik\\{qCPop\ngNq@@dsSUPGSbgIZmshis\\xICPlH\ngNq@@dsSUPGSbgIZmshis\\{qCPlH\ngNq@@dsSUPGSbgIZnn\\DahVD\ngNq@@dsSUPGSbgIZnn]xahVD\ngNq@@dsSUPGSbgIZnshik\\xICPlH\ngNq@@dsSUPGSbgI[Nn\\DahVD\ngNq@@dsSUPGSbgQZmn\\DahVD\ngNq@@dsSUPGSbgQZmn\\DahWx\ngNq@@dsSUPGSbgQZmshik\\xICPop\ngNq@@dsSUPGSbgQZmshis\\xICPlH\ngNq@@dsSUPGSbgQZnn\\DahVD\ngNq@@dsSUTRGSbgIZmrXisVypRFa_`<\ngNq@@dsSUTRGSbgIZmrXisVypRFa_`>\ngNq@@dsSUTRGSbgIZmrXisVywbFa_`<\ngNq@@dsSUTRGSbgIZmrXisVywbFa_`>\ngNq@@dsSUTRGSbgIZmshis\\xICPop<\ngNq@@dsSUTRGSbgIZmshis\\xICPop>\ngNq@@dsSUTRGSbgIZmshis\\{qCPop<\ngNq@@dsSUTRGSbgIZnshis\\xICPlH<\ngNq@@dsSUTRGSbgIZnshis\\xICPlH>\ngNq@@dsSUTRGSbgQZmshis\\xICPop>\ngNq@@dsSUTRGSbgQZnshis\\xICPlH<\ngNq@@dsUURbRGSbgIZmsPqSfms`dMB\x7F@<\ngNq@@dsUURbRGSbgIZmshis\\xICPop<\ngNq@@dsUURdRGSbgIZmshiK\\xIC_Op>\ngNq@@dsUURdRGSbgIZmshis\\xICPop<\ngNq@@dsUURdRGSbgIZmshis\\xICPop>\ngNq@@dsUURdRGSbgIZnshis\\xICPlH<\ngNq@@dsUUTbGSbgIZmn\\DahVD<\ngNq@@dsUUTbGSbgIZmn\\DahVD>\ngNq@@dsUUTbGSbgIZmn\\DahWx>\ngNq@@dsUUTbGSbgIZmrPqSfypRFaXP<\ngNq@@dsUUTbGSbgIZmrXirVypRFaXP<\ngNq@@dsUUTbGSbgIZmrXirVypRFaXP>\ngNq@@dsUUTbGSbgIZmrXirVywbFaXP<\ngNq@@dsUUTbGSbgIZmrXirVywbFaXP>\ngNq@@dsUUTbGSbgIZmsPqSdms`dMBp`<\ngNq@@dsUUTbGSbgIZmsPqSdms`dMBp`>\ngNq@@dsUUTbGSbgIZms`qs\\xICPlH<\ngNq@@dsUUTbGSbgIZmshik\\xICPop<\ngNq@@dsUUTbGSbgIZmshik\\xICPop>\ngNq@@dsUUTbGSbgIZmshis\\xICPlH<\ngNq@@dsUUTbGSbgIZmshis\\xICPlH>\ngNq@@dsUUTbGSbgIZmshis\\{qCPlH<\ngNq@@dsUUTbGSbgIZmshis\\{qCPlH>\ngNq@@dsUUTbGSbgIZnshik\\xICPlH>\ngNq@@dsUUTbGSbgQZmn\\DahVD<\ngNq@@dsUUTbGSbgQZmn\\DahVD>\ngNq@@dsUUTbGSbgQZms`qk\\xICPop>\ngNq@@dsUUTbGSbgQZms`qs\\xICPlH<\ngNq@@dsUUTbGSbgQZms`qs\\xICPlH>\ngNq@@dsUUTbGSbgQZmshis\\xICPlH>\ngNq@@dtuT@GVcdms`dMv}`=\ngNq@@dtuT@GVcdms`dMv}\x7Fdd\\P=\ngNq@@dtuT@GVcdms`dMv~`\ngNq@@dtuT@GVcdmsoGuv~`\ngNq@@dtuT@GVcdn\\FM[gAH[m}@\ngNq@@dtuT@GVchus`dMv}`=\ngNq@@dtuT@GVchus`dMv~`\ngNq@@dtuT@GVchus`dMz~`=\ngNq@@dtuT@GVchvSENZwNBPw[z\ngNq@@dtuT@GVchvVFJ\\ek\\xIC^oh=\ngNq@@dtuT@GVchv\\FM[gAH[m}@\ngNq@@dtuTDbGVcdms`guv}`+\ngNq@@dtuTDbGVcdms`guv}`-\ngNq@@dtuTDbGVcdms`guv}\x7Fdd\\P-\ngNq@@dtuTDbGVcdn]EM[gAH[m}@<\ngNq@@dtuTDbGVcdn]EM[gAH[m}@>\ngNq@@dtuTDbGVcdn]GM[gAOkm}@<\ngNq@@dtuTDbGVcdn]GM[gAOkm}@>\ngNq@@dtuTDbGVcdus`dMv}`+\ngNq@@dtuTDbGVcdus`dMv}`-\ngNq@@dtuTDbGVcdus`dMv~`<\ngNq@@dtuTDbGVcdus`dMv~`>\ngNq@@dtuTDbGVcdv]EM[gAH[m}@<\ngNq@@dtuTDbGVcdv]EM[gAH[m}@>\ngNq@@dtuTDbGVcdv]GI[gAH[u}@<\ngNq@@dtuTDbGVcdv]GI[gAH[u}@>\ngNq@@dtuTDbGVcdv]GM[gAH[m}@<\ngNq@@dtuTDbGVcdv]GM[gAH[m}@>\ngNq@@dtuTDbGVchms`guv}`+\ngNq@@dtuTDbGVchms`guv}`-\ngNq@@dtuTDbGVchvRFJZwNBPw[z<\ngNq@@dtuTDbGVchvRFJZwNBPw[z>\ngNq@@dtuTDbGVchv]EM[gAH[m}@<\ngNq@@dtuTDbGVchv]EM[gAH[m}@>\ngNq@@dtuTpGSbgIZmolDaXP\ngNq@@dtuTpGSbgIZmrpqSdm[{AHVD\ngNq@@dtuTpGSbgIZmsXirVm}`dKB\ngNq@@dtuTtbGSbgIZmsXirVm}`gsB<\ngNq@@dtuTtbGSbgIZmshiK\\xIC^lH<\ngNq@@dtuTtbGSbgIZmshik_XIBp`<\ngNq@@dtuTtbGSbgIZmshik_XIBp`>\ngNq@@dtuTtbGSbgIZmshik_XIB\x7F@<\ngNq@@dtuTtbGSbgIZmshyk_XI|p`<\ngNq@@dtuUPGSbgIZmn\\DahVD\ngNq@@dtuUPGSbgIZmn\\DahVG|dSR\ngNq@@dtuUPGSbgIZmrpqSdm[gAHZEa@\ngNq@@dtuUPGSbgIZmsXirVms`dMBp`\ngNq@@dtuUPGSbgI[Nn\\DahVD\ngNq@@dtuURbRGSbgIZmrPqRVypRFaXP<\ngNq@@dtuURbRGSbgIZmrXiKVypRFa_orQMH<\ngNq@@dtuURbRGSbgIZmrXiKVypRFa_orQMH>\ngNq@@dtuURbRGSbgIZmshiK\\xICPlH<\ngNq@@dtuURbRGSbgIZmshiK\\xICPlH>\ngNq@@dtuURbRGSbgIZmshik\\xICPop<\ngNq@@dtuURbRGSbgIZmshik\\xICPop>\ngNq@@dtuURbRGSbgIZmshyK\\xI}PlH<\ngNq@@dtuURbRGSbgIZmshyK\\xI}PlH>\ngNq@@dtuURbRGSbgIjmshyK\\xICPlH>\ngNq@@dtuURbRGSbgIjnn\\DahVD<\ngNq@@dtuURbRGSbgIjnn\\DahVD>\ngNq@@dtuURbTGSbgIZmrPqRVypRFaXP<\ngNq@@dtuURbTGSbgIZmsPqRVms`dMB\x7F@<\ngNq@@dtuURbTGSbgIZmsPqRVms`dMB\x7F@>\ngNq@@dtuURbTGSbgIZmshiK\\xICPlH<\ngNq@@dtuURbTGSbgIZmshiK\\xICPlH>\ngNq@@dtuURbTGSbgIZmshik\\xICPop<\ngNq@@dtuURbTGSbgIZmshik\\xICPop>\ngNq@@dtuURbTGSbgIZmshik\\xICPowyIGD>\ngNq@@dtuURbTGSbgIZmshyK\\xI}PlH>\ngNq@@dtuURbTGSbgIZnshiK\\xICPlH<\ngNq@@dtuURbTGSbgIjmshiK\\xICPlH<\ngNq@@dtuURbTGSbgIjmshiK\\xICPlH>\ngNq@@dtuURbTGSbgIjnn\\DahVD>\ngNq@@dtuUTRGSbgIZmn\\DahWx<\ngNq@@dtuUTRGSbgIZmrXirVypRFaXP<\ngNq@@dtuUTRGSbgIZmrXirVypRFaXP>\ngNq@@dtuUTRGSbgIZmsXirVms`dMB\x7F@<\ngNq@@dtuUTRGSbgIZmsXirVms`dMB\x7F@>\ngNq@@dtuUTRGSbgIZms`qK\\xICPlH<\ngNq@@dtuUTRGSbgIZms`qK\\xICPlH>\ngNq@@dtuUTRGSbgIZms`qk\\xICPop>\ngNq@@dtuUTRGSbgIZnn\\DahVD<\ngNq@@dtuUTRGSbgIZnn\\DahVD>\ngNq@@dtuUTRGSbgQjnn\\DahVD<\ngNq@@dtuUTRGSbgQjnn\\DahVD>\ngNq@@dtuUTbGSbgIZmn\\D~hVD>\ngNq@@dtuUTbGSbgIZmrXiKVypRFaXP<\ngNq@@dtuUTbGSbgIZmrXiKVypRFaXP>\ngNq@@dtuUTbGSbgIZmrXyKVypSzaXP<\ngNq@@dtuUTbGSbgIZmrXyKVypSzaXP>\ngNq@@dtuUTbGSbgIZmsPqRVms`dMBp`<\ngNq@@dtuUTbGSbgIZmsPqRVms`dMBp`>\ngNq@@dtuUTbGSbgIZmsXirVms`guBp`<\ngNq@@dtuUTbGSbgIZmsXirVms`guBp`>\ngNq@@dtuUTbGSbgIjmn\\DahVD<\ngNq@@dtuUTbGSbgIjmn\\DahVD>\ngNq@@dtuUTbGSbgIkNn\\DahVD>\ngNq@@dwTuPGSbgIZmnUtahVD\ngNq@@dwTuPGSbgIZmobFaXP\ngNq@@dwTuPGSbgIZmshis\\kiCPlH\ngNq@@dwTuPGSbgIZmshis_DMBp`\ngNq@@dwTuPGUedmVwhvmdMBp`\ngNq@@dwTuPGUedmWWhvmdMBp`\ngNqDJDR^BSSMT`]FJmFn\\Danwl\ngNqDJHaQBSWUS@]FNRnnbEa@\ngNqDJIARBSWUUSP]FNRmsdyk]GsB<\ngNqHB@aInij`NcKMgWHvmtKB\ngNqHB@aInijihNcKMWWHvmtKB<\ngNqHB@aInijihNcKMWWHvmtKB>\ngNqHBLQInijihNkENZmshiK_KmBp`<\ngNqHBLQInijihNkENZmshiK_KmBp`>\ngNqHD@aInij`NkGIZmobFaXP\ngNqHH@aJnfjhDNfENRu[\\xICPlH>\ngNqHH@aJnfjhDNfENbu[\\xICPlH<\ngNqHH@aJnfjhDNfENbu[\\xICPlH>\ngNqHHGAJkjh@NlGI[gAH[m{@=\ngNqHHGAJkjh@NlGQkgAH[m{@=\ngNqHHGAJkjhHDNlGIkgAH[m{@+\ngNqHHGAJkjhHDNlGIkgAH[m{@-\ngNqHHGAJkjhHDNlGQ[gAOkm{@+\ngNqHHGAJkjhHDNlGQ[gAOkm{@-\ngNqHHGAJkjj`NfENRu[\\xICPlH\ngNqHHGAJkjjhDNfENSU[\\xICPlH<\ngNqHHGAJkjjhDNfENSU[\\xICPlH>\ngNqHHOAJkfh@NlGI[gAH[m{@=\ngNqHHOAJkfh@NlGI[gAH[m}@\ngNqHHOAJkfh@NlGQkgAH[m{@=\ngNqHHOAJkfh@NlGQkgAH[m}@\ngNqHHOAJkfh@NlGQkgAH[u}@=\ngNqHHOAJkfh@NlGQlvJ\\ek\\xIC^oh=\ngNqHHOAJkfhHDNlGIkgAH[m{@+\ngNqHHOAJkfhHDNlGIkgAH[m{@-\ngNqHHOAJkfhHDNlGIkgAH[m}@<\ngNqHHOAJkfhHDNlGIkgAH[m}@>\ngNqHHOAJkfhHDNlGQ[gAOkm{@+\ngNqHHOAJkfhHDNlGQ[gAOkm{@-\ngNqHHOAJkfi`NfENcU[\\xIC^lH\ngNqHHOAJkfi`NfENcU]\\xIC^lH\ngNqHHOAJkfi`NfENcU]_XIBp`\ngNqHHOAJkfj`NfENRu[\\xICPlH\ngNqHHOAJkfj`NfENcU[\\xICPlH\ngNqHHOAJkfjhDNfENSU[\\xICPlH<\ngNqHHOAJkfjhDNfENSU[\\xICPlH>\ngNqHHOAJkfjhdNfENcU]\\xICPlH<\ngNqHJIAIijjeDhNkENRmshik_XI|p`>\ngNqHaJ@SNRZZj@CkQtZypRF}_P=\ngNqIAJB\\dtuT@GVchus`dMv}`=\ngNqIAJB\\dtuT@GVchus`dMz~`=\ngNqIAJB\\dtuTDbGVcdus`dMz~`+\ngNqIAJB\\dtuTDbGVcdus`dMz~`-\ngNqIHO@ReUuT@GVChus`dMv}`=\ngNqIHO@ReUuT@GVChus`dMz~`=\ngNqLJIARFdLbdLjf@ztRmoFD\ngNqLJIARFdLbdLjf@ztRnoFD\ngNqLJIARFdLbdLji@ztRmoGt\ngNqLJIARFdLbdLjja`ztRmoFD<\ngNqLJIARFdLbdLjja`ztRmoFD>\ngNqLJIARFdLbdLjja`ztRmoGx<\ngNqLJIARFdLbdLjja`ztRmoGx>\ngNqLL@b^BBLbdLZ`dPzd[j{^p+\ngNqLL@b^BBLbdLZ`dPzd[j{^p-\ngNq`@ZdsSUPGQbgK\\zJZwVBp`\ngNq`@ZdsSUPGQbgK\\zJZwV|p`\ngNq`@ZdsSUTRGQbgK\\zJ\\wVBp`<\ngNq`@bdwSUPGQcfk[jaXP\ngNq`@bdwSUPGQcfk[j~_`\ngNq`@bdwSUPGQcfskjaXP\ngNq`@bdwSUTtGQcfk[ja_`<\ngNq`@bdwSUTtGQcfk[ja_`>\ngNq`@bdwSUTtGQcfk\\zJRwUBp`>\ngNq`@bdwSUTtGQcfkkjaXP<\ngNq`@bdwSUTtGQcfkkjaXP>\ngNq`@bdwSUTtGQcfs[ja_`<\ngNq`@bdwSUTtGQcfs[ja_`>\ngNq`@jduuURbrGQcdk\\xJZwQBp`<\ngNq`@jduuURbtGQcdk\\dJ\\uncya@>\ngNq`@jduuUTtGQcdk[haXP<\ngNq`@jduuUTtGQcdk\\yNZwQBp`<\ngNq`@mdTaeT@GTc]W[v=\ngNq`AVdtuUPGQbgI\\lLTyKVzpRD\ngNqa@bnR[ijhChqsUmuPlH\ngNqhHl@cIIKEh@NhFznwl=\ngNqhHl@cIIKEh@NhFznwt\ngNqhHlBsIIKJh@NhGNSdmu^ooyHFD\ngNqhHlGCIIKJh@NhFznwl=\ngNqhHlGCIIKJh@NhFznwt\ngNqhHlGCIIKJj`NbDmVwUBp`\ngNqhHlOCIIKFh@NhFznwl=\ngNqhHlOCIIKFh@NhFznwt\ngNqhHlOCIIKFh@NhFzoWt=\ngNqhHlOCIIKFi`NbDmVwUzp`\ngNqhHlOCIIKFi`NbDmVwcB\ngNqhHlOCIIKFi`NbDmWWUzp`\ngNqhHlOCIIKFj`NbDmVwUBp`\ngNqhHlOCIIKFjhTNbDmWWUBp`>\ngNqi@mJB]dTaeT@GTc]W[v=\ngNqi@mJB]dTaeT@GTc]W[z\ngNqiHl@c]ddebt@GTC]W[v=\ngNqiHl@c]ddebt@GTC]W[z\ngNqiHl@c]ddebt@GTC]Wkz=\ngNqiHlOC]ddecTDBGTC]W[v+\ngNqiHlOC]ddecTDBGTC]W[v-\ngNr@ACTjzjj@zpdmoio[X_v`@\ngNr@ACTjzjj@zpdnoio[X_v`@\ngNrDEcPDSpRZYjhCkQRv|X_vb@\ngNrDHlQxWpRjyjhCkARwNCDmu_LO{Q@\ngNrHEcQxIMMUTAthjnkm{\x7FZH\ngNrHHlPxIUMUTAt`rnkm}\x7FZP\ngNrHHlQxIU\\uTAtPijvzhVG}h`=\ngNrHHlQxIU\\uTAtPijwIbgI[jaX_vb@\ngNrHHlQxYIHXETAulu[\\sZwPlO{S@=\ngNrHHlQxYIHXETAulu[gIrVyfunaX_vf@\ngNrIHlQxRTjnZj@zHTu[]TKC~tP=\ngNrIHlQxRTjnZj@zHTu[_SmBp\x7FmD=\ngNrIXlPxAiJgRYRjZj@CjAnkm{\x7Fb@[R@=\ngNr`hZpiJyInfj`NeGO{R@\ngNt@@TfzBj@zvZmnQm[hVD\ngNt@@Tfzfj@zLlu[gASfyGUnaXP\ngNt@@Tfzfj@zLlu[gQSfyFuvaXP\ngNt@@TjZjj`PzXXiuUn\\EN[eApZEa@<\ngNt@@TjZjj`PzXXiuUn\\EN[eApZEa@>\ngNt@@dfnj`@zTRwqC]oX=\ngNt@@dfnj`@zTRwq}]oX=\ngNt@@dfnj`@zTSWqC]oX=\ngNt@@dfzZj@zl\\ejvyGRFaXP\ngNt@@dfzZj@zl\\ejv~HZEa@\ngNt@@dfzjj@zl\\ejv~HZEa@\ngNt@@dfzjj@zl\\ejwICEN[xahVD\ngNt@ADjzjj@zXTyKUms`dMBp\x7Fm@\ngNt@ADjzjj@zhdejv}f}tahVG}h@\ngNt@ATffjjb`zlTyJz~pREa@>\ngNtDHpxUpRjZjjQCjabgI[eApRF~@<\ngNtDHpxUpRjZjjQCjabgI[eApRF~@>\ngNtDJqHJPRZzj@CiQK_Guv}`=\ngNtHH`xIUMUTAtpqrVk[gAHZEa\x7FZP=\ngNtHH`xYIHYU@At`fobF{^p=\ngNtHHaxYIHXE@AoYm[H[m{@=\ngNtH`iPBYrSWUPRH]JIkxanwl+\ngNtH`iPBYrSWUPRH]JIkxanwl-\ngNtI@]P[ldadjj@zHlv]gASfygUvaX_v`@\ngNtI@iPSdfnj`@zTSWqC]oX=\ngNtIHaxB\\ddLj`@zPSWqC]oX=\ngNtI`]PB]qgIHYFj`NbKMVwLvmtKC~t@\ngNtI`iPBYreIkjh@NeDu|Pw[v=\ngNtI`iPBYreIkjj`NkGIZmrTyKV~HZEa@\ngNtLJqDJHtQdTaeTpGRbT\ngNtLJqHJPtadTaeT@GTc]W[v=\ngNtLJqHJPtadTaeTpGRbT\ngNtLJqHJPtadTaeTpGRbZznwl\ngNtLJqHJPtadTaeTpGRbZznwt\ngNtLlQHR`TaNLiM]UTAtXyjwNSdmuPlO{S@\ngNtLlQHR`TaNLiM]UTAtXyj{NSdmuPlO{S@\ngNtLlQHR`TaNLiM]UTAthzsdyK]Wk{~tp\ngNtLlQHR`TaNtiM]U@AuHyr\\unkm}\x7FZX\ngNtLlQHR`TaNtiM]ULAtXyj{NSdmu^lO{S@\ngNtLlQHR`TaNtiM]ULAthzsdyK]Wk{~tp\ngNtMLQHR`TaNRZzjhCiQugIrVzoWw}i`\ngNtMLQHR`TaNRZzjhCiQugIsVznww}i`\ngNt`CPdfzZj@zt\\moFD\ngNt`CPdfzZj@zt\\moGx\ngNt`EPTfzZjfPzt\\mshiK^LH<\ngNt`EPTfzZjfPzt\\mshiK^LH>\ngNt`hPiJyInfj`NcGMVwUBp\x7FdbZ[R@\ngNt`hPiJyInfj`NcGMVwUBp\x7FmH\ngNtdLx`DTHrRRqZdCiAM]W[v\ngNthJx`DYIHXmLAu`zK_DMv~`\ngNthLX`DYIHXmTAtPyjvzhVG}i`=\ngNthLX`DYIHXmTAtPyjwNSdmuPlO{S@\ngNthLX`DYIHXmTAt`znkm{\x7FZX=\ngNthMX`DYIHXmTAtPyLvzHVG}i`\ngNthMX`DYIHXmTAtPyLvzHW{}i`\ngNthMX`DYIHXmTAu`zM_DMv~\x7FmL\ngNthMX`DYIIXm@Au@wUv}`\ngNthejqHJWrSSUSRH]ZJRwaC~tP<\ngNthejqHJWrSSUSRH]ZJRwaC~tP>\ngNtiLPiPSdfnjj@zT]Yr\\enku}\x7FZX\ngNtiLPiPSdfnjjdPzT]YhTyKVzoWw}i`-\ngNu@DPdwSUPGQcfk[jaXP\ngNu@DPdwSUPGQcfk[jaX_rQMH\ngNu@DPdwSUPGQcfk\\zJ\\wUBp`\ngNu@DPdwSUTtGQcfk\\fJ\\enjEa@<\ngNu@DPdwSUTtGQcfk\\fJ\\enjEa@>\ngNu@DPdwSUTtGQcfk\\zJRwUBp`<\ngNu@DPdwSUTtGQcfk\\zJRwUBp`>\ngNu@DPdwSUTtGQcfkkjaXP<\ngNu@DPdwSUTtGQcfkkjaXP>\ngNuHDz@aIkjiiDNmGI\\dLTuoBD<\ngNuHDz@aIkjiiDNmGI\\dLTuoBD>\ngNuHDz@aIkjiiDNmGI\\zJZwaB<\ngNuHEhOCIIKFh@NhFznwl=\ngNx@@dju\\@GTc]W[v=\ngNx@@dsSUPGSbgIZmn\\DahVD\ngNx@@dsSUPGSbgIZmshis\\xICPlH\ngNx@@dsSUPGSbgQZmn\\DahVD\ngNx@@dsSUPGUddmVwhwmdMBp`\ngNx@@dsSUPGUddmVwhwndMBp`\ngNx@@dsUUTbGSbgIZmn\\DahVD<\ngNx@@dsUUTbGSbgIZmn\\DahVD>\ngNx@@dsUUTbGSbgIZmrPqSfypRFaXP<\ngNx@@dsUUTbGSbgIZmsPqSdms`dMBp`<\ngNx@@dsUUTbGSbgIZmsPqSdmsoDMBp`<\ngNx@@dsUUTbGSbgIZmsPqSdmsoDMBp`>\ngNx@@dsUUTbGSbgIZms`qs\\xICPlH<\ngNx@@dsUUTbGSbgIZms`qs\\xICPlH>\ngNx@@dsUUTbGSbgIZmshis\\xICPlH>\ngNx@@dsUUTbGSbgQZmn\\DahVD<\ngNx@@dsUUTbGSbgQZmn\\DahVD>\ngNx@@dsUUTbGSbgQZmsPqSdms`dMBp`<\ngNx@@dsUUTbGSbgQZms`qs\\xICPlH<\ngNx@@dsUUTbGSbgQZms`qs\\xICPlH>\ngNx@@dtuT@GVcdms`dMv}`=\ngNx@@dtuT@GVcdms`dMv~`\ngNx@@dtuT@GVcdn\\FM[gAH[m}@\ngNx@@dtuT@GVchus`dMv}`=\ngNx@@dtuT@GVchus`dMv~`\ngNx@@dtuT@GVchvSENZwNBPw[z\ngNx@@dtuTDbGVcdms`guv}`+\ngNx@@dtuTDbGVcdms`guv}`-\ngNx@@dtuTDbGVcdn]EM[gAH[m}@<\ngNx@@dtuTDbGVcdn]EM[gAH[m}@>\ngNx@@dtuTDbGVcdus`dMv}`+\ngNx@@dtuTDbGVcdus`dMv}`-\ngNx@@dtuTDbGVchv]EM[gAH[m}@<\ngNx@@dtuTDbGVchv]EM[gAH[m}@>\ngNx@@dtuTpGSbgIZms`qK\\xIC^lH\ngNx@@dtuTtbGQbkIkgAH[m}@>\ngNx@@dtuUPGSbgIZmn\\DahVD\ngNx@@dtuUPGSbgIZmrpqSdm[gAHZEa@\ngNx@@dtuURbRGSbgIZmshiK\\xICPlH>\ngNx@@dtuURbTGSbgIZmshiK\\xICPlH>\ngNx@@dtuUTRGSbgIZms`qK\\xICPlH<\ngNx@@dtuUTRGSbgIZnn\\DahVD<\ngNx@@dtuUTRGSbgIZnn\\DahVD>\ngNx@@dtuUTbGSbgIZmrXiKVypRFaXP<\ngNx@@dtuUTbGSbgIZmrXiKVypRFaXP>\ngNx@@dtuUTbGSbgIZmsPqRVms`dMBp`<\ngNx@@dtuUTbGSbgIZmsPqRVms`dMBp`>\ngNx@@dtuUTbGSbgIjmn\\DahVD<\ngNx@@dtuUTbGSbgIjmn\\DahVD>\ngNx@@dwPUPGQrVk[t[VrFaXP\ngNx@@dwPUPGQrVk\\zJ\\whvndMBp`\ngNx@@dwPUPGQrVkkt[VrFaXP\ngNx@@dwTuPGSbgIZmobFaXP\ngNx@@dwTuPGSbgIZmshis\\kiCPlH\ngNx@@dwTuPGUedmVwhvmdMBp`\ngNx@@dwTuPGUedmVwhvndMBp`\ngNx@@dwTuPGUedmVwhzmdMBp`\ngNx@@dwTuPGUedmVypTyoQu]HZEa@\ngNx@@dwTuPGUedmVytTyoQm]HZEa@\ngNx@@dwTuPGUedmWWhvmdMBp`\ngNx@@dwTuPGUedmWWhvndMBp`\ngNx@@dwTuPGUedmgWhvmdMBp`\ngNx@@dwTuPGUedmgWhvndMBp`\ngNx@@dwTuPGUedugWhvmdMBp`\ngNx@@eSUUPGUEDmVwjwmdMBp\x7Fm@=\ngNx@@eSUUPGUEDmVwjwndMBp\x7Fm@\ngNx@@eSUUPGUEDmVwj{ndMBp\x7Fm@=\ngNx@@eSUUPGWCENRu[^hNBPtKB\ngNx@@eSUUPGWCENRu[^hNBPtKC~t@=\ngNx@@eSUUPGWCENRu[^hN|PtKC~t@\ngNx@@eSUUPGWCENRu[gASf}P]xahVG}h@\ngNx@@eSUUPGWCENRu[gAcf}P\\DahVG}h@\ngNx@@eSUUPGWCENRu]gAcV}P\\DahVG}h@\ngNx@@eSUUPGWCENbu[^hNBPtKC~t@\ngNx@@eSUUPGWCENcV]^hNBPtKC~t@\ngNx@@eSUUTBGWCENRu[gASf}P]xahVD<\ngNx@@eSUUTBGWCENRu[gASf}P]xahVD>\ngNx@@eSUUTBGWCENRu[gAcf}P\\DahVD<\ngNxA@IRZZj@CkQrVypRF{^p=\ngNxA@IRZZj@CkQtZypRF{^p=\ngNxA@IRijjhCkabgIZmoTGAHZEa@\ngNxA@IRijjjACkabgIZms`is^hN|PtKB<\ngNxA@IRijjjACkabgIZms`is^hN|PtKB>\ngNxA@IRjZj@ChaSdmz`xIC]oX=\ngNxA@IRjZjhCkabgIZmoTGAHZEa@\ngNxA@IRkijhCjbRVk[v[vrFaX_v`@\ngNxA@IRkijhCjbRVk[v]vrFaX_v`@\ngNxA@IRkijhCkabgIZmshis\\{qCPlO{P@\ngNxA@IRkijhCkabgQZmrPqrV}g\\DahVG}h@\ngNxDD@b^BSWMPRH]JIkxanwl+\ngNxDD@b^BSWMPRH]JIkxanwl-\ngNxDDDR^BSWMPRH]JIkxanwl+\ngNxDDDR^BSWMPRH]JIkxanwl-\ngNxDHDQHbS]UU@]VNRu[_DMBp`\ngNxDHGBnBUSUURH]LLTyJz}P\\DaofD<\ngNxDHGBnBUSUURH]LLTyJz}P\\DaofD>\ngNxDHOANBS]UU@]VNRu[^cr|PtKC~RAamH\ngNxDHOA^BS]UU@]VNRu[\\cqCPlOyHFFt`\ngNxDHOA^BS]UU@]VNRu[^cr|PtKC~RAamH=\ngNxDHOA^BS]UU@]VNRu[_DMBp`\ngNxDHOA^BS]UU@]VNRu[_DMBp\x7Fd`XP\ngNxDHOA^BS]UU@]VNRu[_DMBp\x7Fd`X[R@=\ngNxDL@aNBSMTu@]VRRu[^c^vPtKB\ngNxE@jCT@eJfjj`NjFIZmobFaXP\ngNxEHBqE`eInjjiDNkGIZmnUxahVG|dCB<\ngNxEHBqE`eInjjiDNkGIZmnUxahVG|dCB>\ngNxEHOA^DeInfj`NkGIZmnQtahVG|dCCZP\ngNxEHOA^DeInfj`NkGIZmnUxahVG|dCCZP\ngNxHAjAJfjj`NfFJRu[\\hICPlO{P@\ngNxHAjAJfjjhDNfFJRu[\\hICPlH>\ngNxHAjAJfjjhDNfFJRu[gAcfyWbFaXP<\ngNxHAjAJfjjhDNfFJRu[gAcfyWbFaXP>\ngNxHD@aIkjhIDNeDm|Pw[v-\ngNxHD@aInfj`NkGIZmobFaXP\ngNxHD@aInij`NkKIZmoQm[HZEa@\ngNxHDOAInjjiDNkGIZmnQxahVD>\ngNxHH@aIfjj`NgENRu[gQSf}GlDahVG}i@\ngNxHHGAIfjj`NgENRu[\\xICPlOyHEFt`\ngNxHHGAIfjj`NgENRu[^cvBPtKC~RAQmH\ngNxHHGAIfjj`NgENRu[^cvBPtKC~t`\ngNxHHGAIfjjiDNgENRu[^cvBPtKB<\ngNxHHGAIfjjiDNgENRu[^cvBPtKB>\ngNxHHGAJijj`NnFJ\\ejv}P\\DahVG}i@=\ngNxHHGAJkjh@NlGQkgAH[m{@=\ngNxHHGAJkjj`NfENRu[\\xICPlH\ngNxHHOAJkfh@NlGQkgAH[m{@=\ngNxHHOAJkfh@NlGQkgAH[m}@\ngNxHHOAJkfhHDNlGIkgAH[m{@+\ngNxHHOAJkfhHDNlGIkgAH[m{@-\ngNxHHOAJkfhHDNlGIkv]pRF}_P+\ngNxHHOAJkfhHDNlGIkv]pRF}_P-\ngNxHHOAJkfj`NfENRu[\\xICPlH\ngNxHHOAJnjjhDNfENRu[\\{qCPlH<\ngNxHHOAJnjjhDNfENRu[\\{qCPlH>\ngNxHJIAIiji`NcEVRwN|_W[v\ngNxHaJ@SNRZZj@CkQrVypRF{^p=\ngNxHaJ@SNRZZj@CkQtZypRF{^p=\ngNxHaJ@SNRZZj@CkQtZypRF}_P=\ngNxHaJ@SNRZZj@CkQt[MbgIZwNBPwkz=\ngNxHaJ@SNRZZj@CkQt[NCFms`dMv~`\ngNxHaJ@SNRZZjBQCkQrZypRF{^p+\ngNxHaJ@SNRZZjBQCkQrZypRF{^p-\ngNxHaJ@SNRZZjBQCkQrZypRF}_P+\ngNxHaJ@SNRZZjBQCkQrZypRF}_P-\ngNxHaJ@SNRZZjBQCkQt[Nbfms`dMv~`<\ngNxHaJ@SNRZZjBQCkQt[Nbfms`dMv~`>\ngNxHaJ@SNRZZjjQCiqSdmVyLTek\\xICPlH<\ngNxHaJ@SNRZZjjQCiqSdmVyLTek\\xICPlH>\ngNxHaj@SnrRFPJhChyKUu{MkYCPlO{P@=\ngNxHaj@SnrRFPJhChyKYu{MkYCPlO{P@=\ngNxHaj@SnrRFPJhChyKYv]EN[v[WRFaX_v`@\ngNxHaj@SnrRFPJhChyMYu{MkYCPlO{P@=\ngNxHaj@SnrRFPJhChyMYu{MkiCPlO{P@\ngNxHhG@]IR[jZhCiqSdmVwJzPtKC~RAamH\ngNxIAJB\\dtuT@GVchus`dMv}`=\ngNxIAJB\\dtuT@GVchus`dMz~`=\ngNxIAJB\\dtuTDbGVcdus`dMz~`+\ngNxIAJB\\dtuTDbGVcdus`dMz~`-\ngNxIAjC\\dwTuPGUedugWhzmdMBp`\ngNxIHGBRdwTuPGSbgIZmoQy]HZEa\x7FI@pvd@\ngNxIHO@ReUuT@GVChus`dMv}`=\ngNxIHO@ReUuTDBGVCdus`dMv}`+\ngNxIHO@ReUuTDBGVCdus`dMv}`-\ngNxIHOBReUsT@GVChus`dMv}`=\ngNxIHOB\\eUsT@GVChu{NxIC]oX=\ngNxLHGBnC\\Djfjj@zhXirV}P\\Daogx\ngNxLHGBnC\\Djnjj@zHTyK\\xIC_Op\ngNxLHGBnChDjfjjdPzhXirVyP\\Dao`<\ngNxLHGBnChDjfjjdPzhXirVyP\\Dao`>\ngNxLHOANF\\DfZjjdPzlTejvywbFaXP<\ngNxLHOANF\\DfZjjdPzlTejvywbFaXP>\ngNxLJHaQFbLbdLj`@zd[j{^p\ngNxLJIARFdLbdLj`@zd[j{^p\ngNxLJIARFdLbdLj`@zd[j{_P\ngNxLJIARFdLbdLjf@zTSWUv}`\ngNxLJIARFdLbdLjf@zTSWUv~`\ngNxLJIARFdLbdLjf@ztRmoFD\ngNxLJIARFdLbdLjf@ztRnoFD\ngNxLJIARFdLbdLji@zTSWUv}`\ngNxLJIARFdLbdLji@zTSWUv~`\ngNxLJIARFdLbdLji@zTSWUz~`\ngNxLJIARFdLbdLji@ztRm@\ngNxLJIARFdLbdLji@ztRmoGt\ngNxLJIARFdLbdLjja`ztRmoFD<\ngNxLJIARFdLbdLjja`ztRmoFD>\ngNxMHOANF\\IJSMMU@]VJRu[\\{qCPlO{R@\ngNx`BDdwSUPGQcfk[jaXP\ngNx`BDdwSUPGQcfk[jaX_rQMH\ngNx`BDdwSUPGQcfk\\zJ\\wUBp`\ngNx`BDdwSUPGQcfskjaXP\ngNx`BDdwSUTtGQcfk[ja_`<\ngNx`BDdwSUTtGQcfk[ja_`>\ngNx`BDdwSUTtGQcfk\\zJRwUBp`<\ngNx`BDdwSUTtGQcfk\\zJRwUBp`>\ngNx`BDdwSUTtGQcfkkjaXP<\ngNx`BDdwSUTtGQcfkkjaXP>\ngNx`DBdwSUPGQcfk[jaXP\ngNx`DBdwSUPGQcfk\\zJ\\wUBp`\ngNx`DBdwSUTtGQcfk[ja_`<\ngNx`DBdwSUTtGQcfk\\zJRwUBp`>\ngNx`bDnLiMtuTAtXyjvzhVD\ngNx`hEIWIMtuTAuXyKUm|PtKC~t`\ngNx`hEIWIMtuTAuXyKUm|PtK}~t`\ngNx`hEIWIMtuTAuXyKUu|PtKC~t`\ngNxaBDYR[ijhChqsUmuPlH\ngNxdMD@baFRRFKU@]DNSMobF~X_vf@\ngNxdMD@baFRRFKU@]DNSNobF~X_vf@\ngNxdMD@baFRRVKT`]HIkj{^p\ngNxhKD@cIICEh@NdDm|Pw[v\ngNxhMD@cIICEj`NjGIZmobFaX_vf@=\ngNxhMD@cIICEj`NjGIZmoczaX_vf@=\ngNxhMD@cIICEj`NjGIZnobFaX_vf@\ngNxhMD@cIICEj`NjGIZnsdyk_DMBp\x7FmL\ngNxhMD@cIICEj`NjGIjmobFaX_rQMMi`=\ngNxhMD@cIICEj`NjGIjmobFaX_vf@=\ngNxhMD@cIICEj`NjGIjmobFa_ovf@\ngNxhMD@cIICEj`NjGIjmsdyK_DMBp\x7FmL\ngNxhMD@cIICEj`NjGIjnobFaX_vf@\ngNxhMD@cIICEj`NjGIjnsdyk_DMBp\x7FmL\ngNxhMD@cIICEj`NjGIkMobFa_ovf@\ngNxhMD@cIICEj`NlGQ[xaoWw}i`=\ngNxhMD@cIICEj`NlGQkxanwo}i`=\ngNxhMD@cIICEj`NlGQkxanww}i`\ngNxhMD@cIICEj`NlGQkxaoWw}i`=\ngNxhMD@cIIKEh@NhFznwl=\ngNxhMD@cIIKEh@NhFznwt\ngNxhMD@cIIKEh@NhFzoWt=\ngNxhMD@cIIKEh@NhGNSfmu]oh\ngNxhMD@cIIKEi`NbDmVyr\\enkua@\ngNxhMD@cIIKEi`NdDv\\gI[j}^p\ngNxhlEJB]iRZzj@CiQM_DMv}\x7FmL=\ngNxhlEJB]irJPrj@CjQnkm{@=\ngNxhlEJB]irJPrj@CjQomz{^p=\ngNxhlEJB]irJPrj@CjQsdyk]W[z\ngNxiMD@c]ddebt@GTC]W[v=\ngNy@BDfZZj@zlTyjv~pZEa@\ngNy@BDfZZjb`zlTyjwNbdm}`tKB>\ngNy@BDfZZjb`zlTzjwNbdm}`tKB>\ngNy@BDfZjjTR`zlTzjwNCDm}`tKB>\ngNy@BDfZjjdPzlTyjv~pZEa@>\ngNy@BDfZjjdPzlTyl{NbgM}`tKB<\ngNy@DDffjjdPz\\TyKUn]EI[gAHZEa\x7FZH<\ngNy@DDffjjdPz\\TyKUn]EI[gAHZEa\x7FZH>\ngNy@DDfnj`dPzTRwqC]oX+\ngNy@DDfnj`dPzTRwqC]oX-\ngNy@DDfnj`dPzTRwq}]oX-\ngNy@DDfnj`dPzTRytTuobF{_P>\ngNy@DDfnj`dPzTSWqC]oX+\ngNy@DDfnj`dPzTSWqC]oX-\ngNy@DDfzZj@zl\\ejv~HZEa@\ngNy@DDfzZj@zl\\ejv~HZE~@\ngNy@DDfzZj@zl\\ejwNbfm|PtK|\ngNy@DDfzZj@zl\\ejwNbgM|PtKB\ngNy@DDfzZj@zl\\ejz~HZEa@\ngNy@DDfzZj@zl\\ej{Nbfm|PtKB\ngNy@DDfzZj@zl\\elz~HZEa@\ngNy@DDfzZj@zl\\flz~HZEa@\ngNy@DDfzZjfPzl\\ej{NbgM|PtKB<\ngNy@DDfzZjfPzl\\ej{NbgM|PtKB>\ngNy@DDfzfj@zl\\ejv~HZEa@\ngNy@DDfzfj@zllejv}FulahVD\ngNy@DDfzjjdPzl\\ejv~HZEa@<\ngNy@HDfZjjdPz\\TyKUms`dMBp`<\ngNy@HDfZjjdPz\\TyKUms`dMBp`>\ngNy@HDfZjjdPz\\TyKUn]EN[g^HZEa@<\ngNy@HDfZjjdPz\\TyKUn]EN[g^HZEa@>\ngNy@HDfZjjdPz\\TzKUms`dMBp`<\ngNy@HDfZjjdPz\\TzKUms`dMBp`>\ngNy@JDffj`@zt\\en\\Danwl\ngNy@JDffj`@zt]Fn\\Danwl\ngNy@JDffji@zLUYK\\xIC]oX\ngNy@JDffjjTRPzlTyJwNbfm}`dKB<\ngNy@JDffjjTR`zlTyJwIcdm[{AOfD<\ngNy@JDffjjTR`zlTyJwNbfm}`dK|<\ngNy@JDffjjb`zlTyJv~pREa@<\ngNy@JDffjjb`zlTyJv~pREa@>\ngNy@JDffjjb`zlTzLv~pREa@<\ngNy@JDffjjb`zlTzLv~pREa@>\ngNy@hAteInij`NgENRu[_DMBp\x7FmH\ngNyAHIJSMMU@]NJ\\ejwNbgMsoDMBp\x7FmH\ngNyDGQDJHRZzjXCkQrWNSfmxP`\ngNyDGQHJPRZzjXCkQrV|HP\ngNyDGQHJPRZzjXCkQrV|O`\ngNyHE@DYICHuU@auPyKUm|PtKB<\ngNyHE@DYICHuU@auPyKUm|PtKB>\ngNyHE@DYIHXmA@at`eobF{^p+\ngNyHE@DYIHXmA@at`eobF{^p-\ngNyHEAxIU\\uTAtPjrVywcz{__vb@\ngNyHEAxIU\\uTAtpitZk[gAHZEa\x7FZH=\ngNyHEAxYIHXuA@at`fobF{^p+\ngNyHEAxYIHXuA@at`fobF{^p-\ngNyHKAxIU\\u@Au`zM\\xIC]oX\ngNyHdIPSeJSSUP@]ZNcYpXun\\Danww}h`\ngNyHdIPSeJSSUS@]FJmFs`qK\\xIC^oo{Q@\ngNyHdIPSeJSWUPRH]JIkxanwl+\ngNyHdIPSeJSWUPRH]JIkxanwl-\ngNyHdIPSeJSWUPRH]JIkxanwt<\ngNyHdIPSeJSWUPRH]JIkxaoWt+\ngNyHdIPSeJSWUPRH]JIkxaoWt-\ngNyHdIPSeJSWUPRH]JIlyNZwqC]oh<\ngNyHdIPSeJSWUPRH]JIlyNZwqC]oh>\ngNyIDIPSdffjj@z\\TzMUv\\FI[gAHZEa\x7FZH\ngNyIDIPSdfnj`dPzTSWqC^oh+\ngNyIDIPSdfnj`dPzTSWqC^oh-\ngNyIDMP[dfzfj@zl\\ej{IbgI[e]HZEa@\ngNyLGQDJHtQdTaeTpGRbT\ngNyLGQDJHtQdTaeUHGRbT\ngNyLGQHJPtadTaeTpGRbT\ngNyLGQHJPtadTaeUHGRbT\ngNyLGQbKDvIdTaeTpGRbT\ngNyLcaHR`TaNLyEHYU@AuHyr\\enku}\x7FZD\ngNyLcaHR`TaNLyEHYU@AuHyr\\unkm}\x7FZD\ngNyLcaHR`TaNLyEHYULAtXejwNSdmxp\x7FmB\ngNyLcaHR`TaNLyEHYULAtXej{NSdmxp\x7FmB\ngNyLcaHR`TaNLyEHYULAthfsdyK]Wk{~tH\ngNy`JDTfzZjfPzt\\moFD>\ngNydMDpDTHrRPqZhCkAr[NSdmtPww{S@\ngNyhCE`DYIIXmTAtPejwNSdmuPlO{P`\ngNyhCEaxYIIXuTAtPejvzhVG}hP=\ngNyhKEaxYIIXuUBau`e[^LH>\ngNyhKEaxYIIXuUBau`e[^Op>\ngNyhKEaxYIIXuUBau`e]^LH<\ngNyhKEaxYIIXuUBau`e]^LH>\ngNyhMEPDYIHXmTAtPyLvzHVG}i`\ngNyhbEiPScNQRFUS@]FIZms`yK^LO{P`\ngNzHHlZGAJijj`NdFUu]oo{R@\ngN|@@ZeSUUPGVEEu|n{kC~t@=\ngN|@@bdwSUPGQefk[d[WZEa@\ngN|@@bdwSUPGQefk\\zJ\\wHvntKB\ngN|@@mdTaeT@GTc]W[z\ngN|DEbHb^FQRFPU@]XmVwJwmtKC~tH=\ngN|LlZIBTBdIqeIkjj`NmGKlyNRwcC~tp\ngN|LlZIBTBdIveIkjjPNmGK\\yNR\x7FmL\ngN|`hZEIWIMtuTAuhy[^LO{R@\ngN|`hZEIWIMtuTAuhy]^LO{R@\ngN}HEcAxIU\\uTAtPijvzhVG}h`=\ngN}HEcAxYIIYATAubu[gArVyV}naX_va@\ngN}HebIPSeJSSUS@]FJZmsXirVmu^lO{Q@\ngN}HebIPSmJSSUURH]FJZmsXirVmuPlO{Q@+\ngN}HebIPSmJSSUURH]FJZmsXirVmuPlO{Q@-\ngN}HebIPSmJSSUURH]JJlvJ\\ek]Wk{~tP+\ngN}HebIPSmJSSUURH]JJlvJ\\ek]Wk{~tP-\ngOp@DjfVjjdEDNnFJ\\ejwMBgIZwjCoDMB\x7F_die`<\ngOp@DjfVjjdEDNnFJ\\ejwMBgIZwjCoDMB\x7F_die`>\ngOp@DjfVjjdEHNnFJ\\ejwMBgIZwjCoDMB\x7F_die`>\ngOp@DjfVjjdEHNnFJ\\ejwMCGIZwj}oDMB\x7F_die`<\ngOp@DjzfZj`NnFJ\\ejv}g\\DahVG|dLl\ngOp@LdadMBj`NcdmVwlvmdMBp\x7Fdmc`=\ngOp@LdadMBj`NcdmVwlvmdMB\x7F_dmc`=\ngOp@LdadMBj`NcdmVytTuoYm]HZEa\x7FI[G@\ngOp@LdadMBj`NcdmWWlvmdMBp\x7Fdmc`=\ngOp@LdadMBjidNcdmVwlvmdM|p\x7Fdmc`+\ngOp@LdadMBjidNcdmVwlvmdM|p\x7Fdmc`-\ngOp@LdadMBjidNcdmWWlvmdM|p\x7Fdmc`+\ngOp@LdadMBjidNcdmWWlvmdM|p\x7Fdmc`-\ngOpB@xQpSagCIIKHjhHCjAoYy^wku}\x7FKCSH`=\ngOpBADQpSagCHiCEjhHCjQnU{^oWw|eLl=\ngOpL@xQpSaddadUTDAt`foYy^H[u}\x7FICS@=\ngOpMAxZ`M@IRj[Fjj@zhXijv}P]x~hVG|dml\ngOp`@dfzMZj`NkGIZmobFaX_rVqp\ngOp`@dfzMZj`NkGIZnobFaX_rVqp\ngOp`@dfzMZjidNkGIZmobF~X_rVqp<\ngOp`@dfzMZjidNkGIZmobF~X_rVqp>\ngOp`@dfzMZjidNkGIZnobF~X_rVqp<\ngOp`@dfzMZjidNkGIZnobF~X_rVqp>\ngOphH`DYIHYVmU@]TNSU[_DMBp\x7Fdck`\ngOq@@dsQkUTAtxitVk[gAHZEa\x7FI[G@\ngOq@@eMtUTEIAuhiK\\hIC]o_yHYx+\ngOq@@eMtUUUIAtxirVk[eAHZEa\x7FICO@<\ngOq`@bdwQkUUMAtXyjvzhVG|el\\<\ngOt@@TjZkjj`NfFJ]U[gAcfyP\\FaX_rQuuh@\ngOu@DPdwU[UTAtXyjvzhVG|d]\\\ngOx@@eSQmUTAupqSdmVwjC`dMBp\x7FdmckP@=\ngOx`hEIWIMtZuU@]VNRu[_DMBp\x7FdmckR@\ngOxhMD@cIICJujhCjarZk[xahVG|d]]ZX=\ngOxhMD@cIICJujjYCjarZk[xahW{|d]]ZX\ngOy@DDfzMZj`NkGIZmobFaX_rVqp\ngOy@DDfzMZj`NkGIZnobFaX_rVqp',Klb),m);d=(b&1)==0?null:(n=Zkb.n5('26,60,96,180\n42,68,91,94\n147,176\n170,261\n210,231,244,267\n59,180\n26,30,38,55,81,96,118,180\n0,54,58,90\n0,55,90\n0,59,68,73\n0,57,77,180\n0,40,90\n0,31,35,46,68\n24,29,55,90\n1,47,51,56,70,75,78,85,88,90\n12,33,67\n0,38\n3,180\n0,44,61,87,90\n27\n0,14,29,35,61,78\n11,28,33,45,55,57\n57,61,63,90,145,148,180\n180\n0,40,47,51,72,179\n0,58\n0,52\n39,60,76,180\n51\n54,59,305\n47,50,66,311\n0,4,62\n63,84,125,163,180\n2,18,56\n60,94,178,180\n52,92,149,178\n42,82,160\n42,79,161\n67,180\n56,166,180\n51\n51\n61,174,180\n42\n0,2,28,174,180\n46,76,163\n60,88,180,208,306\n61,76,304\n0,7,10,13,60,82\n0,60\n3,37,57,60,97,129,180\n0,10,28,136,165,180\n59,61,63,71,169,180\n44,76,165\n44,75,165\n26,47,62,64,68,71,167,186,274,280,301\n27,43,49,55,68,74,145,169,184,190,283,297,301\n24,39,45,58,74,146,184,202,276,302\n47,52,149,162,179,285,287,308\n46,69,180\n40,43,77,158,180\n42,78,80,169\n42,44,49,62,68,156,178,180\n42,47,55,59,81,84,161,178,180\n170\n0,29,57\n180\n2,11,15,44,76,87,90\n0,24,43,76,90\n3\n0,10,18,21,37,44,64\n59,180\n50,72,175,180\n57,180\n58,180\n58,90,150,159,164,168,176,180\n0,3,30,60,64,75,94,123,154,180\n59\n46,52,72,168,172,180\n43,75,164,180\n50,72,172,195,284,315\n45,173,177,180,199,291,315\n170\n16,47,74,166\n53,100,159,180\n43,71,74,111,122,125,180\n31,49,64\n132,171\n32,58,334\n29,58,337,339\n56,180\n54,67,177\n58,160,180\n180\n41,80,173,180\n48,63,84,118,179\n3,41,73,147,166,179\n41,60,72,161,176,180\n48,51,53,78,157,194,282,316\n32,50,81,155,161,166,192,206,280,286,315,325,328\n59,180\n50,60,66,82,158,180\n61,179\n60,180\n48,74,168\n50,85,159,199,220,297,315,351\n61,71,77,83,90,173,193,284,300\n308\n308\n68,192,305\n59,169,174,180\n53\n62\n0,3,9,23,26,28,49\n52,60,62,180\n33,55,180\n35,56\n28,34,53,311\n185,288,290\n0,9,34,37,57,75,77,90,95,102,125,139,142,162,180\n17,62,77,170\n48,76,167,180\n54,58,65,180\n63,80,82,180\n45,48,72,167,179\n59,180\n56,70,74\n18,67,106\n56,180\n56,180\n50,180\n180\n65,186,299\n175\n52,189,191,221,287\n56,175\n62,177\n65,175\n51,72,90,138,181\n188,214,294\n192,226,296\n201,224,275,289\n48,68,77,174,180\n71,299\n44,52,57,59,61,75,298,321\n60,180\n41,73,88,164,180\n59,180\n47,57,60,63,165,167,171,181,287,311\n51,77,80,161,188,204,279,303\n303\n59,180\n61,180\n48,75,167,171,180\n65,183,290,305\n66,178,303\n54,70,178,191,303\n66,181,304\n62,178,194,304\n64,182,309\n53,294\n61,180\n60,180\n60,160,180\n41,45,54,68,93,159,180\n44\n39,55,162,180\n0,35\n0,10,64,92,141,180\n0,6,34\n8,46\n0,22,27,29,42,45,69,90\n0,31,180\n0,29,49,72,98,142,170,179\n42,71,163\n55,172,180\n56,179,295\n60,180\n60,180\n60,180\n43,64,175,191,289,296,303\n45,67,168,176,185,287\n59,178,303\n62,180,301\n53,60,68,70,108,165,289,295,302,305,328\n44,48,51,55,59,64,67,71,75,108,289,294,297,304,308,321\n0,5,41,106\n163,180\n0,15,17,70\n0,20,35,123,180\n61,180\n0,180\n0,20,53,55,75,84\n23,41,60,84,106,138,157\n17,34,53,82,90\n0,10,20,36,46,50,62,66,90\n0,59,61,107,123,180\n13,17,19,33,36,90\n1,31,36,56,58,70,77,90\n0,12,19,27,40,45,48,57,60,68,70,84,109,118,124,128,131,137,157,160,180\n7,54,67,85,90\n2,34,61,65,92,95,106,130,139,144,151,159,173,177\n2,25,28,65,87,109,180\n0,9,66,77,111,114,117,158\n13,34,72,90\n48,63,70,77,90,105,120,134,161,164,179\n0,14,30,54\n17,39,52,57,63,85,151,172,180\n30,51,53,59,69,71,114,136\n2,28,44,66,94,110,113,139,178\n14,34,65,79,136,211,235\n15\n28,35,45,179\n0,60,78\n12,26,40,83,86,105,126,129,137,155,180\n40,110,129,149,180\n24,57,69,180\n180\n62,180\n180\n0,32\n0,31\n0,25,30\n68,180\n66,82,180\n59,83,90,93,104,107,113,120,164,166,180\n55\n56\n0,56\n66,180\n47,77\n45,71,73,148,180\n48\n0,10,58,66,180\n0,7,56\n15,112,130,156,180\n118,147\n0,59,120,180\n123\n13,46,65\n15,44,66\n14,41,62\n17,46,63,65\n93,128,132,159\n0,93,123,149,153,168\n0,4,9,15,17,24,32,45,68\n1,44\n80,86,98\n76\n94,100,111,128,180\n89\n60,77,80,86\n0,14,84,106\n86\n63,164,173,177,180\n61,77,80,157,171\n62,180\n0,14,68\n64,70,81,147,168,180\n59,61,109\n51,53,77,124,179\n180\n60,63,71,92,180\n47,72,114\n87,103,180\n85,109,150,180\n54,73,148,167\n114,180\n43,60,80\n0,50,84\n66,180\n67,180\n60,180\n163,180\n133,140,142,145,147,162,165,169,180\n15,114\n68,88,180\n65,180\n97,180\n62,97\n65\n62\n79,176,180\n65,180\n122,163,179\n0,62,128,171\n0,36\n1,39\n137,152,180\n0,26,56\n70,180\n90,114,153,170,180\n78,97,116,129,142,154,180\n0,56\n45,61,76,96\n59,94\n66,180\n180\n46,63,66,69,79,83\n73,75,122,180\n85,91,157,162,175,180\n53,75,78\n74,126,180\n178,180\n68,180\n71,136,154,163,173,175\n68,111,119,175,179\n0,12,57,76\n3,58,62,163,180\n62,65,67,79,85,163,180\n45,48,72,146,169,180\n106,121,123\n69,78,180\n180\n180\n16,54,77\n74,164,167,179\n65,180\n66,180\n65,180\n180\n55,67,74,180\n48,66,87\n180\n180\n68,180\n69,96,99,115\n180\n72\n73,180\n72,91\n72,94\n86\n89\n78,106,180\n82,91,100,180\n0,28,31,39\n0\n100,113,116,163,180\n117,137,148,158,180\n0,76,78,108\n0,6,69,105\n0,46,71,73,76,117\n68,180\n59\n69\n73,92,111,155,161,168\n0,28,49,64,88\n75,92,180\n46\n136\n180\n180\n0,9,121,162\n0,33,82,124\n51,72,78,94,98,115,147,177,180\n11,21,32,58\n14,41,65\n64,180\n61,75,78,180\n57\n56\n0,67,180\n49\n152,154,179\n0,151,180\n34,55,58,66,75,79,82,104,131,164\n0\n0\n160,180\n0\n0\n84,180\n117,134,137,139,180\n125,134,179\n110,116,119,179\n59\n16,58,85\n58,93\n0,57\n77,180\n131,168,180\n22,50,72,86\n48\n77,180\n77,125,141,144,180\n2,47,87\n27,30,51,77\n76,180\n18,55,83\n169,172,180\n62,94\n30,77\n29\n62,156,176\n97,123,180\n144,151,153,156,164,180\n68,96\n47,78,129,148,153,175,178\n119,121,145,148,154,180\n29,36,51,53\n90,110,162,179\n104,107,129,133,179\n104,127,147,159,161,174,180\n88,111,144,166\n57,82,105\n0,55,93\n0,56\n121,156,180\n36,56,80\n68,180\n68\n67,180\n51,179\n39,66,180\n16,25,66,153,180\n67,160\n106,167,171,180\n85,91,105,111,125,132,139,142,178\n59,92\n61\n0,180\n0,26\n0,180\n0,45\n132,138,180\n130,180\n0,33,60\n180\n180\n180\n0,38\n0,27\n180\n180\n79,90,105,135,180\n77,111,145\n77,91,96,120,142,146,150\n77,101,111,121,140,180\n72,180\n180\n65,180\n0,57\n76,88,91,126,166\n32,38\n80\n40\n78,96,98,128,135,147,179\n78,93,112,154,158,172,178,180\n73,180\n8,57\n15,57\n1\n180\n63,180\n67,73,81,84,119,122,166\n0,57\n0,58\n92,180\n112,178\n165,180\n64\n0,180\n180\n0,98,117,129,138,145\n0,125\n12,80,83,116,125,142,146,157,167,170,173,180\n0,12,52,66\n12,32,69\n155,158,180\n64,180\n26,61,76,84,180\n15,56\n0,55,76\n0,54\n63,180\n49,76\n0,38\n0\n180\n180\n180\n0\n0\n180\n180\n70,180\n85,131,180\n95,152,180\n79,81,105,180\n84,106,180\n57\n0,26,52,66\n55\n19,30,73,88\n56\n65,68,180\n85,90,94,96,122,131,176\n171\n45,47\n54,72,82,148,152,180\n81,116,120,180\n81,84,87,104,113,124,129,134,149,167,178\n0,23,42\n29,46,80\n69,139,175\n80,128,142,146,180\n91,123,137,146,154,180\n123,178\n134,180\n21,37,72\n100,109,136,150,179\n6,8,12,14,27,40,119,153,156,180\n0,54,70\n180\n0,121\n180\n65,180\n136,169,171\n0,9,16,56\n1,55,83\n56\n63,180\n54\n63,180\n149,180\n152,180\n56\n62,180\n73,81,170\n47\n180\n89,109,125,127,153,160,180\n106,123,141,151\n0,27,31,69\n56,69,72,93,102,108,117,126,179\n180\n180\n97\n94,108,112,133,167,180\n153,157,165,177\n96,113,123,167,180\n141,155,180\n54\n63,101,123,130,143,148,159,161,164,180\n32\n87,95,97,104,106,149,153,156,163,180\n0,19,57\n83,101,116,133,159,180\n0,67,180\n67,85,173,179\n62\n62,83\n42,57,80,94\n65,81,83,180\n65,180\n42,57,72,178,180\n70,156,180\n83,113,135,149,153,155,161,164\n58,82,180\n74,178\n65,179\n0,25,33,36,40,52,89\n0,180\n0\n0,180\n180\n180\n1,3,36,53,55\n180\n96,102,122,126,145,156\n76,94,110,121\n75,180\n155,171\n23,56\n72,180\n64,180\n57\n59\n73,131,159,174,179\n60\n47\n61,180\n65,78,180\n58\n58\n0,3,180\n180\n6\n201,249,265\n0,4,9,23,28,30,33,86,109\n0,4,28,50,53,72,75,85,87\n0,85\n122,125,167,180\n10,35,37,168\n2,25,28,40,47,65,170\n0,28\n5,11,29\n35,55,85\n60\n1,31,53,261,356\n71\n83,110,183,189,200,215,219\n89\n221,284,312,329\n233\n274,300,307,309,338\n275,277,295,314\n260,289,291,296,305,308\n160,168,180,203,257\n177,196,226\n0,180\n0,104,134,163,170,180\n25,312,341\n24,310,313,332,358\n58,69,73,163,168,174,180\n160,180\n117,166,169\n357\n3,17,23,31,304,320,343,345\n59,187\n63,65\n74,204\n68,71,205,236\n69,204,221,223,242,284,307\n54,72,98,190,209\n281,297,313,338\n219,222,233,283,286,312,336\n279,313,338\n59,80,190,221\n58,78,188\n72,99,183,196\n2,12,17,31,33,41\n1,27\n4,6,35,167\n4,35,153\n30,181,348\n180\n72\n0\n0,21,31,36,38,164,173\n0,16,19,35,52\n1,12,137,158\n11,147\n89\n102\n180\n90\n0\n4,170\n123,134,140,178\n3,5,25,346\n5,341\n32,56,69,84,105,122,161,180\n0,31\n51,90\n69\n60,95,103,107\n90\n90\n0,48\n0,41\n153,180\n32,53\n0,21,30\n46,127,130,143,158,173,180\n0,11,17,90\n0,36,90\n62,137,180\n0,40,60,81,84,90\n37,41,44,49,95,104,118\n54,57,69,74,85,90\n56,90\n59,91,119\n57,90\n0,29\n142,180\n134,137,158,180\n1,57\n3,38\n71,88,95,113,129\n71,78,90\n8,37,56,71,90\n11,42,58,76\n82,103,106,108,123\n46,55,60,64,73,79,90\n27,30,81\n54,97,125,128,152,167,173,178,180\n1,45,61,81,83,86,90\n0,12,35,42,44,80,89\n67,69,91,121,171\n0,32\n13,35,43\n0,47,56,62\n0,11,15,25,28,56,58\n131\n123,144,166,180\n180\n180\n165,180\n0,21\n0,20\n50,90\n67,89,120\n90\n0,33\n59,84,122\n56,64,72,90\n43\n33\n180\n143,162,177,180\n7,28,48,51,54\n2,50\n0,36,46,50,52,54,152\n47,108,134\n57,77,88,118,138\n47\n52,68,85,105\n0,150,154,180\n59,73,107,123,126,129,138,157\n50,119,148\n58,66,86,114,130\n0,3,159,166,180\n44,46,66,104,136,162,180\n52,137\n60,64,74,117,119\n54,72,77,83,90,111,124,141,153\n0,55,85,90,93,96,99,106,129,180\n0,57,72,77,130,180\n63,91,108,152\n15,180\n0,155,168,179\n0,25,175\n70,89\n53\n149,180\n154,165,179\n180\n0,45\n0,39\n70,122,126,180\n50,86,167\n53,123,127,136,142,154\n23,38,53,78,103,172\n0,35,37,44\n0,17,41\n60,75,97,107,139,158\n38,45,49,57,157,180\n40,62,75,81\n0,44\n66,180\n0,34,59,180\n0,63,65,180\n0,74,180\n282,307,334\n305\n68,163,179,246,321\n21,42,55,72,162,180,231,236,242\n52,71\n55,102,113\n177,199,239,290\n155,158,178,201,285\n6,55,318\n10,56,312,354\n30,59,313,358\n0,23,45,47,50,56,58,309,327,335,338,341\n151,194,284\n152,185,279\n12,14,55,312\n15,54,313,358\n49,314\n46,314\n58,80,183,200,280,285,288\n47,61,185,283\n52,68,71,172,297,311\n64,77,144,169,171,300,308\n31,34,37,51\n0,42,46,58,302\n44,312\n0,54,180\n0,56\n182\n76,87,182\n0,52,79\n67,80,153,164,174\n70,76,80,83,85,87,166,186\n52,309\n46,307,325,345\n71,181\n176\n51\n46,49,307\n49,168,182,310,316\n83,130,175\n80,86,92,95,107,128,157,178\n66,180\n74,175\n74,163,175\n181\n181\n32,52,85,123,180,293,295\n201,300\n63,198,299\n50\n4,56,84\n183\n184\n62,116,118,131,174,293\n61,293\n19,28,50,182,300\n53,184,297\n183,226\n182,187,226\n66,164,298\n69,167,297\n60,180\n59,180\n0,54,71,171\n70,179\n63,78,177,179\n33,42,45,51,59,66,71,88,180\n131,166,178,180\n178\n180\n180\n180\n53\n0,2,4,6,49\n28,55\n9,54\n0,25,46,49\n59,180\n64,180\n49,76\n48\n55,180\n67,179\n180\n180\n46,74\n0,37\n58,175\n61,180\n164\n55\n52,55,58,66,179\n76,180\n63,88,180\n297,303\n300\n58,100\n57,102\n56,96\n54,87\n192,267,292\n189,191,193,201,291\n42,53,311\n306\n9,36,56,307,352\n56,307,339,359\n53,276,296\n36,49,55,300\n31,306\n63,74,174,177,185\n76,175,179,181\n186,207,278,282,291,304\n183,196,280,294\n199,274\n199,271\n9,25,55,61,68,96,102,104,142,174,180\n1,140\n0,30\n1,178,180\n0,2,108,123,125,160\n0,3,9,129,165\n0,8,40,121,129,160\n0\n0,2,138,179\n0,39,135,166,170\n25,94,102,126,133,143,155,161\n157,160,180\n161,180\n0\n0,7,45\n3\n66,99,129\n62,78,103,124,127\n106,124\n0,27,30,38,171,180\n0,5,133,146,150,163\n180\n3,39,164\n1,18,21,127,168,180\n162,180\n63,114\n67,85,88,90,105,125\n180\n123,148,322,336,347,357\n125,297,318,326\n8,50,342\n6,8,10,12,23,335\n2,16,342\n16,305,335,343\n1,6,111,231,245,324,347,350,359\n103,108,114,240,249,260,276,300,319,349\n72,78,85,101,105,110,120,271,287,307\n111,133,185,267,301,350\n9,25,332,348\n16,335,337,352,354\n162,164,173,188\n210,251\n13,137,235,238,298,320\n5,128,237,314,317,327,334,339\n283,303,327\n304,330\n314\n15,224,357\n3,18,43,74,212,249\n13,15,188,220,246,248,340\n200,208,226,248\n204,217,246\n202,219,231,234,252,265\n154,174,211,248,265,267\n219,264\n210,249\n1,8,10,12,45,77,291,338\n12,52,296,341\n17,27,328,345,347\n14,48,339,348\n110,329,348\n21,53,76,79,103,351\n2,6,90,105,339\n10,89,351\n122,140,166,173,208,210,220\n134,147,167\n136,217,236,266\n128,145,147,191,194,236,265\n119,126,132,136,226,239,248\n135,154,226,241\n93,116,119,123,276,302,340\n92,110,122,130,243,277,299\n98,107,114,117,123,253,310,316,342\n99,121,251,271,335,343,348,351\n306\n306\n236,250,276\n180,229,252,255,257\n247,279\n16,339\n339\n5,308,342\n13,339\n122,145\n137,155,229\n215,218,221,254,260\n216,221,224,230,232,253,269\n222,228,234,254,270\n313,343\n347\n34,54,290,309,320,345\n1,33,50,293,311,320,328,339\n10,20,26,335,353\n114,126,136,160\n103,120,204\n10,290,329,352\n0,3,25,46,56,87,123,127,135,142,145,155,180\n0,27,45,48,50,76,122,165,177,180\n78,118,148,151\n180\n180\n0,21,42\n0,2,29\n1\n0\n0,14,25,50,84,121,180\n0,13,34,41\n0,30\n56,81\n21,330,357\n17,345\n356\n6,20,34,341,351\n9,33,36,350,352,356\n31,56,355\n17,27,30,321,358\n0\n0,22,24,42,44,51,85,90\n0,66\n0,2,16,42\n180\n0,132,160,180\n0,45\n5,9,22,54\n180\n0,18\n62,88\n33\n20,145,180\n1,10,12,20,27\n180\n0\n137\n135\n144,148,161,163\n6,18,120,142,146,161,164,166\n122,271,313,325\n114,261,318,343\n305,325\n123,147\n134\n0,8,302,304,331\n2,301,335\n5,32,54,75,79,89,338\n9,26,44,47,51,87\n77,83,106\n51,75,104\n119,121,123,150,199,220,251\n116,150,161,199,225,247,250\n149,167,184,189,195\n132,135,138,150,167,182\n152,156,216\n149,175\n130,150,162,164,181\n169,177\n3,7,50,114\n2,4,48,112,169,175\n261,285,322\n261,287,323\n110,115,127,147\n116,139,155\n303\n303,323\n101,122\n102,121\n247,255,257,261,281\n247,281\n287,332,334\n8,290,332\n9,80,101,348\n12,101,348\n128,164,197,234,241\n119,125,128,148,163,190,194,196,231,233\n72,99,117,119,136\n49,96,98,106,112,134,165\n279,291,301,304,322\n250,266,278,287,301,305,332,352\n289,304\n304\n126\n126\n11,18,23,33,70,77,86,113\n21,39,59,88\n136\n136\n51,337,355\n47,338\n118,146,168,170,221,244\n118,141,154,169,172,188,221,244\n89\n90\n52,55,90\n0\n0,8\n1,3,38,58\n0,132,151,174,180\n0\n74,90\n24,337\n162,179,198\n0,10,19,39\n39,59,180\n59,180\n23,93,252,268,322,338\n0,66,180\n0,180\n0,7,33,112,142,180\n0,22,51,87,107,129,150,180\n0,43\n19,177,180\n74,296\n0\n21,159,166,173,175\n56,180\n31,46\n53\n0,10,14,29\n0\n0,44\n136,143,146,180\n60,110,150,167,180\n43,56,102,168\n60\n56\n60,68,75,80,90,178,180\n59,303\n59,302\n71,85,97,105\n49,72\n56\n0\n180\n69\n69,88,103,111,136\n0,14,18,21,34,41,131,134,156,162\n15,20,29,59,61,90,111,139,141,144,165\n48,80,164\n0\n67,180\n0,56\n56,305\n56,305\n59,173,180\n54,75,123,169,177\n57,180\n69,180\n182\n0\n0,22\n61,74,109,141,180\n29,54,77,83,89,108,162\n38,52,87,90,97,105,174\n46,62,71,107\n31,49,97,143\n35,48,73,95,141,172,286\n35,74,94,155,171,293,317\n58,83,158,164,166,180\n19,41,59,174,180\n61,63,80,179,284,338\n91,178,180,189,306\n52,57,61,114\n63,114\n99,261\n58,82,168\n61,80,177,180\n60,79,102,105,113,116,124,127,133,156,176\n63,180\n36,65\n0\n34,36,43,47,59,80,90\n1,9,35,90\n13,21,35,52,55\n49\n0\n8,12,49,126,154,180\n0,34,36,50,71,90\n1,4,39,73\n66,68,86,136,151,153,155,166,180\n0,27\n0,57,84,122,141,144,146,149,164,180\n0,47,99,131\n137\n0,39,152,180\n1,8,29,51,58,62,73,84,89,100,104,106,109,131,152,180\n0,162,180\n0,8,26,81,150,180\n65,75,81\n80\n27,29,66,68,109\n51,71,98,105\n31,33,59,79,102,235,256\n36,38,41,56,62,90,158\n180\n66\n67,108\n67,174\n12,39,54,96,153,158,174\n161,167,180\n60,145,180\n33\n24,28,45\n48,54,56,59,66,78,162,180\n55,67,86,180\n16,19,42,63,67\n47,154,180\n15,33,39,58,104\n0,20,23,45\n12,21,61\n66\n0,25,38,58,65\n43,67,73,84,87\n0,16,18,29,32,36\n22,30,44,53,56,58\n39,62,78,173\n28,61,81,153,180\n2,49,77,85\n0,26,30,37,41,45,51,55,61,65,90\n60,180\n0,16,138,157,168,180\n0,13,29,48,90\n15,131,152,158\n49,53,68,96,112,142,173\n51,71,74,87,110,132,174\n59,62,93,167\n15,40,57,73,110,115,130,139,143,149,155,180\n0,5,40,74,104,137,159,180\n0,7,85,107,134\n0,11,112,132,144\n61,180\n64,89,148,161,167,180\n60,67,77,108,148,171,176\n21,25,45\n36,40,49,54,82,157,171,180\n37,57,180\n52,55,63,155,180\n20,47\n47,67,168\n2,32,34\n0,3,19,38,64,72,79,81\n124,140,174,180\n40,47,49\n17,46,310,342\n1,31\n42,54,56,65,73,85,90\n0\n62,85\n23,32,56,71,83,87\n192,303\n63,159\n180\n67,81,84,175,177\n48,66,109,174\n238,289\n0,46,55,61,79\n0\n0\n15,32,40,63\n180\n63,76,79,176\n64,73\n57,83\n0,7\n180\n57,180\n54,75,90\n69,80,82\n66,80\n103\n71\n180\n40\n0,5,9,17,57,75,78,85\n0,9,31,43,49,63\n2,19,47,61\n60,64,86,121\n43,75\n43,47,77\n41,78,96,101,104,109\n176\n180\n180\n0,29,33,71,90\n0,118,156,180\n0\n36,40,88,90\n130\n0,3,8,20,28,30,49,70\n0\n90\n10,33,65,88,95,102,122,141,150,164\n8,64,93,109,126,149,158\n4,19,235,254,263,277,282,302,306,319,322,328,335,349\n1,235,278,288,300,325,344,358\n10,109,128,167\n10,15,21,23,25,109,124,174\n21,28,50,105,113,125,137,152\n0,6,50,64,83,121,146,173,177\n6,8,21,58\n66,85,99,104,179\n69,180\n66,209,306,338\n66,207,306,332,334\n187,280,285,291\n111,136\n105,129,133,138,141,143\n90\n35,47,56,69\n70,90\n41\n24,47,54,60,90\n64\n0,9,39,58\n0,45,91,95,122,135,155\n182\n64,90\n34,92,132,180\n0,33\n90\n180\n4\n22,44,47\n176,184\n181\n0,6,24,52,79,82,84,90\n303,330,353\n58,106\n58,92,99,114\n27,31,42,68,102,140,172,176,180\n0,3,20,22,25,32,35,37,52,78\n71\n55,80,96\n82,86,89,93\n180\n180\n51,63,71,180\n0,5,152,156,180\n0,22,29,40,88\n136\n41\n101,168\n98,164\n49,52,61,86,113,180\n63,301,323\n59,195,248,293,330\n50,52,69,167,172,180\n31,61,180\n41,48,61,69,160,180\n25,49,63,71,180\n50,71,73,169\n45,59\n57,176,180\n59,174,176,178\n0,24,34,36,90,136,158,160\n57,59,69,180\n58,180\n0,30,55,57\n32,55,59,72,78,156,171\n34,45,58\n54,81,87,90\n1,10,20,43,70,104,110,115,118,139,142,161\n128,141,145,152,180\n0,8,36,52,88\n179\n77,177,180\n180\n49,81,163\n180\n58\n62,79,82,99,106,109,112,120\n66\n67\n28,61\n0,17,123,125\n0,31,55,66,76,89,154,178\n59,102,180\n54,67,168\n62,180\n180\n30,56\n0,6,11,14,180\n0,35,120,142,146,180\n14,18,23,39,44,147,180\n0,30,59,112,121,155,159,180\n0,9,13,24\n12,92,141,156,164\n13,25,53,78,94,114,145,179\n45,70,158,171\n8,19,42,57,60,80,171,176,179,188,201,205,208,222,251,271,299,341\n11,17,38,55,169,201,309,313\n68\n48\n0,4,58,180\n0,9,46,120,166,177,180\n1,18,52,70,115,180\n180\n0,10,12,14,30,48,69,133,180\n78,99,169\n76,95,99,103,150,168\n70,141,168\n72,165\n29,49,72,74,168\n52,59,180\n33,58,90,100,148,180\n0,2,31,51\n0,2,8,42\n59,180\n13,48,178,192,297,311\n43,155,182,282,297,353\n70,72,149,164\n70,164\n33,37,41,166,177,203,308,355\n9,23,42,45,179,190,204,311\n68,163\n66,165\n0\n0\n114,133,180\n0\n0\n0\n0\n0\n0\n0,180\n180\n0,8,159,180\n151,180\n0\n11,22,35,150,179,183,194,197,348\n1,5,157,166,181,199\n15,355\n221\n216,238,244,259\n22,234,246,249,255,261,268,341,356\n248,358\n4,296,303,314,338,359\n2,246,249,305,344\n6,12,298,346\n19,76,80,117,129,131,234\n16,118,144\n0,180\n0\n68,180\n65,79,81,108,169,187\n295\n295\n292\n180\n184,292\n184,282,287,292,300\n179\n56\n21,55,309\n1,40,56,306\n65,185,302,319\n59,77,178,303\n176\n71,157,178\n180\n63,303\n65,183,305\n33,58,61,306\n33,57,300,325,334,355\n180\n181\n67,175,301\n68,175,299\n66,176\n66,131,180\n301\n187,205,293\n191,294\n192,194,297\n191,211,296\n199,268,298\n60,299\n62,300\n67,193\n59,74,298,301,310,323\n38,44,59,62,195,296\n38,62,76,79\n283,292,298,320\n65,83,176,202,228,263,296\n59,70,167,189,262,282,285\n0\n0,18,43\n63,180\n146,180\n180\n54\n14,54\n0,5,7,56,79\n50,65,170\n180\n61\n59\n13,34,55,306\n51,305\n308\n51,306\n50,307\n0\n0,40,180\n0,67,74,90\n0\n143,179\n0,48,60,90,96,98,103,129,180\n0,15,109,119,142,180\n0,25,27,30,49,55,60,77,100,103,105,138,141,173\n0,180\n0,7,135,156,180\n0,28\n0\n180\n180\n180\n0,27,31,41,46,55,57,70,102,128,144,180\n0,180\n180\n180\n8,180\n0,180\n0,179\n0,61,89,112,180\n180\n2,4,51,71,128,130,147,170,180\n0,11,35,38,55,75,78,110,130,150,170\n89,114,126,147,154,159,179\n28,103,134,150\n129,133,143,148,154,159,163,169,176,196,230,236,239,243,247,249,257,269,273,275,315,317,346\n3,138,145,156,185,217,229,232,245,249,262,272,276,294,299,305,309,329,349,359\n103,125\n2,4,21,30,39,45,67,82,97\n1,15,33,90,93\n138,152,155,171,214\n139,186,194,217\n157,173,220,224\n156,217,220\n50,93,118,147,153,183,185,209,224,258,264,270,337\n19,85,141,196,198,201,205,209,211,243,264,327,336\n139,165,219,248\n11,26,121,235,264,293,300,308,314,326,332,338,353,356\n3,7,23,26,101,172,233,257,275,294,310\n3,22,35,45,61,88\n1,133,171,180\n0,23\n151,155,158,161\n151\n65,180\n57,175\n25,57,303\n57,296,304,306\n302\n0,63,180\n133,180\n63\n60\n63\n60,62,180\n180\n0,78,96,101,110,180\n63,180\n66,174,296,303,306,309\n64,175,299\n26,65,67,173,192\n61,90,174,194\n60,172,296\n1,128,150,170,180\n59,180\n54\n180\n15,52\n10,25,53,60\n54\n48\n48,299\n52,300\n302,325\n301\n303,332\n179\n60,83,85,102,178\n60,82,173\n67,76,85,105\n58,306\n191,208,298\n189,210,216,299\n295\n265,295\n251,275,288\n195,251,266,289\n60,184,302\n58,174,303\n54,306\n55,305\n180,186,196,249,268,270,295\n179,185,192,240,273,295,300\n64,174\n65,175\n72,88,92,133,168\n190,198,206,284,289\n190,194,206,286\n236,239,263,281\n193,224,246,263,265,278,292\n0\n0\n0\n0,44,47,66,102,119,129,132,149,180\n0,57,65,90\n0,5,7,24,27,29,31,39,156,180\n0,12,15,17,46,65,85,95,104,107,130,144,150,153,158,161,169,172,180\n0,64,94,127,130,136,180\n1,112,141,256,272,313,332,349,358\n90\n0,35,55,73,109,115,123,126,130,134,180\n89,123,136,144,180\n80,97,141\n55,76,171,180\n72,178,180\n71,180\n158,180\n153,169\n9,27,50,71,78,81,98,122,145,171,180\n0\n0,21,36,45,64,75,83,94,100,127,153,156,177,180\n1\n5,25,38,67,93,164,297,313,336,341,347,353\n12,35,40,47,68,85,296,311,336,341,350\n0,7,25,35,45,48,63,65,68,94\n28,36,46,79\n50\n123,140,164\n90\n63,90,93,124,166,168,171\n0,42,62,90\n179,218\n0,30,52,85\n87,98,107,112\n0,2,14,45,47,75,114,139\n89,104\n85,105\n16,28,35,42,65,79,101,135,160,180\n36,44,46,54,75,91,216,235,252,279,300\n0,180\n0,180\n0,46,180\n0,22,27,42,78,120,122,139,143,148,158,179\n55,70,74,258,358\n0,50,71,89,218,342\n24,49,67,88,135,182,266,274,280,350\n50,83,153\n38,65,91\n70,94,96,98,104,249,259,266\n8,178\n0,97,107,180\n28,65,91,155,180\n62,165\n67,167\n107,110,126\n0,14,18\n44,48,64,80,82,84,104,106,126,131,156,168,176,178\n106,115\n68,156,180\n15,53\n65,157,172\n64,180\n62,72,85,101,143,152,165\n55,62,180\n59,69,73,75,180\n34,59,84\n0,6,19,28,46\n0,17,21\n75\n0,9,33,50,76,79\n54,59,65,74,79,82,95,180\n98,116,142,172,180\n0,26,28,43\n36,54\n35,41,55,70\n4,19,41,177,321,337\n75,118,139,151,172,180\n21,23,46,48,70,108\n0,13,16,25,82\n24,40\n40\n0,179\n0,5,14,20,28\n2,26,28\n0,10,19,24,116,135\n0,18,98,130,166\n109,142\n0\n58,180\n61,176,180\n180\n56\n42,62,180\n0\n0,40,61,66,68,143,180\n0,75,90\n1\n53,73,92,109,133,172,180\n0\n2\n180\n120,145,147,169,174,178,180\n0,28\n11,56,128,165,180\n28,66,90\n0\n180\n0,23,54,77,148,179\n145,178,180\n61,152,180\n0,80,101,122,142,145,180\n0,8,81,113,133,136,143,148,180\n0\n15,24,27,53\n6,8,25\n0,23\n2,52\n2,31,42,56\n180\n180\n141,166,180\n180\n180\n180\n0,38,50,95\n0\n141,180\n179\n8,25,41,61,64,116,124,154,156,161\n148,151,155,158,162\n0,43,54,64,93,123,140,157\n0,67,89,96,98,105,125,132,137,144,146\n4,7\n1,3,17,19\n0\n0,9,25,48\n180\n180\n180\n180\n70,117,147,151\n0,9,11,35,72,95,122\n180\n180\n144,180\n0,180\n0,177,180\n0,20,25,60,172\n128,149,171,176\n180\n180\n0,42,131,161,180\n3,23,36,51,112\n2,15,40,55,58,70,132,161,168\n180\n158,180\n0,2,9,54,89,136,144,148,151,179\n138,180\n0,159,180\n0\n0,180\n0\n97,142,161,180\n82,127\n126,165\n151\n128,140,158,182,186,190,222,244,250,256,298,345\n128,133,231,243,249,264,284,292,301,303,320,347\n107,118,124,136,142\n112,116,118,120,122\n121,132,141,148\n0,41,53,64,89,115\n40,43,50,55,63,70,92,108,110,356,359\n18,21,47,77,90,104\n149,165,167,172,229,260\n116,133,155,177,228\n179,243,268\n167,184,199,219,222,227,250,257,264\n131,155,205,208,214,236,238\n159,165,228,238,242,244,271\n150,213,242\n152,227,232,240\n140,165,178,212,214,232,234,273\n188,202,205,208,236,253,256,258\n115,124,145,172,227,231\n169,181,194,218,236\n238,251,266,282,287,292,295,298,322,348\n224,237,242,260,300,320,325,345\n25,70,96,146\n135,138,145,152,176,217\n141,145,148,159,165,167,173,179,213\n254,269,272,298,331,351,353\n266,295,298,314,334\n0\n0,35,132,134,137,180\n33,64,79\n0,39\n49,52,65,93,110,126,129\n136,154,180\n159\n0,29\n0,18\n180\n0\n0,13,33,120,149,180\n0,45,49,59,90\n0,2,7,10,19,23\n0,34,36,44,70,77,84,128,153\n0,19,21\n0\n0,15,33,162,180\n0,20\n139,180\n20,28,42,119,149\n46,118,159\n20,84,101,117,216,227,230,261\n21,52,63,108,233,239,244\n51\n28,50,76\n35,71\n36,96\n29,34,38,106,214\n39,67,224\n212,238,257\n212,237,253\n106,127,138,166,201\n102,152,201,215\n251,274,290,326,329\n6,8,13,17,268,290,309,326,338\n271,327,349\n277,292,294,302,307,315,323,337,343\n83,109,131,136,152\n85,87,105,135,141,148,152\n105,134,138,142\n72,93,98,108,127\n4,6,12,18,46,63,83,105,132,156,160\n8,15,38,44,57,96,101,116,142,159\n17,42,46,54,68,101,233,243\n15,19,25,27,41,45,47,50,77,87,101,208,251\n36,59,79,104\n109,140,163,179,198,221,238\n109,140,164\n22,55,74,102,105,110,113,188,192,217,239\n10,12,37,96,195,230\n42,198,218,238,242,246,265\n65,112,207,232,267\n32,225,246\n53,75\n25,131,133,321,349\n25,50\n1,3,8,17,34\n22,229,247,348\n2,22,251,307,343\n6,246,269,358\n246,310,349\n223,246,264,288,337,352\n6,359\n1,240,256,274,310,335\n110,147,164\n89,91,105,120,140\n111,132,155\n109,139,157\n5,13,18,241,251\n19,95,116,235,260,357\n18,112,239\n115,130,133,162,244,248\n23,98,131,239,343\n25,222\n21,40,205,225\n70,92,177\n68,158,168,180,272,309\n295,307,317\n58\n11,67\n60,301\n56,281,302,317\n42,58,299\n52,302\n65,176\n64,176\n114,118,175\n72,170,179\n75,124,155,177\n86,123,179\n93,135,176\n61,177\n118,139\n70,177,200,301\n174\n63,81,175\n146,152,178\n71,181\n1,28,48,61,63,317,354\n24,53,55,169,303,326,340\n10,355\n188,190,222\n37,57\n57\n55,305\n54,305,322,329,334\n214,235,237,300,325\n193,221,223,237,240,244,247,301\n195,217,220,258,306\n70,181\n66,129,132,174\n61,76\n79,95,98\n76,172,177,179\n58,84,95\n35,45,62,198,294,306,310\n54,69,190,306\n68,171\n46,49,58,60,62,186,303\n189,227,291\n187,221,296\n55\n58\n169,172,176,185,289\n62,177,307\n62,96,179,306\n57,177\n166\n55,85,108,111,125,138,140,152,175\n59,85,107,124,127,147,175\n103\n261,302\n302,328\n302\n59,189,233,285,289,302\n58,83,190,213,300\n62,84,303\n61,176\n62,177,304\n0,130,136,144,146,159,165\n180\n0,29\n1,17,23,30\n0,3,5,29\n0,4,136,348\n34,44,51,74\n302,333\n178\n100,130\n66,92,94,127,155\n87,100,114,117,123,130,135,145,148\n78,82,86,91,110,114,128,149\n198,218,220,225,253,262,271\n103,105,113,133\n103,133\n26,28,60,180\n46,67\n180\n159,180\n22,55\n23,29,38,57\n33,62,180\n42,61,180\n60,168,300,310\n36,58,168,298\n56,86,94\n54,78,82\n302,304\n302\n139,155,181\n64,90,172\n64,171\n55,68,88,164\n49,66,89,118,165\n66,92,169\n64,123,136,173\n64,88,160\n57,105,163\n61,164\n186,223,298\n192,228,296\n297\n193,254,259,296\n69,80,169,189\n53,177,295\n59,179,299\n47,63,307,314\n38,52,54,303\n44,300\n64,170,173,175\n63,83,171\n59,65,70,179,182,293,299\n58,182,291\n40,61,324\n61,171,314,317\n181,184,199,277,296,301\n0,4,26,53,159,180\n54,180\n24,166,177\n156,191,225\n155,174,191\n62,180\n76,172\n57,80,103,180\n0,31,49,162\n153,180\n127,159,179\n0,25,44\n15,42,59\n4,46\n0,49,82\n65,180\n69,85,180\n60,66,69,72,96,180\n67,180\n0,42,62\n8,69,156,178,180\n44,49,63\n12,45\n3,44\n67,89\n23,67,307,319,322,327,329\n21,46,302,316,338,341\n47,62,306,311,316,356\n41,60,315\n51,193,196,286,304\n52,189,284,311\n45,321\n0,4,27\n28,47,60,67,73,77,89\n0,19\n138,142,175,178\n1\n0,17,44,76,80,96,104,115,126,171,180\n0,9,16,23,28,31,34,66,88,105,112,122,124,128,135,147,156,166\n125,138,151,180\n9,29\n0,7,9,17,37,57,63,69,89,151,180\n0,3,16,36,91,122,131,151,155,158,160,177,180\n60,65\n63,180\n70\n32,58,65,180\n3,9,12,19,154,162,164,169,173\n2,69,90,95,99,120,140\n26,106,120,169,188,334\n38,40,46,59,91,106,108,115,136,138,154\n0\n143,180,216\n56,123,182,241,271,290\n118,138,174,245,316\n94\n3\n20,22,49,79,84,92,95,153\n0\n0,180\n0,14,180\n0\n2,6,13,180\n22,180\n0,24\n0,22,180\n169\n13,21,30,71,73,238,334\n0\n0\n4\n0\n0\n68,70,182,185,302\n65,186,300\n199,294\n192,194,290,300\n0\n63\n57,59,310\n189,296\n187,203,297\n0\n0,2\n196,239,292\n0\n0,25\n0\n92\n17,77,96\n68,151,172\n69,177,201\n287,290,306\n0\n0\n0,25,49,69\n0,28\n66\n66\n293\n294\n0,11,26\n83,85,102\n87,105\n7,11,14,46,54,58,148,155\n14,47\n5\n11,163\n16,51,140,171\n4,13,41,59,171\n4,35,54,86,224\n4,7,36,59,69,217,219,236,239\n257,268,270,339\n265,339\n225\n222\n225\n228\n63,163,180,279\n1,40,280,343\n0,39,62,80,162,180\n66,116,138,141,145,167,180\n0,3,27,29,65\n13,36,58,76,101,119,172\n0,9,60,74,106,157,159,171,180\n0,63,104,107,110,133,145,172,177,180\n0,2,33,39,42,59,76,102,146,155,168,174,180\n84,109,115,180\n99,152,156,165,172,176\n0,8,37,69,100,103,106,123,162,169,175,178\n63,106,133,171,177,180\n46,66,82,117,170,173\n143,163,180\n0,22,32,60,68,96,111,132,155,167,171\n1,3,7,122\n61,177\n32,34,38,56,180\n56,168\n61,180\n27,58,109,140,180\n39,64,94,180\n27,61,86,154,178,180\n0,12,30,36,51\n36,55,77,99,102,105,144,179\n21,55,71,77,87,91,95,124,139,163\n50,53,62,175,177,179\n13,50\n14\n13,102,106,260,263,282,333,351\n52,64,180\n61,180\n56,178\n59,180\n60,180\n61,180\n3,315\n0,21\n51\n3,72,114,133,162,165,180\n47,110,115,132,160,169,172,180\n0,180\n0,179\n0,180\n7,9,29,87,180\n2,102,149,154,158,185,189\n3,49,96,118,120,136,161,164,181,184,188,198,236\n8,32,41\n14,30,33,64,356\n138,143,149,172,184,188,198\n142,182,198,204\n11,48,190,205,211\n13,344,346\n181,279,297\n181\n69,177\n66,82,142,178\n76,78,141,169\n306,316\n295\n57,70,72,170\n32,56\n48,50,61,180\n60,94\n47,66\n286\n58,62,180\n180\n180\n1,187\n169,188,192,212,358\n15,17,156,184,206,208\n26,167,172,180,199\n0,3,37,180\n46,61,66,156,165,177,180\n142,155\n119,129,138,178\n180\n146,178,180\n76,92,127,131,180\n100,139,157,180\n22,26,33,74,89,102,306,321\n58,79,87,135,148\n81,103,134\n151,168\n43\n85,149,161\n150\n32,44,82,174,180\n0,75,147\n83,131,145,151,173,179\n96,103,107,117,148,180\n72,82,84,88,131,140,148,150,158,160,162,170,180\n106,150,163,180\n73,148,167\n69,129,154,171\n42,72,175\n44\n23,57,74,77,97,106,109,180\n80,152,169,180\n1,3,14,16,124\n59,180\n9,52,172,331,344\n4,17,54,166,312,340\n17,21,34,58,141,310,312,330,347\n19,28,33,36,57,60,64,312,336,341,353\n78,160\n78,131,161\n68,125,155\n68,102,117,131,152\n10,39,74,291,323,347,359\n18,43,346\n6,13,19,24,44,56,80,174,311,330,359\n15,46,53,162,180,313,357\n4,39,66,70,298\n1,40,65,75\n12,29,56,76,86\n46,64,141,163,180\n57,83,179\n44,64,180\n62,180\n39,54,56,68,72,169\n52,174,299\n56,175,194,287,300\n0,21,36\n0,180\n0,180\n180\n0,52,180\n0,180\n1,6,48,73,172,176,180\n0\n0,27,48\n45,75,168\n22,61,180\n0,11,35,117,133,157,159,173\n0,36,144,180\n21,46,54,63,93,115,180\n0,14,33,61,66,73\n212,214,235,237,255\n226,252\n0,9,15,18\n0,6,13,33\n46,62,180\n67,166,168\n55,57,72,75,80,164\n26,44\n56,73,163,173,177\n53,59,170,175\n58,143,163,179\n0,180\n0,54,139,180\n27,105,129,146,163\n48,103,105,130,180\n0\n0,25,31,180\n0,180\n0,3,8,20,23,71,91\n17,55,130,132,139,147,153,180\n0,24,34\n4,7,60,97,137,155,172\n0,177,180\n0,8,31,59,154,164,167,180\n0,7,28,34\n0,18,176\n32,66\n2\n0,179\n146,149,156,169\n180\n73,86,101\n0\n0,180\n0,6,180\n0,163,180\n0,6,150,169,180\n0,20,23,151,180\n32,64,67,95,119,122,180\n63,95,180\n51,92,123\n56,60,74,180\n0,55\n58,174,176\n74,178\n64,180\n65,170,185,201,290,312\n62,67,200,301,306,311\n68,302,320,328\n297\n191,299\n57,71,184,194,301\n60,75,176,193,288,308\n52,282,307,316\n53,60,84,297\n69,71,210,262,304,321\n57,71,300\n38,66,68,85,131,146,149,176,206,220\n49,54,56,63,68,74,76,123,128,133,140,169,180,186,224\n60,65,71,160,177,211\n173,202\n165,189,194,202\n161,194\n167,171,188,193\n164,166,171,179,191,208\n0,14,45,56,81\n31,44,55,66,89\n180\n163,180\n180\n0,4,12,18,46,66,90\n9,13,21,29,34,39,69,78,82\n0\n180\n180\n80,88,91,98,108,114,119,138\n180\n60,303\n0,107,111,118,127,132,141,143\n301,324\n59,174,299\n61,174,299\n24,38,96,150\n270\n270\n38,51,54,319,322\n30,48,182,294\n181\n181\n303,321,342\n299,314\n299,315\n49,61,68\n47,76\n17,40,327\n38,328,340,347\n0\n0,29,153,177,180\n38,41,62,90\n0,35,40,50,90\n49,56,60,64,72,75,98,119,154,160,173,180\n1,34,38,78,87,90\n101,126\n0,8,59,79\n118,180\n21,27,29,87,97,108,162,170,172,174,177\n0,44,79,96,139,180\n27\n51,59,70,90\n154,181,209,227,237\n339\n340,349,351\n0,31,42,47,51,59\n0,47\n0\n0\n0\n180\n0\n0,19\n0,5\n178,180\n0,37\n0,7,12\n0,18,62\n0,28\n6,38\n53,180\n180\n53\n55\n0\n0,6,8,18,38,71,80,83,90\n51,87,90\n0,2,31,82\n5,14,17,26,57,62,68,75,121,127,130,142,157,165\n56,60,71,82,90\n49,69\n34,55,90\n51,72,104,119\n136,180\n0,34\n0\n0,28,30,35,39,41,43,45,100,131,133,135,180\n0,22,37,58,64,67,90\n0,35,90\n51,69,102,113,127,179\n56,75\n0,30,32\n180\n37\n27,58,64,79,82,108,137\n0,23,125,136,142,156,167,172,180\n126,135,152,155,160,165,180\n337\n2,22,26,45,48,51,61,64,79,90\n0,26,104,131,148,167,176\n160,191,250\n160,167,171,203,207,217,221,244\n139,161,164,176,180\n0\n85,90\n35,53,63,80\n77\n302,305,327,333\n0,20,26\n32,51,70,78,87,103,109,113,115,122,131,133,141,143,160,164\n0,71,90\n7,35\n0,29,48,67,89\n0,8,10\n0,8,28,43,77,98,127,141,164,170,180\n34,37,57,63,67,74,90\n0,2,11,43,90\n64,75,80,114\n90\n0,2,37\n0,59,93,120,135,139\n0,6,11,180\n179\n0,2,6,28,155,180\n0,129,137,151,173,180\n2,25,34,36,180\n180\n51,305\n111,275,301,305,320,336\n168,204\n304\n305\n18,308,312,318,322,325\n4,38,42,50,53,280,310,314,323,327\n293,321,323,331,337,354\n286,288,306,325,330\n117,126,133,160\n112,140,165,206\n0,10,16,18,26,36,77,126,139,171,174,177\n20,36,77,96,99,156,180\n57,180\n180\n73,124,177\n66,84,125,173,182\n63\n0,39\n0,45,70\n0,166,169,180\n19,54\n196,298\n314\n74,308,312,315,328,335\n1,3,24,35,44,53,90\n44,58,61,75,97,99,102,123,156,159,175,180\n0,166,180\n33,126,145,159,180\n0,180\n0,180\n180\n251,304\n24\n0\n0,20\n0,15,18,33\n14,46,81,105,112,123,145,180\n37,43,63,87,90\n39,90\n0,16,21,47\n0,45,90\n0\n90\n0,2,7,9,30,47,62\n0,32,34,38,51\n28,48\n58,180\n180\n0,12,37,40,71,171,180\n0,3\n181\n87,251,258,272\n54,79,82,98,106,111,130\n163,166,180\n180\n126,319,325,329,333\n125,137,146,300,305,312,319,331,335\n155,168,180\n61,90,102\n0\n71,262,289\n69,292\n0,43,64,90\n14,36\n0,14,17,29,48\n2,8,10,17,26\n0\n0\n0\n2,8,13,180\n1,14,33,54\n180\n12,113,122,142,158,180\n0\n19,191,217,287,310,340\n0,33\n180\n1,30,180\n162,180\n0\n180\n0\n24\n15,47,49,76,127\n21,181,200,206,210\n29,200,203,231\n59,90\n184,304\n179,302\n0,29\n154,180\n180\n177,180\n0\n0,24,120,136,168\n0,37,147,180\n35,96,109,126,151,157,180\n180\n0\n180\n0,169\n1,5,180\n0,16,180\n0,180\n0,33,67,180\n0,180\n0,23,55,132,151,180\n0,180\n0,145,180\n0,180\n0,143,151,180\n3,10,19,21,30,166\n45,59,86,89,137,158,172,177,191,194,232,248,266,319\n10,43,78,103,151,153,176,245,257,266,287,326,331,338\n0,20\n1,21,167,173,180\n0,154,180\n24,44,57,84\n97\n0\n2\n64,80,119\n56\n2,64,78,135,180\n49\n71,85,111,115,145,180\n45\n47,54,61,180\n49,130\n56,63,174,185,302,342\n49,69,173,295\n61\n72,82,104\n180\n286\n188,277\n82,160,167,180,294,296\n75,95,132,156,162,168\n177,179\n129,150,180\n11,147,175,180\n0,180\n180\n0\n180\n2,4,180\n180\n6,161,180\n0,170\n0\n180\n179\n180\n180\n0\n151,176,180\n59,75,97,117,164,192,220,251,264\n74,104,237\n50,54,61,77,89,96,211\n180\n0,79,107,126,136,161,180\n0\n146,173,178\n180\n0,49,76,87\n0,122,143,173,178,180\n0\n0\n180\n0,7,144,171,180\n180\n0,180\n1,180\n0,25,127,157\n0,2,20,46,67,97,100\n0\n0\n148,175,179\n9,39,51,54,136,139,159,178\n0,75,107,180\n0\n0\n137,150,153,180\n42,44,46,113,132,162,168,171,196\n42,46,74,107,137,166,168,201,204\n30,49,73,91,119,176,181,190,199,206\n47,70,89,116,204\n4,17,323,328,341\n7,245,326,341\n107,115,150,176,181,199,219,224\n109,116,146,192\n30,121,147,166,194,204,313,317,321,324,332,335,356\n31,57,60,136,150,156,162,203,314,327\n14,180\n0,162,165,180\n8,163,180\n167,186\n155,188\n0,30,34,58\n0,84,180\n0\n180\n136,158,180\n0,180\n0\n180\n2,30\n0\n139,180\n2,7,25\n180\n180\n65,157,162,173,180\n0,21\n39,133\n0\n0\n20,26,34\n22,37,322\n180\n159,173,180\n0\n0\n180\n12,35,37,180\n13,16,19,24,40,55\n68,85,135,157,160,169\n0,58,73,179\n63,180\n0\n0,113,115,117,147\n30,61,180\n180\n49,51,57\n1,56\n57,178\n44,78\n65,171,180\n62\n61\n5,9,51,64,300,316\n0\n13,18,38,40,78,131,136,152,178,180\n45,67,89\n0,13,44,89\n71,111,118,120,145\n50,54,71,90\n0,46\n43,68,90\n163,166\n0,16,33\n155\n132,157\n0,36,56,66,123,126,138,163\n100\n0,2,146,171,176,180\n19,58,72,92,117,125,128,156,180\n0\n53\n0,72\n83,101,110\n12,34,46,49,52,67,70,84,90\n0\n47,137,180\n1,4,67,90\n1,29,70,87,90\n174\n139,168,180\n0,36\n0\n13\n143,180\n17,47,66,88\n60,68,78,98,106,110,113,150\n0,21,44,48,66,90\n41,72,114,180\n140,178\n137,164,177\n0,18,20,30\n0,20\n0\n2,24,51,144,180\n73\n2,37,70,90\n63,66,96,99,114,180\n85,90\n2,16\n0,12,25,86,180\n0\n162,180\n157,180\n179\n5,24,33\n50,70,90,105,145\n0,3\n69,154,173,180\n0,58,91,107,142,157,162,168\n8,125,138,151,161,172,180\n0\n0,37,180\n7,118,135,171\n0\n0\n125,234\n143,168,189,208,228,236\n33,69,90\n22,38,57,82,126,144,165\n0,4,50,89\n60,62,87,90,92,97,115,129,133\n132,141,152,161,173,180\n155\n0\n1\n0,21,103,128,162,180\n0,49,71,81,90\n0,35\n44,68,111,135,167,170,180\n64,67,71\n39\n50,58,63,67,87,96,128\n54,90\n52,71,98,118\n137,145,174,176\n138,143,163,180\n0,32\n0,20\n0,10,68,73,79,96,139,178,180\n23,139,159\n0,178,180\n25,47,53,60,135,180\n0\n0,141,155,157,180\n0,21,133\n118,121,138\n166,180\n150\n0,35,132\n65,131\n45,47,122\n44,99,101,119,162\n7,25,32,41,44\n13,18,21,42,44\n25,43,105,129,218,238\n27,66,73,75,77,79,107,217,236\n21,48,55,57,79,85\n53,57\n39,89,109\n36,70,101,104\n13\n23,45\n14,17,43\n29,34,46,76,80\n111,128,147,149,152,173,197,199,209,238,243,245\n110,148,172,197,251,253\n146,160,169,173,175,199\n160,180,194\n3,8,21,41\n1,22,32,40\n259,290,324\n21,282,302,308,322\n243,249,255,260,279,308,325,332,334\n256,275,318,339\n37,44,49,57,86,97,99,107,131,153\n0,14,34,50,70,83,106,108,111,114,133,138,142,153,157,178\n27,44,48,85,93,105,113,214,220,261\n28,55,93,106,114,116,140,219,221\n29,56,77\n33,35,41,48,82\n108,152,168,176,196,218,241\n106,164,200,203,206,237\n18,35\n17,42,356\n13,130,133,238,352\n5,11,17,110,131,225,232,243\n203,209,212,222,229,267\n8,29,72,292,328\n6,17,27\n13,33,342,352\n8,30,33,87,124,145,235,272\n20\n17,343\n20,61,211,236\n19,30,231,233,250\n24,59,106\n55,303\n58,305\n149,178\n146,152,158,180\n60,185,293\n61,180,182,291\n80,180\n80,145,155,181\n141,182\n56,303\n57,303\n177,303\n186\n187\n169,189\n55,57,77\n2,22,36,58\n34,57,306,332,342\n7,53,70,307,324,334,344\n71,122,181\n73,163,180\n50,190,303\n64,82,192,306\n57,59,61\n199,204,207,210,216,297\n71,177\n266,306\n47,298,322,345\n46,52,58,313,345\n0,54,305,326,328\n1,52,303,349\n186,281\n60,180,304\n63,150,179,243,304\n65,165,183,306\n61,81,157,165,169,171\n309\n63,188,296\n64,186,244,295\n43\n63,180\n62,67,292,298,305\n64,149,182,309\n62,184,297,312\n179\n177\n3,6,124,126,138\n13,25\n105,112,135,137\n111,136\n137\n61,180\n58,169\n180\n180\n53\n25,52\n61,180\n52\n71,180,191\n42,65,183,305\n53,81\n58\n68,134,173\n67,94,101,175\n65,137,193\n68,135,172,185,188\n189,201,291,298\n187,190,196,243,293\n61,170,299\n55,180,301\n49,309\n34,44,53,309,312\n68,169\n70,170\n14,19,27,30,55,144,152,176,180\n0,7,14,21,66,149,180\n134,140,154,172,180\n13,28,64,92,151,172,177,180\n123,163\n161,179,182\n38,64,93,99,105,144,158,181,303,331\n157,180\n0,19,32,50,168,177,180\n0,27,58,88,147,178,180\n109,137,150,152,166,179\n0,37,44,51\n41,180\n142,153,155,159,176,189\n128,148,162,173,183,188,199,218\n132,170\n122,128,134,150,172,200,279,299\n35,96,129,169,193,293,311\n73,293,329,344\n122,164\n52,66,85,97,179\n62,169\n57,180\n67,75,87,180\n180\n59\n1,19,37,39,41,74\n30,48\n37,67,70,180\n63,180\n0\n50,52,180\n42,59\n58,68,73,164\n47,53,62,76,166\n25,58,123,171\n41,61,180\n12,31,33,35,49\n0,3,7,10,17,44,78\n70,180\n44,310,321,324\n305\n1,33\n0,44,78,90\n90\n0,49,72,90\n48,74,76,86,91,102,120,135\n90\n56,90\n61,84\n58,90\n4,14,39\n132,160,179\n0\n0,56,88,90\n130,180\n20,45,70\n87\n0,21,44\n90\n0,3,57\n2,12,48,71,73,77,87\n55,93,110,115,126\n59,89\n90\n0,65\n0,9,36,43,68,95,100,105,116\n111,136,158,180\n7,25,33,35,37,48,67\n1,13,64,83,90\n12,38,43,45,72,93,104\n66,84,90\n0,7,49,52,78\n136,151,180\n0,3,6,36,40,51,66,90\n38,84,90\n0,22,137,175\n53,65,83,90\n0,3,5\n58,75\n65,90\n110,113,132,155,180\n11,13,40\n90,93,110,130\n12\n11,84,338\n142,164,187,204,240,249\n140,162,201,203,244\n1,69,342\n6,340\n28,351\n351\n144,215,248\n144,165,198,218,246,280\n157,193,207,238\n156,190,208\n45,58,77,84,90\n49,70\n0,57,59,66,86,89\n0,47,50,57,59,66,78\n14,125,139,163\n61\n0\n117,147,175,180\n101,158,178,180\n0\n0,27\n0,3,19,23,29,32,45,48,71,90\n1,21,35,51,57,70,74,90\n0,3,10,25\n0,38\n0,17,34\n11,66,84,124,177,180\n9\n0\n8,39,64,88,91,122,142\n3,26,73,79,86,130,155\n0,23\n0,29\n95,123,163,180\n0,18\n0,149,152,178\n0\n78,180\n12,35,51\n0\n0\n0,29,35,41,157,162,180\n180\n55,71,180\n29,33,58,80\n70,77,179\n13,18,22,26,28,68\n0,41,180\n180\n304\n300\n0,4,11,15,60,311,334\n27,57,293,310,356\n9,56,308,310\n12,15,58,309\n48,310\n48,314\n152,274\n120,156,162,164,166\n60,282,296\n63,296\n70\n80,100,131,171\n77,95,131,150,155,161\n57,278,294\n76,120,170,189,195\n75,169,187\n172,185,194,213\n182\n160,185\n20,49,63,160,169,175,178,186,291\n15,46,54,60,166,181,281,294,312\n2,5,295,326,343,345,355\n0,86,93,101,118,143,179\n95,130\n117,137\n187,206\n192,207\n291,306\n43,53,64,295,310\n47,63,172,299\n115,135,153,156,160,163,166,226,230,237,241,270,274,285\n91,113,115,120,129,132,144,194,237,264\n163,172,178,235,263,271,275,279,285\n178,208,262,278,284,296\n61,310,351,358\n27,45,55,74,314,335\n308,326\n44,184,297\n44,185,297\n98,116\n104,111,118,144\n182,202\n184\n62,174,307\n163,174,176,309\n19,21,35,41,56,91,94,150,166\n6,12,24,50,71,87,158\n264,267,271,282,312\n274,276\n42,67,314,337,358\n31,61,315,357,359\n171,279\n185,255,274\n3,318,333,346\n122,141,143,149\n110,128,149,193,209\n12,69,314,326,330,335,348,355\n313,325,355\n79,107,287\n109,113,119,127,149,168\n104,106,116,119,122,144\n178,191,223,239,244,250,266,284\n204,251,281,284\n51,307,325,342\n19,322,340,344,352\n297,315,334\n44,276,304,320,337,353\n0,7,63,93,129,131,157,160,180\n0,24,39,87,132,180\n2,39\n41,64,115,132,138,147,153,171\n90\n90\n66,72,90\n91\n64,179\n180\n52\n50,66,70,90\n76,78\n168\n30,54\n38,58\n62,80,83,87,90\n4\n0,11,36\n0,42,82\n0,14,39,41,45,56,90\n53,90\n5,56,92,104,109,138\n55,73,109,126,133\n34,36,69,82,85,89,102,107,230\n24,40,51,54,56,71,86,125,226,243\n124,139,168,195,222,225,243\n165,183,202,225\n45,62\n7,57,70,72,74,90\n21,359\n23\n7,55,304,351\n60,175,309,319\n62,172,191,312,319\n12\n62,177,180\n61,63,170,180\n180\n180\n52\n54\n54\n69,169\n71,97,169\n66,180\n49\n47\n73\n61,90\n67,69,73,78,80,86\n24,42\n44,98,123\n71,73,90\n90\n60,73\n82,90\n55,58,90\n90\n90\n43,49,60,71,78,83,89,95,104,130,161\n80,83,87,90\n53,90\n0,29,43,90\n0,148,180\n66,180\n52,180\n56,299\n62,297\n184\n12,15,57,60,302\n59,180\n180\n180\n12,54\n59,180\n45\n0,132,137,148,151,161,168,172,176,180\n0,139,159,180\n0\n0,175,180\n0,4,6,12,180\n0,20,22,24,137,142,156,171,180\n0,14,17,33\n0\n2,18,36\n0,136\n180\n180\n180\n1\n89\n92\n0\n0\n46,65,90\n90,98,101,256,264,273\n8,180\n0,179\n17,22,38,55,84\n59,89\n84,88\n0\n0,18\n0\n0,36,69\n4,19,166,188\n5,188\n0,26,32,36,117,180\n21,64,90\n89\n0,19,54\n0,7,72,87,90\n21,29,37,60,70\n52,180\n153,174,180\n0\n313,336\n311\n0,8,13,23,34,42,44,67,73,81,96,99,120,146,151,153\n0,4,8,25,37,46,69\n0\n12,18,24,89,121,152\n1,8,41,69,72,85,111,140,151,174\n70,89\n23,50,81,121,124\n32,60,75,77,83,94,120\n164,181,208\n0,28,311\n359\n0,46,318\n0,52,54,90\n72,89\n0,60,62,90\n90\n25,50,90\n74,92\n88\n77,79,89,96,101,126\n65,96,120\n146,171,178\n1,181\n3,160,163,179\n0,180\n90\n0\n0,22,93,180\n0\n0,35\n0\n0,19,33,51,134,148,180\n53,74,117,123,140\n2,179\n207\n60\n31,33,65,75,94,100,107,276,305,333\n0,17,35,58,61,65,68,71,88,165,212,269,308,316,325,344\n38,53,79\n0\n0\n178\n0\n180\n0,11,151\n0\n0,35,60,65,68\n0,14,18,22,26,84,90\n0,7,19,33\n26,52,288,292,301,319,333\n67\n67\n30,57,88\n0,8,16,24,53,106\n0\n0,128,134\n0,2,6,10,13,76,99,112,159\n89,160,180\n1,33,38\n0,17,102,110,113,175\n0\n0,42,152,180\n8,35,56,90\n8\n0,180\n0,24,78,84,99,102,105,117,134,173\n6,59,63,79,116,136\n5,39,41,48,65,72,85,111,125\n111,233,258,270,288\n0\n73,76,105\n99,102,142\n57,77,139,172,179\n32,40,44,49,57,79,165\n90\n88\n151\n30,52,70\n91,93\n70,88,90\n93,115,138\n43\n121,130,152\n148\n114,133,140,143,171\n0,10,180\n0,3,17,29,172\n1,27\n108,125,134,136,150,183,288\n111,131,142,149,156,158,165,168\n77,98,121,145,283\n106,136,148\n103,138,152,186,283\n95,114,140,149,159\n98,126,143,188\n98,101,111,134,154,171\n0,24,26,41,48,67,126,165\n22,46,81,178\n0,24,30,32\n90\n85\n180\n0,3,16\n18\n2,180\n12,27,174\n2,54,65,95,121,163,180\n6,28,46,63,88,91,117,136,162,180\n0,8,10,19,107,109,137,165\n0,18,42,62,76\n90\n0,18,36,40,90\n54,74,89\n69,107,110\n47,68,106,109\n11,42,104,153,180\n0,21,180\n99,103,128,290,333\n175,355\n179,352\n56,66,180\n52,62,180\n17,21,50,57,59,73,129,159,179\n26,46,78,102,109,122,124,146,166\n52,81,170\n54,168,302\n45,63,151,170,180\n63,180\n174,177,180\n11,14,27,52,66,74,77,108,124,157,171\n42,51,63,172,180\n65,183,308,310\n49,66,172,177,183,289,297,300,316\n51,76,78,90\n82,88,90\n2,45,47\n110\n80,90\n21,35\n0,29,31,46,56,71\n33,135,175\n24,151,176,180\n61,64,180\n43,57,75\n60,180\n29,47,63,118,143,159\n54,56,174,180\n1,46,62,92,115,149,152,156,165,170,180\n0,6,9,14,180\n60,180\n0,180\n0,8,12,39,43,52,73,78,81,93,122,128,142,146,151,177,180\n0,180\n0,28,39,47,49,57,80,110,112,135,151,156,180\n0,43,94,112\n0,180\n2,74,81,93,114\n0,2,8,145,149,176,180\n0,180\n0,180\n0,144,180\n0,20,36,48,81,145,180\n0\n0,28,127,154,179\n10,14,37,62,70,82,85,142,155,180\n0\n0\n9,30,35,86,100,105,140,173,194,216,258\n18,28,79,95,111,121,141,188,195,208,220,258\n29,34,55,59,63,67,71,128,189,198,220\n10,26,29,39,82,182\n281,318,338,357\n133,137,141,148,160,170,208,210\n138,162,185,209\n18,63,132,196,213,228,337,357\n18,51,347,355,358\n0,3\n180\n178\n15,170\n0\n0,163,171,177\n0\n0,163,165\n90,119,177\n75,94,134,145,178\n2,23,180\n0,40,97,158,160,169,171,180\n0\n12,14,17,22,180\n0\n0\n7,12,27,30,62,95,114,125,184,205,208\n22,27,33,54,61,71,93,127,185,188,212\n25,331,338,344,354,358\n18,243,265,317,352\n117,147,171,198\n16,30,32,89,190,194\n15,28,30,33,185,195,197\n0,180\n75,176\n177\n35,67,78,85,157\n54,178\n0,10,20\n0\n3,7,12,17,176,180\n0,153,180\n180\n0,180\n172\n1,7,9,15,170,180\n0,3,29,53,74\n0\n0,38,180\n0\n0,2,180\n7,155,174,178,180\n13,31,171,198,214\n2,5,17,198,356\n0\n0,33,145,165,180\n0,61,90\n0,16,38,68,86,99,131,180\n0,2,23,179\n0,23,30,180\n0,180\n0,13,141,163,179\n0,179\n0,44,47,50,59,76,85,92,127,133,143,146,180\n0,23,26,60,65,80,140,151,163,180\n100,126,158,279,288,301,319,335,339,344,353\n104,130,132,138,141,147,316,338,341,348,352\n0,180\n164,180\n1,21,145,190\n7,144,172,204,351\n20,23,353,358\n0,174,180\n1,58,77,88,96,132,145,153,177,180\n0,6,173,180\n0,180\n0,180\n1,21,171,178,180\n0,43,141,171\n17,28,158,206,338\n7,23,30,104,135,137,150,185,187,192,194,213,325,329\n0\n5,51,61,182,317,341\n4,8,12,54,58,179,298,318,342,345\n33,64,105,184,289,328\n3,25,38,44,70,315\n0,61,180\n52,68,86\n90,93\n61,84,115\n80\n78\n92,118\n78,97\n0,166,174\n0,20\n90\n90\n83,99,105,139,180\n0,3,120\n0,13,18,38,66\n0,15\n64,81,94\n87,122\n64\n66\n62,78\n51,70,72\n63\n68,180\n82,150,180\n55\n58,180\n75,87,106\n197,210,213,227,234,271\n207,268,283,290\n1,180\n68\n73\n150,179\n0\n144,150,156,160,168,173,177,180\n105,111,119,125,127,129,138,174,180\n0\n4,180\n0\n0\n0\n15,130,132,156,174,178\n97,117,119\n154,178\n150,173,176\n0\n0\n0\n180\n17,19,41,58,70,78,83,86,92,108,114,123,139,169\n12,65,70,154\n0\n0\n0,180\n0,180\n1,36\n0\n0\n1,176,180\n0,2,18,154,156,163,180\n1,16\n26,32,35,40,118\n0\n0\n12,22,25,119,140,178,212,221\n10,18,25,52,58,98,113,115,133\n15,19,21,23,32,98,100,102,112\n0,120,124,141,144,180\n0,177\n0,180\n0,180\n0,180\n0,45,125,180\n43,103,190,213,218,264\n286\n64,183,293\n69,186,292\n181\n181\n53,303\n48,64,282,304,330\n69,72,174\n75,175\n59,170,299\n69,161\n71,172\n60,180,304\n58,181,307\n65,84,174,303,320,324\n184\n177,191\n189,192,297\n181,200,267,297\n42,48,66,176\n67,170\n63,65,82,174,189,307\n63\n59,63,66,76,185,302\n59,291,301\n72,180,204,207\n70,180,192\n35,40,57,311\n54,68,75,83,186,189,202,204,206,208,229,247,294,298,303\n64,67,69,176,178,209,272,279,287,297,308\n0\n0,2,137,144,147,174,179\n0\n1\n0\n180\n166\n180\n0,180\n0,139,149,178\n0\n0\n180\n179\n3,7,172\n0,9,38\n3\n0\n180\n0,31\n85,129,147,180\n3\n180\n159,180\n0,154,174,180\n0\n180\n0,17\n180\n0,180\n0,24,50,52\n0,25\n180\n152,171,180\n23\n180\n0,3,6\n3,7,75\n180\n17,51,53,58,62,84,88,97\n18,58\n70,90,94,103,112,152,155\n66,244\n11,26,41,47,63,89,110,113,122,226,246,274\n48,68,82,85,98,269,318\n62,87\n55,59,61,63,66,87,93\n83,89,92,102,129,146\n16,347,355\n10,15,19,348\n58,183,306\n69,179,304\n295\n64,177\n64,161,176\n196,291,294,298,302\n189,203,297\n0,26,90\n0,41,57,63,79,84,124,126,180\n6,13,49,83,89\n0\n180\n0,33,40,44,53,79,88,112,129,180\n0,46,102,135\n0\n0,29\n180\n180\n180\n1,70,73,96,111,116\n0,21,25,28,110,124,129,134\n137,160,180\n129,180\n2,7,162,165,180\n0,6,180\n4,7,42,54,75,80,93,128,134,180\n0\n180\n145,180\n178,180\n82,92,108,124,149,179\n0,49\n90,118,120,144,151,166\n256,291,323,325\n294,304,308,310,328\n7,29,42,46,51,54,88,344\n5,14,29,58,85\n112,152,198,218,253\n111,121,154,178,201,222,255\n144,163,199,254\n26,153,259,270,322,341,348\n261,315,333\n144,147,195,213\n147,165,195,198,231,272\n0\n0,28,33,118,140\n180\n0\n0,124,130,144,152,154,162,180\n4,61,71,75,78\n0\n0\n1,160,180\n31,55,62,70,101,165,180\n23,28,40,60,164,166\n3,23,41,51,86,109,124,127\n6,10,12,25,60,73,79,95,121,157\n52,92,241,251,262,300,339,345,354\n47,73,101,122\n69,90,93\n1,19,36,58,64\n0\n7,13,55,117,120,141,160\n22,168\n26,43,137,178\n39,222\n36,213\n209\n208,230\n180\n145,180\n0,3,63,170\n27,54,60,64\n64,179\n65,140,169\n65,156,171\n186,209,303\n54,56,180,296\n62,187,299\n62,180\n56\n62,90,188,280,284,293,314\n64,170\n65,173\n33,62,180\n41,49,62,65,79\n249,288,290\n197,199,271,292\n199,286\n286\n214,250,260\n204,222,253,266\n0\n7,36\n33\n65,77,90\n56,64,171\n63,80\n62,137\n22\n22,32,61\n38,46,50,306\n173,296\n60,68,75,312\n64\n60,63,78\n2,174\n176,186,357\n180\n180\n0,22\n16,34,52,229\n90\n35,57,66,70,72\n54,56,180\n0,134,137,152,156,167\n10,35\n359\n0\n16\n22,24,26,36,46,56,61,67\n12,178\n22,43,61\n26,57\n1,157\n0,44\n0,8,15,137,153\n0,18,21\n1,5\n12\n13,41\n62,83\n217,239,266,269,277,279,298,312\n0\n0,180\n0,18,42,47,49,73,137,162,179\n0\n0\n0,6,33,45,48,100,102,108,155,158\n153,170,172,180\n180\n0,13,173\n15,49,58,61,96,103\n0\n0\n46,169,191,193,205\n174,179\n24,60,83,180\n180\n42,62,65\n0\n0\n61,297,317,320\n59,65,305\n12,42,44\n0,16,18,20,46\n35,58,60,72,93,154,160,167\n37\n0\n0,3,18,26\n0,83,112,180\n15,166\n0,180\n9,12,18,28,34,193,358\n61,65,97,170,180\n49,76,80\n53,80,82,98,167,180\n51\n35\n66,77\n49,57,80\n14,31,44,62,71,81\n43,70,184,304,308,317\n45,66,138,181,310,339\n75,98,100,154,168\n76,105,163\n18,40,66,309,354\n20,44,60,189,292,311,329\n3,8,17,29,36,47,179\n38,48,180\n54,66,68,180\n68,172,175\n70,131,180\n0,5,9,46\n28,38,47,64,153,184,190,201,318\n26,41,44,47,60,153,172,195,206,210,213,318\n60,180\n0,6,152,155,180\n149,180\n9,13,27,42,90,125,127,167,174,176,180\n0,43,180\n180\n121,151,180\n67,93,124,126,141,158\n141,180\n33\n12,33\n0\n0,180\n16,150,180\n0,24,32,159,163,180\n137,180\n36,95,98,118,233\n2\n0\n6\n0,40,59\n155,180\n0\n152,180\n0\n75,79,88,90\n0\n0,14,24,56\n0\n0,30,80,83,90\n1,38\n62,71,78,114,138,160\n85,101,120\n82,84,102,118\n91,93,96,98,101,114,268,296,299\n113,238,243,249,267,279,294,300\n75,91,93,101,109,133,140,147,283,288,300\n86,99,112,153,160,291,311\n91,134,275,303\n87,117,249,274,284,305\n0\n0,19,42,61,80\n0,22\n6,16\n33\n0,2\n10\n0,180\n33,48,67,128,180\n0,180\n0,26,40,154,180\n0,180\n0\n49,76,107,180\n134,154\n75,180\n0,16,156,163,180\n0,180\n0,19,142,163,172,180\n0,180\n0,161,180\n180\n0,144,149,151,157,180\n180\n50,55,62,70,167,180\n58,75,173\n49\n0,9,23,45\n49,67,179\n48,164\n0,6,50\n60,66,161,168,180\n0\n0,123,180\n1,31,56,88\n0,27\n0,40,124,180\n3,63\n147,180\n180\n0,7\n0\n0,45,57,180\n0,50,72,180\n29,41,143,180\n180\n0,7,58,131,149,180\n180\n160,173,180\n180\n152,179\n157,162,180\n179\n180\n124,163,180\n0,30,34\n0,36\n0\n0\n0\n0,29\n0\n0,33\n46,135,162,180\n0,3,27,51,180\n68,109,143,165,172,176,180\n180\n180\n0,24\n0,32\n179\n0,13,52,180\n177,180\n0,2,39,44,48,148,176\n0,33,43\n0,41,61,120,136\n54,180\n53\n0,52\n0,23,34\n180\n180\n125,129,147,180\n0,55,179\n170\n54\n158,162,180\n157,180\n53,56,128,180\n72,164,318\n73,127,148,169,276,311\n51,58,75,79,96,151,181,342\n63,96,135\n278,301\n300\n312\n312\n258,303,312,343\n276,298\n177,235,289\n177,229,287\n188,204,217,219,289\n187,215,219,293\n179,212,232,272\n177,197,199,230,273,288,290\n55,308\n55,307\n2,26,51,57,324\n21,52,311,323\n5,54,83,315,319\n11,55,90,311,331,350\n52,310\n55,311\n25,46,57,322,336\n58,78\n56,94,308\n3,60,316\n61,322\n1,10,14,18,61\n5,55,323,349,354\n52,55,72,164,178\n61,71,73,146,177,313\n314\n191,292,297,303\n168,190,282,299\n17,19,48,284,312,315\n48,81,283,302,319,358\n34,45\n45,323\n31,46,323\n68,172,284,289,293,299\n65,97,99,173,293,296\n64,66,79,158,180\n299\n298\n297,344\n155,190,287\n158,180,215,285\n184,202,278\n54,312\n55,308\n47,59,315,343\n54,316,350\n64,176\n63,174\n163,290,305,307\n49,313\n47,313\n67,149,170,180,183\n69,155,161,169,171\n174,178,231,282\n145,180,228,286,288,298\n176,232\n176,229,231\n47,310\n49,310\n40,48,314\n45,47\n0,28,107\n15,59,93\n0,61,95,97,103\n0,51,96\n99,143\n64,86,122\n0,15,42,65\n20\n0,18,46,52,60\n14,66\n18,37,64\n12,32,55\n126,167,180\n93,127,159,169,172,178\n129\n125,155,173,178,180\n128,158\n125,152,178,180\n98,129,151,180\n123,143,146,150\n0,26,64,75,94,113,143\n41,51,57,97,144\n1,37\n0,103,147\n98,113\n21,45,68\n22\n13,33,43,51,67\n29,32\n98,122,143,157,167,180\n23,67,85,88,116,120,129\n0,20,61,63,103,125,180\n0,23,25,31,108\n25,74,77,82\n78,107,130,137,180\n87\n18\n19\n15,45\n14,57,59\n128,156\n162\n130,163,180\n1,15,21,51,67,103,112\n65,68,71,74,76,93,117,145\n0,119\n0,16,52,89,118\n0,177\n180\n180\n0,100,122,128,137\n7,37\n9,120,339\n117,334,355\n80,107\n92,111,124,126,146,179\n283,303\n285,303\n305\n289,304\n15,49,65,298,328,347\n19,50,68,296,328,348\n6,13,34,66,315,333,349,355,357\n1,6,17,66,317,327\n23,42,334,351\n2,14,16,28,36,45,49,326,353\n18,41,49,69,347\n18,47,342\n3,18,68,332\n1,10,12,30,37,341,354\n342\n183,202,216,248,278,280\n180,208,229,231,251,253,257,289\n218,221,252\n179,209,241,259\n117,225,353\n121,219,347,355,357\n114,140\n107,109,128,146\n302\n302\n0,2,17,36,40,46,337,347,351\n17,48,54,330,334,350\n16,43,48,333,346\n15,23,46,338\n9,116\n116\n162,194,244,262\n182,219,225,233,239,248,263\n328,343,349,358\n328,353\n0,90\n90\n0,96\n0,83\n90\n0,90\n14,30,66\n0,17,69\n111,163\n112,149,180\n0,11,29,42,82,90\n0,16,58,89\n62,90\n0,44,66\n113,131,136,148,180\n0\n180\n0,40,180\n79,97,263,281\n1\n0,180\n40,45,64\n15,38,170\n18,39,61,79,90\n1,41,76,90\n3,11,41,65,85,100\n42,49,79\n142\n86,103\n107\n17,43,62,127\n84,90\n0,58,93,134\n0,59,72,77,180\n138,165,176,180\n0,23,30,33,56,59,86,97\n138,180\n0,3,6,30,72,104,120,144,180\n1,26,50,99\n36,76,106\n15,74,90,92,137\n126,149,157,171\n63,302\n63,305\n60\n61\n0,89\n0,3,20,77,90\n0,4,27,29,90\n62,90\n29,47\n34,90\n63,90\n0,11,80\n11,13,42,46,52,101\n90\n42,81,90\n87\n106,143\n24,44,55,57\n0,21,102\n57,180\n17,20,25,40\n15,61,299\n44,63,295,349\n180\n180\n0,27,29,37,178,180\n0,180\n0\n0\n71,190,297\n189,297\n70,185,271,289\n59,292\n48,71,269,295,312\n71,178,200\n73,142,179,201\n71,151,184\n67,150,155,161,177\n75,142,181\n78,144,180\n182,198,293,299\n54,300\n64,66,308\n165\n34,41,61,68,78,83,102,128,130,158,180\n0,22,28,55,60,82,84,97\n136,166\n0,3,15,29,53,76,78,80,88,90\n0,63,65,90\n0,45,56,58,86,113\n9,77\n0,90\n0,76,81,84\n10,26,28,36,40\n120,151,180\n128,157\n1,9,33,53,61,90\n0,47,79,105,126\n62,79,90\n0,40,65\n118,147,180\n0,26,118,165\n15,90,103,110,123,135,156,179\n0,24,39\n37\n19,133,156,165\n4,46\n0,26,34,42\n0,81,111,125,154\n26,45,48,109,127,165,178\n1,33\n143,180\n126,153\n0,96\n96,109,159,166,180\n106\n123,147\n94,106\n88,91,95,106,111\n46,72,174\n0,32,51,180\n41,49,60,310\n16,50,52,83,311\n63,73,148,168,181,246,293\n54,62,73,80,82,145,166,177,300\n292\n37,53,308\n26,56\n67,82,86,94,98,125,128,144\n23,47,58,60,317,337,343\n72,140,159,179,286,306\n62,155,160,304\n12,24,27,31,58,76,327\n17,38,76,318\n0,41,87\n0,34,43,53,77,92,94,101\n37,64,68\n0,15,27\n85,89\n23,43,75,99\n80,89\n16,100,173\n0,49,51,57,66,68,90\n2,97\n2,52,90\n12,42,90\n0,66,87,102\n68,90\n118,138,157,161,170\n103,125,155,158,180\n103,133,135,138,155,158,180\n65,97,109,112,114\n0,20,41,63,180\n90\n58,90\n90\n52\n97,133,159,187,190,287\n75,168,191,287\n68,133,180\n72,74,181\n67,77,99\n52,61,180\n47,49,69,77,85\n97,110\n0,19,29,84,90\n97\n52,180\n152,180\n158,181,188,193,273,295\n65,297\n71,179\n69,178\n70,72,158,185\n79,166,186,188,190\n5,220,245\n302\n300\n70,178\n69,89,177\n54,180\n69,178\n70,109,112,138,185\n90\n97\n90\n100,120\n114\n70,189,297\n66,191,220,292\n69,177,207\n69,177\n78,82,180\n68,70,183\n70,122,186\n63,89\n27,77,80,101\n90\n0,52,60,88\n90\n13,65\n65\n41,60\n58,92,190,205,227,242,292\n60,292\n60,290\n56,100,289,316\n179\n179\n77,183\n182\n193,285\n88\n71,90\n0,25,33,36,53,180\n48\n35,56\n34,57,168\n51\n76,81,91,110,182,303\n87,113,181,306\n180\n52,87,150,174\n180\n247,293,311,313,315\n249,293\n292\n289\n0,55,300\n8,11,55,302\n55\n6,55\n0,16,61,111,119,125\n58,79,165,180\n44,58,73,90\n21,94,97\n29,42,45,48,82\n2,14,30,35,78,87,102,105\n31,68,76,90\n90\n0,86\n180\n180\n185\n185\n59\n291\n290\n246,293\n248,295\n292\n292\n42,55\n0,5\n0,138,155,180\n0\n138,140,142,145,154,156,173\n0\n63,186,294\n65,184,293\n69,293\n67,190,210,291\n59,96\n57,80,300,333\n60,300\n69,175\n68,176\n66,162,177,180,187,191,292\n70,161,180\n55,66,80,82,180\n0\n0\n0\n0\n180\n167\n180\n177\n0\n0\n180\n180\n0\n0\n180\n168\n0\n180\n0,180\n0,180\n180\n180\n0,80,127,133,138,180\n8,39,46,49,68,78,120,146\n113,141,169,172\n120,137,169,176,178,180\n1,67,89,91,94,108,145,155,157,167,180\n57,180\n180\n35,45,58,307\n29,59,305\n56,312\n27,57,304,323\n180\n45,65,296\n0,180\n0,27,32,58\n180\n0,22,26,65\n70,106,157,161,299\n70,146,149,301\n63,65,87,91,93,122,169\n70,93,95,121,132\n63,65,81,108,143\n96,114,144\n256,298\n262,300,305,332\n60,90\n60,92\n61\n59\n178,296\n178,299\n179,198,201,247,291\n181,211,237,253,296\n180,264\n71,73,119,127,129,132,136,143,146,299\n69,133,154,298\n63\n63\n283\n40,59,63,73,76,88,97,101,139,308\n55,75,124\n151,188,196,199,202,219,271,278,280,317\n193,217,252,257,286\n0,180\n0,23,180\n0,55,96,120,137,144,180\n0,5,13,15,25,45,49,53,79,104,143\n14,37,53,88,108,110,121,136,171,180\n0\n1\n0\n0\n358\n0\n46,310\n71,87,101,124,151,223,245,263,270\n0,10,13,20,27,54,306,333,340,347,350\n78,97,263,282\n71,85,98\n34,51,76,94\n44,60,88,137\n0,176\n0\n0,23,173,178,330\n0\n182\n46,53,67,174,304\n180\n136,145,171,177,181,224\n0\n0\n0,16\n0,64,94,121,141,152,155,157,162,166,171\n0,9,40,171,180\n92,115,128\n183,358\n19,34,47,307,311,315,329,354\n7,11,14,355\n173,180\n10,29,158,180\n0\n0,180\n0,27,31\n0,180\n0,180\n180\n6,180\n0,180\n0,180\n1,15,73,81,93,95,101,111,131\n4,132,149,333,339,346\n0,110,135,145,265,356\n0,43,64,83\n0,36,58,92,109\n90\n0,17,36,71\n111,142,163\n26,97,112,136,143\n0,122\n3,8,25,28,102,113,123,141\n0,13,32\n137,139\n113,130,180\n123,127,149,169\n66,90,115,118,124,127,140\n0,34,79,100\n89,120,124,128\n93,123,136\n110,126,153\n57,180\n49,52,61,63,180\n35,44,56,172,174\n180\n159\n55,180\n65,175,292,303,308\n67,172,295,306\n62,187,331\n56,305,330\n54,303\n56,314,317\n56,293,310\n177,299\n172,196,275,293\n37,62,66,169,302\n61,176,299\n57,307\n57,305\n0,170\n0,102\n0,32,55,180\n0,5,13\n180\n180\n180\n173\n0,36\n0,178,180\n180\n180\n0,73,88,97,100,104,112,123,127,130\n5,9,41,47,51,84,113\n0,20,47,51,57,69,100\n134,151,180\n128,151,180\n131,179\n94,124,163,173,179\n0,19,22,52,55,108,121,146,149,151\n0,50,104\n0,85,97,105\n106,153\n150\n3,116\n0\n0\n0,115\n180\n180\n180\n180\n0,180\n0,179\n215,241,260,262\n193,213,234,244\n4,117,135,202,240\n2,101,130,164,197,205,235\n12,205,228,237,239,353\n1,211,218,220,223,242,342\n31,54,80\n31,57\n31,56\n94,108,112,114,135,177,179,182\n74,77,107,122,128,138,176\n102,141\n108,144,147,150\n81,105,139,164\n93,110,113,140\n101,111,114,144\n89,108,123,144,167\n60,185,297\n62,187,222,297\n41,47,53,72,171,184,190,203,213,221,229,240,284,305\n43,60,66,69,183,191,200,281,296,304\n47,56,60,184,202,258,268,295\n40,195,205,228,258,294\n227,274,280,286\n25,28,57,91\n20,23,58\n60\n62,88\n57\n64\n53,304\n52,304\n301\n1,10,34,60,304,330\n49,279,308\n278,306,326\n67,132,149,176\n69,177\n73,123,176,202\n72,124,128,149,176\n67,117,181\n44,66,108,180\n96,112\n74,100,121,144,154,169,178,181\n46,73,164,184\n64,81,183,297\n67,188,296,340\n48\n47\n52,307\n53,307\n49,74,87,91,153,170,196\n74,95,139,167,170,193\n38,72,168\n62,182,274,297\n60,182,297\n304\n50,305\n305\n50,304,352\n71,73,171\n50,72,176,200\n77,149,172\n63,180,285,298\n0,5,42,76,99,134,180\n23,61,70,101,180\n45\n164,180\n159,180\n159,180\n164\n64,68,180\n47,49,65,72,105,180\n66,75,88,100,103,161,170,175,180\n165,178\n158\n0\n0\n90\n0,18,22,28,90\n0,8,11,28,30,36,57,69,77,85\n90\n0,18\n0,20\n180\n112,162\n0,33,37,77,85,90\n0,105\n90\n0,30\n114,143,180\n0,119\n0\n0,41,43,116,180\n180\n0,4,7,27,47,67,94,121,157,159\n0\n0\n15\n0\n1,17\n13\n0,5\n162,173,180\n138,167,172\n107,149,180\n0,50,53,103\n16,25,89,112,115,136,146,153,157,179\n0\n0,27,66\n0\n11,78\n157,176,180\n1,6,92,123,127,171\n0,32,111,131,134\n0\n0\n0,18\n180\n180\n107,110,135\n0\n0\n0\n142,176\n14,83,87,113,124,147,169,180\n0,14,25\n122,165\n166\n0\n180\n0,37\n14,28,49\n1,21\n1,8,21,43,46,52\n180\n180\n42\n9,45\n0,5,22,46,49\n85,129,177\n84,105,112,116,148\n78,111,151,172\n95,140,176\n102,135\n265,271,278,298,320,324\n312\n62,304\n61,303,326\n15,23,33,62,308\n19,27,43,62,92,318,321,344\n59\n35,39,58,350,353\n133,174,176,185,218,233,289\n151,153,172,178,239,278,282,284,287\n138,176,261\n133,152,172,187,192,276\n79,108,116,162,296\n72,79,88,91,116,164,297\n27,63,103,305,329,350\n29,61,305,343\n56\n58,105\n159,186,196,226,260,267,281\n152,190,193,258,279\n75,101,126,133,139,155\n70,93,103,143,152,159\n150,171,194,263,288\n182,271\n49,308,323,326\n52,92,322\n48,80,314,317\n47,75,84,86,315\n46,320\n186,247,289,292\n175,192,198,252,270,289\n72,78,93,159\n76,78,141,163\n51,315\n16,25,52,314,325\n181,277,281,284,288,290\n176,192,279\n180\n0,154\n357\n0,10,13,15,29,32,36,67,116,129,132,153\n48,310\n0,180\n0\n16,20,27,37,40,54,56,70,103,105,115,128\n23,42,64,80,83,90\n0,5,33,63,90\n131,155\n47,54,90\n2,5,23\n180\n117,156,167,173,180\n0,24\n0,20\n0\n0,10,20\n22,33,38,335\n76,92,111\n0\n60,77,148,180\n93,135\n187,296\n71,181,294\n67,169,186,296\n289,291\n53,188,211,214,302\n180\n169,180\n1,14,180\n67,186\n65,152,183\n62,76,96,115,171\n77,80,88\n33,80\n84\n156\n68,81,83,85,93,116\n67,92,103,111,131,157\n25\n77,80,103\n0,2,9,11,19,21\n97,102,111,130,150\n296\n296\n49,172\n50,173\n46,190,291\n48,188,289,291\n49,185,291\n42,160,183,292\n40,289,309\n34\n0,18,37,55,61,63,68,90\n11,14,31,34,58,79,164,177,180\n75\n0,12,18,23,25\n147,172,176,180\n22,36,48,61,76,78,80,95,169\n59,95,109,126,144,148,172\n0\n50,61,68,92,104\n54,103,127,133,136,139,149,154,156\n45,85,355\n81,103,126,147,160\n89,109,132,151\n21,36,40,59,86,90\n0,8,13,22,43,54,69,73,75,93,95,134,143\n62,64,89\n15,20,39,48,90\n0,5,9,12,18,40,59,68,72,96\n51,90\n72\n12,43,73\n105,160,180\n109,142,170,180\n57,59,63,94,119\n0,10,40\n0,35\n40,59,312\n43,61,311\n20,29,41,54,91,325,344,358\n177\n0,3,6,10,30,44\n0,92\n0,33,95\n47,58,295\n62,181,280,299\n58,70,225\n61,171,190\n0\n0\n1\n0\n0,180\n0\n1\n55,59,297,311\n80,112,118\n64,74,290\n79,99,102,296\n0\n0\n63,189,294\n63,185,295\n186,293\n0\n351\n12,29,67\n116,160\n12\n0,16\n65,90\n0,180\n0\n0\n180\n141,170,180\n0\n180\n0,123,179\n359\n358\n85\n67,69,87\n1\n56,167\n54,66,166\n28,48,139,163,172,180\n180\n0,4,7,39,61,64,81,129,147,149,157,170,178,180\n47,49,58,63,328\n60,318,324,332\n0,180\n0,59\n0,180\n0\n0,180\n0\n0,43,146,180\n0,180\n0\n0,180\n1,180\n0\n0,180\n13,19,31,33,38,61,79,109,129,155,160,168,174,180\n0,13,180\n0,17,101,119,136\n158,160,162,180\n64,189,294,304\n69,183,304\n54,304\n54,303,327\n43,61,78,164,178\n62,72,78,163,185\n51,306\n46,50,306\n0,2,8,18,47,67,83,95,125,160,165,168,170,174,180\n0,33,56,88,110\n49,54,56,63,66,93,103,121,138,157,177\n68,108,128,174,180\n64,92,102,133,155,157,180\n59,90,101,110,116\n9,24,62\n118,167,170,180\n49,52,180\n90\n104,135,171,177,180\n180\n180\n90\n26,37,53\n73,99,110\n33,36,40,58\n41,54,56,81,84,90\n0,20,54,75,81,94,112\n106,145,168\n61,281,306\n60,282,305\n62,306\n61,305\n290,310\n291,310\n59,306,333\n0\n0\n0\n0,180\n0\n157,178,180\n180\n0,56,58,180\n0\n126,180\n0,180\n0\n0\n179\n0,2,177,179\n0\n167,172,177,180\n0,44\n0,63,69,180\n0\n0,24\n0\n0,10,17,32,66,163,165,180\n11,26\n0,56,150,179\n0,21,24,123,135,180\n152,156,180\n0,18,136\n0,19,54,67,69,72,74,90\n0\n180\n0,169\n0,45,87,105\n121,148,164,166\n102,108\n0,13,99,116\n9,30,44,79,98,128,137,146,156,180\n0,41,43,78,83,107,109\n0,33,35,37,52,81,84,92,130,180\n10,59,68,91,95,101,107,110\n13,57\n180\n59,304\n58,304\n0,47\n4,19,29,180\n0,4,27,50,55,77\n0,38,57\n0,38,78\n0,180\n0,21,28,36\n0\n0,33,35,38\n0,3,9,36,38,63,66,90\n0,27,45\n151,180\n90\n69,90\n0,155,180\n70,89\n27,59\n62,83\n74,91,97,117\n75,77,79,96\n89\n75,97\n0,54,76,82\n79,92,100,119,150,180\n40,52,72,83,101,127\n68,83,106,120,155\n71,83,88,119,122,139,173,180\n85,97,113,118\n2,7,9,18,22,89,95\n110,125,155,159,161,164,167\n44,81,111,117,142,146,159,180\n39,54,91,129\n193,205,262,270,290,296\n191,289,291\n70,181,202\n62,151,180\n182,195,300\n185,191,195,296\n0\n0,47,115,180\n0,31,57,81,90\n0,3,35,53,55\n17,45,55,128\n50,57\n0,180\n180\n4,180\n0\n0\n0,28,52,90\n180\n0\n0,180\n0\n0\n0,21,145,163,166,180\n0,27,34,70,129,134\n0\n180\n7\n8\n128,132,180\n180\n180\n162,179\n142,158,170\n9\n180\n180\n180\n180\n0,18,21,52,59,65,154\n0\n180\n180\n67,90,93,138,172,180\n0,49,129,151,170,180\n91,180\n0,22\n163,165,180\n119,167\n79,104,108,111,125,130,134,292\n64,92,119,150\n293\n40,59,84\n46,317,327\n29,48,322,336,339\n62,124,157,176,211\n54,317,345\n52,315\n53,304,340\n70,98,104,137,155\n0\n180\n1\n0\n1,33,55,64,67\n36,67,71,180\n0,180\n76,194,283,298\n188,299\n19,38,54,61,126,144,159,163\n180\n13,34,39,62,95,119,159,170\n180\n163,180\n0\n0,19\n0,180\n153,180\n0,180\n180\n180\n0,46,68,89,92,107,137,140,152,180\n44,62,125,130,136\n0,7,61,64,84,99,116,146,162,180\n82,87,115\n68,305\n180\n180\n0\n0,162,180\n173,182,188\n0,180\n0,3\n18,87,100,106,142\n0,4,7,10,13,16,74,77,82,84,90,98,109,115,132\n105,165,200\n100,170,201\n16\n0,5,169,180\n0,5,9,14,165,168,170,176,178\n180\n0\n21,27,30,53,65\n1,59\n180\n0,120,180\n0,180\n180\n0,180\n145,180\n1,154,180\n0,162,180\n180\n1,180\n163,180\n0,173,180\n0,180\n0,178\n180\n69,91,121,163\n0,2,5,24\n170\n0,156,180\n23,148,180\n89,91\n0,16,149,175\n0\n0,90\n0\n0,26\n136,164,166,176\n0,40,87,90,147,180\n0,35,65,68,89,92\n125,127,155,180\n75,94,103,109,112\n173\n180\n0,91,116\n180\n42,51,53,58,136,143\n0,180\n11,22,30,160\n21,27,33,36,73,90\n0,55\n17,27,38,46,68,90\n0,2,55,65,75\n0,10,20,164,180\n3,180\n0,180\n0,96,180\n0,14,177,180\n0,4,175,179\n0,180\n0,180\n0,180\n0\n180\n0,180\n180\n180\n0,44,109,114,154,174\n111,144,162,164,180\n5,59,62,67,97\n180\n0,180\n0\n180\n145,152,166,168\n0,180\n142,180\n0,17,180\n0\n0,176,180\n59,93\n56,100,102,150,180\n0,99,134\n110,116,123,158,162,169,178\n0\n0\n0\n0\n0,12,15,40,180\n180\n0\n0,16,54\n180\n180\n0\n180\n0,31\n0,8,25,45,131,161,163,167,180\n0,180\n0,23,35,68,88,109\n0,8,24\n0\n0,180\n0,25,41\n0\n2,10,25,143\n0\n165,180\n180\n0,31,180\n0,180\n0,180\n0,180\n0,180\n13,82,108,110,115,119,126,141,144\n55,90\n3,52,73,111,139\n37,88\n13,59\n120,165\n135,156,160\n0,6,57,96,104,109,122,128,134,139,149,153\n0,94,115,128,131,138\n11\n0,16,34,66\n126,151\n128,161\n0,119,121\n128,141,164,180\n2,15\n1,10,50\n58,180\n180\n56\n63,170\n14,56,303,320,354\n3,29,55,303\n56,300\n36,57,301\n176,180,192,194,269,271,279,293,323\n179,182,293\n63,176,291,301\n59,178,299\n305\n3,9,15,35,39,54,76,307,336\n54,77,309,322\n176,200,260,288,310\n59,168,287\n62,161\n0,180\n0\n0,156,168,179\n0\n0,180\n0,27,62\n0,21,35,152,180\n6,59,180\n0\n10\n180\n180\n180\n180\n54,63,66,133,169,180\n0,18,34,38,40\n180\n0,97,117\n0,23,35,90,117\n80,109,150\n83,102,127\n19,30,71\n130,178,180\n110,112,119,150\n91,136,152,176\n125,138,141,179\n8,39,63,85,117\n0,7,14,67,89,108\n55,90\n0,11,35,73\n18,47,75\n160\n0,25,38,69,106,120,122,145,148,151,157,161\n0,21,75,78,83,95,105\n169,180\n0,5,10,13,137,151\n9,12\n0,25\n180\n180\n180\n0,151,154,166,180\n0\n180\n19,34,37,48,119,127,144,147,152,155,167,180\n0,180\n0\n131,158,180\n180\n210,216,238,243,256\n124,127,208,233,358\n0,128,130,210,232\n32,55\n30,56,78\n56\n57\n20,345,349\n23,350\n110,115,133,144,156,162,171\n128,133,144,170,175,189\n111,142,159,179\n75,90,108,128,146,160\n1,13,101,114,238,241,245\n62,185,298\n58,188,298\n191,196,198,223,296\n54,70,194,197,213,216,241,298\n188,191,215,226,232,242,287,299\n180,190,197,290,297\n58,82\n59\n38,59\n49,54,60\n5,53,305,347\n6,53,306,340\n55,304,320,322\n51,309,327\n44,304\n45,52,58,303\n70,180\n70,179\n66,104,181\n102,180\n71,114,123,130,178\n66,79,82,171,173,177\n62,184,295\n61,83,188,297\n137,163,166,199,296\n202,221,297,305\n17,47,312\n50,310\n83,171\n88,173\n91,157,179\n53,56,191,297\n57,189,193,269,294\n63\n13,52,281,305\n51,278,306\n50,307\n40,260,310,327\n73,174\n77,173\n53,68,184,294\n68,178,196,300\n49,312\n51,309\n0,16,18,27,31,39,51,75,114,180\n16,18,43,47,54,57,84,99\n0,54,56,91\n80,180\n114,164\n154\n25,59,72,74,142,180\n0,69,76,78,100\n0,50,55,70,75,90,92\n59,73,79,148,154,180\n0,16,19,29,33,62\n19,23,27,37,65\n128,162\n160\n162,180\n156\n29,74,92\n72,108,114,128,135,162,180\n0,56,62,66,87\n50,73,94,96,151,154,180\n75,92,103,170,180\n21,39,41,64\n19,29,49,63\n130,132,137,139,141,167\n134,164\n157\n53,57,59,81,84,86,90,93,95,107,113,119,126,130,168,170,173,175\n0,2,5,9,29,62,78,90\n72,88,91,180\n77,101\n0,37\n0,41\n2,16,44,73,90\n8,58,90\n2,66,119\n90\n6\n0,40\n180\n143,180\n180\n110,135,152,180\n0\n0,42\n0\n0\n0,31,36,92,123\n0,5,16,33,35,73\n0,78\n0,44,90\n2,14,30\n0,12,43,50,53,56,66\n0,17,49\n0,26\n162,180\n117,156,179\n0,31,33\n0,108,146\n47\n0,27,90\n1,29\n0,29\n123,154,180\n0\n0,180\n0,56,59,61,63,73,131,180\n0\n12\n9,11,17,19,21,54\n180\n0,53,80,122,180\n0\n0,39\n0,177,180\n180\n21,27,29,180\n0\n1\n180\n126,141,180\n0,20\n138,175,180\n21,51,75,97,116,139,159,180\n0,18\n35,42,46,62,112,144,163\n19,50,180\n0,4,6,43,47,49\n14,24,34,180\n29\n43,62\n0,6,23,28,33,38,48,179\n0,13,24,40,43,54,76\n41\n19,40\n90,124\n84,89,103,119,126,150\n2,62,295\n30,60,93,293\n1,26,28,40,66,68,325,344,351,356\n20,28,40,67,321,338,340,355\n38,57\n59,61,63,67,70,100,119,173\n67,174\n86,152\n85,90,103,106,132,150\n62,301\n63\n26,46,330,351,353\n26,49,326,332,334\n89,105,127\n71,83,86,90,103,106,115,135\n173,289\n172,190,193\n37,41,45,314\n71,77,84,152,155\n51,303\n29,32,35,53,337\n46,84,315,322\n13,52,82,326\n73,173\n75,108,167\n47,312,336\n6,50,76,96,313,316,328\n72,87,94,119,144\n69,125,128,157\n0,33,44,48\n0,55\n134,175,180\n180\n0\n0\n0,156,180\n0,6,20,74,97,123,148,154,162\n180\n0\n0\n9,13,15,170\n1,10,13,19,26\n41,180\n29,33,37,55,68,90\n90\n1,26,52,180\n65,90\n79,105,145,166\n180\n58\n162,180\n78,101,113,123,137\n0,22,56\n0,38,57,82\n0,6,28,35,43,60,82\n48,180\n53,78,90\n87,89\n0,93,160\n78,144,178\n0,44,76\n93\n94,108,122,127,157\n24,55\n30,59\n102\n100,102,105,180\n0,14,43,81\n0,38,151,180\n55,79,81,90\n86,90\n0,22,80\n16,54,56,62,64,89\n0,27,29,100\n62,82\n90\n117,119,132,159,167,180\n32,69\n14,42,90\n1,21,38,95\n82\n4,7,28,30,32,65,67\n69,86,119,309\n69,115,304\n176,204,290,310\n150,176,247,292,309\n59,306\n59,301\n43,46,62,65,93\n61,94\n60\n60\n69\n67,80,83,142\n51,80,280,284,313\n52,286,313\n60,83,86,89,154,166,241,250,253,279,282\n66,68,84,132,152,154,161,170,245,282\n312\n112,138,161,200,278\n113,160,201,280\n59,302\n59,302\n68,87,114,120,129,156,268,274,276,284,292,294,300\n71,90,111,119,123,162,269,273,289,295\n278,315\n278,314\n62,91,285\n35,41,47,75,101,103,293,295\n78,123,138,270\n78,98,271,300\n0\n0\n0,8\n104,125\n12,16,24,40,74,327,355\n9,43,75,328,353\n123\n117,136,324\n36,72,324,359\n38,327,357\n180\n141,169,179\n13,15,35,41,90\n0,25,30,103\n86\n90\n86\n90\n15,60\n15,71\n110,165\n85,103,132\n150\n127\n57,173,175,180\n10,55,303,321,358\n19,55,304,359\n16,57,92,309,338,356\n63,176\n56,71,302\n180\n180\n0\n167,180\n0,5\n154,180\n67,189,226,298\n68,191,222,226,282,289,300\n206,299\n208,299\n56,58\n62\n57\n57\n2,53,305,353,358\n55,304,339\n72,179\n179\n61,186,207,296\n62,186,279,288,300\n45,313\n92,173\n185,299\n54,304,342\n304,343\n81,97,129,137,169\n75,95\n14\n0,4,29,173,176,180\n0,4,9,36,53,59,81\n40,51,89,110\n77,85\n124,146,155,167,177,179\n0\n23,64,90\n59,180\n57,306\n57,75,82,304\n177\n77,144,156,177\n52,180\n3,8,17,40,45,58\n180\n180\n56,180\n56,314\n56\n48,305\n48,284\n0,9,83,85,90,100,105,119\n52,91,113,119\n24,49,55,62\n0,9,70\n98,117,135\n123,151\n90,112,151\n87,96,108,129\n93\n29,57,78\n0,6,13,51,102,133,137\n10,27,41,43,69,71,101\n87\n91\n0,8,35,78,84,88,97,159,164\n0,31,38,42,93,102,109\n91,109,111,158\n58,105\n0,10,20,41\n0,35,331,354,357\n29,329,348\n85,88\n0,18,95\n90\n6,23,46,80\n106,141\n1,23,25,35,41,90\n0,6,105\n1,33\n0\n0\n0,180\n1,21,27,87,89,153,155,179\n90\n13,33,171,178\n62,66,69,86,89\n0\n0,180\n0,2,6,171,180\n25,32,41\n63,74,87,90\n0\n180\n0\n0\n357\n359\n0\n180\n0,21\n0,22\n0,31\n33,38,41\n79,284\n78,283\n0\n53,70,81,137,169\n36,53,75,84,92,126\n164\n0,41,54\n180\n0,40,58,60,180\n79,96,102,105,170\n93,96,159,165\n46,281,299,308,312,314\n49,280,303,305\n0\n180\n0\n180\n0\n180\n0,180\n0\n180\n0,2,6\n0\n0,27\n0,37,52,54,56,110,125\n118\n180\n105,142,164,167,180\n0,8,10,43,57,78,102,180\n0,29,39,43,89\n180\n40,180\n0,22,32,42,161,180\n180\n180\n80,96\n192,216,227,237,241,245,256,259\n2,34\n24,45,63,77\n27,37,71,90\n57,61,90\n99,130,151\n91,111,134\n17,36,54\n89,109,125,128\n2,30\n20\n0,35,54,143\n0,21,23,33\n80,120,133,147\n61,97,123,128,164,302,307,313\n88,94,100,104,120,126\n94,109,119,133,139\n56,93,306\n60,92\n85,105,115,141,168\n74,102,124,147,163,296,301\n79,97,102,108,146,161,164,167\n95,108,111,118,125,144,157,176\n106,136\n84,101\n75,79,109,127,141\n52,76,113,142,178\n153,172\n112,152,161,167\n91,144\n64\n95,118,162\n109,135,157,180\n89,150,164,180\n89,91,114,124,152,180\n68,73,75,92,107,119,168\n86,125,148,180\n96,118,133,151,157,161\n108,119,131,142,152,170,180\n96,141,162\n0\n114,153\n1,17\n64,90\n104,111,121,140,157,159,180\n255\n97,256\n0,50\n1,11,15,19,47,52,56,119\n63,68,90\n2,12,33,46,60\n0,45,77\n0,7,11,13,35,42,59,62,91\n90\n100,117,180\n0,22,180\n81,88,91,106,138,155,157\n91,107,118,147\n91,100,130,151\n21,52,94\n10\n108,110,157\n106,128,140,142\n10,51\n87,115\n88,102,121,211,214,216,231,236,245,248\n81,96,223,246,249\n108,221,238,263,279\n0,4,18,25,47\n0,55,66,68,88,116,118,121,146,180\n0,15,24,35,46,52,64,100\n46\n145\n64,181,199,298\n45,59,179,187,190,193,297,313\n0,6,180\n0\n180\n158,180\n0,12,78,89,102,106,114,121,136,174\n0\n145,180\n0,150,157,169\n0\n148,180\n0,3,35,59,98,102,106,110,114,135,148\n0,27,29,33,57,100,160,174,180\n0,116\n37,310\n28,33,39,58,308\n2,24\n61,182\n98\n85\n53,66,185,188,194,295\n57,80,87,110\n61,63,69,79,111,129\n0,24,66,76,88,116\n61,66,92\n0\n36,39,57,161,180\n0,35,45\n70,90\n0,22,34,37,42,60\n69,87,89,114,127\n54,61,74,101,143\n58,75,188,300\n78,184,300\n0,10,81\n1,180\n0,177\n0\n0\n0,160,170,176\n53,64,177\n0,179\n0\n3,12\n2\n0,103,180\n152,166,172,180\n14,52,62,108,173,178,180\n0\n0\n180\n160,180\n0\n154,173\n0,24,31,87\n0\n0,178\n180\n180\n0,180\n171,180\n0,145,176,180\n0,177,180\n0,24,157,180\n0,180\n16,38,61,85,88,91,99,130,158,175,180\n15,41,49,57,79,87,105,107,130,152,154,180\n0,2,169\n2\n0,154,168\n0,7,180\n34,51,79,88,94,121,160,164,173,303\n25,30,36,67,89,118,156,173,290,312\n58,330,333\n59,326\n0,5,135,153\n0\n0,180\n65,182,184,296\n66,187,204,295,325\n59,75,303\n58,303,338\n66,176\n66,86,93,164,180\n188,296\n295\n54,306\n62,145,151,179\n0\n0,174,180\n72,82,90\n87\n59,90,107\n35,64\n72,103\n62,296\n297\n180\n0,72,98\n150,157,180\n0\n0\n0\n0\n180\n180\n180\n180\n0\n0\n180\n180\n0\n0\n180\n170\n0\n180\n0\n0\n0\n223,227,247,269\n257,277,280\n74,143\n274,282,289\n288\n287\n0\n0,25,38,43,46,122,127,140,175,180\n180\n180\n0,38,48,88,180\n26,64,66,71,73,135\n113,152,173,176,180\n103,151,179\n10,27,41,56,70,148,168\n109,147,153,175\n0,180\n11,52,76,144,150,180\n41,61,66,77,79,93,119,168\n58,308\n57,354\n189,212,293\n192,292\n0\n174,191\n67,174,192\n65,71,190,289\n189,196,289\n61,305\n0,177\n90\n90,110\n0\n5,31,65,100\n85,118\n100,126\n103,109,118\n58,72,298,351\n39,45,55,75,115,302,307,313,350\n25,76,114,294,358\n76,111\n0,3,20,23,42,45,48\n170,180\n61,297,300,303\n45,60,75,299,317\n53,100,132,161\n53,82,124,144,169\n66\n12,65,307\n180\n0,180\n0,180\n0,180\n0,163,171,180\n5,8,15,17,20,23,31,39,55,65,75,113,123,127,155,176,179\n0,125\n72,74,84,88,90,140,148,163,180\n53,76,80,84,88,92,116,135\n53,66,86,140\n19,61\n62,187,298\n61,184,297,301\n53,64,300\n58,301\n66,68,137,176,192\n68,177\n67,190,192,303\n64,185,300\n53,306\n58,303\n0,180\n0\n109,154,180\n0,2,156,161,163,171,179\n1,39,56,85,99,101,123,126,180\n115,180\n0\n0\n0,22\n0\n0,64\n180\n180\n0\n180\n14\n70,125,180\n175\n161,180\n180\n114,143,153,180\n87,120,145\n180\n180\n94,106,141\n72,94,116,130,136,151,163,165,298,300\n71,105,126,140,149,297\n44,61,300\n59,63,306,317\n176,265,287\n175,193,275,295\n73,140,163,295\n68,74,121,147,299\n43,62,80\n53,68,85,308\n43,90,308,322\n47,81,311,328\n111,113,115,166\n0\n286\n273,290,307,331\n308\n302\n54,298,300,304\n70\n180\n180\n56,70,291,303\n61,174,297\n0,8,180\n0\n14,26,50,55,70,76,94,96,99,160,180\n98,134\n0,180\n28,180\n0,11,34,112\n0,40,44,74,84,101,179\n10,19,55,67,72,76,83,96\n0,25,30,59\n222,233,259,315,332\n25,220,276\n21,31,217,248,268\n249,270\n218,260,273,275\n33,49,279\n0\n0\n1\n0,2\n0\n0\n1\n180\n0,180\n1,167,174,176\n0,180\n2,6,29,77\n0,14\n0\n21,160\n0,180\n2,17,29\n0,180\n0,123,180\n0,25,29,38,85,116,158\n38\n180\n4,180\n0,180\n0,5,11,14,94,110,133\n0,25,27,31,44,47,88,114,128,132,154\n0,21,59,99,101,104,158,160\n136,180\n0,33,180\n0\n128,132,144,180\n0,8,10,164,171,177\n0,179\n0,159,164,180\n0,2,180\n180\n0,17,24,180\n2\n0\n0\n0\n74,94,138\n12,39,62,69,72,91\n43,78,109,111,125,178,180\n90,114,146,170\n74\n0\n0\n0,11,13,60,65,80,90\n0,10,50,57,78\n0,174,180\n1,15,17,52,180\n3,15\n8,180\n0\n1,24\n0\n180\n0\n22,94,135,154,180\n67,81,91,95,112,130,172,180\n35,145,167,180\n0,180\n0\n0\n180\n26,28,141,144,148,159,161,172,175\n0,23,147,150,156,180\n0,180\n0,180\n54,90,124,149,180\n0,35,54,134,153,171,174,177\n0\n0,180\n0\n0\n0\n0,3,25,180\n0,9\n0,23,30\n58,81,87,114,123,133\n168,180\n0\n0,180\n0,179\n0\n3,7,9,180\n0\n152,166,180\n180\n128,138,155,169,174\n146\n311,318,326,350\n284,312,326,352\n59\n63,67,83,206\n56,66,85,96,205,229\n29,309,333,341,359\n287,313,322,353,358\n4,10,16,30,33,65,338,358\n20,50,68,358\n219,272,326\n224,272,314,316,318,328\n79,201\n48,66\n168,180,198\n85,197\n157,179,191,208,213\n68,77,177,202\n224,271,286,303,323\n284,308\n269,281,290,302,327,345\n224,278,319,321\n58\n0,11,24,51\n7,30,83,88,90\n10,12,37,59,75\n9,96,154,158,166,168,171\n0,66,73,77,89\n59,180\n180\n136,180\n60,123,177,180\n61,180\n56,71,163,180\n49,180\n50\n53,58,178\n180\n60,180\n180\n48,51,174,180\n59,76,164,180\n0,59\n178\n179\n175\n176\n34,39,59,303\n12,31,34,60,297,326\n51,54,57,315\n50,54\n79,118,124,177,294\n52,304\n52,307,338\n51,285,309\n306\n62,188,302\n63,184,279,304\n182\n57,180,197,293\n58,180,198,288,307\n42,71,166,287,317,320\n182\n180\n27,50,62,64,68,75,78\n32,52\n57,99,178,225,309\n58,164,184,309\n227\n70,161,296\n67,165,169,296\n53,309\n54,306\n177,203,287\n178,282,288\n16,53,82,297,311\n55,310\n176,217,234\n180,223,226,237,240,285,287\n71,177,293\n57,166,184,300\n180\n73,166,293,295\n26,54,310\n2,54,307\n175,196,214,271,290\n178,197,209,290\n34,41,48,290,310\n44,310,324\n52,294,304,308,321\n55,157,181,291\n34,158,182,280,283,295\n179\n7,9,122\n1,4\n160,168,180\n0,96,101,108,133\n13,93,97,106,122,124,150\n0,120,163\n0,32,38,40,52,79,94,109,125,142,163,167,180\n2\n54,77,160\n0,18,59,98,100,104,154\n106\n83,99,101,113,122\n75,107\n82,87,110\n0,4,21,35,54\n0,7,25\n18,57\n93,113,124,148,169\n130,180\n139,174,176\n177,179\n0,106,108,121\n180\n0,3,9,30,114\n0,9,16,50,65,85,123,128,134,157,170,180\n93,121\n1,22\n180\n3,10,349,359\n150,161,163,338,357\n151,338,351\n114,143,164,352\n5,35,43,46\n4,318,325,344,348\n242\n234,246\n0,60\n45,63,90\n0,7,9,29,33,40,61,64,83,87,90\n3,10,19,90\n50,73,80\n0,54,120,173,176\n0,17,28,47,57,90\n90\n0,21,23\n0,15,26\n0,11\n143,150,177,179\n118,165\n0,57,73\n0,8,21,25,28,40,45,90\n10,26,121\n3\n119,142,180\n150,164\n14,47,49,89\n13,116\n180\n0\n145,166,180\n40\n0,22,31,44,64,69,89\n142\n0,54,89\n0,7,119,123,138,149,168,179\n13\n153,160,180\n4,23,155,158,163,166,169,177\n162,184,191,205,208,214\n237\n237\n139,165,176,179,195\n147,167,173,195,217\n6,35,37,50,167\n10,36,55,98,110,147,160\n22,27,52,55,61,67,161,175\n13,47,157\n359\n359\n18,53,69,96\n14,58,97\n209\n208\n31,58,73,170,180\n48,77,166,169,180\n58,180\n0,25,74,85,92,122,132,143,157\n38,60,80\n90\n39,46,52,72\n180\n80,91\n3,31,55,70,88,120,122,124,136,157\n47,80,90,93\n0,7,31,47,53,62,67,83,87,90,117,149,154,157,165,180\n0,10\n0,12,57,78,80\n17,107,128\n87,90\n90\n1,20,33,49,68,83,99,119,122,125,128,131,150,157,165,170\n3,22,25,49,52,54,58,88,117,164\n55,148,180\n150,171,175,179,201,283,315\n58,149,165,173,179\n29,45,63,78,105,136,158,180\n48,75\n0,13,21,32,37,47,51,74,79,90\n0,115,126\n6,10,12,32,65,87,111,146,152,179\n1,15,22,25,31,60,139,142,149,151,166\n56,60,180\n20,94,101,110,140\n79\n80,88,90,103,126\n0,29,52,81,86,90\n0\n35,64,68,118\n42,66,149,151,158,163,180\n28,44,58,63,180\n0,8,50,76,86,90\n0,2,137\n32,57,72,88,121,180\n61,80,174,198,289,291,314\n53,80,178,196,295,304,306,310,316\n0\n94,129,152,156,160\n90\n41,88\n61,90\n45,75,105,138,159\n0,3,41,74,121,136\n19,53,66,79,90\n5,43,69,72,149,151,167\n45,48,56,59,148,167\n53,55\n0,26\n0,10,33,55,90\n48\n34,78,80,92,95,118,146,166\n6,10,26,78,93,95,127,155\n2,113,343\n2,23,39,71,132,138,166\n28,64,122,147\n59,68,74,146,149,180\n24,27,35,49,62,177\n39,180\n66,167,310,321\n60,77,207,300,332\n0,9,15,28,35,41,44,60,90\n0,13,56\n26,41,45,90,111,122,159,162\n29,50,88,94,98,103,123,164\n0,8,10,23,30,51,72,90\n0,2,8,23,49,55,57,60,68,71,75\n17,38,80,111,133,158,178\n15,80,82,108,165,179\n56,180\n0,3,14,20,57\n23,55\n0,16,24,37,46,51,90\n90\n0,40,63,90\n0,21,42,54,63,90\n0,121\n58,180\n27,44,54,62\n20,22,25,47,76\n62,180\n16,51,90\n14,37,42,52,56\n22,30,40,51,54,79\n19,44,60,93,163\n0,20,66,72,84,86,90\n20,59,112,140,161\n0,19,57,108,114,139,158,169\n43,59,87,133,139,149,153,157,174,180\n0,5,11,13,46,49,69,90\n0,5,14,45,59\n0\n61,68,76\n351\n350\n45,51,59,162\n28,56,96,102,109,148,180\n39,85,137,163,169,180\n28,141,159\n0\n0,47,139,180\n1,3,26,34,39,46,71,76,90\n0,2,16,112,131\n3,25,58,90\n90\n145,168,171,174,176,179\n0,24,41,67,90\n0,39,95,121,144,180\n44,63,90\n120,153,175,180\n0,11,15,52\n18,121,136,161\n0,30,44,49,62,75\n0,26,58\n0,20,120\n144,180\n8,12,18,20,37,49,62,102,105\n3,14,26,44,58,66,106\n29,38,41,85,134,158\n0,88,102,122,135,148,150,153\n0,10,30,49,59,82,105,128,131,134,150,180\n0,22,64,109,138\n18,70,72,85,92,115,118,142,149,160,163,165,167\n0,20,34,111,115,120,138\n59,180\n33,35,51,63,70,179\n54,180\n41,61,180\n2,40,78,86,90\n107\n70,177\n0,24\n184\n75,179\n22,38,53,57,71\n0,43,51,76\n49,179\n58,79,169,171,197,299,319\n56,77,172,197,270,273,294,300,309,311,313,318,320\n35,71,73,163,165,185,265,285,311\n51,151,181,185,270,293,295,310\n26,48,55\n2,25,28,55,74,82,86,88,90\n17,19,28,83,87,90\n17,85,90,99,109,138,165\n19,109,177\n18,51,53,77\n0,2,4,11,17,47,52,67,90\n2,5,45,72\n42,75,163\n51,54,73,151,157,166,186,263,281,308\n29,51,61,153,182,270,279,283,311\n12,32,54,72,90\n4,6,8,15,19,32,42,49,65,72,90\n53\n17,47,78\n1,28,35,39,42,123,155\n0,9,52\n147,168\n29,31,33,50,66,90\n2,7,27,49,75\n0,3,10,112\n0,52,64,88,121,148,168\n44,64,82,170,172\n47,69,176,180\n0,18,33,56,79,90\n14,61\n0,12,18,20,22,47,78,81,90\n0,54\n33,60,90\n12,65\n0,3,10\n80,97\n44,49,65\n29\n0,14,17,48,59,64,68,74,87,90\n0,14,34,40,43,53,60\n57\n172\n15,18,50,63,82,95,136,163\n43,74,100,113,219,221,224,276,314,349\n40,68,73,114,160,199,225,295,312,336\n49,70,173,180\n0,6,13,19,38,70,90\n0,67,99,122,143,173\n0,5,34,38,53,59,90\n1,5,15,45,65,83,88,104,116,132,134,146,176\n0,4,112,114,121,139\n0,123\n37,45,61,68,91,150,170,175,180\n0,13,36,89,120,157\n60,180\n40,63,181,300\n60,178,299\n54,64,177,299\n75,93,112,184,215,232,281,321,354\n34,63,183,203,273,301,328\n0,3,40,48,74,80,86,113,154,169\n173,180\n22,26,34,51,185,187,284,300\n24,54,183,290,299,305\n21,34,41,59,106,125,138\n60,64,167,172,179,181,292\n48,80,183,186,277,296\n56,73,177,195,301\n66,185,300\n0,2,7,12,153,166,168,180\n3,130,158,160\n151,163,169,191,341\n123,153,189,209,241\n199,214,225,234\n230,251,260,277,280,292,304,328,330,338,340,343\n228,235,253,282,330\n244,266,269,325,332,340\n211,214,240,273,302,347\n196,244,262,286,296,301,329,338,350\n6,68,123\n3,17,20,67,115\n30,49,52\n263,321,336\n262,329,336,340\n19,48,92,95,99,106,125\n314,330,332,334\n0,19,39,90\n36,101,118,136\n90\n123,133,136,141,162\n156\n19,48,54,72,90\n151,158,161,166,186,204\n0,38\n58,180\n180\n304,310\n307\n56,184,211,298\n56,185,298\n48,67\n55,310\n55,310\n0,47,67,124\n0,20,41,72,84,103,111,121,152,180\n0,30,73,104,123,166\n11,34,86,97,109,124,170\n0,10,20,26,103,107,110,123,131,173\n0\n156,180\n4,7,39,51,53,71,75,77,106,120,135,180\n1,5,115,126,135,141,146,159,180\n8,49,87,115,133,213,235,333,345\n25,41,92,94,96,135,144,155,192,202,208,270,338,357\n4,27,88,92,95,122,154,174,195,199,201,208,211,233,330,335,341\n59,180\n56,69,306\n54\n50,180\n52,179\n48,300\n49,301\n47,290,311,331\n58,296,308,323\n26,296,328\n293\n65,172\n69,171\n180\n65,178\n185,292\n185,259,267,271,290\n174,178,181,199,201,294\n55\n65,158\n61,172,194,295\n64,127,182,302\n63,167,183,302\n161,175,177,194\n302,328\n65,93,153,178\n64,166,182\n60,175\n59,181,308\n63,182\n0,10,25,40,46,56,67,78,110,121,127\n99,128,131,134,164\n0,2,15,21,46,61,86,92,104,117,123,164\n52,67,69,172,299\n47,66,76,85,156,161,176,179,194,269,275,285\n41,61,63,70,88,91,96,104,124,134\n98,117,131\n44,85,97,119,127,136,138,151,154\n13,15,30,177\n90\n104\n90\n67,90\n90\n10,34,70,75,108,142,144\n57,59,68,90\n117,150,175\n111\n48,51,53,58,68,80,84,97,122\n112\n37,40,55,60,65,70,89,97,101,104,143\n98\n91\n48\n56,180\n48,50,84,313\n31,56,311\n56,62,93,163,166,173,198,291,307\n64,163,177,206,284,317\n64,175,198,286,314\n50,67,87\n0,9,37,63,78,90\n0,21,72,88,90\n0,17,43,106,127,131\n52,67,69\n31,60,172,178\n12,173\n14,34,176\n12,58,74,77,101,159,163,178\n8,21,42,81,84,165\n0,9,57,87,111,138,156\n0,137,180\n65,98,106,129\n10,12,39,75\n0,67,88\n9,90,112,136\n2,14,33,69,71,75,83,85,87,104,147,168\n19,53,102,122,148,167\n0,3,6,27,65,84,104,123,126,152,178\n15,66,81\n0,9,15,32,37,43,79,99,114,157,180\n0,2,25,27,29,66,123,140,161,163,175,180\n0,73,75,91,110\n0,11,24,50,108,113,116,120,140,180\n0\n0\n133,138,172,177,180\n114,118,122,138,159\n142,148,180\n156,160,173,177,179\n25,113,125,154\n3,36,61,70,100,126,141,151,154\n130,140,143,169\n0,18,20,29,111,137\n1,12,36,75,103,127,154,158,160,163,166,171,174,180\n0,28,32,84,101\n145,171\n99,151\n0,25,99,118,129\n223,255\n226,271\n225,276,288,291,293\n225,248\n128,150,217\n123,154,175,217\n165,175,196\n143,154,175,219\n146,217\n153,213\n150,214\n59,76,288,301\n68\n88,157\n189,293\n181,208\n188,193,198,202,279,298,317\n63,171,185,285,304\n60,79,186,188,304\n63,188,203,301\n56\n292,307\n299,302\n301\n303\n51,179,183,196,212,214,237,294\n52,188,237\n61,286,303\n68,175,192\n69,94,177\n69,97,176\n67,123,176\n59,80,122,157,179\n67,71,121,123,149,161,172,176,178\n169,171,173,176,186\n59,180,302\n59,68,178,306\n302\n63,299\n58,301\n72,174,185\n0,35,69,90\n0,4,6,33,40,60,70,90\n0,129,145,149,164,166,176,179\n0,133,150,152,180\n117,151,166,178,180\n0,14,31,89\n0,134,155,157,180\n45,90\n0\n0,59\n111,141,168\n32,49,52,120,123,161\n122,160,165,167\n46,82,136,144,167\n252,255,257,268,270,285,325,327\n252,280,306,329,351\n31,79,82,85,95,101,359\n10,14,16,22,38,91,95,102\n10,56,69,123,127,147\n0,3,73,122,139,152\n7,119,236,240,244\n6,121,233,359\n282,285,294,300,321\n281,284,311,313,323,326\n222,242,266\n224,232,243\n39,53,96,115,356\n18,21,25,39,51,93,108,359\n39,49,51,86,89,161\n1,7,50,70,73,77,80,90,151\n244\n243\n8,287,295,298,330,351\n5,8,287,330,351\n4,122,145\n30,63,135,180\n109,131\n88,101,253\n89,114,119,124,127,155\n9,243,261,306\n245,247,354,356\n244,258,308,316,324,339\n15,21,27,110,120\n61,180\n32,40,43,65,85,179\n47,179\n53,180\n58,66,180\n60\n68\n63\n64,166,196,199\n61,173\n46,302,332\n46,300,331\n255,262,268,298\n186,261,291,294,296\n176,197,288,304\n53,56,169,187,302\n39,59,158,180,299\n12,60\n298\n300\n64,96,164\n62,81,96,139,159,161,176\n179,196,235,297\n183,197,295,298,306\n287\n189,296\n53,70,170\n61,176\n63,167\n44,67,189,300\n172,188,303\n184\n156,184,187,191,226\n63,91,298\n59,72,144,159,172,296,298,300,308\n57,306\n31,35,57,302,325,327\n157,181,205,226\n47,60,301\n59,179,301,307\n301\n301\n173,303\n298\n297\n54\n59\n57,185,202,268,289\n55,187,292\n54,181,305,309,318,326,329\n39,47,56,174,312\n58,177,300\n58,178,296,312\n175,188\n0,24,51,56,62,92,120,139,180\n58,180\n180\n145,149,176\n45,57,62,70,173\n60,92,173,180\n47,180\n0,112,129\n71,92,168\n10,28,46,48,50,82,100,164\n30,44,50,162,272,295,323,344\n35,280,323\n300\n300\n26,73,130,148,151,155,157,163,172,180\n24,52,173,288\n41,52,175,181,196,203,291\n58,174,289\n1,28,49,64,84,86,90\n0,16,43,55,58,90\n8,45,54,89,108,138,156,162,169\n6,14,28,34,52,119,139\n13,73,84,88,91,112,122,168\n22,63,69,85,111,123,126,133,171\n59,83,142,152,180\n58,60,182,297\n59,95,184,287\n2,37,43,53,90\n0,25,111,127,144,160\n23\n6,45,117,137,154\n0,24,50,72,75\n90\n8,58,78,85,102,174\n26,45,76,100,172\n10,23,29,123,149,208,214,221,255,351\n18,107,110,124,206,228,359\n6,9,12,15,21,140,162\n8,23,27,137,139,160,173,175,179\n0,19,48,74,80,90,96,171\n13,66,113,116\n0,90,102,125,127,152\n60,64,67,70,73,76,84,179\n45,61,64,83,180\n62,156,177,188,193,203\n44,66,154,181,199,269\n254,300,340\n196\n0,51\n0,3,5,10,39,90\n0,52,90\n3,13,15,29,31,56,58,63,89,101,128,145\n59,74,96,103,130,179\n0,25,55,88\n0,23,47,68\n0,26,58,78,80,83,95,135,161,180\n0,37,47,89,109,124,154,180\n36,56,90,114,120,134,137,170\n65,189,306\n68,181,307\n58,181,299\n57,179,299\n19,22,25,38,78,94,156\n31,55,58,95,177\n143,165,180\n160,180\n120,129\n0,103,135,140,153,171,173\n0,6,10,133,155,180\n11,127,149,153,157\n3,139,164,186,189,204,324,345\n2,5,8,10,12,82,105,134,154,168,171,188,243,292,323,330,346,348\n250,284,322,335\n15,17,69,109,139,157,171,173,175,248,254,264,345\n9,20,153,155,170,180,245,341\n0,3,31,91,188,221,242,267,310,329,351\n24,40,122,125,174,195,218,253,272,308,355\n180\n194\n57,62,178,192,309\n72,149,172\n0,9,13,15,55\n180\n0,42,180\n85,89\n120\n33\n7,28,40,43,52,70,84,90\n0,119\n62,180\n0,23,41,62,90\n0,117,140,144,155,159\n0,71,79,90\n0,81,95,122,132\n0,8,101\n0,56,80\n51,55,77,79,163,180\n62,171,175,186,299\n12,30,48\n0,17,98,100,102,118,120,122\n0,6,31,65,90\n0,119,162,165\n0,33,67,87,90\n2,8,14,28,35,39,46,59,72,107,143,146,163,169,177\n9,17,29,37,46,62,69,90,139\n0,46,90,160,177,180\n17,31,38,41,44,74,77,82,85,180\n50,80,123,154\n0,5,26\n18,44,59,62\n0,6,120,135\n0,2,7,17,36,70,72,74,90\n180\n16,29,58\n40\n0,7,9,38,67,90\n13,19,30,48,59,79\n0,90\n0,19,67,77,106,111,113,129,132,160,180\n1,8,18,43,53,159,176,180\n24,35\n178\n175,177\n174\n0,3,26,29,33,39,54,70,84,86,89\n0,90\n0,10,54,59,61,64,67,72\n8,28,59,116,180\n0,2,12,122\n53,58,176,178,180\n180\n7,123\n0,24,83,86,120,122,124,143,151,180\n59,205,311\n38,59,178,184,190,218,277,280,292,295,299,312,337\n23,44,50,56,62,69,75,81,143,160,175,189,205,241,259,278,300,337\n66,90\n0,82,84,90\n0,13,22,25,45,54,61,88\n11,13,64,70,85,90\n4,12,27,50,63,65,94,125,147\n4,20,27,31,43,52,63,67,70,84,111,121,123,156,160,170,172,176,178\n0,6,9,15,28\n1,4,21,29,67,77,90\n0,31,61,73,75,90\n29,65,87,97,134\n0,18,32,74,90\n180\n0,26,104,124,138,180\n0,10,52,90\n0,29,47,94,124,152\n15,52,95,114,120,142,180\n14,79,99,126,161\n0\n0,14\n0\n156,180\n0,3\n0\n0\n180\n0,13,91,106,116,122,140,165\n3,43,76,123,143,147,150,180\n58,60,63,67,78,99\n32,56,77,80,117\n0,91,180\n0,6,24,46,69,73,92,125,149\n102,119,124,135\n13,35,60,112,117,121\n25,27,70,72,90\n17,26,31,54\n87,90\n64,120\n68\n54,73,101\n62,76,90,92,94,130\n5,21,36,42,65,218,228,349,352\n11,28,36,39,42,157,217,231,234,351,353\n0\n124,137,139\n10,34,150\n42,76,153,172\n180\n235,257\n234\n300,320,337\n263,294,307,321,349\n20,98,112,125,143,165,169,194,250,352\n118,155,177,209,234,354\n106\n103\n74,88\n0,5,7,30,32,35,37,54,90\n0,11,15,19,28,58,90\n0,2,40,94,121,137,180\n137,180\n0,3,14,20,85,119,147,180\n0,4,7,20,25,29,51,82,120,123,126,129,150,180\n2,7,10,109,113,116,118,134\n61,181,301\n65,184,303\n53\n60,75,183,290,311\n200\n191,274\n55,304,306\n55,305,307,318\n72,146,180\n62,172,195,304\n60,187,308\n193,288\n57,306,351\n52,306,329\n0,8,43,47,88,90\n0,9,92,96,127,129,149,151\n147,167\n2,4,6,48,81,83,85\n8,114,127,145\n0\n0,124,130,156,176\n15,23,27,30,53,127,148,154,158,174,178\n317,319,339\n283,324\n15,34,40,54,72,91,111,123,125,135,144,149,162,166,172\n4,16,18,20,38,51,59,61,84,87,102,124,135,145,163\n304,341\n304,337\n0,2,13,17,35\n8,115,118,222,225,233,237,246,262,265\n53,120,180\n65,180\n54,69,153,173\n41,74,82,84,88,130,172\n49,306\n49,51,60,64,67,98,168,296\n40,58,174,191,297,299,307\n299\n298\n58,76,191,288,305\n58,186,306\n54,58,66,146,175,187,309\n42,58,74,88,143,149,156,177,297\n0,3,57,118,174,180\n167\n66\n0,3,12,15,64,72,80,84,119,121,173,178,180\n142,170,173,180\n0,22,54,83,106,109,180\n0,20,55,79,88,103,106,125,169\n34,61,164,180\n22,25,27\n125,129,154,172,176,180\n2,11,52,71\n18,28,57,78,129\n51,167\n16,114,159\n38,41,46,51,80,85,180\n1,14,29,31,41,62,64,80,90\n0,33,49,53,84,86,118,132,136,142,155,180\n0,7,14,55\n44,58,180\n0,24,36,61,87\n60,180\n151,180\n2,16,23,29,48\n0,4,32\n10,60,108,125,131,137,176,180\n25,29,33,56,89,91,128,147\n172\n172\n2,57,306\n18,52,77,90\n4,41\n54,69,179\n177,265\n177,270\n2,60,90\n64,160,180\n10,93,120,139,180\n7,20,38,66,86,139,147,149,169,172,180\n139,171,180\n180\n5,24,45,55,82,117,147,160\n2,15,20,36,42,75,146,165\n20,31,41,112,134,148,150,167\n25,38,43,150,177\n0,36,45,55,82,156\n69,154,180,300,309\n54,57,180,306\n13,18,24,40,67,99,141,165\n0,8,28,39,41,43,70,81,108,157,180\n15,44,75\n35,64,77,80,95,157,171,180\n0,11,22,60,85,126,128,149,180\n37,55,82,87,90\n0,10,15,27,46,88,111,127,155\n46,71,166\n3,125,167,224,229,232,240,352,357\n3,111,165,171,177,224,227,233,240,288\n21,40,46,74,80,86,101,119,133,154,168\n44,79,161\n42,60,87,127,153,180\n38,80,125,155,175,202,224,258,281,335\n28,49,333\n27,49\n34,39,43,64,85,133,154\n23,58,100,119,142\n0,35,55,68,92,147,180\n47,170,207,291,314\n93,156,159,180\n0,10,34,39,50,79,113,133,137,139,151,165,180\n0,20,32,104,146,148,153\n0,20,100,106,117,130,147,163\n14,37,136,234,317,320,331,351,357\n89,95,116,149,208,227,315,321,332,354\n0,61\n1,38,46,55,72,77,90\n55,82,180\n0,19,70,82,90\n0,11,112,134,152,177,180\n2,21,42,45,68,89,91,93,95,97,108,111,118,126,144,148,166,169,173,176\n5,31,34,63,79,88,115,118,138\n1,30,72,97\n6,28,97\n61,90,180\n57,176,183,292,310\n49,72,166,182,196,278,306,308\n14,149,177,180\n32,55,82,90\n0,5,56,65,68,75,89\n3,6,58,90\n90\n127,175,180\n0,52,58,63,68,79,81,108,120,125,133,137,140,145,163,166\n6,17,73,98,115,148,155\n12,15,25,30,46,55,114,134,136,168\n15,46,65,86,90,105,133,170\n254,273,275,282,285,291,295,336\n256,272,274,287,295,344\n303\n303\n0,32,64,90\n0,12,25,37,40,55,71,90\n127,141\n1,19,22,31,33,49,68,90\n0,7,120\n0,17,22,30,100,118,127,137,142,144,146\n0,2,4,11,15,38,50,53,90\n0,2,23,25,59,90\n7,12,15,33,67,96,110,167\n10,96,106,113,166\n0,32,65,91,124,158\n0,18,35,83,87,90,110,120,126,142,147,149,180\n0,10,16,42,45,76,83,90\n17,23,35,63,105,120,138,154,173\n13,22,26,29,57,79,104,161\n0,20,40,68,90\n28,55,64,70\n0,22,60,67,92,108,111,155,170,180\n44,79,163\n26,43,60,147,165,169,202,249,323,356\n9,39,78,95,140,155,178,246,254,280,319,355\n25,88,197,203,210,216,222,259,311,330\n14,132,187,217,235,240,250,260,266,322,328,335\n33,58,92,95,137,157,180\n0,6,41,51,54,69,79,90,110,152,156,158,178,180\n0,23,90,97,106,125,142\n9,46,62,64,86,108,120,123,132,137,147,149,156,159,172,180\n0,14,101,104,124,126,147,180\n0,6,20,50,74,77,113,124,129,133\n18,50,103,109,115,135\n14,33,37,41,62,147,180\n0,4,9,113,132\n26,67,97,142,162,171,180\n43,46,61,175,180\n0,22,112,117,124,132,135\n60,182,285,300\n38,64,177,188,302\n0,9,26,56,59,95,107,117,137\n0,43,72,93,141\n81,101,132,146,172\n152,175,177,179\n0,24,42,120,126,134,138,147\n121,124,129,147,149,163,188,329,353,358\n5,142,144,147,181,229,258,310,334,349\n241,273,303,345\n273,288,326,334,345\n2,4,6,18,28,40,42,45,55,60,89,136,147,156,158,221,234,279,316,347,358\n7,12,17,64,126,136,147,196,200,216,265,281,290,332,344,349,356\n0,9,121,138,141,153,156,179\n144,159,169,178\n172,220\n285,307,323,331,348\n0,25,31,42,142,154,160,164,177,180\n0,13,25,45,50,68,72,89,127,171,176\n62,92,106,119,121\n0,14,16,24,77,87,109,112,141,159\n1,35,127,130,143,180\n70,91,140\n74,90\n70,81,113\n24,55,59,69,78\n73,88,90\n55,60,90\n78,117\n122,128,132,145,162\n57,60,63\n71\n73,115,119\n54\n71\n85,90,93,180\n64,78\n76,86,88\n71,90\n85\n75,90\n90\n17,19,113\n67,86,90\n120,147\n35\n32\n25,62,67,84,90\n3,23,31,40,69,88\n76,90\n148,160,172,180\n19,58,78\n9,14,24,136,157\n326\n5,253,271,292,316,319,322,325,328,334\n62,79,169\n43,67,169,190,300,303\n150,161,172,186\n55,71,98,126,137,156\n52,83,100,124,156\n8,21,126,150,168\n23,36,41,93,128,131,134,146,159\n8,34,170\n9,33,63,88,92\n18,20,45,85,158,161,165,168,174\n6,25,32,55,121,125,137,146,159\n7,59,76,103,122,142,145,169\n8,36,39,64,89\n145,164\n118,151,180\n98,105,124,126,139\n160,171,180\n0,28,109,125\n0,40,48,58,84,105,108,111,117,142,161,177,180\n163,166,169,187,205\n162,164,166,186,201\n55,59,61,158,161,179\n34,53,65,72,173,180\n59,61,180,298\n57,180,287,295\n54,56,166,172,186,300\n175\n175\n58,180,299\n57,74,179,296\n0,2,6,180\n0,10,20,30,53,82,138,161,180\n27,46,56,62,68,80,127,167,180\n296\n308\n190,274\n62,298,300\n57,80,82,177,189,299\n47,69,289,309\n50,64,80,179,304\n61,180\n138,167\n167\n0,56,81,99\n62,77,83,95\n65,184,306\n64,183,306\n0,19\n5,71,164\n170\n0,20,24,32,69\n11,13,31,34,90,98,131,143,149,174\n11,47,85,94,106,117,131,150,169\n149,153,156,180\n153,172,176,180\n0,6,9,31\n17,34,59,105,132\n6,26,54,77,117,140,158,175\n7,32,115,118,127\n15,65,69,125,139\n10,62,129\n274,301,319,340\n272,286,302,317,320,337\n35\n66,140\n2,5,64,141,143,156,162,167,175,179\n15\n1,14,53,60,78,114,118,124,139,153,180\n59,162,180\n0,33,53,63,115,160,172,180\n34,59,70,171,180\n7,27,62,71,89,119,156\n0\n167,169,180\n14\n0,16\n0\n0,6,8,15,18,56,106,183\n57\n0,43,60\n1,90\n39,181,293,307\n276,306,329\n47,50,306\n302,317\n64\n0,8,27,34\n0,7,106,115,118,124\n0,2,15,22,48,55\n131,141,144\n179\n0,24,99,122\n75\n0,37\n0,14,17\n13,37,76,136,172,176,179\n16,39,51,62,66,115,145,147,152,180\n1,33,59,67,79,90\n0,20,49\n102\n102\n100\n94\n96\n312\n98,310\n270,320\n197\n65,116\n1,3,5,45,67,90\n61,86,90\n136,145,148,157,170\n0,63,74,90\n9,12,15,36\n35,49\n41,54\n38\n12,30,33,38,59\n67\n42,60\n0,169\n1,31,40,62,85,95,106,123,179\n0,3,99,140,179\n1,26,31,185,305,315,334\n35,57,153,185,210,234,271,317,351\n4,18,24,72,154,159,165,201,246,314,346,349,352,354,357\n0,17,32,37,43,141,187,211,347\n68\n138,156\n8,26,102,136,157,166,172\n41,179,185,191\n1,22,40,62,68,74,208,329,347\n28,47,54\n149,154,175,178,180\n66,83,90\n0,25,40,140,142,163,165\n23,85,90\n105\n123,135,162,180\n99,111,150,173',Klb),n);q=(b&1)==0?null:(o=Zkb.n5('14-38,46-74,87-105,169-191\n33-44,47-81,83-92,92-103\n133-160,167-185\n159-184,249-280\n199-221,221-232,232-255,258-267\n40-75,160-200\n18-26,28-37,37-45,48-64,72-81,93-105,109-127,171-189\n-27-27,49-56,56-76,76-104\n-43-43,45-65,65-115\n-28-28,58-61,61-70,70-90\n-16-16,44-69,69-82,157-203\n-21-21,21-52,73-107\n-11-11,20-33,33-39,39-59,59-78\n3-25,25-43,43-67,78-102\n0-24,32-49,49-52,52-69,69-73,73-77,77-79,79-87,87-89,89-91\n0-26,26-46,58-76\n-29-29,29-51\n0-20,170-190\n-14-14,21-58,58-70,70-89,89-91\n8-37\n-1-1,1-28,28-30,30-47,52-69,69-87\n0-27,27-29,29-43,43-47,47-56,56-63\n42-60,60-62,62-80,80-100,136-146,146-155,171-189\n167-193\n-12-12,24-41,41-50,50-71,71-81,164-180\n-11-11,43-70\n-23-23,40-70\n28-42,42-75,75-87,160-200\n42-70\n36-55,55-73,293-321\n31-49,49-61,61-75,294-322\n-3-3,3-15,53-71\n55-63,74-93,114-135,143-170,170-190\n0-4,7-29,42-72\n17-92,92-107,132-179,179-181\n34-65,83-101,140-153,160-180\n32-51,72-92,151-169\n33-51,70-87,151-176\n46-79,156-204\n40-67,153-175,175-185\n40-65\n40-63\n48-75,156-176,176-184\n33-52\n-1-1,1-17,21-37,165-176,176-184\n37-56,65-86,152-175\n47-74,79-88,170-190,199-217,296-315\n49-75,75-86,291-318\n-4-4,4-9,9-11,11-13,46-74,74-93\n-9-9,49-75\n0-18,28-46,47-58,58-75,85-107,125-133,169-191\n-1-1,1-13,13-42,125-146,156-167,167-193\n38-60,60-62,62-66,66-85,155-178,178-182\n33-54,64-88,155-176\n33-55,66-85,155-176\n22-29,30-59,59-63,63-65,65-70,70-79,156-181,181-195,259-277,277-286,286-319\n13-29,29-44,44-52,52-67,67-73,73-84,136-155,155-173,173-185,185-204,273-292,292-298,298-320\n15-29,34-41,41-49,49-72,72-83,137-155,171-197,197-211,267-285,288-314\n34-51,51-71,140-151,151-162,172-179,268-286,286-298,302-317\n33-58,58-78,162-198\n29-42,42-59,67-88,148-164,164-196\n29-56,62-79,79-90,158-179\n30-43,43-48,48-55,55-63,63-83,136-166,166-179,179-181\n28-46,46-51,51-58,58-71,71-83,83-100,149-174,174-179,179-181\n160-180\n-11-11,18-48,51-70\n171-189\n0-10,10-14,14-34,34-55,72-77,77-88,88-92\n-10-10,11-31,31-53,67-78,78-102\n0-19\n-9-9,9-12,12-19,19-35,35-39,39-44,55-73\n32-82,158-202\n39-61,61-83,162-177,177-183\n41-77,156-204\n45-84,159-201\n48-68,81-99,139-157,157-160,160-165,165-175,175-179,179-181\n-2-2,2-11,11-50,51-60,63-70,70-75,84-103,110-137,137-168,171-189\n48-69\n31-49,49-58,58-84,154-171,171-175,175-185\n33-56,61-87,151-177,179-181\n37-60,60-82,160-182,182-205,275-293,306-324\n32-58,161-174,174-179,179-180,187-209,282-300,306-324\n157-180\n3-19,30-61,61-89,149-180\n42-65,91-109,143-167,167-193\n27-60,60-73,73-91,100-115,115-124,124-134,159-201\n17-48,48-51,51-78\n129-132,158-180\n17-35,48-69,325-343\n20-38,48-70,321-338,338-350\n44-75,167-193\n38-59,59-80,161-180\n46-71,151-165,165-195\n166-194\n28-57,57-96,158-177,177-183\n39-53,58-72,75-93,109-127,163-180\n2-15,24-63,63-100,134-149,149-178,178-180\n26-57,57-63,63-93,147-172,172-178,178-182\n30-49,49-52,52-65,65-101,144-179,180-215,263-303,303-338\n20-33,33-62,68-93,141-160,160-162,162-178,178-203,203-219,267-281,281-300,304-324,324-326,326-341\n43-70,170-190\n38-50,56-60,65-72,72-91,149-169,169-191\n49-72,166-180\n48-72,168-192\n38-57,65-83,158-180\n37-63,74-85,150-168,190-208,211-229,288-305,307-324,338-365\n50-70,70-71,76-80,80-83,87-99,164-181,183-203,275-290,290-300\n294-319\n296-319\n48-80,183-192,296-314\n47-79,158-170,170-175,175-185\n41-65\n48-73\n-2-2,2-4,4-19,19-24,24-27,27-29,40-58\n36-54,54-61,61-76,167-193\n24-43,43-68,168-192\n26-38,39-69\n19-31,31-34,37-66,302-320\n174-195,276-289,289-306\n-1-1,1-22,22-35,35-47,47-66,66-76,76-86,86-93,93-96,96-121,121-128,128-140,140-148,148-170,170-190\n4-28,43-76,76-87,160-178\n39-48,62-91,154-179,179-181\n43-57,57-62,62-80,165-195\n30-77,77-81,81-94,164-196\n34-47,47-58,58-85,154-169,169-180\n48-71,167-193\n44-69,69-71,71-86\n5-29,56-87,97-115\n44-82,158-202\n47-65,165-195\n39-63,169-191\n164-196\n51-75,177-195,290-308\n163-191\n43-61,174-190,190-201,212-230,278-296\n45-68,163-190\n50-76,165-189\n51-79,155-190\n41-61,61-81,86-99,130-138,172-190\n178-198,202-229,276-308\n180-192,216-236,276-308\n189-212,218-233,266-279,285-298\n20-67,67-70,70-96,148-175,175-185\n54-85,289-316\n35-46,46-54,54-58,58-60,60-62,62-85,288-310,317-325\n44-76,163-197\n31-52,59-87,87-99,149-178,178-182\n40-78,160-200\n36-55,55-58,58-61,61-63,149-166,166-170,170-172,172-192,278-296,301-321\n42-58,61-78,78-90,152-170,178-194,194-213,270-288,293-313\n292-314\n47-71,169-191\n42-78,164-196\n30-61,61-92,144-170,170-178,178-182\n47-81,169-201,278-291,291-319\n42-81,163-200,282-318\n41-69,69-81,167-188,188-203,288-315\n46-80,167-196,290-316\n50-78,165-193,193-205,293-318\n48-76,167-203,298-320\n44-62,285-303\n47-76,165-195\n49-71,168-192\n38-84,149-165,165-195\n33-41,44-52,52-55,55-82,83-102,150-163,168-192\n26-55\n30-41,41-83,158-166,166-194\n-28-28,28-53\n-7-7,7-25,51-76,81-103,132-143,150-210\n-5-5,5-22,25-43\n0-25,38-46\n-17-17,17-25,25-28,28-37,37-44,44-45,61-69,80-100\n-11-11,22-40,155-205\n-4-4,16-30,30-60,60-90,90-111,131-142,156-176,176-180\n29-57,60-89,151-176\n35-80,152-179,179-181\n44-70,165-192,287-304\n46-77,167-193\n46-74,165-195\n43-73,168-192\n34-47,53-76,165-182,182-191,286-294,294-297,297-315\n37-45,58-76,158-175,175-179,179-196,275-297\n44-72,168-189,292-315\n51-74,167-190,282-313\n33-59,59-61,61-69,69-81,99-117,156-174,274-293,293-301,301-303,303-305,319-337\n32-45,45-50,50-51,54-58,58-59,61-65,65-67,70-74,74-75,99-117,275-293,293-295,295-298,298-306,306-318,318-336\n-2-2,2-16,32-50,97-116\n153-170,171-189\n-13-13,14-16,16-45,50-83\n-14-14,18-32,32-38,111-132,171-189\n50-71,170-190\n-12-12,171-189\n-10-10,10-33,35-54,54-66,66-79,79-90\n14-31,33-49,50-69,75-93,97-115,127-147,153-166\n6-31,31-40,40-71,71-89,89-91\n-5-5,5-19,19-23,23-45,45-49,49-53,53-63,63-78,78-102\n-12-12,49-60,60-78,98-113,113-132,168-192\n2-14,14-18,18-26,26-35,35-54,77-103\n0-11,11-35,35-55,55-57,57-63,63-71,71-89,89-91\n-1-1,1-14,14-22,22-34,34-41,41-46,46-53,53-59,59-66,66-69,69-73,73-96,96-117,117-119,119-127,127-129,129-135,135-148,148-159,159-168,168-192\n0-31,31-62,62-84,84-88,88-92\n0-28,28-42,48-62,62-80,80-94,94-104,104-114,114-138,138-142,142-150,150-158,158-160,160-174,174-180\n0-12,12-26,26-43,46-77,77-97,97-120,160-200\n-1-1,1-20,53-72,72-90,98-112,112-116,116-130,150-167\n0-19,19-49,49-89,89-91\n34-61,61-64,64-71,71-79,79-102,102-118,118-121,121-145,145-162,162-166,166-180\n-3-3,3-16,16-41,43-62\n8-25,29-51,51-53,53-57,62-72,76-94,142-160,163-178,178-182\n16-43,43-52,52-58,58-62,62-70,70-95,105-123,128-136\n-1-13,18-31,31-60,60-78,83-104,104-112,112-122,126-149,162-179\n5-17,17-46,56-69,75-88,127-145,202-220,224-235\n0-39\n19-33,33-35,37-55,162-180\n-11-11,46-74,74-87\n3-16,22-30,36-49,67-84,84-96,98-105,117-127,127-136,136-143,143-168,171-189\n31-49,97-122,122-138,138-163,169-191\n16-24,44-59,59-78,166-194\n168-192\n51-73,167-193\n168-192\n-10-10,22-42\n-18-18,29-44\n-10-10,21-27,27-45\n47-87,168-192\n37-80,80-115,159-201\n45-68,72-88,88-92,92-97,97-106,106-110,110-113,117-129,142-165,165-168,168-192\n44-66\n44-67\n-27-27,42-68\n42-84,165-195\n31-64,71-89\n36-47,60-72,72-82,135-149,153-207\n34-64\n-2-2,2-28,41-62,62-85,166-194\n-3-3,3-23,39-70\n0-29,74-117,117-154,154-170,170-190\n88-145,145-170\n-26-26,49-60,73-148,162-198\n96-144\n0-29,39-60,62-80\n0-32,34-56,56-77\n0-36,36-56,56-75\n0-33,35-56,56-64,64-80\n83-94,98-129,129-153,153-177\n-17-17,80-97,97-140,146-150,152-163,163-178\n-1-1,1-6,6-14,14-16,16-23,23-24,26-33,33-57,65-68\n0-14,32-59\n66-83,83-87,87-110\n65-86\n85-96,96-102,102-124,124-139,171-189\n69-111\n40-74,75-79,79-85,85-86\n-1-1,2-25,75-93,97-115\n72-102\n48-94,149-172,172-175,175-178,178-182\n44-76,76-78,78-80,143-159,159-180\n46-85,163-197\n-3-3,3-25,50-80\n50-69,69-77,77-95,137-155,155-179,179-181\n49-60,60-80,100-118\n39-52,52-57,57-99,115-133,165-180\n163-197\n44-62,62-63,69-72,72-106,171-189\n38-56,63-81,104-124\n64-99,99-112,171-189\n62-106,108-122,139-161,171-189\n45-55,55-92,139-157,158-176\n105-123,160-200\n34-46,47-75,77-89\n-15-15,24-68,75-96\n53-87,170-190\n56-79,167-193\n52-69,171-189\n143-170,170-190\n123-133,135-141,141-143,143-146,146-155,155-163,163-165,168-170,171-189\n3-28,92-131\n58-75,75-98,163-197\n49-80,165-195\n88-106,165-195\n49-74,88-106\n53-76\n52-73\n69-88,161-179,179-181\n53-81,166-194\n113-131,146-164,164-180\n-31-31,50-74,108-144,148-180\n-9-9,23-48\n0-16,31-48\n128-149,149-156,167-193\n-9-9,15-26,44-66\n51-106,156-204\n70-102,105-126,142-161,161-179,179-181\n68-87,87-112,112-120,120-140,140-144,148-155,157-203\n-3-3,22-76\n31-46,46-70,70-90,90-105\n49-69,84-105\n42-90,157-203\n159-201\n35-62,62-64,64-67,67-71,72-82,82-92\n53-74,74-101,112-129,160-200\n68-86,86-104,142-161,161-163,163-177,177-183\n25-71,71-76,76-92\n53-104,109-144,158-202\n162-179,179-181\n51-84,164-196\n62-80,123-144,144-154,162-164,164-174,174-180\n43-108,108-118,118-134,160-176,176-180\n-1-1,1-23,34-70,70-90\n2-12,26-59,59-87,151-176,176-184\n42-64,64-66,66-70,70-84,84-99,143-166,166-194\n36-46,46-55,59-82,135-154,154-177,177-183\n88-120,120-122,122-133\n51-77,77-95,163-197\n160-200\n159-201\n12-16,42-66,66-91\n63-74,152-165,165-168,168-180\n52-79,168-192\n56-76,166-194\n54-77,169-191\n161-199\n41-66,66-68,68-86,164-196\n35-48,53-80,80-95\n154-206\n162-198\n57-79,164-196\n59-78,83-98,98-100,100-135\n160-200\n48-94\n64-82,170-190\n63-75,75-104\n59-81,81-106\n71-100\n78-99\n67-94,95-106,168-192\n71-89,89-93,93-111,169-191\n-9-9,19-29,29-38,38-48\n-11-11\n82-105,105-115,115-142,154-173,176-184\n104-123,126-147,147-155,155-170,170-190\n-12-12,60-77,77-89,98-118\n-4-4,4-18,56-87,94-115\n-12-12,36-57,57-72,72-74,74-91,102-127\n53-83,157-203\n49-70\n56-89\n58-74,74-106,108-120,146-158,158-161,165-177\n-9-9,19-35,37-54,54-74,78-97\n48-80,80-101,155-205\n36-57\n123-151\n170-190\n168-192\n-6-6,6-26,107-126,151-173\n-17-17,31-46,65-85,93-149\n39-51,63-77,77-82,82-97,97-100,100-130,130-163,163-178,178-182\n0-19,19-22,22-56,56-69\n0-26,34-50,55-75\n48-80,166-194\n46-71,71-77,77-96,158-202\n45-70\n41-78\n-12-12,52-83,163-197\n37-62\n141-153,153-155,161-180\n-14-14,140-151,155-205\n24-43,52-56,56-60,60-72,72-76,76-80,80-91,94-114,122-140,155-173\n-23-23\n-23-23\n144-164,164-196\n-10-10\n-12-12\n63-119,157-203\n92-128,128-135,135-138,138-140,146-214\n117-126,126-140,148-180\n99-111,111-117,117-131,134-180\n48-69\n0-27,35-72,83-104\n43-70,81-104\n-23-23,47-67\n54-118,152-208\n121-133,136-178,178-182\n7-27,36-68,68-78,78-98\n36-67\n50-121,160-200\n64-101,103-139,139-142,142-145,151-209\n0-3,24-62,76-98\n15-28,28-31,34-66,69-91\n46-101,161-199\n8-27,37-67,72-94\n143-170,170-177,177-183\n46-75,81-105\n17-45,68-86\n16-41\n51-81,143-161,161-180\n79-105,110-124,141-219\n113-145,145-152,152-154,154-157,157-165,165-195\n50-83,83-106\n35-59,67-94,94-131,131-152,152-155,155-177,177-180\n107-120,120-127,127-146,146-152,152-156,156-204\n14-30,30-41,41-52,52-63\n81-100,101-119,145-170,170-180\n65-105,105-125,125-131,131-134,134-180\n88-115,115-146,146-156,156-160,160-163,163-175,175-185\n79-97,100-123,131-153,157-175\n43-72,72-94,97-119\n-13-13,41-69,83-104\n-13-13,47-66\n109-133,140-157,157-203\n25-46,52-65,71-95\n52-85,157-203\n58-79\n53-76,163-197\n38-70,163-180\n28-39,55-77,170-190\n4-24,24-39,53-79,143-159,165-195\n55-79,151-169\n94-121,154-168,168-172,172-188\n69-87,87-99,99-106,106-120,120-126,129-137,137-140,140-142,164-180\n48-70,83-101\n48-72\n-11-11,164-196\n-10-10,15-36\n-13-13,164-196\n-16-16,35-55\n106-137,137-147,153-207\n120-140,161-199\n-10-10,24-43,48-75\n169-191\n163-197\n165-195\n-25-25,25-51\n-9-9,18-36\n168-192\n166-194\n61-88,88-104,104-130,130-149,149-211\n62-98,98-123,136-154\n61-84,84-92,92-114,114-140,140-143,143-147,147-152\n60-95,95-105,105-112,112-130,130-149,171-189\n53-83,159-201\n165-195\n43-91,166-194\n-13-13,47-67\n62-85,85-89,89-103,116-136,157-175\n16-37,37-54\n57-92\n28-55\n45-93,93-97,97-111,118-132,132-138,142-152,152-180\n69-83,83-103,103-126,138-156,156-166,166-176,176-179,179-181\n54-94,166-194\n0-22,48-66\n0-28,49-57\n0-19\n164-196\n41-83,163-197\n55-72,72-74,74-83,83-96,110-121,121-129,148-180\n-17-17,48-67\n-20-20,48-69\n74-103,171-189\n103-122,156-180\n145-179,179-181\n54-74\n-14-14,169-191\n168-192\n-12-12,84-102,102-128,128-130,130-144,144-159\n-16-16,105-147\n1-26,67-81,81-99,102-117,117-141,141-144,144-156,156-158,158-169,169-171,171-174,174-186\n-1-1,1-40,49-54,54-78\n0-24,24-49,58-84\n145-157,157-159,159-201\n46-81,164-196\n17-35,47-71,71-79,79-98,158-202\n0-26,45-67\n-19-19,42-66,72-90\n-13-13,39-67\n43-79,162-198\n34-65,74-89\n-10-10,27-51\n-9-9\n167-193\n166-194\n156-204\n-9-9\n-9-9\n169-191\n164-196\n55-105,161-199\n62-130,130-132,132-228\n87-95,141-161,161-199\n69-80,80-83,87-136,169-191\n74-96,99-108,155-205\n44-70\n-9-9,9-51,51-53,53-84\n40-69\n7-24,24-42,64-78,83-97\n40-70\n47-66,66-91,159-201\n61-89,89-92,92-95,95-118,118-124,124-149,149-180\n155-180\n32-46,46-63\n43-60,60-80,80-94,130-149,149-159,159-201\n65-106,113-117,117-133,160-200\n72-82,82-85,85-89,89-112,112-122,122-128,128-132,132-142,142-162,162-170,170-180\n-4-4,9-25,25-60\n17-40,40-71,72-93\n51-89,130-149,154-180\n60-113,124-129,129-143,143-148,154-206\n78-98,100-136,136-138,138-147,147-158,158-202\n93-148,166-180\n99-151,167-193\n0-27,27-51,54-82\n89-107,107-109,126-137,137-158,160-180\n0-7,7-9,9-13,13-18,18-38,38-54,99-148,148-154,154-166,171-189\n-13-13,41-59,59-79\n166-194\n-13-13,104-141\n161-199\n49-82,163-197\n123-150,152-170,170-180\n-6-6,6-10,10-27,45-66\n0-24,40-66,71-97\n44-66\n51-77,163-197\n36-68\n47-95,158-202\n139-154,156-204\n137-156,160-200\n46-66\n42-83,159-201\n60-75,75-81,149-180\n37-57\n166-194\n67-102,102-120,120-126,126-138,138-158,158-162,162-198\n90-108,108-134,138-141,144-162\n-8-8,8-29,29-47,49-83\n45-56,62-70,70-80,80-101,101-107,107-108,116-117,119-126,159-180\n166-194\n166-194\n84-114\n84-106,106-110,110-120,120-144,155-178,178-182\n138-155,155-158,158-166,166-180\n70-112,112-114,114-134,134-178,178-182\n113-148,148-168,168-192\n44-74\n48-82,89-113,113-127,127-132,132-147,147-153,153-160,160-162,162-179,179-181\n14-45\n65-88,88-96,96-103,103-105,105-125,125-150,150-154,154-157,157-179,179-181\n-5-5,5-30,43-68\n71-94,94-102,102-126,126-146,146-174,175-185\n-12-12,41-87,161-199\n56-80,80-85,157-177,177-180\n52-71\n53-64,64-99\n25-54,54-57,66-81,81-104\n52-80,80-82,82-95,167-193\n53-75,169-191\n33-47,47-61,61-72,163-179,179-181\n57-83,146-168,169-191\n74-92,104-123,123-138,138-152,152-154,154-158,158-163,163-178\n46-73,73-93,164-196\n54-87,152-180\n54-86,164-180\n-4-4,11-32,32-35,35-39,39-42,42-62,68-100\n-10-10,169-191\n-12-12\n-10-10,170-190\n163-197\n160-200\n0-2,2-31,31-45,45-54,54-65\n156-204\n84-101,101-103,103-123,123-144,144-152,152-160\n64-80,80-106,106-111,111-135\n57-99,165-195\n146-156,156-180\n13-33,42-77\n55-92,160-200\n48-83,160-200\n48-67\n50-68\n56-96,121-141,147-163,163-177,177-180\n50-73\n35-60\n44-82,155-205\n48-75,75-95,164-196\n49-67\n47-67\n-2-2,2-5,170-190\n162-198\n0-24\n190-212,240-255,255-274\n-1-1,1-5,5-20,20-27,27-29,29-32,32-47,77-96,96-122\n-3-3,3-27,27-46,46-51,51-54,54-74,74-82,82-86,86-90\n-19-19,68-90\n111-123,123-149,158-169,169-191\n-5-24,24-36,36-60,147-175\n-9-17,17-27,27-39,39-41,41-64,64-74,143-171\n-9-5,5-40\n-4-5,7-12,12-42\n23-35,43-65,75-95\n36-71\n-2-16,22-40,44-62,250-272,342-358\n59-82\n69-95,95-122,168-185,185-197,197-200,207-216,216-229\n78-105\n210-232,275-293,304-322,322-329\n211-246\n263-286,287-306,306-308,308-322,327-349\n264-276,276-281,281-311,313-323\n248-270,270-290,290-293,293-297,297-307,307-326\n152-160,166-169,169-189,189-217,248-266\n158-195,195-196,217-235\n-11-11,159-201\n-5-5,95-113,121-149,149-167,167-173,173-187\n8-37,303-323,323-356\n17-35,301-312,312-314,314-357,357-372\n48-68,68-71,71-84,154-164,164-168,173-176,176-184\n132-165,165-195\n104-130,143-168,168-180\n342-370\n2-4,4-22,22-30,30-40,295-316,316-327,330-344,344-362\n45-76,168-197\n46-64,64-79\n57-87,192-215\n52-69,69-80,192-223,230-248\n59-79,184-220,220-222,222-240,240-246,275-284,296-307\n45-62,62-83,90-98,181-198,201-218\n272-291,291-300,300-323,329-347\n210-221,221-223,223-242,274-285,285-297,298-323,326-347\n269-287,298-323,323-352\n50-68,71-90,178-205,211-221\n48-66,70-88,179-198\n63-81,90-108,172-194,194-212\n-9-9,9-13,13-28,28-32,32-35,35-54\n-9-12,15-42\n-9-5,5-22,25-48,156-171\n-10-18,26-44,144-162\n13-42,166-184,339-357\n167-193\n50-90\n-17-17\n-6-7,7-30,30-33,33-37,37-58,151-169,169-174\n-19-6,6-18,18-26,26-51,51-67\n-11-5,5-23,129-137,149-169\n-13-32,138-147\n64-90\n89-115\n167-193\n76-104\n-17-17\n-5-13,158-186\n110-125,125-138,138-141,147-180\n1-4,4-16,21-34,324-361\n3-8,324-363\n21-40,45-67,67-77,77-96,96-116,116-132,150-172,172-188\n-11-11,11-51\n33-77,81-99\n47-90\n39-87,87-100,100-104,104-140\n60-120\n56-124\n-12-12,35-61\n-23-23,28-54\n124-174,174-186\n18-42,42-68\n-20-20,20-23,23-46\n27-58,117-128,128-142,142-144,144-171,171-176,176-184\n-6-6,6-14,14-30,79-101\n-1-1,17-63,78-102\n48-72,126-149,168-192\n-2-2,12-56,56-78,78-82,82-85,85-95\n25-38,38-42,42-46,46-71,82-100,100-108,108-131\n43-56,56-59,59-73,73-76,76-87,87-93\n29-81,81-99\n36-85,85-102,102-142\n44-71,71-109\n-13-13,13-43\n130-154,159-201\n121-136,136-138,138-164,164-196\n0-6,18-90\n0-25,25-58\n41-87,87-92,92-96,96-127,127-145\n44-74,74-87,87-93\n0-9,9-41,41-66,66-80,80-100\n0-41,41-54,54-58,70-88\n61-96,96-104,104-107,107-109,109-138\n30-48,48-56,56-62,62-65,65-74,74-86,86-94\n0-28,28-62,76-86\n35-80,86-107,107-127,127-142,142-163,163-170,170-177,177-179,179-181\n0-15,32-46,46-66,66-82,82-85,85-89,89-91\n-2-2,2-33,33-36,36-43,43-76,76-88,88-90\n52-68,68-79,82-100,112-130,162-179\n-2-2,2-61\n10-17,21-42,42-60\n-27-27,40-48,48-60,60-73\n-1-1,1-14,14-24,24-26,26-43,43-57,57-74\n109-148\n114-132,132-154,154-167,167-193\n154-206\n169-191\n155-165,171-189\n-11-11,11-37\n-18-18,18-33\n33-83,88-92\n45-80,80-106,106-136\n51-129\n-7-7,7-79\n42-83,83-98,98-138\n43-63,63-67,67-81,81-99\n31-68\n18-68\n158-202\n132-149,149-174,174-179,179-181\n0-18,18-45,45-50,50-53,53-63\n0-27,41-59\n-11-11,24-45,45-49,49-51,51-53,53-67,129-164\n34-61,99-117,120-146\n39-72,72-81,81-101,106-132,132-151\n31-61\n36-56,56-77,77-97,97-114\n-9-9,138-153,153-155,157-203\n50-61,61-83,98-117,117-124,124-128,128-130,130-151,151-166\n37-68,110-128,136-160\n37-59,59-80,80-86,105-120,124-139\n-2-2,2-16,147-165,165-170,171-189\n33-45,45-55,55-80,93-104,125-146,150-169,169-191\n36-63,118-147\n45-61,61-65,65-97,97-118,118-138\n40-55,55-76,76-82,82-85,85-110,110-113,113-137,137-149,149-165\n-9-9,34-79,79-89,89-92,92-94,94-98,98-103,103-109,120-149,167-193\n-12-12,33-69,69-73,73-95,118-143,163-197\n51-76,82-98,101-117,140-167\n11-19,171-189\n-10-10,151-155,160-169,169-180\n-9-9,12-38,162-180\n58-87,87-89\n41-68\n139-149,170-190\n141-164,164-167,167-180\n155-205\n-27-27,32-56\n-16-16,29-48\n50-94,103-123,123-149,171-189\n41-50,77-95,154-180\n34-70,114-123,126-135,135-139,139-142,145-167\n14-27,27-38,42-62,68-78,94-112,154-180\n-18-18,28-36,36-43,43-60\n-11-11,11-28,31-51\n45-73,73-95,95-98,98-132,132-139,147-167\n23-42,42-46,46-54,54-71,148-166,171-189\n29-52,53-74,74-75,80-90\n-18-18,30-57\n51-85,161-199\n-18-18,18-38,38-71,167-193\n-10-10,47-64,64-84,161-199\n-9-9,63-83,168-192\n273-286,295-320,326-343\n293-321\n60-77,154-166,166-188,236-246,312-330\n8-32,36-45,45-65,65-81,154-162,169-188,222-232,232-236,241-251\n39-63,63-81\n42-73,91-102,107-116\n151-190,190-208,226-253,275-305\n146-156,156-162,163-192,192-212,271-303\n-10-17,36-69,292-343\n-1-22,35-71,292-336,340-359\n18-43,44-70,302-324,346-370\n-7-9,14-28,28-46,46-49,49-51,51-57,57-71,301-309,319-334,334-337,337-340,340-350\n141-151,180-207,275-300\n143-161,176-194,266-297\n-4-13,13-25,36-67,296-330\n-1-22,31-69,298-330,349-359\n27-62,300-330\n32-63,301-324\n50-58,71-89,173-191,192-209,266-283,283-286,286-301\n35-59,59-71,176-194,270-296\n40-63,63-70,70-88,161-183,282-310,310-315\n44-76,76-89,136-144,155-170,170-181,285-302,302-325\n22-32,32-36,36-38,38-69\n-9-9,31-44,44-47,47-70,293-311\n33-55,302-323\n-14-14,36-69,167-193\n-10-10,37-67\n171-192\n59-84,84-100,164-195\n-21-21,34-67,74-90\n56-79,79-97,140-158,158-165,165-185\n57-75,75-79,79-82,82-84,84-86,86-98,156-176,176-198\n37-72,294-328\n32-70,294-324,324-341,341-349\n62-80,167-192\n161-197\n39-62\n32-47,47-63,298-316\n40-58,160-168,170-192,295-313,313-335\n71-94,117-144,149-188\n64-81,81-91,91-93,93-101,101-117,117-141,141-164,164-193\n46-82,166-194\n62-93,161-188\n63-90,141-166,166-185\n171-192\n171-190\n23-41,43-61,76-94,115-123,170-190,284-294,294-310\n175-221,288-311\n49-75,175-217,283-312\n35-67\n-5-13,36-69,74-84\n167-195\n170-197\n51-80,105-117,117-124,128-142,157-186,281-311\n51-76,282-304\n7-26,26-31,34-66,167-194,283-318\n27-69,166-209,282-319\n167-200,215-238\n168-183,183-202,217-235\n55-77,149-180,285-308\n57-81,154-181,286-307\n43-79,162-198\n47-73,166-194\n-12-12,40-65,65-85,157-180\n40-96,160-180\n54-68,73-87,152-178,178-180\n18-34,34-44,44-49,49-54,54-64,64-68,68-84,84-97,167-193\n123-131,155-170,170-179,179-181\n164-180\n169-191\n171-189\n169-191\n39-65\n-1-1,1-3,3-5,5-15,34-62\n19-37,43-66\n3-10,32-68\n-13-13,13-28,28-48,48-65\n43-78,160-200\n54-74,165-195\n34-62,68-86\n33-62\n36-74,165-195\n43-84,164-180\n170-190\n171-189\n25-62,71-88\n-12-12,25-54\n41-77,162-180\n47-74,167-193\n147-177\n44-64\n39-53,53-57,57-65,65-82,164-180\n66-85,171-189\n40-78,84-88,165-195\n282-298,298-316\n286-313\n42-72,88-112\n46-73,93-111\n37-72,87-105\n42-65,76-98\n181-204,259-267,277-306\n180-190,190-192,192-199,199-210,276-306\n31-43,45-65,296-328\n294-320\n-1-20,25-37,37-69,296-319,338-359\n40-67,295-319,329-348,348-370\n38-69,264-277,277-313\n23-39,39-50,50-68,283-321\n22-40,295-317\n51-68,68-86,159-176,176-178,178-199\n59-89,155-177,177-180,180-195\n172-197,201-216,268-281,281-290,290-303,303-313\n171-185,185-211,268-283,283-303\n190-208,263-292\n188-210,259-282\n0-23,23-36,46-58,58-61,65-77,82-98,98-103,103-116,133-151,165-176,176-184\n0-27,119-177\n-14-14,14-50\n0-22,162-179,179-181\n-1-1,1-17,95-122,122-124,124-136,147-170\n-2-2,2-8,8-26,110-152,155-174\n-3-3,3-16,18-55,107-123,123-144,146-176\n-11-11\n-1-1,1-33,129-149,154-180\n-26-26,33-50,102-161,161-168,168-180\n17-25,85-94,100-103,103-132,132-136,136-154,154-156,156-172\n147-158,158-165,171-189\n149-167,171-189\n-13-13\n-1-1,1-20,34-45\n0-18\n54-81,81-116,116-151\n52-73,77-80,81-123,123-126,126-145\n95-121,121-124\n-26-26,26-28,28-31,31-50,164-171,179-181\n-4-4,4-15,123-142,142-148,148-162,162-178\n171-189\n0-18,30-48,144-180\n0-14,14-20,20-21,109-151,155-178,178-182\n153-166,170-190\n54-72,100-126\n56-69,69-86,86-89,89-92,92-115,118-125\n171-189\n111-139,139-161,311-323,323-344,344-348,348-370\n116-134,288-299,299-319,319-343\n0-18,41-59,329-358\n-13-7,7-9,9-11,11-13,13-37,326-335\n-7-14,14-30,328-353\n1-31,293-319,323-342,342-361\n0-4,4-16,101-125,227-234,234-266,312-336,336-349,349-356,356-360\n91-107,107-109,109-127,225-248,248-251,251-271,271-286,291-309,309-329,335-364\n63-75,75-78,82-86,91-102,102-106,106-111,111-133,262-275,280-287,294-322\n91-124,124-133,176-194,258-276,292-310,342-350\n-3-24,24-39,321-336,336-357\n-4-30,324-336,336-351,351-353,353-356\n141-163,163-170,170-174,174-199\n197-232,240-271\n3-26,113-159,224-236,236-254,288-307,307-338\n-5-14,106-147,227-247,297-316,316-325,325-332,332-335,335-352\n274-291,294-313,317-337\n295-314,321-339\n305-323\n4-29,211-248,347-364\n-11-17,17-32,32-52,65-83,200-231,238-260\n-13-14,14-29,180-188,191-236,236-247,247-263,331-340\n191-207,207-209,211-242,242-260\n191-215,215-232,242-246\n192-210,212-219,223-232,232-238,241-256,256-277\n145-164,164-188,197-226,238-258,258-266,266-289\n193-249,249-278\n195-231,232-273\n0-2,2-9,9-11,11-37,44-57,68-86,282-301,316-360\n-1-37,42-61,285-308,317-359\n12-19,19-39,307-330,330-346,346-372\n3-28,33-59,310-341,341-363\n88-123,317-332,332-375\n19-33,46-53,66-77,77-85,85-118,326-376\n-11-4,4-22,79-102,102-116,329-347\n0-21,76-102,341-360\n109-130,130-153,153-169,169-185,196-209,209-214,214-232\n107-146,146-157,157-185\n112-155,202-217,222-249,250-277\n114-144,144-146,146-159,175-193,193-202,213-258,258-276\n104-124,124-127,127-135,135-146,204-238,238-242,242-263\n125-145,145-165,217-227,227-256\n82-104,104-117,117-122,122-138,264-297,300-309,329-351\n78-103,103-121,121-123,123-145,233-253,263-295,295-321\n89-100,100-108,111-115,115-121,121-133,244-271,301-312,312-318,318-356\n96-99,113-133,243-261,261-285,322-342,342-345,345-350,350-362\n296-315\n297-315\n221-237,237-274,275-285\n171-189,220-236,239-253,253-256,256-272\n233-261,265-297\n9-41,321-360\n321-360\n-3-34,295-321,329-357\n3-27,324-361\n121-130,130-162\n126-154,154-164,209-246\n202-216,216-220,220-233,233-259,259-277\n202-220,220-222,222-229,229-231,231-242,242-259,259-282\n213-224,224-232,232-237,239-269,269-280\n302-323,327-370\n330-367\n25-45,45-63,281-305,305-310,310-329,329-364\n-5-1,24-40,43-59,284-301,303-312,312-321,321-333,334-355\n-1-19,19-24,24-35,315-350,350-353\n100-125,125-129,129-148,150-172\n95-103,107-144,195-213\n2-19,281-299,320-339,343-360\n-2-2,2-13,13-44,44-49,49-68,76-104,104-124,124-128,128-136,136-144,144-152,152-166,166-194\n-19-19,19-42,42-46,46-49,49-63,63-78,90-148,162-166,166-178,178-182\n70-78,100-141,146-150,150-168\n169-191\n163-197\n-8-8,10-39,40-51\n-1-1,1-13,16-42\n0-38\n-41-41\n-12-12,12-15,15-39,39-62,73-93,100-145,169-191\n-12-12,12-32,32-35,35-54\n-10-10,20-40\n44-68,72-90\n10-33,321-339,345-370\n2-29,331-362\n339-370\n-8-18,18-20,24-45,320-350,350-352\n-1-25,26-35,35-36,329-351,351-354,354-359\n23-31,46-56,336-371\n16-26,26-29,29-33,309-321,340-376\n-46-46\n-10-10,10-23,23-40,40-43,43-46,46-80,80-87,87-93\n-28-28,54-79\n-1-1,1-3,3-28,34-51\n140-220\n-14-14,108-150,150-172,172-188\n-27-27,36-56\n0-8,8-20,20-34,43-64\n168-192\n-13-13,17-33\n42-72,72-90\n0-79\n8-31,118-173,173-187\n0-4,4-11,11-13,13-26,26-43\n171-189\n-10-10\n111-168\n112-164\n124-146,146-151,151-162,162-190\n5-17,17-18,110-129,130-143,143-149,149-163,163-165,165-185\n108-133,257-283,288-321,321-353\n105-114,248-271,292-340,340-360\n295-313,315-333\n113-135,135-157\n124-144\n-1-4,4-22,289-303,303-309,314-359\n1-15,293-310,317-361\n-8-19,19-50,50-60,61-77,77-80,80-105,328-348\n-7-19,19-39,39-45,45-48,48-56,56-112\n61-79,79-92,92-118\n42-60,66-75,90-117\n105-120,120-122,122-124,124-186,186-214,214-238,238-263\n104-125,133-159,159-179,181-221,224-241,241-249,249-264\n129-162,162-178,178-185,185-189,194-204\n123-133,133-136,136-139,139-161,161-181,181-191\n134-153,153-179,205-226\n130-164,168-175\n121-137,140-153,153-163,163-172,172-192\n146-170,170-190\n2-5,5-28,31-53,65-169\n0-3,3-23,23-49,54-168,168-174,174-180\n239-275,275-291,297-351\n241-273,273-293,298-350\n98-112,112-121,121-139,139-157\n90-130,130-154,154-167\n292-313\n292-313,318-323\n91-104,110-134\n92-105,110-134\n229-254,254-256,256-258,258-264,271-292\n232-258,270-292\n278-296,314-333,333-359\n1-18,279-304,315-361\n5-27,52-82,82-115,327-361\n6-25,75-118,327-361\n114-129,134-181,181-227,233-237,237-254\n104-124,124-127,127-129,129-158,158-179,179-193,193-195,195-222,226-232,232-246\n61-80,83-116,116-118,118-121,121-157\n40-58,74-97,97-105,105-110,110-113,113-151,164-173\n265-282,282-295,295-302,302-313,313-332\n241-253,253-275,275-279,279-295,295-302,302-319,319-346,346-361\n281-289,294-314\n295-313\n114-137\n114-138\n-4-17,17-22,22-25,25-45,61-71,71-78,78-102,109-117\n2-32,32-48,48-68,74-101\n126-157\n126-157\n42-60,320-352,354-364\n38-56,322-360\n106-132,135-155,155-169,169-195,208-231,231-255\n106-132,132-153,153-155,155-170,170-187,187-200,211-231,233-255\n79-99\n82-99\n28-54,54-75,80-100\n-13-13\n-4-4,4-27\n0-2,2-21,21-53,53-71\n-13-13,122-134,134-163,163-176,176-184\n-33-33\n63-79,79-101\n14-33,326-347\n152-166,166-194,194-207\n-5-5,5-15,15-25,25-60\n28-41,43-74,162-198\n45-72,169-191\n14-31,79-106,243-253,253-281,313-327,327-347\n-13-13,56-79,171-189\n-18-18,166-194\n-4-4,4-9,9-54,102-122,123-146,146-214\n-14-14,14-32,37-66,78-97,97-114,117-144,144-154,165-195\n-21-21,34-56\n7-31,162-178,178-182\n65-82,281-309\n-13-13\n12-30,149-160,160-167,167-174,174-180\n43-70,164-196\n9-34,34-65\n36-64\n-1-1,1-12,12-20,20-43\n-14-14\n-18-18,32-57\n126-136,138-144,144-152,152-208\n51-69,101-119,134-151,151-179,179-181\n30-55,55-66,90-116,159-177\n46-77\n46-67\n50-67,67-69,69-77,77-81,81-100,161-179,179-181\n45-69,294-312\n49-69,292-312\n62-72,72-93,93-100,100-119\n40-58,63-81\n46-67\n-12-12\n161-199\n54-83\n58-75,75-97,97-106,106-111,129-136\n-12-12,12-15,15-20,20-21,26-35,35-54,123-132,132-145,145-160,160-168\n6-16,16-26,27-35,38-60,60-79,79-101,101-138,138-140,140-143,143-154,157-165\n26-59,69-90,147-179\n-12-12\n58-76,168-192\n-9-9,46-66\n46-65,296-314\n46-65,296-314\n44-74,164-178,178-182\n51-60,60-88,114-132,156-170,170-180\n47-67,161-199\n57-82,171-189\n172-191\n-11-11\n-6-6,8-33\n52-62,62-74,96-122,133-141,171-189\n14-40,44-65,68-79,79-87,87-96,98-119,153-171\n25-43,43-63,71-89,89-90,93-98,98-117,165-183\n20-61,61-70,70-86,92-119\n21-39,39-61,82-110,135-152\n26-47,47-57,64-82,86-104,132-150,163-181,277-295\n25-44,65-83,85-103,146-160,160-180,278-304,308-326\n45-78,81-94,141-163,163-165,165-168,168-192\n10-26,28-48,48-70,166-175,175-185\n51-62,62-65,65-92,168-191,275-293,329-347\n82-91,166-179,179-188,188-208,295-317\n41-55,55-60,60-73,102-126\n44-75,97-126\n89-117,243-271\n48-58,73-91,157-178\n46-78,78-89,161-179,179-181\n46-72,72-90,90-103,103-110,110-114,114-123,123-126,126-130,130-134,134-170,170-180\n42-75,164-196\n17-36,56-74\n-10-10\n14-35,35-38,38-46,46-58,58-61,61-87,87-93\n0-5,5-23,23-59,81-99\n0-20,20-34,34-36,36-54,54-70\n20-83\n-34-34\n0-10,10-24,24-68,101-142,142-165,165-195\n-32-32,32-35,35-49,49-51,51-81,81-99\n0-2,2-15,15-64,72-82\n36-67,67-84,84-93,122-147,147-152,152-154,154-163,163-167,167-193\n-10-10,15-40\n-15-15,46-68,72-97,114-130,130-142,142-145,145-147,147-150,150-178,178-182\n-14-14,36-60,91-99,120-142\n125-150\n-23-23,35-39,142-152,162-198\n0-5,5-21,21-41,41-57,57-60,60-66,66-76,76-86,87-97,97-102,102-105,105-107,107-122,122-140,143-157,162-198\n-16-16,151-163,163-197\n-1-1,1-17,17-35,62-93,128-163,169-191\n54-67,67-76,76-93\n55-94\n19-28,28-30,34-67,67-101,101-129\n27-62,62-92,92-101,101-120\n15-32,32-45,50-70,70-88,88-116,226-244,247-265\n22-37,37-38,40-45,45-57,57-76,81-99,149-167\n166-194\n51-76\n57-78,99-117\n57-78,163-186\n3-24,24-41,41-78,92-96,136-157,157-159,159-180\n142-166,166-168,168-192\n47-78,137-145,167-193\n22-45\n11-27,27-33,33-60\n38-53,53-55,55-58,58-62,64-67,67-89,149-171,171-189\n42-61,61-81,83-90,160-200\n2-18,18-29,31-57,57-66,66-77\n30-67,145-163,168-192\n4-23,28-35,35-42,42-70,93-115\n-16-16,16-22,22-30,30-55\n0-19,19-42,52-70\n38-90\n-10-10,11-29,29-55,55-58,62-74\n34-48,50-71,71-83,83-85,85-90\n-15-15,15-17,17-19,19-30,30-35,35-50\n8-26,26-35,35-45,45-55,55-57,57-72\n29-49,49-77,77-90,157-180\n19-37,51-71,71-90,144-159,164-196\n0-11,19-71,71-78,78-90\n-9-9,16-29,29-35,35-38,38-42,42-49,49-54,54-58,58-62,62-77,82-98\n49-71,171-189\n-8-8,12-25,125-155,155-161,161-179,179-181\n-2-2,2-14,14-39,39-65,79-101\n11-19,120-147,147-156,156-167\n40-49,52-58,58-86,91-102,106-118,122-153,159-188\n42-52,57-73,73-86,86-99,101-118,120-151,161-188\n44-61,61-77,81-106,155-180\n4-24,24-56,56-58,58-97,99-114,114-119,119-131,131-140,140-147,147-150,150-167,167-193\n-4-4,4-20,28-52,64-83,84-126,126-148,150-168,168-192\n-6-6,6-24,76-94,96-107,122-146\n-1-1,1-23,104-112,123-142,142-153\n26-85,156-204\n44-87,87-98,136-148,154-163,163-168,168-192\n51-65,65-69,69-88,100-108,134-158,158-173,173-180\n12-21,23-30,34-63\n20-37,37-46,46-49,52-54,73-91,146-158,158-178,178-182\n22-40,40-87,153-207\n39-54,54-56,56-85,146-164,167-193\n11-29,33-62\n38-53,56-78,158-178\n0-18,20-33,33-50\n-2-2,2-5,5-23,23-55,55-71,71-74,74-80,80-90\n111-134,134-153,160-178,178-182\n15-42,42-48,48-64\n9-17,35-58,299-324,334-342\n0-11,16-46\n20-48,48-55,55-63,63-66,66-84,84-89,89-91\n-14-14\n43-81,81-94\n12-25,25-41,41-70,70-82,82-84,84-100\n182-202,292-314\n44-74,150-168\n170-190\n56-79,79-83,83-84,159-176,176-187\n39-53,56-76,100-118,164-185\n227-249,280-298\n-10-10,29-54,54-60,60-74,74-88\n-9-9\n-9-9\n2-16,16-39,39-48,48-79\n171-189\n52-75,75-78,78-89,167-185\n51-67,67-87\n41-69,69-90\n-6-6,6-23\n169-191\n42-74,164-196\n31-67,67-89,89-91\n50-79,79-81,81-99\n52-79,79-95\n93-113\n61-80\n171-189\n24-55\n-2-2,2-7,7-16,16-23,33-70,70-77,77-84,84-90\n-2-2,2-20,22-41,41-47,47-53,59-72\n0-7,7-32,32-60,60-81\n51-60,63-69,69-96,111-132\n17-61,61-86\n33-43,46-52,57-92\n32-51,59-94,94-100,100-103,103-105,105-120\n163-187\n168-192\n164-196\n-13-13,13-32,32-58,60-72,72-108\n-11-11,110-118,136-175,175-185\n-27-27\n0-37,37-87,87-89,89-91\n110-175\n-2-2,2-5,5-9,9-27,27-29,29-31,31-69,69-80\n-10-10\n77-103\n-2-32,32-46,46-77,77-90,90-96,96-121,121-126,126-148,148-151,151-178\n-1-35,45-75,75-95,95-117,117-137,137-151,151-179\n-10-13,18-28,226-242,245-262,262-265,265-281,281-288,301-304,304-312,312-320,320-325,325-328,332-345,345-350\n-1-17,226-244,266-286,286-291,291-313,316-335,336-346,346-359\n-6-26,92-119,119-138,154-174\n0-12,12-20,20-22,22-24,24-36,86-113,113-136,161-180\n6-24,27-35,35-63,97-105,111-115,115-135,135-138,138-176\n-2-4,4-6,41-54,60-70,73-94,99-133,133-159,165-173,175-178\n0-7,7-11,11-31,48-58\n53-78,78-97,97-100,100-114,147-180\n59-79,165-195\n53-82,198-223,293-319,323-351\n53-81,198-215,294-323,323-333,333-345\n168-209,271-281,281-285,290-300\n101-121,123-155\n96-111,111-132,132-137,137-139,139-142,142-167\n77-104\n13-45,45-48,48-67,67-85\n55-83,87-93\n17-64\n9-25,25-53,53-55,55-88,88-92\n41-89\n-1-1,1-27,28-49,49-71\n-9-9,22-76,76-93,93-106,106-134,134-154,154-171\n167-195\n47-85,89-91\n23-47,82-102,114-160,167-193\n-17-17,17-55\n80-100\n166-193\n-15-16\n13-23,23-45,45-61\n160-178,178-197\n164-192\n-1-1,1-8,8-36,41-68,68-80,80-83,83-89,89-91\n281-313,322-330,341-367\n49-67,80-126\n49-67,78-93,93-101,101-125\n16-27,30-32,32-42,59-77,92-112,131-140,159-173,173-177,177-183\n-2-2,2-9,9-21,21-23,23-31,31-33,33-36,36-38,38-71,75-81\n58-85\n46-63,66-84,84-105\n66-85,85-88,88-90,90-107\n170-190\n169-191\n39-62,62-66,66-80,163-197\n-2-2,2-19,137-154,154-166,166-194\n-14-14,14-27,27-36,36-66,70-90\n113-163\n26-56\n86-113,146-180\n85-114,144-184\n41-51,51-60,60-70,77-95,104-122,168-192\n51-74,283-317,317-336\n50-68,187-195,239-257,275-311,321-339\n34-51,51-59,59-86,153-171,171-177,177-183\n18-33,42-90,160-200\n31-41,44-49,49-65,65-84,148-169,169-191\n17-34,37-50,50-70,70-88,167-193\n40-52,52-72,72-88,160-178\n34-48,48-68\n35-85,159-177,177-183\n39-83,153-175,175-177,177-180\n-7-7,7-33,33-35,35-49,69-102,115-147,147-159,159-179\n42-58,58-68,68-80,167-193\n44-82,167-193\n-4-4,18-36,36-56,56-72\n23-41,44-56,56-64,64-76,76-95,148-156,158-180\n23-43,43-46,46-80\n45-64,65-86,86-89,89-91\n-8-8,8-11,11-32,32-52,52-93,93-109,109-113,113-117,117-135,135-140,140-143,143-172\n114-139,139-142,142-149,149-169,169-191\n-5-5,5-9,9-50,50-70,82-90\n167-192\n63-90,160-178,178-182\n170-190\n38-59,68-94,150-175\n170-190\n45-68\n52-72,72-80,80-92,92-100,103-108,108-111,111-113,113-132\n54-77\n53-81\n19-37,50-75\n-12-12,16-26,107-124,124-137\n-10-10,20-39,44-64,64-71,71-79,79-102,142-154,160-180\n45-73,93-111,167-193\n32-57,57-82,157-180\n51-74,167-193\n171-189\n21-38,47-65\n-2-2,2-7,7-12,12-30,169-191\n-20-20,22-45,108-131,131-144,144-149,158-202\n0-16,16-22,22-28,28-42,42-61,137-147,171-189\n-13-13,18-33,38-84,104-113,113-136,136-156,156-162,162-198\n-2-2,2-12,12-14,14-34\n3-21,77-105,128-154,154-156,159-173\n1-23,23-36,37-70,70-92,92-103,105-123,133-159,163-180\n32-60,60-89,149-160,160-180\n4-8,13-26,26-55,55-59,59-67,73-91,159-171,173-177,177-179,186-192,198-203,203-206,206-214,214-233,239-251,259-280,296-299,330-341\n4-13,13-26,26-39,39-69,158-183,187-223,302-309,311-329\n57-83\n35-68\n-3-3,3-15,30-82,157-203\n-2-2,2-19,38-56,105-130,162-166,168-178,178-182\n0-5,5-19,19-68,68-83,105-124,162-198\n170-190\n-1-1,1-11,11-13,13-15,15-39,39-68,68-85,123-142,158-202\n69-78,88-110,155-182\n63-91,91-96,96-100,100-114,140-151,155-182\n57-85,137-141,147-179\n56-83,151-178\n20-35,35-61,61-73,73-83,156-180\n39-58,58-69,167-193\n23-41,45-70,78-96,96-104,134-159,169-191\n-1-1,1-3,7-47,50-51\n-1-1,1-5,5-13,21-56\n46-73,168-192\n4-22,37-61,165-189,189-196,286-305,310-320\n30-56,146-164,171-198,273-284,284-309,344-362\n56-71,71-90,139-151,151-175\n57-84,142-177\n19-35,35-40,40-55,163-166,170-184,187-213,300-308,345-365\n-4-21,21-27,27-42,44-61,164-188,188-191,191-215,293-323\n53-82,153-173\n56-75,150-178\n-14-14\n-16-16\n86-131,131-150,171-189\n-15-15\n-10-10\n-21-21\n-11-11\n-10-10\n-9-9\n-12-12,170-190\n167-193\n-2-2,2-20,150-168,170-190\n138-162,168-192\n-17-17\n-4-21,21-23,23-46,140-162,162-182,182-192,192-195,195-212,338-348\n-16-2,2-33,144-165,165-169,169-194,194-208\n5-35,344-365\n205-243\n202-231,234-242,242-249,254-268\n14-32,221-245,245-247,247-251,251-260,260-262,262-280,327-349,349-369\n236-262,327-371\n0-15,284-302,302-304,304-319,319-356,356-360\n-15-17,238-247,247-265,293-317,329-345\n4-10,10-21,289-307,326-364\n2-41,66-79,79-88,103-128,128-130,130-143,215-245\n2-39,93-133,134-153\n-13-13,166-194\n-10-10\n47-84,165-195\n60-65,69-80,80-97,97-108,157-179,179-204\n284-306\n284-306\n281-311\n168-192\n171-198,280-308\n172-198,268-286,286-291,291-295,295-313\n166-194\n42-70\n10-34,41-68,296-325\n-10-9,26-44,44-69,294-320\n55-77,167-197,293-309,312-328\n46-74,74-86,166-189,294-312\n165-187\n63-82,148-161,165-190\n171-189\n47-79,280-319\n47-81,168-204,283-320\n24-40,43-60,60-73,296-317\n21-43,43-70,286-323,323-328,328-346,346-365\n169-191\n170-191\n55-87,165-184,290-311\n56-82,166-184,290-309\n53-83,166-188\n53-79,120-131,166-194\n292-310\n173-204,204-220,277-307\n175-211,279-308\n175-193,193-220,282-312\n177-205,205-222,278-310\n191-199,256-283,287-311\n47-73,286-314\n46-74,288-311\n57-77,184-202\n50-71,71-83,289-300,300-309,309-320,320-336\n29-40,40-48,48-60,60-72,186-204,285-308\n28-50,50-72,72-78,78-79\n267-284,284-297,297-309,309-330\n54-80,80-92,165-188,193-211,219-237,252-263,287-305\n40-60,60-81,157-176,180-201,251-270,270-283,283-300\n-14-14\n-11-11,11-38,40-43\n43-78,163-197\n137-155,167-193\n168-192\n43-65\n2-14,32-67\n-4-4,4-6,6-22,40-67,73-88\n40-58,58-75,159-180\n169-191\n51-71\n47-70\n4-13,20-40,40-70,292-319\n38-63,292-319\n297-319\n41-61,293-317\n42-50,297-316\n-19-19\n-28-28,28-88,150-210\n-25-25,25-73,73-75,75-105\n-16-16\n127-148,160-180\n-27-27,42-58,58-69,69-94,94-97,97-102,102-117,119-140,140-220\n-14-14,14-29,96-115,115-119,124-156,167-193\n-24-24,24-26,26-28,28-45,45-50,50-59,59-70,70-78,78-101,101-104,104-122,122-140,140-151,151-180\n-18-18,152-208\n-6-6,6-29,128-137,140-158,158-202\n-18-18,18-43\n-27-27\n165-195\n165-195\n167-193\n-14-14,18-30,30-38,38-45,45-50,50-56,56-63,63-83,83-111,111-143,143-155,169-191\n-21-21,151-209\n164-196\n169-191\n0-8,165-195\n-24-24,162-198\n-17-17,161-180\n-35-35,50-80,80-100,100-126,131-229\n168-192\n0-3,3-49,49-58,58-74,80-129,129-143,143-159,159-179,179-181\n-1-1,1-22,25-36,36-45,45-65,66-76,76-84,87-116,116-137,137-168,168-180\n77-100,100-116,116-138,138-151,151-155,155-170,170-180\n15-39,90-113,113-135,135-172\n108-131,131-136,136-146,146-153,153-156,156-161,161-168,168-171,171-188,193-204,204-235,235-238,238-240,240-244,244-248,248-254,254-261,261-270,270-274,274-276,276-316,316-333,333-379\n2-24,122-144,144-153,153-173,173-197,203-220,220-230,230-241,241-248,248-250,250-271,271-275,275-277,277-298,298-300,300-306,306-316,316-338,338-358,358-362\n94-113,113-135\n-8-3,3-18,18-22,22-38,38-43,43-55,58-72,77-87,87-106\n-11-2,2-23,23-45,74-92,92-102\n125-146,146-154,154-168,168-183,190-242\n128-160,164-188,188-195,195-237\n146-172,172-183,201-222,222-235\n144-166,203-218,218-235\n41-62,80-106,106-129,129-149,149-170,173-184,184-197,197-217,219-232,235-259,259-268,268-287,297-368\n17-33,74-94,126-165,177-197,197-200,200-203,203-206,206-210,210-221,221-254,254-280,301-335,335-372\n130-148,155-177,198-232,239-257\n8-16,21-35,112-130,226-244,255-273,290-298,298-301,301-310,310-324,324-326,331-334,334-342,342-354,354-364\n-8-5,5-16,16-25,25-35,92-110,163-181,224-242,248-264,267-275,287-296,296-322\n0-21,21-34,34-36,36-52,52-67,67-90\n0-15,115-161,161-179,179-181\n-10-10,13-33\n140-154,154-156,156-159,159-173\n137-175\n53-77,169-191\n45-68,163-180\n17-25,43-72,292-314\n45-69,281-298,298-305,305-319\n288-316\n-13-13,52-77,169-191\n124-143,167-193\n50-75\n41-73\n49-75\n50-61,61-76,168-192\n167-193\n-16-16,66-78,85-100,100-106,106-119,171-189\n47-80,164-196\n56-76,162-193,287-296,299-305,305-308,308-309\n47-75,159-187,285-313\n17-35,55-66,66-83,157-187,187-201\n49-72,81-99,163-187,189-203\n45-76,160-185,285-296\n0-16,119-135,138-164,164-176,176-184\n42-76,160-200\n41-67\n161-199\n0-16,31-66\n2-10,15-25,37-54,54-72\n45-64\n35-62\n34-61,284-311\n33-70,286-313\n290-312,315-336\n290-312\n293-314,322-342\n164-194\n49-72,76-84,84-96,96-111,169-187\n50-71,75-95,164-181\n55-72,72-77,77-92,94-116\n49-67,296-320\n181-201,201-218,274-312\n178-204,204-213,213-226,272-312\n276-307\n261-269,284-306\n239-258,258-278,278-298\n184-207,242-256,261-273,278-301\n48-73,173-196,290-313\n46-70,161-187,286-320\n45-64,296-316\n45-64,295-314\n171-183,183-186,189-207,240-255,255-269,269-281,281-310\n170-182,182-185,189-201,229-251,260-286,286-296,296-314\n49-78,161-184\n56-75,167-184\n57-86,86-90,90-103,124-142,159-177\n181-190,196-199,199-215,258-288,288-308\n182-190,193-200,200-217,264-307\n219-237,237-247,248-265,265-303\n183-193,213-224,242-247,247-264,264-274,274-291,291-306\n-10-10\n-9-9\n-27-27\n-22-22,34-46,46-58,58-79,79-116,118-121,121-130,130-134,134-157,157-203\n-10-10,30-63,63-67,67-113\n-3-3,3-6,6-22,22-26,26-28,28-30,30-36,36-51,141-168,168-192\n-8-8,8-13,13-16,16-27,34-58,58-72,72-93,93-97,97-105,105-117,117-137,137-145,145-151,151-156,156-159,159-163,163-171,171-177,177-183\n-12-12,55-73,85-103,111-129,129-131,131-141,168-192\n-1-10,103-121,132-150,247-262,266-281,293-325,325-347,347-351,351-359\n68-112\n-12-12,26-45,45-59,59-96,100-114,114-120,120-124,124-126,128-133,133-146,171-189\n66-104,111-135,135-137,137-153,167-193\n66-84,84-109,132-150\n37-70,70-88,159-178,178-182\n60-89,162-179,179-181\n59-82,169-191\n146-163,166-194\n132-161,161-180\n0-23,23-36,36-64,64-77,77-80,80-97,97-109,109-132,136-157,157-178,178-182\n-27-27\n-15-15,15-35,35-37,37-63,63-72,72-76,76-88,88-96,96-116,116-142,142-154,154-167,170-179,179-181\n0-21\n-3-16,17-36,36-47,56-77,84-102,155-173,288-297,306-323,327-337,337-341,346-350,350-353\n3-16,29-36,36-41,41-59,59-79,79-94,287-307,307-320,327-337,337-341,343-361\n-1-1,1-7,10-34,34-36,36-46,46-56,56-64,64-66,66-83,87-103\n19-34,34-38,38-56,66-92\n32-61\n115-123,134-149,155-172\n67-113\n54-64,70-91,91-113,113-152,152-167,167-170,170-180\n-25-25,30-52,52-74,74-106\n169-190,206-218\n-11-11,18-40,40-66,72-98\n73-97,97-104,104-110,110-123\n-1-1,1-3,3-38,38-46,46-58,59-88,99-126,126-151\n76-99,99-125\n74-92,94-118\n3-26,26-30,30-38,38-43,43-72,72-91,92-112,117-147,147-170,170-190\n23-39,39-45,45-48,48-69,69-81,85-100,206-225,228-242,245-261,270-288,291-309\n-14-14,166-194\n-18-18,167-193\n-17-17,42-46,165-195\n-17-17,17-23,23-29,29-61,61-102,110-121,121-123,123-141,141-145,145-157,157-160,160-180\n44-59,59-73,73-99,249-267,349-367\n-12-10,41-59,62-76,76-99,209-227,333-348\n15-33,40-53,59-74,78-88,126-144,173-191,257-267,267-276,276-295,341-359\n42-50,72-96,138-165\n27-38,56-74,78-105\n56-81,81-95,95-97,97-103,103-114,237-256,256-259,263-275\n0-25,144-180\n-9-9,93-101,101-107,164-196\n20-28,54-75,81-101,145-166,168-192\n48-73,145-177\n54-80,156-176\n91-108,108-118,118-136\n-10-10,10-17,17-28\n36-44,46-51,51-71,71-81,81-83,83-90,90-105,105-125,125-129,129-142,146-156,163-169,169-177,177-180\n92-114,114-129\n56-92,145-159,159-201\n6-25,36-73\n55-76,148-161,161-180\n39-89,152-208\n45-71,71-74,74-97,99-101,133-143,151-152,154-179\n37-57,57-76,162-198\n46-66,66-71,71-74,74-89,167-193\n20-47,47-72,73-94\n-1-1,1-7,7-27,27-31,31-69\n-7-7,7-18,18-36\n57-87\n-4-4,4-9,24-36,36-59,59-78,78-91\n41-58,58-60,60-71,71-78,78-81,81-90,90-108,149-211\n89-102,108-116,124-160,163-178,178-182\n-19-19,19-27,27-41,41-54\n26-37,37-68\n26-37,37-45,45-57,57-81\n-6-13,13-19,33-50,168-186,304-334,334-348\n65-85,105-129,133-140,140-160,161-179,179-181\n5-22,22-33,33-47,47-62,62-81,99-117\n-1-1,1-14,14-24,24-40,68-95\n8-25,25-52\n22-52\n-10-10,156-180\n-3-3,3-13,13-19,19-21,21-43\n0-14,14-27,27-45\n-8-8,8-18,18-21,21-37,103-122,122-148\n-12-12,12-27,89-98,114-151,157-175\n94-123,133-142\n-15-15\n42-75,163-197\n41-92,158-177,177-183\n163-197\n45-67\n38-44,49-74,166-194\n-34-34\n-19-19,19-57,57-63,63-67,67-91,104-156,163-197\n-21-21,40-76,76-104\n0-46\n34-56,56-91,91-94,94-121,121-154,154-173,173-187\n-13-13\n0-30\n165-195\n109-127,127-146,146-148,148-170,170-175,175-179,179-181\n-4-4,4-53\n0-16,23-91,91-142,142-178,178-182\n0-36,36-67,67-113\n-14-14\n165-195\n-22-22,22-37,43-64,64-97,135-154,159-180\n129-146,149-179,179-181\n52-61,148-156,160-200\n-17-17,68-91,91-107,119-131,139-143,143-153,159-201\n-2-2,2-8,72-90,104-113,125-134,134-140,140-145,145-158,165-195\n-23-23\n0-23,23-25,25-43,46-66\n0-7,7-9,9-37\n-13-13,21-50\n0-16,38-72\n0-28,28-39,39-48,48-69\n163-197\n159-201\n131-144,146-168,168-192\n164-196\n160-200\n151-209\n-12-12,25-42,42-62,83-110\n-12-12\n132-148,156-204\n156-180\n1-18,18-26,26-58,58-62,62-74,100-122,122-125,128-155,155-160,160-180\n124-149,149-153,153-157,157-159,159-180\n-25-25,25-47,47-56,56-65,65-115,115-134,134-152,152-171\n-23-23,58-78,78-92,92-97,97-101,101-120,120-131,131-134,134-138,138-145,145-162\n0-5,5-31\n0-2,2-9,9-18,18-40\n-12-12\n-1-1,1-23,23-42,42-59\n169-191\n162-198\n165-195\n164-196\n57-83,105-117,130-150,150-168\n-3-3,3-10,10-28,28-46,52-82,82-113,113-133\n169-191\n163-197\n134-144,166-194\n-14-14,159-201\n-24-24,161-179,179-181\n-14-14,14-21,21-51,51-60,146-180\n119-139,146-149,155-174,174-180\n167-193\n167-193\n-14-14,31-53,122-131,137-175,175-185\n0-22,22-28,28-48,48-63,103-112\n0-3,3-32,32-54,54-56,56-63,63-84,112-160,160-163,163-180\n170-190\n148-159,166-194\n-1-1,1-7,7-34,43-65,75-90,98-137,137-145,145-149,149-174,174-180\n114-149,170-190\n-13-13,126-163,163-197\n-19-19\n-20-20,165-195\n-11-11\n85-104,112-158,158-167,167-193\n70-91,104-151\n111-140,154-175\n127-166\n120-129,129-149,149-167,170-184,184-188,188-202,213-234,234-245,245-254,254-267,280-312,312-362\n114-132,132-151,220-238,238-244,244-258,258-266,274-286,286-293,293-302,302-309,309-333,333-368\n97-107,115-119,119-135,135-136,141-151\n90-115,115-117,117-119,119-121,121-135\n109-127,127-134,134-146,146-161\n-17-29,35-42,42-54,54-78,78-101,105-115\n28-41,41-48,48-51,51-62,62-67,67-77,77-105,105-109,109-131,341-357,357-383\n7-19,19-33,33-59,68-78,78-90,103-114\n115-162,162-166,166-169,169-186,189-252,257-273\n104-118,118-142,142-169,169-187,189-252\n166-191,230-256,259-277\n158-174,174-194,194-203,203-221,221-225,225-239,241-254,254-260,260-273\n128-137,137-169,188-207,207-213,213-216,216-237,237-252\n144-161,161-178,201-233,233-239,239-243,243-256,257-285\n128-161,201-227,227-254\n137-174,210-229,229-239,239-255\n136-144,156-167,167-190,202-213,213-221,221-233,233-259,261-282\n175-201,201-204,204-206,206-208,223-252,252-254,254-257,257-269\n111-115,117-131,133-156,164-172,212-229,229-244\n166-177,177-181,184-204,204-228,228-247\n227-245,245-253,253-275,275-284,284-288,288-293,293-296,296-305,305-331,331-366\n211-229,231-238,240-244,244-272,272-319,319-323,323-329,329-365\n5-44,61-79,84-108,137-155\n122-137,137-139,139-146,146-159,159-197,197-231\n127-144,144-146,146-150,150-164,164-166,166-172,172-174,174-191,191-230\n230-268,268-270,270-272,294-302,311-350,350-352,352-367\n251-278,285-296,296-303,303-317,317-356\n-30-30\n-20-20,20-56,120-133,133-136,136-155,170-190\n24-42,49-78,78-90\n-17-17,17-68\n31-51,51-59,59-76,80-94,94-115,115-128,128-144\n127-146,150-159,164-196\n148-176\n-10-10,19-40\n-14-14,14-30\n158-202\n-23-23\n-12-12,12-26,26-53,109-131,138-162,168-192\n-13-13,29-47,47-50,50-73,73-107\n-1-1,1-6,6-8,8-11,11-21,21-51\n-13-13,22-35,35-43,43-61,61-70,74-80,80-93,118-138,142-166\n-12-12,18-20,20-31\n-19-19\n-11-11,13-17,17-45,150-166,166-194\n-11-11,14-29\n131-139,169-191\n-9-26,26-29,29-82,106-132,132-154\n-4-80,106-127,136-162\n4-70,76-90,90-114,114-130,203-217,220-228,228-244,250-273\n3-50,50-61,61-89,95-115,206-238,238-243,243-257\n35-66\n17-31,31-75,75-86\n12-54,68-81\n10-55,83-111\n13-32,32-36,36-53,97-115,205-223\n17-51,57-76,215-233\n202-223,227-252,252-266\n200-223,223-250,250-263\n94-119,123-131,131-151,156-166,188-225\n93-120,141-152,188-206,206-226\n227-254,254-289,289-307,307-328,328-369\n1-7,7-12,12-14,14-30,246-281,281-308,308-310,310-337,337-361\n258-289,304-341,341-363\n260-291,291-293,293-294,300-305,305-309,309-322,322-325,325-342,342-367\n80-88,92-126,128-135,135-142,142-161\n75-86,86-90,90-125,126-140,140-146,146-151,151-162\n95-118,125-134,136-141,141-154\n63-81,84-94,94-98,102-114,114-140\n-10-5,5-7,7-13,13-22,22-62,62-79,79-95,95-127,127-134,134-158,158-170\n-8-12,12-17,17-40,40-54,54-82,86-100,100-108,113-120,120-143,143-172\n4-35,35-43,43-53,53-55,55-85,85-114,229-237,237-243\n-6-16,16-24,24-26,26-40,40-42,42-46,46-48,48-64,64-86,86-89,89-124,199-217,241-263\n33-44,44-71,71-89,96-104\n100-118,130-150,152-177,177-184,188-210,213-228,231-247\n101-109,128-152,152-178\n-1-46,49-66,71-84,91-104,104-109,109-112,112-128,177-190,190-199,201-224,224-264\n-8-11,11-21,21-63,84-106,183-207,215-260\n30-56,189-202,202-233,233-238,241-245,245-246,261-274\n57-74,103-121,195-217,218-252,258-276\n23-41,214-234,234-257\n42-64,66-88\n16-34,120-132,132-154,311-321,340-366\n10-39,39-58\n-12-2,2-7,7-9,9-30,30-45\n13-30,212-230,230-261,339-360\n-11-11,11-31,232-263,295-319,331-343\n4-20,234-260,266-278,345-364\n236-256,301-319,337-368\n211-223,238-250,256-274,278-304,328-342,347-361\n1-21,339-361\n-8-10,231-243,243-263,263-285,301-319,326-344\n91-125,125-159,159-164\n77-90,90-92,92-117,117-138,138-154\n91-125,125-143,147-155\n90-122,122-146,146-168\n-4-6,6-14,14-27,228-242,242-262\n0-31,86-104,107-126,225-245,251-269,348-360\n-3-38,103-121,225-252\n106-124,124-131,131-148,151-162,217-247,247-265\n12-34,90-98,122-139,226-264,332-343\n3-51,203-241\n12-21,33-40,196-209,211-243\n60-80,80-103,164-196\n54-82,147-167,167-172,172-183,259-285,300-318\n280-305,305-308,308-328\n46-69\n2-20,57-77\n49-60,291-315\n47-65,272-289,292-316,316-327\n33-42,51-68,286-314\n38-65,282-314\n52-81,162-187\n50-91,157-195\n105-114,116-134,159-188\n61-83,155-178,178-199\n64-93,113-142,142-162,162-191\n74-96,113-123,165-193\n84-102,126-144,163-190\n51-71,163-189\n102-119,119-153\n61-79,168-185,191-209,282-316\n162-187\n51-75,75-91,158-192\n137-148,148-156,159-192\n60-82,161-194\n-2-12,18-33,33-60,60-62,62-76,313-317,338-356\n15-33,40-54,54-72,160-178,290-325,325-327,327-357\n6-22,340-366\n169-189,189-208,213-231\n23-41,41-72\n39-72\n42-64,290-320\n43-64,291-319,321-325,325-330,330-347\n191-231,231-236,236-249,284-316,324-338\n178-210,210-222,222-226,226-239,239-241,241-246,246-258,285-315\n185-195,208-218,218-236,249-267,285-319\n56-81,152-194\n52-86,121-130,130-136,147-199\n49-73,73-88\n57-90,94-96,96-101\n57-89,159-176,176-178,178-193\n43-73,73-94,94-107\n23-35,41-45,47-73,186-208,284-294,296-307,307-323\n35-67,67-69,181-200,284-319\n47-80,163-171\n32-47,47-57,57-59,59-61,61-74,177-195,294-312\n176-202,212-238,273-309\n178-196,209-221,285-306\n39-74\n44-74\n160-171,171-175,175-178,178-196,276-302\n46-82,158-193,293-322\n47-78,94-118,158-196,292-324\n48-72,167-188\n153-179\n43-82,82-97,97-110,110-117,117-129,129-139,139-150,150-153,153-192\n45-70,70-102,102-122,122-125,126-145,145-148,150-194\n92-114\n253-261,286-315\n285-323,323-348\n289-318\n40-72,176-202,224-242,275-288,288-290,290-312\n46-73,73-92,179-201,209-225,278-311\n49-73,77-93,294-312\n42-78,163-197\n48-80,159-193,292-326\n-21-21,109-135,135-142,142-145,145-157,157-161,161-175\n163-197\n-1-1,15-42\n0-10,10-20,20-28,28-40\n-1-1,1-4,4-10,16-42\n-4-1,1-26,127-136,335-356\n22-42,42-47,47-62,62-84\n293-311,322-343\n169-187\n87-103,111-147\n56-76,79-93,93-96,110-148,154-165\n76-97,97-101,101-116,116-121,121-129,129-131,131-140,140-147,147-160\n66-81,81-84,84-86,88-92,95-111,111-115,115-141,141-159\n188-209,209-219,219-221,221-241,241-259,259-264,264-282\n88-104,104-111,111-117,120-146\n93-113,120-148\n16-27,27-33,41-78,161-199\n31-58,58-78\n167-193\n146-164,170-190\n0-32,39-69\n13-24,24-36,36-40,45-67\n24-42,47-75,168-192\n29-43,48-78,165-195\n39-75,156-194,296-304,304-310\n33-39,43-77,156-188,287-319\n43-72,84-88,88-103\n43-69,75-80,80-96\n285-303,303-314\n293-312\n130-145,149-164,172-192\n49-78,88-107,156-184\n51-80,156-184\n42-67,67-68,71-99,152-176\n37-50,50-88,88-106,106-134,153-176\n39-79,82-100,158-183\n51-77,109-126,126-146,165-173\n52-79,85-97,134-172\n45-74,96-116,154-172\n51-71,151-177\n174-213,213-236,278-310\n178-211,211-242,280-310\n287-307\n182-203,241-258,258-274,283-308\n57-79,79-92,150-182,182-200\n41-75,164-192,281-321\n46-71,168-191,283-316\n33-57,62-72,291-309,309-327\n27-46,46-53,53-66,292-314\n32-66,289-317\n51-76,153-171,171-174,174-193\n51-75,82-96,148-183\n46-62,62-66,66-85,162-180,180-194,281-297,297-314\n48-71,169-194,279-291\n31-43,46-77,315-333\n51-71,162-180,302-315,315-332\n170-182,182-189,189-209,268-284,284-297,297-316\n-2-2,2-17,17-28,28-78,137-163,163-197\n41-66,167-193\n15-33,144-168,168-180\n144-170,175-208,216-234\n145-163,163-182,182-203\n50-74,168-192\n58-88,163-180\n46-64,64-95,95-112,161-199\n-13-13,13-43,43-70,153-170\n140-156,158-202\n118-136,140-160,160-180\n-15-15,17-25,27-67\n4-30,30-52,52-69\n0-8,20-70\n-11-11,15-64,74-91\n42-78,166-194\n58-76,76-95,168-192\n38-61,61-68,68-70,70-86,90-109,160-200\n38-87,159-201\n-10-10,32-51,56-71\n0-8,48-91,140-159,159-179,179-181\n25-48,48-50,50-75\n0-19,27-59\n1-15,25-59\n52-82,83-98\n12-40,58-76,296-318,318-320,320-325,325-328,328-342\n12-30,42-46,292-314,314-326,328-340,340-358\n35-49,49-73,289-310,310-315,315-338,343-369\n28-47,47-72,291-335\n37-67,176-194,194-207,274-295,295-314\n33-68,179-189,273-295,301-321\n35-56,312-331\n-3-3,3-18,18-45\n25-28,35-59,59-62,62-71,71-75,75-79,79-90\n-3-3,3-30\n130-138,140-148,152-176,176-204\n-10-13\n-3-3,3-28,32-56,62-77,77-91,91-97,97-113,113-119,119-139,157-179,179-181\n-8-8,8-12,12-17,17-27,27-30,30-33,33-50,50-75,75-100,100-111,111-121,121-123,123-125,125-130,130-138,138-155,155-158,158-180\n115-136,136-140,140-164,171-189\n0-17,17-40\n-5-5,6-8,8-16,16-19,19-54,54-59,59-68,68-79,79-102,139-165,166-194\n-1-1,1-10,10-26,26-44,79-101,111-122,129-131,136-152,152-157,157-159,159-172,172-179,179-181\n45-64,64-83\n53-81,169-191\n60-80\n23-41,44-62,62-77,171-189\n-6-8,8-11,11-14,14-31,143-161,161-163,163-165,165-172,172-174\n-10-2,60-69,77-94,94-96,96-114,114-129,131-149\n17-35,97-110,116-129,165-175,175-202,325-343\n17-39,39-43,43-47,47-72,72-105,105-107,107-109,109-129,129-137,137-152,152-164\n-11-12\n135-143,169-191,208-216\n45-67,114-132,170-182,231-251,261-282,282-300\n105-136,136-147,165-183,235-254,307-325\n77-108\n0-18\n8-21,21-38,38-58,69-83,83-91,91-93,93-111,143-162\n-17-17\n-12-12,166-194\n-13-13,13-28,163-197\n-11-11\n0-3,3-8,8-28,170-190\n8-46,157-203\n-9-9,13-24\n-17-17,17-31,161-199\n158-181\n5-13,19-23,23-42,55-72,72-83,229-247,326-334\n-15-15\n-10-10\n0-22\n-10-10\n-13-13\n60-69,69-86,162-183,183-201,292-313\n53-77,177-195,290-300\n191-199,279-307\n175-193,193-203,279-298,298-315\n-9-9\n54-80\n36-58,58-74,300-320\n178-199,285-306\n178-197,197-203,283-309\n-10-10\n-1-1,1-20\n187-205,230-248,283-309\n-11-11\n-15-15,23-40\n-12-12\n71-104\n8-26,64-85,85-113\n59-77,142-155,156-189\n58-80,162-190,191-210\n278-288,288-297,297-317\n-10-10\n-22-22\n-16-16,16-37,46-49,52-81\n-14-14,20-37\n56-75\n56-77\n283-303\n285-304\n-2-2,2-17,17-37\n69-84,84-96,96-117\n76-94,94-115\n-18-10,10-13,13-31,37-48,48-57,57-76,139-154,154-158\n-17-42,42-69\n-12-22\n-1-38,154-163\n3-38,42-63,129-144,148-183\n2-6,6-32,32-56,56-73,148-182\n-14-21,21-51,51-67,74-101,214-224\n-15-5,5-28,28-52,55-63,63-81,204-218,218-234,234-238,238-250\n244-261,261-269,269-284,319-354\n245-282,323-352\n208-240\n207-239\n200-245\n211-244\n48-76,152-176,176-193,270-288\n-10-19,31-49,271-289,334-348\n-17-17,23-60,61-64,66-104,141-179,179-181\n62-66,100-133,133-140,140-144,144-150,150-178,178-182\n-1-1,1-11,11-28,28-45,54-77\n1-26,30-45,47-58,61-89,93-101,111-119,163-178\n-2-2,2-22,46-72,72-87,95-117,142-158,158-170,170-171,173-187\n-10-10,14-103,103-105,105-108,108-119,119-134,134-154,154-176,176-178,178-182\n-1-1,1-16,16-37,37-41,41-49,49-60,60-93,93-118,126-153,153-157,157-170,170-179,179-181\n57-99,99-113,113-117,131-229\n88-109,131-153,153-160,160-166,166-173,173-180\n-2-2,2-8,24-50,50-90,97-102,102-104,104-109,111-134,143-163,163-172,172-177,177-180\n49-76,86-118,123-145,149-176,176-179,179-181\n37-53,53-78,78-98,101-130,137-171,171-180\n134-152,152-170,170-190\n-9-9,12-25,25-44,47-62,62-68,87-107,107-120,123-142,145-162,162-168,168-179\n0-2,2-6,6-17,109-136\n38-82,152-180\n21-33,33-35,35-39,39-69,167-193\n27-75,158-178\n38-77,166-194\n16-35,36-75,100-118,130-149,158-202\n30-48,54-79,85-103,164-196\n18-36,58-78,79-95,145-161,164-179,179-181\n-1-1,1-27,27-34,34-38,38-70\n23-37,37-66,66-93,93-100,100-103,103-110,134-155,159-180\n8-35,46-66,66-74,74-77,81-87,90-94,94-95,112-138,138-150,154-171\n39-51,51-58,58-74,164-176,176-178,178-180\n2-13,29-68\n5-24\n0-24,86-104,104-116,243-261,261-272,275-291,324-339,339-360\n39-59,59-78,164-196\n44-73,155-205\n36-69,163-180\n41-80,163-197\n48-72,168-192\n49-72,169-191\n-6-12,299-339\n-7-7,7-33\n37-65\n0-17,63-81,105-123,123-144,144-164,164-166,166-194\n28-57,88-114,114-123,123-145,145-165,165-170,170-175,175-185\n-12-12,169-191\n-14-14,157-180\n-18-18,158-202\n0-8,8-22,22-29,76-97,163-197\n-18-34,81-115,124-150,150-157,157-161,161-186,186-215\n-20-33,37-64,85-107,107-119,119-129,129-137,146-162,162-166,166-182,182-187,187-194,194-216,225-245\n-17-22,29-34,34-56\n-2-29,29-31,31-33,52-64,343-358\n129-139,139-143,148-157,162-183,183-186,186-197,197-211\n129-163,170-195,195-203,203-204\n-12-34,43-62,179-198,198-206,209-218\n-6-32,333-345,345-348\n168-193,271-279,286-310\n170-193\n58-82,165-189\n55-80,80-95,129-153,165-189\n63-77,77-93,132-150,160-177\n294-315,315-327\n282-311\n45-68,68-71,71-85,148-180\n23-42,47-66\n31-49,49-58,58-75,165-195\n48-75,85-106\n38-54,54-80\n276-295\n47-61,61-80,164-196\n169-191\n170-190\n-19-24,164-204\n156-171,171-191,191-211,211-223,342-395\n1-16,16-42,144-156,172-196,196-207,207-218\n5-37,150-168,168-174,174-194,194-211\n-1-1,1-17,24-59,169-191\n25-60,60-63,63-76,143-159,159-170,170-179,179-181\n130-154,154-168\n112-121,121-133,133-151,159-180\n159-201\n136-148,160-179,179-181\n37-77,77-106,106-128,128-139,145-215\n91-109,130-141,141-173,173-187\n11-22,24-29,29-36,65-79,79-89,100-111,297-308,308-330\n49-62,62-82,82-102,125-147,147-157\n69-94,94-118,123-145\n142-160,160-178\n33-54\n77-85,132-159,159-174\n137-174\n19-34,34-54,69-98,152-179,179-181\n-12-12,62-89,135-159\n62-127,127-143,143-146,146-161,161-174,174-180\n77-99,99-104,104-109,109-134,139-157,170-190\n56-81,81-83,83-87,87-104,105-132,132-147,147-149,149-151,151-159,159-161,161-166,166-179,179-181\n75-134,147-153,153-165,165-195\n59-92,139-155,155-180\n49-103,114-148,148-159,159-180\n33-51,55-92,148-180\n35-54\n14-32,47-67,67-75,75-87,87-98,98-107,107-118,165-195\n71-89,143-157,158-178,178-182\n0-2,2-13,13-15,15-30,95-146\n32-87,153-207\n1-20,20-82,154-189,297-340,340-361\n1-16,16-20,20-82,148-187,290-316,316-361\n7-18,18-22,22-44,44-82,132-151,297-311,311-313,313-335,335-362\n11-21,21-31,31-34,34-43,43-58,58-63,63-80,301-313,313-337,337-351,351-371\n59-93,145-172\n60-91,116-133,146-172\n59-77,106-136,141-167\n58-78,93-107,112-120,120-141,141-162\n0-18,18-56,65-83,287-295,309-335,337-358,358-360\n6-19,19-58,336-358\n5-7,7-17,17-23,23-25,25-46,46-71,74-92,164-184,295-328,328-346,348-365\n7-24,29-50,50-78,146-164,164-195,290-341,347-367\n-7-15,28-51,58-67,67-80,290-298\n-8-10,28-52,61-65,69-87\n3-15,26-34,34-75,75-76,80-86\n33-49,49-86,131-150,151-165,165-195\n42-82,82-89,157-180\n31-53,53-73,164-196\n45-76,163-197\n35-40,42-55,55-66,66-71,71-86,156-180\n34-62,154-198,282-311\n44-67,158-193,193-203,272-289,289-311\n-10-10,10-26,26-47\n-11-11,171-189\n-12-12,162-198\n171-189\n-9-9,42-63,171-189\n-13-13,167-193\n0-5,5-18,39-57,64-82,161-172,174-179,179-181\n-18-18\n-15-15,21-27,40-48\n32-60,61-86,152-180\n0-49,51-70,155-205\n-2-2,2-25,25-44,108-125,125-145,145-158,158-172,172-177\n-18-18,28-45,132-153,169-191\n11-30,35-53,53-54,56-74,82-106,106-126,171-189\n-12-12,12-23,24-42,46-65,65-72,72-89\n201-213,213-216,216-236,236-248,248-277\n213-239,239-267\n-6-6,6-14,14-17,17-35\n-2-2,2-12,12-32,32-43\n15-55,55-85,167-193\n43-81,143-167,167-180\n45-56,56-71,71-73,73-76,76-89,153-180\n15-32,32-56\n36-69,69-84,148-164,164-176,176-180\n39-57,57-73,154-171,171-180\n42-76,128-147,147-169,169-180\n-17-17,161-199\n-10-10,40-66,117-170,175-185\n16-38,92-119,119-136,136-146,156-172\n36-61,85-104,104-112,112-149,171-189\n-20-20\n-23-23,23-29,29-40,169-191\n-16-16,157-203\n-1-1,1-4,4-16,16-21,21-34,57-84,87-95\n4-33,43-70,117-131,131-136,136-141,141-148,148-169,169-191\n-16-16,21-29,29-47\n0-6,6-18,51-69,88-106,128-145,145-165,165-178\n-18-18,157-178,178-182\n-6-6,6-27,27-42,49-69,147-155,155-166,166-169,169-191\n-1-1,1-23,23-29,29-56\n-1-1,1-44,163-180\n20-44,57-75\n0-17\n-13-13,157-180\n129-147,147-155,155-158,158-180\n171-189\n61-79,79-90,90-112\n-11-11\n-15-15,168-192\n-4-4,4-6,165-195\n-19-19,153-170,170-190\n-1-1,1-17,137-155,155-179,179-181\n-18-18,18-22,22-34,138-164,165-195\n16-54,56-65,65-78,83-107,112-121,121-131,171-189\n51-74,82-108,171-189\n42-51,73-107,107-136\n48-57,57-62,62-84,171-189\n-10-10,40-65\n46-82,156-175,175-194\n63-84,162-190\n53-79,171-189\n54-76,161-175,180-191,195-210,281-299,303-322\n47-64,64-80,191-209,287-305,305-308,308-325\n59-77,291-312,312-327,327-344\n285-319\n180-205,286-324\n43-70,70-85,172-185,185-206,291-311\n51-70,70-84,167-183,186-202,279-290,293-324\n42-62,272-293,297-311,311-316\n39-58,58-78,78-95,280-317\n53-70,70-84,207-210,253-271,288-319,319-334\n45-69,69-71,290-310\n16-50,53-67,67-83,83-97,119-139,139-147,147-160,166-188,193-218,218-220\n35-51,51-55,55-62,62-65,65-69,69-75,75-88,112-126,126-131,131-135,135-140,156-172,172-181,181-203,220-224\n51-61,61-65,70-80,151-167,170-186,198-232\n156-187,194-212\n153-187,187-190,190-200,200-214\n147-174,183-218\n157-169,169-179,179-189,189-216\n149-165,165-167,167-177,177-180,180-204,204-208\n-2-2,2-24,33-45,48-68,72-89\n15-33,33-54,54-56,56-77,77-90\n170-190\n152-175,178-182\n169-191\n-2-2,2-7,7-15,15-33,35-53,53-74,74-106\n2-9,12-16,16-22,22-30,30-36,36-59,64-70,70-79,79-90\n-29-29\n169-191\n162-198\n71-81,81-90,90-95,95-101,101-111,111-115,115-129,129-148\n158-202\n49-70,293-312\n-10-10,86-110,110-116,116-124,124-131,131-133,133-142,142-153\n281-310,315-333\n49-69,162-192,287-310\n50-71,164-184,288-310\n15-25,25-51,87-104,138-150\n260-280\n261-280\n28-48,48-53,53-54,308-321,321-332\n21-33,37-60,169-195,280-306\n172-190\n172-190\n294-305,305-332,332-351\n290-309,309-332\n290-307,307-325\n39-60,60-62,62-78\n38-57,57-87\n8-26,29-40,317-345\n29-47,317-339,339-341,341-368\n-21-21\n-10-10,16-42,138-169,169-179,179-181\n22-40,40-51,51-85,87-93\n-10-10,20-36,36-42,42-63,78-102\n46-54,54-59,59-63,63-66,66-74,74-85,89-107,110-128,145-157,157-160,164-174,174-186\n0-33,33-36,36-53,53-79,79-88,88-92\n78-117,117-141\n-5-5,5-34,40-69,69-90\n108-129,169-191\n0-24,24-28,28-68,76-93,93-99,99-124,136-165,165-171,171-173,173-176,176-180\n-36-36,36-67,69-89,89-109,126-159,169-191\n6-70\n38-57,57-67,67-77,77-103\n145-163,169-194,200-220,220-227,229-248\n329-349\n328-348,348-350,350-364\n-11-11,16-37,37-43,43-49,49-58,58-73\n-21-21,38-58\n-13-13\n-12-12\n-13-13\n169-191\n-11-11\n-12-12,16-19\n-3-3,3-16\n164-179,179-181\n-15-15,22-54\n-1-1,1-11,11-23\n-17-17,17-32,52-62\n-13-13,14-43\n0-19,30-38\n40-66,166-194\n170-190\n32-64\n34-70\n-27-27\n-1-1,1-7,7-17,17-19,19-65,65-79,79-82,82-84,84-96\n35-62,62-88,88-92\n-1-1,1-3,3-68,81-90\n0-12,12-16,16-21,21-33,33-61,61-67,67-69,69-96,104-121,124-128,128-141,141-143,143-161,161-180\n44-57,57-61,61-73,73-85,85-95\n33-60,60-90\n22-46,46-56,66-114\n43-60,60-87,90-105,105-130\n118-150,169-191\n-16-16,31-45\n-31-31\n-17-17,17-29,29-32,32-36,36-40,40-42,42-44,44-64,91-108,116-132,132-134,134-153,160-200\n-13-13,15-27,27-46,50-58,60-66,66-68,71-109\n-8-8,8-63,76-104\n38-63,63-86,86-112,112-114,114-145,145-180\n45-59,59-90\n-19-19,29-31,31-48\n168-192\n27-46\n18-36,42-60,60-76,76-80,80-94,99-117,128-146\n-12-12,14-32,112-135,135-140,140-143,143-163,163-168,168-179,179-181\n117-128,128-136,136-153,153-159,159-163,163-179,179-181\n324-359\n0-21,21-24,24-39,39-46,46-50,50-52,52-62,62-66,66-89,89-91\n-18-18,18-36,87-114,114-140,140-165,165-175,175-180\n147-174,178-204,241-259\n146-166,166-170,170-190,190-204,204-216,216-219,219-232,235-254\n120-152,152-163,163-174,174-178,178-182\n-23-23\n59-89,89-91\n24-41,41-61,61-69,69-90\n63-90\n289-303,303-325,325-331,331-342\n-17-17,17-22,22-65\n18-37,37-63,63-76,76-85,85-94,94-108,108-112,112-114,114-117,117-128,128-132,132-133,140-142,142-149,150-162,162-178\n-10-10,54-87,87-93\n0-34,34-60\n-16-16,16-45,45-53,53-73,73-90\n-1-1,1-9,9-45\n-1-1,1-15,15-32,32-64,67-89,91-99,103-140,140-160,160-166,166-178,178-182\n25-36,36-38,38-62,62-65,65-72,72-79,79-101\n-1-1,1-5,5-13,13-78,86-94\n45-73,73-77,77-97,97-140\n63-117\n-1-1,1-26,26-51\n-9-9,47-78,82-104,116-124,127-136,136-149\n-1-1,1-10,10-33,171-189\n163-180\n-1-1,1-3,3-15,15-39,143-162,162-198\n-9-9,118-132,132-139,139-152,152-174,174-186\n0-23,23-26,26-35,35-47,160-200\n165-195\n38-71,293-316\n102-120,267-275,290-301,303-306,306-331,331-339\n156-187,195-213\n295-314\n296-314\n8-18,294-311,311-317,317-319,319-324,324-346\n-5-13,26-41,41-44,44-52,52-53,271-289,301-311,311-320,320-324,324-340\n274-305,310-322,322-330,330-333,333-350,350-363\n272-287,287-289,289-319,319-328,328-343\n105-124,124-129,129-144,144-179\n100-123,130-149,149-182,195-217\n-5-5,5-15,15-17,17-25,25-35,35-49,73-77,110-127,127-151,157-173,173-175,175-180\n10-20,24-36,68-87,87-97,97-121,146-156,171-189\n40-71,169-191\n171-189\n62-93,116-124,161-191\n55-74,74-94,116-134,161-181,181-193\n50-75\n-11-11,26-51\n-12-12,33-57,62-70\n-12-12,159-168,168-170,170-190\n7-29,43-64\n187-205,287-313\n302-326\n65-83,294-311,311-313,313-325,325-331,331-344\n0-2,2-21,21-24,26-43,43-45,45-62,81-99\n31-45,45-60,60-69,69-90,90-98,98-101,101-112,112-132,143-158,158-161,161-179,179-181\n-18-18,155-169,169-191\n21-51,115-134,134-154,154-169,170-190\n-14-14,170-190\n-13-13,169-191\n170-190\n239-263,292-324\n10-40\n-19-19\n-1-1,1-35\n-1-1,1-16,16-20,20-55\n5-23,37-55,70-91,94-111,111-116,116-123,136-154,170-190\n23-41,41-44,44-86,86-89,89-91\n31-39,73-107\n-15-15,15-19,19-34,34-65\n-10-10,21-79,81-99\n-30-30\n73-107\n-1-1,1-6,6-8,8-21,21-41,46-52,57-71\n-13-13,20-33,33-37,37-41,41-72\n19-33,36-59\n46-76,169-191\n167-193\n-2-2,2-22,22-38,38-55,58-84,163-172,172-188\n-2-2,2-21\n165-194\n64-99,239-257,257-259,259-285\n35-71,71-80,80-93,93-99,99-107,107-119,119-150\n155-165,165-169,171-189\n171-189\n111-145,309-324,324-327,327-332,332-342\n113-132,132-140,140-158,288-300,304-306,306-315,318-324,324-333,333-351\n151-155,160-170,171-189\n52-61,79-98,98-122\n-23-23\n57-95,247-273,277-301\n58-79,282-301\n-18-18,23-59,59-76,76-104\n0-28,33-45\n-1-1,1-16,16-28,28-34,34-62\n0-5,5-9,9-16,16-25,25-48\n-15-15\n-15-15\n-17-17\n0-5,5-10,10-23,168-192\n0-4,4-27,27-47,47-63\n171-189\n3-21,103-121,121-122,126-152,152-172,172-188\n-13-13\n11-19,176-203,214-232,278-296,301-310,325-363\n-23-23,31-46\n164-196\n0-16,19-43,171-189\n145-164,164-196\n-14-14\n168-192\n-22-22\n9-35\n4-27,33-48,48-59,67-85,118-136\n12-21,172-187,188-202,202-207,207-231\n20-38,187-202,202-227,227-245\n47-68,72-108\n170-196,286-319\n169-179,287-315\n-15-15,15-46\n145-159,159-201\n162-198\n163-179,179-181\n-10-10\n-16-16,16-36,111-123,123-155,159-177\n-9-9,24-51,128-157,161-199\n24-50,87-97,97-118,118-126,142-153,153-161,162-198\n171-189\n-21-21\n171-189\n-9-9,156-185\n0-3,3-25,154-206\n-15-15,15-29,155-205\n-23-23,167-193\n-12-12,17-46,57-79,170-190\n-15-15,162-198\n-22-22,22-46,48-65,115-138,138-160,160-200\n-12-12,169-191\n-22-22,135-156,159-201\n-14-14,167-193\n-17-17,133-145,145-160,163-197\n0-4,4-18,18-20,20-28,28-48,151-179\n36-49,55-68,70-88,88-89,123-148,152-162,168-173,173-177,181-193,193-205,222-232,235-259,263-275,311-319\n1-19,34-52,69-87,94-112,135-152,152-165,168-185,230-256,256-260,260-276,276-296,314-326,330-332,332-341\n-10-10,10-44\n0-20,20-35,156-170,170-175,175-185\n-20-20,141-159,159-201\n15-31,32-47,47-66,75-93\n87-107\n-19-19\n0-20\n49-78,78-97,109-129\n44-73\n0-17,46-75,75-104,126-144,155-205\n35-63\n45-83,83-104,104-113,113-126,133-152,152-208\n30-59\n25-53,53-59,59-80,171-189\n37-61,118-130\n43-62,62-76,162-182,182-200,293-311,333-351\n38-59,59-82,161-188,286-304\n47-76\n58-73,73-103,103-113\n168-192\n275-296\n165-203,268-286\n72-92,151-165,165-169,169-201,282-295,295-312\n66-84,86-103,114-148,151-158,158-166,166-177\n159-178,178-180\n120-135,135-163,166-194\n1-22,135-159,163-179,179-181\n-24-24,164-196\n167-193\n-14-14\n167-193\n0-3,3-18,158-202\n164-196\n0-29,149-170,170-190\n-11-11,151-180\n-14-14\n159-201\n163-180\n167-193\n166-194\n-11-11\n136-152,154-179,179-181\n50-63,67-83,87-107,111-117,155-173,181-205,206-232,242-254,254-264\n59-90,92-123,225-237\n38-53,53-56,56-64,65-88,88-91,91-109,202-220\n160-200\n-9-9,62-92,96-119,119-135,135-137,146-171,171-189\n-12-12\n137-155,161-177,177-180\n157-203\n-12-12,40-49,64-83,83-101\n-12-12,113-132,139-147,155-177,177-179,179-181\n-10-10\n-12-12\n169-191\n-2-2,2-7,133-149,149-178,178-182\n168-192\n-24-24,166-194\n0-22,162-198\n-14-14,14-47,119-127,149-157\n-1-1,1-5,5-36,36-56,56-67,90-99,99-109\n-10-10\n-10-10\n136-157,162-178,178-180\n1-9,27-45,45-53,53-54,127-138,138-142,142-171,172-180\n-13-13,59-87,94-118,165-195\n-10-10\n-11-11\n124-139,139-152,152-155,155-205\n-4-43,43-45,45-76,97-121,123-143,143-166,166-169,169-173,173-234\n4-44,44-73,73-93,96-118,120-150,150-167,167-174,174-202,202-233\n19-42,42-59,62-81,81-100,110-128,167-177,177-181,183-197,197-199,203-215\n25-62,68-82,82-99,112-120,194-215\n3-4,8-29,304-324,324-329,329-359\n-4-17,236-254,305-332,332-356\n94-108,108-128,135-151,151-177,177-183,183-218,218-220,220-237\n96-115,115-124,124-172,172-234\n11-53,109-132,137-157,157-179,190-194,199-204,300-314,314-318,318-322,322-328,328-334,334-342,352-356\n8-56,56-59,59-65,124-136,142-151,151-161,161-177,184-217,310-318,318-340\n0-28,166-194\n-14-14,154-164,164-176,176-184\n0-20,154-170,173-187\n156-172,172-203\n146-162,166-207\n-21-21,29-31,31-47,47-85\n-10-10,73-94,163-197\n-20-20\n168-192\n127-144,145-167,167-193\n-27-27,161-199\n-11-11\n167-193\n0-20,26-40\n-10-10\n131-139,168-192\n0-4,4-24,24-34\n169-191\n170-190\n48-75,148-158,158-162,164-175,175-185\n-16-16,16-34\n29-48,120-147\n-10-10\n-10-10\n3-25,25-28,28-55\n0-36,36-74,313-332\n160-200\n146-170,170-177,177-183\n-9-9\n-15-15\n170-190\n3-21,25-36,36-53,169-191\n2-15,15-17,17-20,20-28,28-49,54-64\n55-82,82-113,124-144,146-159,159-161,161-179\n-9-9,44-72,72-84,161-180\n49-76,170-190\n-12-12\n-17-17,99-114,114-116,116-138,140-147\n20-39,45-76,162-198\n168-192\n33-50,50-52,52-70\n0-12,35-68\n42-81,163-180\n31-60,69-87\n52-79,156-176,176-184\n50-73\n50-72\n-5-6,6-24,42-54,54-64,290-308,308-326\n-40-40\n0-17,17-19,19-39,39-61,68-90,114-135,135-138,138-161,161-179,179-181\n34-52,52-77,77-90\n-11-11,11-14,23-69,85-90\n41-87,87-117,117-119,119-135,135-162\n40-53,53-55,57-78,78-102\n-13-13,22-61\n34-52,58-81,81-99\n147-164,164-180\n-11-11,11-28,28-48\n144-165\n121-135,135-173\n-14-14,27-41,46-61,61-79,114-125,125-133,133-149,154-172\n89-112\n-1-1,1-17,136-156,159-171,174-177,177-183\n10-28,49-60,60-81,83-98,98-120,120-127,127-139,147-165,167-193\n-19-19\n43-77\n-22-22,31-90\n72-84,84-106,106-125\n1-20,20-45,45-48,48-51,51-53,53-68,68-71,71-88,88-92\n-45-45\n19-73,121-156,166-194\n0-2,2-23,44-82,86-94\n0-18,18-52,59-83,83-88,88-92\n161-180\n124-152,152-178,178-182\n-16-16,16-48\n-15-15\n0-36\n130-156,157-203\n3-29,29-48,48-75,75-90\n47-67,67-77,77-78,86-105,105-107,107-112,112-123,141-159\n-1-1,1-43,43-45,45-49,49-89,89-91\n30-54,56-82,93-130,164-196\n137-152,161-180\n123-152,152-175,175-180\n-1-1,1-19,19-22,22-41\n-4-4,4-42\n-31-31\n0-9,9-44,44-64,134-153,163-197\n53-85\n0-4,4-61,69-82,82-98\n48-65,65-75,86-98,98-111,111-114,154-206\n61-87,87-93\n0-9,9-38\n-10-10,10-13,13-39,77-95,170-190\n-12-12\n151-164,169-191\n146-165,165-195\n161-180\n0-22,23-30,30-44\n37-58,62-80,82-91,91-116,129-156\n-1-1,1-17\n60-78,151-156,156-177,177-183\n-18-18,49-67,82-97,101-116,133-147,152-158,158-162,167-177\n2-17,106-134,134-150,150-152,152-170,170-173,173-187\n-10-10\n-18-18,25-48,169-191\n0-19,108-126,126-149,160-180\n-13-13\n-13-13\n114-125,215-249\n134-152,159-177,180-196,199-211,211-235,235-250\n0-68,68-87,87-93\n13-28,32-47,48-66,74-91,104-141,141-153,156-174\n-2-2,2-13,13-86,86-90\n45-61,61-74,78-89,89-91,91-94,96-98,98-128,128-130,130-153\n120-139,139-144,144-155,155-162,162-176,176-184\n140-172\n-25-25\n0-33\n-13-13,13-51,91-114,117-137,142-167,167-193\n-9-9,35-64,64-80,80-83,83-97\n-11-11,11-60\n26-59,59-83,101-119,123-145,145-168,168-179,179-181\n44-65,65-70,70-90\n16-62\n32-57,57-61,61-66,66-74,74-89,89-109,111-141\n33-88,88-92\n37-62,62-86,86-108,108-129\n122-144,144-148,148-175,175-180\n123-140,140-146,148-169,169-191\n-21-21,21-44\n-13-13,13-38\n-4-4,4-22,59-69,69-73,78-89,89-106,126-152,165-179,179-181\n13-33,125-158,158-166\n-21-21,165-179,179-181\n16-34,38-50,50-53,57-69,117-156,171-189\n-11-11\n-24-24,129-143,143-156,156-164,164-196\n-16-16,16-34,121-148\n108-119,119-127,127-160\n154-178,178-182\n140-161\n-9-9,21-46,118-145\n56-74,118-147\n-7-46,46-98,98-148\n-5-94,94-100,100-108,108-151,151-165\n-15-8,8-28,28-39,39-43,43-57\n-5-15,15-20,20-31,31-43,43-60\n1-39,39-81,81-124,128-145,204-230,230-261\n1-64,64-70,70-74,74-76,76-78,78-84,84-122,205-227,227-257\n16-25,25-49,49-56,56-78,78-82,82-100\n33-56,56-77\n10-65,76-97,99-120\n12-62,68-83,83-103,103-118\n-4-39\n2-36,36-45\n11-16,16-19,21-55\n12-30,30-35,35-65,68-77,77-92\n101-122,122-130,130-148,148-150,150-154,154-183,183-198,198-200,200-227,233-239,239-244,244-256\n98-121,126-153,153-183,183-227,242-252,252-265\n132-154,154-161,161-170,170-174,174-186,186-220\n138-172,172-181,181-222\n-6-4,4-8,10-31,31-55\n-2-1,8-31,31-34,34-54\n245-260,260-304,304-350\n12-30,260-295,295-303,303-311,311-353\n234-245,245-253,253-256,256-260,263-293,299-309,309-328,328-333,333-346\n243-258,258-288,298-334,334-352\n-8-43,43-48,48-50,50-72,72-96,96-98,98-101,101-126,126-147,147-166\n-1-1,1-15,15-37,37-65,65-82,82-100,100-107,107-109,109-112,112-132,132-136,136-139,139-150,150-156,156-165,165-179\n5-41,41-45,45-66,72-91,91-101,101-106,106-124,197-215,215-240,250-272\n-8-54,54-67,70-104,104-108,108-115,115-135,135-153,203-220,220-232\n18-44,47-69,69-89\n20-34,34-39,39-47,47-62,69-95\n97-119,141-153,153-175,175-180,180-212,212-236,236-241\n97-115,140-178,178-201,201-204,204-236,236-253\n6-34,34-51\n4-31,31-54,347-363\n-1-30,123-132,132-142,222-253,341-359\n-3-5,7-16,16-26,95-122,122-140,211-231,231-234,234-253\n191-208,208-210,210-214,214-226,226-252,258-276\n-3-8,17-40,63-81,283-301,319-337\n-12-16,16-19,19-40\n-1-29,29-42,330-344,344-359\n-3-17,17-32,32-44,78-96,115-133,136-154,226-244,263-281\n0-48\n2-48,331-350\n-1-36,50-72,203-211,226-236\n5-29,29-35,217-232,232-248,248-264\n15-33,48-70,97-115\n41-65,291-316\n33-70,294-317\n140-158,164-199\n131-148,148-156,156-159,161-190\n52-60,163-197,282-305\n43-75,162-181,181-194,283-291\n68-93,166-192\n69-92,132-150,150-157,163-193\n132-150,163-194\n38-67,292-318\n41-69,293-317\n166-198,294-312\n162-207\n177-198\n161-169,179-199\n41-56,56-76,76-85\n-7-11,13-26,26-41,41-72\n24-44,44-68,290-327,330-332,334-353\n-4-17,34-68,69-79,296-323,323-332,332-335,335-356\n59-90,113-132,159-191\n54-90,154-164,165-192\n41-59,175-205,290-323\n47-77,77-92,181-204,284-318\n45-58,58-60,60-76\n189-203,203-206,206-209,209-213,213-231,285-308\n57-86,165-190\n257-275,288-316\n38-47,287-309,314-322,333-360\n37-48,48-56,56-67,301-329,331-360\n-10-12,34-66,293-325,325-327,327-339\n-9-14,34-66,291-322,335-351\n177-195,268-294\n45-79,166-194,290-323\n46-80,133-157,164-195,233-252,287-325\n50-81,152-177,181-193,295-306\n52-67,71-93,145-159,159-166,166-170,170-189\n290-322\n53-73,178-206,281-307\n49-78,168-202,234-244,285-305\n34-52\n47-77,171-189\n46-63,63-81,283-295,295-298,302-314\n43-78,139-157,161-195,295-322\n48-81,161-197,287-297,300-321\n170-191\n167-189\n0-5,5-28,113-125,125-131,131-150\n1-14,14-37\n91-111,111-113,113-136,136-161\n99-117,117-153\n122-152\n40-77,163-197\n42-80,156-180\n169-191\n170-190\n41-64\n14-36,36-65\n42-81,164-196\n40-62\n56-83,176-180,187-191\n33-47,53-85,170-196,296-314\n36-68,73-90\n44-75\n54-83,122-148,159-188\n53-82,92-99,99-120,157-189\n56-75,126-150,184-202\n58-78,123-147,160-184,184-187,187-188\n175-199,199-216,275-292,292-311\n177-188,188-195,195-207,233-252,282-304\n40-71,159-191,287-314\n40-72,167-193,288-314\n34-65,298-331\n30-36,36-46,46-69,290-311,311-326\n57-84,154-181\n59-84,159-183\n2-14,17-20,20-29,29-37,39-68,130-151,151-159,162-177,177-183\n-3-3,3-11,11-17,17-30,54-80,140-153,156-204\n122-139,139-141,141-156,156-177,177-183\n1-22,22-40,55-73,77-95,142-156,161-176,176-178,178-182\n114-132,149-174\n150-170,170-180,180-197\n29-47,55-73,84-95,95-103,103-114,135-148,154-167,172-190,284-319,321-342\n144-162,162-198\n-9-9,9-27,27-47,47-71,156-169,169-178,178-182\n-1-1,1-33,33-76,76-101,138-154,157-179,179-181\n100-118,120-138,138-151,151-153,153-177,177-180\n-10-10,14-38,38-46,46-64\n28-55,167-193\n128-150,150-154,154-158,158-167,169-177,177-209\n119-137,137-150,150-171,171-175,175-187,187-197,197-199,215-218\n123-141,147-190\n113-124,124-132,132-140,144-157,157-186,191-209,270-286,286-311\n26-44,87-105,117-129,160-178,184-202,279-308,308-320\n64-82,284-302,319-340,342-353\n113-131,147-175\n34-65,65-83,83-90,90-108,164-180\n47-88,158-180\n43-73,163-197\n55-72,72-79,79-100,155-205\n163-197\n38-73\n0-8,8-35,35-38,38-40,40-56,63-87\n21-33,34-60\n28-37,49-68,68-88,169-191\n49-79,157-203\n-17-17\n36-51,51-69,171-189\n20-47,47-59\n37-67,67-69,69-95,153-175\n32-52,52-54,54-72,72-89,154-179\n16-36,43-90,111-137,161-180\n28-42,47-76,168-192\n2-20,20-32,32-34,34-37,37-62\n-1-1,1-6,6-9,9-15,15-18,18-58,68-89\n41-82,166-194\n35-44,291-320,320-323,323-336\n290-322\n0-13,13-56\n-11-11,30-75,75-86,86-94\n45-135\n-8-8,29-71,71-89,89-91\n36-61,61-75,75-85,85-90,90-93,93-118,118-121,121-148\n69-111\n34-81,81-99\n41-77,77-90\n40-68,68-112\n0-8,8-27,27-52\n120-143,143-176,176-180\n-35-35\n-22-22,33-81,81-89,89-91\n109-158,158-202\n8-31,36-54,60-80\n46-90\n-13-13,13-33,33-68\n57-123\n-1-1,1-27,47-67\n0-3,3-25,25-60,60-72,72-74,74-81,81-90\n52-55,81-106,106-111,111-119,119-137\n42-60,66-90\n77-103\n-14-14,55-65\n-1-1,1-18,18-41,41-60,60-86,86-99,99-101,101-107,107-129\n92-119,119-146,146-165,165-195\n0-21,21-26,26-34,34-36,36-38,38-66,66-79\n0-12,12-22,22-79,79-89,89-91\n3-12,24-41,41-44,44-47,47-81,81-103,103-125\n48-67,67-88,88-92\n-2-2,2-21,33-51,51-53,53-93\n122-137,137-152,162-198\n-2-2,2-5,5-6,26-36,38-41,41-61,61-74,74-106\n6-82,82-89,89-91\n-14-14,14-32,120-159,159-180\n24-55,55-81,81-84,84-96\n-1-1,1-4,4-17\n44-61,61-90\n50-69,69-111\n98-112,112-118,118-139,139-164,164-196\n2-12,12-24,28-58\n76-91,91-94,94-124,124-139\n-11-25\n-5-23,75-93,329-347\n131-149,152-178,178-195,195-225,230-248,248-262\n130-141,150-176,176-202,202-230,234-260\n-1-15,60-78,320-359\n-4-18,322-351\n26-45,327-376\n329-376\n135-144,198-229,234-262\n132-144,159-174,187-206,206-230,234-258,271-289\n136-167,176-194,194-226,232-252\n137-168,176-195,195-232\n32-54,54-62,62-83,83-86,86-94\n36-58,58-85\n-43-43,43-58,58-61,61-67,67-88,88-90\n-30-30,35-49,49-56,56-58,58-63,63-69,69-90\n3-25,107-125,138-148,152-179\n45-74\n-10-10\n108-126,132-161,161-177,177-183\n92-111,137-162,162-179,179-181\n-29-29\n-11-11,18-38\n-1-1,1-4,4-21,21-26,26-30,30-41,41-47,47-57,57-89,89-91\n0-20,20-22,22-48,48-53,53-64,64-73,73-84,84-96\n-1-1,1-6,6-11,11-36\n-27-27,33-50\n-9-9,9-30,30-51\n0-25,56-78,78-96,114-133,166-179,179-181\n0-23\n-16-16\n2-17,30-48,49-81,81-90,90-101,112-132,136-151\n0-20,20-26,64-76,76-79,83-95,120-139,146-164\n-19-19,19-35\n-16-16,16-40\n81-109,113-133,154-167,167-193\n-16-16,16-43\n-10-10,126-150,150-153,153-180\n-19-19\n56-97,155-205\n0-27,27-48,48-60\n-33-33\n-23-23\n-10-10,26-34,34-36,36-54,146-158,158-163,165-195\n159-201\n42-57,57-84,169-191\n17-32,32-36,36-68,68-90\n54-73,73-92,161-180\n0-14,14-21,21-25,25-27,27-52,57-79\n-15-15,25-57,158-202\n170-190\n292-315\n289-311\n-9-0,2-9,9-12,12-22,42-75,288-325,326-334\n17-39,45-69,284-294,294-326,347-365\n6-24,42-70,293-309,309-321\n3-13,13-28,45-70,296-319\n36-59,298-323\n39-57,302-328\n139-176,265-283\n110-130,141-157,157-163,163-165,165-179\n47-71,273-293,293-306\n51-75,283-310\n58-83\n71-89,91-109,122-140,157-182\n66-85,85-104,122-140,141-151,151-155,160-170\n47-71,269-280,280-305\n64-90,111-129,157-188,188-193,193-204\n66-84,154-183,184-200\n163-175,175-185,188-195,195-224\n171-194\n151-169,175-197\n11-29,40-50,50-72,149-168,168-173,173-176,176-185,185-195,282-300\n6-24,35-53,53-54,59-69,156-167,167-193,272-283,283-305,305-321\n-1-4,4-16,284-306,314-342,342-344,344-351,352-359\n0-12,77-90,90-94,94-113,113-118,134-152,167-179\n86-104,110-150\n107-118,118-151\n170-201,201-216\n180-202,204-216\n279-305,305-306\n32-52,52-53,56-75,284-309,309-319\n38-57,57-72,163-181,288-311\n106-124,126-141,145-154,154-159,159-161,161-165,165-166,216-229,229-233,233-238,238-251,261-270,273-275,275-294\n82-97,101-114,114-115,117-128,128-130,130-134,134-164,186-194,228-246,255-264\n152-170,170-176,176-187,226-244,250-268,268-272,272-278,278-280,280-307\n169-187,200-208,249-277,277-282,282-290,290-308\n44-79,294-348,348-357,357-380\n14-38,38-49,49-62,62-84,293-326,326-364\n298-316,316-336\n28-60,170-208,275-313\n29-62,171-210,277-314\n79-102,102-142\n81-110,110-117,117-143,143-162\n172-192,194-211\n174-193\n53-62,163-187,294-320\n153-165,165-175,175-185,296-323\n5-20,20-28,28-40,40-47,47-68,75-92,92-105,135-160,160-181\n-4-9,9-13,13-33,33-65,65-71,73-100,145-171\n235-265,265-269,269-272,272-299,302-321\n257-275,275-308\n34-52,57-76,295-331,331-349,349-381\n24-43,51-72,294-343,343-358,358-379\n162-180,270-288\n176-194,246-257,260-284\n1-12,306-331,331-334,334-361\n103-134,134-142,142-144,144-163\n98-110,113-139,139-160,184-193,199-209\n4-22,60-78,296-325,325-328,328-332,332-345,345-348,352-360\n299-323,323-341,345-365\n61-89,95-123,274-300\n96-112,112-118,118-122,122-138,138-161,165-177\n94-105,105-113,113-118,118-120,120-123,123-164\n169-180,180-191,214-229,233-240,240-244,249-255,255-266,268-296\n195-213,242-255,263-282,282-299\n39-51,298-308,308-336,336-362\n11-31,310-329,329-341,341-350,350-370\n288-299,299-322,322-351\n35-53,268-285,293-318,318-325,325-348,348-365\n-2-2,5-10,39-87,90-97,118-130,130-139,139-159,159-165,165-195\n-17-17,17-38,38-48,78-97,99-155,169-191\n0-28,32-50\n31-50,55-73,105-125,125-137,137-145,145-149,149-157,157-180\n71-109\n74-106\n52-70,70-73,73-107\n74-106\n40-83,162-180\n170-190\n42-62\n33-64,64-67,67-81,81-99\n47-77,77-90\n156-180\n21-39,44-63\n29-47,50-67\n50-76,76-81,81-83,85-88,88-92\n0-22\n-1-1,1-34,34-45\n-12-12,27-55,73-88\n-10-10,10-23,23-40,40-43,43-49,49-84,84-96\n34-82,82-98\n-8-6,24-87,87-103,103-106,106-126,130-150\n25-70,70-102,103-123,123-132,132-149\n19-35,35-53,55-78,78-84,84-86,86-98,98-106,106-117,219-243\n12-37,37-41,41-53,53-55,55-60,60-85,85-86,110-137,217-237,237-251\n115-129,134-148,156-179,186-204,206-224,224-234,236-252\n154-181,181-190,192-211,216-234\n32-50,50-82\n-3-15,36-69,69-71,71-73,73-84,84-102\n5-35,346-360\n2-36\n-8-18,45-65,293-315,342-352\n48-75,163-192,290-313,313-332\n50-75,160-186,186-191,296-314,314-333\n0-34\n48-75,161-178,178-182\n53-62,62-79,159-179,179-181\n171-189\n171-189\n41-62\n43-65\n43-65\n58-82,158-181\n61-81,88-106,157-182\n47-80,164-196\n39-59\n31-60\n61-86\n47-67,67-113\n53-68,68-71,71-77,77-79,79-83,83-90\n0-36,36-61\n33-54,87-98,114-132\n59-72,72-80,80-100\n65-115\n47-67,67-90\n67-88,88-92\n39-57,57-68,68-112\n63-117\n74-106\n34-46,46-49,53-60,68-71,75-79,79-83,88-91,91-97,97-115,120-140,152-170\n49-81,81-84,84-89,89-91\n39-67,67-113\n-28-28,28-39,39-64,79-101\n-14-14,136-161,166-194\n50-93,152-208\n41-63,169-191\n40-66,290-308\n50-73,286-297\n171-197\n2-14,14-31,40-58,58-72,290-315\n45-74,166-194\n162-198\n170-190\n3-21,43-65\n45-76,164-196\n34-55\n-22-22,120-136,136-147,147-150,150-154,154-167,167-170,170-174,174-178,178-182\n-9-9,128-147,147-177,177-183\n-27-27\n-21-21,161-179,179-181\n-1-1,1-5,5-11,11-31,167-193\n-18-18,18-21,21-23,23-39,124-138,138-154,154-158,158-174,174-186\n-1-1,1-16,16-27,27-52\n-24-24\n0-9,9-19,19-54\n-18-18,125-136\n171-189\n168-192\n169-191\n-9-10\n67-114\n76-105\n-11-10\n-10-10\n34-48,48-84,89-91\n79-93,93-99,99-112,247-262,262-265,265-282\n2-17,164-196\n-11-11,158-180\n8-18,18-22,24-49,52-64,75-93\n50-60,60-90\n70-87,87-90\n-12-12\n-10-10,14-18\n-23-23\n-15-15,20-39,60-79\n-5-18,18-28,157-171,174-201\n-11-16,174-201\n-12-12,15-31,31-35,35-48,105-138,169-191\n13-30,52-78,78-102\n70-90\n-7-7,7-29,45-62\n-1-1,1-20,54-86,86-89,89-91\n12-21,27-30,30-46,49-62,62-81\n38-74,158-202\n138-155,155-177,177-183\n-13-13\n303-323,328-345\n300-324\n-6-6,6-11,11-14,14-31,31-41,41-43,43-63,63-71,71-77,77-82,82-97,97-106,106-137,137-147,147-152,152-176\n-3-3,3-6,6-8,12-35,35-38,38-55,55-81\n-13-13\n3-14,14-22,22-33,76-101,110-121,144-161\n-5-4,4-26,31-41,59-70,70-81,81-95,95-124,128-141,141-162,162-175\n56-71,71-112\n11-23,30-79,79-92,106-122,122-152\n16-34,43-74,74-76,76-78,78-93,93-100,100-137\n150-168,168-203,207-216\n-9-11,18-37,302-321\n347-372\n-26-20,36-46,306-332\n-12-12,36-53,53-80,84-96\n55-73,73-90\n-13-13,48-61,61-72,74-106\n68-112\n13-32,32-83,83-97\n65-75,75-111\n69-107\n56-78,78-87,87-90,90-100,100-115,119-135\n51-76,76-114,116-120\n137-155,159-177,177-180\n-10-19,169-202\n-9-18,150-162,162-164,164-191\n-13-13,171-189\n79-101\n-16-16\n-12-12,12-54,85-102,171-189\n-16-16\n-17-17,25-45\n-20-20\n-16-16,18-24,24-44,44-64,120-136,136-167,167-193\n40-53,70-83,104-122,122-124,124-155\n0-22,165-180\n197-221\n50-69\n18-32,32-52,52-66,66-89,89-97,97-100,104-116,263-289,296-314,322-333\n-6-7,10-22,27-35,49-60,60-63,63-66,66-70,70-71,83-97,156-174,203-221,254-281,298-315,315-320,320-334,339-350\n25-52,52-53,67-79\n-20-20\n-12-12\n159-180\n-16-16\n166-194\n-1-1,1-24,139-164\n-15-15\n-25-25,28-35,50-60,62-66,66-68\n-13-13,13-15,15-19,19-23,23-39,67-89,89-91\n-5-5,5-9,9-20,20-56\n13-38,42-62,278-291,291-300,300-309,311-323,329-342\n57-77\n57-77\n3-55,55-79,81-90\n-1-1,1-14,14-18,18-33,41-90,98-116\n-12-12\n-11-11,111-129,129-148\n-1-1,1-3,3-9,9-12,12-22,67-85,90-100,100-122,150-168\n80-98,148-175,175-185\n0-31,31-34,34-52\n-9-9,9-28,93-103,103-112,112-122,162-180\n-25-25\n-14-14,29-56,147-154,162-198\n0-19,26-44,47-65,77-103\n0-24\n-14-14,168-192\n-9-9,15-33,63-80,80-92,92-100,100-104,104-108,108-128,128-134,164-177\n-4-17,44-62,62-73,73-98,98-130,130-150\n-4-14,20-40,40-47,47-49,49-71,71-84,84-89,89-123,123-140\n102-120,224-242,245-263,263-284,284-297\n-27-27\n62-74,74-78,78-126\n82-100,100-122,133-142\n37-60,60-90,124-156,157-177,177-180\n21-33,33-43,43-45,45-53,53-69,73-88,156-174\n64-116\n66-105\n139-161\n3-33,33-56,56-87\n76-92,92-111\n52-87,87-89,89-91\n77-103,103-128,131-152\n31-54\n97-128,128-148,148-152\n137-161\n99-132,132-133,136-141,141-155,162-179\n-1-1,1-42,164-196\n-2-2,2-11,11-20,20-41,157-180\n0-14,14-38\n86-118,118-133,133-135,135-137,137-169,174-192,279-298\n88-128,128-141,141-148,148-153,153-157,157-161,161-167,167-194\n68-86,89-107,112-130,133-163,274-292\n89-121,121-143,143-164\n85-129,131-139,139-169,175-197,273-293\n84-104,104-128,132-140,148-153,153-159\n89-107,107-140,140-157,177-199\n89-99,99-110,110-119,121-147,147-154,166-180\n-4-5,10-25,25-39,39-41,45-57,58-76,117-135,157-165\n7-37,37-58,72-90,164-187\n-8-8,8-28,28-31,31-47\n75-105\n68-90\n164-196\n-1-1,1-5,5-25\n3-32\n0-19,158-202\n3-13,13-38,161-180\n0-20,41-64,64-65,81-103,103-133,153-163,170-190\n0-16,16-36,36-50,50-86,86-89,89-108,108-128,128-145,145-166,166-194\n-3-3,3-9,9-12,12-35,92-108,108-128,128-149,157-165\n-2-2,2-31,32-52,52-72,72-88\n68-112\n-3-3,6-32,32-38,38-55,79-101\n37-57,57-76,76-90\n55-82,92-109,109-123\n37-47,53-84,92-108,108-123\n0-38,41-53,93-115,136-162,162-198\n-18-18,18-32,166-194\n87-102,102-118,118-138,278-302,325-333\n155-189,339-369\n161-192,332-367\n42-62,62-81,167-193\n40-61,61-77,163-197\n14-18,18-40,40-54,54-58,58-60,60-99,99-142,142-175,175-194\n8-44,44-51,51-101,101-103,103-116,116-123,123-136,136-152,152-188\n37-62,73-81,153-181\n42-65,154-186,294-302\n33-45,48-74,141-157,158-179,179-181\n48-76,169-191\n160-176,176-179,179-181\n1-12,12-24,24-37,37-64,64-71,71-75,75-77,99-122,122-133,145-170,170-178\n31-49,49-52,52-73,160-178,178-182\n55-76,174-192,293-309,309-323\n40-51,51-79,163-173,173-177,182-192,280-290,290-299,299-300,306-325\n40-64,64-77,77-87,87-93\n67-83,83-89,89-91\n0-10,21-46,46-64\n97-130\n68-89,89-91\n11-23,23-45\n-14-14,19-30,30-44,44-47,47-68,68-80\n21-45,127-135,159-180\n13-36,142-157,160-177,177-183\n46-63,63-76,164-196\n34-45,46-67,67-87\n48-71,170-190\n17-29,46-53,57-72,109-127,134-149,153-168\n40-55,55-81,163-177,177-183\n0-23,37-52,56-71,83-99,101-126,133-151,151-152,155-164,164-166,166-170,174-186\n-2-2,2-7,7-12,12-28,166-194\n48-72,162-198\n-20-20,158-202\n-4-4,4-10,10-23,26-42,42-44,44-61,61-75,75-79,79-85,85-109,109-124,124-133,133-144,144-149,149-154,154-179,179-181\n-13-13,164-196\n-15-15,25-33,33-40,40-48,48-51,51-69,71-89,94-111,111-124,124-138,138-153,153-158,158-202\n-16-16,34-65,75-106,106-122\n-22-22,159-201\n0-20,61-80,80-82,82-104,104-123\n-1-1,1-6,6-27,133-146,146-150,150-177,177-183\n-13-13,164-196\n-14-14,160-200\n-17-17,131-144,169-191\n-19-19,19-32,32-37,37-60,71-91,123-154,154-206\n-15-15\n-20-20,20-43,117-135,139-158,158-180\n0-13,13-18,18-42,42-63,63-76,76-84,84-107,125-152,152-156,161-199\n-11-11\n-17-17\n-29-25,25-32,32-70,72-96,96-103,103-117,120-162,162-178,178-203,203-240,248-270\n-26-19,19-57,71-82,87-96,96-116,118-122,125-163,163-194,194-197,197-218,218-240,251-275\n-4-31,31-50,52-57,57-61,61-65,65-69,69-83,116-140,175-192,192-212,212-230\n0-11,11-28,28-36,36-57,71-94,172-193\n272-290,309-319,319-355,355-368\n122-134,134-139,139-145,145-159,159-165,167-185,198-209,209-226\n126-151,151-172,172-194,194-221\n0-37,54-72,123-141,188-196,207-218,223-237,327-337,350-359\n-1-39,43-51,333-351,351-357,357-359\n-2-2,2-16\n168-193\n165-192\n2-27,157-180\n-13-13\n-13-13,138-164,164-172,172-180\n-16-16\n-20-20,151-164,164-180\n79-101,105-130,154-180\n61-78,78-126,127-135,135-155,155-180\n0-20,20-36,164-196\n-13-13,28-40,88-106,143-159,159-161,161-170,170-173,173-187\n-10-10\n2-13,13-16,16-21,21-34,157-203\n-10-10\n-10-10\n-4-9,9-15,15-29,29-54,54-74,82-110,110-116,116-137,162-203,203-207,207-230\n4-24,24-31,31-51,51-57,57-62,62-83,83-102,117-138,166-186,186-205,205-223\n11-36,316-337,337-343,343-345,345-357,357-368\n2-31,231-255,260-274,309-317,343-356\n107-130,136-158,162-180,189-207\n6-19,19-31,31-44,77-101,177-191,191-208\n12-21,21-29,29-30,32-44,169-186,186-196,196-216\n-11-11,160-200\n62-89,164-188\n166-187\n23-46,57-77,77-78,82-94,146-168\n45-63,163-180\n-7-7,7-18,18-35\n-21-21\n0-5,5-11,11-15,15-29,158-177,177-183\n-31-31,134-157,157-203\n153-207\n-28-28,148-212\n160-180\n0-3,3-8,8-10,10-29,154-179,179-181\n-1-1,1-17,21-38,44-62,65-83\n-15-15\n-18-18,27-47,166-194\n-27-27\n-1-1,1-25,159-201\n0-19,146-161,164-176,176-179,179-181\n-12-14,14-47,158-175,176-205,205-230\n0-4,4-6,6-42,173-227,335-360\n-19-19\n-23-23,23-73,108-162,162-166,166-194\n-17-17,17-69,69-111\n-15-15,15-35,35-52,57-75,75-88,88-109,118-146,166-194\n-1-1,1-14,19-32,165-180\n-20-20,20-26,26-44,158-202\n-16-16,167-193\n-12-12,12-29,128-146,146-168,168-180\n-13-13,149-180\n-29-29,32-45,45-49,49-58,58-66,68-83,83-88,88-102,110-132,132-139,139-144,144-148,148-212\n-20-20,20-25,25-55,57-64,64-75,75-84,99-150,150-152,152-164,164-196\n92-100,111-155,155-173,268-285,285-290,292-303,303-334,334-336,336-342,342-345,345-364\n94-112,112-131,131-134,134-139,139-146,146-163,297-333,333-340,340-342,342-351,351-363\n-16-16,159-201\n153-169,169-191\n-17-16,16-42,136-154,180-200\n-8-44,128-154,159-187,187-217,334-352\n2-22,22-35,344-354,354-358\n-22-22,155-178,178-182\n0-19,48-65,68-85,85-89,89-96,122-142,142-147,147-153,167-179,179-181\n-5-5,5-20,161-174,174-186\n-14-14,170-190\n-10-10,168-192\n0-15,20-30,157-174,174-179,179-181\n-13-13,33-55,128-154,162-179\n-4-26,26-43,149-167,182-218,329-347\n-17-13,13-25,25-57,96-113,126-136,136-146,146-154,157-186,186-189,189-193,193-198,198-233,310-328,328-343\n-22-22\n-3-15,38-57,57-74,178-182,297-340,340-353\n-4-5,5-10,10-31,40-57,57-72,171-179,287-304,304-332,332-343,343-356\n20-46,51-75,96-114,175-194,276-302,319-337\n-6-12,14-25,30-39,39-57,61-79,303-328\n-13-13,48-75,166-194\n44-52,55-75,75-96\n62-92,92-115\n52-69,73-94,106-124\n52-94\n66-89\n79-107,111-140\n56-93,93-106\n-13-13,153-173,173-180\n-17-17,17-32\n75-105\n73-105\n54-98,98-101,101-125,125-151,151-209\n-2-2,2-16,85-132\n-2-2,2-15,15-36,36-51,56-76\n-1-1,1-35\n47-78,78-93,93-108\n71-113,113-136\n49-84\n50-94\n50-64,64-103\n37-63,68-71,71-83\n45-82\n44-84,166-194\n69-94,140-152,154-206\n37-65\n46-78,162-198\n54-76,76-102,102-121\n186-206,206-212,212-225,225-228,228-243,249-291\n185-221,265-268,272-284,284-303\n0-14,170-190\n57-86\n56-90\n141-154,161-180\n-14-14\n125-149,149-153,153-157,157-167,167-169,169-176,176-178,178-182\n94-106,106-112,112-124,124-126,126-128,128-134,134-151,161-175,175-185\n-12-12\n0-20,164-196\n-12-12\n-22-22\n-10-10\n1-26,115-131,131-133,133-172,172-175,175-180\n77-113,113-118,118-130\n141-160,160-180\n134-168,168-174,174-180\n-9-9\n-14-14\n-11-11\n169-191\n6-18,18-27,27-53,55-58,64-71,71-82,82-84,84-91,91-96,96-113,113-116,116-129,129-148,155-180\n0-33,52-69,69-77,146-165\n-14-14\n-13-13\n-11-11,168-192\n-16-16,166-194\n0-17,26-46\n-12-12\n-18-18\n0-23,163-177,177-183\n-1-1,1-3,3-34,141-155,155-161,161-164,164-196\n0-5,5-37\n8-28,28-33,33-39,39-54,115-133\n-11-11\n-10-10\n0-13,13-23,23-45,109-128,132-153,169-188,197-216,218-236\n-4-15,15-19,19-51,51-53,53-72,84-108,108-114,114-129,129-137\n-6-18,18-20,20-22,22-30,30-49,87-99,99-101,101-104,104-127\n-21-21,112-120,123-131,134-143,143-153,169-191\n-15-15,162-180\n-17-17,168-192\n-14-14,166-194\n-16-16,154-206\n-10-10,35-55,115-136,167-193\n34-52,94-112,179-201,201-216,216-233,252-264\n272-300\n40-80,162-206,277-306\n56-79,159-201,267-310\n167-196\n166-192\n40-67,286-316\n33-55,55-77,268-286,286-316,323-341\n54-71,71-94,157-193\n53-88,163-187\n47-71,157-191,289-310\n60-78,149-181\n53-82,160-183\n46-72,168-193,290-318\n42-83,172-194,282-324\n43-78,82-88,163-185,277-318,318-321,321-343\n167-194\n158-180,180-203\n171-191,191-210,283-316\n169-188,188-216,253-269,276-316\n33-43,43-52,53-80,164-190\n51-84,156-185\n44-64,64-78,78-91,165-179,184-198,295-317\n51-76\n49-62,62-64,64-67,67-86,173-196,289-322\n45-74,277-293,293-322\n49-93,168-197,197-206,206-216\n47-96,165-183,183-205\n26-36,36-40,43-68,296-322\n43-62,62-69,69-82,82-90,165-188,188-201,201-203,203-205,205-207,207-222,222-229,239-257,272-296,296-301,301-317\n49-66,66-68,68-89,164-177,177-193,197-221,264-272,275-281,281-295,295-301,304-308\n-17-17\n-1-1,1-18,123-143,143-146,146-150,156-178,178-180\n-15-15\n0-22\n-20-20\n165-195\n153-180\n162-198\n-16-16,159-201\n-16-16,128-147,147-161,161-180\n-12-12\n-11-11\n162-198\n160-180\n0-6,6-21,158-180\n-5-5,5-28,28-47\n0-19\n-17-17\n170-190\n-22-22,29-54\n72-98,117-132,132-155,155-205\n0-18\n166-194\n146-170,170-190\n-18-18,136-161,161-179,179-181\n-12-12\n166-194\n-1-1,1-30\n167-193\n-11-11,159-201\n-16-16,16-37,37-51,51-65\n-10-10,13-36\n164-196\n140-162,162-179,179-181\n0-48\n170-190\n-2-2,2-5,5-19\n0-6,6-25,62-86\n168-192\n2-41,41-52,52-57,57-60,60-75,75-87,87-96,96-110\n-1-37,37-93\n59-86,86-93,93-102,102-105,105-122,136-154,154-155\n53-78,233-262\n-11-25,25-28,28-45,45-49,49-88,88-108,108-112,112-118,120-138,216-228,232-262,265-288\n36-58,58-78,78-83,83-95,95-107,260-278,309-327\n42-75,76-97\n40-58,58-60,60-62,62-64,64-83,83-87,92-102\n68-88,88-91,91-93,93-113,120-136,139-155\n-4-29,335-354,354-356\n-2-13,13-18,18-30,332-358\n49-67,171-193,287-318\n59-78,166-194,292-317\n285-308\n54-75,167-186\n53-75,158-161,165-187\n185-211,278-293,293-295,295-299,299-316\n180-189,201-212,276-314\n-1-1,1-57,80-100\n-25-25,25-50,50-62,62-78,78-82,82-95,95-125,125-156,156-204\n0-10,10-22,33-62,62-84,84-90\n-12-12\n151-209\n-14-14,21-39,39-43,43-48,48-65,65-81,81-100,100-124,124-145,160-200\n-15-15,32-57,90-107,107-167\n-13-13\n-17-17,24-44\n168-192\n165-195\n169-191\n0-13,54-71,71-83,83-107,107-112,112-126\n-20-20,20-21,23-26,26-28,101-110,113-126,126-133,133-145\n127-146,146-162,169-191\n116-140,169-191\n0-6,6-27,148-163,163-168,168-192\n-3-3,3-28,170-190\n0-6,6-41,41-49,49-54,67-79,79-87,87-105,113-131,131-153,158-202\n-13-13\n169-191\n132-157,169-191\n125-179,179-181\n79-89,89-98,98-114,114-134,134-161,161-180\n-25-25,39-57\n79-103,109-119,119-127,127-150,150-152,152-180\n248-256,271-310,310-324,324-346\n266-301,301-307,307-309,309-319,319-345\n-2-18,18-41,41-45,45-46,48-52,52-54,75-101,341-344\n-7-11,11-14,19-40,49-63,67-100\n102-122,133-182,182-211,211-236,240-266\n100-120,120-124,128-172,172-182,182-214,214-238,238-268\n132-158,158-174,190-208,245-263\n15-37,142-164,256-260,260-280,288-339,339-342,342-359\n252-271,293-327,327-355\n135-145,145-163,182-204,204-236\n137-155,155-175,184-196,196-214,222-240,263-281\n-24-24\n-16-16,24-32,32-58,107-118,128-154\n164-196\n-17-17\n-19-19,110-129,129-136,136-149,149-153,153-155,155-166,166-194\n0-20,45-70,70-72,72-76,76-90\n-15-15\n-11-11\n0-16,156-164,165-195\n16-45,46-55,59-63,63-83,90-112,154-166,166-194\n10-27,27-30,30-50,50-72,151-165,165-177\n-19-17,17-33,37-50,50-64,74-95,95-115,115-125,125-149\n-6-9,9-11,11-15,15-39,40-72,72-78,78-86,86-96,96-135,146-169\n43-61,83-101,229-248,248-251,255-274,289-311,330-341,341-347,347-365\n37-56,56-95,95-111,113-131\n48-89,89-92,92-104\n0-13,13-20,23-46,49-63,63-80\n-15-15\n1-10,10-27,48-67,114-119,119-122,122-142,142-181\n14-33,131-194\n0-41,42-52,127-137,169-179\n29-49,208-233\n22-49,205-213\n199-219\n198-218,222-239\n170-190\n136-156,165-195\n-2-2,2-16,44-83,160-180\n18-36,41-58,58-63,63-75\n45-81,162-180\n54-81,125-153,156-182\n54-78,145-164,164-182\n177-195,198-220,293-312\n40-55,55-76,168-192,282-309\n44-81,177-197,280-310\n39-85,167-193\n38-76\n52-72,78-90,179-197,270-283,283-292,292-298,298-326\n52-76,157-182\n53-77,156-184\n30-43,51-74,166-194\n17-43,43-55,55-64,64-75,75-88\n240-258,267-289,289-306\n179-198,198-214,262-280,281-302\n189-209,269-297\n271-298\n195-244,244-251,251-272\n192-220,220-240,240-260,260-279\n-12-12\n0-18,22-46\n13-48\n43-76,76-85,85-95\n42-59,59-78,161-179\n53-72,75-89\n52-72,128-146\n10-40\n9-31,31-47,52-70\n29-40,40-48,48-59,293-318\n162-184,283-313\n39-66,66-69,69-86,296-323\n48-86\n46-61,61-66,66-93\n-13-18,162-189\n162-184,184-200,344-374\n167-192\n169-191\n-18-18,18-35\n-4-27,27-43,43-62,220-238\n64-116\n26-41,46-65,65-67,67-71,71-82\n37-55,55-76,162-198\n-11-11,122-136,136-139,139-155,155-161,161-180\n0-22,27-35\n347-370\n-17-17\n5-27\n11-23,23-25,25-29,29-38,38-51,51-59,59-64,64-84\n2-35,167-182\n12-22,27-56,56-76\n13-40,45-74\n0-19,134-180\n-28-28,35-57\n-6-6,6-9,9-15,126-143,143-163\n-13-13,13-19,19-33\n0-4,4-21\n0-29\n0-26,31-53\n50-70,70-97\n208-222,222-251,255-268,268-270,270-278,278-290,290-308,308-321\n-10-10\n-22-22,163-197\n-15-15,15-26,26-43,43-48,48-62,63-83,128-146,146-169,169-180\n-11-11\n-15-15\n-1-1,1-18,23-43,43-46,46-57,83-101,101-107,107-124,136-157,157-171\n139-166,166-171,171-176,176-184\n165-195\n-12-12,12-22,163-180\n6-24,40-50,50-59,59-61,84-102,102-118\n-11-11\n-9-9\n37-55,155-183,183-192,192-204,204-214\n158-176,176-180\n14-33,43-70,74-92,171-189\n169-191\n30-42,44-63,63-80\n-11-11\n-15-15\n52-70,287-315,315-319,319-323\n52-60,60-78,287-315\n3-21,30-43,43-58\n-13-13,13-17,17-19,19-27,32-59\n26-45,46-59,59-69,69-89,89-102,145-157,157-160,164-176\n16-48\n-33-33\n-1-1,1-4,4-25,25-46\n-13-13,70-94,99-121,159-201\n1-29,152-180\n-12-12,170-190\n8-11,11-13,13-24,24-28,33-43,184-201,349-368\n47-62,62-84,89-108,157-177,177-183\n36-70,70-77,77-91\n41-67,67-81,81-96,96-107,156-178,178-182\n37-65\n24-46\n53-75,75-95\n32-50,50-69,72-90\n5-21,24-32,32-56,56-69,69-74,74-92\n32-56,59-80,174-196,289-305,305-309,309-330\n34-56,56-76,129-147,172-190,289-322,324-351\n63-91,91-99,99-120,145-157,157-168\n65-95,97-117,153-172\n8-26,26-53,53-84,283-325,345-363\n8-30,30-52,52-82,177-200,277-293,293-327,327-340\n0-4,4-15,15-20,20-35,35-38,38-60,160-180\n28-47,47-61,163-197\n40-55,55-67,67-88,169-191\n56-79,160-174,174-180\n59-81,119-146,169-191\n-4-4,4-7,7-38,38-58\n16-34,34-42,42-54,54-74,144-162,173-189,189-191,191-221,309-327\n15-34,34-42,42-45,45-51,51-70,144-162,163-181,184-203,203-207,207-211,211-222,309-327\n39-76,176-184\n-4-4,4-20,131-154,154-156,158-202\n140-155,158-202\n1-9,12-14,14-35,35-57,69-112,112-126,126-128,155-168,168-175,175-178,178-182\n-7-7,38-56,157-203\n166-194\n111-133,139-157,161-199\n55-77,81-93,108-125,125-133,133-154,154-167\n132-141,165-195\n16-46\n1-15,15-48\n-30-30\n-19-19,159-201\n5-23,124-161,161-199\n-19-19,22-26,26-42,139-160,160-166,166-194\n127-147,157-203\n24-47,79-97,97-107,109-127,222-233\n0-58\n-15-15\n0-19\n-15-15,31-40,51-69\n142-158,162-198\n-15-15\n139-165,169-191\n-16-16\n58-76,76-84,84-89,89-91\n-14-14\n-1-1,1-16,16-42,51-59\n-15-15\n-19-19,21-42,73-81,81-87,87-93\n0-22,23-55\n54-62,69-72,72-78,103-114,127-152,152-160\n69-88,88-117,117-131\n69-83,83-90,90-117,117-129\n79-92,92-95,95-97,97-99,99-102,102-127,257-279,286-297,297-315\n99-122,226-241,241-245,245-253,253-278,278-291,291-296,296-314\n64-82,82-92,92-99,99-102,102-119,123-134,134-146,146-154,274-287,287-290,290-317\n72-98,98-101,101-132,137-155,157-175,277-301,301-322\n80-104,125-143,263-286,293-313\n78-96,105-129,239-259,261-279,279-288,288-326\n-29-29\n-18-18,18-22,22-53,53-78,78-90\n-12-12,15-34\n0-9,9-46\n18-47\n-1-1,1-18\n0-23\n-10-10,169-191\n24-36,36-57,57-76,119-137,166-194\n-11-11,170-190\n-9-9,12-29,29-50,139-166,171-189\n-11-11,164-196\n-20-20\n40-58,65-92,96-119,171-189\n125-143,145-163\n63-85,171-189\n-13-13,13-28,142-162,162-167,168-192\n-15-15,164-196\n-16-16,16-33,133-153,153-164,164-173,173-187\n-18-18,166-194\n-17-17,149-161,164-196\n154-206\n-15-15,129-145,145-150,150-152,152-158,162-198\n152-208\n33-54,54-61,61-64,64-85,156-178,178-182\n40-58,72-84,151-180\n32-61\n-7-7,7-9,11-31,31-58\n19-65,65-82,154-180\n25-84,154-174\n-4-4,4-6,30-63\n43-62,62-81,152-166,166-169,169-191\n-21-21\n-44-44,99-135,161-199\n0-20,25-34,34-85,85-90\n-18-18,18-56\n-17-17,17-63,113-141,170-190\n1-19,37-86\n135-159,159-201\n167-193\n-3-3,3-24\n-23-23\n-10-10,30-47,47-69,162-198\n-18-18,37-64,66-74,168-192\n14-30,30-58,134-150,158-202\n167-193\n-2-2,2-16,42-84,114-141,141-156,163-197\n171-189\n144-161,161-174,174-186\n169-191\n141-158,162-180\n141-161,161-163,169-191\n145-180\n169-191\n113-136,146-164,164-196\n-25-25,25-33,33-49\n-9-9,27-45\n-11-11\n-14-14\n-13-13\n-23-23,24-29\n-21-21\n-15-15,23-43\n32-46,123-136,146-163,163-197\n-1-1,1-17,21-36,42-60,166-194\n57-80,99-117,121-149,149-166,166-174,174-177,177-183\n165-195\n164-196\n-12-12,12-39\n-11-11,16-45\n167-180\n-10-10,10-35,38-52,165-195\n160-179,179-181\n-1-1,1-17,27-39,43-45,45-48,138-148,153-180\n-30-30,32-35,35-54\n-9-9,26-42,42-72,105-123,123-158\n34-71,164-196\n33-76\n-4-4,4-68\n-8-8,8-24,24-62\n171-189\n171-189\n115-128,128-134,134-161,161-199\n-11-11,37-72,161-180\n160-180\n41-67\n148-158,160-164,169-191\n148-167,170-190\n35-55,55-71,119-137,161-199\n51-103,131-187,305-342\n46-101,113-140,140-159,159-193,262-288,290-326\n38-57,57-74,74-77,77-81,81-116,138-164,168-197,330-342\n50-72,85-110,126-144\n265-279,290-314\n289-312\n300-333\n297-330\n249-267,288-310,310-325,334-352\n263-286,286-310\n163-198,222-247,265-304\n164-199,214-248,274-303\n178-191,191-216,216-218,218-228,275-300\n177-198,198-216,216-237,280-308\n165-193,209-214,214-246,252-293\n163-191,196-198,198-209,211-247,262-282,282-289,289-300\n41-66,294-328\n40-67,293-327\n-8-12,18-26,37-52,52-69,303-336\n12-26,30-71,289-314,314-334\n-5-21,39-68,78-96,299-317,317-332\n-1-21,32-70,81-100,300-325,325-342,342-359\n40-65,297-332\n39-67,296-334\n16-34,35-54,54-70,313-326,332-345\n43-74,74-97\n44-71,85-103,299-317\n-8-13,31-74,299-334\n38-74,301-334\n-10-9,9-11,11-15,15-32,42-74\n-5-16,41-67,311-335,339-352,352-355\n39-53,53-56,56-85,155-168,174-187\n48-70,70-72,72-87,137-155,166-190,305-322\n305-323\n178-209,265-296,296-298,298-316\n158-170,178-202,268-292,292-309\n3-18,18-20,31-64,274-296,299-314,314-333\n32-67,75-90,273-294,294-302,306-330,346-358\n17-37,37-58\n35-56,314-332\n22-32,32-56,314-332\n48-84,153-189,273-288,288-292,292-294,294-312\n49-83,92-98,98-117,150-191,282-294,294-312\n48-65,65-69,69-90,149-168,172-189\n286-311\n284-311\n285-308,341-344\n145-162,164-211,265-312\n144-163,163-205,213-219,271-310\n166-199,200-211,268-288\n41-66,296-332\n40-66,295-331\n32-48,48-72,306-325,339-343\n29-69,303-333,341-359\n50-86,163-199\n47-82,156-188\n153-185,279-297,297-306,306-315\n32-64,303-323\n32-59,299-326\n53-86,137-165,165-172,172-182,182-198\n53-86,145-156,156-165,165-170,170-187\n159-177,177-203,220-245,264-303\n132-150,160-202,215-242,266-287,287-291,291-311\n163-186,219-245\n160-187,219-230,230-247\n27-72,297-326\n35-64,298-324\n28-41,41-61,305-323\n30-46,46-63\n-21-21,24-44,65-140\n11-19,47-65,73-118\n-24-24,51-73,81-96,96-102,102-120\n-9-9,39-59,68-130\n78-117,132-152\n48-65,65-107,110-131\n-1-1,1-33,40-57,57-80\n1-32\n-4-4,7-27,34-50,50-59,59-69\n0-47,57-82\n0-31,31-52,52-77\n0-31,31-45,45-78\n103-146,163-169,169-191\n80-101,104-155,155-163,163-170,170-177,177-180\n115-143\n108-140,146-165,165-175,175-179,179-181\n103-156,156-180\n112-134,134-165,169-179,179-181\n78-100,100-146,146-165,165-195\n103-137,137-145,145-146,148-166\n-25-25,25-39,54-74,74-77,77-104,104-132,136-154\n29-42,46-56,56-67,74-128,140-158\n0-18,28-46\n-20-20,77-127,135-159\n78-104,104-131\n0-36,40-56,56-84\n7-45\n0-30,30-42,42-50,50-53,53-84\n7-31,31-52\n85-107,107-132,132-151,151-166,166-168,168-192\n14-32,58-71,73-86,86-104,108-116,119-127,127-138\n-15-15,19-40,45-62,62-75,83-122,122-140,170-190\n-22-22,22-24,24-30,30-50,71-124\n15-33,62-76,76-81,81-96\n65-89,89-127,127-132,132-156,163-197\n65-117\n2-41\n8-36\n0-36,43-70\n0-31,48-58,58-75\n116-128,144-180\n148-173\n119-139,143-179,179-181\n0-14,14-20,20-37,40-56,56-77,90-109,109-130\n42-67,67-69,69-73,73-75,75-92,92-96,96-132,136-155\n-24-24,83-157\n-15-15,15-26,43-60,81-89,104-132\n-45-45,163-179\n170-190\n169-191\n-13-13,91-100,111-125,125-134,134-150\n0-20,28-46\n-10-23,101-145,325-350\n95-146,317-347,347-367\n68-82,82-133\n80-92,98-122,122-125,125-134,137-155,170-188\n274-291,293-312\n276-292,292-312\n295-314\n280-291,293-314\n1-39,39-59,59-77,286-302,302-334,334-361\n3-35,49-57,57-79,285-304,304-329,329-363\n-2-11,11-31,31-45,51-80,302-329,332-334,334-351,351-356,356-358\n-10-5,5-8,8-35,55-76,306-325,325-339\n14-34,34-50,321-350,350-360\n0-4,4-15,15-26,26-35,35-37,37-46,46-59,314-338,342-360\n-1-35,38-43,43-58,58-81,325-359\n-4-40,40-68,325-356\n-8-5,5-32,57-79,322-342\n0-3,3-11,11-27,27-30,34-46,329-351,351-360\n330-353\n167-186,186-214,214-233,233-263,266-279,279-296\n167-191,196-222,222-230,230-235,235-252,252-255,255-276,279-298\n196-220,220-238,238-274\n165-192,195-222,229-242,242-273\n99-141,213-225,338-364\n97-139,209-219,332-349,349-356,356-368\n101-132,132-150\n96-108,108-112,112-144,144-161\n293-312\n293-311\n-1-1,1-5,5-33,33-39,39-41,41-62,324-345,345-350,350-359\n1-36,42-51,51-69,315-333,333-344,344-361\n1-42,42-46,46-58,320-340,340-359\n-1-21,21-41,41-58,323-359\n-1-9,95-138\n92-131\n153-171,174-205,231-251,251-274\n173-191,204-223,223-232,232-235,235-240,240-249,249-273\n317-337,337-344,344-357,357-373\n317-344,344-364\n-19-19,44-136\n66-114\n-32-32,59-120\n-10-10,67-103\n71-109\n-4-4,75-105\n0-26,26-47,54-79\n-1-1,3-41,60-78\n99-122,125-180\n99-127,127-176,176-184\n-3-3,3-14,14-30,30-53,53-89,89-91\n-11-11,11-31,31-64,64-122\n47-75,75-105\n-17-17,33-57,57-79\n101-125,125-132,132-137,137-162,162-198\n-9-9\n170-190\n-10-10,27-61,170-190\n57-93,93-113,249-266,266-303\n0-15\n-13-13,168-192\n31-41,41-45,51-74\n6-23,25-50,161-179\n6-30,31-48,52-65,65-87,87-93\n0-32,32-59,59-87,87-93\n0-8,8-27,36-51,51-70,70-90,90-114\n33-46,46-50,56-90\n130-153\n75-88,88-125\n92-119\n8-17,31-54,54-73,118-136\n67-89,89-91\n-23-23,23-92,92-123,127-147\n-17-17,46-69,69-76,76-88,167-193\n111-146,146-172,172-178,178-182\n-4-4,15-26,26-31,31-35,35-57,57-73,74-94,94-110\n128-154,170-190\n-1-1,1-5,5-15,15-47,49-100,103-107,107-134,134-153,171-189\n0-18,21-41,41-63,88-119\n22-50,58-97,98-117\n11-15,63-86,86-91,91-103,124-150\n118-126,132-156,156-160,160-180\n52-74,287-318\n52-74,293-318\n49-70\n50-74\n-20-20,74-111\n-2-2,2-10,10-31,65-88,88-92\n-3-3,3-25,25-28,28-51,78-111\n50-63,64-116\n16-31,31-62\n24-45,68-112\n52-71,71-109\n-2-2,2-17,41-90\n0-12,12-23,23-45,45-50,50-56,56-127\n70-110\n34-42,62-83,83-97\n72-100\n94-131,131-156\n12-34,34-54,54-56,56-72\n-15-15,15-35,90-123\n43-74,169-191\n3-19,19-24,24-28,28-62\n6-24,49-72,289-311\n32-44,50-74,283-295,338-349\n167-193\n171-189\n-14-14,24-28,28-36,36-50,155-179,179-181\n-14-14,165-195\n-14-14\n-16-16\n60-71,179-200,279-314\n175-203,277-312\n60-82,171-201,263-271,282-298\n48-71,280-305\n39-57,60-82,260-278,284-309,309-325\n60-82,164-193,197-213\n53-93,130-142,167-190,194-221\n60-82,142-160,170-197\n58-76,141-151,151-155,160-164,166-189\n64-86,132-152,169-197\n64-88,134-153,158-198\n172-197,197-207,278-298,298-308\n45-63,282-315\n48-65,65-78,288-321\n145-176\n6-36,36-43,43-67,67-77,77-82,82-101,101-119,119-129,129-139,139-159,164-196\n-15-15,15-26,26-36,36-58,58-79,79-83,83-85,85-112\n123-143,151-180\n-1-1,1-14,14-19,19-39,43-53,64-77,77-79,79-81,81-89,89-100\n-37-37,37-64,64-77,77-103\n-29-29,43-48,48-57,57-64,66-101,101-128\n2-9,54-90\n-15-15,68-112\n-22-22,60-80,80-82,82-100\n0-23,23-27,27-32,32-37,37-52\n105-132,132-164,164-196\n107-141,141-172\n0-2,2-21,21-50,50-55,55-72,72-108\n-31-31,31-60,60-80,80-107,107-153\n38-78,78-88,88-92\n-13-13,17-52,57-65\n107-127,132-169,169-191\n-12-12,18-38,114-118,155-165\n6-24,72-101,101-107,107-122,122-133,133-136,136-157,157-180\n-12-12,22-25,25-52\n26-48\n4-31,103-155,155-161,161-180\n0-22,33-57\n-25-25,25-30,30-35,35-53\n-13-13,72-91,93-123,123-135,142-166\n17-36,36-46,46-64,85-118,118-151,151-175,175-180\n0-13,17-45\n128-161,163-197\n113-144,144-173\n-10-10,82-110\n78-106,106-126,147-165,165-168,168-192\n74-123\n114-130,135-174\n81-97,97-132\n76-90,90-94,94-97,97-110,110-126\n14-70,71-82,160-180\n-7-7,12-37,37-73,163-197\n29-46,46-50,50-76,297-323\n6-28,32-51,51-73,76-84,300-324\n52-65,65-84,140-148,154-173,173-194,237-255,281-293\n45-61,61-64,64-74,74-81,81-94,134-152,152-176,176-191,290-300\n283-301\n28-38,38-66,297-319\n16-38,41-68\n55-81,81-85,85-88,91-96,96-109,113-127,127-132,132-155\n14-30,33-48,48-59,59-72,305-333,333-341,341-352\n53-83,131-145,150-168,170-188,277-295,297-315\n52-82,140-156,156-173,295-313\n1-20,20-26,26-29,29-42,42-72,72-85,307-336\n2-18,18-49,63-90,306-339\n-19-19,31-51,65-90\n-30-30,30-38,38-52,52-62,66-84,84-93,93-95,95-114\n24-40,43-66,66-84\n-12-12,14-16,16-42\n60-87,87-90\n14-29,32-51,54-86,86-111\n67-87,87-90\n5-27,85-109,164-177\n-12-12,12-50,50-54,54-61,61-67,67-74,74-106\n0-18,89-106\n0-20,48-56,69-111\n0-32,32-50,50-130\n-34-34,52-69,69-92,92-120\n44-79,79-101\n108-127,128-147,147-160,160-168,168-179\n91-112,112-138,143-157,157-167,169-191\n93-103,117-134,134-137,137-148,148-157,157-164,164-196\n57-65,75-107,107-110,110-113,113-129\n-2-2,2-30,30-51,51-77,166-194\n78-102\n47-66,66-114\n75-105\n30-75\n88-106,120-145,148-159,165-189,189-208,278-296\n66-84,156-168,179-204,278-296\n59-77,124-133,168-193\n60-73,73-89,168-194\n63-67,72-77,86-116\n40-53,53-74,163-197\n31-48,48-59,59-76,76-78,78-95\n86-106,106-124\n-15-15,15-19,23-41,57-87,87-93\n78-111\n40-66,170-190\n141-152,171-189\n149-168,169-186,186-192,192-203,264-281,285-308\n55-77,282-309\n61-80,168-191\n56-80,168-189\n53-71,71-84,149-161,161-196\n61-88,161-169,169-187,187-189,189-204\n-5-23,211-229,236-254\n286-317\n285-312\n50-81,168-187\n58-82,84-89,167-188\n41-66,168-192\n58-79,168-187\n59-81,93-111,111-123,129-147,173-200\n64-116\n72-111\n74-106\n87-112,112-131\n100-137\n56-85,173-203,277-308\n54-79,173-205,211-229,275-304\n56-83,166-192,199-207\n58-81,166-189\n68-80,80-98,169-191\n57-69,69-86,168-196\n60-82,112-122,163-199\n53-73,73-90\n18-36,65-78,78-86,86-118\n56-124\n-13-13,38-59,59-72,75-114\n77-103\n1-26,50-78\n44-80\n22-59,59-60\n49-67,83-101,180-202,202-214,218-232,237-251,283-301\n49-71,283-292\n49-70,281-299\n46-75,91-109,279-299,307-325\n167-194\n167-194\n60-88,171-196\n170-196\n179-218,276-294\n63-90\n53-72,72-108\n-4-4,12-27,27-35,35-38,38-65,171-189\n36-63\n22-54,54-56\n21-35,35-72,158-177\n36-73\n61-77,77-90,90-106,106-119,168-197,294-312\n65-105,105-123,163-195,295-306\n171-189\n40-52,73-99,141-159,162-180\n163-197\n236-262,280-305,310-312,312-314,314-325\n237-262,281-307\n281-303\n277-301\n-8-0,45-65,290-313\n-9-9,9-21,45-65,292-312\n45-64\n-3-15,45-64\n-2-2,2-27,52-70,100-118,118-119,124-134\n31-72,73-79,155-169,169-191\n35-45,45-66,66-81,81-99\n6-24,70-96,96-111\n14-30,30-43,43-46,46-49,52-90\n0-13,13-27,27-33,33-47,65-84,84-95,95-104,104-114\n12-43,54-73,73-89,89-91\n63-117\n-10-10,67-102\n167-192\n168-193\n173-197\n173-197\n39-70\n282-300\n280-300\n238-255,281-304\n238-258,284-306\n280-302\n282-303\n33-43,44-65\n-3-3,3-20\n-24-24,125-153,153-164,170-190\n-21-21\n124-139,139-141,141-143,143-147,147-155,155-158,158-180\n-16-16\n47-82,167-202,280-309\n51-79,166-203,277-311\n59-69,278-305\n54-81,173-206,206-224,276-314\n49-70,87-105\n46-67,71-89,286-315,324-342\n51-69,289-310\n52-85,163-194\n55-84,164-186\n55-77,153-166,166-178,178-186,186-188,188-202,280-313\n50-88,151-169,169-191\n51-59,59-67,67-81,81-94,161-199\n-12-12\n-13-13\n-12-12\n-13-13\n161-199\n149-180\n161-199\n152-180\n-15-15\n-12-12\n169-191\n159-201\n-12-12\n-16-16\n160-200\n156-180\n-14-14\n168-192\n-16-16,159-201\n-18-18,165-195\n161-199\n166-194\n-36-36,66-98,106-129,129-134,134-159,159-201\n0-37,37-43,43-47,47-55,55-77,77-118,118-135,135-161\n95-124,124-152,152-170,170-180\n105-121,121-150,150-170,170-177,177-179,179-181\n0-40,54-80,80-90,90-92,92-96,96-133,133-154,154-156,156-166,166-169,169-191\n42-75,167-193\n168-192\n16-44,44-46,48-68,292-321\n18-29,45-70,293-319\n44-68,294-323\n18-36,43-71,293-313,319-332\n158-202\n36-54,57-65,287-305\n-10-10,171-189\n-18-18,23-28,28-41,48-67\n169-191\n-17-17,21-24,24-26,51-79\n53-97,97-128,139-159,159-174,282-313\n55-100,135-148,148-172,289-316\n45-64,64-79,79-88,88-92,92-107,113-134,157-181\n56-88,88-94,94-111,114-122,122-143\n53-64,64-71,71-93,93-118,132-152\n71-109,112-114,135-153\n247-265,282-316\n259-262,279-303,303-322,323-343\n49-70,80-99\n48-71,81-92\n51-71\n45-69\n167-190,267-309\n166-198,275-311\n165-197,197-199,199-201,233-260,272-305\n169-197,198-222,226-240,240-264,281-308\n170-190,250-276\n56-72,72-87,109-120,120-128,128-131,131-133,133-137,137-144,144-166,289-311\n53-91,129-137,141-165,289-310\n53-73\n53-72\n272-299\n31-44,58-62,62-64,64-74,74-87,87-96,96-100,100-114,128-150,299-317\n41-58,60-97,114-134\n142-160,178-195,195-198,198-200,200-202,212-230,250-277,277-279,279-296,307-317\n182-205,207-217,240-256,256-264,264-298\n-24-24,151-209\n-11-11,12-34,162-198\n-36-36,46-70,70-106,106-130,130-139,139-149,149-211\n-1-1,1-10,10-14,14-16,16-39,39-48,48-52,52-64,68-90,96-104,133-153\n0-29,29-49,49-65,67-100,100-109,109-118,118-128,128-148,158-179,179-181\n-12-12\n-15-13\n-11-11\n-11-11\n344-381\n-13-13\n37-55,302-319\n62-77,81-91,91-101,114-134,140-151,214-229,233-248,248-267,267-285\n-4-4,4-12,12-16,16-22,22-45,45-65,295-315,315-338,338-344,344-348,348-356\n69-87,87-106,254-273,273-291\n62-73,73-86,86-110\n25-37,37-64,64-90,90-107\n24-52,52-77,77-99,134-137\n-12-11,166-187\n-11-11\n-14-16,16-33,161-174,174-192,318-340\n-9-9\n162-195\n37-52,52-55,55-78,163-188,291-318\n170-190\n126-141,141-147,147-176,176-180,180-211,211-235\n-15-15\n-13-13\n-13-13,13-26\n-39-39,56-72,76-109,114-124,133-143,143-153,153-156,156-158,158-165,165-170,170-180\n-1-1,1-29,35-53,156-172,172-188\n79-106,106-125,125-137\n172-196,342-370\n4-24,24-45,45-60,295-310,310-313,313-315,317-341,341-364\n3-8,8-12,12-24,343-363\n160-179,179-181\n0-22,23-38,148-158,171-189\n-13-13\n-21-21,169-191\n-16-16,24-29,29-49\n-10-10,165-195\n-15-15,162-198\n169-191\n0-20,168-192\n-4-4,169-191\n-14-14,168-192\n0-14,14-36,63-80,80-82,82-94,94-100,100-102,102-120,120-147\n-8-4,123-134,134-163,324-336,336-339,343-352\n-2-15,99-121,123-136,136-156,256-274,344-358\n-23-23,23-45,45-66,66-90\n-35-35,35-54,54-65,65-96,96-140\n60-120\n-3-3,3-24,24-61,63-81\n99-125,125-155,155-180\n15-35,76-111,111-134,134-137,137-161\n-20-20,91-143\n0-7,7-20,20-27,27-39,90-111,111-114,114-136,136-150\n-2-2,2-24,24-43\n117-138,138-167\n100-114,114-151,167-193\n110-126,126-146,146-156,159-169\n57-75,79-101,112-116,116-122,122-126,126-135,135-140\n-19-19,28-46,69-87,87-110\n80-98,108-123,123-126,126-128\n69-107,114-133,133-145\n101-115,115-135,142-168\n42-73,166-194\n39-51,51-59,59-62,62-76,164-196\n24-43,43-47,47-69,160-173,173-180\n167-193\n150-173\n42-69,163-197\n50-89,155-187,279-301,301-304,304-321\n45-85,158-187,282-305,305-322\n53-71,173-200,319-342\n42-68,291-323,326-341\n39-69,291-320\n45-68,297-315,315-317\n46-66,284-295,295-320\n165-194,290-309\n161-182,182-211,266-279,279-306\n28-45,45-65,65-80,160-178,293-302\n45-79,165-187,287-310\n41-69,298-317\n47-68,291-315\n-13-13,156-180\n-11-11,90-114\n-24-24,24-47,47-68,161-199\n-4-4,4-10,10-24\n167-193\n157-203\n168-192\n150-180\n-13-13,29-54\n-23-23,160-179,179-181\n170-190\n166-194\n-38-38,58-87,87-89,89-99,99-101,101-111,111-119,119-125,125-128,128-157\n0-6,6-35,39-46,46-48,48-59,59-109,111-124\n-1-1,1-45,45-49,49-55,55-58,58-82,88-109\n112-142,142-174,174-186\n112-133,133-168,174-186\n107-169,169-180\n92-99,110-157,157-164,164-177,177-180\n-18-18,18-20,20-37,50-54,54-58,83-120,120-139,139-147,147-150,150-164\n-28-28,46-58,85-122\n-24-24,65-95,95-102,104-118\n96-118,135-167\n134-164\n0-33,104-116\n-13-13\n-13-13\n-13-13,104-128\n170-190\n168-192\n170-190\n153-207\n-12-12,170-190\n-13-13,163-180\n191-231,231-256,256-261,261-273\n183-196,196-222,222-243,243-268\n-10-27,106-129,129-146,181-207,207-261\n-13-20,92-112,119-145,154-174,184-204,204-206,209-257\n-1-24,192-213,213-236,236-238,238-252,344-359\n-14-11,202-212,212-219,219-222,222-232,233-251,333-346\n22-39,42-65,71-89\n20-44,47-67\n23-42,46-65\n80-97,97-111,111-113,113-117,117-153,170-178,178-181,181-191\n62-76,76-82,91-120,120-127,127-129,129-161,169-189\n90-126,126-157\n97-125,131-145,145-148,148-163\n65-82,82-114,114-154,154-187\n78-103,103-112,112-117,117-167\n84-107,107-113,113-127,127-157\n75-98,98-122,122-124,124-158,160-178\n39-81,168-218,277-314\n40-81,164-209,213-233,278-314\n33-41,43-52,52-63,63-85,167-174,174-187,187-195,195-212,212-215,215-227,227-230,230-250,272-299,299-318\n34-54,54-61,61-68,68-81,169-188,188-194,194-211,267-285,285-297,297-318\n32-52,52-57,57-71,171-194,194-215,247-261,261-273,273-311\n29-51,188-198,198-208,218-236,238-271,277-315\n216-238,265-276,276-284,284-295\n7-27,27-32,41-70,81-102\n11-22,22-30,44-71\n48-73\n48-76,80-98\n40-72\n49-73\n41-64,293-316\n40-63,293-315\n289-317\n-11-7,7-23,25-43,51-69,294-317,325-339\n38-60,270-289,295-322\n266-278,296-324,324-339\n53-88,117-146,146-151,162-189\n55-88,165-188\n61-96,113-129,139-189,199-216\n58-88,115-126,126-138,138-156,163-189\n55-79,103-138,162-193\n34-48,52-81,96-116,166-194\n85-96,101-123\n65-84,89-100,108-131,133-153,153-155,155-170,170-179,179-192\n31-49,60-85,151-166,170-216\n52-78,78-91,169-203,281-311\n46-78,178-200,281-309,328-352\n39-58\n38-57\n42-61,297-322\n43-63,296-323\n40-49,63-86,86-90,90-104,139-154,156-182,183-208\n63-90,90-108,119-148,155-168,168-182,182-203\n28-48,61-92,160-168\n49-76,168-200,263-274,283-316\n51-70,167-194,282-310\n291-319\n36-68,287-319\n293-329\n41-59,293-324,341-364\n54-72,72-88,154-200\n38-56,60-83,159-193,193-211\n66-96,141-149,161-183\n54-72,171-189,274-287,287-314\n-1-1,1-27,29-47,47-92,92-112,125-143,170-190\n14-32,45-63,63-83,91-111,163-197\n32-57\n149-179,179-181\n148-171,179-181\n143-179,179-181\n142-177\n53-65,65-83,167-193\n34-48,48-57,57-70,70-88,96-114,156-204\n44-69,69-84,84-89,89-101,101-125,143-168,168-172,172-176,176-184\n150-177,177-180\n146-171\n-16-16\n-18-18\n58-122\n-16-16,16-21,21-23,23-49,69-111\n-5-5,5-9,9-12,12-29,29-31,31-48,48-58,58-71,71-78,78-98\n69-111\n-14-14,14-41\n-1-1,1-47\n153-207\n102-125,143-180\n-24-24,24-35,35-52,52-79,79-86,86-94\n-57-57,57-135\n47-133\n-17-17,17-53\n103-127,130-154,157-203\n-14-14,89-135\n-12-12\n-24-24,30-42,42-51,71-149,149-211\n165-195\n-3-3,3-6,6-26,26-38,38-52,52-81,85-105,112-131,141-158,158-172\n-12-12\n-14-14\n0-30\n-23-23\n0-11,11-33\n0-32\n-1-1,1-27\n149-172,172-176,176-184\n126-145,145-168,168-180\n98-116,124-161,169-191\n-19-19,36-52,52-67,85-124\n12-18,18-32,66-102,102-114,114-135,135-137,137-151,151-155,155-164,164-180\n-20-20\n-12-12,12-42,55-66\n-24-24\n0-32,66-90\n145-168,168-179,179-181\n0-3,3-19,83-101,106-124,124-136,162-179\n-16-16,18-47,95-125,125-133,133-145\n-10-10\n-15-15\n-13-13,13-29\n152-208\n159-201\n85-109,109-129,129-144\n-10-10\n-11-11\n-21-21\n133-147,161-180\n5-14,66-84,84-98,98-123,123-143,143-153,153-177,177-183\n-11-11,11-15,15-40\n110-134,151-180\n153-180\n-13-13\n167-193\n-3-3,3-59\n2-23,23-29,29-62\n0-11,11-38\n0-7,7-16,16-42,42-44,44-50,50-65\n170-190\n170-190\n7-61\n0-15,21-67\n-4-4,4-12,12-23,23-47,47-66\n63-118,118-164,171-187\n64-99,99-110,110-113,113-145,145-179\n69-87,102-120,136-165,165-184\n86-104,128-160,162-190\n86-118,126-144\n256-268,268-271,275-280,283-318,318-321,321-336\n290-324\n43-75,290-318\n38-76,291-317,317-345\n3-22,22-24,24-37,37-73,297-320\n7-26,26-28,28-49,49-76,81-102,302-320,320-339,339-355\n48-70\n22-37,37-40,46-70,335-351,351-376\n123-141,151-175,175-177,177-201,209-219,219-243,273-304\n135-152,152-154,156-173,173-212,229-239,261-279,279-283,283-286,286-302\n127-149,153-194,250-270\n121-144,147-158,159-182,182-191,191-206,267-285\n60-107,107-109,109-125,125-183,280-309\n58-78,78-86,86-89,89-105,105-129,131-185,279-313\n5-36,36-76,94-116,290-322,322-341,341-360\n4-34,34-78,288-328,330-358\n31-72\n39-74,101-109\n149-169,169-192,192-210,216-226,246-265,265-269,269-292\n140-169,172-191,191-208,245-260,260-290\n60-88,88-124,124-127,127-137,137-143,143-169\n58-92,92-94,94-120,126-149,149-153,153-168\n140-153,153-173,173-209,250-277,279-288\n161-207,261-281\n34-62,290-322,322-325,325-326\n39-63,82-101,312-322\n33-63,71-80,301-316,316-338\n30-62,66-83,83-85,85-97,300-345\n32-61,309-330\n166-207,238-256,273-291,291-292\n166-189,189-192,197-207,243-260,262-273,273-302\n59-77,77-86,86-96,146-171\n60-77,77-89,126-143,143-177\n33-65,300-334\n3-20,20-25,34-64,303-324,324-342\n160-197,266-280,280-283,283-285,285-289,289-303\n160-191,191-204,270-279\n171-189\n-10-10,145-163\n343-374\n-4-4,7-11,11-14,14-16,16-31,31-33,33-51,51-92,106-124,124-131,131-132,144-162\n39-57,301-320\n-13-13,160-200\n-12-12\n2-19,19-24,24-35,35-39,39-43,44-55,55-65,65-83,88-104,104-114,114-116,116-142\n10-26,26-59,61-72,72-81,81-89,89-91\n-1-1,1-19,19-41,52-72,72-108\n120-145,145-165\n33-48,48-67,76-104\n0-4,4-6,6-37\n168-192\n99-132,140-165,165-172,172-177,177-183\n-11-11,16-33\n-17-17,17-33\n-34-34\n-4-4,4-18,18-35\n11-31,31-34,34-48,326-344\n65-76,81-101,104-120\n-10-10\n38-75,75-92,137-148,169-191\n80-109,123-147\n177-209,285-310\n61-80,165-193,285-303\n58-76,160-175,178-186,286-308\n277-290,290-307\n44-62,169-204,204-212,212-214,293-311\n170-190\n151-176,176-184\n0-12,12-25,162-198\n57-83,173-197\n54-80,143-162,170-197\n54-62,64-89,89-104,104-125,162-180\n53-79,79-81,81-90\n24-38,47-109\n60-90\n132-169\n52-79,79-82,82-84,84-90,91-102,102-127\n59-77,77-102,102-105,105-122,125-140,148-166\n14-37\n61-79,79-87,92-117\n-1-1,1-4,4-10,10-14,14-20,20-46\n86-98,98-103,103-128,128-139,141-159\n282-312\n278-306\n39-60,158-182\n40-61,163-182\n36-58,181-190,274-304\n40-48,175-201,271-290,290-307\n30-59,174-196,271-309\n32-52,146-169,171-195,277-304\n31-49,279-301,307-318\n22-46\n-17-17,17-30,30-40,40-60,60-62,62-67,67-76,76-104\n0-13,13-30,30-32,32-35,35-70,70-97,152-175,175-179,179-181\n62-90\n-7-7,7-13,13-20,20-24,24-40\n129-160,166-172,174-179,179-181\n7-34,34-37,37-60,60-71,71-77,77-79,79-92,92-95,160-178\n56-59,75-108,108-117,117-137,137-145,145-161,164-180\n-55-55\n39-60,60-62,62-69,69-103,103-135\n36-64,71-125,125-131,131-134,134-137,137-147,147-150,150-155,155-165\n34-58,76-94,344-368\n77-81,84-121,121-129,134-159,159-176\n85-89,92-117,117-148,148-166\n7-25,25-37,37-44,44-73,73-87,87-93\n-7-7,7-10,10-14,14-27,27-46,46-67,67-70,70-74,74-85,85-94,94-105,121-141,141-154\n43-63,63-74,74-90\n0-18,18-21,21-47,47-49,49-131\n-1-1,1-6,6-10,10-15,15-23,23-51,51-61,61-69,69-81,81-111\n36-60,67-113\n47-87\n3-12,20-53,57-84\n92-127,148-168,168-192\n97-124,125-169,169-171,171-189\n42-58,58-61,61-79,83-105,110-128\n-3-3,3-26,26-62\n-29-29,29-55\n26-41,41-73,298-324\n34-44,46-74,302-320\n9-20,27-29,31-46,46-65,78-105,316-334,335-348,354-367\n164-187\n-1-1,1-4,4-8,8-29,29-40,40-53\n-18-18,67-105\n-22-22,26-47,86-95\n36-48,48-71,277-314\n50-76,166-200,267-283,283-316\n46-69,69-84,216-225\n49-73,158-185,185-199\n-13-13\n-18-18\n0-14\n-15-15\n-12-12,169-191\n-14-14\n0-14\n39-56,56-78,288-301,307-320\n51-96,96-116,116-133\n48-66,66-95,278-304\n63-97,97-101,101-114,285-307\n-17-17\n-15-15\n54-73,173-203,282-305\n52-75,175-195,281-310\n176-196,283-309\n-17-17\n335-383\n0-18,18-39,44-80\n104-128,143-180\n0-27\n-11-11,11-33\n53-74,74-106\n-25-25,146-214\n-14-14\n-14-14\n159-201\n132-141,159-179,179-181\n-15-15\n171-189\n-29-29,114-132,155-180\n345-373\n345-381\n68-102\n55-68,68-73,73-108\n-11-12\n43-73,152-178\n41-65,65-79,154-177\n19-38,38-58,130-148,155-163,165-173,173-187\n170-190\n-1-1,1-6,6-10,10-51,55-63,63-71,71-81,114-140,140-148,148-156,156-160,160-174,174-179,179-181\n33-48,48-51,51-59,59-77,315-341\n48-71,305-322,322-329,329-348\n-18-18,164-196\n-29-29,50-59\n-11-11,165-195\n-17-17\n-11-11,170-190\n-11-11\n-14-14,31-55,142-146,155-205\n-14-14,168-192\n-14-14\n-15-15,167-193\n0-15,167-193\n-17-17\n-12-12,168-192\n2-18,18-24,24-32,32-37,37-44,57-69,71-88,100-118,120-138,145-159,159-162,162-169,169-179,179-181\n-10-10,10-26,162-198\n-13-13,13-30,93-101,112-126,126-145\n137-159,159-161,161-179,179-181\n54-78,177-204,279-303,303-318\n50-80,174-198,287-317\n43-64,294-317\n42-66,284-322,324-336\n35-43,50-69,69-89,149-168,168-188\n52-66,66-73,73-89,153-173,177-194\n42-60,294-318\n38-46,48-57,295-321\n-1-1,1-6,6-15,15-34,34-58,58-82,82-84,84-103,103-142,142-162,162-166,166-169,169-173,173-178,178-182\n-15-15,22-45,45-65,75-93,93-133\n20-51,51-55,55-61,61-64,64-90,90-94,94-117,117-122,124-154,154-161,161-180\n56-84,98-108,121-128,165-176,176-184\n51-77,88-92,94-112,124-141,146-156,156-164,164-196\n48-75,77-96,96-105,105-115,115-125\n1-14,19-33,51-75\n109-127,151-168,168-178,178-182\n27-50,50-65,163-197\n52-128\n87-123,129-149,158-176,176-179,179-181\n171-189\n171-189\n77-104\n14-36,36-39,39-67\n65-73,84-101,101-132\n14-35,35-38,38-42,47-69\n32-41,43-55,55-63,66-83,83-85,85-95\n-10-10,10-29,44-54,64-80,80-85,85-106,106-123\n93-119,132-158,158-177\n51-71,272-291,295-316\n50-71,273-291,294-315\n53-71,294-318\n53-61,293-317\n281-299,302-321\n281-300,303-320\n50-68,295-317,324-342\n-12-12\n-10-10\n-15-15\n-17-17,155-205\n-16-16\n152-159,159-179,179-181\n167-193\n-21-21,45-57,57-72,149-211\n-15-15\n115-138,168-192\n-15-15,152-208\n-10-10\n-13-13\n164-180\n-1-1,1-18,158-178,178-180\n-14-14\n149-170,170-176,176-179,179-181\n-17-17,32-57\n-15-15,48-65,65-83,165-195\n-17-17\n-14-14,14-38\n-18-18\n-8-8,8-13,13-17,22-41,58-66,142-164,164-179,179-181\n0-14,14-38\n-12-12,43-69,138-157,157-180\n-17-17,18-23,23-24,110-127,127-147,171-189\n143-153,153-161,165-195\n-17-17,17-35,127-145\n-5-5,5-31,43-64,64-68,68-71,71-73,73-84,84-96\n-11-11\n170-190\n-19-19,161-169\n-17-17,42-53,79-88,88-127\n107-132,136-160,160-165,165-177\n83-103,103-123\n-1-1,1-38,83-114,114-128\n0-25,25-31,31-56,56-85,85-123,123-131,131-145,145-151,151-166,169-191\n-22-22,33-42,42-54,64-81,81-97,97-108,108-123\n-11-11,18-34,34-36,36-42,42-66,69-82,82-89,89-112,118-156,171-189\n2-10,49-59,67-68,72-93,93-99,99-102,102-109,109-123\n4-22,44-70\n169-191\n40-73,294-315\n48-67,293-314\n-35-35,40-74\n0-17,17-20,20-42,165-195\n-3-3,3-16,16-39,39-53,53-62,62-90\n-12-12,30-47,47-66\n-14-14,14-59,67-89\n-12-12,163-197\n-18-18,18-24,24-29,29-49\n-14-14\n-24-24,32-34,34-36,36-49\n-2-2,2-7,7-18,18-37,37-57,57-64,64-79,86-94\n-12-12,14-39,39-55\n141-161,171-189\n57-123\n59-89,89-91\n-22-22,146-155,169-191\n55-86,86-107\n6-42,44-74\n59-62,70-90\n60-90,90-91,96-106,108-126\n59-76,76-78,78-91,91-110\n59-90\n53-90,90-125\n-9-9,28-66,70-78,78-97\n63-91,91-95,97-107,110-137,137-151,159-201\n36-42,42-54,56-82,82-100,100-115,115-137\n59-71,72-93,97-110,116-129,146-164\n47-81,81-84,84-117,117-120,120-136,136-156,158-179,179-181\n59-94,94-112,112-114,114-131\n1-4,4-8,8-17,17-21,21-35,48-93,93-119\n100-112,112-137,137-158,158-160,160-163,163-166,166-180\n32-45,49-110,110-116,116-141,141-143,143-148,148-178,178-182\n25-40,40-55,62-119,127-140\n181-193,198-217,253-265,265-271,271-295,295-313\n181-202,272-290,290-313\n57-82,170-194,194-213\n52-74,139-164,170-201\n173-183,183-204,290-314\n174-186,186-192,192-205,283-309\n-21-21\n-32-32,46-64,102-130,169-191\n-20-20,20-53,53-74,74-87,87-93\n-2-2,2-28,34-37,37-54,54-67\n5-28,31-46,46-65,119-138\n35-54,54-71\n-12-12,168-192\n168-192\n0-18,168-192\n-20-20\n-13-13\n-13-13,15-42,42-62,79-101\n156-204\n-13-13\n-12-12,169-191\n-12-12\n-10-10\n-17-17,19-33,136-155,155-165,165-173,173-187\n-19-19,22-28,28-49,58-81,107-132,132-150\n-14-14\n170-190\n0-23\n0-19\n119-128,131-140,165-195\n169-191\n170-190\n141-170,170-180\n124-150,150-169,169-180\n0-18\n171-189\n171-189\n171-189\n170-190\n-16-16,16-19,19-41,42-52,54-63,63-74,144-154\n-24-24\n168-192\n170-190\n58-76,81-92,92-101,126-145,151-179,179-181\n-10-10,39-58,118-141,145-156,161-179,179-181\n80-108,168-192\n-9-9,9-41\n154-164,164-166,168-192\n110-128,153-177\n67-79,94-104,106-109,109-112,112-126,126-133,133-150,283-301\n55-73,83-97,104-147,147-159\n281-312\n31-42,43-71,75-84\n27-58,303-321,321-341\n20-33,37-61,307-334,334-337,337-348\n48-74,112-139,142-170,170-185,202-220\n44-65,302-331,335-362\n38-63,299-334\n44-62,293-314,331-349\n59-81,81-103,103-120,133-141,141-165\n-9-9\n170-190\n0-17\n-14-14\n0-18,21-44,47-56,56-65,65-76\n7-66,66-68,68-85,152-208\n-11-11,169-191\n67-85,182-206,274-285,285-310\n176-205,281-311\n2-24,24-53,53-60,60-75,115-130,130-153,153-161,161-172\n171-189\n0-26,26-38,38-58,58-79,79-108,117-128,146-161,164-179\n171-189\n152-164,167-193\n-18-18\n-14-14,14-34\n-17-17,167-193\n133-163,169-191\n-13-13,167-193\n170-190\n170-190\n-18-18,33-51,53-82,82-91,91-94,94-123,126-139,139-150,150-159,159-201\n35-54,54-74,115-129,129-133,133-148\n-3-3,3-16,45-63,63-64,73-95,95-103,109-116,137-152,156-168,168-192\n56-84,84-102,110-125\n59-77,286-317\n170-190\n171-189\n-10-10\n-17-17,150-169,169-191\n160-177,177-185,185-201\n-11-11,169-191\n-1-1,1-25\n9-27,77-96,96-104,104-115,133-151\n-1-1,1-5,5-8,8-11,11-15,15-19,59-76,76-80,80-83,83-89,89-92,92-100,100-113,113-127,127-141\n95-116,154-176,189-214\n91-109,150-181,192-210\n6-26\n-2-2,2-18,157-177,177-183\n-1-1,1-6,6-10,10-34,150-167,167-169,169-175,175-177,177-180\n160-200\n-11-10\n8-26,26-29,29-38,38-64,64-75\n0-16,48-78\n170-190\n-15-15,93-138,165-195\n-15-15,158-202\n169-191\n-15-15,162-198\n128-164,168-192\n0-30,142-156,163-197\n-9-9,153-163,165-195\n168-192\n0-28,159-201\n153-166,166-194\n-16-16,158-176,176-184\n-14-14,158-202\n-19-19,162-180\n170-190\n59-69,78-102,109-131,151-176\n-1-1,1-3,3-14,14-24\n154-180\n-10-10,130-171,171-189\n14-33,136-170,174-186\n71-90,90-113\n-9-9,9-30,134-156,161-180\n-14-14\n-20-20,79-101\n-13-13\n-15-15,15-37\n126-145,150-165,165-175,175-180\n-19-19,31-49,80-89,89-99,137-157,170-190\n-27-27,33-53,53-66,66-83,83-90,90-99\n114-126,126-140,145-168,168-192\n53-88,88-94,102-108,108-110,110-128\n158-180\n166-194\n-11-11,82-98,104-131\n160-200\n27-46,46-52,52-54,54-71,117-138,138-157\n-14-14,170-190\n0-19,19-28,28-54,148-174\n0-25,25-29,29-35,35-52,62-79,79-101\n-22-22,45-66\n4-26,26-34,36-45,45-55,60-68,75-105\n-1-1,1-20,45-64,64-67,67-86\n-8-8,8-13,13-33,154-175,176-184\n0-18,169-191\n-23-23,158-202\n-14-14,87-105,168-192\n-12-12,12-29,159-179,179-181\n-3-3,3-18,159-177,177-180\n-14-14,166-194\n-11-11,170-190\n-13-13,169-191\n-12-12\n168-192\n-12-12,166-194\n169-191\n170-190\n-34-34,40-59,96-113,113-132,135-156,156-180\n98-130,130-145,145-163,163-165,165-195\n0-19,44-60,60-65,65-82,88-107\n170-190\n-17-17,168-192\n-23-23\n169-191\n137-146,146-157,157-167,167-180\n-17-17,166-194\n122-156,166-194\n-16-16,16-30,169-191\n-15-15\n-11-11,160-178,178-182\n46-64,68-113\n53-56,85-101,101-114,139-161,167-193\n-9-9,80-122,122-147\n101-113,113-116,120-132,139-160,160-168,168-172,172-180\n-13-13\n-21-21\n-12-12\n-23-23\n-6-6,6-14,14-26,28-51,168-192\n161-199\n-15-15\n-6-6,6-37,44-63\n170-190\n168-192\n-11-11\n170-190\n-11-11,22-40\n-4-4,4-16,16-39,39-45,119-142,151-162,162-166,166-169,169-191\n-24-24,168-192\n-11-11,11-34,34-44,55-78,83-97,101-118\n-1-1,1-21,23-33\n-19-19\n-29-29,169-191\n-17-17,24-30,30-62\n-21-21\n0-3,3-24,24-35,133-155\n-19-19\n151-167,167-193\n166-194\n-11-11,22-40,163-197\n-22-22,169-191\n-12-12,169-191\n-9-9,162-198\n-13-13,155-205\n0-29,71-92,92-109,109-112,112-116,116-123,123-136,136-143,143-154\n0-80,80-100\n0-43,43-63,63-74,74-127,127-156\n13-45,54-90\n0-37,48-71\n102-137,137-180\n121-149,149-157,157-173\n-5-5,5-15,48-57,84-103,103-108,108-111,111-126,126-133,133-136,136-147,147-152,152-165\n-22-22,81-99,99-127,127-129,129-134,134-157\n0-33\n-1-1,2-30,30-46,56-66\n113-132,132-169\n115-155,158-179\n-21-21,101-120,120-132\n115-128,133-153,153-179,179-181\n0-6,6-28\n0-2,2-23,41-59\n40-75,159-201\n162-198\n41-69\n43-80,160-179\n3-27,39-67,289-315,315-331,343-363\n-9-12,12-32,36-68,293-321\n47-65,289-314\n27-46,47-57,291-311\n163-179,179-187,187-193,193-206,256-270,270-277,277-280,280-305,313-333\n170-181,181-201,277-304\n49-83,162-190,280-300,300-314\n47-84,158-190,282-317\n294-317\n-6-5,5-13,13-22,25-35,37-40,40-70,75-85,298-316,327-345\n45-63,68-86,300-311,311-331\n167-185,190-200,251-267,274-299,303-319\n47-80,159-177,279-287\n48-76,156-176\n-17-17,160-200\n-23-23\n-17-17,134-165,165-169,169-180\n-18-18\n-12-12,170-190\n-13-13,20-39,54-62\n-12-12,17-25,25-46,139-162,168-192\n0-20,50-68,170-190\n-10-10\n0-22\n169-191\n170-190\n169-191\n170-190\n45-56,56-64,64-75,124-141,148-179,179-181\n-12-12,12-30,30-35,35-39,39-54\n169-191\n-13-13,70-104,104-143\n-9-9,13-34,34-54,81-99,108-126\n60-101,101-126,139-164\n68-97,97-113,115-139\n3-20,20-42,61-83\n113-145,166-179,179-181\n96-111,111-116,116-138,141-159\n76-101,109-148,148-166,166-180\n104-133,133-139,139-153,164-180\n2-17,30-48,54-72,76-94,101-132\n-1-1,1-8,8-33,58-76,78-99,99-108\n46-65,71-120\n-3-3,3-31,31-51,60-85\n9-27,38-60,60-84\n145-180\n-9-9,22-25,35-38,57-82,87-117,117-121,121-134,134-147,147-150,150-156,156-160,160-161\n-18-18,18-37,61-76,76-79,79-91,91-96,96-124\n149-178,178-182\n-2-2,2-7,7-12,12-24,128-138,138-161\n0-10,10-26\n-13-13,16-35\n170-190\n161-199\n168-192\n-20-20,142-153,153-161,161-168,168-192\n-18-18\n159-201\n10-29,29-36,36-44,44-48,110-126,126-129,129-145,145-151,151-153,153-166,166-170,170-190\n-13-13,159-201\n-16-16\n120-131,148-167,167-193\n170-190\n195-213,213-223,223-240,240-254,254-270\n115-126,126-135,196-209,209-256,344-388\n-22-25,117-129,129-152,195-211,214-263\n23-37,44-64\n21-39,46-65,68-87\n47-66\n47-66\n-4-44,335-345,348-353\n1-46,338-361\n93-113,113-132,132-134,134-149,149-161,161-169,169-180\n101-132,132-139,139-157,159-170,174-176,176-210\n97-118,118-152,152-174,174-179\n66-79,79-94,94-126,126-136,138-150,156-169\n-8-2,2-22,92-103,103-123,224-239,239-244,244-258\n36-81,169-212,278-316\n42-81,169-214,281-319\n177-193,193-197,197-213,213-232,285-307\n44-54,60-79,179-196,196-204,204-214,214-228,234-252,286-312\n173-189,189-204,208-217,217-227,227-240,240-257,272-289,289-313\n169-189,189-193,193-207,276-291,291-311\n47-70,73-92\n44-80\n30-38,48-70\n32-52,52-58,58-75\n-4-15,39-66,293-319,334-356\n-6-16,37-67,292-323,329-352\n45-65,290-319,319-321,321-335\n39-62,290-323,323-339\n34-54,289-319\n37-45,48-56,56-67,288-321\n56-87,168-192\n56-87,167-191\n55-86,94-104,166-193\n90-114,164-196\n54-89,103-122,122-126,126-130,156-193\n55-78,78-80,80-93,155-172,172-174,174-196\n44-77,165-211,279-315\n40-77,82-93,164-208,281-313\n128-146,154-164,164-173,189-209,271-309\n193-211,212-230,283-300,300-320\n8-17,30-60,297-324\n37-65,296-324\n68-96,158-187\n70-101,162-184\n76-105,153-157,168-188\n39-55,55-71,173-207,283-313\n45-70,174-192,192-208,258-273,278-314\n51-74\n3-24,39-65,269-287,291-325\n36-66,266-285,292-325\n40-62,289-322\n31-49,251-269,295-326,326-327\n62-94,156-190\n63-94,160-189\n43-53,55-80,174-199,278-309\n59-77,168-186,190-205,281-312\n40-58,299-324\n42-60,296-325\n-15-15,15-17,17-20,20-29,29-36,36-40,40-52,52-102,103-130,165-195\n5-17,17-32,32-44,44-52,52-55,55-67,81-85,85-111\n-22-22,43-55,55-61,65-108\n60-91,164-196\n104-125,131-180\n144-166\n3-40,41-61,61-73,73-91,129-152,165-195\n-18-18,56-73,73-77,77-84,84-112\n-9-9,39-53,53-57,57-72,72-78,78-91,91-109\n47-65,65-74,74-96,134-153,153-159,166-194\n-6-6,6-18,18-28,28-29,31-47,52-80\n7-22,22-25,25-27,33-47,52-84\n108-141,147-180\n144-174\n146-179,179-181\n144-169\n14-41,49-91,91-103\n42-105,105-113,113-126,126-133,133-146,146-168,168-192\n-19-19,39-58,58-65,65-68,68-116\n40-50,59-88,88-95,95-119,142-152,152-161,161-199\n58-88,88-100,100-117,160-179,179-181\n10-32,32-40,40-50,55-73\n4-21,21-43,43-61,61-72\n115-131,131-134,134-138,138-140,140-145,145-180\n127-135,146-180\n147-169\n39-55,55-58,58-74,74-82,82-85,85-88,88-92,92-94,94-105,105-108,108-117,117-125,125-128,128-130,166-169,169-171,171-174,174-180\n-1-1,1-3,3-6,6-13,13-46,46-74,74-87,87-106\n60-83,83-90,90-101,166-194\n63-100,100-111\n-17-17,17-54\n-16-16,16-59\n0-14,14-18,18-49,49-76,76-104\n6-14,29-82,82-98\n0-16,38-109,109-134\n59-121\n0-22\n-23-23,31-50\n168-192\n130-157,166-194\n167-193\n100-120,123-150,150-161,169-191\n-10-10\n-17-17,29-53\n-10-10\n-55-55\n-30-30,30-32,32-82,82-93,93-148\n-1-1,1-11,11-32,32-34,34-50,53-90\n-11-11,44-90\n-34-34,35-58,78-102\n0-11,11-28,28-41\n-2-2,2-36,41-45,45-51,51-55,55-57,57-78\n-13-13,16-35,35-60\n-9-9,9-42\n117-166,166-194\n105-135,142-176,176-180\n-16-16,16-32,32-69\n-43-43,80-125,129-160\n22-61\n-15-15,15-39,48-132\n0-16,19-38\n-15-15,15-43\n112-136,136-167,167-193\n-16-16\n-18-18,163-197\n-26-26,43-58,58-60,60-62,62-68,68-92,92-149,162-198\n-9-9\n0-25\n0-10,10-14,14-18,18-20,20-33,45-63\n152-208\n-16-16,40-68,68-88,108-135,160-200\n-17-17\n-21-21,28-48\n-21-21,159-178,178-182\n160-200\n3-23,23-28,28-45,161-199\n-11-11\n0-18\n162-198\n109-140,140-148,159-201\n-15-15,17-33\n129-148,152-178,178-182\n12-30,38-60,66-84,84-106,106-125,130-149,149-167,167-193\n-10-10,10-30\n23-41,41-43,43-47,47-82,99-123,134-151,151-176\n7-24,28-67,163-197\n-1-1,1-5,5-23,23-44,44-48,48-69\n0-23,23-25,25-68,160-200\n3-41\n28-61,61-77\n-3-3,3-22,22-25,25-31,31-37,37-41,41-59,165-180\n-1-1,1-16,16-36,36-41,41-44,44-67,67-85\n12-59\n4-22,22-56\n77-97,97-150\n57-88,88-95,95-108,108-121,121-148,148-164\n-9-2,49-77,284-306\n19-37,47-73,82-105,284-293\n-3-10,10-27,27-30,30-55,55-67,67-84,311-342,342-348,348-353,353-357\n3-24,24-34,34-55,55-81,310-328,328-339,339-353,353-363\n27-39,39-68\n43-60,60-62,62-66,66-69,69-85,85-112,112-128,150-186\n45-93,153-188\n64-99,99-171\n68-87,87-93,93-105,105-115,115-133,133-175\n49-75,292-311\n49-75\n11-37,37-59,310-349,349-352,352-371\n16-37,37-63,311-331,331-333,333-351\n71-101,101-115,115-145\n60-72,72-84,84-89,89-92,92-105,105-114,114-125,125-145\n155-184,280-298\n161-186,187-191,191-202\n23-40,40-42,42-60,301-331\n58-76,76-79,79-97,130-153,153-169\n35-62,292-313\n15-30,30-33,33-39,39-64,324-350\n30-58,73-96,303-316,316-335\n4-22,31-69,69-96,317-335\n60-91,142-186\n52-97,99-117,142-188\n24-65,301-326,326-348\n-5-15,31-64,71-76,86-96,301-314,314-327,327-342\n61-86,86-87,91-103,110-128,134-154\n48-91,110-127,127-138,148-166\n-14-14,25-36,36-46,46-70\n-28-28,39-79\n122-146,146-179,179-181\n166-194\n-11-11\n-11-11\n-13-13,152-160,167-193\n-4-4,4-10,16-29,59-85,88-106,109-135,139-150,150-155,155-162\n167-193\n-10-10\n-15-15\n0-10,10-14,14-31,161-179\n0-9,9-12,12-14,14-25,25-46\n18-64,163-197\n18-29,32-36,36-37,40-57,57-80,80-100\n62-118\n0-12,12-50,51-65,169-191\n51-66,71-109\n61-103,103-129,133-157,157-166\n168-192\n47-69\n152-169,171-189\n66-84,84-112,112-114,114-136,136-171\n-1-1,1-31,42-69\n-9-9,12-39,39-69,73-92\n-4-4,4-13,17-31,31-36,36-56,56-69,73-91\n31-64,162-198\n41-64,64-87,87-93\n51-88,88-90\n-11-11,65-118,148-169\n61-113,134-158,158-180\n-8-8,8-62,62-88\n71-115\n76-95,95-119,119-126,126-145,145-180\n8-29,40-68\n19-44,44-78\n69-133\n88-101,101-103,103-130,167-193\n-2-2,2-25,28-61,68-93\n-15-15,19-56,138-161,170-190\n42-57,57-80,80-84,84-96\n59-88,88-92\n-17-17,17-28,43-90\n7-25,41-55,55-58,58-63,63-69,71-90\n-24-24,24-28,28-38,59-117\n53-63,63-100\n62-118\n106-118,118-124,124-144,144-164,164-179,179-181\n1-51,55-82\n0-15,15-55,55-125\n0-7,7-27,27-48,63-126\n49-90\n0-6,6-9,9-29,29-31,31-43,49-66,66-76\n58-83,84-99,107-137,296-322\n58-82,102-134,291-317\n158-198,198-215,268-307,307-319\n138-154,157-198,244-262,279-304,306-309\n49-70,281-328\n49-70,279-315\n30-44,44-47,47-64,64-82,86-104\n48-80,84-104\n50-72\n49-72\n55-81\n54-79,79-82,82-96,130-153\n39-65,69-98,270-283,283-285,287-327\n40-64,275-296,296-325\n45-67,67-84,84-87,87-119,130-165,165-182,230-249,249-252,252-256,258-281,281-308\n52-67,67-70,70-114,118-143,143-153,153-157,157-165,165-183,233-253,258-312\n292-321\n102-123,127-143,148-179,187-211,265-300\n99-125,144-177,187-214,269-295\n49-70,287-314\n49-70,290-313\n54-82,82-100,100-118,118-122,122-143,143-176,258-269,269-275,275-277,277-291,291-293,293-299,299-310\n55-89,89-102,102-118,118-120,120-138,149-175,249-272,272-275,275-293,293-312\n270-278,305-325\n269-287,304-324\n52-74,77-106,276-294\n26-37,37-45,45-51,57-87,87-102,102-118,284-294,294-311\n56-91,114-126,130-148,261-279\n59-92,95-107,262-280,291-309\n-31-31\n-45-45\n-5-5,5-22\n92-112,112-136\n8-13,13-23,23-25,25-57,66-83,315-340,340-368\n8-18,29-58,65-85,317-340,340-368\n94-137\n91-135,135-152,313-335\n23-53,63-81,309-338,350-369\n20-48,313-338,348-366\n169-191\n132-150,156-178,178-180\n0-14,14-17,17-36,36-42,52-128\n-22-22,22-26,26-47,69-133\n56-90\n76-104\n69-102\n78-102\n5-27,51-69\n6-24,60-82\n96-123,150-180\n74-96,100-112,120-146\n135-164\n117-137\n37-69,163-174,174-179,179-181\n4-25,38-66,294-314,314-331,346-364\n10-19,44-66,294-314,344-370\n3-27,47-67,83-101,300-319,329-342,348-356\n42-76,160-186\n47-61,66-80,292-311\n156-204\n167-193\n-12-12\n157-169,169-191\n-1-1,1-19\n142-165,168-192\n52-80,171-204,215-244,273-311\n56-79,172-207,215-223,225-236,271-288,288-290,290-312\n194-220,278-310\n196-220,285-310\n39-57,57-70\n53-71\n47-66\n48-66\n1-14,41-64,295-317,338-357,357-361\n45-74,294-317,329-349\n59-92,168-190\n169-190\n45-77,165-199,199-218,273-310\n51-73,171-210,278-287,287-289,289-311\n34-58,297-325\n75-105,161-185\n172-197,281-312\n45-54,292-320,333-351\n290-316,334-352\n71-94,94-111,122-131,131-150,158-180\n61-93,93-113\n0-29\n-1-1,1-19,19-39,163-175,175-179,179-181\n-3-3,3-8,8-23,23-52,52-57,57-72,72-90\n28-40,43-62,78-92,94-124\n60-78,78-90\n114-132,132-152,152-156,156-170,170-178,178-180\n-9-9\n14-33,55-64,75-105\n37-72,164-196\n46-70,294-324\n48-67,73-77,77-91,295-314\n155-189\n68-77,140-144,148-158,161-189\n24-71,165-195\n0-5,5-14,14-30,30-44,44-54,54-72\n165-195\n171-189\n31-78,165-195\n45-67,303-324\n45-67\n37-58,292-318\n36-59,275-293\n-1-1,1-20,68-84,84-88,88-96,96-102,102-111,111-130\n43-61,71-112,112-117,117-140\n9-44,47-52,52-55,59-71\n-5-5,5-48,57-81\n89-104,107-129,129-149\n107-150,150-152\n81-94,101-133,142-160\n75-93,93-97,97-122,122-139\n78-108\n15-43,48-64,67-88\n-3-3,3-11,11-31,33-53,57-129,129-136,136-149\n0-26,26-29,33-42,42-54,54-70,70-73,79-117\n71-118\n73-111\n-7-7,7-18,18-63,63-83,83-86,86-89,89-145,152-160,160-177\n-16-16,20-32,32-40,40-53,77-100,100-107,107-126\n66-102,102-110,110-131,143-161\n54-58,83-118\n-6-6,6-13,13-40,40-60\n-2-16,25-45,318-349,350-356,356-358\n16-44,311-344,344-360\n56-87,87-90\n-15-15,15-18,78-113\n77-103\n0-15,15-35,35-60,71-89\n96-119,128-154\n0-12,12-24,24-30,30-36,36-47,59-121\n-4-4,4-15,79-119\n0-18,24-43\n-17-17\n-11-11\n-14-14,166-194\n0-20,20-24,24-43,84-88,88-97,140-154,154-156,160-180\n75-105\n0-29,30-42,150-176,176-180\n52-62,64-67,67-70,71-88,88-90\n-14-14\n-12-12,170-190\n-1-1,1-5,5-16,148-177,177-183\n12-31,31-40,40-50\n51-69,69-80,80-88,88-92\n-10-10\n170-190\n-14-14\n-9-9\n344-373\n350-369\n-11-12\n171-189\n-10-10,11-31\n-11-11,11-33\n-16-16,20-42\n10-35,35-39,39-53\n68-89,271-300\n68-89,271-294\n-13-13\n30-58,58-79,79-96,128-146,160-169\n16-50,50-57,57-83,83-91,91-101,117-135\n149-175\n-4-4,21-47,47-72\n160-200\n-9-9,26-53,53-59,59-81,170-190\n66-95,95-97,97-104,104-117,152-180\n70-94,94-117,143-160,160-178\n35-58,272-284,284-306,306-311,311-313,313-324\n30-59,271-284,288-304,304-324\n-10-10\n170-190\n-14-14\n170-190\n-12-12\n169-191\n-15-15,169-191\n-20-20\n169-191\n-1-1,1-3,3-22\n-30-30\n-13-13,19-38\n-18-18,19-51,51-53,53-55,55-67,98-122,122-138\n107-130\n171-189\n92-123,133-146,146-165,166-177,177-183\n-1-1,1-9,9-26,32-55,55-72,74-78,92-112,168-192\n-12-12,18-37,37-40,40-54,77-99\n171-189\n28-64,161-199\n-5-5,5-24,24-33,33-59,149-161,169-191\n166-194\n171-189\n69-86,86-107\n181-213,214-216,220-227,233-238,238-242,242-250,250-258,258-259\n0-17,25-34\n0-34,34-60,60-64,64-90\n0-33,33-54,54-88,88-110\n46-60,60-64,68-112\n91-99,121-138,140-164\n58-103,103-125,125-145\n8-24,26-49,49-54\n79-104,106-109,113-126,126-137\n0-16,16-69\n0-53\n-11-11,11-48,48-64,134-152\n-7-7,7-22,22-27,27-45\n68-92,96-132,132-134,134-161\n52-70,83-107,110-124,124-141,146-172,293-303,303-307,312-322\n74-93,93-99,99-102,102-111,111-121,121-140\n80-97,97-118,118-131,131-137,137-149\n45-73,84-102,296-306\n50-70,82-102\n71-98,98-108,108-122,122-154,154-185\n53-87,87-112,112-133,133-154,154-186,280-297,297-316\n69-80,80-101,101-104,104-124,124-160,160-162,162-165,165-184\n70-107,107-109,109-116,116-121,121-126,126-147,147-175,175-187\n92-125,125-148\n65-100,100-115\n63-78,78-97,100-115,119-127,140-150\n43-61,67-85,91-131,131-152,163-180\n132-156,156-180\n101-123,123-160,160-162,162-180\n64-127,127-168\n49-78\n75-112,112-131,131-180\n93-110,110-136,136-175,175-185\n77-101,135-153,153-177,177-183\n61-90,90-101,101-123,123-130,130-172,177-183\n56-69,69-74,74-77,77-106,106-108,108-134,148-180\n64-108,111-138,138-179,179-181\n71-114,114-121,121-147,147-156,156-160,160-178\n96-118,118-121,121-141,141-143,143-169,169-170,177-183\n93-96,116-155,155-173\n-21-21\n106-114,139-169\n0-9,9-40\n53-71,71-109\n95-109,109-113,113-129,129-152,152-158,158-169,171-189\n239-274\n84-110,234-276\n-31-31,34-63\n0-3,3-12,12-17,17-32,38-47,50-53,53-68,107-119\n47-65,65-69,69-111\n0-4,4-32,32-35,35-58,58-69\n-40-40,40-73,76-88\n-3-3,3-9,9-12,12-29,29-41,41-52,52-60,60-71,80-102\n74-106\n91-102,102-129,158-202\n-5-5,5-58,171-189\n69-87,87-90,90-92,92-128,128-150,150-156,156-176\n63-106,106-108,108-131,131-164\n61-96,96-117,117-142,142-167\n6-24,35-69,86-94\n0-21\n85-109,109-118,118-178\n77-118,118-139,139-141,141-166\n2-10,34-65\n78-96,106-124\n70-90,90-119,119-121,199-213,213-215,215-221,221-233,233-241,241-246,246-263\n70-91,91-113,205-237,237-247,247-261\n98-119,212-225,225-249,255-269,273-288\n-2-2,2-5,5-22,22-43,43-56\n-16-16,38-56,56-67,67-69,69-104,104-117,117-120,120-140,140-158,167-193\n-14-14,14-23,23-25,25-45,45-48,48-62,62-68,78-120\n35-56\n134-163\n53-77,172-191,191-199,278-317\n36-49,55-68,167-185,185-189,189-191,191-196,281-311,311-322\n-5-5,5-25,166-194\n-17-17\n168-192\n145-168,168-192\n-10-10,10-36,74-78,83-93,93-105,105-113,113-115,115-124,124-148,162-180\n-18-18\n135-154,168-192\n-12-12,142-150,154-160,160-180\n-14-14\n136-166,173-187\n-2-2,2-17,17-48,50-72,86-100,100-104,104-108,108-112,112-120,120-138,138-160\n-9-9,13-28,28-30,30-49,49-69,91-109,151-164,170-176,176-184\n-11-11,106-116\n28-46,298-323\n19-29,29-33,38-48,49-67,297-320\n0-17,20-33\n48-71,172-194\n80-110\n68-103\n44-54,54-74,182-186,186-192,192-204,284-306\n48-63,65-84,84-98,98-124\n49-62,62-67,67-75,75-93,102-121,121-129\n-7-7,13-35,57-74,74-77,77-106,106-129\n50-62,62-82,82-114\n-12-12\n21-38,38-46,46-78,152-173,173-187\n-20-20,27-35,37-56\n61-75,75-105\n-4-4,4-33,33-35,35-38,38-52,53-60\n59-78,78-88,88-100,100-120,120-139\n44-58,58-62,62-89,89-113,133-153\n48-70,71-89,178-198,289-313\n69-78,176-184,291-309\n-1-1,1-21,69-81\n0-19,171-189\n-14-14,163-179\n-13-13\n-16-16\n-31-31,136-165,165-171,171-177\n39-63,63-77,164-180\n-11-11,158-180\n-20-20\n0-5,5-24\n0-18\n-35-35,99-120,159-201\n140-165,165-167,167-177,177-183\n2-27,48-52,54-72,98-118,162-177,177-179,179-181\n-13-13\n-18-18\n158-202\n148-167,167-193\n-21-21\n138-161,161-180\n-14-14,22-25,25-45,78-96\n-18-18\n-21-21,158-180\n164-196\n163-197\n-14-14,166-194\n156-173,173-187\n-28-28,136-148,148-177,177-183\n-15-15,154-178,178-182\n-20-20,22-34,153-161,168-192\n-16-16,167-193\n0-20,20-54,54-83,83-86,86-90,90-98,98-100,100-157,157-174,174-176,176-184\n6-25,32-41,48-52,52-63,63-86,86-95,95-106,106-119,119-145,145-153,153-163,171-189\n-1-1,1-25,159-179\n0-17\n-33-33,143-160,160-180\n-1-1,1-22,168-192\n25-46,46-60,65-82,82-93,93-108,113-132,151-160,163-172,172-182,293-313\n16-26,26-30,35-45,58-77,77-102,109-127,145-163,169-182,279-301,303-321\n49-67,309-331,331-343\n42-72,316-335\n-4-4,4-28,124-145,145-163\n-22-22\n-12-12,167-193\n36-81,165-183,183-208,279-315\n42-84,166-201,203-215,278-315,324-341\n50-68,68-85,292-314\n46-71,292-316,334-338\n54-81,165-188\n55-82,85-87,87-102,154-165,165-193\n166-199,279-310\n282-314\n45-63,293-318\n44-100,138-146,146-158,158-180\n-11-11\n-12-12,165-175,175-185\n56-81,81-83,83-97\n75-101\n50-68,71-103,103-120\n26-44,55-73\n59-83,87-124\n54-71,287-305\n287-306\n169-191\n-17-17,62-86,86-108\n147-154,154-158,165-195\n-13-13\n-14-14\n-14-14\n-12-12\n169-191\n158-202\n163-197\n167-193\n-12-12\n-14-14\n167-193\n164-196\n-13-13\n-15-15\n168-192\n159-180\n-13-13\n161-199\n-12-12\n-12-12\n-17-17\n214-223,225-233,233-254,254-284\n244-271,271-278,278-295\n65-83,131-156\n251-275,275-283,283-303\n276-300\n273-301\n-23-23\n-16-16,24-36,36-40,40-44,44-60,106-126,126-137,137-153,158-176,176-184\n170-190\n170-190\n-26-26,26-46,46-85,85-125,159-201\n0-40,40-65,65-67,67-72,72-105,124-147\n93-127,127-170,170-175,175-178,178-182\n86-115,133-175,175-180\n0-22,22-32,32-55,55-57,57-114,133-154,154-179\n98-129,136-151,151-157,157-180\n-15-15,162-198\n1-11,43-62,64-91,135-144,146-153,153-207\n31-49,49-65,65-68,68-78,78-91,91-106,110-128,158-178\n46-69,296-320\n46-68,345-363\n177-201,208-216,279-307\n179-205,275-322\n-10-10\n164-187,187-203\n58-76,163-186,186-202\n49-67,67-85,177-203,272-305\n173-190,190-208,277-306\n52-70,293-315\n-25-25,174-179\n54-126\n71-109,109-125\n-18-18\n0-19,23-41,54-78,89-109\n67-99,108-129\n89-111,114-140\n93-108,108-111,111-138\n49-60,60-82,288-309,341-351\n30-42,42-45,47-62,62-85,107-115,293-303,303-307,312-322,341-359\n14-36,66-86,105-122,286-294,349-367\n67-86,100-120\n-2-2,2-7,7-22,22-24,24-44,44-47,47-63\n155-179,179-181\n41-76,284-298,298-302,302-316\n36-50,50-70,70-84,284-316,316-326\n44-63,96-100,121-142,148-184\n43-63,69-95,113-134,134-154,154-179\n46-78\n3-21,52-76,298-316\n167-193\n-10-10,171-189\n-11-11,169-191\n-11-11,168-192\n-12-12,152-164,164-172,172-188\n1-6,6-12,12-16,16-19,19-22,22-27,27-32,32-42,42-64,64-68,68-105,111-114,114-125,125-135,135-156,156-177,177-180\n-17-17,113-135\n52-73,73-83,83-86,86-89,89-121,121-141,141-156,156-164,164-196\n39-66,73-78,78-83,83-87,87-89,89-93,93-133,133-135\n41-62,62-69,69-97,128-140\n6-30,51-70\n47-76,169-205,280-316\n47-81,164-200,277-299,299-317\n36-59,59-78,289-313\n45-70,290-318\n54-67,67-91,126-137,167-190,190-204\n55-79,161-190\n54-82,175-191,191-204,286-316\n52-75,175-197,287-316\n32-65,295-319\n49-67,291-315\n-13-13,169-191\n-13-13\n99-109,142-166,166-194\n-1-1,1-35,142-160,160-162,162-164,164-178,178-180\n0-20,29-39,50-63,63-98,98-100,100-116,116-124,124-135,158-202\n99-125,168-192\n-12-12\n-13-13\n-13-13,13-34\n-14-14\n-24-24,54-73\n156-204\n168-192\n-16-16\n168-192\n0-38\n58-81,113-140,159-201\n158-180\n147-168,168-192\n159-201\n102-114,131-143,149-155,159-201\n72-101,108-134,137-154\n169-191\n158-202\n72-99,99-127,128-153\n58-90,90-105,105-129,129-130,135-139,139-160,160-164,164-176,288-299,299-316\n55-98,104-108,108-139,139-144,144-162,288-306\n28-46,46-72,287-313\n35-62,62-74,293-313,313-321\n164-198,256-275,275-299\n164-189,189-207,264-284,284-307\n53-88,131-149,154-173,285-305\n56-69,69-91,114-121,134-150,288-312\n31-43,45-77,77-93\n44-56,56-83,83-85,297-319\n28-57,81-99,300-308,320-331\n34-62,72-90,299-323,323-337\n96-112,112-114,114-126,155-180\n-20-20\n269-304\n258-274,274-293,293-318,321-340\n277-320\n289-318\n46-54,277-299,299-303,303-317\n49-90\n171-189\n170-190\n41-58,58-81,277-293,293-315\n48-81,165-184,280-316\n-1-1,1-17,169-191\n-14-14\n0-25,25-43,43-52,52-67,67-71,71-78,78-95,95-98,98-115,148-176,176-184\n86-108,119-145\n-11-11,166-194\n18-37,163-197\n-4-4,4-23,28-43,100-124\n-31-31,36-43,43-56,56-83,83-88,88-111,161-180\n3-17,17-23,36-62,62-70,70-73,73-82,82-93,93-105\n-12-12,17-26,26-44,48-59\n212-232,232-242,242-286,300-320,320-360\n14-35,206-224,238-297\n9-21,23-42,206-217,227-251,251-294\n236-256,258-288\n209-227,245-272,272-274,274-287\n22-33,35-60,260-293\n-14-14\n-15-15\n0-16\n-1-1,1-19\n-21-21\n-12-12\n0-24\n167-193\n-10-10,165-195\n0-13,156-170,170-175,175-180\n-12-12,169-191\n0-4,4-23,23-29,67-87\n-1-1,1-25\n-19-19\n3-32,152-160\n-14-14,166-194\n0-15,15-17,19-40\n-10-10,161-199\n-14-14,110-136,169-191\n-14-14,17-28,28-37,37-47,76-94,107-125,149-167\n23-50\n170-190\n0-17,164-196\n-14-14,159-201\n-4-4,4-10,10-13,13-28,86-95,95-126,126-143\n-9-9,12-26,26-28,28-32,32-45,45-65,66-112,112-115,115-129,129-137,137-166\n-18-18,18-30,46-69,84-100,100-102,102-125,146-159,159-175\n114-158,164-196\n-16-16,22-47,157-203\n-10-10\n119-128,130-138,138-149,157-203\n-2-2,2-9,9-25,144-165,165-172,172-180\n-28-28,162-180\n-18-18,149-161,161-165,165-195\n-1-1,1-28,171-189\n157-203\n-12-12,16-19,19-26,168-192\n0-22\n-14-14\n-13-13\n-18-18\n59-88,88-107,129-147\n1-12,27-39,45-63,63-70,70-74,74-114\n33-51,64-98,98-110,110-124,124-136,164-179,179-181\n72-108,108-129,137-156,158-179\n50-99\n-14-14\n-11-11\n-6-6,6-12,12-25,43-63,63-67,67-88,88-92\n-4-4,4-22,38-56,56-59,59-90\n-12-12,156-177,177-183\n0-14,14-16,16-30,38-65,164-196\n0-14,14-30\n0-19,168-192\n-9-9\n0-15,15-34\n-17-17\n169-191\n-14-14\n5-43,84-102,125-143,143-166,171-189\n56-70,70-90,90-92,92-107,107-122,122-139,163-178,178-182\n21-49,131-161,162-172,179-181\n-26-26,155-205\n-14-14\n-19-19\n169-191\n16-27,27-44,132-143,143-147,147-150,150-160,160-171,171-173,173-180\n-22-22,22-38,136-148,148-153,153-159,159-201\n-13-13,169-191\n-18-18,169-191\n45-63,81-99,113-124,126-160,170-190\n-9-9,19-47,47-66,121-139,139-168,168-172,172-175,175-180\n-9-9\n-13-13,166-194\n-12-12\n-17-17\n-12-12\n-1-1,1-21,21-37,158-202\n-7-7,7-27\n-19-19,22-26,26-39\n48-66,70-82,82-100,104-121,121-125,125-147\n158-178,179-181\n-22-22\n-24-24,169-191\n-24-24,164-180\n-9-9\n0-4,4-8,8-25,169-191\n-18-18\n143-153,153-169,169-191\n171-189\n121-129,129-153,153-157,157-173,173-190\n128-173\n302-317,317-320,320-335,339-361\n275-290,295-324,324-335,339-365\n46-79\n53-63,66-68,68-100,197-215\n44-63,63-66,70-92,92-107,196-214,220-238\n26-29,299-319,324-340,340-343,344-371\n274-296,309-316,316-322,338-354,354-381\n0-8,8-12,12-20,20-32,32-33,49-77,329-347,349-360\n9-31,41-59,59-79,344-369\n209-229,263-281,313-338\n213-245,263-272,303-315,315-317,317-319,319-339\n65-94,191-201\n34-51,51-81\n159-169,169-185,185-213\n64-96,183-209\n146-157,168-190,190-205,205-209,209-228\n64-70,70-88,156-190,190-214\n215-233,262-276,281-289,289-315,315-334\n274-294,296-324\n258-271,271-289,289-291,291-324,324-333,333-354\n215-233,267-295,303-320,320-332\n39-72\n-1-1,1-23,23-37,42-60\n0-24,24-45,73-85,85-89,89-91\n0-11,11-28,31-46,50-63,63-85\n1-19,80-106,138-156,156-161,161-167,167-170,170-180\n-19-19,50-69,69-74,74-78,78-90\n44-77,162-198\n170-190\n128-136,158-202\n46-75,113-134,159-178,178-182\n52-69,171-189\n46-66,66-82,154-170,171-189\n38-60,169-191\n41-59\n37-54,54-80,164-180\n170-190\n36-77,154-206\n165-195\n33-49,49-65,165-176,176-184\n43-75,75-76,154-165,165-195\n-9-9,46-73\n166-190\n166-190\n164-187\n166-186\n18-38,38-41,41-70,292-322\n-4-29,29-33,33-42,48-71,286-308,315-337\n48-52,52-55,55-70,305-330\n37-53,53-70\n68-92,104-122,122-139,168-186,285-303\n41-66,292-320\n42-61,295-318,329-347\n42-60,276-293,297-323\n294-328\n49-73,175-201,279-313\n52-74,174-193,267-290,296-313\n171-198\n46-69,171-185,185-207,284-302\n47-69,171-181,181-209,279-297,298-316\n33-51,62-71,153-188,278-296,301-319,319-330\n167-195\n169-194\n19-37,39-61,61-63,63-65,65-68,72-77,77-91\n28-32,39-68\n42-69,87-108,159-193,212-237,297-320\n43-75,155-171,171-202,299-318\n214-241\n58-83,139-183,283-310\n54-81,148-168,168-183,284-310\n36-67,293-330\n37-66,280-331\n165-190,194-220,274-300\n166-194,264-284,284-302\n7-16,38-68,78-93,287-297,299-321\n37-68,298-321\n164-195,204-227,227-244\n166-194,211-225,225-231,231-239,239-250,271-286,286-295\n57-83,160-192,279-311\n43-69,150-167,167-195,286-314\n168-193\n62-83,146-181,277-294,294-304\n14-33,39-69,297-327\n-7-11,34-70,294-325\n162-192,192-204,206-223,262-279,281-298\n159-187,187-208,208-218,276-301\n25-40,40-43,43-48,281-295,297-321\n33-55,297-320,320-338\n29-68,281-297,297-305,305-317,317-333\n41-69,148-166,169-193,280-301\n25-43,149-168,168-195,271-281,281-288,288-306\n167-191\n0-8,8-20,98-145\n0-2,2-30\n141-161,161-179,179-181\n-25-25,81-97,97-107,107-111,111-147\n3-26,78-96,96-104,104-108,108-123,123-134,141-159\n-16-16,104-136,149-170\n-11-11,12-37,37-39,39-43,43-67,67-93,93-99,99-119,119-141,141-148,148-164,164-173,173-187\n0-16\n40-66,67-86,151-170\n-3-3,3-32,50-68,83-99,99-101,101-116,145-163\n92-121\n70-98,98-100,100-112,112-114,114-133\n63-77,79-134\n73-83,83-87,93-123\n-3-3,3-8,8-24,24-44,44-63\n-6-6,6-13,13-41\n0-37,45-71\n83-97,97-115,115-136,136-161,162-179\n112-154,163-197\n109-163,163-175,175-180\n159-178,178-180\n-13-13,89-107,107-116,116-133\n171-189\n-2-2,2-5,5-25,25-39,102-137\n-7-7,7-9,13-25,41-51,51-78,78-96,114-124,124-128,133-142,143-168,168-171,171-189\n83-103,110-133\n0-15,15-36\n170-190\n1-4,4-21,334-358,358-361\n136-153,153-162,162-163,327-344,344-370\n136-163,328-350,350-363\n103-114,134-152,156-164,341-362\n-27-34,34-42,42-45,45-54\n-11-38,305-323,323-326,326-347,347-349\n224-254\n223-239,239-258\n-29-29,29-90\n18-47,47-67,67-113\n-2-2,2-8,8-18,18-31,31-39,39-51,51-63,63-72,72-86,86-88,88-92\n0-6,6-11,11-32,59-121\n34-71,71-74,74-80\n-16-16,36-70,104-135,160-174,174-180\n-14-14,14-18,18-40,40-48,48-70,79-101\n80-100\n-13-13,13-22,22-37\n-13-13,13-17,17-38\n-1-1,1-35\n127-144,144-162,162-178,178-180\n107-127,135-180\n-18-18,18-70,70-90\n-7-7,7-13,13-23,23-27,27-33,33-43,43-54,58-122\n0-25,25-41,101-147\n0-17\n109-121,128-163,163-197\n139-151,151-174\n0-17,17-48,48-70,70-90\n4-22,104-135\n165-195\n-10-10\n133-154,154-178,178-182\n27-54\n-4-4,4-28,28-32,32-58,58-65,65-74,74-90\n130-158\n-21-21,21-80,80-90\n-2-2,2-16,103-122,122-136,136-138,142-155,155-169,169-180\n0-25\n125-158,158-164,164-196\n-2-19,19-32,145-156,156-160,160-164,164-167,167-176,176-178\n153-162,169-189,189-202,202-207,207-209,209-226\n225-251\n225-252\n129-139,151-166,166-178,178-184,184-217\n137-149,149-171,171-182,182-208,213-228\n-1-6,23-36,36-43,43-68,160-174\n7-10,14-48,48-70,86-107,107-123,144-147,151-171\n6-26,26-27,39-54,54-57,57-66,66-67,139-173,173-186\n1-28,33-61,135-171\n349-369\n349-369\n7-29,42-53,55-83,84-111\n5-23,45-74,85-110\n195-221\n195-219\n19-43,47-66,66-84,159-178,178-182\n37-59,59-88,152-168,168-179,179-181\n46-70,163-197\n-10-10,22-25,61-84,84-86,86-92,112-131,131-133,133-156,156-167\n29-45,48-65,65-90\n79-101\n25-42,42-46,51-61,63-81\n171-189\n68-89,89-112\n0-9,9-54,54-63,63-74,74-118,118-121,121-123,123-129,129-138,138-180\n36-58,66-87,87-92,92-106\n-6-6,6-26,26-46,46-52,52-55,55-66,66-72,74-86,86-89,89-91,91-142,142-150,150-156,156-158,158-166,166-194\n-5-5,5-26\n-11-11,11-46,46-74,74-79,79-88\n7-25,92-118,118-140\n73-89,89-91\n78-102\n-9-19,19-32,32-42,42-62,66-73,73-83,93-101,104-121,121-124,124-127,127-130,130-135,135-153,153-163,163-167,167-171\n-5-21,21-23,23-42,42-50,50-53,53-55,55-69,75-102,108-129,134-175\n44-76,139-160,165-195\n139-157,157-173,173-176,176-192,194-210,274-292,306-324\n48-68,140-151,151-166,166-174,174-193\n19-37,37-45,56-64,64-89,95-115,127-142,146-172,172-188\n29-59,62-88\n-1-1,1-18,18-31,31-34,34-38,38-50,50-70,70-75,75-87,87-93\n-13-13,100-123,123-142\n2-8,8-11,11-22,22-41,56-75,75-100,102-120,131-150,150-168,168-182\n-12-14,14-15,18-24,24-26,26-43,50-70,116-140,140-143,143-150,150-164,164-166\n46-58,58-78,169-191\n11-29,79-100,100-109,109-119,130-151\n63-90\n69-86,86-89,89-92,92-119,119-137\n-13-13,18-33,34-69,69-85,85-87,87-93\n-11-11\n23-46,61-66,66-79,108-135\n31-54,54-84,138-150,150-155,155-160,160-170,170-190\n18-31,31-57,57-59,59-80,164-196\n-5-5,5-22,30-61,61-81,81-89,89-91\n-1-1,1-23,114-160\n22-32,48-67,67-85,85-97,112-130,167-193\n36-69,69-94,158-188,188-215,271-290,290-300,300-345\n37-61,61-95,156-186,186-212,277-298,298-305,305-308,308-312,312-345\n-12-12\n85-103,109-145,146-153,153-157,157-171\n66-114\n32-41,72-104\n53-61,79-101\n35-55,66-84,96-114,127-138,152-168\n-1-1,1-21,30-54,65-74,111-133,133-156\n6-31,43-65,65-67,67-79,89-91\n0-14,33-51,55-70,70-82,140-150,150-160,160-180\n28-46,46-52,52-58,58-70,139-157,157-180\n35-54,54-71\n-22-22,22-39\n-1-1,1-22,22-42,42-79,86-94\n36-70\n23-58,66-79,79-82,82-93,93-105,105-125,125-159,159-190\n-7-9,9-19,19-39,74-80,80-94,94-104,104-138,138-168\n-7-11,100-132,334-352\n-4-7,11-27,27-53,62-80,118-137,137-154,157-172\n15-40,55-73,110-129,129-162\n39-67,67-72,72-94,137-147,147-153,157-203\n14-25,25-33,33-36,36-58,58-86,162-180\n30-48,158-202\n55-76,158-176,292-320,320-341\n51-67,70-86,198-216,288-322,322-342\n-3-3,3-13,13-17,17-34,34-36,36-42,42-45,45-73,79-101\n-11-11,11-15,39-79\n23-26,29-43,43-63,78-104,104-112,112-139,146-160,160-173\n19-37,37-64,75-91,91-97,97-99,99-103,112-135,156-164\n-1-1,1-9,9-21,21-25,25-38,38-60,60-80,80-100\n-1-1,1-7,7-14,14-34,34-54,54-56,56-59,59-61,61-70,70-72,72-90\n8-28,34-47,68-94,102-120,124-133,149-168,169-188\n3-27,57-81,81-97,101-117,156-168,168-183\n39-71,166-194\n-2-2,2-13,13-18,18-29,46-72\n9-37,47-55\n-1-1,1-23,23-27,27-38,38-47,47-81,88-92\n80-100\n-9-9,30-49,54-72,77-103\n-10-10,10-25,25-53,53-61,61-85,85-95\n-16-16,107-139\n49-67,171-189\n17-35,35-53,53-55,55-75\n8-21,21-23,23-30,30-67,72-76\n46-73,163-197\n4-26,29-71,81-99\n4-19,19-38,38-51,51-55,55-70\n13-28,28-32,32-40,45-53,53-54,70-88\n10-28,35-50,54-69,83-93,151-173\n-3-3,3-41,50-71,71-78,78-85,85-89,89-91\n7-40,47-80,101-122,122-153,153-171\n-7-7,7-31,45-70,93-112,112-126,132-139,146-168,168-169\n34-47,47-72,75-99,124-135,135-143,143-151,151-155,155-163,163-175,175-185\n-4-4,4-10,10-12,12-35,35-47,47-55,55-81,81-99\n-1-1,1-7,7-27,29-56,56-77\n-9-9\n52-66,66-71,71-85\n340-362\n339-361\n31-46,46-58,58-73,150-172\n18-39,44-83,92-99,99-102,106-118,134-160,167-193\n30-48,76-94,125-160,161-165,165-173,173-187\n17-39,132-142,147-171\n-10-10\n-9-9,38-56,130-148,155-205\n0-2,2-7,7-27,27-37,37-45,45-53,53-74,74-78,78-102\n-1-1,1-15,15-36,81-113,113-151\n0-14,14-34,34-89,89-91\n65-115\n142-153,154-170,170-173,173-175,175-177,177-180\n-13-13,13-31,31-51,51-71,71-109\n-11-11,28-50,74-100,100-133,133-155,168-192\n35-46,46-80,85-95\n107-133,134-163,163-176,176-184\n-2-2,2-13,13-16,16-90\n8-27,99-134,134-146,152-161\n-13-13,26-30,33-47,47-50,50-71,71-89\n-17-17,17-27,27-90\n-15-15,15-23,106-144\n134-155,161-199\n-6-11,11-13,13-19,19-35,35-37,46-50,50-75,86-104,104-114\n-9-13,13-15,15-34,34-54,54-59,59-78,93-120\n20-31,31-39,39-50,74-96,125-143,146-169\n-20-20,71-89,89-108,108-131,131-147,147-149,149-151,151-162\n-7-7,7-11,11-48,48-51,51-71,71-94,94-118,118-129,129-133,133-135,135-166,166-194\n-11-11,11-32,53-82,100-118,129-147\n7-30,54-71,71-80,82-87,87-97,97-117,117-127,127-146,146-159,159-161,161-164,164-166,166-176\n-9-9,11-24,30-43,99-112,112-119,119-132,132-147\n40-95,166-194\n22-34,34-45,45-54,54-65,65-89,165-180\n37-76,167-193\n30-42,44-74,168-192\n0-17,26-54,64-85,85-89,89-91\n98-116\n55-80,167-186\n-13-13,13-54\n173-194\n66-84,168-190\n13-26,26-48,48-56,56-70,70-84\n-9-9,23-44,44-70,72-85\n39-68,164-180\n47-67,67-90,156-170,170-184,184-209,284-315,315-331\n46-65,65-91,153-187,187-207,261-272,272-279,279-299,299-307,307-310,310-312,312-316,316-319,319-332\n24-35,56-72,72-84,144-164,164-174,174-196,261-265,274-294,300-322\n40-65,141-161,170-183,183-201,261-279,281-294,294-298,298-325\n11-38,38-49,49-74\n0-4,4-27,27-41,41-72,72-80,80-83,83-87,87-89,89-91\n0-18,18-20,20-54,54-85,85-88,88-92\n4-30,76-86,86-90,92-100,100-119,129-147,154-176\n9-29,96-120,163-186\n6-29,39-52,52-67,67-86\n-1-1,1-3,3-5,5-12,12-30,33-51,51-59,59-80,80-100\n0-4,4-33,33-56,56-90\n30-52,65-84,153-173\n35-53,53-54,66-85,143-151,153-162,162-173,173-198,254-271,272-290,297-319\n17-37,37-60,60-74,142-164,173-191,261-271,271-280,280-291,295-311\n3-22,22-42,43-63,63-85,85-95\n0-5,5-7,7-9,9-18,18-20,20-38,38-43,43-64,64-66,66-74,74-106\n35-67\n0-31,31-75,75-90\n0-19,22-28,32-37,37-40,40-51,103-138,143-165\n-3-3,3-9,36-72\n137-160,161-179\n13-30,30-32,32-35,35-65,65-76,78-102\n0-4,4-21,21-37,37-60,60-90\n-2-2,2-4,4-22,100-136\n-13-13,43-62,62-73,79-97,108-133,136-158,163-177\n33-51,51-81,81-94,153-171,171-180\n36-59,59-80,163-178,178-182\n-8-8,13-22,22-42,45-68,68-88,88-92\n0-21,21-79\n-1-1,1-15,15-19,19-21,21-33,35-47,62-80,80-88,88-92\n-22-22,37-86\n0-59,59-61,61-119\n0-27,40-83\n-1-1,1-4,4-23\n69-96,96-106\n29-47,47-62,62-74\n10-42\n-12-12,12-15,15-30,38-58,58-61,61-65,65-71,71-85,85-89,89-91\n-1-1,1-21,21-39,39-41,41-52,52-58,58-72\n35-68\n153-180\n5-17,17-24,24-53,53-81,81-85,85-112,124-148,148-180\n34-43,64-85,86-102,102-123,205-220,220-221,223-238,267-285,296-329,341-349\n31-40,52-69,69-87,104-124,150-160,188-209,221-229,286-299,299-328,328-347\n39-59,59-79,160-179,179-181\n-3-3,3-10,10-16,16-20,20-62,62-75,75-105\n-35-35,57-70,70-106,106-140,140-168,172-178\n-1-1,1-8,8-36,36-52,52-54,54-74,74-106\n0-4,4-12,12-31,35-55,55-75,75-87,87-95,103-106,106-123,123-133,133-144,144-157,162-180\n-3-3,3-20,95-113,113-116,116-137,137-139\n-13-13,107-135\n24-44,44-52,52-64,64-78,84-102,141-154,154-174,174-176,176-184\n-3-3,3-26,30-45,80-98,106-131,145-157\n39-75,165-195\n20-49,49-73,169-194,286-310\n52-69,166-188,286-309\n51-54,57-75,165-189,282-311\n66-83,83-102,103-121,175-193,206-227,227-241,272-290,312-321,345-363\n25-43,53-73,172-183,197-212,263-283,289-311,319-337\n-2-2,2-16,27-42,42-48,65-76,76-84,84-95,100-133,145-157,157-178\n157-176,176-184\n14-22,24-33,33-41,41-51,174-186,186-194,275-290,294-309\n13-39,43-65,173-193,279-298,298-299,304-314\n7-33,33-35,35-41,53-71,93-109,109-132,132-154\n45-61,61-78,158-168,168-177,177-180,180-193,272-303\n39-57,71-89,166-184,184-197,266-277,281-317\n47-63,66-82,169-177,188-204,287-313\n55-80,174-196,288-312\n-1-1,1-5,5-8,8-27,120-163,163-167,167-179,179-181\n0-18,113-150,150-159,159-170\n138-162,162-168,168-169,179-203,333-341\n112-124,126-174,183-192,201-218,228-255\n186-212,212-223,223-225,227-245\n216-239,239-259,259-268,268-279,279-291,291-298,298-304,314-329,329-333,333-339,339-342,342-364\n209-231,231-238,238-268,268-299,306-359\n231-260,260-268,268-269,313-331,331-333,333-351\n202-212,212-224,224-271,271-286,292-311,336-361\n186-206,230-248,248-277,279-287,287-299,299-316,319-329,336-338,341-363\n-4-27,59-77,113-133\n-8-11,11-18,18-32,57-77,92-132\n17-47,47-51,51-52\n244-285,309-322,322-356\n249-279,317-335,335-339,339-358\n8-37,43-57,83-94,94-98,98-102,102-115,118-134\n302-329,329-331,331-333,333-343\n-16-16,16-25,25-49,62-118\n27-45,80-117,117-130,130-136\n72-108\n111-123,125-134,134-137,137-150,150-172\n135-171\n7-35,35-53,53-57,57-73,73-107\n141-153,153-159,159-163,163-183,183-194,194-213\n-17-17,35-38\n46-75,169-191\n169-191\n290-309,309-321\n290-320\n46-67,172-197,202-220,289-307\n44-67,175-195,288-309\n38-58,58-77\n44-65,297-322\n44-66,298-323\n-43-43,43-66,66-69,72-168\n-11-11,11-34,34-41,55-81,81-92,92-110,110-112,112-137,137-169,171-189\n-14-14,20-43,63-73,95-110,110-146,151-178\n0-29,29-47,50-96,96-98,98-123,123-157,162-173\n-1-1,1-19,19-24,24-26,94-103,105-109,109-112,112-127,127-145,164-177\n-16-16\n132-168,168-192\n0-6,6-32,32-45,47-52,52-58,58-72,72-76,76-78,78-118,118-134,134-166,166-194\n0-3,3-32,100-123,123-128,128-138,138-143,143-158,158-165,165-195\n-4-20,40-58,76-87,106-123,125-142,201-223,226-244,324-334,334-355\n15-37,37-50,76-93,93-95,95-112,125-143,143-144,148-155,180-198,198-206,206-217,261-279,329-347,348-366\n-9-15,19-37,76-89,89-93,93-107,113-131,143-154,164-184,184-198,198-200,200-205,205-209,209-221,224-242,321-331,331-335,340-349\n47-72,169-191\n47-67,67-78,293-319\n41-68\n39-50,164-200\n43-61,167-195\n31-69,286-321\n36-64,282-325\n37-57,282-290,301-324,324-331\n49-67,283-297,297-321,321-335\n18-38,284-319,319-338\n281-306\n52-78,156-185\n56-91,154-183\n167-191\n47-77,167-189\n169-198,276-306\n170-202,246-266,266-268,268-272,272-304\n166-174,177-180,180-184,189-200,200-210,281-309\n43-77\n54-76,149-179\n48-72,163-179,182-204,285-306\n39-83,118-136,156-197,281-318\n47-77,148-168,168-197,281-317\n150-169,169-176,176-186,186-206\n291-314,318-338\n52-80,82-103,143-154,154-190\n54-75,154-174,174-193\n48-72,166-184\n49-69,169-195,298-308\n52-73,172-192\n-1-1,1-17,17-39,39-42,42-50,50-56,63-71,71-91,101-120,120-122,122-142\n77-114,117-129,129-132,132-139,152-174\n-1-1,1-13,13-19,19-30,37-51,56-70,77-89,89-92,96-107,107-119,119-138,150-179\n38-57,57-68,68-82,162-182,290-308\n38-52,57-66,72-79,79-97,147-157,157-161,166-177,177-187,191-203,260-272,272-275,278-296\n27-60,60-62,62-64,64-76,76-89,89-95,95-100,100-111,111-131,131-147\n74-113,113-127,127-140\n35-53,74-85,88-108,108-126,126-129,129-137,137-150,150-152,152-154\n12-14,14-15,21-45,164-192\n56-124\n88-128\n70-110\n51-80,80-100\n55-125\n1-19,25-34,54-71,74-81,85-133,138-143,143-157\n34-58,58-61,61-83,86-94\n106-126,134-166,166-180\n91-133\n35-49,49-52,52-54,54-67,67-69,69-81,81-85,85-108,108-137\n92-132\n26-38,38-48,48-56,56-62,62-68,68-79,79-96,96-99,99-103,103-123,134-152\n77-112\n77-120\n28-65\n31-75,157-203\n38-49,49-65,75-93,303-324\n19-40,40-71,303-320\n42-60,60-77,84-102,152-164,164-168,168-186,189-207,282-297,301-316\n51-75,154-164,164-188,197-215,275-293,308-326\n48-76,163-188,193-207,277-295,305-323\n37-63,63-85,85-90\n-4-4,4-23,34-43,43-64,64-89,89-91\n-19-19,19-22,22-84,84-89,89-91\n-12-12,12-28,34-52,94-121,121-130,130-140\n37-66,66-68,68-78\n20-31,33-78,156-177,177-180\n1-37,162-181\n5-25,25-44,164-185\n0-35,47-67,67-75,75-77,92-110,142-162,162-171,171-180\n-11-9,9-36,36-61,66-82,82-94,153-169\n-2-2,2-21,46-67,75-97,97-124,124-144,144-177\n-24-24,127-149,163-197\n56-74,84-105,105-125,125-138\n0-11,11-26,35-39,49-90\n-12-12,48-81,81-90\n0-9,81-96,100-124,124-150\n0-4,4-27,27-51,58-70,70-72,72-80,80-84,84-86,86-88,88-135,135-161,161-180\n5-32,44-62,89-112,118-131,140-148,159-176\n-2-2,2-5,5-19,19-43,43-83,83-89,89-116,116-125,125-143,143-164,165-180\n5-28,56-78,78-89\n-6-6,6-9,14-22,25-33,33-37,42-52,67-89,93-103,103-114,146-168,168-192\n-1-1,1-21,21-26,26-28,28-58,58-70,73-137,137-159,159-162,162-164,164-178,178-182\n-20-20,62-74,74-80,80-98,98-134\n-4-4,7-11,14-38,41-59,96-108,110-114,114-116,118-123,123-156,169-191\n-28-28\n-24-24\n108-137,137-157,157-174,174-179,179-181\n102-116,116-120,120-126,126-146,146-173\n110-143,143-169,169-191\n122-159,159-165,165-176,176-178,178-180\n11-38,92-122,122-138,144-164\n0-18,26-46,57-61,63-79,84-113,118-134,134-143,145-152,152-166\n116-132,132-141,141-152,152-180\n-10-10,10-19,19-26,26-44,99-126,128-146\n0-3,3-33,33-55,72-79,79-112,112-153,153-156,156-159,159-161,161-164,164-167,167-172,172-175,175-185\n-17-17,21-30,30-48,72-88,88-116\n131-158,158-180\n88-110,121-176\n-14-14,22-25,88-110,110-120,120-146\n208-237,244-277\n211-250,262-279\n210-240,257-286,286-289,289-292,292-302\n212-243,243-260\n109-141,141-163,195-232\n109-136,142-165,165-186,193-233\n153-174,174-181,181-216\n129-146,146-172,172-175,198-233\n128-167,196-233\n144-153,196-231\n139-169,192-228\n50-61,64-91,279-299,299-310\n54-79\n74-100,148-166\n177-204,283-303\n169-202,202-208\n177-192,192-194,194-200,200-216,270-288,289-307,308-326\n43-81,156-172,172-202,274-286,286-318\n49-72,72-92,164-187,187-205,285-319\n54-72,178-200,200-212,288-316\n45-69\n281-301,301-321\n279-300,300-316\n283-317\n289-315\n33-64,171-179,181-185,185-206,206-213,213-226,226-249,285-303\n38-66,178-209,227-251\n46-73,277-290,290-315\n54-83,147-190,190-202\n60-78,83-105,158-190\n57-83,93-107,159-190\n57-80,113-134,161-189\n50-62,66-95,113-131,148-164,165-193\n59-67,69-78,111-122,122-136,136-156,156-163,163-173,173-177,177-192\n160-170,170-172,172-175,175-177,177-197\n47-78,168-196,283-313\n45-65,65-82,169-188,289-319\n292-313\n52-75,286-313\n47-70,288-315\n55-88,154-179,179-198\n-31-31,31-61,61-87,87-93\n-1-1,1-5,5-19,19-39,39-59,59-68,68-79,79-101\n-19-19,108-142,142-147,147-162,162-165,165-175,175-178,178-180\n-14-14,123-133,137-151,151-173,173-187\n107-127,131-152,152-177,177-179,179-181\n-13-13,13-16,16-73,73-90\n-18-18,102-153,153-156,156-171,171-189\n31-61,81-99\n-11-11\n-9-9,49-59\n99-124,127-151,159-177\n22-42,42-50,50-68,109-121,121-125,132-195\n111-129,133-164,164-166,166-195\n37-55,68-94,122-137,137-157,157-178\n242-253,253-256,256-267,267-269,269-271,271-296,296-326,326-352\n232-262,264-293,293-313,313-343,343-363\n15-42,65-80,80-83,83-94,94-95,100-110,350-368\n0-12,12-15,15-18,18-28,28-52,76-94,94-96,96-114\n-19-45,54-60,60-82,82-125,125-130,130-161\n-25-1,1-51,60-77,85-134,134-150,150-155\n-4-17,106-140,225-239,239-243,243-257\n5-21,107-134,230-233,340-365\n265-284,284-293,293-297,297-310,310-330\n265-283,283-293,299-312,312-316,316-325,325-341\n209-237,237-258,258-278\n209-226,226-233,233-255\n15-44,44-71,80-113,113-126,344-375\n14-19,19-22,22-26,26-45,45-65,80-106,106-122,344-374\n34-40,40-50,50-66,70-88,88-101,136-186\n-2-3,3-26,36-68,68-71,71-73,76-79,79-83,83-102,139-178\n234-254\n232-253\n2-17,271-293,293-297,297-322,324-341,341-362\n3-7,7-17,272-318,323-339,339-361\n0-23,110-137,137-160\n20-39,50-76,124-146,167-193\n89-123,123-142\n76-89,89-119,242-263\n80-98,111-115,115-120,120-125,125-140,140-167\n1-9,230-257,257-275,297-315\n229-246,246-260,339-355,355-376\n234-257,257-267,297-314,314-318,318-338,338-348\n6-17,17-25,25-36,98-119,119-135\n41-76,164-196\n23-33,33-42,42-43,55-65,75-93,166-180\n38-66,165-180\n26-65,167-193\n43-62,62-80,160-200\n39-70\n54-84\n53-84\n46-82,152-186,191-197,197-208\n50-74,154-189\n35-57,292-312,323-341\n27-57,278-313,317-342\n247-255,257-266,266-277,285-311\n178-186,252-270,279-292,292-295,295-310\n164-189,191-206,280-294,294-313\n44-55,55-72,160-177,179-196,290-313\n30-48,50-68,149-163,167-192,280-312\n3-12,46-71\n286-319\n289-311\n44-86,92-109,150-187\n44-80,80-95,95-109,114-150,150-160,160-162,162-187\n171-179,189-196,223-235,278-313\n174-187,193-206,280-297,297-299,299-318\n278-297\n177-201,286-306\n44-54,54-83,161-180\n50-74,160-189\n50-76,157-182\n35-53,58-76,180-197,286-313\n163-182,182-188,289-316\n168-196\n147-165,171-186,186-190,190-203,217-235\n53-73,82-91,287-311\n49-71,71-81,135-148,148-171,171-181,285-297,297-299,299-303,303-320\n43-68,281-320\n17-34,34-36,42-69,289-313,316-326,326-343\n144-167,167-189,189-220,221-226\n34-48,48-70,286-319\n40-72,166-194,286-306,306-322\n287-313\n284-313\n160-191,290-315\n280-313\n275-309\n42-72\n48-72\n45-72,176-195,195-202,259-268,275-303\n45-66,173-201,278-307\n46-63,172-189,296-305,308-317,317-319,319-328,328-329\n31-39,44-49,49-66,163-186,303-320\n43-71,167-197,289-313\n44-70,167-190,287-305,305-321\n165-183,183-199\n-13-13,15-33,42-52,52-56,61-71,83-101,111-130,130-151,170-190\n43-79,162-198\n161-199\n133-146,146-150,150-180\n35-55,55-61,61-67,67-82,164-177\n47-86,91-98,161-175,175-185\n38-56,158-202\n-21-21,101-119,119-129\n61-81,85-101,149-182\n1-11,11-40,40-47,47-49,49-66,74-82,93-109,154-174\n16-30,43-48,48-59,153-171,263-281,287-295,313-334,338-353\n25-35,271-289,312-334\n291-310\n291-310\n17-26,53-100,120-130,133-149,149-153,153-156,156-162,162-169,169-178,178-182\n15-33,42-63,163-184,278-304\n38-47,47-64,162-180,180-193,193-196,200-212,282-300\n48-66,156-186,268-302\n0-9,9-45,45-52,52-65,65-85,85-89,89-91\n-14-14,14-29,29-53,53-57,57-77,77-103\n-1-20,32-49,49-54,80-93,98-127,128-138,149-159,159-162,166-174\n-5-13,13-14,19-29,29-43,45-52,104-129,129-148\n8-27,57-79,79-87,87-90,90-97,97-121,121-138,138-188\n19-33,45-67,67-74,74-95,95-118,118-124,124-130,130-139,139-190\n32-72,72-98,127-143,143-153,160-200\n44-59,59-70,170-200,288-306\n45-73,86-104,172-196,278-296\n0-29,31-42,42-52,52-62,78-102\n-14-14,17-34,102-115,119-135,139-145,145-178\n0-90\n0-18,34-56,96-122,122-153,153-178\n-13-13,13-35,35-63,63-73,74-88\n78-102\n7-46,46-75,75-83,83-92,92-107,123-187\n23-44,44-63,63-89,89-105,123-203\n-3-22,22-23,28-38,113-132,140-158,199-211,211-214,218-230,246-264,342-356\n12-29,96-109,109-112,112-146,196-206,219-238,346-372\n-2-8,8-10,10-13,13-20,20-36,130-140,146-178\n5-18,18-26,26-37,124-138,138-152,152-161,161-174,174-177,177-185\n-5-5,5-31,38-56,60-75,75-89,89-90,95-105,162-179\n0-33,57-75,96-114,114-126\n-13-13,80-101,101-102,106-126,126-142,142-161\n48-62,62-65,65-69,69-72,72-75,75-82,82-96,163-180\n42-54,54-62,62-74,79-87,152-208\n52-72,147-165,165-187,187-190,190-194,194-217\n35-53,57-74,145-163,169-197,197-208,260-278\n245-263,283-315,331-349\n183-207\n-31-31,35-81\n-1-1,1-4,4-6,6-28,28-50,70-110\n-23-23,23-80,80-100\n-22-8,8-14,14-28,28-30,30-48,48-57,57-59,59-77,79-97,97-103,107-143,143-158\n47-67,70-74,87-102,102-104,107-143,162-223\n-2-2,2-43,43-70,70-90\n-11-11,13-35,38-57,57-80\n-11-11,15-39,40-71,71-79,79-80,82-92,92-95,124-146,152-164,164-196\n-12-12,27-45,45-59,79-89,97-110,110-144,144-163,171-189\n27-42,46-66,81-99,105-116,116-124,124-136,136-137,161-179\n53-75,177-201,294-319\n51-79,166-202,296-318\n45-70,168-200,285-313\n44-71,166-191,287-311\n10-20,20-24,24-26,26-49,69-84,88-103,147-165\n15-47,48-57,57-58,84-103,168-186\n122-151,151-168,168-192\n151-162,162-198\n108-128,128-146\n-33-33,81-110,110-136,136-152,152-164,164-172,172-180\n-2-2,2-9,9-26,124-138,138-169,174-186\n0-25,103-142,142-151,151-154,154-172\n-13-22,124-147,147-182,182-187,187-203,203-224,310-327,327-347\n0-4,4-6,6-9,9-11,11-27,73-91,94-121,121-142,142-164,164-169,169-178,178-207,231-255,281-292,314-327,327-332,332-347,347-360\n239-262,273-295,313-323,323-345\n11-16,16-31,59-89,98-124,124-144,144-167,167-172,172-174,174-189,238-250,250-258,261-279,328-371\n8-11,11-30,135-154,154-168,169-174,174-180,234-256,325-368\n-7-1,1-3,20-31,82-100,177-201,208-232,232-251,259-267,301-319,321-338,342-353\n16-24,35-49,109-123,123-141,165-180,184-203,203-232,245-262,263-281,299-317,345-366\n170-191\n172-205\n43-60,60-76,169-182,188-201,299-319\n58-85,140-158,161-184\n-2-2,2-12,12-14,14-34,43-69\n164-196\n-17-17,34-52,156-204\n46-86,86-90\n89-134\n23-42\n0-18,18-38,38-42,42-45,45-57,57-82,82-86,86-94\n-18-18,109-138\n41-79,160-200\n-13-13,13-40,40-59,59-73,76-104\n-15-15,107-127,130-143,143-146,146-157,157-176\n-18-18,62-78,78-81,81-99\n-24-24,68-93,93-104,110-122,128-145\n-1-1,1-23,91-101\n-21-21,45-66,71-80\n43-52,52-60,60-78,78-98,147-165,165-195\n52-62,163-171,173-181,181-186,280-310\n2-24,24-30,32-61\n-16-16,16-17,89-99,99-101,101-106,106-119,119-121,121-137\n-5-5,5-8,8-50,50-69,69-111\n-15-15,103-134,152-164,164-179\n-7-7,10-48,52-77,84-89,89-91\n-1-3,3-12,12-24,24-31,31-36,36-44,44-56,56-61,61-93,97-117,129-144,144-159,159-164,164-172,172-179\n-1-16,16-17,19-31,36-44,44-56,56-63,63-83,83-90,128-151\n-15-15,28-67,81-98,142-175,175-179,179-181\n8-20,20-31,33-40,40-43,43-53,61-76,76-78,78-84,84-95,159-201\n41-59,71-89,114-132,139-171\n-1-1,1-25,25-42\n9-27,34-55,55-61,61-77\n-5-5,5-15,103-134,134-148\n-1-1,1-6,6-9,9-18,18-63,63-71,71-73,73-86,86-94\n162-198\n4-24,24-43,48-70\n26-55\n-6-6,6-8,8-26,26-51,51-81,81-99\n2-14,14-20,20-46,46-48,56-59,62-90\n-4-4,72-108\n-14-14,14-41,55-67,69-87,95-107,107-112,112-118,118-131,131-151,151-173,173-187\n0-3,3-16,16-35,35-43,49-66,133-170,170-177,177-183\n8-25,25-48\n155-180\n156-176,176-191\n159-190\n-2-2,2-12,12-27,27-32,32-38,38-40,40-57,57-80,80-85,85-87,87-90\n-12-12,74-106\n-3-3,3-22,32-56,56-60,60-62,62-65,65-70,70-90\n2-17,19-37,48-69,103-130,171-189\n-1-1,1-11,11-27,100-150\n38-55,55-72,162-177,177-179,179-181\n171-189\n0-17,107-135\n-10-10,12-41,73-84,84-101,105-121,121-123,123-141,142-145,145-151,170-190\n46-73,195-215,302-320\n25-50,52-68,169-180,180-188,188-199,208-228,261-279,279-280,284-293,293-296,296-304,304-327,328-337\n10-34,38-46,46-54,54-59,59-62,66-71,71-79,79-90,134-148,152-168,172-179,185-195,199-214,232-249,249-268,269-284,284-315,328-346\n53-69,76-104\n-11-11,69-83,83-87,87-93\n-12-12,12-14,14-23,23-25,37-52,52-54,58-70,73-90\n0-12,12-23,35-68,68-72,72-86,86-94\n-8-4,11-14,16-38,38-59,59-64,64-81,81-102,102-137,137-156\n3-14,14-24,24-28,28-35,35-44,44-58,58-64,64-68,68-78,78-97,97-116,116-122,122-147,147-157,157-169,169-171,171-173,173-177,177-183\n-1-1,1-8,8-14,14-19,19-39\n0-2,2-20,20-22,22-39,45-76,76-80,80-100\n-12-12,22-41,44-62,62-74,74-89,89-91\n20-38,56-76,76-89,89-108,125-143\n-13-13,13-21,21-46,66-74,84-96\n171-189\n-13-13,17-35,94-104,112-129,129-148,168-192\n-1-1,1-27,33-66,80-100\n-15-15,18-36,36-58,81-107,107-138,138-164\n6-24,43-61,86-99,105-119,119-130,130-153,168-192\n3-25,69-89,92-108,116-141,150-172\n-21-21\n-13-13,13-33\n-28-28\n144-157,157-203\n-1-1,1-33\n-19-19\n-20-20\n161-199\n-2-2,2-26,79-105,105-106,112-116,121-130,132-149,156-174\n2-17,23-44,44-96,96-142,142-144,144-148,148-162,171-189\n42-59,59-62,62-64,64-68,68-90,90-107\n23-41,46-66,66-79,79-94,108-126\n-11-11,78-100,167-193\n-5-5,5-8,10-33,33-62,62-70,70-83,83-97,97-138,138-174\n72-115,115-121,121-134,134-146\n1-22,22-44,51-69,100-112,115-118,118-133\n9-26,26-38,50-71,71-88,89-91\n4-21,21-26,29-32,32-65\n68-88,88-92\n42-90,109-130\n56-81\n42-56,56-94,97-101\n50-71,71-89,89-91,91-93,93-107,120-140\n-7-18,18-31,31-37,37-54,54-74,206-218,224-228,340-351,351-353\n-2-26,26-28,33-37,37-40,40-42,147-167,206-225,225-233,233-245,339-352,352-358\n-16-16\n114-132,132-138,138-149\n1-21,21-46,127-174\n33-51,67-85,135-164,164-180\n161-199\n223-250,252-257\n222-246\n287-306,306-334,334-354\n254-272,280-305,305-309,309-338,344-358\n7-33,89-102,108-115,115-125,136-152,155-165,168-183,183-203,241-259,343-361\n109-127,144-166,166-199,199-218,225-243,345-363\n93-116\n92-114\n61-84,84-100\n-1-1,1-6,6-16,16-31,31-33,33-36,36-48,48-54,74-106\n-2-2,2-14,14-17,17-22,22-42,47-70,76-104\n-1-1,1-21,31-50,82-95,95-135,135-147,171-189\n115-159,166-194\n-1-1,1-12,12-14,19-29,76-94,107-136,143-156,169-191\n-1-1,1-5,5-19,19-21,21-26,26-39,39-61,69-98,98-122,122-125,125-127,127-142,142-163,165-195\n0-3,3-8,8-24,94-111,111-115,115-117,117-119,119-147\n45-79,167-196,285-315\n51-79,173-201,287-315\n43-72\n51-72,72-84,174-201,281-300,300-325\n185-213\n181-203,265-283\n43-67,291-305,305-322\n41-69,289-306,306-317,317-335\n63-81,138-146,169-191\n50-74,163-182,183-213,287-329\n50-69,178-195,296-321\n184-202,278-298\n37-69,295-322,341-360\n37-66,294-319,322-341\n-1-1,1-41,41-46,46-80,80-89,89-91\n-3-3,3-30,77-94,94-106,108-128,128-145,145-150,150-167\n130-148,148-180\n0-3,3-5,5-33,33-80,80-82,82-84,84-90\n2-17,105-115,115-137,137-145\n-12-12\n-2-10,109-129,129-137,144-171,171-178\n5-22,22-25,25-28,28-39,44-62,113-131,131-149,149-156,156-173,173-176,176-185\n290-318,318-338,338-353\n275-283,310-345\n-7-31,31-39,39-41,41-65,65-80,80-97,97-122,122-124,124-126,126-136,136-146,146-161,161-165,165-170,170-173\n-8-15,15-17,17-19,19-36,36-39,39-52,52-60,60-78,78-86,86-100,100-108,108-134,134-136,136-156,156-172\n284-328,333-352\n285-325,331-348\n-1-1,1-3,3-16,16-25,25-46\n-3-19,99-117,117-127,212-224,224-230,230-234,234-244,244-246,250-263,263-275\n39-73,112-129,166-194\n53-76,165-195\n45-59,64-78,144-160,163-183\n32-50,55-80,80-83,83-87,87-97,121-139,159-183\n35-59,296-316\n33-50,50-58,58-61,61-65,65-76,89-107,158-178,282-308\n31-46,50-58,165-180,180-201,280-298,298-305,305-323\n289-317\n289-308\n49-67,69-85,182-200,277-295,295-315\n48-69,173-198,285-316\n46-54,56-65,65-75,137-155,161-186,186-199,300-318\n33-43,43-72,72-78,84-97,134-146,146-149,153-161,161-190,288-306\n-1-1,1-19,37-78,105-130,160-176,176-184\n154-180\n53-83\n-2-2,2-7,7-13,13-27,41-70,70-79,79-81,81-84,104-120,120-137,156-177,177-179,179-181\n130-153,153-172,172-178,178-182\n-13-13,15-30,35-73,73-98,99-107,107-119,164-196\n-12-12,12-36,42-65,72-85,85-88,90-104,104-112,112-157,157-179\n23-34,48-82,151-168,168-192\n6-24,24-26,26-41\n116-125,127-135,140-163,163-173,173-179,179-181\n0-4,4-12,19-57,57-89\n7-27,27-35,41-73,73-94,117-148\n29-67,151-180\n7-25,92-127,150-168\n25-39,39-42,42-47,47-71,71-84,84-101,160-200\n0-10,10-24,24-30,30-40,40-42,42-63,63-72,72-89,89-91\n-20-20,23-41,41-50,50-68,72-85,85-96,102-131,131-135,135-141,141-147,147-174,174-186\n-5-5,5-8,8-27,43-73\n29-47,47-80,153-207\n-13-13,13-35,35-37,37-86,86-90\n48-73,167-193\n135-178,178-182\n0-5,5-21,21-26,26-35,35-69\n-3-3,3-16,16-53\n1-19,50-72,100-108,119-127,127-135,135-146,164-177,177-183\n14-25,27-32,32-45,47-65,76-90,90-106,119-139,139-157\n161-183\n161-182\n-7-2,47-67,297-315\n4-31,44-52,65-89,89-91\n0-10,21-67\n44-59,59-78,165-180\n158-188,256-274\n158-188,261-279\n0-22,30-77,80-100\n41-81,147-171,171-189\n0-24,84-102,109-134,134-151,171-189\n3-8,13-20,33-47,51-70,70-106,125-142,142-148,148-163,163-171,171-172,178-182\n127-158,159-179,179-181\n171-189\n-5-6,6-37,39-45,47-66,71-97,104-130,130-159,159-172\n-10-14,14-18,18-34,34-38,38-56,61-88,135-157,157-170\n7-28,28-40,40-48,108-112,121-142,142-149,149-158,158-176\n4-37,37-41,41-54,140-161,166-184\n-12-12,25-44,44-46,46-66,71-82,145-156\n56-82,145-163,171-189,285-301,301-323\n39-56,56-72,170-189,283-322\n4-14,14-18,23-27,27-51,58-76,90-108,125-156,156-176\n-2-2,2-8,18-29,29-40,40-42,42-60,65-70,73-92,104-108,131-173,176-184\n0-27,27-61,61-90\n17-50,52-71,71-79,79-89,89-105,136-170,170-173,173-187\n-4-4,4-18,18-26,47-76,79-97,111-127,127-136,139-153,166-194\n23-54,54-64,71-86,86-89,89-91\n-2-2,2-14,14-16,16-40,40-46,78-97,102-120,120-135,139-166\n37-55,62-80,156-175\n2-12,116-135,158-176,214-228,228-231,231-236,236-253,343-353,353-357\n-6-12,102-120,156-167,167-175,175-186,214-225,225-228,228-235,235-253,279-297\n12-23,23-43,43-59,65-76,76-84,84-90,90-112,112-119,132-142,144-166,166-177\n25-54,67-92,150-173\n23-50,50-69,78-98,123-131,143-164,166-194\n29-47,71-89,116-134,144-165,168-184,193-211,215-233,246-270,272-290,327-335\n18-38,40-58,324-342\n17-37,40-58\n22-34,37-40,40-54,54-74,74-96,124-142,145-163\n10-35,49-67,88-110,114-128,133-151\n-10-10,26-44,46-57,57-77,83-101,138-156,175-185\n38-56,161-179,198-216,279-301,305-323\n80-106,144-157,157-161,161-199\n-7-7,7-21,21-37,37-41,41-64,65-101,101-122,125-136,136-138,138-140,140-163,163-179,179-181\n-1-1,1-21,21-44,81-118,131-147,147-152,152-167\n-9-9,9-41,83-104,104-116,116-124,124-136,136-158,158-163\n7-23,28-46,127-145,224-234,305-318,318-321,321-347,347-355,355-364\n80-91,91-99,99-126,140-158,199-217,219-227,306-318,318-321,325-332,343-363\n-15-15,51-73\n0-27,27-43,43-47,47-71,71-73,73-89,89-91\n43-67,71-94,165-195\n-11-11,11-56,56-77,77-84,84-96\n-5-5,5-25,102-119,119-151,151-152,164-178,178-182\n-2-17,17-37,37-44,44-56,56-80,80-90,90-92,92-94,94-96,96-100,100-110,110-116,116-125,125-133,133-147,147-152,152-168,168-172,172-174,174-178\n-27-20,20-32,32-47,47-68,77-80,80-102,102-116,116-123,125-150\n-14-14,21-39,63-81,86-108\n-10-18,23-37,88-106\n42-79,79-99,168-192\n37-69,160-178,178-203,278-298,298-319\n36-62,64-81,157-168,168-188,188-206,268-287,290-307,307-317\n5-26,138-159,163-178,178-182\n23-41,43-68,71-82,89-91\n-1-1,1-31,31-64,64-66,66-71,71-88,88-90\n0-5,5-31,31-76,76-104\n67-113\n118-136,154-179,179-181\n-8-13,42-53,53-59,59-67,67-73,73-80,80-93,93-109,109-123,123-131,131-135,135-139,139-142,142-162,162-165,165-172\n-5-6,11-20,50-85,89-103,103-128,135-154,154-171\n11-14,14-24,24-29,29-31,31-54,54-77,96-132,132-135,135-152,155-191\n3-33,33-54,54-74,74-89,89-91,91-118,118-147,157-183\n244-264,264-274,274-280,280-284,284-290,290-294,294-308,327-345\n247-260,260-273,273-280,280-289,289-308,335-353\n290-315\n293-313\n-9-9,13-38,38-78,78-102\n-11-11,11-15,15-28,28-39,39-48,48-57,57-89,89-91\n113-129,129-153\n0-18,18-20,20-23,23-32,32-35,35-58,58-82,84-96\n-2-2,2-19,106-133\n-12-12,12-18,18-24,24-49,81-111,111-126,126-128,128-139,139-143,143-145,145-164\n-1-1,1-3,3-6,6-14,14-28,32-44,44-52,52-53,75-105\n-1-1,1-20,21-24,24-29,29-88,88-92\n-3-7,9-13,13-15,29-42,54-80,87-99,99-110,158-173\n-1-32,82-104,104-108,108-122,157-175\n-11-11,13-32,56-74,82-100,115-133,149-167\n-10-10,10-32,32-48,68-84,84-89,89-98,98-118,118-122,122-138,138-143,143-148,148-157,168-192\n-9-9,9-12,12-41,41-44,44-52,52-78,78-88,88-92\n8-20,20-23,25-45,54-72,97-105,116-128,130-144,148-163,164-182\n0-16,16-23,23-28,28-29,48-66,70-88,93-115,143-173\n-11-11,11-35,35-54,54-81,82-98\n17-28,45-63,63-64,69-79\n-8-8,8-45,45-61,61-81,81-105,105-110,110-122,133-167,167-173,173-187\n33-54,70-88,154-172\n17-30,34-55,55-69,138-153,157-165,168-186,193-211,239-249,314-332,347-365\n6-18,30-48,67-92,92-104,131-145,150-164,169-187,233-248,248-254,271-289,308-330,347-355\n15-35,77-99,188-200,200-203,207-212,212-220,220-231,250-268,302-318,318-339\n5-23,120-143,178-196,208-225,227-236,236-240,245-250,256-260,265-275,313-325,325-328,332-344\n22-43,49-67,75-93,93-105,128-146,148-166,170-190\n-5-5,5-15,28-47,47-52,52-67,67-78,78-83,83-103,106-114,140-154,154-157,157-159,159-179,179-181\n-11-11,11-45,81-96,96-100,100-116,116-138,138-152\n0-20,23-58,58-63,63-77,77-95,95-118,118-122,122-124,124-133,133-145,145-148,148-153,153-157,157-162,162-178,178-182\n-2-2,2-28,92-103,103-107,107-125,125-145,145-147,176-184\n-5-5,5-15,15-29,41-59,65-75,75-92,99-118,118-125,125-130,130-152\n9-27,41-59,94-105,105-113,113-118,122-148\n5-25,25-33,35-40,40-49,54-72,135-147,163-197\n-3-3,3-5,5-28,95-128,128-146\n14-38,58-76,86-112,127-156,156-162,169-171,173-187\n32-45,45-47,47-79,165-176,176-184\n-12-12,16-31,100-112,114-118,118-126,126-134,134-145\n49-74,171-193,275-286,286-310\n27-38,45-78,164-186,186-203,289-320\n-7-7,7-11,11-39,42-58,58-70,83-95,106-108,108-125,125-151\n-32-32,32-66,66-75,75-96,103-171\n72-90,92-110,129-133,133-157,163-178\n144-153,157-176,176-178,178-180\n-23-23,23-25,25-55,105-124,124-132,132-135,135-144,144-147\n110-122,122-128,128-131,131-148,148-162,162-171,173-201,310-334,334-354,354-383\n4-17,126-143,143-145,145-168,170-201,225-233,249-267,301-319,319-335,335-364\n232-250,263-283,294-303,327-357\n263-281,285-297,315-333,333-336,336-356\n1-3,3-5,5-15,15-21,21-36,36-41,41-43,43-51,51-56,56-69,81-100,123-143,143-148,148-157,157-174,218-222,222-249,270-290,306-322,322-355,355-361\n6-10,10-13,13-26,51-77,113-134,134-139,139-157,184-199,199-202,202-228,254-278,278-281,288-303,319-340,340-345,345-355,355-366\n-7-7,7-16,109-126,126-139,139-145,145-155,155-158,158-180\n135-146,146-168,168-176,176-180\n156-182,198-234\n275-295,295-315,315-324,324-347,347-357\n-8-8,14-29,29-37,37-42,131-149,149-158,158-162,162-165,165-178,178-182\n-12-12,12-14,14-35,35-46,46-67,67-71,71-84,84-90,90-157,161-175,175-180\n54-62,76-103,103-107,107-120,120-142\n-2-2,2-15,15-17,17-38,65-86,86-99,99-111,111-120,131-153,153-171\n0-18,29-44,115-128,128-141,141-156,167-193\n55-78,78-114,131-149\n56-76,76-116\n56-71,71-103,108-122\n15-24,40-58,58-68,68-70,70-89\n54-84,84-89,89-91\n41-59,59-64,70-110\n55-106,111-128\n109-127,127-129,129-133,133-160,160-163\n43-59,59-61,61-83\n52-90\n51-106,111-118,118-130\n43-65\n50-105\n71-89,89-91,91-111,176-184\n48-66,66-94\n60-85,85-87,87-90\n59-74,74-106\n67-117\n52-89,89-91\n55-125\n0-18,18-34,81-135\n45-84,84-87,87-93\n105-127,133-180\n19-46\n23-41\n16-34,52-66,66-68,71-85,85-95\n1-7,7-27,27-33,33-48,48-70,70-90\n61-78,78-102\n138-159,159-161,161-178,178-182\n4-26,26-74,74-90\n1-10,10-14,19-24,125-152,152-170\n308-348\n-8-16,244-261,261-271,283-305,305-318,318-320,320-324,324-326,326-330,330-348\n50-76,78-88,159-169\n34-50,52-80,159-178,182-200,290-301,301-319\n138-153,153-165,165-173,173-198\n46-64,64-81,86-108,116-132,132-138,138-169\n43-61,74-88,88-110,115-124,145-169\n-9-20,20-60,111-139,139-151,151-171\n-6-35,35-40,40-65,84-104,119-129,129-132,132-139,141-146,151-172\n-4-18,22-46,161-176\n0-18,24-42,54-72,79-88,90-108\n5-19,19-29,29-61,81-85,148-159,159-164,164-166,166-169,169-184\n-7-23,23-28,28-42,42-68,113-121,123-130,130-144,144-148,148-173\n0-42,42-74,74-77,77-104,104-140,140-143,143-160,160-180\n1-8,26-38,38-45,45-81,81-99\n129-163,163-180\n102-125,133-160,160-200\n80-102,102-110,110-125,125-138,138-160\n147-165,165-172,172-188\n-15-15,15-44,97-112,112-137\n-7-7,14-42,42-52,52-73,73-92,92-106,106-110,110-112,112-133,133-154,154-173,173-178,178-182\n143-164,164-168,168-174,174-195,195-221\n146-163,163-165,165-173,173-194,194-223\n39-56,56-60,60-84,148-160,160-163,163-180\n25-40,40-63,63-66,66-85,164-177,177-183\n48-60,60-77,163-191,288-308\n46-68,169-199,272-288,288-307\n38-55,55-67,157-169,169-172,174-198,289-311\n166-185\n166-185\n46-68,170-190,288-311\n47-70,70-85,169-190,285-308\n-1-1,1-5,5-20,162-198\n-1-1,1-19,19-27,27-42,42-62,72-92,127-149,152-172,172-188\n18-33,37-46,53-60,60-65,65-68,72-93,117-137,155-179,179-181\n284-310\n298-317\n177-207,265-283\n49-84,289-299,299-314\n45-72,72-81,81-91,165-186,186-201,290-310\n38-57,57-89,280-299,299-319\n34-55,55-78,78-91,165-194,295-313\n50-72,166-194\n128-149,157-176\n148-178\n-14-14,46-68,68-90,90-108\n52-64,64-80,80-84,84-107\n52-80,170-197,294-320\n52-77,171-196,293-319\n-16-12,12-41\n-7-21,59-83,155-169\n157-180\n-15-15,15-23,23-30,30-50,57-87\n-5-12,12-29,29-33,33-57,64-94,94-116,118-141,141-148,148-155,159-175\n-5-42,42-68,74-91,93-99,99-107,109-124,124-137,137-157,157-175\n140-149,152-154,154-158,162-198\n140-169,170-175,175-179,179-181\n-3-3,3-7,7-14,14-45\n-17-26,26-49,49-70,96-112,112-161\n1-7,7-42,42-69,74-92,100-118,118-155,155-159,159-181\n-4-18,23-41,106-117,117-126,126-136\n3-29,50-67,67-82,112-137,137-151\n-3-24,50-75,119-140\n263-284,292-314,314-328,331-349\n263-284,284-288,288-314,314-319,319-328,328-346\n25-45\n43-78,128-151\n0-4,4-15,46-81,127-142,142-155,155-160,160-166,166-173,173-177,177-180\n6-24\n0-13,13-29,38-57,57-73,73-78,93-115,115-123,123-138,138-140,140-169,169-191\n42-79,151-167,167-193\n-22-22,22-35,35-60,60-96,101-146,146-171,171-179,179-181\n23-42,42-60,60-81,157-177,177-183\n3-13,13-39,51-62,69-71,76-98,106-132,145-167\n-18-18\n152-168,168-170,170-190\n0-27\n-1-1,1-38\n-24-24\n-15-4,4-7,7-14,14-16,16-32,47-65,98-106,174-192\n46-67\n-12-12,31-44,44-71\n0-31,79-101\n30-48,172-190,280-306,306-323\n264-293,299-315,320-338\n37-48,48-66,288-319\n281-316,316-332\n52-76\n-2-2,2-25,25-33,33-43\n-3-3,3-16,93-111,111-116,116-120,120-138\n-1-1,1-4,4-21,21-40,40-50,50-69\n116-140,140-142,142-163\n163-180\n-9-9,15-33,87-110,110-144\n56-90\n-23-23,23-54\n-13-13,13-15,15-36\n0-15,15-67,67-93,115-161,167-173,173-177,177-180\n6-25,25-50,50-54,54-65,65-83,95-128,128-146,146-148,148-164,169-191\n0-18,18-47,47-65,65-71,71-89,89-91\n-6-6,6-35,35-61\n88-113\n86-113\n83-112\n83-104\n85-106\n302-326\n82-109,301-319\n261-280,306-334\n183-208\n54-77,105-133\n0-2,2-4,4-27,31-48,48-69,69-111\n52-67,71-87,87-93\n125-142,142-147,147-150,152-158,158-180\n-14-14,50-64,64-75,75-105\n-4-10,10-14,14-18,18-62\n16-42,42-68\n27-51,51-70\n26-62\n3-17,22-32,32-37,37-42,42-75\n47-78\n32-44,44-76\n-13-13,158-180\n0-25,25-36,36-55,55-72,75-87,87-98,98-107,107-136,136-180\n-2-2,2-16,86-111,130-150,153-180\n-9-11,13-30,30-46,176-197,292-311,311-315,318-351\n25-45,49-57,144-162,176-194,201-219,224-244,262-280,305-317,341-361\n2-14,14-22,22-33,63-81,145-155,155-159,164-174,192-210,237-255,305-323,332-347,347-350,350-353,353-354,356-362\n-3-10,10-17,29-33,33-37,42-52,132-150,178-196,202-220,338-357\n48-80\n124-151,155-160\n2-16,18-35,82-115,125-144,149-164,164-170,170-178\n27-57,170-181,181-189,189-200\n-3-10,13-31,33-49,53-64,64-72,72-83,197-222,320-339,339-351\n17-45,45-50,50-63\n133-150,150-157,157-177,177-179,179-181\n52-74,74-85,85-95\n-16-16,21-30,30-49,124-141,141-152,152-164,164-177\n8-39,61-86,86-94\n80-134\n103-133,133-151,151-166,166-194\n88-106,106-127,141-159,164-177',Klb),o);g=(b&1)==0?null:(p=Zkb.n5('24,45,24,8\n1,90,5,5\n99,1\n51,49\n23,9,64,3\n58,42\n7,9,3,5,6,4,5,62\n91,2,4,4\n74,5,20\n96,1,2,2\n80,3,1,16\n72,21,7\n86,4,2,6,2\n19,30,37,15\n60,11,4,16,2,2,1,3,1,1\n80,20,1\n93,7\n69,31\n46,34,5,11,3\n100\n3,50,5,21,8,14\n68,3,12,2,7,7\n12,3,9,5,2,3,66\n100\n17,12,11,16,1,43\n5,95\n33,67\n5,31,4,60\n100\n19,25,56\n10,7,1,82\n45,55,1\n1,8,3,31,58\n1,28,71\n64,3,30,4\n46,1,1,53\n71,29,1\n21,35,44\n9,91\n2,62,36\n100\n100\n7,55,38\n100\n19,70,7,1,4\n19,19,62\n36,3,17,6,39\n68,7,24\n12,8,4,4,47,25\n26,73\n7,5,15,23,16,3,30\n1,13,40,15,2,29\n18,5,8,26,35,8\n50,28,22\n48,37,15\n1,27,2,1,2,3,19,2,6,5,32\n7,14,9,12,2,1,2,3,5,10,16,5,11\n1,1,7,25,1,1,38,1,1,24\n25,23,1,10,7,18,15,1\n17,19,64\n12,13,18,9,48\n30,23,22,24\n10,7,8,9,20,25,15,5\n17,8,10,14,13,11,24,2,1\n100\n8,82,10\n100\n34,13,30,17,1,3,2\n32,18,37,1,12\n100\n43,6,17,25,2,2,5\n39,61\n31,35,20,13\n55,45\n54,46\n31,1,30,6,10,16,4,2\n5,8,36,2,2,1,4,10,29,3\n100\n16,11,39,15,6,13\n28,35,36,1\n11,26,11,50,1,1\n45,6,5,2,28,12,1\n100\n1,34,33,32\n24,7,21,48\n41,11,10,2,2,1,33\n70,3,28\n1,98\n12,87,1\n1,76,13,10\n48,51\n34,38,28\n61,1,38\n100\n43,27,21,9\n1,1,9,1,89\n1,41,32,3,20,2\n33,6,24,27,6,4\n10,3,6,14,17,19,18,13\n1,12,16,7,1,6,15,7,6,10,12,1,6\n45,55\n3,3,1,10,31,52\n55,45\n72,28\n43,26,32\n23,13,2,2,2,2,2,53\n41,3,1,3,1,1,38,1,10\n100\n100\n92,7,1\n59,12,9,20\n100\n100\n18,11,49,9,7,5,1\n12,11,18,58\n4,5,92\n1,99\n9,5,85,1\n73,13,14\n1,7,3,4,9,7,7,4,2,11,1,2,2,10,30\n21,66,7,6\n2,83,14,1\n22,10,20,48\n46,3,6,45\n14,15,34,16,21\n42,58\n74,6,20\n43,52,5\n48,52\n8,92\n43,57\n100\n98,1,1\n100\n10,46,42,1,1\n22,78\n70,30\n26,74\n60,33,1,6,1\n9,6,85\n4,10,85\n97,1,1,1\n39,3,18,24,16\n42,58\n2,4,2,1,1,49,38,2\n48,52\n38,33,2,24,2\n48,52\n21,2,2,2,15,9,5,36,1,7\n1,7,6,1,8,12,25,41\n100\n35,65\n47,53\n41,25,20,10,5\n50,25,4,21\n43,32,25\n34,10,21,9,26\n34,34,32\n55,16,3,25\n50,23,26\n30,70\n58,42\n51,49\n42,7,52\n7,7,1,39,13,1,32\n100\n8,63,3,25\n88,12\n5,4,2,2,1,86\n47,46,7\n97,3\n70,7,3,7,3,1,3,6\n25,11,63\n1,3,36,29,6,1,18,5\n47,16,37\n64,32,4\n33,46,21\n57,43\n54,46\n55,45\n1,26,16,12,15,5,26\n7,1,25,8,23,36\n12,51,37\n24,48,28\n31,5,18,18,1,1,13,9,2,2,1\n5,4,1,3,1,3,2,3,1,1,17,4,5,17,22,10\n12,29,12,47\n6,94\n81,2,11,6\n83,5,1,2,9\n74,26\n53,47\n9,13,23,20,17,18\n1,1,59,1,13,24,1\n34,1,50,12,2\n10,12,3,21,4,4,10,13,22\n27,24,30,1,10,8\n17,11,18,21,24,8\n12,32,22,2,5,7,18,2\n1,5,4,6,3,3,4,3,4,2,2,12,12,2,5,2,4,7,5,4,11\n38,31,22,4,4\n26,2,5,7,9,8,4,17,3,4,3,1,7,5\n10,11,13,16,12,21,17\n2,18,19,18,9,7,9,18\n14,30,54,2\n17,1,2,3,14,7,1,11,15,6,22\n3,15,69,12\n1,51,1,4,1,13,13,13,5\n30,14,11,6,14,22,1,4\n10,8,31,4,14,5,3,20,7\n1,90,1,1,1,1,5\n100\n11,2,32,55\n9,75,16\n1,1,1,17,17,6,8,12,1,23,13\n6,19,17,18,39\n2,7,31,60\n100\n5,95\n100\n92,8\n98,2\n94,2,4\n9,91\n7,4,89\n3,2,1,1,2,1,1,1,12,4,74\n100\n100\n30,70\n15,85\n95,5\n1,2,1,3,93\n100\n5,23,5,5,62\n1,3,96\n2,37,46,7,8\n86,14\n14,1,80,6\n100\n91,6,2\n82,12,6\n83,12,5\n70,17,6,7\n1,52,41,6\n35,6,56,1,1,1\n4,7,10,2,7,2,8,58,1\n58,41\n24,11,66\n100\n8,9,64,8,11\n100\n85,6,8,1\n2,97,1,1\n100\n88,8,1,1,2\n52,3,3,6,36\n10,90\n1,5,93\n33,19,27,3,17,1\n42,58,1\n6,3,75,4,12\n100\n5,1,2,46,46\n24,24,53\n57,16,26\n81,2,2,15\n1,84,1,14\n2,98\n1,98,1\n9,89,2\n21,79\n10,89\n4,96\n18,82\n2,3,2,2,4,2,1,1,84\n6,94\n2,8,90\n22,78\n6,92\n99,1\n100\n100\n41,47,12\n30,70\n7,28,65\n21,7,21,51\n87,13\n29,71\n22,1,78\n51,3,45\n70,30\n54,10,17,17,2\n4,10,2,6,1,2,75\n1,99\n8,57,29,6\n93,7\n52,48\n100\n79,2,3,3,8,5\n22,26,1,51\n17,34,10,3,22,14\n90,4,7\n23,4,73\n79,21\n25,75\n9,21,17,4,28,21\n82,4,3,7,4\n2,24,55,19\n1,30,35,25,9\n10,3,4,15,10,11,48\n3,4,10,8,55,19\n78,6,15\n4,2,93\n100\n100\n1,55,44\n11,26,12,51\n45,55\n36,64\n25,75\n100\n6,1,3,90\n9,79,11\n100\n100\n3,97\n18,11,4,66\n100\n100\n6,93\n6,94\n32,68\n100\n100\n64,5,30\n14,4,14,69\n69,12,15,4\n100\n36,22,31,9,2\n3,45,8,9,35\n71,13,10,6\n15,16,46,22\n38,31,12,3,12,3\n88,12\n100\n100\n16,82,1,1,1,1\n7,3,27,56,7\n20,74,5\n100\n100\n100\n100\n42,46,8,4\n50,1,2,47\n1,3,1,6,2,29,36,17,6\n33,5,58,4\n23,2,75\n34,66\n14,5,8,72\n100\n100\n1,44,55\n100\n5,2,94\n36,1,63\n31,7,8,18,4,4,8,20,1,1\n100\n100\n16,84\n100\n100\n14,86\n10,2,1,1,85\n1,3,95\n3,4,8,85\n100\n9,89,2\n93,7\n21,79\n19,81\n3,86,12\n3,77,7,12\n100\n8,92\n5,9,1,1,85\n1,95,4\n4,2,85,8\n10,90\n2,91,7\n47,29,24\n80,20\n99,1\n100\n21,12,67\n3,2,95\n17,9,4,5,12,54\n59,41\n4,8,19,22,4,35,7\n3,3,10,5,4,75\n21,26,30,22\n5,10,50,35\n15,14,4,2,65\n27,45,7,3,2,8,8\n1,23,53,24\n74,23,3\n15,81,4\n40,60\n7,11,82\n22,1,77\n41,59\n100\n27,73\n22,78\n1,74,25\n3,1,61,1,34\n99,1\n4,27,14,55\n12,17,7,18,6,11,3,2,25\n99,1\n100\n10,90\n95,5\n19,81\n97,3\n10,5,85\n2,98\n52,21,27\n100\n100\n100\n77,23\n98,2\n100\n100\n22,15,15,6,41\n64,31,5\n28,16,34,19,1,1,1\n44,6,4,15,13,18\n75,25\n100\n60,40\n33,67\n52,8,15,23,1\n60,41\n100\n100\n53,2,6,3,1,3,31\n1,10,13,22,24,19,6,5\n24,76\n39,61\n97,3\n100\n100\n80,20\n19,4,16,14,2,1,43\n35,65\n91,9\n64,36\n2,98\n95,5\n100\n61,39\n100\n67,3,19,1,6,2\n45,55\n2,7,9,21,42,2,4,1,4,1,2,5\n8,86,1,5\n61,27,13\n3,1,96\n25,75\n2,18,6,9,65\n30,70\n8,87,5\n4,96\n15,85\n97,3\n90,10\n100\n100\n100\n100\n100\n100\n100\n100\n11,89\n48,1,51\n1,14,85\n2,1,95,2\n1,1,98\n100\n15,54,2,29\n100\n49,50,1,1\n100\n10,12,78\n27,6,6,24,4,14,20\n100\n47,53\n2,8,5,6,6,73\n32,1,1,66\n3,2,3,33,15,8,4,8,13,3,9\n2,11,87\n53,38,8\n22,9,69\n41,1,2,1,55\n2,16,1,4,6,70\n98,2\n96,4\n37,45,18\n3,1,2,16,78\n3,1,2,2,8,2,73,3,4,2\n8,31,61\n100\n20,80\n100\n19,81\n13,46,41\n9,3,9,79\n12,83,5\n100\n12,88\n100\n10,90\n3,96\n6,94\n100\n17,83\n4,4,93\n100\n99\n33,11,3,6,11,3,32\n16,78,1,5\n11,39,33,17\n3,4,4,23,6,1,1,3,55\n100\n100\n100\n31,3,5,15,42,5\n22,8,21,48\n25,1,10,56,7\n47,29,24\n100\n31,10,7,3,15,7,8,3,15,2\n100\n10,7,6,2,13,24,7,6,24,1\n1,5,94\n13,4,30,23,27,3\n1,29,69\n33,2,50,14\n100\n1,99\n23,1,6,69\n36,1,3,61\n54,46\n1,13,23,48,14\n42,24,34\n1,8,17,29,6,10,12,18\n35,11,53\n41,59\n58,42\n3,13,2,2,2,12,67\n85,15\n100\n72,28\n100\n100\n13,72,7,4,4\n100\n18,4,41,32,2,2\n11,49,8,31\n35,65\n4,95\n9,90\n23,77\n64,36\n100\n100\n85,2,4,7,2\n100\n100\n92,8\n46,28,26\n100\n100\n1,1,98\n100\n100\n64,8,28\n7,12,33,7,2,3,5,5,25\n20,44,12,2,1,10,5,2,2\n32,68\n21,42,5,32\n41,15,18,25\n38,10,11,2,14,1,23\n5,95\n4,6,90\n4,54,42\n100\n21,39,19,6,14\n100\n28,60,3,4,1,2,2\n100\n71,12,13,3\n100\n25,42,6,18,8\n11,9,79,1\n8,23,8,10,24,27\n4,2,31,62,1\n98,1,1\n20,79\n11,1,21,21,12,34\n40,7,52\n4,3,1,86,8\n61,10,22,1,2,1,4\n33,66\n7,55,37\n98\n2,27,13,8,21,1,12,17\n86,13\n52,47\n81,19\n2,2,93,4\n6,79,2,8,1,2,1\n29,38,5,28,1\n23,8,68,1\n4,1,20,7,7,47,12\n5,37,57\n1,16,79,4\n10,18,72\n12,1,77,10\n36,10,27,5,4,18\n24,76\n42,41,4,14\n99,1,1\n86,13,1\n100\n100\n100\n13,40,5,7,17,13,5\n18,22,17,37,5\n26,32,5,36\n95,5\n100\n100\n100\n100\n100\n18,82\n1,4,1,94\n7,12,1,81\n5,95\n14,27,7,12,10,4,21,6\n36,64\n92,8\n100\n71,9,3,16\n100\n100\n97,3\n82,18\n87,13\n45,55\n78,4,18\n48,8,12,1,27,1,2\n33,22,25,20\n1,97,2\n85,10,4\n1,69,22,2,2,5\n14,9,9,28,13,6,21\n10,4,28,8,29,20\n85,15\n48,7,45\n35,65\n49,51\n43,57\n3,1,22,74\n1,99\n66,34\n43,5,4,35,13\n55,32,13\n1,17,33,20,28\n90,7,1,2\n33,7,3,3,53\n7,9,9,5,19,31,21\n52,47,1\n59,8,12,9,7,2,2,1,1\n6,4,23,36,10,13,7\n8,48,5,10,26,3,1\n21,21,1,56,1\n5,95\n1,59,40\n96,1,2,1\n6,31,25,6,21,6,6\n100\n7,18,9,67\n100\n100\n1,99\n64,36\n93,7\n98,2\n41,26,33\n100\n5,95\n61,8,31\n37,9,25,29\n100\n100\n100\n18,65,12,6\n45,46,4,2,3\n87,13\n11,23,4,3,3,8,48\n92,2,6\n51,7,15,23,4\n100\n25,44,26,5\n4,3,1,92\n1,16,26,8,8,5,36,1\n90,1,9\n28,64,7,1,1\n3,4,13,4,77\n15,14,24,1,4,9,33\n80,20\n18,9,42,16,16\n7,32,12,6,26,1,11,3,2\n5,32,2,1,1,1,1,1,4,53\n3,47,3,14,9,24\n74,1,1,24\n3,97\n80,1,3,15\n4,8,87\n99,1\n100\n2,98\n27,3,70\n100\n86,14\n95,5\n65,14,18,3\n4,1,95\n70,5,6,1,1,17\n1,6,53,4,1,35\n94,2,2,2\n66,28,6\n52,25,2,18,1,2\n12,4,7,6,4,68\n35,63,1,1\n48,52\n41,59\n4,4,39,53\n10,2,3,85\n75,3,22\n1,99,1\n100\n26,1,66,6,1\n11,1,18,1,7,56,1,4,1\n65,35\n97,1,2\n33,8,5,54\n1,1,18,10,70\n3,78,19\n5,79,13,3\n18,38,39,5\n1,1,19,7,5,15,21,4,16,4,3,5\n3,20,77\n10,1,90\n3,3,72,22\n5,77,17,1\n65,35\n84,16\n14,1,29,20,19,6,12\n50,8,1,41\n29,10,14,14,30,1\n37,6,2,12,11,12,21\n4,4,2,89\n1,24,11,63,1\n44,56\n26,4,70\n13,87\n100\n5,3,92\n7,90,3\n57,17,7,4,15\n21,6,5,4,4,10,27,23\n46,54\n52,42,5,1\n1,99\n99\n100\n40,47,13\n1,5,44,25,26\n7,6,87\n3,5,1,2,4,16,17,52\n19,81\n46,54\n39,22,39\n100\n100\n1,1,1,10,18,33,35\n7,93\n2,52,45\n100\n4,94,2\n100\n100\n23,1,1,1,17,57\n3,97\n2,1,20,18,60\n26,17,57\n86,14\n36,52,12\n19,37,44\n3,10,86\n55,45\n71,29\n1,38,28,33\n27,73\n1,1,83,15\n7,17,10,10,16,6,13,1,20\n5,37,42,15\n100\n100\n100\n100\n100\n1,1,1,2,96\n1,99\n1,98\n33,9,34,24\n53,47\n11,89\n96,4\n100\n46,54\n82,18\n100\n100\n98,2\n4,96\n90,10\n17,83\n100\n100\n12,7,12,10,60\n94,6\n54,1,46\n40,60\n100\n84,16\n96,4\n80,20\n65,35\n11,1,87\n6,2,5,3,83\n2,3,95\n100\n2,3,38,56,2\n29,66,3,3\n16,4,80\n3,5,12,80\n45,55\n9,11,28,7,45\n54,23,7,16\n14,1,38,30,17,1\n8,38,17,37\n79,21\n78,22\n44,5,1,1,1,13,9,13,8,1,4\n41,59\n55,45\n83,13,4\n8,30,30,1,2,29\n2,2,2,88,5\n4,7,62,3,5,19\n100\n10,64,5,21\n58,2,35,2,3\n3,3,2,37,9,32,2,13\n2,2,95\n4,96\n100\n14,82,4\n100\n27,44,29\n44,1,49,2,4\n98,2\n80,2,3,12,2,1\n14,11,33,12,21,8\n100\n46,9,45\n15,2,1,71,10,1\n2,98\n1,99\n3,14,5,5,71,2\n100\n26,9,7,26,4,28\n1,1,32,66\n15,1,85\n22,7,7,7,52,5\n47,12,41\n35,8,33,24\n5,6,16,2,25,19,14,8,4\n6,1,7,13,1,18,4,4,15,30\n1,1,1,13,8,11,49,1,3,14\n73,15,1,7,1,4\n44,5,15,36\n66,12,17,2,3\n20,13,8,58\n58,42\n2,57,1,2,8,30\n7,39,4,17,12,7,3,10\n1,77,22\n80,20\n100\n56,18,26\n42,8,2,2,20,26\n18,13,1,54,6,6,1\n4,1,77,19\n67,31,1\n8,3,5,4,27,52\n5,5,29,26,13,22\n69,31\n51,48\n2,7,3,14,1,2,2,70\n32,3,3,62\n5,16,18,27,34\n28,12,27,33\n22,10,68\n4,1,1,1,10,85\n26,29,29,6,10\n10,83,7\n29,39,10,9,4,3,8\n54,14,31\n45,4,32,18\n45,2,7,2,1,38,4\n19,4,11,8,46,2,10\n31,41,1,27\n29,14,7,11,35,1,2\n26,16,2,13,1,32,11\n1,4,5,6,5,25,1,3,50\n1,8,12,10,36,7,10,14\n100\n100\n13,87,1\n9,3,32,13,42\n46,54\n4,96\n100\n37,6,57\n11,89\n18,82\n42,1,57\n11,6,13,43,28\n19,4,11,4,10,21,31\n1,4,1,83,11\n9,91\n100\n11,11,19,2,13,45\n8,1,1,1,1,12,32,42\n24,4,1,68,3\n62,5,27,5\n8,86,5\n1,1,97,1\n5,9,19,2,9,11,6,2,5,6,5,7,14\n22,8,1,1,2,2,61,1,3,1\n1,95,1,2\n100\n100\n10,89,1\n3,8,89\n100\n100\n10,1,11,3,3,70,2\n71,20,1,8\n96,4\n92,8\n48,1,51\n45,54\n100\n51,1,10,34,4\n52,4,1,25,8,12\n2,2,95\n9,2,2,1,85\n100\n28,19,21,3,3,21,3,2\n97,3\n2,2,92,4\n100\n10,60,22,8\n98,2\n28,32,16,24\n100\n93,7\n47,53\n100\n1,90,9\n11,17,7,37,29\n100\n100\n100\n100\n22,10,25,43\n7,1,12,5,6,27,8,34\n3,3,57,37\n1,3,89,6\n79,21\n55,45\n100\n3,8,3,2,84\n5,4,92\n15,19,2,19,7,36,1\n18,14,2,1,3,61\n18,19,63\n1,7,92\n2,1,1,58,20,11,7\n2,24,16,50,4,2,2\n82,15,1,2,1\n4,4,4,53,35,1\n39,52,9\n96,4\n1,12,22,22,44\n43,57\n1,2,2,95\n1,3,2,90,2,2\n10,5,85\n9,6,85\n21,21,35,22\n75,23,2\n100\n99,1\n3,97\n3,97\n9,1,1,3,86\n7,93\n1,42,57\n10,3,88\n2,9,64,25\n2,72,27\n1,52,45,1,1\n3,1,1,31,25,15,3,20,1,1\n4,31,2,3,61\n1,13,7,4,3,71,1\n15,22,14,20,30\n1,24,5,25,9,17,19,1\n2,98\n100\n100\n100\n20,6,4,18,4,9,35,3\n21,6,5,68\n100\n100\n1,99,1\n1,99\n37,10,10,12,6,26\n37,13,1,8,8,1,5,27\n100\n100\n43,36,21\n100\n33,67\n8,37,43,12\n25,2,35,22,17\n100\n24,76\n54,46\n11,80,9\n11,13,12,63\n1,41,57\n51,49\n19,18,2,30,4,28\n12,61,27\n11,89\n2,1,18,1,5,74\n5,1,23,2,3,5,1,59\n98,2\n24,51,26\n41,59\n100\n7,20,22,27,24\n74,26\n32,68\n100\n5,24,19,53\n99\n92,8\n2,4,5,90\n1,1,11,84,4\n62,15,22,1\n100\n100\n17,3,8,4,29,32,8\n89,11\n90,10\n6,46,15,33\n69,31\n100\n100\n100\n100\n23,47,16,10,5\n50,2,2,1,7,19,3,4,7,5\n1,2,1,18,22,23,28,1,1,1,1\n40,24,36\n100\n26,74\n3,97\n59,41\n59,41\n97,2,1\n9,57,1,13,20\n2,98\n60,40\n100\n100\n8,92\n1,22,10,7,60\n16,35,1,5,1,43,1\n26,41,7,1,6,17,1\n62,8,5,25\n29,38,21,11\n36,1,1,1,1,59,1\n49,1,1,1,25,22,1\n58,2,13,2,3,23\n1,35,40,8,16\n6,3,39,35,10,6\n3,33,31,28,5\n24,13,20,43\n53,47\n50,50\n20,14,66\n80,8,10,3\n10,6,5,4,2,4,1,2,2,50,13\n73,27\n11,89\n100\n14,4,11,12,2,43,14\n13,35,51,1\n31,17,2,28,22\n100\n100\n6,6,39,18,10,21\n62,1,4,1,19,13\n3,12,85,1\n18,12,2,27,5,3,7,2,23\n90,10\n68,1,4,1,2,1,1,1,19,3\n55,15,4,25\n99\n78,1,1,20\n7,15,10,7,1,2,4,6,7,3,2,2,5,4,2,23\n76,3,21\n2,13,10,11,44,20\n24,29,47\n100\n2,1,45,44,8\n46,40,5,8\n24,18,16,12,28,1,1\n8,2,6,23,44,8,8\n100\n100\n90,9\n87,13\n6,7,26,1,16,3,41\n30,5,65\n61,1,39\n100\n14,8,78\n12,3,4,5,3,23,26,24\n22,22,1,55\n9,7,68,10,7\n66,1,34\n8,1,4,62,25\n56,5,5,35\n52,35,13\n100\n10,27,60,1,1\n1,46,37,6,11\n58,2,2,15,9,15\n10,9,16,29,9,27\n14,27,4,55\n1,29,10,1,59\n3,80,6,11\n18,14,8,4,5,11,8,6,6,16,5\n60,40\n9,1,61,8,19,2\n2,8,43,42,5\n1,75,13,11\n5,5,35,1,1,36,17\n1,24,21,5,1,31,17\n17,14,6,62\n6,18,1,23,3,1,5,6,6,2,11,18\n10,12,5,7,36,13,6,10\n30,21,10,13,26\n3,33,6,58,1\n57,43\n61,3,1,4,3,28\n6,3,20,4,14,30,23\n3,3,94\n8,9,3,3,16,4,45,10\n7,51,41\n17,5,37,3,37\n1,99\n1,66,34\n66,16,19\n2,2,19,58,11,2,4,4\n49,40,8,3\n45,21,34\n8,43,41,8\n23,77\n33,13,14,6,27,5,3\n100\n91,8\n3,8,62,15,3,10\n21,79\n99,1\n100\n69,4,1,14,12\n1,80,1,18\n99,1\n22,49,14,14,1\n100\n100\n7,31,13,49\n100\n92,3,5,1\n41,59\n55,45\n56,44\n100\n54,46\n62,35,3\n67,8,25\n82,17\n100\n100\n100\n100\n1,2,2,1,59,13,12,9\n15,66,15,3,1,1\n7,36,45,12\n6,6,68,20\n79,21\n2,2,97\n6,76,5,3,2,8\n100\n100\n100\n37,23,23,2,14\n1,1,80,18\n100\n43,56,1,1\n100\n4,3,4,23,4,4,56,2\n100\n100\n18,3,13,8,5,17,3,13,2,19\n18,8,8,17,16,12,22\n17,1,1,14,2,27,14,2,4,4,4,3,7,1\n9,1,30,5,25,20,1,10\n29,38,29,5\n13,11,3,3,8,21,29,12\n8,4,16,3,2,18,2,46\n5,2,1,1,14,37,35,4,3\n17,12,67,4\n27,12,1,2,58\n5,95\n26,18,49,8\n30,2,56,6,5\n94,1,4,1\n31,69\n1,33,14,7,9,36\n100\n59,4,27,10\n97,3\n100\n3,40,6,49,2\n100\n10,69,11,10\n1,39,9,7,29,13,2\n100\n99,1\n8,1,82,10\n30,70\n100\n100\n100\n1,51,49\n43,57\n100\n1,6,48,26,8,3,6,2\n63,6,31\n1,99\n1,14,17,69\n7,3,29,1,30,8,8,6,8\n1,1,11,4,12,3,4,3,59,2\n100\n1,25,74\n41,12,9,39\n100\n100\n31,2,5,62\n9,22,13,13,42\n42,17,12,19,11\n100\n100\n73,27\n31,68\n24,22,6,10,10,27\n32,59,9\n1,8,1,89,1\n13,10,35,22,11,10\n1,50,49\n3,4,25,30,17,21\n12,7,35,17,28\n4,48,42,6\n27,73\n64,23,14\n76,16,4,5\n6,20,2,7,20,24,10,12\n18,17,10,54\n95,5\n2,14,46,38\n4,11,12,20,20,2,30\n21,3,76\n9,63,16,12\n8,2,10,12,35,7,2,2,5,1,1,15\n61,6,12,17,5\n9,4,65,21,1\n100\n33,47,20\n100\n32,40,27\n100\n100\n28,8,12,8,9,4,3,28\n100\n100\n1,99\n73,1,14,12\n8,15,14,5,5,20,3,30\n65,1,34\n27,45,28\n43,57\n100\n1,99\n1,2,2,4,91\n11,2,2,2,1,83\n9,6,5,13,11,2,54\n2,3,66,1,3,3,2,20\n8,23,7,63\n8,34,49,2,7\n13,4,39,8,1,2,6,25\n36,46,1,17\n2,5,35,2,3,6,2,2,1,3,3,2,4,11,2,12,1,3\n4,7,5,30,10,34,2,5\n100\n100\n4,4,57,35\n2,10,39,37,2,6,4\n2,7,42,2,1,46\n100\n1,5,2,2,28,36,5,3,18\n2,8,90\n15,2,1,3,2,77\n28,2,70\n69,31\n1,35,17,15,32\n34,14,51\n5,42,1,1,5,46\n1,1,97,1\n1,1,1,97\n37,63\n7,23,35,3,26,4\n9,1,63,1,25,1\n25,26,8,41\n41,59\n11,5,9,1,4,42,2,26\n15,2,8,8,10,1,39,14\n45,55\n55,45\n100\n100\n71,6,23\n100\n100\n100\n100\n100\n100\n92,8\n100\n21,71,1,8\n9,91\n100\n20,2,20,11,16,13,4,12,2\n26,35,6,1,22,9\n48,51\n100\n94,4,1,1\n2,9,1,1,3,1,4,42,38\n15,83\n11,6,1,10,68,4\n73,3,5,4,15\n3,1,1,95\n78,1,1,12,1,2,4\n91,7,2\n3,97\n100\n20,80\n4,14,17,3,35,27\n100\n100\n100\n100\n96,4\n91,3,2,1,3\n100\n100\n3,69,28\n4,20,43,32\n35,63,1,1\n27,1,72,1\n100\n17,1,82\n99\n82,18\n79,4,17\n1,14,11,74\n9,17,46,4,12,13\n100\n100\n29,22,50\n25,24,51\n93,7\n81,1,19\n100\n8,2,90\n13,87\n12,14,74\n18,3,79\n5,63,32\n52,47\n47,53\n90,10\n33,1,26,23,12,5\n1,7,11,9,1,72\n30,64,5,1\n15,37,23,26\n65,1,25,1,1,6,1\n13,37,16,13,5,7,8\n100\n68,32,1\n52,48\n53,47\n100\n100\n1,99\n6,2,7,84,2\n42,32,26\n100\n100\n100\n1,3,11,85\n8,92\n100\n9,91\n13,87\n100\n22,7,71\n30,34,3,34\n100\n4,96\n63,2,1,3,1,1,2,2,24\n33,4,2,1,14,45\n41,1,1,4,1,1,1,1,7,2,8,7,5,21\n46,54\n8,8,1,12,72\n77,23\n100\n100\n100\n100\n48,5,3,3,2,2,3,6,10,12,2,4\n36,64\n100\n100\n4,96\n24,76\n89,11\n57,4,2,4,33\n100\n2,12,1,2,28,15,16,21,3\n1,7,1,1,5,1,1,9,24,43,6\n9,13,33,14,6,14,9\n15,3,16,66\n3,1,2,2,1,1,1,1,2,1,4,1,1,1,1,1,1,2,1,1,21,16,34\n10,4,2,2,1,1,2,3,2,1,5,1,1,10,2,4,7,20,19,4\n23,77\n19,28,3,26,6,6,1,1,10\n13,41,39,4,2\n13,5,7,4,70\n25,9,5,60\n51,2,28,19\n54,22,24\n1,4,3,4,4,1,1,1,1,4,3,4,70\n2,1,5,1,1,1,1,1,1,8,8,39,32\n1,21,78,1\n1,1,1,1,1,16,5,12,22,4,1,8,13,13\n9,11,13,9,1,1,1,1,7,1,44\n32,13,2,12,12,30\n7,77,14,2\n8,92\n39,10,14,37\n100\n24,76\n72,28\n2,60,37\n61,11,11,16\n100\n6,60,35\n80,20\n100\n100\n100\n44,50,7\n100\n73,1,7,3,3,11\n66,34\n27,57,5,7,3,1\n38,42,21\n1,28,32,38,1\n59,1,40,1\n75,22,3\n64,1,25,7,4\n82,18\n100\n100\n3,97\n3,10,35,52\n100\n100\n5,95\n15,85\n19,81\n100\n98,2\n100\n85,4,5,1,4\n90,8,2\n11,3,13,73\n1,99\n4,2,94\n7,1,1,90\n100\n3,95\n15,29,56\n28,1,1,71\n48,17,36\n63,4,33\n87,13\n91,9\n1,1,7,1,16,18,58\n1,1,1,9,38,19,32\n22,78\n84,16\n78,4,7,10,1\n1,1,2,55,41\n1,1,2,95\n3,3,13,80\n2,5,1,23,23,30,15\n100\n100\n100\n57,3,2,3,6,1,2,1,5,21\n24,20,4,52\n9,5,14,2,1,1,3,4,29,31\n14,4,3,7,6,3,7,2,4,5,12,5,4,4,3,3,6,5,4\n19,7,7,20,5,22,19\n6,8,1,1,1,50,28,1,5\n100\n13,10,12,43,7,3,2,1,2,2,5\n79,12,1,2,6\n25,74,1\n65,15,17,3\n86,10,3\n79,21\n7,93\n49,51\n34,13,29,8,2,6,1,2,1,3,1\n100\n39,21,2,15,2,1,3,2,4,4,2,3,2,1\n100\n23,16,1,33,1,1,6,12,1,4,1,2\n1,11,9,31,21,1,11,1,1,3,11\n1,3,25,3,15,17,12,5,17,2\n12,4,33,51\n100\n20,14,66\n100\n1,25,34,30,4,1,4\n65,10,7,17\n97,3\n31,29,31,9\n59,16,12,14\n2,2,43,4,5,29,8,7\n58,42\n9,91\n12,1,1,2,24,19,5,11,14,12\n18,14,8,42,1,1,13,1,1,1,1\n45,55\n16,84\n61,1,37\n32,2,2,14,12,1,1,7,2,6,1,19\n19,42,37,1,1\n33,1,1,63,1,1\n1,1,16,29,1,1,1,19,26,1\n7,36,58\n5,12,83\n21,24,9,18,15,10,2,1\n32,68\n11,2,1,84\n3,23,6,15,53\n23,77\n97,3\n30,28,43\n58,21,20\n1,1,13,10,3,8,25,25,2,3,1,1,4,2\n69,31\n23,5,72\n7,93\n39,14,47\n57,43\n34,5,49,1,2,1,8\n12,16,71\n29,9,6,16,40\n38,42,20\n1,4,23,4,67\n33,30,37\n100\n7,4,1,29,36,23\n10,2,10,6,2,5,4,60\n1,4,71,18,7\n70,12,14,3\n11,88\n6,9,22,63\n19,4,1,1,57,18\n11,10,1,49,24,5\n16,13,22,25,23,1\n1,17,19,14,49\n14,86\n100\n33,67\n17,25,15,6,38\n37,31,33\n19,11,3,11,17,39\n21,1,4,74,1\n95,5\n99\n53,47\n58,26,16\n100\n100\n1,36,63\n100\n13,12,1,1,2,11,61\n45,22,33\n100\n7,24,1,16,28,11,14\n100\n100\n100\n2,4,1,42,21,19,11\n12,88\n1,31,29,34,4\n5,23,71\n100\n100\n39,3,3,3,5,47\n3,82,15\n2,2,95\n75,3,2,2,1,1,17\n2,2,5,2,5,5,4,7,69\n100\n60,7,30,2\n15,6,80\n92,8\n50,49\n77,9,5,8\n100\n100\n2,24,74\n100\n100\n100\n80,1,3,15\n100\n2,98\n100\n2,1,12,1,1,4,1,38,13,27\n35,12,12,7,35\n35,5,3,3,33,10,7,4\n32,3,10,6,5,19,7,2,3,5,7\n26,74\n8,20,27,45\n100\n9,66,18,6\n100\n100\n100\n100\n22,3,40,34\n4,5,8,3,28,44,8\n100\n100\n1,99\n3,97\n83,14,3\n43,6,15,2,33\n12,1,57,29\n100\n100\n8,3,2,77,10\n62,8,21,6,2\n3,23,14,1,3,7,42,1,5\n100\n2,98\n2,4,10,1,1,29,11,7,29,7\n96,3\n2,31,67\n100\n93,7\n100\n2,56,11,32\n2,98\n85,15\n100\n1,7,5,1,1,1,3,2,2,1,12,66\n7,6,2,1,3,1,5,4,9,8,27,27\n29,18,50,2,1\n44,9,9,9,30\n29,16,30,25\n77,1,3,8,10,1\n3,2,1,3,1,2,16,1,3,26,41\n7,11,50,1,23,7\n17,2,2,6,72,1\n1,6,11,6,76\n28,62,10\n1,11,1,29,14,23,8,5,8\n2,21,8,4,2,35,28\n6,6,37,13,9,17,12\n11,50,39\n47,20,19,15\n1,2,13,11,11,22,26,14\n35,1,1,1,48,3,4,8\n2,7,23,3,35,29\n7,2,17,35,39\n5,3,11,5,3,4,2,6,20,42\n2,1,1,10,37,4,5,40\n83,9,7,1\n2,1,2,5,28,62\n10,2,4,13,3,6,2,14,46\n25,1,1,1,68,1,3\n23,3,3,8,63\n100\n55,28,5,2,7,2\n1,84,16\n36,64\n11,8,13,4,25,22,17\n51,1,48\n100\n89,11\n86,14\n100\n100\n47,14,15,2,20,2\n3,21,6,32,38\n6,13,6,8,23,43\n37,12,11,12,3,2,3,17,3\n97,1,3\n100\n56,1,16,4,23\n94,6\n1,99\n32,6,59,2,1\n97,2,2\n85,3,6,1,1,1,2,1\n75,8,10,2,4,1,2\n100\n7,90,3\n98,1\n98,2\n35,14,33,5,13\n89,5,6\n54,46,1\n27,63,11\n19,2,4,2,73\n22,2,32,44\n6,31,12,19,31\n2,1,1,3,29,17,1,29,18\n41,41,18\n39,2,1,4,3,10,2,21,17\n3,80,3,3,12\n6,4,69,9,5,3,4\n89,3,3,4\n1,1,4,11,84\n6,2,4,6,44,11,5,9,1,7,5\n11,4,27,20,19,1,1,1,5,11\n37,4,7,2,18,28,2,1\n18,12,3,13,2,3,2,6,10,2,23,2,5\n11,58,26,5\n1,23,51,1,22,1,1\n7,48,45\n45,2,1,5,3,2,4,1,1,9,28\n9,8,27,3,1,52\n29,1,61,4,3,1,1\n15,1,13,71,1\n4,30,66\n87,13\n1,25,35,5,35\n60,40\n16,10,5,53,17\n8,3,68,20\n18,17,59,4,2\n8,75,1,16\n29,1,70\n5,1,11,82,1,1\n55,44\n1,1,45,50,1,1\n55,43,1\n5,2,51,29,12\n85,13,2\n32,32,36\n7,14,18,12,49\n71,1,18,9,1,1\n73,12,15\n6,3,5,2,54,29\n12,3,17,65,3\n37,63\n6,5,1,89\n17,14,69\n37,29,6,16,11,1\n29,6,65\n99\n30,70\n2,98\n24,7,65,4\n2,3,95\n33,67\n10,90\n14,86\n1,2,97\n3,56,41\n22,13,12,52\n5,1,93\n8,1,92\n6,94\n10,90\n1,14,1,85\n100\n12,4,84\n1,4,96\n35,65\n7,10,59,4,10,2,5\n3,16,18,3,44,1,14\n36,64\n44,37,20\n18,82\n99\n7,93\n10,82,2,2,4\n14,2,3,81,1\n9,2,1,4,1,2,3,78\n2,3,4,8,84\n77,23\n66,1,1,33\n68,32\n98,1,2\n84,8,2,6\n59,30,11\n3,2,48,13,3,14,17\n34,1,18,47\n95,5\n30,33,8,8,20,1,1\n9,22,68\n1,3,96\n100\n100\n7,4,3,19,67\n47,42,11\n37,2,49,12\n55,45\n100\n47,3,1,1,3,4,4,1,36\n18,26,11,2,6,1,37\n100\n1,99\n84,16\n100\n30,39,8,2,1,20\n9,2,81,3,5\n98,1,1\n68,32\n59,33,9\n85,7,2,1,3,1,2\n100\n1,99\n30,26,22,22\n1,2,3,94\n13,39,5,43\n47,10,21,21\n42,58\n100\n3,97\n1,2,1,94,2\n13,2,19,9,12,4,14,12,16\n4,2,1,2,14,6,57,15\n20,11,4,20,15,6,23\n5,3,2,90\n5,95\n1,1,62,36\n55,45\n100\n3,97\n7,93\n3,5,2,90\n4,73,23\n3,81,16\n63,35,1,1\n1,56,23,19\n97,1,2\n94,2,4\n57,43\n100\n1,1,99\n54,2,43\n56,44\n63,1,29,7\n9,59,7,7,18\n85,6,9\n86,3,10,1\n79,3,18\n92,4,4\n74,25\n32,7,61\n26,9,65\n99\n8,6,4,82\n54,19,21,6\n18,38,44\n46,25,29\n17,1,40,42\n27,13,14,45\n72,28\n93,3,1,3\n92,1,6\n12,4,15,20,17,16,16\n62,34,4\n1,99,1\n68,1,13,18\n12,12,34,1,12,28\n3,6,4,44,7,36\n42,58\n3,47,50\n31,68,1\n17,38,45\n49,51\n94,6\n3,8,2,87\n18,44,28,10\n4,96\n5,15,79\n22,2,76\n52,28,20\n2,98\n10,88,1\n49,51\n20,20,60\n14,10,4,14,1,58\n48,52\n10,89,1\n1,55,5,32,7\n25,5,70\n3,97\n2,98\n92,8\n30,17,35,3,5,3,7\n6,2,57,17,9,9\n10,31,25,10,20,4\n8,14,78\n37,10,8,20,25\n46,3,22,28\n54,46\n26,43,32\n1,50,4,13,7,7,19\n8,92\n1,2,38,59\n100\n2,19,12,8,12,5,14,4,10,13,2\n8,2,3,6,2,2,6,11,21,9,5,1,1,2,3,8,2,9\n49,4,37,10\n38,63\n8,2,4,1,39,1,3,2,7,8,26\n2,7,11,14,12,3,1,15,9,4,14,6,2\n51,49\n34,66\n100\n10,47,34,9\n26,8,7,22,21,3,3,8,3\n7,9,41,8,33,1,1\n1,1,1,22,74,1\n5,2,3,22,36,2,2,16,4,6,1\n100\n5,89,5\n15,1,6,15,34,30\n56,1,1,40,1\n100\n100\n12,13,7,11,9,2,7,39\n100\n95,5\n54,14,32\n100\n15,24,60,1\n38,61\n98,2\n34,3,62\n100\n9,6,32,22,22,1,9\n100\n100\n100\n100\n100\n10,13,27,34,16\n95,1,4\n5,95\n22,18,40,19\n100\n100\n21,20,60\n24,76\n15,2,83\n100\n20,80\n23,1,76\n100\n97,3\n100\n99\n1,36,63\n1,1,98\n9,80,11\n17,19,64\n100\n100\n68,16,1,15\n97,3\n100\n100\n100\n100\n6,28,65\n37,36,27\n28,72\n46,10,31,3,4,4,2,1\n91,9\n100\n97,2\n43,4,2,51\n7,30,12,4,46\n47,37,4,10,3\n29,38,14,1,2,6,8,1,1\n19,15,19,47\n54,45\n100\n100\n100\n100\n55,38,6,1\n98,1,1,1\n8,29,1,28,33,1\n1,33,3,2,2,50,7\n2,11,24,23,40\n16,1,4,70,5,5,1\n2,12,37,13,5,13,12,1,6\n5,60,1,1,3,3,7,14,3,4\n1,4,7,2,4,5,23,7,16,4,13,11,3\n8,2,1,89\n2,27,17,15,19,20\n1,1,18,33,1,1,1,11,13,10,6,4\n5,14,8,55,11,7\n1,5,3,8,55,27\n15,30,55\n10,7,17,6,5,11,1,19,10,5,8\n8,13,20,59\n66,34\n9,4,6,69,11\n99,1\n92,8\n6,47,3,6,39\n1,53,1,46\n1,23,1,1,57,19\n3,50,6,1,41\n3,36,22,1,1,2,6,29\n33,7,1,1,3,3,1,33,4,14\n21,19,29,18,7,7\n2,98\n100\n36,19,13,7,6,1,1,19\n31,24,44\n22,77\n54,46\n57,43\n54,46\n59,41\n1,99\n21,79\n100\n8,2,3,5,19,5,58\n26,21,10,21,9,4,3,6\n72,28\n52,48\n73,27\n6,7,2,8,77\n78,2,2,1,1,8,9\n74,6,1,1,1,1,2,1,4,2,2,4,1\n91,1,7\n75,1,1,2,20\n1,3,1,62,9,20,5\n48,45,6,1\n93,2,2,1,1\n98,2,1\n51,1,48\n100\n15,85\n51,11,1,37\n36,41,1,23\n73,27\n100\n63,7,16,14\n45,55\n16,13,11,59\n93,7\n18,82\n100\n12,13,76\n100\n100\n61,39\n3,12,11,2,72\n17,27,1,33,13,10\n72,5,3,13,6\n1,4,57,37\n81,2,6,3,4,4,1\n75,25\n14,28,29,29\n100\n2,79,19\n4,6,5,4,81\n8,6,70,17\n7,7,11,1,24,1,1,48\n1,35,36,28,1\n58,19,23\n51,49\n100\n2,73,25\n100\n8,25,30,32,5\n50,25,25\n85,5,1,3,3,3\n27,11,12,43,2,5\n30,4,6,13,8,10,1,1,6,2,5,11,2\n83,1,3,13\n92,2,6\n85,7,2,6\n16,43,40\n100\n3,23,6,7,2,5,5,49\n1,1,87,11\n4,15,3,10,68\n52,48\n5,39,10,30,15\n4,1,43,7,7,38\n2,1,15,29,2,2,1,17,30\n5,6,2,5,10,6,10,2,21,19,14\n18,82\n18,2,81\n19,36,45\n21,1,1,26,52\n8,67,2,1,5,16,1\n4,86,9\n1,3,2,1,14,26,2,5,38,6,3\n3,15,17,1,8,51,4\n4,87,3,3,2\n5,90,1,4\n1,10,84,1,4\n9,32,2,7,49\n58,2,40\n9,11,80\n48,52\n1,17,18,5,8,50\n24,58,18\n12,57,5,6,19\n50,18,31\n10,90\n1,99\n100\n90,7,3\n21,78\n28,39,11,11,5,5,2\n100\n96,2,2\n35,38,26\n52,4,44\n3,16,10,11,20,17,21,1\n63,8,8,20\n11,6,1,6,23,12,40\n12,1,7,43,18,19\n8,4,32,25,32\n58,42\n40,23,10,27\n16,35,42,7\n54,39,7\n43,32,24\n18,21,2,3,7,50\n21,79\n50,13,13,18,6\n43,32,12,13\n37,6,33,24\n3,97\n2,5,91,3\n13,24,14,22,27\n7,9,8,46,29\n100\n89,4,3,4\n6,94\n7,10,36,12,20,12,2\n20,6,7,4,4,8,21,29\n95,2,3\n24,27,30,1,1,16,1\n50,38,12\n40,42,9,1,1,2,1,5\n7,58,9,26\n4,86,9\n90,10\n100\n29,71\n21,17,6,56\n100\n28,25,47\n100\n99,1\n10,3,87\n68,6,26\n4,25,7,62,2\n35,2,2,13,48\n52,3,3,3,1,1,37\n31,61,8\n3,63,33\n3,2,26,68\n7,93\n30,34,35\n37,63\n9,91\n28,1,1,1,28,41\n18,19,7,27,7,23\n6,62,21,11\n100\n2,98\n34,9,3,12,41\n10,1,1,1,1,88\n43,44,8,5\n17,13,2,68\n12,11,1,6,59,10\n39,2,59\n13,10,12,2,24,9,11,7,10,1\n8,4,6,3,4,7,9,8,4,4,4,6,9,22,1\n1,3,1,1,1,94\n96,4\n79,3,9,8\n20,80\n19,20,21,41\n9,4,14,5,65,3\n8,68,4,20,1\n7,27,2,35,30\n100\n98,2\n100\n6,8,13,19,3,13,38\n6,5,7,16,14,30,1,9,12\n100\n100\n100\n1,11,6,6,14,8,20,34\n100\n52,48\n6,24,10,11,8,3,18,20\n99,1\n7,42,52\n15,55,30\n8,61,26,5\n100\n100\n23,5,2,32,39\n1,25,17,57\n100\n100\n1,74,25\n63,37\n42,58\n75,4,21\n13,88\n1,4,95\n1,60,6,34\n100\n40,4,43,10,3\n30,26,43,1\n41,12,9,34,4\n7,5,4,3,8,6,10,1,1,2,17,35\n69,3,9,10,6,3\n67,33\n23,37,22,18\n3,97\n19,6,29,2,1,3,21,8,3,4,5\n83,10,2,2,3,1\n100\n26,14,10,50\n14,37,15,6,27\n100\n62,9,29\n69,10,4,5,7,5\n99,1\n100\n100\n100\n100\n100\n99,1\n39,61\n76,24\n77,23\n13,49,38\n93,6,1\n67,33\n97,3\n2,98\n100\n100\n100\n100\n3,9,14,3,61,4,1,1,4\n28,55,17\n4,4,91,1\n3,1,1,3,21,8,4,21,5,3,6,1,12,11\n8,6,21,33,32\n51,49\n4,2,94\n10,19,13,57\n88,12\n98,2\n100\n14,3,1,1,1,1,1,4,1,5,1,6,60\n28,3,7,1,2,1,57\n9,89,3\n28,17,13,1,13,27\n5,95\n97,1,2\n100\n100\n1,33,40,9,16,1,1\n10,1,23,4,1,29,11,19,3\n1,5,31,19,12,31,2\n100\n34,3,12,5,3,2,8,4,26,3\n27,4,10,29,26,3,1\n76,21,3\n37,10,24,9,9,2,5,5\n61,16,15,4,4\n100\n89,11\n12,37,13,37\n100\n38,58,4,1\n58,9,33\n6,26,14,8,6,10,3,2,2,7,2,1,1,3,5,4\n4,84,12\n83,17\n41,28,2,11,19\n8,26,66\n1,7,11,22,5,1,34,12,2,3,1\n2,1,28,6,12,11,40\n2,4,7,84,2\n35,7,24,33\n100\n10,58,32\n16,61,11,3,4,4\n11,41,42,5\n100\n2,2,8,20,9,59\n2,4,4,11,43,36\n11,1,2,2,85\n100\n85,15\n1,5,4,3,77,10\n99,1\n100\n100\n3,32,19,7,14,25\n9,7,3,7,1,1,16,21,10,25\n42,13,16,7,21,1\n10,3,59,14,14\n16,4,8,72\n19,18,54,9\n16,16,4,10,7,3,2,4,23,7,2,4\n5,23,14,14,27,5,13\n86,14\n100\n19,4,77\n21,28,5,34,12\n100\n14,86\n7,92,1\n42,5,1,51\n72,28\n18,82\n100\n1,41,10,32,6,10\n8,29,1,18,2,17,25\n2,17,15,22,4,2,4,6,4,2,18,3\n92,2,6\n42,15,27,12,3\n95,5\n72,28\n100\n4,96\n100\n100\n2,98\n3,22,8,67\n1,1,15,13,3,4,14,49\n13,3,80,2,2\n1,99\n71,6,13,10\n4,91,6\n100\n100\n9,18,9,29,35,1,1\n8,17,11,11,53\n1,99\n22,78\n100\n2,20,26,30,5,4,13\n28,72\n100\n60,8,1,30\n46,5,6,1,7,13,23\n3,1,96\n100\n54,21,7,9,10\n24,10,13,5,3,15,7,11,12\n1,5,93\n5,55,39\n100\n57,9,34\n71,29\n11,44,12,33\n99,1\n1,26,24,8,41\n15,13,21,24,27\n100\n100\n100\n22,22,37,20\n11,55,30,3\n100\n9,17,1,35,30,8\n100\n7,34,13,1,7,38\n98,2\n100\n56,27,16\n19,81\n100\n100\n100\n100\n43,29,26,1,1\n4,1,27,19,49\n7,34,49,10\n8,92\n16,84\n3,98\n46,54\n5,95\n100\n79,21\n100\n65,8,1,26,1\n19,9,12,60\n12,1,16,5,1,4,63\n100\n100\n100\n1,99\n5,20,75\n25,2,72\n78,22\n69,16,9,5\n64,36\n59,5,1,3,5,27\n83,17\n55,5,40\n73,27\n63,2,3,32\n10,35,5,14,17,17\n1,1,9,2,19,1,1,3,10,6,5,38,1,5\n1,1,1,1,18,17,1,24,3,8,9,3,2,10\n43,57\n55,8,14,8,15\n84,2,14\n1,34,64,1\n100\n100\n100\n72,14,14\n100\n3,22,12,1,62\n100\n17,5,1,1,7,70\n100\n50,19,26,5\n76,24\n21,10,40,27,1,1\n33,46,13,8\n100\n26,73,1\n100\n100\n86,13\n19,12,5,39,12,12\n1,1,93,1,5,1\n81,19\n1,30,70\n31,8,50,11\n20,80\n100\n100\n100\n15,38,47\n100\n15,40,45\n9,91\n100\n100\n100\n100\n100\n100\n5,80,14\n1,10,19,4,1,17,42,1,6\n65,32,2\n8,4,12,52,4,19,1\n100\n1,5,21,4,1,38,31\n100\n4,73,23\n100\n90,1,5,3\n17,6,2,52,11,11\n100\n100\n100\n3,4,7,74,12\n100\n69,31\n22,78\n57,41,1,1\n4,6,58,20,3,5,4\n100\n100\n4,77,19\n2,4,3,1,5,3,63,18\n46,2,1,51\n100\n100\n2,6,2,89\n31,4,22,2,2,5,1,1,30\n27,21,5,2,4,3,2,16,19\n35,15,17,19,1,1,2,9,1,1\n91,3,2,1,3\n1,8,17,10,65\n29,2,27,42\n2,6,4,18,8,51,2,9\n10,5,34,52\n74,5,3,6,1,1,1,1,1,1,1,2,1\n40,1,2,1,2,3,2,42,1,6\n24,76\n90,3,4,2\n79,11,11\n14,86\n1,99\n91,1,3,5\n5,5,89\n100\n100\n7,39,53\n79,21\n100\n100\n97,3\n100\n3,97\n24,70,6\n100\n100\n53,1,3,19,24\n88,12\n78,22\n100\n100\n41,9,50\n59,40,1\n100\n71,15,13\n100\n100\n100\n53,6,6,34\n13,4,6,13,56,7\n56,34,2,2,1,5\n5,58,6,30\n74,26\n100\n38,22,7,32,1\n3,48,50\n100\n41,10,49\n2,98\n76,24\n99,1\n82,10,8\n100\n100\n14,28,1,8,24,25\n100\n6,1,15,15,1,7,2,21,26,6\n11,49,40\n4,1,94,1\n56,19,2,9,13\n2,1,36,62\n13,87\n1,81,19\n45,55\n51,29,19\n100\n6,94\n71,1,6,6,5,5,6,1\n100\n18,65,8,3,2,4\n1,1,18,1,33,19,20,1,6\n100\n100\n24,76\n11,49,40\n5,25,3,2,2,13,5,34,11\n100\n9,5,86\n4,17,77,1\n45,50,4,1,1\n100\n33,55,12\n55,45\n100\n100\n15,85\n4,8,49,40\n43,16,2,24,2,6,7,1\n4,56,2,4,32,1\n2,8,11,80\n5,95\n66,29,5\n2,31,10,57\n13,87\n100\n2,18,4,2,73\n100\n4,92,2,2\n8,6,4,4,1,77\n69,31\n32,68\n12,1,31,4,51\n100\n3,97\n17,83\n100\n91,5,5\n7,9,1,18,66\n21,79\n1,4,67,29\n89,7,1,1,1,1,2,1\n1,43,21,2,17,2,15\n100\n82,14,5\n15,26,34,25\n100\n100\n2,97\n1,9,1,7,62,20\n91,7,1\n1,1,1,23,73,1,1\n2,4,90,5\n12,11,6,2,3,2,45,3,16\n11,2,10,11,39,27\n100\n100\n100\n28,18,2,1,17,33\n21,35,23,4,16\n23,77\n46,15,3,6,14,13,2\n37,18,46\n99\n18,4,4,6,10,13,45\n96,4\n44,38,10,8\n13,3,59,25\n3,2,39,57\n80,20\n79,21\n20,35,4,4,5,6,5,13,6\n5,91,4\n95,3,1\n1,1,2,1,64,32\n100\n88,2,3,2,6\n68,13,18\n14,16,70\n91,9\n100\n5,22,72\n10,90\n46,41,14\n83,2,3,11,1\n16,36,22,9,17\n25,11,20,22,22\n37,23,22,1,10,8\n55,2,1,1,1,2,29,5,5\n4,36,21,34,2,4\n50,49\n96,2,2\n93,2,3,2\n99\n93,7\n3,1,95\n19,12,62,3,4\n6,1,4,1,2,28,20,4,32,1,1,1\n7,3,25,63,1,1\n16,7,10,7,13,47\n41,8,50\n1,3,54,42\n1,58,9,31\n2,47,51\n2,34,8,10,46\n1,4,1,2,58,1,16,8,11\n9,64,23,3\n32,6,3,19,15,2,2,13,6,3\n1,4,15,29,14,11,4,2,2,9,1,1,2,1,1,3\n27,3,8,15,10,5,14,6,10,2\n46,3,25,3,6,9,1,3,3\n71,17,13\n27,18,25,24,5\n3,3,19,5,51,18,1\n2,25,26,7,38,2\n88,12\n52,44,5\n26,5,4,54,11\n3,8,4,16,12,24,5,27\n26,5,8,27,34,1\n5,80,1,13,1\n56,8,36\n73,1,6,20\n39,36,22,1,1,1,1,1\n100\n97,3\n81,12,3,3\n27,6,22,30,14\n1,99,1\n19,81\n49,51\n5,95\n4,5,2,88\n2,77,20\n35,32,29,4\n24,76\n17,4,3,76\n1,99\n7,93\n9,91\n99,1\n100\n100\n3,97\n47,49,4\n1,1,9,90\n8,8,76,1,8\n6,49,1,31,4,1,8\n49,5,46\n50,2,49\n4,42,54\n19,3,21,56\n40,13,47\n17,6,6,7,13,50\n56,44\n1,99\n22,30,8,40\n1,5,1,70,24\n10,61,27,1,2\n7,69,22,2\n1,99\n50,26,24\n47,2,28,2,21\n30,65,2,1\n1,6,22,21,14,36\n100\n32,41,26\n33,46,1,20\n100\n96,3\n42,54,1,2,1\n64,1,26,9\n69,25,1,5\n100\n100\n20,53,7,6,14\n21,79\n19,3,41,37\n29,71\n100\n57,43\n91,9\n100\n100\n100\n31,69\n74,26\n100\n94,2,2\n1,79,20,1\n96,4\n100\n51,2,47\n50,1,2,47\n80,19,1\n43,7,46,3,1\n44,16,13,27\n12,13,10,35,29\n19,21,60\n45,23,33\n26,74\n3,9,23,36,28\n60,40\n69,31\n1,1,1,1,20,8,3,38,25\n1,2,1,2,7,2,85\n10,2,21,49,17\n30,27,1,8,1,21,5,8\n5,95\n55,20,24\n1,1,1,5,1,1,1,1,70,19\n13,87\n35,28,23,6,2,4,2\n1,12,57,18,1,8,2\n5,8,16,4,59,8\n7,24,22,47\n95,4\n27,6,6,7,4,50\n7,9,35,7,21,17,4,1\n1,99\n1,10,1,1,48,1,1,36\n2,2,8,2,2,83,2\n7,1,92,1\n1,99\n34,14,2,5,45\n76,24\n77,23\n5,3,9,83\n100\n100\n15,50,6,5,16,9\n4,96\n5,33,37,26\n79,21\n100\n36,40,24\n38,62\n44,5,29,22\n19,4,28,17,32\n3,61,12,23\n2,66,32\n8,10,3,4,75\n2,3,2,4,2,74,12\n86,14\n6,73,7,14\n100\n22,78\n1,88,7,4\n100\n2,85,12,1\n18,17,16,3,2,26,1,17\n100\n79,21\n71,29\n23,77\n21,42,37\n33,60,6\n100\n72,22,4,1\n74,26\n74,7,19\n100\n45,25,30\n100\n16,82,3\n3,19,38,14,4,10,12\n1,57,7,12,22\n4,96\n100\n99,1\n2,12,36,28,12,2,1,1,6\n5,18,16,61\n51,4,6,2,2,31,4\n7,5,69,15,4\n1,2,1,1,34,40,20\n14,66,20\n1,3,7,2,87\n2,6,92\n7,3,2,5,3,40,10,30\n95,4,1\n11,3,55,31\n40,51,2,8\n18,24,58\n22,78\n9,91\n2,2,12,29,55\n3,3,94\n7,4,74,14\n100\n82,3,14\n6,53,15,22,3,1\n1,43,31,21,5\n6,2,92\n2,98\n2,98\n100\n5,72,23\n3,1,18,61,16,1\n28,20,50,2\n16,21,63\n27,9,41,6,16\n35,65\n70,6,2,3,16,3\n72,6,4,1,3,3,11\n20,20,1,58\n100\n100\n1,36,39,24\n4,33,51,12\n100\n94,6\n1,1,14,7,5,12,6,8,44,3\n34,2,30,4,8,6,7,9\n2,4,5,89\n98,2\n41,41,17\n12,13,5,61,6,3\n100\n100\n1,7,48,6,4,33,1\n60,5,1,2,1,31,1\n91,9\n70,30\n61,9,1,29\n81,19\n5,20,5,70\n100\n75,25\n72,27,1\n100\n100\n3,3,1,4,3,2,84\n100\n8,21,72\n8,3,45,44\n8,9,82\n26,20,12,7,30,6\n46,5,49\n100\n100\n100\n1,1,1,1,84,11,1\n10,67,2,19,2\n2,86,6,5\n1,2,83,14\n35,65\n31,69\n78,22\n20,21,19,9,30\n75,20,6\n89,10\n100\n26,1,1,73\n59,34,1,1,4,1\n32,1,67\n12,5,77,3,3\n1,94,5\n1,6,10,84\n100\n9,91\n1,1,22,28,8,4,9,1,27\n1,8,1,1,9,62,1,17,1\n3,3,5,76,3,6,4\n5,13,5,35,7,29,5\n1,99\n10,89\n88,12\n96,4\n95,5\n27,1,16,55,1\n15,1,1,83\n1,1,8,7,3,5,2,10,5,6,10,7,3,31\n1,8,2,12,2,3,63,4,1,4\n9,4,1,1,26,7,13,6,34\n1,6,67,9,8,10\n4,82,6,8\n4,1,2,4,51,38\n31,69\n32,43,25\n29,38,33\n28,72\n46,17,31,6\n99,1\n100\n1,28,71\n5,11,8,76\n11,8,11,5,10,13,12,18,12\n4,2,22,45,2,14,9\n24,8,7,56,4\n40,60\n1,2,53,19,24\n1,2,69,14,14\n99,1\n1,1,98\n1,71,2,26\n55,11,4,29\n2,42,48,2,7\n8,1,63,5,6,14,1,1\n60,30,11\n30,46,23\n22,13,6,23,35,1\n10,9,5,2,3,72\n1,6,1,1,2,1,4,86\n1,1,53,46\n1,3,58,38\n3,33,24,20,20\n1,39,60\n10,18,21,1,34,17\n1,1,34,1,1,2,9,5,48\n51,12,1,3,29,4\n90,10\n8,8,30,15,7,2,5,25\n100\n100\n15,4,80\n100\n77,23\n100\n100\n64,5,15,16\n57,43\n100\n57,43\n97,3\n84,4,2,3,6\n100\n5,94,1\n8,91,1\n14,5,18,8,13,40,3\n85,15\n1,85,7,1,4,1\n68,26,3,1,1\n19,22,19,5,2,8,4,3,17\n14,1,9,3,5,29,1,7,24,8\n1,1,77,1,13,7,1\n56,1,32,11\n23,76\n5,68,3,3,10,9\n98,2\n100\n28,31,40,1\n42,23,18,17\n19,25,2,23,31\n100\n74,18,8\n8,10,75,7\n100\n100\n100\n100\n100\n53,47\n35,1,65\n47,53\n100\n100\n100\n14,86\n29,11,19,8,13,20\n63,37\n48,4,48\n22,21,57\n100\n50,50\n78,22\n10,8,82\n100\n100\n1,2,6,2,1,4,1,7,16,58,1\n53,14,22,11\n25,75\n84,6,4,5\n4,13,83\n52,48\n24,76\n92,8\n98,2\n100\n9,9,21,20,41\n52,48\n100\n100\n2,98\n37,63\n100\n79,7,5,1,1,4,1,1,1,1\n22,31,43,4\n100\n94,5,1\n8,14,19,32,26\n57,2,2,5,4,6,1,11,13\n3,34,27,36\n100\n16,17,67\n99,1\n100\n100\n100\n100\n100\n100\n100\n100\n12,87,1\n26,18,27,9,3,18\n2,98\n12,88\n1,3,94,1,1\n5,95\n75,25\n100\n99,1\n100\n56,17,27\n30,1,1,69\n82,18\n44,9,2,3,18,25\n16,35,49\n100\n15,71,14\n6,37,54,2,1\n6,3,13,24,53\n35,64\n10,61,29\n100\n99,1\n100\n6,3,2,10,6,1,7,3,2,2,10,8,25,5,3,8\n2,1,1,23,3,15,55\n100\n1,10,1,56,29,1\n19,25,2,2,4,3,14,2,12,16\n9,91\n1,53,3,16,27\n1,34,2,2,8,3,51\n21,77,2\n79,6,15\n100\n78,3,19\n9,34,54,3\n28,72\n14,11,9,65\n100\n11,79,11\n9,91\n100\n31,22,7,22,17,1\n25,73,2\n1,79,21\n45,55\n39,5,2,54\n67,33\n100\n100\n49,48,2,1\n100\n91,9\n100\n39,1,6,3,7,28,16\n11,1,14,2,73\n83,17\n100\n100\n16,25,11,32,1,1,1,8,1,4\n1,1,4,6,3,3,3,1,1,1,18,15,19,8,15,1\n96,1,3\n100\n100\n100\n100\n100\n8,62,31\n100\n91,3,3,3,2\n41,4,6,6,16,24,4\n8,4,14,75\n20,68,5,5,1,1,1\n100\n100\n83,15,2\n1,8,2,9,75,5\n100\n86,5,9\n6,6,18,10,17,1,1,31,10\n1,78,21\n90,2,8\n34,29,1,9,7,20\n100\n57,2,1,40\n78,11,1,9\n100\n19,81\n11,11,13,17,7,5,4,28,5,1\n5,19,15,21,28,11\n3,6,5,1,23,12,2,37,10\n1,1,38,59,1\n100\n3,2,95\n46,50,3\n20,55,9,12,3\n13,27,8,23,27,1,1\n100\n100\n100\n12,28,60\n43,57\n93,4,4\n39,51,10\n100\n65,33,2\n100\n71,1,7,12,9\n5,59,36\n3,6,6,17,68\n44,56\n27,16,3,3,47,3,2\n58,14,6,4,3,3,4,9\n1,1,1,96,1\n55,25,20\n63,2,20,10,5\n52,37,4,4,4\n14,66,13,7\n13,18,8,55,6,1\n1,43,43,2,1,1,1,8\n58,25,1,17\n10,44,13,32\n100\n100\n100\n6,9,85\n100\n57,43\n1,32,67\n33,9,1,8,38,2,7\n3,9,8,33,1,6,6,3,8,23\n5,6,4,19,17,27,20,2\n2,39,19,33,7\n100\n2,71,5,8,13\n13,38,48\n67,19,14\n2,67,16,14\n58,2,1,7,32\n40,5,55\n29,31,33,4,3\n46,54\n42,58\n29,25,46\n51,19,31\n2,7,4,2,1,17,23,32,11\n15,2,47,1,5,3,5,5,16\n59,3,37\n55,42,3\n2,33,5,56,4\n49,51\n63,21,16\n8,11,5,22,4,3,2,22,1,23,1\n10,3,45,33,10\n37,19,24,20\n1,51,1,3,1,1,8,2,33\n48,22,19,11\n46,37,17\n4,52,44\n100\n89,11\n18,82\n40,17,18,3,21,1\n5,3,92\n15,1,51,33\n27,23,50\n1,62,37\n51,49\n65,2,2,27,2,2\n33,42,15,10\n41,1,1,1,32,7,1,6,1,3,8\n10,13,14,22,41\n72,28\n38,62\n3,3,4,4,1,5,5,2,3,10,4,4,6,4,3,34,6\n38,62\n23,1,1,2,1,4,1,1,1,2,5,2,55\n82,5,11,1\n26,74\n35,21,4,29,10\n3,6,9,6,4,53,20\n75,25\n71,29\n95,1,4\n41,7,2,9,3,6,31\n100\n66,9,1,4,20\n1,1,5,15,15,9,16,3,1,34\n100\n100\n40,7,18,5,1,2,8,2,6,10,1\n34,31,1,1,2,1,8,6,1,8,4,1\n45,32,1,1,1,1,1,2,3,6,7\n8,32,20,28,6,6\n1,1,90,8\n12,10,11,17,5,5,17,23\n29,15,12,43\n91,1,1,4,1,1,3,1\n78,2,12,5,2\n33,67\n100\n100\n4,96\n100\n6,38,25,31\n100\n71,13,16\n11,30,59\n5,52,2,12,30\n13,2,85\n7,3,1,17,6,21,10,35\n100\n4,2,3,4,87\n100\n100\n5,3,8,7,2,3,1,3,54,3,11\n7,5,8,1,1,4,3,2,27,29,13\n69,10,4,1,10,6\n71,21,1,6,1\n39,50,10,1\n9,17,13,5,24,32\n5,5,1,5,21,27,36\n34,66\n5,95\n100\n25,37,2,1,36\n1,99\n47,30,23\n100\n11,13,8,14,35,19\n51,4,45\n100\n33,67\n100\n7,11,6,29,41,5\n18,73,1,8,1\n100\n48,2,51\n100\n9,44,47\n68,1,16,8,7\n19,53,1,13,14\n5,3,42,34,16\n100\n47,15,21,2,15\n19,29,52\n21,5,1,1,1,4,4,62\n7,20,1,72\n33,2,4,61\n50,50\n36,6,6,23,30\n54,45\n27,2,1,2,2,3,1,2,4,2,1,1,50\n36,3,9,1,1,1,15,1,7,25\n1,39,2,4,1,5,33,1,3,2,8\n4,13,4,8,10,12,32,4,2,7,4\n73,27\n24,76\n60,20,17,4\n71,5,1,1,21\n56,41,1,3\n47,40,12\n63,4,6,1,2,15,1,2,4,1\n20,16,22,42\n67,33\n87,13\n68,1,15,11,6\n81,13,6,1\n31,12,8,43,4\n20,14,26,1,1,1,1,7,2,2,3,17,3,3\n100\n2,22,18,1,53,3\n4,3,5,16,12,1,4,39,8,8\n13,43,1,30,13,1\n1,6,17,38,1,37\n1,15,84\n3,35,62\n60,39\n12,76,12\n100\n100\n91,9\n92,8\n74,19,6\n93,7\n100\n100\n38,2,11,10,39\n5,7,87\n7,30,44,8,11\n3,97\n71,20,10\n79,21\n100\n100\n13,87\n97,1,2\n100\n42,57\n15,2,83\n100\n32,68\n31,61,8\n27,9,13,2,6,42\n74,1,7,17\n31,69\n100\n100\n4,96\n100\n33,10,9,19,5,12,5,8\n7,6,16,3,3,6,13,20,25\n100\n3,97\n100\n100\n100\n5,4,1,74,6,9\n92,4,4\n22,78\n77,12,12\n100\n100\n100\n100\n3,3,10,1,2,4,1,3,1,8,2,8,12,41\n77,8,3,11\n100\n100\n98,2\n37,63\n93,7\n100\n100\n85,8,7\n1,1,37,7,5,2,47\n15,85\n36,17,19,21,7\n100\n100\n12,19,26,12,5,11,11,6\n20,7,36,1,4,17,5,8,1\n32,6,6,16,20,4,2,2,10\n61,2,2,3,2,31\n96,4\n58,42\n81,19\n62,38\n53,15,20,13\n1,1,51,23,19,5\n100\n15,52,33\n6,49,44\n100\n100\n25,75\n12,10,9,66,2\n14,15,72\n33,67\n32,47,21\n1,99\n50,50\n39,30,32\n62,7,31\n61,1,7,25,1,5\n100\n34,66\n5,4,91\n4,6,1,89\n2,5,63,30\n76,24\n48,31,1,1,1,18\n100\n4,1,2,15,14,64\n22,24,54\n72,22,3,2\n59,16,24\n1,3,78,18\n8,3,6,2,12,10,1,1,1,5,2,3,20,9,16\n16,5,14,12,13,15,3,5,10,2,2\n100\n1,2,5,1,1,76,14\n100\n100\n100\n100\n100\n100\n67,33\n72,7,4,16\n100\n100\n100\n100\n17,23,60\n30,48,22\n100\n100\n100\n95,5\n1,1,17,80\n100\n100\n54,45\n88,5,5,1\n100\n100\n4,96\n100\n15,85\n78,13,5,4\n30,70\n100\n48,45,7\n100\n100\n28,22,50\n32,56,11\n100\n53,9,5,3,11,9,6,4\n50,50\n59,9,9,2,14,6,1\n37,63\n21,1,10,4,40,8,1,1,1,1,11,2\n45,36,5,11,1,1,1\n75,25\n37,9,9,9,34,2,1\n26,7,6,59,1,1\n78,19,3\n30,15,22,32\n24,24,52\n14,39,47\n100\n76,24\n78,1,21\n42,17,5,9,27\n4,1,96\n5,93,2\n36,8,5,5,1,3,13,14,14\n1,1,28,47,22\n100\n100\n67,3,1,1,2,3,4,7,5,7\n69,4,2,26\n100\n95,5\n100\n100\n100\n38,7,8,34,5,8\n73,1,1,1,3,9,6,5\n3,4,93\n7,93\n6,10,12,8,62\n28,68,3\n6,18,1,1,2,1,1,8,10,52\n100\n100\n3,97\n92,8\n2,1,3,7,38,48\n92,8\n36,3,3,15,2,41\n2,43,20,33\n45,13,5,15,22\n15,22,2,1,2,1,54,1\n7,2,25,1,66\n3,41,24,12,20\n3,1,39,3,26,12,17\n61,22,1,17\n1,2,1,4,77,3,12\n4,58,38\n4,8,34,54\n17,21,21,31,9,1\n100\n86,2,3,1,8\n100\n100\n75,3,1,3,1,1,4,13\n25,41,5,8,20\n100\n100\n41,3,56\n24,3,2,16,7,4,42\n12,4,40,26,9,8\n26,9,5,1,6,18,14,21\n7,2,3,17,11,2,1,2,36,17\n1,1,15,3,15,36,1,8,19\n18,70,6,6\n94,2,4\n29,5,43,15,7\n100\n6,7,1,1,1,13,71\n9,91\n95,1,4,1\n87,13\n97,3\n100\n99,1\n100\n6,94\n5,7,70,18\n8,46,19,26\n90,10\n65,22,13\n71,17,12\n10,10,80\n21,25,3,51\n54,3,43\n60,40\n100\n15,6,1,11,10,1,56\n77,23\n75,25\n3,78,19\n26,26,21,20,8\n9,54,37\n22,21,19,38\n21,79\n100\n82,4,14\n52,23,14,11\n100\n81,19\n100\n69,16,15\n40,54,6\n99,1\n100,1\n100\n70,29,1\n8,16,16,60\n2,98\n15,4,18,63\n100\n21,12,67\n93,7\n31,16,54\n100\n100\n90,10\n34,20,36,10\n100\n1,63,7,11,18\n34,39,27\n3,11,5,31,16,35\n97,3\n100\n100\n100\n8,3,5,13,22,15,10,22\n69,31\n2,74,24\n9,90\n19,81\n96,4\n6,2,3,33,57\n81,7,11\n29,71\n100\n95,5\n15,84\n1,36,9,3,18,22,10,1\n100\n83,17\n28,3,6,3,5,4,5,26,20\n100\n100\n2,10,11,1,2,5,4,3,39,22\n67,10,10,14\n100\n26,1,74\n1,1,7,2,52,37\n100\n100\n1,67,14,18,1\n73,27\n30,58,1,11\n100\n2,45,53\n100\n100\n11,72,9,8\n18,28,54\n7,47,46\n21,2,1,3,74\n19,24,26,28,1,1,1,1\n100\n100\n4,6,53,37\n3,2,5,90\n41,59\n82,18\n4,3,18,8,8,23,38\n31,51,4,9,4\n72,12,16\n33,20,16,1,27,3\n100\n100\n65,34\n41,52,7\n1,1,32,27,10,30\n16,8,8,17,9,41\n14,20,4,4,49,8\n70,10,14,1,6\n74,13,14\n3,10,11,73,2\n6,11,16,4,8,51,4\n5,12,5,17,4,17,41\n9,2,89\n14,33,47,5\n84,10,7\n7,87,7\n23,10,44,24\n13,6,9,12,6,14,2,32,5\n11,4,2,5,25,7,7,23,2,2,5,6\n97,3\n2,2,7,2,88\n6,94\n1,1,13,10,37,7,2,9,9,5,6\n1,2,96\n100\n6,7,87\n31,3,18,15,33,1\n1,99\n100\n5,95\n100\n6,94\n1,31,68\n32,1,2,8,4,53\n5,95\n75,12,7,1,5\n100\n100\n100\n97,1,2\n4,96\n100\n33,67\n100\n40,31,19,9\n100\n6,38,55,1\n100\n88,10,1,1,1\n60,40\n10,6,10,9,57,9\n26,64,10\n17,14,60,9\n5,2,2,2,2,37,31,7,11\n28,6,3,6,38,10,2,6\n13,7,6,3,15,5,11,3,8,3,24\n27,1,26,4,6,19,16\n32,11,23,33\n13,10,12,10,9,46\n100\n46,2,27,22,4\n90,10\n27,73\n100\n19,81\n100\n47,53\n1,34,26,1,39\n87,13\n15,9,23,9,44\n9,91\n100\n39,35,12,13\n50,50\n49,51\n41,7,4,1,47\n58,42\n55,10,8,5,7,14\n46,54\n75,1,24\n100\n22,2,1,1,2,71\n100\n29,14,6,29,20,2\n19,1,80\n100\n5,1,31,63\n35,8,57\n85,15\n4,1,94\n27,27,12,4,29\n100\n92,5,4\n35,3,58,3\n65,35\n33,56,3,8\n1,99\n23,77\n100\n29,71\n100\n2,4,10,84\n13,16,1,70\n5,12,1,82\n100\n1,1,18,8,5,68\n100\n22,34,44\n100\n11,89\n6,1,93\n100\n100\n12,17,72\n87,6,7\n89,11\n100\n100\n100\n98,2\n100\n91,9\n1,1,18,79\n2,6,1,1,92\n7,3,22,26,19,8,15\n100\n100\n79,21\n85,15\n100\n14,10,1,74\n83,18\n10,33,1,1,1,2,52\n90,1,8\n3,3,28,6,60\n84,16\n100\n5,95\n16,24,60\n100\n100\n3,2,44,50\n2,91,7\n100\n100\n1,1,99\n24,76\n23,19,36,22\n70,28,3\n78,7,5,5,2,4\n20,17,3,3,43,2,11,1\n31,61,7\n3,97\n100\n100\n100\n1,71,29,1\n28,72\n77,2,21\n57,4,40\n3,51,3,8,34\n37,22,25,16\n70,1,18,11\n68,1,4,21,3,1,1\n81,19\n85,15\n7,4,7,13,68\n1,46,20,34\n3,83,3,6,5\n4,78,1,13,3,2\n96,4\n91,9\n14,59,25,1,1\n77,23\n99,1,1\n3,90,7\n90,10\n32,4,7,19,38\n13,70,10,5,2\n10,4,85,1,1\n44,7,23,3,18,6\n100\n49,27,4,20\n1,68,19,11\n2,1,71,4,10,12\n71,1,4,1,22,1\n43,56\n91,9\n5,95,1\n47,46,2,1,1,3\n38,1,1,56,2,3\n13,7,53,26,1\n100\n100\n98,1\n3,47,50\n4,52,1,43\n84,1,16\n89,11\n88,12\n24,56,19,1\n84,13,3\n49,50\n66,34\n71,12,9,8\n31,69\n55,45\n73,14,2,5,5\n91,1,3,2,3\n35,45,3,17\n1,67,5,9,4,15\n80,19\n86,7,7\n59,41\n69,31\n27,65,7\n48,52\n31,2,67\n1,3,96\n67,6,11,7,8\n1,3,96\n96,4\n13,79,7\n7,86,4,3\n100\n4,79,11,6,1\n94,6\n63,23,14\n75,12,13\n92,2,6\n6,78,4,5,5,2\n100\n69,14,9,5,3\n76,24\n22,75,3,1\n7,61,12,20\n84,7,1,8\n38,2,4,1,27,26,2\n1,1,1,94,2\n95,5\n58,40,2\n46,54\n88,4,8\n100\n63,11,5,2,18\n50,50\n7,28,21,16,2,26\n1,1,38,50,5,5,1\n50,2,2,2,33,5,6\n34,1,2,3,60\n7,37,20,35\n11,21,1,5,63\n100\n100\n100\n93,7\n90,5,5\n3,97\n100\n10,86,4\n33,8,11,7,17,12,12\n17,4,6,4,16,3,47,3\n89,11\n67,9,12,6,7\n98,2\n100\n100\n44,5,21,16,14\n99,1\n9,89,2\n90,6,4\n3,97\n5,67,10,16,1,1\n18,82\n17,83\n100\n1,99\n43,9,5,1,12,30\n57,1,6,2,6,28\n15,15,2,35,15,1,10,5,3\n17,5,32,24,15,7\n36,18,45,1\n3,22,26,7,1,5,6,22,8\n59,2,5,5,30\n58,12,30\n16,61,7,15\n5,16,23,1,1,38,16\n100\n8,48,20,20,2,2\n5,29,6,4,22,7,23,3\n27,20,53\n23,61,1,14\n93,1,6\n85,1,3,4,6\n84,16\n9,6,74,12\n100\n100\n3,5,30,2,1,6,31,9,13\n48,2,2,18,13,16\n62,2,3,16,17\n27,23,6,44\n1,99\n100\n1,19,24,56\n1,11,8,1,3,10,66\n55,13,22,9\n78,22\n8,92\n100\n25,75\n24,76\n100\n1,98\n61,33,6\n1,92,6\n10,90\n20,75,5\n4,8,13,24,47,4\n3,3,11,83\n41,59\n42,42,16\n29,5,4,20,42\n100\n100\n7,90,2\n39,10,10,40\n100\n89,11\n1,2,97\n23,76,1\n55,13,1,25,6\n70,19,10,2\n33,52,1,2,5,7\n2,1,97\n100\n10,90\n100\n4,49,39,8\n85,14\n26,64,9,1\n42,9,2,2,44\n29,46,15,11\n3,4,2,2,32,25,22,9\n67,33\n2,3,4,13,58,1,6,5,8\n68,9,7,16\n10,78,12\n2,66,7,9,15\n4,37,8,52\n88,11\n88,11\n100\n100\n62,38\n9,14,51,23,3\n21,51,4,13,11\n2,98\n12,88\n5,95\n11,89\n1,2,97\n2,2,7,2,3,83\n100\n1,46,53\n100\n81,19\n44,38,4,14\n55,14,31\n91,9\n17,9,7,67\n1,16,84\n4,76,15,5\n100\n100\n91,1,2,2,4,1\n95,5\n100\n100\n1,19,80\n25,74\n24,69,6,1\n60,40\n1,7,1,76,16\n17,79,3\n13,1,80,6\n52,1,47\n1,1,3,1,95\n27,3,70\n19,6,76\n47,1,39,13\n1,99\n15,12,73\n100\n6,3,17,8,3,9,4,1,1,3,46\n34,5,4,19,18,2,1,16\n3,97\n6,20,5,31,3,8,3,3,11,11\n66,13,7,14\n83,1,1,1,8,5\n1,99\n6,94\n30,33,6,30\n51,8,9,10,22\n13,37,50\n43,57\n3,22,28,4,12,31\n17,7,7,18,50\n76,17,7\n22,77,1\n3,76,21\n92,5,1,1\n2,14,3,7,3,1,14,56\n84,1,15\n100\n5,79,5,11\n87,13\n78,4,4,14\n62,5,27,3,4\n1,1,1,40,36,18,4\n8,92\n29,71\n70,30\n77,23\n43,20,14,2,20\n100\n2,98\n24,75\n25,11,8,32,24\n83,2,15\n2,22,51,25\n10,4,25,59\n12,25,28,1,33\n6,18,5,30,37,1,3\n5,1,9,9,10,9,39,16,2\n100\n7,82,11\n15,85\n53,2,2,3,4,9,5,21\n1,10,25,22,37,6,1\n58,1,38,1,1,1\n71,9,12,6\n16,4,2,6,24,1,47\n4,48,7,41\n27,6,68\n82,3,4,1,2,2,1,5\n2,52,46\n82,1,16\n81,19\n1,5,45,49\n83,17\n21,78,1\n11,25,5,8,7,8,36\n88,11\n10,1,88\n24,7,69\n67,2,12,19\n49,51\n8,23,30,22,16\n16,66,7,4,6\n3,10,4,9,7,5,61\n3,66,6,7,17\n2,29,27,25,18\n100\n12,88\n100\n100\n1,6,3,50,39,1\n1,4,95,1\n2,1,97\n4,5,91\n2,2,95\n15,45,40\n20,15,32,4,29\n65,35\n9,1,2,62,26\n100\n58,42\n2,98\n4,8,4,4,4,75\n24,75\n34,65\n33,67\n13,11,1,76\n21,8,36,8,26\n64,1,35\n100\n100\n37,63\n30,1,70\n54,46\n62,39\n33,8,5,1,54\n100\n100\n100\n61,39\n100\n13,52,34\n9,33,3,54\n45,54,1\n41,59\n15,23,62\n9,12,79\n53,2,44\n37,63\n11,9,8,72\n100\n2,7,2,88\n100\n21,79\n100\n98,2\n16,16,63,1,1,1,1\n96,4\n99,1\n71,9,9,10\n100\n100\n3,97\n100\n99,1\n100\n13,87\n2,12,11,5,58,11\n100\n98,3\n8,89,4\n100\n14,27,15,1,42,1\n42,8,49,2\n100\n4,55,1,41\n100\n11,86,1,1,2\n10,90\n100\n100\n1,86,13\n2,2,90,6\n100\n4,96\n8,79,1,10,1,1\n68,3,5,24\n2,30,30,38\n13,55,32\n2,4,2,2,90\n36,18,6,9,13,6,6,4\n25,37,33,4\n100\n28,72\n100\n100\n100\n100\n100\n100\n100\n28,72\n28,72\n100\n100\n1,99\n37,62\n73,10,2,15\n100\n7,2,2,4,10,5,69\n100\n36,26,38\n43,14,43\n2,97\n5,21,4,70\n99,1\n18,1,80,1\n13,86\n71,29\n34,66\n16,1,6,7,2,6,63\n80,5,15\n3,3,15,14,65\n100\n100\n100\n100\n100\n100\n100\n100\n100\n100\n100\n100\n100\n100\n100\n100\n100\n100\n71,29\n61,39\n100\n100\n83,3,3,1,3,5\n46,4,3,6,17,19,2,2\n12,34,31,23\n4,45,26,14,5,5\n64,7,3,1,2,13,4,1,2,1,3\n72,28\n100\n8,1,36,55\n1,32,67\n17,83\n1,71,27,1\n100\n1,6,93\n96,4\n87,2,3,8\n100\n87,1,1,11\n77,18,2,1,3\n95,1,2,2\n36,32,7,4,9,9,2\n72,6,10,2,9\n8,7,36,44,5\n87,1,11\n21,79\n1,47,38,13\n98,2\n99,1\n100\n100\n68,32\n12,88\n54,1,1,12,32\n37,14,2,5,42\n16,84\n27,28,2,3,1,1,2,4,9,22\n80,1,5,14\n100\n100\n100\n1,8,5,26,32,9,3,4,13,1\n3,95,2\n3,6,1,1,1,3,47,8,30,1\n20,2,12,8,56\n59,41\n5,2,93\n57,3,5,6,2,2,25\n4,13,6,4,36,5,2,3,12,9,6\n34,14,6,23,4,4,4,5,5,1\n100\n100\n100\n100\n100\n100\n49,51\n1,1,8,11,5,1,13,36,24\n9,9,5,7,18,7,7,18,7,5,9\n25,25,25,25\n1,19,80\n6,50,37,6\n32,44,22,1\n72,28\n100\n61,7,9,17,6\n100\n100\n4,1,30,13,52\n100\n6,3,39,10,32,10\n100\n100\n83,17\n77,2,13,1,1,1,1,1,1,1,1\n9,62,2,9,18\n81,18,1\n31,69\n17,36,7,3,1,1,25,9\n13,11,20,56\n83,17\n67,1,19,13\n100\n58,42\n95,2,4\n32,68\n24,76\n100\n32,68\n2,98\n26,74\n35,19,4,1,6,4,1,12,17\n26,1,67,1,3,1\n29,8,10,27,1,25\n36,17,20,26\n52,4,2,16,26\n100\n4,34,55,7\n20,43,37\n1,61,25,2,10\n66,34\n21,23,6,6,20,3,21,1\n4,61,34\n40,60\n8,90,2\n46,47,1,6\n1,55,9,13,5,11,6\n72,3,6,20\n89,6,3,2\n88,12,1\n1,13,86\n69,31\n29,25,9,19,17\n33,9,45,7,6\n100\n100\n89,11\n48,28,13,2,8\n49,20,20,11\n8,46,46\n70,28,1\n59,41\n88,10,3\n64,1,35\n45,55\n33,31,1,35\n6,34,26,31,3\n69,9,22\n60,40\n73,27\n96,4\n98,2\n48,7,1,44\n37,26,37\n100\n100\n100\n100\n95,5\n95,4,1\n100\n100\n82,6,1,2,1,2,2,1,1,3\n18,48,2,1,2,29,1\n5,79,1,2,1,10,1\n46,49,6\n14,81,4\n94,6\n1,85,4,8,2\n44,2,9,1,1,29,8,2,1,2\n96,1,3\n91,7,1,1\n5,95\n100\n99,1\n100\n100\n96,4\n100\n100\n100\n100\n92,8\n75,25\n54,35,4,6\n2,27,46,24\n28,1,1,5,64\n27,2,3,1,3,1,62\n22,13,44,5,15,1\n38,10,14,8,14,16,1\n1,98,1\n9,91\n14,86\n8,16,4,6,62,2,1,2\n1,1,37,11,4,42,3\n53,47\n85,5,3,7\n1,15,57,27\n21,9,6,64\n28,12,17,43\n21,27,1,47,3\n19,28,54\n18,20,1,61\n2,5,3,3,2,4,3,7,1,3,1,10,43,13\n6,2,3,3,10,5,11,13,16,31\n3,1,3,5,4,4,6,75\n7,1,1,2,6,82\n94,1,5,1\n3,1,94,2\n1,1,98\n100\n91,9\n100\n100\n15,85\n17,83\n100\n6,5,1,1,88,1\n7,4,88\n2,90,8\n28,5,1,66\n33,67\n41,1,57,1\n32,1,1,2,63\n41,3,56\n3,45,2,50\n3,97\n46,1,17,7,1,9,9,10\n2,17,1,79\n14,1,13,72\n10,6,83,2\n100\n100\n9,91\n9,91\n1,14,2,3,2,55,23\n44,6,6,11,16,18\n13,81,7\n7,20,1,72\n3,9,88\n100\n5,95\n100\n3,85,12\n22,23,54\n2,46,44,7\n54,5,42\n1,1,22,76\n3,14,7,65,8,2,2\n4,24,26,4,43\n100\n94,6\n99,1\n95,5\n100\n9,17,74\n10,9,13,12,2,54\n17,17,6,19,33,4,1,1,2\n87,13\n100\n100\n100\n100\n18,2,1,8,71\n4,2,2,12,3,14,7,16,11,28\n100\n81,19\n4,96\n100\n5,95\n38,8,12,24,8,9\n64,36\n100\n75,25\n4,12,84\n94,6\n100\n11,1,1,45,43\n100\n13,7,27,6,7,30,3,3,3,2\n100\n100\n100\n100\n50,50\n100\n13,87\n63,13,24\n9,49,42\n1,88,11\n85,3,3,10\n1,1,52,17,19,1,3,1,2,5\n100\n30,67,3\n100\n96,4\n58,34,8\n15,44,7,17,16,1\n28,13,43,8,8\n100\n100\n76,24\n100\n100\n46,47,7\n100\n100\n100\n2,98\n1,14,14,39,19,2,10,2\n66,5,29\n1,99\n100\n100\n100\n10,90\n12,4,84\n36,64\n24,26,42,1,3,3\n100\n100\n100\n5,95\n3,3,4,46,43\n73,26,1\n42,15,5,30,7\n1,1,66,33\n1,34,65\n99,1\n1,1,1,91,2,5\n99\n95,5\n88,7,5\n8,2,9,76,5\n4,1,20,50,2,12,11,1\n100\n3,1,92,1,3\n2,30,6,41,1,6,11\n3,1,26,60,1,4,2,1,4\n16,79,4\n41,2,31,8,7,10\n34,1,6,57,2\n13,7,3,10,9,55,2\n12,71,1,13,2,2\n9,74,12,5\n100\n97,2\n15,30,23,2,5,1,25\n16,26,24,3,32\n54,32,1,3,1,8\n59,3,25,7,2,5\n2,8,87,2,1\n94,5\n61,37,2,1\n73,22,5\n80,1,9,11\n66,5,1,2,27\n88,11\n91,1,7,1\n45,4,1,1,1,49\n8,5,6,81\n17,16,7,61\n78,22\n1,1,77,15,6\n79,7,3,2,3,5\n83,13,4\n100\n99,1\n100\n4,3,3,2,17,4,19,32,8,3,1,4\n50,50\n57,43\n100\n11,5,9,3,3,14,13,7,9,9,1,16\n9,70,6,6,7,2\n1,5,5,15,73\n83,17\n10,30,59\n10,6,84\n100\n8,47,18,13,15\n97,4\n83,17\n100\n25,45,30\n44,5,16,35\n14,85,1\n100\n61,12,2,25\n51,49\n59,41\n22,56,22\n1,1,7,90\n44,56\n1,86,9,3,1\n100\n72,28\n27,6,66\n80,20\n3,4,94\n6,56,12,24,1\n56,10,34\n2,98\n100\n100\n42,4,3,7,9,35\n19,52,5,22,1,1\n100\n3,3,94\n7,9,17,12,17,38\n22,15,61,1,1\n100\n99\n71,28\n88,12\n20,3,76\n3,5,49,43\n13,28,59\n8,4,27,60\n1,99,1\n100\n28,5,3,14,2,4,6,36\n15,15,1,2,30,18,15,2,1\n100\n28,12,18,12,30\n96,2,2,1\n32,4,37,9,5,2,7,1,3\n1,50,10,20,6,8,4\n100\n6,1,2,52,38\n10,78,2,1,1,3,1,1,2\n81,1,18\n1,53,4,34,7\n1,27,55,16\n7,9,7,47,20,11\n7,2,2,8,19,30,2,3,6,5,4,8,4\n36,28,36\n4,1,10,1,84\n1,2,2,2,3,22,9,8,11,40\n4,96\n100\n1,15,84\n78,7,15\n63,31,1,5\n27,13,41,10,10\n10,32,58\n82,18\n8,82,9\n1,99,1\n5,3,16,23,52,1,1,1\n100\n10,13,19,51,7,1\n38,62\n94,5,1\n4,24,72\n7,23,13,56\n73,22,5\n76,24,1\n100\n100\n100\n100\n97,3\n100\n100\n41,58,1,1\n64,21,14\n33,56,10\n80,3,4,13\n100\n100\n11,46,43\n20,26,53\n42,58\n100\n100\n23,39,38\n56,44\n100\n61,39\n25,74\n79,21\n100\n100\n100\n5,88,7\n100\n100\n82,1,17\n100\n100\n100\n18,11,71\n100\n86,14\n60,10,30\n9,31,1,4,14,40\n100\n1,3,2,56,2,2,3,7,3,4,2,9,4,2\n16,6,18,33,27\n24,30,17,29\n31,69\n99,1\n20,80\n100\n68,32\n100\n22,3,1,74\n53,47\n100\n61,39\n20,80\n100\n72,28\n14,7,9,7,8,1,1,1,1,13,5,12,18,4\n4,2,94\n66,12,4,1,17\n45,10,43,2\n9,41,35,14\n5,7,88\n61,38\n56,42,2\n3,17,22,15,43\n22,17,34,14,14\n16,84\n3,5,91\n2,3,5,8,10,9,1,6,22,14,4,4,4,5,4\n23,8,3,10,56\n33,8,11,6,23,1,7,1,5,1,5\n90,3,3,1,4\n14,1,7,7,4,5,61\n64,13,9,10,4\n1,1,99\n8,43,36,13\n21,14,64\n100\n92,3,3,1,1\n100\n100\n100\n36,7,56\n3,29,68\n6,2,3,89\n1,5,4,43,10,38\n4,6,2,18,9,43,17\n8,60,32\n45,2,52\n40,10,50\n3,97\n2,98\n94,6\n93,7\n12,87,1\n100\n100\n100\n21,79\n100\n8,75,17\n100\n52,1,1,46\n100\n52,47\n56,44\n100\n100\n100\n18,67,13,3\n100\n53,24,13,10\n86,14\n90,2,3,5\n100\n81,19\n100\n13,2,2,11,2,34,32,4\n21,79\n23,3,13,61\n85,2,1,3,6,4\n3,5,92\n86,11,3\n4,43,29,3,3,2,8,8\n100\n100\n98,2\n83,1,1,15\n19,61,8,12\n34,66\n1,23,66,9\n17,2,11,17,39,3,6,2,3,1\n74,2,2,6,7,5,5\n11,3,1,2,11,13,11,18,26,2\n4,3,1,28,15,7,17,23\n1,99\n100\n37,63\n43,57\n93,7\n12,2,11,75\n9,14,20,13,10,34\n96,2,2\n64,34,2\n86,14\n80,4,4,12\n100\n97,1,1,2\n5,5,6,31,33,6,9,3\n25,63,11\n47,53\n100\n98,2\n97,1,3\n71,29\n83,17\n1,99\n96,2,1,1\n37,10,33,20\n100\n61,39\n2,87,4,6\n5,1,1,3,1,88\n1,3,50,28,9,10\n1,85,1,1,13\n44,6,34,2,6,4,4,1\n64,31,1,4\n1,1,1,1,1,64,31\n3,25,27,6,8,8,24\n2,72,4,11,1,1,7,1\n1,3,94,1\n1,6,6,5,52,30\n15,40,45\n22,51,26\n25,19,56\n1,34,65\n7,6,9,77\n100\n75,1,2,22\n66,25,7,1,1\n22,57,1,11,8\n9,16,54,21\n58,42\n49,51\n100\n16,84\n100\n100\n61,18,13,8\n100\n100\n87,13\n100\n100\n90,3,3,1,1,1\n79,3,9,3,3,2\n100\n100\n100\n100\n3,4,93\n100\n100\n62,38\n41,46,14\n100\n100\n100\n100\n100\n75,4,13,2,3,2,1\n100\n100\n100\n2,2,2,6,77,11\n10,39,28,1,20,2\n94,6\n20,80\n5,2,93\n1,99\n5,6,4,4,33,23,25,1\n1,1,98,1\n100\n1,94,5\n53,22,25\n1,26,66,2,5\n49,24,24,1,1\n24,63,13\n32,68\n1,89,10\n25,32,19,3,21\n100\n100\n100\n100\n53,36,1,5,5\n57,1,3,39\n77,23\n1,55,1,43\n60,40\n14,51,8,8,1,13,3,2\n100\n43,18,20,8,6,1,1,2\n100\n4,96\n100\n81,19\n80,20\n20,80\n63,37\n100\n100\n36,2,19,3,1,20,3,3,1,11\n52,9,17,7,15\n7,13,12,2,16,1,6,1,1,41\n57,42,1\n1,99\n100\n100\n100\n45,24,31\n36,30,35\n5,95\n18,82\n1,74,15,9,1\n2,3,2,3,6,6,12,6,5,8,3,10,22,11,1\n23,24,54\n1,87,12\n100\n21,52,22,4\n4,8,8,29,24,6,12,4,5\n100\n100\n19,3,6,60,12\n53,47\n100\n53,3,43\n37,63\n100\n86,14\n37,63\n23,1,76\n21,2,77\n100\n74,26\n12,88\n17,48,34\n86,14\n74,26\n100\n2,15,7,76\n11,11,37,41\n100\n12,71,17\n9,85,5\n50,50\n26,26,3,45\n100\n99,1\n100\n57,43\n10,38,39,13\n91,1,1,1,1,5\n93,3,1,2,1,1\n4,4,49,43\n69,12,8,2,8\n100\n100\n51,1,49\n100\n9,7,3,12,31,37\n95,5\n46,17,18,18\n25,7,10,15,7,35\n73,27\n36,9,5,1,4,46\n5,23,37,5,29\n22,6,16,52,3\n69,31\n91,9\n50,1,49\n60,20,16,4\n27,39,26,8\n67,33\n73,27\n75,25\n100\n100\n96,4\n100\n100\n78,4,1,1,4,12\n9,6,16,3,66\n47,16,9,15,12\n100\n85,15\n100\n100\n8,20,32,39\n96,4\n4,96\n41,2,57\n100\n84,11,5\n5,95\n1,11,11,23,51\n2,76,22\n1,1,1,38,24,11,24\n100\n100\n100\n100\n8,8,6,54,24\n100\n100\n32,66,2\n100\n100\n100\n100\n82,18\n12,15,18,1,7,7,4,3,34\n98,2\n32,36,1,9,1,21\n12,88,1\n100\n28,72\n87,3,10\n100\n4,28,4,64\n100\n11,89\n100\n43,3,55\n43,57\n93,8\n2,98\n26,74\n47,10,10,3,4,8,11,4,3\n81,19\n31,5,3,39,23\n3,97\n42,58\n32,68\n72,11,16\n5,2,2,19,6,3,23,12,5,13,5,6\n44,4,27,3,6,15\n100\n2,79,18,2\n11,89\n93,7\n84,10,7\n12,44,41,2\n26,74\n14,85,1\n94,6\n100\n100\n84,16\n9,48,27,10,6\n2,4,43,51\n38,62\n14,20,66\n10,7,6,7,10,8,4,43,4\n20,23,56\n32,54,10,5\n30,62,8\n100\n1,5,1,4,3,69,1,17,1\n86,1,1,13\n1,6,1,91,1\n84,14,1\n94,6\n65,35\n100\n64,20,4,12\n100\n89,11\n88,9,3\n12,1,6,2,79\n19,6,75\n100\n100\n100\n100\n100\n100\n1,5,6,1,83,5\n71,17,3,3,6\n100\n62,14,24\n8,71,20,1,1\n75,21,4\n80,11,10\n4,26,70\n95,4,1\n33,16,39,12\n1,63,24,11\n40,13,20,26\n1,1,1,1,97\n5,16,41,1,30,8\n6,94\n4,17,9,70\n1,44,55\n100\n5,1,1,11,48,5,8,8,4,5,2,1\n52,5,6,3,9,4,21\n86,14\n7,8,8,10,6,60\n45,55\n78,22\n100\n100\n100\n82,2,2,1,14\n100\n100\n11,2,2,1,10,2,17,9,4,15,3,23\n58,42\n100\n3,29,68\n100\n18,15,28,28,12\n1,1,3,69,26\n31,2,3,2,62\n1,99\n1,85,15\n100\n100\n96,2,2\n82,18\n30,33,2,14,15,5,1\n42,16,23,2,1,16\n15,53,30,1\n1,11,85,1,1,1\n1,20,1,11,27,16,24\n9,30,61\n8,31,61\n7,3,9,5,75\n2,6,7,5,4,5,4,68\n5,6,2,4,6,2,25,50\n9,1,2,34,53\n86,14\n100\n1,99\n44,20,36\n4,38,53,5\n3,39,54,4\n12,79,3,7\n35,57,9\n13,87\n2,5,3,89\n7,93\n5,95\n9,2,89\n3,97\n42,5,1,1,50\n27,3,9,24,6,31\n17,30,54\n18,1,38,44\n5,3,4,13,74\n1,1,42,56\n1,42,57\n33,67\n61,39\n51,49\n94,1,4\n4,3,33,60\n3,15,14,1,67\n100\n3,38,3,56\n29,2,69\n23,77\n1,1,98,1\n35,65\n42,58\n1,12,23,63\n1,12,1,86\n13,86\n1,99\n15,1,1,3,2,1,5,53,7,11\n14,15,8,8,4,7,2,41\n39,2,1,57\n47,53\n9,91\n100\n11,13,24,26,8,18\n47,8,3,5,38\n1,2,1,15,11,34,37\n7,5,9,4,1,73\n9,15,13,1,7,55\n4,2,1,5,88\n12,88\n100\n98,2\n100\n9,84,6\n63,4,4,2,2,6,19\n5,11,7,3,74\n1,31,5,12,4,5,42\n59,19,14,7,1\n80,10,9,1\n21,57,21,1\n6,2,3,2,3,84\n1,98\n100\n18,7,16,6,3,3,4,2,8,2,7,6,2,1,3,2,3,6\n1,1,1,2,22,41,16,17\n39,8,8,45\n92,8\n49,51\n40,60\n2,1,11,30,55\n1,75,24\n1,84,15\n100\n100\n94,6\n100\n23,77\n100\n18,72,1,9\n100\n95,5\n100\n100\n77,2,15,1,6\n4,14,25,2,8,48\n2,98\n92,7,1\n50,39,11\n12,78,1,1,1,1,7\n78,7,15\n15,85\n37,63\n9,85,6\n46,23,30\n92,6,2\n99\n3,3,94\n90,10\n69,31\n28,20,51\n100\n20,80\n18,3,1,1,2,5,17,54\n100\n100\n29,15,17,10,29,1\n100\n3,3,2,6,85\n100\n99,1\n97,2,1\n100\n3,1,3,93\n100\n100\n100\n7,1,93\n94,6\n7,70,23\n1,6,6,23,8,15,13,27\n55,45\n9,1,2,24,31,11,22\n5,90,6\n5,9,24,28,8,25\n38,5,51,7\n100\n95,5\n15,34,4,7,7,5,19,9\n1,10,27,4,3,48,7\n100\n10,90\n19,81\n25,9,17,18,28,2\n1,93,6\n2,91,5,1\n6,12,4,23,10,10,27,3,3,2\n16,12,21,22,6,8,11,4\n4,96\n6,2,3,2,6,8,2,70\n32,68\n15,85\n8,4,9,8,18,53\n97,3\n100\n15,11,65,2,6\n15,14,39,7,25\n39,19,42\n2,9,5,4,26,21,16,18\n99,1\n93,2,4\n22,5,23,50\n16,3,16,36,29\n81,19\n10,5,9,69,7\n48,38,4,9\n4,72,20,4\n16,84\n30,2,68\n80,14,6\n2,79,1,1,6,8,4\n84,2,1,1,12\n68,18,13,1\n93,2,2,3\n87,13\n19,71,10\n100\n100\n100\n51,2,47\n8,1,1,27,1,44,1,6,10\n100\n100\n100\n33,19,47,1\n27,9,7,30,27\n86,14\n2,2,1,20,53,23\n100\n26,60,2,12\n4,96\n85,13,2,1\n100\n100\n11,89\n9,39,4,30,19\n1,15,85\n5,19,73,3\n5,1,21,13,40,1,19\n93,7\n28,62,10\n88,12\n2,96,2\n93,4,3\n5,62,34\n100\n11,31,9,15,33\n6,94\n42,58\n100\n22,8,38,33\n1,13,80,6\n22,20,3,55\n5,39,15,40\n79,21\n4,1,95\n3,5,3,4,5,80\n18,1,1,80\n1,99\n100\n8,6,19,36,28,3\n88,12\n2,19,79\n1,3,3,92\n100\n6,3,34,8,20,15,14\n77,5,11,6\n69,24,6\n57,6,34,3\n4,66,2,27,1\n94,6\n95,5\n11,5,41,39,4\n89,11\n100\n100\n99\n60,7,14,19\n47,5,2,1,45\n60,6,34\n11,15,4,19,11,4,3,1,1,15,18\n7,3,33,4,2,1,2,4,1,42\n100\n3,4,68,20,5\n3,80,10,8\n94,6\n94,6\n29,5,9,3,17,21,2,2,1,6,1,2,2\n44,7,8,1,6,15,3,1,7,7\n1,99\n10,90\n31,68,1\n1,4,1,29,21,24,10,11\n89,1,10,1\n98,1,1,1\n100\n100\n50,50\n29,71\n3,7,2,39,5,16,28\n3,21,17,30,29\n100\n80,18,2\n53,1,17,29\n74,25,1\n100\n1,88,11\n2,1,3,1,93\n25,1,3,71\n100\n100\n100\n100\n92,8\n1,99\n23,77\n68,1,31\n100\n100\n97,1,1,1\n31,11,20,10,27\n1,34,59,6\n52,26,1,17,1,3\n47,53\n1,1,98\n100\n100\n100\n20,79\n17,83\n9,91\n26,38,1,35\n10,41,1,1,12,2,32\n18,82\n8,92\n56,44\n100\n100\n100\n12,9,53,20,7\n13,77,10\n5,95\n100\n31,34,11,23\n18,63,4,1,15\n32,68\n77,23\n52,48\n4,95,1\n99,1\n53,13,6,14,12\n80,20\n100\n11,52,28,4,2,1\n12,10,19,38,5,9,8\n2,9,4,85\n47,53\n5,17,5,30,31,12\n100\n6,3,91\n96,4\n84,16\n90,1,2,8\n99\n2,1,5,91\n77,22\n9,16,21,22,16,17\n100\n100\n87,13\n86,14\n100\n92,8\n99,1\n3,24,19,8,11,6,9,19\n1,76,7,17\n98,1,1,1\n28,64,8\n1,67,33\n99,1\n1,99,1\n25,9,52,13\n100\n60,1,40\n1,2,3,3,85,2,2\n11,1,2,2,3,1,78\n100\n100\n6,3,21,17,4,4,41,1,2\n44,3,3,3,23,9,15\n64,11,19,5\n1,98\n27,16,47,10\n4,8,84,3,1\n18,70,12\n82,18\n14,1,86\n100\n33,34,23,10\n20,80\n2,2,1,1,2,92\n3,2,96\n84,16\n100\n100\n22,78\n16,1,3,1,1,4,1,73\n100\n73,1,21,5\n3,2,3,74,18\n100\n78,22\n5,8,12,54,21\n59,30,11\n34,27,24,15\n100\n100\n100\n100\n100\n100\n100\n100\n75,25\n44,56\n83,16\n44,18,39\n43,57\n69,31\n100\n32,47,17,3,1\n56,4,35,5,1,1\n100\n3,49,48\n100\n5,52,11,17,14\n60,4,12,15,9\n42,39,6,12\n22,1,45,13,5,14\n31,1,33,34\n100\n100\n100\n100\n100\n100\n80,20\n100\n100\n15,15,71\n100\n98,2\n48,27,1,1,3,15,5\n100\n100\n38,1,27,25,9\n1,5,6,21,6,1,8,51\n9,41,7,22,21\n100\n67,33\n2,19,20,54,1,4\n100\n100\n32,68\n75,1,3,4,3,6,6,1\n95,5\n36,31,5,28\n33,22,37,9\n2,1,97\n7,1,92\n74,18,8\n1,95,4\n75,1,12,12\n27,73\n100\n28,61,10,1\n15,28,15,41\n22,37,3,37\n1,31,20,23,23,1,2,1\n25,13,6,13,16,27\n21,47,19,6,8\n75,21,5\n61,39\n17,5,8,42,27\n11,13,11,23,34,4,5\n1,13,3,14,52,3,3,11\n23,1,3,3,3,26,39,3\n69,31\n90,9\n44,50,1,5,1\n1,1,47,34,18\n25,75\n15,49,6,29\n71,29\n100\n20,9,71\n1,24,70,5\n36,16,46,3\n15,10,23,7,44,1\n1,1,1,18,1,8,71\n39,27,33,1\n66,4,22,3,1,3\n28,4,30,3,32,1,2\n1,75,23\n100\n4,96\n31,68\n14,86\n10,4,17,37,4,4,25\n100\n4,96\n84,16\n11,29,19,36,1,1,2,1\n7,3,90\n12,64,1,18,4\n90,9,1\n15,15,8,28,14,8,4,4,3\n99\n1,45,55\n19,80,1\n16,2,1,37,27,7,10\n40,3,24,32\n37,27,25,11\n2,97,1\n100\n9,6,85\n47,30,4,19\n3,97\n50,50\n9,33,1,7,3,5,11,10,7,13\n33,20,23,11,12\n45,6,47,1,1\n10,8,45,37,1\n14,3,6,2,45,11,4,11,3,1\n32,3,1,14,1,3,1,46\n100\n100\n29,3,1,67\n1,1,23,5,2,6,60,1\n40,42,18\n100\n100\n49,51\n23,12,1,2,6,3,1,3,11,39\n100\n25,74\n77,2,2,19\n100\n95,5\n7,15,42,2,2,1,1,1,2,10,17\n12,17,5,37,21,1,1,1,6\n97,3\n1,99\n1,3,1,1,95\n99,1\n24,76\n100\n100\n7,44,8,11,8,23\n1,41,30,29\n21,15,19,25,15,5\n3,10,14,3,49,21\n14,34,51\n100\n24,17,45,11,3\n90,2,8\n8,92\n10,61,4,6,18,2\n16,11,13,31,29\n9,4,55,20,11\n48,4,3,45\n4,4,91\n11,87,3\n95,5\n98,1\n100\n100\n94,3,1,1\n50,11,39\n29,71\n100\n26,74\n100\n31,2,67\n61,5,21,13\n12,1,8,4,50,12,12\n100\n100\n100\n30,70\n100\n43,57\n93,1,3,3\n100\n94,6\n100\n100\n96,4\n43,57\n78,1,15,6\n88,9,3\n51,1,1,46\n68,32\n8,26,17,1,1,2,1,36,5,1,2\n5,4,2,6,25,8,16,15,10,3,3,3\n16,82,2\n100\n86,5,9\n8,46,47\n26,1,12,20,13,8,5,6,1,8\n1,3,1,22,34,20,9,1,9,1\n18,51,30\n81,19\n36,53,8,3\n100\n79,21\n13,6,9,72\n17,12,1,68,1\n10,8,81\n13,85,1\n46,53\n46,1,2,4,47\n7,93\n99\n1,99\n90,1,2,7\n100\n90,4,6\n53,8,40\n100\n8,65,26\n1,99\n16,84\n11,89\n100\n100\n95,3,3\n3,1,96\n100\n100\n100\n100\n100\n100\n100\n100\n100\n100\n100\n100\n100\n100\n100\n100\n100\n100\n100\n100\n100\n2,3,21,75\n72,12,16\n10,90\n26,23,50\n100\n100\n100\n80,4,1,1,3,2,2,2,3,3\n100\n100\n61,15,18,5,1\n22,29,5,10,30,4\n18,60,9,6,7\n15,82,3\n23,10,20,2,35,3,6\n53,10,6,31\n88,13\n1,3,19,2,4,71\n10,17,6,21,20,6,1,19\n95,5\n99,1\n29,2,69\n21,78\n100\n78,22\n1,68,31\n2,4,8,85\n9,15,75\n1,99\n99,1\n100\n85,15\n100\n33,4,59,4\n89,11\n65,35\n34,10,56\n1,61,34,4\n1,2,21,65,6,1,3,1,1\n21,63,9,2,5\n92,7\n3,3,14,3,42,10,24\n88,11\n68,12,8,12\n1,15,1,83,1\n33,2,29,35\n25,12,13,17,34\n100\n1,98,1\n100\n91,9\n84,16\n83,17\n70,5,7,18\n1,2,1,1,1,1,1,3,10,2,11,1,3,3,13,37,10\n67,33\n17,12,4,4,17,5,6,4,30\n17,3,3,2,1,2,70,1\n16,5,75,3\n81,19\n42,25,33\n28,28,23,21\n23,21,56\n65,35\n21,39,2,35,3\n32,68\n16,7,6,70\n10,23,67\n34,66\n11,89\n87,13\n100\n1,35,64\n12,79,3,1,1,4,1\n59,3,4,20,1,3,1,1,10\n9,91\n100\n100\n82,18\n100\n97,3\n100\n100\n100\n100\n100\n12,11,75\n100\n31,69\n100\n2,2,3,93\n81,18,1\n100\n100\n41,51,9\n59,9,10,1,1,10,2,3,2,2\n67,1,19,3,6,4\n20,74,6\n60,31,5,3\n92,2,6\n65,13,8,14\n59,1,27,13\n22,53,3,6,15\n3,79,19\n17,66,2,15\n85,1,14,1\n71,1,28,1\n19,6,16,60\n100\n100\n2,21,75,3\n99\n100\n3,47,19,32\n100\n100\n100\n21,50,8,20\n66,4,30\n1,3,96\n100\n35,15,4,6,1,2,12,4,11,8,1\n24,76\n76,24\n3,97\n27,66,1,7\n74,1,2,5,1,7,11\n6,3,32,16,7,19,13,5\n77,7,13,3\n12,3,33,12,39\n2,1,97\n1,3,1,10,85\n10,90\n1,72,6,21\n3,43,53\n100\n100\n100\n20,80\n100\n100\n100\n100\n13,86\n50,24,13,13\n13,87\n21,52,6,21\n5,95\n100\n95,5\n61,39\n52,2,46\n3,97\n92,2,7\n73,6,5,1,8,8,1\n100\n100\n8,92\n39,61\n14,10,6,13,6,47,5\n1,2,1,2,8,9,24,1,9,8,36\n28,2,2,21,6,33,5,4\n12,88\n62,5,34\n100\n1,1,2,95\n2,3,4,38,23,29\n93,7\n26,7,4,64\n16,80,4\n100\n67,1,2,30\n100\n100\n100\n100\n80,20,1\n1,1,9,7,5,77\n2,57,13,13,4,9,2\n71,10,17,1\n100\n100\n100\n4,2,3,22,8,50,11\n5,10,10,1,73\n3,65,33\n9,1,2,13,75\n66,34\n97,3\n100\n58,42\n100\n100\n100\n41,4,9,41,4\n12,42,4,22,8,1,9,3\n30,58,11,2\n65,35\n100\n100\n100\n11,11,6,3,3,26,28,4,9\n56,5,2,2,2,33\n55,45\n25,75\n1,8,4,80,8\n3,33,9,7,41,2,2,3\n100\n12,88\n100\n100\n100\n10,45,7,38\n54,46\n96,1,3\n13,13,22,24,5,22\n99,1\n100\n90,10\n55,45\n100\n19,20,50,10\n100\n2,14,84\n100\n12,49,3,23,13\n100\n42,11,40,7\n1,74,7,18\n100\n4,2,93,1\n9,2,56,32,1,1\n1,17,6,2,72\n30,3,3,23,39\n4,1,4,6,1,83,1,1\n23,28,24,25\n19,1,80\n32,3,11,4,4,45\n95,5\n17,82\n3,22,73\n26,73\n1,61,24,3,10\n3,6,44,46\n1,1,1,69,28\n25,75\n6,15,2,51,3,23\n1,65,18,16\n100\n4,74,21,1\n81,9,5,3,2\n21,23,1,7,49\n7,35,17,9,12,7,12\n80,6,3,3,9\n49,51\n100\n1,99\n77,2,15,6\n43,57\n50,23,1,27\n35,65\n100\n28,45,27\n100\n64,36\n100\n48,46,1,5\n31,1,6,61\n97,3\n100\n100\n100\n100\n13,4,74,8\n29,1,2,53,10,3\n5,5,11,80\n51,49\n55,19,14,12,1\n26,73\n11,84,6\n1,1,98\n100\n65,2,33\n81,8,6,6\n100\n84,1,15,1\n62,1,37,1,1\n1,4,82,1,7,5\n100\n100\n13,60,3,3,4,6,10\n1,99\n44,1,13,14,28\n41,2,26,31\n99\n9,4,87\n9,2,2,87\n74,26\n93,7\n85,12,3\n92,4,4\n1,83,3,1,12\n87,13\n82,12,6\n88,2,1,2,2,3,3\n26,35,39\n20,5,26,50\n100\n18,57,13,12\n5,73,22\n1,76,23\n75,1,1,1,23\n29,18,1,54\n12,4,5,1,79\n47,34,18\n54,11,11,15,10\n21,12,10,57\n1,15,36,9,12,28\n100\n8,9,84\n15,85\n37,59,4\n66,3,3,1,27\n18,16,11,4,28,22,1\n53,46,1\n11,9,1,2,13,16,2,9,9,1,8,8,10\n100\n48,13,38\n5,48,1,20,6,20,1\n100\n63,5,15,2,15\n4,96\n1,3,96\n4,3,17,33,42\n21,11,68\n95,5\n3,17,31,44,5\n91,9\n84,10,6\n81,19\n27,26,20,27\n100\n8,6,19,1,67\n8,1,1,1,29,9,1,3,1,21,3,24\n46,54\n52,48\n100\n8,34,50,8\n9,12,3,11,66\n84,14,2\n6,13,7,74\n95,3,1,2\n77,3,1,16,3\n100\n42,58\n49,51\n6,13,80\n5,7,11,16,13,10,7,4,15,5,8\n1,1,3,96\n91,3,5\n49,3,45,1,1\n30,3,30,8,21,8\n100\n72,14,14\n70,5,26\n8,92\n22,36,34,8\n5,95\n30,51,19\n4,1,3,1,2,4,3,82\n15,2,83\n100\n1,39,60\n16,84\n10,38,29,23\n1,99\n100\n100\n36,58,6\n100\n2,11,2,36,8,11,30\n100\n37,54,9\n2,6,23,17,1,5,18,29\n100\n34,10,56\n32,1,14,9,10,9,20,5\n6,40,26,5,3,20\n100\n100\n1,8,16,10,65\n3,26,17,51,2\n1,23,18,53,3\n1,50,30,8,3,1,7\n15,1,7,2,8,1,57,9\n12,24,65\n100\n100\n18,4,35,43\n7,32,60\n100\n100\n38,19,14,24,4\n14,33,24,24,4\n59,41\n19,1,18,1,3,19,1,31,4\n1,22,78\n100\n43,21,24,12\n100\n61,39\n3,31,4,5,22,1,1,1,2,31\n5,49,17,29\n13,12,7,1,1,2,1,3,1,1,34,2,2,1,3,16\n40,59\n54,36,9,1,1\n7,45,47\n81,19\n100\n34,10,4,5,1,1,1,4,1,1,1,2,14,11,5,5\n33,1,6,2,1,1,3,5,4,44\n37,7,56\n30,30,10,28,1,1,1\n7,1,20,23,49\n16,5,1,33,8,1,28,9\n71,29\n3,25,19,5,6,17,18,2,4,2\n24,46,29\n12,7,13,9,4,8,4,14,11,17\n21,1,3,1,6,7,21,6,14,17,1\n11,17,71\n1,27,10,1,62\n100\n28,6,6,49,12\n3,5,73,11,2,5\n100\n23,6,9,61\n23,36,6,5,5,8,18\n10,42,3,13,32\n12,9,24,29,19,7\n4,17,80\n5,46,21,1,1,27\n16,15,24,19,6,4,16\n8,19,22,21,8,4,2,3,12\n100\n1,88,4,3,5\n100\n1,99\n15,85\n90,1,1,7,1\n5,20,10,3,48,15\n39,36,2,20,2\n1,9,13,13,22,23,18\n13,9,9,10,21,39\n55,45\n85,15\n4,31,23,40,2\n100\n16,4,2,8,8,10,33,18\n7,5,9,1,7,5,32,34\n1,98,1\n1,20,45,1,23,10,1\n44,1,6,50\n22,5,11,1,1,60\n6,6,2,56,23,7\n12,88\n14,1,60,25\n1,1,1,75,22\n2,6,3,15,3,6,4,57,4\n7,1,91\n1,12,14,22,9,32,5,6\n16,41,9,6,3,4,18,2\n4,14,15,2,5,19,19,21\n4,9,8,20,20,3,4,3,11,3,14\n20,1,33,1,6,13,26\n31,35,22,1,1,10\n47,53\n7,11,4,1,77\n85,15\n1,21,6,17,18,37,1\n100\n26,42,9,23\n11,8,44,13,21,3\n20,79\n50,50\n22,36,6,37\n13,5,12,68,1\n37,62\n7,89,4\n11,32,32,9,16\n16,6,22,33,7,16\n1,1,1,61,35\n4,43,22,10,10,7,4\n25,19,13,31,11\n5,17,26,15,9,3,23,1\n8,29,7,1,5,5,3,6,14,21\n15,10,4,16,5,4,28,19\n3,6,15,47,29\n100\n42,18,40\n100\n100\n23,39,19,20\n9,73,1,1,1,11,4\n1,1,89,1,4,6\n36,5,59\n100\n13,5,5,77\n1,2,10,8,7,6,22,7,38\n4,19,14,21,42\n13,14,72,1\n100\n7,42,15,11,11,15\n18,11,14,14,43\n11,2,10,57,19,1\n6,91,3\n18,32,27,23\n2,7,3,88\n58,31,8,3\n34,2,9,3,33,19\n32,7,61\n32,3,64\n27,73\n20,5,14,26,2,3,24,3,2\n27,3,21,16,3,14,16\n1,5,7,43,9,35\n58,2,7,20,9,1,1,2\n7,2,26,1,6,7,10,4,2,1,20,13\n32,26,40,1,1\n7,7,7,2,4,15,9,23,15,2,2,2,5\n33,1,1,25,20,19,1\n51,49\n11,12,8,13,26,30\n53,47\n3,70,27\n25,41,27,4,3\n100\n62,38\n59,41\n100\n1,99\n1,49,21,24,6\n7,31,61,1\n38,62\n13,19,9,10,20,24,6\n13,29,14,10,2,1,13,6,2,2,3,2,4\n3,16,15,11,10,28,2,8,6\n36,12,4,5,6,7,5,25\n57,15,28\n2,29,25,36,3,1,2,1,1\n21,4,37,27,5,6\n26,1,4,10,43,1,14\n36,42,21\n25,27,29,19\n3,3,3,9,20,17,10,19,15\n7,27,23,43\n34,36,30\n7,1,7,4,10,11,27,1,16,16\n7,34,13,16,1,1,6,8,16\n7,10,39,38,7\n4,2,2,7,2,17,6,19,2,6,33\n100\n33,54,13\n24,1,1,1,1,61,11\n3,3,95\n89,11\n8,2,3,71,12,4\n6,21,17,24,32\n11,6,39,43\n33,29,1,1,24,11,1\n9,45,6,22,18\n35,28,25,11\n12,1,36,25,22,5\n11,89\n2,29,13,9,23,4,9,7,4\n50,50\n49,1,50\n33,67\n12,16,73\n90,10\n53,38,8\n100\n46,5,14,13,3,3,4,8,2,1\n2,27,32,5,18,7,8\n100\n100\n4,3,19,23,2,13,11,26\n2,17,5,25,5,1,5,4,34,2\n2,6,8,17,2,8,2,4,37,12\n40,35,21,4\n6,7,6,4,39,11,27\n42,1,9,35,10,1\n2,5,34,22,3,13,21\n6,8,10,16,11,5,4,1,11,7,7,4,10\n18,29,18,6,27,1\n56,44\n23,6,11,13,9,1,20,4,13\n6,43,1,1,44,5\n46,54\n16,32,29,22\n21,45,34\n1,6,62,30\n1,18,18,1,34,1,1,9,18\n1,52,6,1,13,26,1\n7,10,6,5,1,5,1,43,1,21\n59,41\n10,14,1,10,34,27,1,1\n25,14,28,29,2,1\n8,1,2,2,8,46,34\n11,15,9,12,5,9,39\n1,1,17,14,5,63\n1,1,7,1,90\n24,7,70\n3,5,4,16,47,6,15,3\n9,74,9,8\n53,9,2,30,6\n3,87,2,3,5\n72,17,2,9\n4,11,3,4,3,1,1,19,9,13,8,25\n5,3,16,6,70\n39,6,1,24,4,25\n3,6,52,3,16,20\n5,8,33,4,18,17,3,1,11\n88,1,11\n24,11,15,5,44\n93,5,2\n52,9,39\n39,32,9,19\n79,1,6,3,3,7,1\n90,3,2,5\n5,1,5,89\n5,87,6,2\n100\n3,10,5,16,64\n100\n6,8,3,15,68\n18,20,16,36,1,9\n98,1\n89,11\n100\n67,33\n100\n60,39,1,1\n46,27,27\n59,41\n72,28\n69,31\n46,4,1,49\n8,7,1,12,6,15,1,21,27,2\n43,8,2,8,29,10\n13,4,31,3,29,18,1\n4,32,6,2,4,3,3,22,24,1\n100\n50,50\n5,12,2,1,1,3,1,1,36,15,16,6\n14,58,6,2,4,2,5,1,9\n11,1,6,1,1,49,1,1,30\n23,1,16,5,16,16,1,3,6,4,1,8,1,1\n6,7,9,6,12,1,3,10,16,3,7,6,10,1,1,2,1\n58,42\n30,6,64\n99\n5,95\n1,99\n16,84\n26,73\n12,7,76,5\n1,12,72,15\n6,79,15\n100\n26,74\n9,91\n100\n63,37\n50,50\n43,12,1,2,40\n6,3,4,31,26,29\n100\n44,55\n30,1,20,49\n43,1,40,17\n41,5,29,24\n38,14,18,29\n35,65\n18,38,2,43\n17,47,35\n72,28\n14,85,1\n25,74\n3,23,29,1,4,3,4,6,17,2,10\n82,2,2,3,11\n8,25,5,1,1,1,1,2,8,12,15,20\n27,29,19,24,1\n1,7,11,17,1,6,16,16,1,1,3,19\n34,2,2,7,8,5,4,6,18,13\n92,8,1\n7,3,18,26,6,17,20,1,1\n3,2,38,56\n100\n100\n100\n61,39\n100\n1,1,1,1,93,1,2\n42,11,45,2\n3,73,24\n100\n8,3,3,11,2,10,4,29,31\n100\n5,7,8,9,9,12,26,5,6,14,1\n100\n100\n100\n72,28\n20,23,1,57\n18,40,41\n20,15,28,8,5,20,1,1,1\n51,1,47,1,1,1\n62,35,1,1,1\n73,24,2\n7,8,6,19,56,4\n24,1,62,8,4\n18,5,5,55,10,7\n87,4,10\n2,40,47,11\n77,23\n38,19,43\n49,7,2,1,4,16,10,10\n20,52,21,3,2,3\n4,14,5,9,26,14,28\n69,2,29\n1,61,37,1\n10,10,1,78\n34,52,14\n7,1,26,65\n3,21,11,2,1,3,2,1,1,38,12,5\n57,1,30,1,9,1\n5,3,10,9,12,1,22,9,14,11,5\n35,57,8\n8,3,1,1,3,1,7,1,5,21,50\n3,14,2,1,8,1,51,14,1,1,4,1\n46,5,4,15,30\n3,2,10,12,2,2,1,3,45,19\n100\n100\n42,30,17,7,4\n5,3,4,31,57\n36,39,25\n44,15,27,7,7\n11,58,25,6\n3,4,1,2,79,4,2,2,3\n6,12,15,67\n55,9,8,9,12,8\n4,25,6,1,13,39,1,1,1,1,1,2,1,4\n80,2,2,4,12\n55,45\n3,97\n18,1,22,12,46\n75,25\n90,10\n83,12,1,1,2\n87,12\n26,13,62\n7,6,6,81\n19,6,75\n21,39,1,39\n41,58\n3,97\n38,62\n1,83,16,1\n100\n99,1\n81,19\n96,4\n39,9,21,28,1,1,1\n30,10,27,3,29\n21,12,19,15,33\n1,47,1,51\n100\n59,41\n56,44\n100\n100\n46,1,1,16,4,5,8,19\n54,25,21\n16,7,77\n26,67,7\n19,13,68\n41,1,58\n41,1,58\n1,56,8,1,35\n3,5,15,15,13,6,16,9,18\n17,6,9,6,62\n7,27,66\n19,13,14,54\n100\n6,94\n5,95\n64,19,18\n83,13,4,1\n6,10,23,27,20,4,3,7\n64,22,2,6,1,3,1,1\n23,4,29,37,7\n17,16,57,5,5\n37,5,51,7\n56,34,2,5,3\n80,20\n100\n82,18\n56,37,7\n2,1,1,1,1,95\n4,52,7,36\n1,22,14,40,23\n3,1,4,1,1,17,42,31\n12,15,18,39,15\n64,12,6,14,2,1,1\n15,6,6,16,27,11,2,16\n55,1,3,12,4,26\n25,28,1,29,13,4\n39,53,3,2,2\n10,68,1,21\n33,21,7,14,25\n11,6,22,11,26,24\n67,26,7\n18,15,68\n26,29,8,1,36\n3,2,3,23,23,7,2,36\n3,6,7,4,3,76\n5,13,17,1,1,1,1,4,58\n100\n100\n1,46,11,32,4,6\n1,1,88,4,7\n49,39,13\n39,13,43,4\n83,17\n14,53,34\n1,9,12,12,19,48\n6,79,15,1\n22,17,29,32\n45,7,18,7,22,1\n1,4,1,74,21\n38,62\n1,5,1,3,43,47\n83,17\n57,43\n14,10,76\n100\n100\n100\n30,68,1,1\n35,65\n22,78,1\n13,68,19\n1,3,2,94\n10,4,33,15,39\n51,1,17,31\n11,11,1,1,78\n1,1,1,26,72\n6,94\n100\n100\n72,1,27\n69,8,2,5,3,1,12\n1,1,1,98\n1,1,32,8,58\n100\n83,17\n1,67,32\n78,22\n86,14\n1,24,16,60\n13,3,83\n100\n7,40,20,32,1\n17,2,80\n20,1,7,22,1,14,6,9,21\n72,28\n2,1,72,20,2,3\n5,25,66,2\n7,39,54\n15,16,41,28\n100\n100\n75,25\n100\n100\n100\n100\n25,27,4,4,41\n53,23,23\n28,41,7,9,1,11,2\n7,6,24,37,26\n20,58,21\n31,56,8,4\n62,38\n9,1,1,3,1,1,23,9,53\n52,48\n100\n4,3,93\n59,13,11,16,1\n93,2,2,3\n6,94\n89,6,4\n29,1,70\n2,53,10,4,13,5,3,9\n11,3,1,1,1,12,72,1\n5,1,95\n100\n100\n3,50,2,15,6,5,7,5,4,2\n1,20,18,61\n17,12,45,21,2,1,1\n7,65,27\n8,35,4,9,28,10,6\n27,13,26,6,15,13\n15,14,8,1,47,10,1,3,1\n13,2,9,22,7,22,26\n8,7,3,1,3,16,10,52\n1,4,2,6,15,5,5,7,55\n36,19,1,1,43\n28,25,47,1\n45,1,53,1\n83,7,5,3,2\n52,1,1,8,1,37\n100\n9,1,21,53,16\n29,24,30,8,8\n100\n26,8,1,1,1,63\n11,4,3,1,80\n50,1,1,44,1,1,1,1,1,1\n13,7,3,39,2,5,31\n14,5,6,12,13,2,48\n18,7,6,10,12,6,18,7,15\n11,63,7,6,12,1,1,1\n87,1,7,6\n5,27,1,23,26,18\n14,5,6,5,5,9,9,46\n2,1,1,1,95\n13,8,28,4,5,42\n1,25,12,60,1,1\n1,86,13\n100\n51,49\n5,8,5,29,23,30\n45,49,7\n21,8,14,2,7,2,1,4,2,1,33,6\n4,1,3,1,44,48\n2,47,36,15\n43,7,19,30\n14,8,27,6,1,5,1,8,3,27\n54,5,1,1,4,28,5,2\n1,34,1,1,9,15,3,35\n14,40,46\n19,36,46\n26,28,46\n33,28,39\n7,7,5,79,1,1,1\n73,5,1,14,6\n16,25,58\n4,96\n59,41\n76,2,6,7,4,3,3\n13,23,27,1,31,6\n26,51,8,3,11\n48,6,17,2,6,3,3,16\n4,2,3,2,8,3,6,5,10,2,4,10,2,1,2,1,16,18\n42,33,1,25\n2,4,4,5,4,14,2,1,3,2,2,2,55\n1,6,17,16,1,1,5,51\n5,2,4,1,23,44,8,4,8,1,1\n5,1,11,15,1,8,39,1,1,1,19\n100\n100\n42,30,1,1,26\n23,1,76\n11,27,8,34,20\n100\n61,4,34\n82,18\n100\n100\n18,20,4,3,12,29,5,9\n55,45\n61,39\n40,37,11,2,10\n64,8,6,2,9,11\n80,5,1,13\n74,19,2,1,2\n14,82,4\n64,27,10\n2,2,18,21,9,47\n7,8,11,7,67\n27,3,69\n37,1,6,2,4,22,6,21\n6,2,31,14,47\n35,62,1,1\n6,73,17,3,1\n3,9,10,5,4,8,6,2,13,8,9,11,2,5,5\n15,2,20,12,8,5,16,2,20\n6,58,3,28,3,2\n1,5,7,4,4,8,3,7,8,53\n1,1,1,98\n12,73,15\n1,70,13,16\n21,12,56,11\n3,6,4,10,55,7,2,10,5\n100\n34,20,46\n100\n16,4,15,31,23,12\n11,10,41,1,1,36\n2,98\n22,10,1,7,4,4,4,14,18,13,3\n6,19,13,1,3,39,9,9\n33,67\n100\n56,44\n100\n2,3,5,3,3,1,14,47,10,5,7\n3,97\n2,6,26,9,6,8,12,32\n1,1,56,30,12\n5,18,16,61\n12,14,47,14,14\n100\n27,71\n27,18,3,4,17,5,21,1,1,2\n81,12,6\n19,1,1,4,1,20,6,1,9,4,11,23,4\n8,1,5,1,1,1,5,1,1,11,1,1,1,1,10,1,35,18\n3,97\n5,42,23,31\n55,1,7,2,10,2,1,23\n2,2,37,8,30,21\n3,1,12,15,4,7,11,39,8\n3,3,1,3,4,9,4,3,6,7,17,9,18,3,5,1,1,2,3\n6,19,17,11,47\n6,32,3,15,24,3,17\n30,3,18,23,22,3\n10,29,16,35,10\n42,9,39,3,6\n100\n11,1,6,31,41,11\n4,29,62,5\n41,4,8,14,21,11\n1,1,1,23,11,26,37\n23,26,1,36,13\n100\n69,30\n100\n5,95\n14,86\n100\n100\n100\n3,47,45,1,3,1,1,1\n1,2,35,54,1,2,4,1\n12,5,4,6,56,17\n1,39,32,28,1\n31,34,34\n3,1,15,16,4,6,5,31,20\n72,7,14,6\n21,62,1,4,4,8\n3,2,53,40,1\n5,3,2,90\n72,28\n96,4\n100\n7,91,2\n41,33,3,3,9,11\n53,16,4,10,6,2,2,5,1\n46,1,2,2,1,12,12,4,4,8,6\n100\n51,23,26\n2,2,96\n1,1,65,33\n100\n98,2\n100\n20,62,18\n1,31,5,62,1\n20,2,2,16,2,11,20,25,2,2\n1,29,42,14,1,13\n100\n100\n65,35\n3,7,10,13,3,4,11,4,44\n2,11,4,7,18,21,37\n4,18,5,5,62,3,2\n82,18\n4,11,2,1,1,58,1,24\n2,3,8,1,2,4,9,9,11,3,2,9,8,30\n7,11,22,11,5,3,3,39\n34,32,34\n40,23,36\n100\n25,1,40,14,20\n99\n90,10\n32,32,36\n50,23,18,8\n25,4,71\n28,5,18,48\n60,12,29\n1,99\n20,78,2\n34,64,2\n6,64,6,21,2,1\n14,42,3,3,18,16,2,2\n18,82\n5,4,32,51,2,2,4\n1,1,68,31\n100\n13,7,3,67,11\n7,1,1,2,3,4,26,21,31,1,2\n41,49,9\n6,94\n26,4,1,11,7,7,13,1,1,6,7,10,2,2,2\n19,2,2,8,1,7,6,10,2,4,2,13,1,13,10\n95,5\n94,6\n5,5,30,19,41\n15,16,9,10,8,6,11,2,13,10\n62,3,35\n65,34\n1,1,1,97\n1,30,7,9,11,1,41\n59,40\n20,15,4,5,9,1,13,34\n1,3,1,15,35,22,25\n100\n100\n29,1,1,19,51\n21,50,29\n8,11,1,1,60,18,1\n1,46,1,1,1,1,1,49,1\n1,4,46,17,17,15\n100\n100\n3,3,4,5,12,3,1,1,13,15,26,6,6\n31,38,19,12\n11,1,45,13,1,1,28\n24,15,4,2,1,9,8,31,6\n2,40,13,45\n49,12,39\n2,2,48,24,17,7\n1,1,37,61\n6,1,63,27,4\n8,92\n1,99,1\n13,5,8,25,9,6,34\n19,16,7,9,1,16,10,20,2\n29,5,2,3,2,3,37,3,3,3,8,1\n18,7,29,46\n13,38,50\n23,14,1,60,2\n57,43\n97,3\n6,21,7,12,54\n14,19,68\n1,39,7,1,7,1,23,21\n6,6,6,1,27,31,12,12\n100\n100\n6,46,47\n33,7,58,3\n2,98\n10,14,76\n95,5\n96,4\n23,65,11\n60,16,24\n40,1,41,11,7\n1,4,1,10,33,17,9,17,5,1,3\n53,42,5\n100\n5,40,1,7,19,7,19,2\n44,6,13,1,4,8,13,10\n40,12,4,2,14,6,7,14\n54,5,9,21,10\n9,34,3,44,5,5\n46,1,7,15,31\n15,13,21,50\n1,3,1,23,1,1,60,11\n2,2,8,16,5,16,2,9,1,37,2\n27,38,35\n19,9,4,4,5,43,3,13\n1,2,1,33,3,1,1,2,54\n40,1,37,12,9\n2,8,2,21,2,30,10,5,20\n12,11,77\n6,19,19,15,6,8,14,6,6\n10,10,1,5,1,11,6,16,30,10\n1,34,26,1,5,1,13,5,1,14,1\n41,33,27\n11,19,10,2,9,47\n3,3,3,34,3,3,3,29,3,18\n22,77,1\n31,69\n6,5,10,18,59,1,1\n42,1,27,1,29\n11,1,15,55,1,1,17\n1,65,1,33,1\n6,4,3,87\n6,6,9,4,20,19,5,3,1,1,19,7,1\n1,17,30,31,8,5,8\n19,34,16,11,4,4,11,1\n1,1,1,6,15,8,59,7,1\n1,8,55,1,1,8,1,2,6,15\n54,46\n26,19,7,33,2,12,2\n44,4,52\n30,42,14,5,9\n15,21,10,29,1,16,8\n19,11,2,2,8,3,1,1,1,2,5,3,4,2,6,3,13,5,3,5\n48,7,9,10,1,8,2,2,11\n30,1,1,68\n58,1,41\n31,10,58\n24,14,20,16,26\n6,1,1,28,30,15,10,9\n20,12,45,22\n20,73,5,2\n4,31,35,3,7,18,2\n9,24,42,26\n100\n27,62,10\n6,2,4,5,3,4,5,7,16,11,5,5,4,18,1,2\n2,5,24,4,15,32,17\n2,5,1,1,14,5,30,2,5,35\n14,8,6,4,1,20,31,17\n42,18,14,8,9,4,5,1\n1,20,16,21,41,1\n100\n100\n4,9,54,32\n18,1,7,11,10,9,43,2\n25,75\n15,1,1,4,2,39,36,3\n19,56,24\n30,5,6,16,16,8,1,6,3,2,7\n3,3,4,13,15,7,5,1,48\n7,26,1,1,63,2\n8,8,5,2,57,2,17,2\n59,23,5,12,1\n54,42,1,1,1,1\n18,17,4,6,5,6,18,4,12,2,3,3,2\n28,5,29,2,4,18,9,4\n1,3,78,1,10,1,1,1,1\n9,8,6,2,1,1,13,59\n29,28,15,24,4\n20,67,4,9\n2,16,7,15,18,2,2,29,3,7\n20,1,79\n2,49,2,2,11,19,2,11,2,2\n1,1,41,1,1,1,1,11,10,1,18,10\n20,20,2,3,2,11,2,2,2,39\n2,55,2,2,2,8,10,8,2,2,4,2\n59,1,13,10,1,1,15\n2,1,17,6,15,7,3,7,1,7,3,2,24,5\n20,36,8,3,13,17,3\n9,21,4,7,8,8,1,1,5,9,2,3,2,3,13,4\n9,44,2,1,21,22,1,1\n10,7,4,5,5,6,19,11,10,22\n35,1,1,6,1,56\n4,2,2,2,8,1,81\n13,6,27,43,9\n13,1,26,32,8,3,17\n7,2,65,11,14\n71,1,3,3,6,8,8\n34,32,3,31\n1,21,20,9,48\n6,2,40,8,6,8,1,11,17\n45,8,1,3,44\n1,1,5,92,1\n3,63,17,17\n54,1,29,6,3,1,3,1\n2,2,1,10,11,2,8,13,22,29\n6,12,3,15,9,1,2,4,11,38\n1,11,6,82\n11,1,34,6,48\n2,2,5,2,7,2,1,3,2,4,9,6,2,5,5,1,9,8,2,16,4\n2,2,4,2,9,2,5,2,1,15,11,1,2,17,6,12,9\n5,3,4,9,6,12,5,56\n12,60,19,9\n63,37\n32,30,7,30,1\n7,12,7,4,18,10,4,3,23,11\n12,1,11,6,11,2,4,2,49,2,1\n2,40,6,26,24\n3,16,5,34,17,7,4,3,6,4\n66,1,9,13,5,6\n39,60,1\n25,75\n18,81,1\n3,37,24,4,31\n76,16,8\n3,1,96\n97,3\n21,4,7,64,3\n42,11,46\n100\n97,2,1\n100\n100\n44,9,42,3\n29,71\n77,10,13\n18,82\n100\n92,8\n100\n1,1,97\n87,5,8\n5,95\n100\n100\n2,4,1,39,54\n1,7,4,9,25,54\n24,76\n52,2,34,12\n8,73,19\n1,3,4,84,9\n100\n17,1,5,29,13,4,7,4,6,14\n95,1,4\n1,53,24,9,5,8\n7,14,12,68\n10,9,32,8,4,37\n1,1,67,6,25\n44,29,12,2,12\n57,8,19,2,1,1,2,2,8\n25,74,1\n59,1,24,6,10\n17,15,52,1,3,2,1,1,7\n41,4,8,11,2,3,7,2,22\n31,10,1,11,30,2,7,8\n2,6,4,76,12\n81,19\n2,27,71\n17,9,28,28,18\n32,19,49\n45,32,4,19\n2,14,10,17,11,7,3,2,12,10,8,2,2\n8,3,4,42,42\n6,2,5,42,44\n26,12,32,5,2,24\n1,42,7,34,10,6\n4,5,54,37\n28,50,6,16\n17,14,1,1,29,39\n100\n100\n40,27,33\n54,4,24,18\n4,7,12,76\n3,23,7,8,13,2,5,27,12\n1,4,5,1,1,8,10,67,2\n100\n100\n90,10\n77,11,12\n63,8,6,13,4,6\n12,45,22,21\n28,47,7,13,5\n40,60\n71,29\n100\n37,30,17,16\n5,26,10,59\n34,36,30\n36,37,27\n66,34\n93,7,1\n100\n46,10,7,10,26\n25,24,4,10,12,8,5,1,1,10\n60,5,3,1,1,3,3,9,15\n1,1,1,97\n94,3,2,1\n5,4,6,85\n29,22,7,4,38\n4,30,17,2,5,31,1,11\n83,7,5,5,1\n13,26,22,29,9\n39,38,23\n22,45,1,33\n30,1,48,5,6,10\n100\n65,35\n2,3,36,19,20,6,5,5,2,1\n100\n18,9,9,7,1,15,9,11,1,15,5\n59,9,32\n23,3,13,14,28,14,4,1\n11,25,45,12,6\n1,33,4,2,21,23,16\n100\n33,8,60\n100\n5,95\n100\n36,11,20,6,17,1,7,1\n100\n11,8,81\n93,6\n1,1,75,24\n99,1,1\n3,5,92\n88,11\n100\n19,68,8,5\n11,18,26,11,10,24\n5,6,34,23,12,20\n64,7,29\n100\n7,1,31,62\n100\n74,26\n72,5,22\n2,34,5,56,1,1,1\n11,22,3,8,7,20,12,3,13,2\n24,35,15,6,18,2\n10,49,41\n100\n100\n100\n100\n100\n100\n99,1\n91,9\n100\n42,58\n3,3,14,3,13,64\n1,59,40\n14,5,3,8,70\n24,6,12,58\n8,4,4,85\n48,51\n62,38\n99\n1,10,7,7,76\n100\n10,90\n39,61\n24,4,4,2,1,1,2,14,49\n5,9,18,4,65\n6,13,11,32,4,1,32\n19,10,1,1,1,19,1,7,38\n14,9,1,1,1,5,1,1,1,1,20,11,11,5,16\n26,9,1,4,1,1,1,1,55\n100\n98,2\n1,1,56,16,17,7,1\n94,1,5,1\n2,21,2,2,11,2,38,22,2\n89,4,7\n12,9,55,12,12\n42,26,31\n46,1,9,11,12,12,9\n55,28,17\n100\n36,12,7,45\n53,46,1,1',Klb),p);f=(b&2)==0?null:(l=Zkb.n5('0,0,0,0,31,31,63,0,0,0,0,63,63,95,0,0,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0\n0,0,0,0,0,0,0,0,18,0,0,36,18,72,127,0,18,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,101,25,127,25,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,84,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,36,36,36,0,0,54,0,90,127,36,0,0,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,42,28,56,127,56,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,28,56,56\n0,0,0,0,0,31,0,0,15,0,0,15,0,0,0,0,15,15,0,15,0,0,0,0,15,0,0,0,7,0,0,0,0,0,0,0,127\n127,47,25,12,14,11,6,6,7,3,2,6,3,5,0,1,1,3,2\n99,127,68,57,46,27,38,30,13,12,13,23,15,12,14,20,28,34,43\n127,94,54,36,29,14,11,7,6,6,6,2,5,3,6,4,5,0,0\n127,60,20,12,4,1,1,3,1,1,1,4,2,1,3,0,4,1,2,1,2,3,0,0,0,2,0,1,1,2,0,1,2,4,3,6,27\n127,76,38,19,0,25,12,25,31,25,6,0,0,0,0,0,6,12,12\n127,29,4,4,4,0,8,4,0,8,8,0,0,4,4,0,0,0,0\n0,0,31,31,31,127,31,95,0,31,63,127,63,0,0,0,0,31,63\n115,127,80,34,23,11,11,0,23,23,34,23,46,11,23,0,11,23,0\n0,42,42,127,0,0,42,21,21,0,0,0,0,21,0,0,0,0,0\n60,127,48,84,36,18,12,6,24,12,0,0,0,0,0,0,0,0,0\n127,101,114,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,76\n127,12,25,0,0,12,25,12,12,50,25,0,25,12,0,0,25,0,50\n0,0,19,14,39,43,127,0,0,0,0,0,0,0,0,0,0,0,0\n0,42,127,42,127,0,84,42,84,0,0,0,84,0,0,42,84,0,0\n0,95,127,95,31,31,31,31,31,0,31,31,31,31,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,5,10,0,26,0,15,0,0,5,10,0,0,0,0,0,0,0,0,0,0,10,0,5,0,0,0,10,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,45,127\n29,14,4,0,0,0,19,9,9,43,9,14,29,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,39,127\n5,4,0,0,0,0,0,3,3,18,18,79,127,26,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n21,42,21,21,10,0,0,10,0,52,127,116,42,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,10,10,10,15,21,15,42,5,10,15,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,5,10,21,15,127\n0,0,0,0,0,0,0,0,0,12,127,38,0,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n15,0,0,0,0,0,0,0,15,31,15,63,31,47,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,31,63,31,15,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,25,0,50,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,25,50,127,0,0,0,0,0,0,0,0\n56,127,14,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,10,15,5,0,0,0,0,0,5,5,5,0,0,10,5,10,42,47,10,26,127\n0,7,3,46,76,7,0,0,7,19,53,103,127,23,23,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,6,6,26,46,13,60,46,73,73,113,106,127,73,80,60,20,13,20,20,0,0,0,0,6,6,6,26,26,26,53,33,73,73,66,106\n0,0,0,0,0,0,0,0,21,42,42,42,21,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,21,0,0,21,42,42,127\n0,0,0,0,0,0,0,0,127,14,14,0,0,0,0,0,56,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0\n0,0,0,0,0,0,0,0,50,50,0,0,0,0,0,25,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127,25,25,0,0\n0,0,0,0,0,0,0,0,0,0,7,9,14,25,21,9,0,0,4,2,0,0,0,0,0,0,0,0,0,2,0,11,37,61,117,127,122\n0,0,0,0,0,0,0,0,0,0,2,4,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,9,56,127,66,53,127\n0,0,0,0,0,0,0,0,0,39,127,78,0,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,35,127,31,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,11,11,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,5,23,44,82,127,59\n0,0,0,0,0,0,0,18,72,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n84,127,84,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0\n0,0,0,0,0,0,0,0,0,63,31,0,0,0,31,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,54,36,54,0,0,0,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,36,18,0,0,0,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,18,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,76,127,127,0,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,50,50,0,0,0,0,0,0,0,0,25\n101,0,0,101,0,0,0,0,0,0,0,50,50,127,0,25,76,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n72,0,0,0,0,0,0,9,0,0,0,36,127,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n42,0,21,0,0,0,0,21,21,0,0,105,0,21,42,0,0,0,21,0,63,0,0,0,0,21,0,21,0,0,21,0,0,21,0,0,127\n0,15,95,0,0,127,31,63,0,0,0,0,15,0,0,0,0,0,0,0,0,0,15,0,0,15,0,79,15,0,0,0,0,31,0,15,127\n0,0,0,0,0,0,0,0,0,42,0,127,0,84,84,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,84,127,0\n0,0,0,0,0,0,0,7,59,127,14,0,0,0,37,37,37,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,67,14,0,0\n0,0,0,0,0,0,10,0,95,84,0,10,0,0,0,127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,42,10,0,0\n0,0,0,0,25,0,25,0,101,101,50,76,0,25,50,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,50,127,0,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,25,50,25,0,101,127,50,76,25,0,0,0,0,0,0,0,0\n0,0,0,0,50,25,50,25,127,25,50,101,25,25,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,0,0,25,25,25,0,50,50,76,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,127,25,50,25,101,0,50,25,0,0,0,0,0,0,0,0\n0,0,0,0,0,42,0,0,42,0,42,0,84,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,42,127,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,42,0,84,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,63,63,127,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,63,63,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,0,127,0,0,0,63,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,21,42,21,21,0,21,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,0\n0,0,0,0,0,0,0,42,42,42,42,0,0,0,0,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,0,127,0\n0,0,0,0,0,0,0,42,42,42,42,0,0,0,42,42,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,0\n0,0,0,0,0,0,0,0,84,42,42,42,0,127,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,84,42,0,42,84,0\n0,0,0,0,0,0,0,70,28,84,56,56,98,14,28,28,84,70,0,42,0,0,0,0,0,0,0,0,0,0,28,0,127,70,14,28,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,32,127,8,16\n21,0,0,10,5,31,127,21,21,10,0,10,15,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127\n84,127,84,84,84,42,0,28,28,84,0,0,0,0,14,0,14,14,0\n127,31,0,0,63,31,31,0,63,127,0,0,0,0,0,31,0,0,63\n127,95,127,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,21,42,42,84,21,42,0,0,42,0,0,0,42,0,0,0,0,0\n0,0,0,0,0,0,0,7,47,7,39,63,71,47,47,23,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,15,39,63,127,63\n0,0,0,0,0,0,0,0,0,42,127,0,42,42,42,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,84\n0,0,0,0,0,0,0,0,0,34,57,92,127,23,57,11,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,23,57,46,69\n0,0,0,0,0,0,0,25,0,0,50,127,127,76,76,25,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,0,101,101\n0,0,0,0,0,0,0,0,0,0,0,127,127,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,127,63,63,0,127,63,63,0\n127,0,63,31,31,63,95,95,63,31,0,0,63,0,0,31,31,0,0,63,0,0,0,31,31,31,31,0,31,31,95,95,95,0,0,0,63\n0,0,0,0,0,0,0,0,0,0,0,79,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,63,42,63,21,42,21,127,84,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,63,21,63,42\n0,0,0,0,0,0,0,0,63,127,18,18,0,9,72,127,45,9,0,0,0,0,0,0,0,0,0,0,0,9,0,27,72,108,54,18,0\n0,0,0,0,0,0,0,0,0,42,0,42,0,0,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,0,42,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,42,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,127,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,0,63,0,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,63,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127,101,127,0\n0,0,4,4,8,0,12,16,76,105,110,55,97,59,110,84,105,16,8,4,4,0,4,0,0,4,0,0,4,0,12,38,55,127,101,38,84\n0,0,0,0,0,0,0,0,0,0,95,31,31,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,31,63,0,63,0,63,127\n0,0,0,0,0,0,18,54,127,90,90,18,18,54,54,54,36,0,18,0,0,0,18,18,0,36,0,0,0,0,18,0,0,36,36,90,36\n0,0,0,12,12,114,114,127,25,25,38,0,76,38,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,15,0,0,15,0,63,127,47,95\n0,0,0,0,0,25,0,50,0,0,0,101,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0\n0,0,0,0,0,0,25,0,0,0,0,127,127,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,25,25,0,0\n0,0,18,0,0,0,0,0,0,18,18,54,127,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,36,108\n0,0,0,0,0,1,0,8,8,42,91,75,61,58,127,24,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,22,72,56,77\n0,0,0,0,0,0,0,0,0,0,0,127,25,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,50,50\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,17,75,127\n0,0,0,0,25,0,0,101,127,127,25,25,0,50,25,25,101,25,25,0,0,0,0,0,25,0,0,0,25,0,0,0,0,127,0,50,101\n0,0,0,0,0,0,0,0,0,0,21,0,0,21,0,0,0,42,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,21,63,127,42\n23,0,11,5,0,23,23,80,121,127,51,75,57,57,75,127,63,40,34,40,0,5,5,0,0,0,5,0,11,23,34,5,69,63,57,46,34\n0,0,0,0,0,10,0,42,105,84,31,52,42,42,42,116,10,21,10,0,0,0,0,0,0,0,0,0,0,0,21,42,127,31,42,21,84\n0,0,0,0,0,0,0,42,84,0,84,84,21,0,21,42,105,21,21,42,0,0,0,0,0,0,0,0,0,0,84,63,42,63,21,21,0,0,127,63,105,21,0,21,0,0,0,0,0,0,0,0,0,0,42,63,21,105,21,42,21,0,21,127,42,0,21,21,0,0,0,0\n0,0,0,0,0,0,21,21,0,63,84,42,21,0,0,84,63,127,0,0,0,0,0,0,0,0,0,0,0,21,63,21,42,21,84,0,0,42,84,63,63,63,42,21,0,0,0,0,0,0,0,0,0,0,0,63,63,42,84,21,0,0,63,84,63,0,63,42,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,25,12,76,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127\n0,0,0,0,0,0,0,0,0,31,0,31,0,31,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,0,31,31,127\n0,0,0,0,0,0,0,0,0,0,15,15,79,79,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,47,127\n0,0,0,0,0,0,0,0,14,0,0,112,127,84,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,28\n0,0,0,0,0,0,0,0,0,101,101,0,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,63,12,0\n0,0,0,0,0,0,0,0,0,127,0,127,0,0,0,0,127,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,0,127,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,127,0,0,0,0,0,127,127,127\n0,0,0,0,0,0,0,0,0,0,0,63,63,63,0,63,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,127,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,26,43,127,13,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,71,127,31,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,84,0,127,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,127,84,84,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,84\n0,0,0,0,0,0,0,0,0,8,101,127,33,8,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,18,36,127,127,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,127,95,95,31,0,127,0,0,0,31,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,19,6,38,6,50,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,6,12,25,127\n0,0,0,0,0,0,4,9,0,0,9,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,63,127\n0,0,0,0,0,0,0,18,0,0,90,18,127,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,84,0,84,42,127,84,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,127,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,36,0,18,0,0,0,0,0,0,0,0,0,0,0\n0,7,28,0,7,0,7,21,0,14,0,35,7,0,28,14,7,28,0,28,7,14,21,0,7,0,7,0,14,7,0,7,28,14,7,7,127\n0,0,21,42,42,0,0,0,0,21,21,21,127,63,0,42,21,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,42,0,0\n0,0,0,0,0,0,0,0,0,15,15,0,0,15,111,111,127,47,15,0,15,0,0,0,0,0,0,0,0,0,15,0,0,15,47,0,31\n0,0,0,0,0,0,0,0,0,0,127,42,42,84,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,84\n0,0,0,0,0,0,0,36,0,54,36,36,108,127,54,36,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,36,127,108\n0,0,0,0,0,0,0,0,45,54,36,54,36,36,81,45,27,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,63,45,27,127\n0,0,0,0,0,0,0,0,0,0,12,127,101,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,12,114,127\n0,0,0,0,0,0,0,0,0,0,84,127,127,42,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,36,27,117,0,0,0,0,9,0,0,0,127,9,36,36,9,0,0,0,27,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,50,127,38,50,25,12,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,25,38,50,101\n0,0,0,0,0,0,0,0,0,0,0,31,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,84,127\n0,0,0,3,0,0,0,3,0,24,69,42,9,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,30,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,59,127,44\n0,0,0,0,0,0,0,0,0,0,42,0,21,127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,76,127,25,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,127,95,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,14,70,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,112,70,42,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,48,127,66,42,6,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,24,30,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,12,42,30,42,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,24,72,127,54,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,127,21,0,0,63,21,0,0,21,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,15,0,0,0,15,15,15,0,0,0,0,0,0,0,0,0,0,31,15,63,127,111,127,15,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,0,0,0,0,31,31,0,0,0,0,0,0,0,0,0,31,0,95,63,127,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127,50,25,0,0,25,0,0,0,0,0,0,0,0,0,25,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,28,0,56,28,70,84,112,112,56,42,84,56,112,28,42,0,0,0,0,0,0,0,0,0,0,0,28,42,70,70,84,127,112\n0,0,0,0,0,0,0,0,0,0,0,10,21,21,52,63,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,42,21,10,0,0,10,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,23,0,23,11,0,46,127,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,69,92,11,0,11,0,11,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,3,10,32,89,127,77,33,13,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,12,44,90,110\n0,0,0,0,0,0,0,21,127,84,0,0,0,42,21,127,0,21,21,0,0,0,0,0,0,0,0,0,0,21,0,0,42,63,21,21,0\n0,0,0,0,0,0,0,0,0,46,53,80,127,46,38,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,30,57,100,76\n0,0,0,0,0,0,0,0,0,84,84,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,127,42,0,127,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,42,42,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,31,0,0,0,31,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,31,31,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,31,95,0,0,0,63,127,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,127,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,15,15,47,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,127\n0,0,0,0,0,0,0,0,9,27,18,72,117,117,36,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,27,127,127\n0,0,0,0,0,0,0,47,63,111,127,47,15,15,79,63,47,31,15,0,0,0,0,0,0,0,0,0,0,0,31,15,63,63,63,47,31\n0,0,0,0,0,0,0,0,0,14,14,56,112,42,127,56,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,98,42,42,14,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,42,14,42,56,42,0,14,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,18,72,54,90,127,90,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,36,108,72,72,36,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,36,54,54,108,18,18,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,21,105,105,84,42,105,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,84,84,42,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,127,105,42,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,21,42,105,42,105,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,84,84,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,63,105,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,21,31,127,116,21,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,31,21,21,10,21,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,10,21,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,10,42,74,127,52,10,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,31,31,21,21,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,105,10,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,36,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,127,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,1,1,4,18,41,127,79,28,14,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,14,54,79\n0,0,0,0,0,0,0,0,0,1,4,46,127,46,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,49,104\n0,0,0,0,0,0,0,0,18,9,9,45,90,27,9,9,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,9,9,54,127\n0,0,0,0,0,0,0,0,127,0,0,63,0,127,63,63,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,63,127\n0,0,0,0,0,0,25,0,38,127,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,31,63,0,127,31,63,63,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,31,63\n112,127,84,56,70,0,42,42,14,14,14,0,14,0,0,14,0,0,0\n14,21,14,28,0,0,0,0,0,0,0,0,14,0,14,0,0,0,14,7,0,0,0,0,7,0,0,0,14,0,0,42,56,63,91,98,127\n127,95,63,95,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0\n0,127,108,54,36,0,0,0,0,36,0,0,0,0,0,0,0,0,0\n127,63,0,21,21,42,0,21,0,42,0,0,0,0,42,0,0,21,0\n127,31,0,0,0,0,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,95,0,95,63\n0,25,0,0,0,25,25,25,50,76,127,76,0,50,127,50,50,0,0,25,25,25,0,0,0,0,0,0,25,25,0,0,25,76,50,50,50\n0,0,0,0,0,0,0,84,84,84,63,0,0,21,63,21,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,21,63,127,42,0,0\n0,0,0,0,0,0,0,0,15,63,47,127,63,15,15,15,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,15,79,47,0\n0,0,0,0,0,0,0,0,0,0,31,63,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,63,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,4,0,4,31,58,127,54,40,9,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,18,45,117\n0,0,0,0,0,0,0,0,0,3,20,73,127,79,25,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,25,65,92\n0,0,0,0,0,0,0,0,0,8,50,42,127,50,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,84\n0,0,0,0,0,0,0,0,0,63,0,63,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,63,0,127,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,127,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,0,63,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,25,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,76,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,50,50,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,18,36,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,127,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,54,18,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,63,0,127,63,63,63,127,63,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,63,63,0,63,63,0,0,0,63,0,0,0,0,0\n0,0,0,0,0,0,0,0,63,0,63,63,0,63,63,0,63,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,127,63,0,127,127,63,63,0,63,0,0,0,0,0\n56,28,70,0,0,0,0,0,56,0,0,0,0,0,0,0,0,0,0,0,0,127,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,2,2,0,0,0,0,0,2,0,0,2,0,0,0,0,0,2,0,0,0,0,6,4,0,2,127\n127,20,9,5,11,3,3,1,3,0,0,3,0,3,3,3,1,0,0\n127,122,14,4,24,0,4,0,9,0,4,4,0,0,0,0,0,0,0,0,0,0,0,0,9,0,4,0,4,0,0,0,4,0,0,0,48\n0,0,0,0,0,0,0,0,0,0,0,69,127,92,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,92\n79,31,7,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,127\n31,15,0,15,63,15,0,15,0,47,79,79,47,15,31,63,63,0,127\n0,0,0,0,0,21,0,0,21,0,0,0,127,0,0,0,0,21,0,0,0,42,0,0,0,0,0,42,0,21,0,21,0,0,0,0,0\n0,0,0,84,84,0,0,42,0,0,127,42,42,42,0,0,42,42,0\n84,63,42,105,0,42,84,63,105,63,21,105,21,105,105,21,42,63,127\n84,42,0,0,0,0,0,0,0,0,0,42,127,42,84,0,0,0,0,0,0,42,0,0,0,84,0,0,0,0,0,0,0,0,0,42,0\n0,0,84,84,0,84,0,127,42,0,42,0,0,0,0,0,0,42,0\n108,36,63,63,45,99,81,127,63,90,18,63,63,27,54,54,81,45,54\n0,29,48,39,19,78,39,19,39,68,39,58,39,19,68,39,19,127,9,29,29,87,58,39,39,68,39,58,58,19,39,48,68,19,29,48,58\n75,127,110,70,94,64,48,48,78,51,91,86,72,75,105,54,56,64,43\n127,95,95,95,31,0,31,0,31,0,31,0,63,31,63,0,31,0,127,63,0,95,0,31,63,31,127,31,31,63,31,0,63,0,63,95,0\n127,0,31,31,31,31,63,63,0,0,31,0,31,63,31,0,31,63,31,0,0,63,63,63,0,0,0,0,31,0,0,0,0,31,0,31,63\n0,42,42,42,0,0,0,0,0,0,0,0,84,0,84,0,84,0,0,0,0,42,0,84,42,0,0,0,0,0,0,0,127,0,0,0,0\n0,7,49,28,35,28,49,56,49,21,14,21,56,77,42,127,42,0,84\n0,0,0,0,0,0,0,10,10,31,84,0,21,0,10,21,21,10,74,0,21,31,21,10,0,10,31,42,10,0,10,84,0,95,52,21,127\n42,0,0,84,0,63,127,42,0,0,0,63,0,0,0,0,0,0,0\n0,0,0,31,0,0,0,31,127,0,31,0,0,31,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,63,0,0\n0,0,0,0,0,127,63,127,0,63,63,127,63,63,127,63,63,0,63,0,0,0,0,63,0,0,0,127,0,0,0,0,0,0,0,0\n95,0,31,0,0,31,63,0,63,95,31,0,31,0,31,0,0,0,63,31,31,0,31,31,0,0,31,0,127,0,0,0,0,0,31,0\n0,0,0,42,0,42,127,127,84,0,0,0,0,42,0,0,42,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n13,23,63,127,26,40,16,16,6,3,0,3,3,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,63,0,0,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,63,127\n0,42,0,0,0,0,0,0,0,0,42,84,127,127,0,0,127,0,0\n0,0,63,0,0,63,0,0,63,0,0,0,0,0,0,63,63,0,127,0,0,127,0,0,0,127,0,63,0,0,0,127,63,0,0,0,127\n0,0,0,0,0,0,0,0,42,0,0,0,0,21,0,0,0,21,0,0,0,21,63,0,0,21,42,21,0,42,21,21,0,0,0,21,127\n0,0,0,0,0,36,0,0,0,0,18,18,18,18,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,108,0\n1,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,6,47,127\n2,0,0,0,0,0,0,0,0,0,0,0,7,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,12,30,127\n0,0,0,0,0,0,1,1,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,12,56,127\n127,16,4,4,1,0,4,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,24,18,9,7,2,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,10,2,3,2,1,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,1,3,5,5,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,11,41,127\n0,0,0,0,0,0,0,0,1,2,5,5,4,7,7,4,5,5,3,1,4,2,1,1,0,1,1,0,0,1,2,7,16,27,66,92,127\n0,0,0,0,0,0,0,0,0,0,0,3,3,3,0,0,6,0,3,3,0,6,0,0,6,0,0,0,0,3,3,6,6,18,9,6,127\n1,0,0,0,0,0,0,2,4,8,17,127,25,5,2,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n1,1,1,1,1,1,2,3,6,9,20,127,58,8,2,1,1,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n17,18,7,6,4,1,2,1,5,13,22,127,47,17,2,1,0,2,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,2,3,4,10,13,12,6,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,9,24,71,127\n0,1,2,0,4,3,7,22,64,127,111,55,19,8,5,6,12,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,7,0,3,3,0,3,10,0,0,0,0,0,0,0,0,0,0,0,0,3,17,7,10,21,38,67,59,127\n3,1,3,0,1,1,7,10,31,127,127,69,24,7,6,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n18,18,20,22,11,4,0,0,0,1,4,5,6,4,6,2,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,3,3,15,30,127\n2,3,2,3,1,0,2,10,13,29,70,125,127,27,5,3,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n7,3,9,5,7,1,0,0,0,1,0,0,3,5,7,12,16,32,30,52,47,70,90,92,59,127,85,116,50,38,25,32,29,21,18,23,18\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,30,15,86,71,60,127,86,96,55,50,30,45,30,35,20,15,0,0,0\n47,19,18,5,9,4,1,1,3,3,1,3,5,3,10,19,31,28,36,34,37,77,80,124,123,127,78,43,34,23,11,7,4,2,11,10,15\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,4,3,12,14,33,69,74,92,127,66,34,15,12,4,1,1,3,0,0,3\n31,42,92,127,42,15,11,5,4,9,5,3,2,3,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n24,8,47,127,35,15,15,3,7,21,5,0,3,10,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n60,35,102,127,73,31,25,16,17,25,6,6,8,12,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n9,19,21,127,78,34,7,7,14,24,19,12,7,26,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,9,0,0,0,19,0,48,48,87,78,107,127,87,107,39,0,19,29,9,0,9,0\n115,51,40,5,5,0,0,0,0,0,0,0,0,11,0,0,0,11,28,11,23,28,46,69,92,127,75,34,11,0,0,17,0,5,11,0,0\n0,36,36,18,0,36,0,36,18,127,54,0,18,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n112,127,56,0,0,14,0,0,98,28,42,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,67,42,25,76,127,33,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,33,127,59,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,63,31,127,0,31,31,0,0,0,0,0,0,0,0,0,63\n0,0,0,0,0,0,0,0,0,0,0,0,7,3,11,34,57,96,127,69,57,38,15,3,0,0,3,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,31,63,95,31,127,0,63,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,21,105,127,63,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,1,4,1,6,17,54,127,104,30,9,9,8,6,0,1,0,0,1,0,0,0,0,0,1,0,6\n0,0,0,0,0,0,0,0,0,0,22,82,127,119,97,52,67,29,29,7,7,0,0,7,0,0,0,0,0,0,0,7,29,14,14,7,14\n0,0,0,0,0,0,0,0,0,25,0,101,50,76,50,0,101,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,0,25,127,25,50\n0,0,0,0,0,0,0,0,0,0,3,3,11,9,2,4,1,2,0,0,0,0,0,2,1,0,0,0,0,0,0,0,3,10,34,43,127\n7,1,0,12,0,0,0,7,0,7,10,12,29,61,127,21,3,1,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,28,42,127,14,42,70,42,42,0,0,0,0,0,0,0,0,0,0,14,14,0,14,42,42,0,0\n0,0,0,0,0,0,0,0,0,0,0,127,127,84,84,42,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,28,0,14,28,0,70,28,127,14,56,0,0,14,0,0,0,28,0,0,0,0,0,0,0,0,14,28,28\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,95,127\n0,0,0,0,0,0,0,0,0,0,15,0,15,15,0,15,15,15,63,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127\n0,0,0,0,0,0,0,0,0,127,0,0,0,0,127,0,0,0,0,0,0,0,63,127,63,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,63,84,21,42,21,21,21,21,0,0,0,0,0,0,0,0,0,0,0,127\n0,0,0,0,0,0,0,0,0,0,11,0,0,34,34,69,127,92,103,92,34,11,11,11,0,0,0,0,0,11,0,11,0,0,0,0,115\n0,0,0,0,0,0,0,0,0,0,0,42,0,84,42,127,42,42,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,84,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,13,13,31,36,127\n0,0,0,0,0,0,0,0,0,21,0,127,21,63,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n24,24,0,0,12,6,60,78,42,120,127,127,72,30,0,0,0,18,0,6,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,1,0,1,8,17,11,1,4,0,1,0,1,0,0,0,0,1,0,0,2,0,0,0,2,3,0,18,127\n0,0,0,0,0,0,10,0,0,0,0,0,0,31,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,84,127\n0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,2,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,2,11,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,6,13,6,6,4,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,0,9,0,4,0,4,4,0,127\n0,0,10,10,10,0,0,0,0,0,0,0,0,0,0,0,0,0,10,10,21,42,95,127,10,52,0,10,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,3,3,6,25,3,0,0,0,0,3,0,0,0,3,0,6,0,3,19,53,69,127\n0,0,0,0,0,0,0,0,0,0,2,9,21,31,23,7,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,3,8,22,77,127\n0,0,0,0,0,0,0,0,0,0,0,0,18,0,18,0,0,0,0,36,0,0,0,0,0,0,0,0,0,18,0,0,18,0,18,127,36\n0,0,0,0,0,0,0,0,0,18,0,36,108,127,18,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,2,1,3,5,4,6,6,33,127,27,8,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,127,76,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,63,127\n0,0,0,0,0,0,0,0,0,0,0,12,12,63,25,12,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,21,21,42,42,42,127,42\n27,18,18,18,0,13,0,0,0,0,4,0,27,22,0,0,0,0,4,0,0,0,13,0,18,54,31,31,4,4,18,18,45,36,127,95,45\n127,5,0,0,0,0,10,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n19,29,19,0,0,0,0,9,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,0,31,0,0,31,0,127,127\n127,21,0,0,0,21,21,0,0,0,42,42,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,1,10,29,83,123,126,127,91,68,39,26,18,18,11,7,8,2,7,4,3,3,6,7,7,24,31,54,74\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,25,50,127,127,0,0,25,50,0,25,0,0,0,0,50,50,25,25,76,25,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,12,0,12,38,25,0,12,12,12,0,25,12,0,25,0,0,38,50,25,114,127\n5,6,5,7,11,16,30,19,29,49,65,127,113,35,16,20,5,3,3,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,11,0,0,0,11,23,11,11,57,127,0,46,34,69,0,0,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,1,1,5,31,127,16,0,0,0,0,3,7,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,2,3,0,1,3,5,11,9,33,43,82,103,107,57,43,19,9,8,14,7,2,1,3,3,1,2,2,3,8,5,14,45,37,76,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,7,7,21,42,35,127\n0,0,0,0,0,0,0,0,38,127,63,25,12,0,25,0,12,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,1,0,0,0,7,28,49,64,59,56,45,30,10,11,3,1,1,4,4,1,3,2,1,1,4,12,21,26,75,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,63,95,127,0,0,0,0,31,0,0,0,0,0,31,31,63,0,31,95,63\n0,0,11,3,11,7,23,59,79,71,127,99,87,19,11,19,31,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,1,1,3,11,12,28,26,20,18,5,15,9,1,0,2,5,7,4,5,3,0,1,10,20,24,39,91,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,79,47,127\n0,0,0,0,0,0,0,0,0,0,3,12,42,33,30,48,6,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,12,60,127,120\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,63,0,63,0,0,127,0,0,127,63,0\n0,0,0,0,4,0,0,0,0,19,58,63,73,107,127,83,43,39,39,14,14,24,4,19,14,9,9,0,0,0,0,0,4,9,14,34,48\n0,31,31,63,0,0,0,0,31,31,31,31,127,0,31,31,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n14,0,7,0,7,21,14,14,63,14,77,112,127,98,98,49,56,0,14,7,0,0,0,7,0,0,0,0,0,7,7,7,84,119,14,77,42\n0,0,0,0,0,0,0,0,0,0,21,21,42,42,21,42,63,42,42,0,0,0,0,21,0,0,0,0,0,0,21,0,63,42,21,84,127\n0,0,0,0,0,0,0,0,0,42,0,21,0,0,42,21,0,0,0,21,0,0,0,0,0,0,0,0,21,0,42,0,21,127,42,105,42\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,84,127,0,84,42,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,2,3,6,7,3,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,6,8,11,64,115,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,8,8,87,127,61\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,25,25,38,127\n0,0,9,0,9,0,0,0,0,0,97,117,39,29,29,127,9,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,95,31,95,127\n0,0,0,0,0,0,0,0,2,0,2,9,58,79,39,16,0,2,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,9,7,51,127\n0,0,0,0,0,0,0,0,0,0,0,0,10,63,74,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,52,127\n0,0,0,0,0,0,0,0,0,0,1,1,14,33,15,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,33,127\n0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,5,2,1,0,0,0,0,0,0,0,0,0,2,0,0,1,1,7,25,49,88,127\n0,0,0,0,0,0,0,0,3,0,3,15,7,3,3,3,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,19,19,127,84\n0,0,0,0,0,0,0,14,0,28,28,0,28,127,56,14,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,0,47,47,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,33,38,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,21,21,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,0,0,0,42,0,84,0,84,127,42,42,42,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,0,0,0,2,4,1,0,0,0,0,0,1,0,0,0,2,4,9,33,77,117,127\n0,0,0,0,0,0,0,0,0,0,0,63,21,63,127,21,63,42,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,84,127,63,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,21,84,42,21,0,105,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,95,95,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,101,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,50,25,0,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,25,50\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127\n127,0,0,0,0,0,42,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,50,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,127,54,54,54,127,36,54,36,18,0,18,0,0,18,54,0,18,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,7,0,0,127,10,29,3,21,10,10,3,3,108\n127,127,31,0,0,0,31,0,0,0,0,0,0,31,31,0,95,0,0,0,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n23,57,46,11,0,0,0,0,0,0,0,0,11,69,127,11,23,0,23,0,0,115,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0\n98,36,8,4,0,0,0,12,0,127,20,0,4,28,24,32,28,8,4,0,0,4,0,8,8,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,1,4,14,52,114,127,65,20,7,2,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,5,7,15\n2,1,0,1,2,1,2,1,3,4,4,46,127,25,3,2,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,4,18,127,125,77,39,27,2,7,2,0,1,0,1,1,0,0,0,0,0,0,0,0,0,2,1\n0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,50,25,50,127,50,25,0,25,0,0,0,0,0,0,0,0,25,0,0,25,0,0\n29,0,0,0,0,0,14,0,7,29,44,29,22,127,14,0,0,7,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,1,0,0,0,1,8,2,8,16,13,21,11,127,79,1,2,2,1,0,0,0,0,0,0,0,0,1,1,1,2,4\n0,0,0,0,0,0,0,0,18,127,66,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,42,21,63,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,63,127\n36,127,72,72,54,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,36,0,18,18,0,0,0,0,0,18,18,0,0,0\n79,127,43,14,6,0,6,4,0,2,0,2,2,2,0,8,0,10,4,12,14,16,39,41,83,60,60,60,14,16,8,0,4,0,2,0,0\n0,0,0,0,0,0,0,0,0,15,0,15,0,15,0,31,0,15,31,47,0,31,47,79,95,31,31,31,79,95,47,79,31,47,79,31,127\n56,14,112,70,28,42,98,127,42,84,14,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n3,5,10,23,7,3,0,0,3,1,0,0,12,127,17,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,1,2,6,16,38,54,29,10,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,6,19,68,127\n0,0,0,0,0,0,0,0,0,0,11,11,34,40,5,40,28,11,5,5,0,0,0,0,0,0,0,0,0,0,5,17,11,28,57,92,127\n0,0,0,0,1,2,1,0,3,8,19,127,77,14,6,7,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,2,11,16,24,127,82,11,24,11,5,8,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,6,0,0,0,0,0,6,0,0,0,19,82,95,88,82,12,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,57,101,127\n0,0,6,0,0,0,0,6,18,54,127,42,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,4,4,19,63,78,127\n127,63,0,15,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,0,47,47,79,95\n0,0,0,0,0,0,42,127,0,0,84,0,42,42,42,0,84,0,0,0,42,84,0,0,0,0,42,0,0,0,0,0,0,42,0,0,0\n127,49,24,38,9,10,3,1,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,24,13,32,6,4,3,0,0,1,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,21,42,0,127,42\n127,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,39,11,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,1,2,4,7,16,17,12,8,5,4,3,2,2,2,2,2,3,4,5,10,16,29,53,97,127\n0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,1,1,2,9,13,14,16,16,10,13,14,11,14,17,16,32,50,56,110,127\n0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,0,0,0,0,0,0,4,0,4,0,7,7,4,7,2,18,37,68,82,96,96,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,31,31,0,31,31,31,31,63,63,127,63,127,127\n0,0,0,0,1,1,2,3,5,6,8,50,127,14,3,1,0,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,6,5,6,9,2,5,9,17,22,26,56,127,22,11,4,2,3,3,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,1,0,0,0,0,5,4,15,35,114,127,33,6,5,1,1,7,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n15,7,4,8,0,0,0,1,0,3,6,127,72,10,3,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,1,2,8,12,18,28,21,19,12,11,7,7,4,3,1,2,2,3,4,6,15,15,26,41,65,115,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,22,0,7,44,14,37,89,104,127,82,29\n0,0,0,6,6,6,6,6,16,100,127,87,26,13,19,22,6,22,26,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,7,28,127,91,35,14,21,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,1,2,2,4,6,6,4,2,2,2,1,1,0,0,1,0,2,2,1,4,6,11,22,49,95,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,9,9,4,7,0,2,2,4,4,19,16,19,2,7,11,7,16,55,47,59,127,71\n5,3,4,12,10,15,18,26,69,127,116,51,15,5,6,1,1,10,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,4,16,8,4,29,76,127,101,29,16,4,12,21,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,2,4,3,3,8,8,8,3,4,2,1,0,0,0,0,0,0,0,1,2,3,3,8,19,49,91,127\n0,0,0,6,3,0,0,3,25,22,57,127,69,3,0,3,6,12,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,12,0,0,12,0,0,0,25,25,12,50,76,76,127,50\n0,0,0,0,0,0,0,0,15,0,15,63,95,127,31,0,0,15,15,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,31,95,127,31,63,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,4,0,26,96,127,61,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,54,0,18,18,0,0,0,18,0,0,0,0,0,0,0,0,0,0,36,0,36,0,127,54,72\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,9,7,2,0,9,2,4,9,9,4,21,17,26,36,51,39,83,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,23,7,23,39,39,47,71,79,55,87,87,79,127\n0,6,0,0,0,0,0,0,0,0,6,26,46,40,80,26,40,0,6,127,26,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,3,0,0,0,0,0,7,19,23,0,3,0,7,30,50,11,11,3,3,34,26,46,38,42,57,34,76,73,57,80,61,84,111,127,107\n0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,7,14,14,14,7,22,29,37,22,37,37,37,74,127,44\n0,0,0,0,42,42,42,84,84,0,127,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,47,0,0,0,0,0,0,0,15,47,47,63,15,31,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,4,6,11,19,9,16,26,43,39,32,43,27,29,32,33,27,44,55,53,75,92,114,127,107\n0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,10,0,0,21,10,95,84,31,0,63,127,116,42,42,31,21,42,10,52,0,42,42\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,63,31,0,0,0,31,0,127,31,0,0,95,0,0,0\n0,0,0,0,0,0,0,8,11,0,59,101,127,36,11,14,50,39,2,2,11,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n32,9,4,0,1,0,0,0,7,28,65,127,82,5,20,0,0,0,4,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n67,33,8,0,0,0,0,0,0,0,0,127,93,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,18,0,18,36,36,0,0,0,36,36,36,90,36,108,127,108\n0,0,0,0,0,0,0,50,25,0,0,25,0,0,0,0,127,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,21,76,127,114,80,12,8,12,0,0,0,0,0,0,0,0,4,0,4,4,0,25,42,71,110,127\n0,0,0,0,0,0,0,0,0,0,0,0,21,84,127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,21,0,84,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,127,42\n0,0,0,0,0,0,0,0,0,15,15,31,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,47,71,127\n0,0,0,0,0,0,0,10,0,10,0,0,52,127,116,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,84\n0,0,6,6,6,0,6,0,0,0,3,3,66,127,76,30,6,0,0,0,0,0,0,0,0,0,0,0,0,0,3,6,0,0,23,50,26\n0,0,0,0,0,0,0,0,0,0,0,0,42,127,127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,10,0,10,0,0,0,0,0,0,0,0,42,74,63,63,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,63,63,63,0,63,63,63,0,63,63,0,63,63,0,0,0,0,63,63,127\n0,0,0,0,0,0,0,0,0,0,0,127,105,42,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,95,127,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n21,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,52,127\n127,13,1,0,0,6,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n31,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,31,26,127\n63,127,52,10,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,3,1,9,1,13,4,6,2,8,13,11,9,17,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,5,1,0,0,0,1,5,30,42,75,127\n127,38,0,0,0,0,38,50,0,0,0,50,38,12,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,8,17,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,4,9,14,32,97,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,11,29,82,127\n127,21,17,17,7,8,8,21,38,1,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,9,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,11,52,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,19,65,127\n0,0,0,0,0,0,0,0,0,0,0,0,2,12,36,53,48,46,29,56,24,41,26,29,29,9,19,12,24,2,9,17,7,34,31,24,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,95,127,31,63,63,0,0,127,95,0,0,0,0,0,63,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,21,63,127,84,63,105,127,105,105,42,21,63,105,0,21,21,0,21,21,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,21,0,0,63,84,63,63,0,21,0,42,0,42,42,21,21,0,84,0,0,0,0,0,0,0,127\n0,0,0,0,0,0,0,0,0,0,0,25,50,25,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,50\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,15,3,127\n0,0,0,0,0,0,0,0,5,7,21,34,55,71,56,34,12,13,11,1,1,0,0,0,0,0,0,0,0,0,1,2,3,6,12,27,127\n58,28,6,3,0,0,0,0,1,3,10,123,127,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,42,42,0,84,0,0,0,0,0,42,84,0,0,0,0,0,0,42,0,0,0\n0,0,0,0,25,76,50,127,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,31,15,15,95,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0\n0,0,0,0,0,0,0,115,127,80,34,11,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,18,18,36,54,54,54,127,72,54,18,0,54,0,18,18,0,0,36,0,36,0,18,18,0,90,36,72,108\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,63,0,0,63,0,31,0,0,0,0,63,0,127,31,31,31,95,0\n0,0,0,0,0,0,0,0,0,0,1,1,1,11,13,11,11,8,1,1,1,0,0,0,0,0,0,0,0,0,0,0,1,5,11,18,127\n19,28,45,21,3,0,0,1,0,1,1,127,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,30,50,127,76,20,0,0,0,0,0,10,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,63,52,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,47,95,127\n0,0,0,0,0,0,0,0,11,19,69,78,112,127,78,34,19,9,3,0,0,0,0,0,0,0,0,0,0,3,3,1,2,4,17,21,53\n0,0,0,0,0,0,0,0,0,0,0,0,36,127,0,72,127,54,54,0,0,0,0,0,36,0,18,0,0,0,0,54,90,90,108,54,0\n46,18,16,4,0,0,0,0,0,0,1,127,104,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,89,40,36,7,0,0,0,0,0,0,22,22,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,36,63,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,4,0,0,0,0,0,0,0,0,27,90,86,99,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,13,26,60,113,127,100,46,40\n0,0,0,0,0,0,0,0,0,0,0,0,60,127,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,11,63,127\n127,114,12,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,12,0,12,12,12,50,25,12,0,25,12,12,0,12,0,0,12,0,0\n117,95,39,13,0,1,3,0,0,0,0,0,0,0,0,0,0,1,0,3,6,7,28,60,86,127,83,52,30,13,4,0,1,1,0,0,3\n0,0,25,0,12,0,0,0,0,0,0,0,0,0,12,25,38,38,50,0,0,0,127,76,114,114,127,38,25,12,38,0,0,38,12,12,50\n84,84,127,127,70,42,35,21,14,14,0,0,14,7,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,31,127,111,23,15,63,23,31,15,0,0,0,39,7,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,15,31,63,127\n0,0,0,0,0,0,0,0,0,2,7,15,29,35,23,10,3,1,0,1,0,0,0,0,0,0,0,0,0,0,0,1,4,12,35,82,127\n0,0,0,0,0,19,0,0,0,0,0,39,39,29,29,19,39,0,39,0,0,0,9,0,0,0,0,0,0,9,0,9,19,19,19,127,78\n34,0,23,34,17,0,0,0,5,5,28,127,51,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n6,3,2,1,1,1,2,2,4,12,35,127,44,5,3,5,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n7,2,0,0,2,1,0,2,13,26,79,127,63,6,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,1,1,0,1,8,12,15,21,10,6,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,2,9,19,46,87,127\n0,0,0,1,0,1,1,13,44,97,127,86,19,11,5,3,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,17,0,0,0,0,0,17,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,12,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,6,0,16,71,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,127,115\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,0,27,36,127\n127,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,40,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,127,84\n0,0,0,0,0,0,0,0,0,0,0,0,2,10,13,5,9,9,5,1,2,1,0,0,1,1,4,0,0,0,1,1,9,25,62,92,127\n0,0,0,0,0,0,0,0,0,0,0,5,13,12,34,60,94,127,92,69,59,53,41,33,25,21,18,19,23,16,22,30,36,40,65,94,81\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,10,0,42,52,0,31,74,127,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,7,3,7,48,78,127,56,29,33,33,26,7,7,3,3,0,0,0,0,3,7\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,0,0,3,0,7,0,0,0,0,0,3,0,0,7,43,35,51,75,127\n0,0,0,0,0,0,0,0,1,6,59,96,127,22,9,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,9,29,63,112,107,117,58,53,63,24,14,68,112,87,29,19,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,36,0,108,108,127,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,25,127,25,76,50,101,0,0,0,0,0,0,0,25,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,49,63,70,127,14,14,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,2,3,19,26,19,31,25,13,7,2,2,0,0,0,0,0,0,0,0,1,1,3,6,13,39,54,109,127\n0,0,0,0,1,0,0,0,0,0,1,5,13,23,43,78,116,121,111,115,127,90,48,45,33,55,40,50,38,36,31,33,48,41,66,63,63\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,10,31,52,127,74,42\n0,0,0,0,0,0,0,36,36,127,54,72,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,7,7,0,0,23,15,7,31,0,0,0,0,0,0,0,0,0,7,7,15,23,7,15,15,71,39,127\n0,0,0,0,0,0,0,0,1,0,0,1,2,4,11,29,56,38,22,23,9,5,2,3,4,3,0,1,2,0,4,4,11,22,31,76,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,31,31,95,63,95,63,95,0,95,31,31,0,95,0,0,31,31,0,127\n0,21,0,0,63,21,21,84,127,127,63,63,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,31,63,127,47,31,127,47,15,31,0,0,15,31,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,21,0,21,63,21,0,21,0,0,21,0,0,0,0,0,0,0,63,0,0,21,21,42,127,105,84\n0,0,0,0,0,0,0,0,0,3,0,0,8,29,42,78,73,89,39,49,29,17,13,10,3,5,5,5,15,10,6,15,24,32,96,89,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,0,0,14,3,0,11,11,11,37,26,11,3,26,3,26,26,11,18,70,74,127\n3,0,4,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,5,20,38,28,47,99,102,127,102,49,24,20,10,10,4,2,4,5,9\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,47,47,63,63,63,127,47,31,7,7,0,0,0,7,15\n14,14,44,89,82,89,67,127,127,52,0,14,0,37,44,67,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,9,0,9,0,0,0,9,9,19,19,9,0,19,68,127,39\n13,13,20,20,13,20,26,13,13,0,6,0,0,0,0,0,0,0,6,0,13,46,53,127,113,127,60,60,33,26,13,33,20,0,0,0,26\n0,31,0,0,0,0,0,0,0,0,63,31,63,31,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,127,50\n31,39,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,39,71,127,87,63,39,15,7,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,7,28,60,99,127\n0,0,0,0,0,0,0,0,1,1,2,8,22,29,23,10,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,8,14,37,97,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,0,15,15,0,47,47,127,95,31\n20,2,5,17,5,0,0,0,2,0,35,127,25,12,2,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n13,8,7,4,2,1,1,3,7,20,29,127,36,3,1,0,6,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,2,0,0,0,0,0,2,12,32,127,51,6,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,1,0,0,1,0,3,0,3,25,25,12,3,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,6,3,18,43,127,106\n0,0,0,0,0,3,0,6,20,99,96,127,123,0,0,6,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,1,0,8,10,12,9,8,4,3,1,1,1,0,0,1,1,0,1,0,0,1,2,7,14,37,56,96,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,25,0,0,63,50,63,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,14,3,14,7,14,18,89,127\n0,0,0,0,0,0,0,1,0,1,13,127,55,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,1,0,1,6,8,20,26,25,11,8,6,1,1,0,0,0,0,2,0,0,0,0,0,1,0,5,16,33,66,104,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,25,25,25,76,127,127,0\n0,0,0,0,0,0,0,0,0,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,127,108\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,59,42,76,127,50,16,16,84,16,33,25,42,16,25,0,76,16,42,59,16,76,67\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,12,50,0,63,127,0,12,0,0,12,12,0,0,0,0,0\n54,18,9,27,127,99,90,127,45,9,4,22,9,36,36,22,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,25,25,0,50,0,0,0,76,50,0,25,25,0,0,25,25,0,0,25,0,0,25,50,25,127,101\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127,84\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,36,127,108,36,18,0,0,18,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,42,0,42,42,0,0,84,42,0,0,0,0,42,127,42,84,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,84,42,42,127,84,84\n0,0,0,0,0,0,0,0,10,0,0,0,0,0,10,10,10,45,50,45,55,25,30,20,30,35,20,10,30,40,60,96,40,127,101,55,121\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,50,50,50,76,127,76,50,101,101,0,50,50,50\n0,0,0,0,0,0,0,0,0,0,47,127,31,15,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,63,84,105,63,21,21,0,0,21,42,63,0,0,63,21,21,63,0,127,42,42,84,42,63,21,42\n0,0,0,21,21,84,21,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,9,9,9,58,39,48,48,68,39,39,39,39,39,9,68,87,58,117,68,87,127,78,19,0\n9,0,0,9,4,4,0,0,9,18,27,127,90,9,9,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,15,31,15,31,31,111,63,15,63,127,0,0,63,31,95,47,0,31,0\n0,7,0,0,0,0,0,0,3,11,34,23,38,50,42,34,11,11,0,0,0,0,0,0,0,0,0,0,0,3,0,7,11,23,96,127,92\n0,0,0,0,0,0,0,0,0,0,0,0,0,90,54,0,0,36,0,0,18,0,0,0,0,0,0,0,0,0,0,0,18,36,54,127,36\n0,0,0,0,0,0,0,3,0,0,9,0,127,74,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,84,127,127,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,9,9,9,39,0,9,9,0,0,19,0,19,39,127,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,3,56,89,37,7,3,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,18,82,127\n0,0,0,0,0,0,0,0,0,0,0,0,56,127,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,14,112\n0,0,0,0,0,0,0,0,31,0,0,63,0,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,127\n0,0,0,0,0,0,0,0,0,0,0,0,15,95,31,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,31,15,0,31,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,127,0,0,127,63,127,63,127,127,127,63,127,0,0\n0,0,0,0,0,0,0,0,0,0,42,42,127,42,0,21,21,42,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,116,84\n0,0,0,0,0,0,0,0,0,0,0,0,50,0,101,25,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,25,76,127,50\n0,0,0,0,0,0,0,0,0,0,0,25,25,127,76,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,76,101\n0,21,0,0,42,21,0,21,21,0,42,21,0,0,0,84,21,42,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,26,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,20\n127,81,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,27,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,45\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,6,14,38,87,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,3,10,10,29,32,120,127\n127,95,111,31,79,0,15,31,0,15,0,31,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,63,63,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,95,63,31,95,95,95,127,63,63,31,0,31,0,31,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,76,25,25,127,127,50,101,25,101,76,50,50,0,0,25,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,3,3,5,11,55,44,34,17,7,13,1,1,0,0,0,0,0,0,0,1,1,9,3,15,21,86,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,28,127,42,56\n0,0,0,0,18,27,0,0,0,18,72,72,127,18,72,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,4,9,21,43,39,26,21,7,2,0,0,0,0,0,0,2,0,0,0,7,2,14,29,73,107,127\n0,0,0,0,0,0,0,0,3,8,14,50,117,127,93,53,20,8,4,0,0,0,0,0,0,0,0,0,0,0,2,0,4,18,32,47,61\n0,0,0,0,0,0,0,0,0,2,3,110,127,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,25,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,44,44,93,127,60,33,16,22,5,0,0,0,0,0,11,5,0,0,0,22,0,11,5,16,22\n0,2,0,0,0,0,0,0,0,6,0,24,127,11,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,5,55,99,127,22,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,2,9,36,84,127,103,62,35,19,4,5,5,0,0,0,0,0,0,0,0,0,0,0,0,5,1,4,11,2\n0,0,0,0,0,0,0,0,0,0,15,31,23,127,39,63,47,55,31,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,23,7,95\n0,0,0,0,0,0,0,0,0,0,0,80,127,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,12,0,67,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,26,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,7,14,127\n95,95,127,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127,50,25,0,0,0,0,0,0,0,50,0,0,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,95,127,63,31,0,63,0,31,0,0,0,0,0,0,0,0,63,0,0,0,95,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0\n91,127,101,60,30,30,30,30,15,10,15,20,10,20,25,20,25,10,30\n46,23,11,0,23,0,0,0,0,0,0,0,0,0,23,23,127,34,115\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,31,31,63,31,31,0,0,0,31,31,0,127\n42,127,112,112,84,42,98,98,56,84,14,28,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,14,56,70,70,84,70\n80,127,57,57,34,69,57,34,34,57,46,34,0,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,34,23,80,57,69,92\n42,0,0,84,42,84,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,50,0,50,50,50,76,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,25,0,25,0,0,127,25,0,0,0,25,76,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,8,8,16,33,16,67,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n63,0,42,0,0,0,127,21,0,0,21,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,21,21\n0,0,0,0,0,0,0,0,0,0,0,0,15,55,111,127,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,14,70,42,42,0,28,98,127,98,0,0,0,0,0,0,0,0,0,0,0,14,0,28,0,14,0,14,0,14,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,38,25,12,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,127,90,0,0,0,0,0,0,0,0,0,0,0,54,0,0,0,0,36,18,0,0,36,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,76,0,101,127,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,42,0,0,127,42,127,0,84,0,0,0,42,42,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,0,42,42,127,42,21,0,21,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,21,0,21,42,84,63,127,42,105,127,63,21,21,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,63,31,63,0,31,127,31,95,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,76,127,76,50,0,25,25,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n99,27,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,5,5,5,11,44,71,127,88\n0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,84,0,84,0,0,42,42,84,42,127,0\n0,0,0,42,127,84,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,42,42,0,42,0,127,84,127,42,0\n21,21,0,0,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,21,84,84,127,84,84,0,63\n0,0,0,0,0,0,0,0,0,0,0,127,101,0,76,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,21,0,0,0,0,0,0,21,0,42,42,42,63,42,21,127,84\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,14,14,14,0,0,0,28,28,56,84,112,127,42,56\n127,15,15,0,15,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,15,0,15,47,63\n0,42,42,42,127,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,0,0,42,0,0,42,42,42,42,42\n0,0,0,0,0,0,0,0,0,18,18,72,127,72,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,18,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,25,76,127,101,76,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,31,31,127,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,4,0,9,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,14,65,127,79,32,23,0,4,4,9,0,0,0,0,0,0,0,0,0,0,0,4,0,4,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,12,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,12,38,38,127,63,76,12,12,25,12,12,0,0,12,0,0,0,0,0,0,25,0,0,0,12,12,0,0,0,12,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,31,95,0,0,127,31,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,0,31,31,0,127,95,0,0,0,0,31,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,25,76,0,0,0,25,0,0,0,0,25,50,0,25,0,25,127,50,25,0,25,25,25,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,0,31,31,0,127,63,63,31,63,95,95,127,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,95,127,0,31,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,31,31,0,0,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,42,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,50,50,76,50,76,0,25,76,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25\n76,25,0,0,50,50,127,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n105,127,84,63,0,0,21,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,21\n63,127,42,21,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,21\n0,0,0,25,0,25,127,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,84,127\n0,0,0,0,0,0,0,0,0,0,11,34,11,69,127,127,34,11,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n108,127,54,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n50,50,25,76,76,127,25,25,127,0,50,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,76,25,25,25\n127,31,31,127,127,31,127,127,63,31,63,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31\n31,31,31,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,0,31,127,0,0,63\n63,127,127,127,127,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,0,0,0,63,63\n0,0,0,0,10,0,0,0,0,0,0,0,0,10,52,21,74,84,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,13,48,127,109,43,4,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,111,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,39,127\n127,84,74,10,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,10,10,10,10,21,52,10,84,116,127,105\n31,63,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,31,95,127,31\n25,0,50,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,76,127,101,76,25\n0,0,0,0,31,0,95,31,0,0,63,127,31,0,63,31,0,95,0,0,0,95,0,0,31,31,0,0,0,0,0,31,127,31,0,0,63\n127,26,24,25,44,65,86,77,49,25,9,4,0,0,0,0,0,0,0\n0,0,0,0,1,3,4,19,54,106,127,112,80,53,22,16,13,12,16\n0,0,0,0,0,0,0,2,4,9,19,35,83,108,127,94,72,67,68\n0,1,0,0,0,1,2,9,18,24,63,110,127,117,69,43,27,26,29,27,28,29,31,23,23,20,9,8,3,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,1,5,8,32,56,70,95,109,127\n0,0,0,0,0,0,0,0,0,2,4,9,27,34,61,69,91,96,127\n127,19,4,11,2,0,1,1,0,2,1,1,0,0,0,0,0,0,0\n127,37,15,15,13,6,5,11,23,16,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,15,32,25,34,82,101,127,89,36,24,42,20\n0,0,1,0,15,29,109,87,13,13,127,101,27,29,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,116,52,52,31,31,31,63,10,10,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,42,42,63,127,127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,0,63,0,42,42,105,42,0,0,42\n36,90,0,127,36,18,0,0,0,0,0,18,0,0,0,0,0,36,36\n0,9,9,16,11,37,84,127,105,65,30,28,14,14,4,2,0,4,4\n0,0,0,0,0,0,0,11,0,0,23,23,127,57,11,0,0,11,0,0,0,0,0,0,11,0,0,23,11,0,0,11,0,0,0,11,0\n0,8,8,16,25,76,67,76,127,101,25,67,42,50,42,8,8,25,16\n0,0,0,0,0,0,63,127,31,63,127,95,31,63,0,0,0,0,95,0,63,31,63,31,95,63,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,50,25,25,50,127,25,76,101,50\n0,1,0,3,7,4,16,27,74,91,127,100,123,76,56,35,29,27,47\n0,0,0,0,0,0,0,0,36,72,72,54,127,72,18,54,18,18,36,36,0,18,36,108,127,90,54,54,18,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,10,31,63,116,21,63,21,42,127,63\n63,63,0,63,0,63,127,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,127,0,0,0,42,42,84,84\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,14,7,21,21,14,35,14,49,127\n11,9,8,13,15,24,41,68,84,100,103,127,115,93,62,53,27,29,19\n127,25,88,25,12,25,12,50,12,25,12,12,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,45,45,63,63,127,72,127,63,36,81,63,45,90,108,127,63,54,81,81,18,9,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,6,0,46,66,80,113,73,106,66,127,13\n6,9,9,12,19,31,47,57,50,44,92,127,66,82,85,95,66,88,101\n28,98,70,127,42,56,56,14,28,28,0,14,14,0,14,0,14,0,0\n0,0,0,0,0,25,0,0,25,0,0,0,0,25,0,25,25,101,0,25,0,50,25,25,127,25,76,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,42,42,42,0,84,42,42,127,0,84,84\n93,97,98,116,124,122,127,115,125,96,62,48,10,14,3,5,3,5,2\n0,0,0,0,0,0,7,7,28,63,77,127,77,56,21,28,14,0,7,42,14,7,7,28,35,21,49,28,0,7,28,14,7,14,7,7,14\n21,21,10,0,0,0,0,0,21,10,21,42,52,52,10,95,84,42,127\n63,127,119,103,103,95,63,71,87,71,79,55,63,55,0,23,15,23,0\n0,0,0,0,0,0,0,0,0,0,0,0,21,42,42,0,0,0,21,0,0,0,0,0,127,0,0,0,0,0,0,0,0,0,21,0,0\n40,20,32,36,45,86,73,127,36,16,24,12,16,4,8,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,9,9,0,9,19,127,107,87,78,107,19,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,81,38,33,29,10,5,1,2,0,7,0,7,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n31,47,63,127,31,47,63,31,15,0,15,31,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,79,31,111,127,79,47,31,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,12,25,0,0,38,25,12,0,25,12,12,50,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,6,7,8,8,10,15,16,20,54,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,1,0,4,4,6,18,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,6,127\n127,27,0,45,36,27,18,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,87,7,23,7,15,7,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,1,5,18,50,109,127,108,57,39,29,20,15,12,14\n0,0,0,0,0,0,5,0,0,5,28,46,63,80,86,46,34,57,40,63,28,40,23,57,127,51,23,5,11,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,4,7,23,52,57,88,59,59,127,100\n16,17,13,20,26,83,108,127,96,93,80,55,58,34,37,20,11,4,4\n0,0,0,0,0,0,0,0,14,14,42,127,112,98,56,42,28,70,0,14,14,0,28,70,42,98,28,14,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,25,0,0,127,50,25,76,25,25,50,50\n0,2,4,0,0,2,2,31,119,127,63,19,26,12,13,7,2,0,1,3,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,18,108,81,127,117,36,54,54,27,18,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,2,1,2,4,16,16,22,58,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,29,14,22,127,59,44,52,29\n127,95,127,63,31,95,95,95,31,31,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,127,127,95,31,31,0,0,0,0,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n63,31,0,0,0,0,31,127,31,63,31,31,63,0,0,0,0,0,0,0,0,0,0,0,31,0,0,63,63,63,127,127,31,0,0,0,0\n0,0,0,0,0,0,0,0,84,127,118,50,8,8,8,0,0,0,0,0,0,0,16,0,0,8,8,8,8,0,0,8,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,50,101,25,127,0,25,25,25,25,50,25,0,0,25,50,76,0,0,25,0,25,0,0,0,0,0,0,0\n0,0,0,0,0,0,9,21,86,107,127,32,17,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,19,58,48,68,19,127,68,48,39,107,19,0,9,29,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0\n31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,15,0,31,31,127,31\n0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,42,0,0,0,0,0,127,0,0,0,84,0,42,127,0,0,42,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,127,63,63,31,31,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,31,31,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,31,0,31,95,0,127,0,0,31,31,0,0,0,0,31,0,0,31,0,0,0,0,0,0,0,0,0,0\n0,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,17,0,0,11,127\n0,0,7,0,0,0,0,14,42,56,14,35,7,77,0,14,7,0,0,0,7,0,7,0,0,0,0,21,7,0,0,14,7,35,0,14,127\n0,0,0,0,0,0,12,12,0,38,101,127,12,0,0,0,0,0,0,0,0,0,0,0,0,12,12,12,50,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,28,35,105,14,63,127,14,28,28,0,14,28,28,35,35,21,42,14,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,46,34,23,115,57,115,57,69,127,34,23,11,23,11,11,57,11,0,34,11,0,23,0,0,0,0,0\n31,0,0,0,0,0,0,0,21,15,21,42,21,15,26,0,5,5,5,0,10,0,5,5,0,10,5,5,5,0,0,0,10,5,5,63,127\n0,18,0,0,0,0,0,18,18,72,0,127,54,18,36,36,18,36,18,0,0,18,0,0,0,36,18,18,0,0,0,0,0,18,18,18,72\n0,0,0,0,0,0,0,0,0,0,0,42,127,42,84,0,0,0,42,0,0,0,42,0,0,0,0,0,0,0,84,0,42,0,0,0,0\n0,0,9,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,127\n127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,7,0,7,7,42\n28,0,0,0,14,14,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,127,127,56\n0,0,0,0,0,0,0,0,0,0,0,0,14,56,127,42,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,23,103,127,46,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,0,0,0,0,5,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,15,0,15,47,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,42,42,105,127\n127,52,74,31,42,10,10,0,21,52,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,31,10,10,5,0,0,5,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,15,0,0,0,31,0,127,79,47,95,15,15,15,0,0,15,31,31,47,15,31,31,0,0,0,0,0,0,0,31\n0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,95,127,31,63\n0,0,0,0,0,0,0,0,63,0,95,127,0,31,0,0,0,0,0,0,0,0,0,0,31,31,0,31,0,0,31,31,31,0,0,0,0\n0,0,0,0,0,31,0,31,31,0,63,127,0,0,0,31,31,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,31,0,63,63,0\n127,55,13,21,7,0,2,5,5,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,15,7,55,31,0,0,0,15,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,12,12,88,127,63,50,38,63,25,25,38,0,50,38,0,25,12,0,12,12,0,0,12,12,0,0,0,0\n0,0,0,0,0,0,12,6,6,12,6,12,0,6,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,12,0,0,0,6,127\n0,0,0,0,0,0,0,21,63,21,0,21,127,21,21,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n63,95,15,31,0,0,0,31,127,111,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,3,14,59,81,69,31,13,7,4,1,1,0,0,0,0,0,0,0,1,0,2,3,7,18,38,71,127\n10,4,1,0,0,1,10,9,5,9,34,37,78,58,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,1,5,20,71,127\n54,9,0,0,0,0,0,0,0,0,0,9,9,9,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,63,127,127\n127,7,6,2,0,0,0,0,0,0,0,0,2,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,9,22\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,15,0,127,63,15,0,0,0,15,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,31,15,15,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,127,0,0,0,0,0,0,0,0,0,0,0,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0\n0,0,0,25,0,25,0,0,25,0,0,50,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,0,0,127,0,0,0,0,0,0,0,0,0,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,14,84,127,127,42,14,127,56,0,0,0,0,0,14,0,0,0,14,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,19,82,127,76,12,0,25,0,0,0,0,6,6,0,12,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,27,27,27,72,54,18,9,0,54,0,0,0,0,0,9,9,18,9,0,9,0,0,0,9,27,117,127,90,27,0,9,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,4,14,23,37,18,0,4,37,9,4,0,0,0,0,0,0,4,0,0,0,0,0,23,103,127,79,14,32,0,0,0,0,0,0,0,0,0,0,0\n1,6,3,1,3,3,6,13,19,17,89,127,89,26,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,3,14,9,21,17,13,3,4,3,1,0,1\n2,5,10,4,1,4,5,16,10,43,68,127,65,59,4,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,10,16,10,13,2,7,0,1,0,7,5\n25,0,0,0,0,25,50,25,0,0,25,25,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,127,0,0,0,0,0,0,0,25\n42,0,0,0,0,42,0,0,127,42,42,84,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,0,84,42,0,42,42,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,11,0,0,0,0,0,11,11,11,23,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,23,127,11,23,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,127,127,0,42,0,0,0,0,0,0,0,0,0,0,0,0\n0,5,11,2,5,2,2,11,14,23,77,127,57,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,17,25,31,11,2,5,0,0,0,0,0\n6,0,15,6,3,6,12,15,21,60,87,127,66,21,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,9,24,33,12,9,0,0,0,0,0,3\n0,0,0,0,0,0,25,76,25,101,76,101,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,127,25,25,0,0,0,0,0,0\n0,0,0,0,0,0,25,0,127,127,101,76,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,76,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,42,127,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,42,0,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,84,0,42,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,42,42,127,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,25,50,127,25,50,50,50,50,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,50,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,76,101,25,0,25,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,21,0,21,42,127,21,0,63,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,21,21,63,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,84,42,21,21,0,0,0,0,0,0,0\n0,0,0,0,0,0,42,0,21,21,127,105,42,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0\n31,0,0,0,0,0,0,31,63,95,0,127,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,21,21,105,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,127,0,0,0,0,0,0,0,0\n34,36,4,0,2,0,0,0,2,2,4,7,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,83,127\n50,0,0,0,0,12,0,0,25,12,50,127,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,4,13,127,103,7,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,3,1,5,5,1,7,1,0,0,0,0,1,1,1,0,1,5,3,1,10,9,18,19,127,70,34,5,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n12,5,3,3,1,1,5,9,39,89,110,127,53,16,1,5,7,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,127,31,21,31,21,21,0,0,0,0,0,0,0,0,0,0,0,21,10,10,0,21,31,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,63,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,31,127,0,31,31,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,18,72,72,99,45,18,18,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,27,108,127,63,45,27,0,0,0,0,0,0\n0,0,0,0,0,0,0,9,81,27,127,45,18,9,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,45,108,63,18,18,9,27,0,9,0,9,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,54,127,90,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,25,0,0,0,25,0,0,50,76,101,127,50,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,63,105,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,25,0,0,0,0,0,101,50,101,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,25,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,127,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,84,0,42,42,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,8,16,8,8,0,0,0,0,0,16,0,16,0,0,8,42,25,59,42,127,93,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,21,10,10,10,10,0,21,0,0,42,42,0,0,21,10,21,42,10,31,74,127,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,4,0,9,13,9,22,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,18,45,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,127,63,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,127,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,76,50,0,0,25,0,0,0,0,0,0,0,0,0,25,0,25,50,25,50,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,127,45,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,127,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,42,0,0,0,42,0,0,0,0,0,0,42,0,0,0,0,0,0,0,84,0,0,0,0,0,0,0,0,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,0,42,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,2,4,3,0,2,0,0,0,0,0,0,0,0,0,0,0,1,2,4,10,53,127,49,3,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,5,0,11,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,11,16,16,77,60,104,66,44,11,0,0,5,0,0,5,0,5,0,5,0,0,0,16,55,82,127,60,16,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,25,88,127,101,50,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,28,0,0,0,0,0,0,42,28,84,127,98,28,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,4,25,21,127,110,30,4,2,4,4,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,8,35,105,127,73,13,0,3,0,3,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,11,79,31,19,11,3,0,0,0,0,0,3,0,7,3,0,7,0,0,0,3,0,23,31,23,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,35,127,115,55,43,11,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,6,0,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,108,127,17,3,1,0,0,0,0,0,0,0,0,0\n0,0,0,13,0,9,4,0,18,31,49,40,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,31,45,49,9,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,9,63,99,127,90,49,22,9,0,0,4,0,0,0,0\n0,0,0,0,0,4,9,9,14,23,42,56,28,9,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,14,18,42,14,18,4,9,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,18,61,127,89,51,47,28,4,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127,76,101,127,50,0,0,0,0,25,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,127,50,76,101,0,0,0,0,0,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,21,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,21,74,31,52,10,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,10,74,127,10,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,6,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,4,13,9,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,18,127,111,7,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,2,6,12,39,69,127,84,45,21,7,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,5,13,37,72,83\n0,0,0,0,0,0,0,0,0,0,18,127,127,36,36,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,36,36\n0,7,0,0,0,0,0,0,14,22,97,89,82,82,59,127,14,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,7,104,82,74,59\n0,0,0,0,0,0,0,0,1,3,5,7,9,18,16,19,10,10,12,0,0,0,0,0,0,0,1,3,3,0,0,16,1,29,96,103,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,63,95,63,127\n0,0,0,0,0,42,0,42,42,127,0,42,84,42,0,84,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,21,63,42,21,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,21,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,6,36,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,12,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,7,32,127\n1,1,0,0,0,1,2,4,8,33,100,127,32,6,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n5,4,2,2,1,8,4,19,28,121,127,86,16,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,25,0,0,0,101,127,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n4,1,2,4,4,5,6,14,27,46,61,127,60,16,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,42,0,0,42,21,42,21,63,84,84,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,2,2,14,50,124,127,82,38,20,17,0,2,0,0,0,0,0,0,0,0,0,0,0,2,5,2,26,50,85,82\n0,0,0,0,0,0,0,0,0,0,0,0,25,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,88,127\n3,0,0,0,0,3,13,6,36,127,122,82,8,8,1,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,25,63,127,101,76,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,1,4,12,43,66,63,73,29,15,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,12,24,85,127\n0,0,0,0,0,0,0,11,11,11,46,69,57,103,127,34,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,57,46\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,15,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,127\n0,1,5,0,3,5,35,38,93,127,88,56,17,3,1,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,14,0,0,0,0,28,127,70,42,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,14,14,97,112,127,112,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,29,22,29\n0,0,0,0,0,0,0,0,0,1,3,11,25,15,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,15,68,127\n0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,27,72,127,54,9,0\n0,0,0,0,0,0,0,2,8,2,19,127,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,9,18,36,0,45,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,63,127\n0,0,0,0,0,0,0,0,0,0,0,0,3,0,10,127,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13\n0,0,0,0,0,0,0,0,0,50,12,25,127,88,76,0,0,12,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,63,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,42,127,84,127,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,112,127,127,14,14,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,9,0,29,58,127,117,87,9,0,0,0,9,19,39,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,2,2,10,127,33,20,15,5,0,0,0,0,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,42,0,127,84,127,0,42,0,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,101,127,25,0,0,0,0,76,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,39,9,9,0,0,0,0,0,0,0,0,9,0,0,0,9,9,0,19,68,127,127,48,9,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,0,36,0,0,0,0,0,0,0,0,0,18,0,0,0,18,0,18,108,54,127,36,18,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,1,2,0,2,3,4,0,7,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,6,18,63,127,72,42,17,2,0,0,0,0,0\n0,0,0,0,0,0,1,1,1,1,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,6,24,127,43,18,8,1,1,0,1,1,0,0\n0,1,5,1,0,0,5,7,9,9,34,78,46,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,25,127,105,23,5,0,1,0,1,0,3,5\n5,1,0,0,1,0,0,0,5,7,20,42,34,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,28,127,72,18,10,0,0,6,3,2,0,3\n0,0,0,0,0,0,0,0,0,25,25,12,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,25,0,38,88,127,114,50,25,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,21,0,21,0,42,21,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,105,127,127,0,84,0,21,0,0,0,0,0,0\n0,0,0,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,84,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,39,19,9,29,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,19,127,9,87,87,97,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,25,0,101,76,127,50,0,0,0,0,0,0,25,0,0,0,0,0,0,0,25,50,25,50,101,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,18,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,18,0,127,0,54,18,0,18,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,21,21,127,42,0,21,0,0,0,0,0,0,0,0,0,0,0,0,42,84,0,42,127,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,11,127,22,0,0,0,0,0,0,0,0,0,0,0,5,5,27,0,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,127,46,0,0,0,0,0,0,0,0,0,0,0,23,11,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,84,127,42,42,0,42,0,0,0,0,42,0,0,42,0,0,0,42,42,84,0,84,0,0,0,0,0,84,0,0,0,0,0,0,42,0\n127,55,55,23,23,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,7,15,47,39,23,87,15,39,55,0,15,7,0\n127,95,31,0,63,95,0,95,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,117,81,27,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,18,18,36\n108,60,78,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,24,127,6,12,6,12,0,0,12,0,48,96,36,0,0,0\n0,10,10,0,10,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,10,0,21,52,31,127,52,21,52,10,0,0,31,0,0,0\n0,25,12,12,12,25,25,127,88,63,25,0,0,0,0,0,0,0,0,0,0,0,0,12,0,25,0,25,0,0,12,25,38,38,0,12,0\n127,63,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,51,75,43,31,28,17,5,5,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,20,0,2,5,5,11,25,20,57\n123,127,96,59,42,13,1,11,9,5,0,0,0,1,0,0,0,0,5,0,1,21,21,9,46,48,73,78,65,55,34,13,23,13,23,19,7\n0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,63,0,63,95,95,0,127,95,0,31,31,63,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,2,0,5,11,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,0,1,13,127\n127,45,20,2,1,1,1,0,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n84,21,127,42,0,0,0,0,21,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n89,97,127,7,0,7,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,9,0,45,127,81,27,36,45,63,127,99,90,36,27,36,72,127,27,36,27,9,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,2,2,2,6,127,90,9,6,4,11,13,32,62,66,39,23,6,13,9,4,4,0,2,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127,127,0,0,42,0,0,0,0,0,0,0,0,0,0,0\n127,95,31,63,31,31,31,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,31,0\n0,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,42,127,84,42,84,127,0,84,42,42,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,127\n50,127,127,0,0,0,0,0,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,127,50,50,25,0\n63,31,15,0,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,31,63,63,127,47,0,31,15,0,0,31,15,15,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,19,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,42,42,127,63,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,10,0,0,10,10,0,21,21,21,21,21,127,31,0,0,21,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,127\n127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,63,31,0,31,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,0,95,63,0,63,31\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,84,0,127,42,84,42,42,0,0,0\n0,25,50,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,76,127,50,0\n42,42,84,42,42,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,0,0,42\n63,127,21,63,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,63,63,63,63,42\n0,0,95,63,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,31,0,0,0,127,31,127,31,95,31\n0,95,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,0,127,63,0,31,0,0,0,0,0,0,0,0,0,0,0,63,95,0,0,63,63,31,63\n0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,31,63,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,63,31,31,31,127,0,0,31,31,0,0,0,63,0,0,31,127,0,0,0,31,95,63,95\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,0,31,31,63,31,95,31,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,31,0,0,63,0,31,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,95,95,95,0,31,0,127,31,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,63,0\n31,79,79,79,0,47,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,63,47,0,127,47,31\n19,39,39,127,39,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,39,29,29,29,9,19\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,63,31,31,63,31,63,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,63,63,63,0,31,0,0,31,127,31,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,15,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,63,79,47,127,79,63,63,31,0,0,0,0,0,0,15,0,0,0,0,0,0,0,15,0,15,15,0,0,0,0,0,0,0,0,0,63,0,15,15,95,95,47,15,31,0,0,0,15\n0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,42,127,42,84,127,42,84,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,0,0,0,0,0,0,0,0,0,0,42,0,127,127,84,84,0,84,84,42,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,127,76,0,0,25,0,50,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,127,0,0,0,0,54,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,127,0,0,0,0,0,0,0,0\n36,0,54,127,54,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,18,36,0,18,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,72\n79,127,31,15,47,15,0,0,15,15,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,63,0,31,0,0,15,47,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31\n0,25,101,76,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,76,25,127,76,101,127,25,0,50,25,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,0,50\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,0,36,108,90,127,54,0,72,18,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,72,127,72,54,54,54,0,0,18,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,21,0,21,21,0,0,63,0,21,127,0,63,127,84,21,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,0,0,15,15,15,0,0,0,15,31,127,15,31,0,0,0,15,31,111,15,63,47,63,31,47,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,50,50,76,127,101,50,50,50,0,50,0,101,101,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,54,127,36,127,54,0,36,0,36,127,36,90,54,18,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n20,20,53,16,32,16,12,4,4,4,4,0,0,0,0,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,4,0,0,8,12,12,49,65,127,86,94,36,45\n15,47,84,58,42,47,15,10,5,0,21,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,15,10,0,0,5,21,63,68,100,127,111,79,42\n72,36,36,54,36,36,108,18,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,36,72,54,108,54,90,127,90,108\n12,38,88,63,127,0,0,12,12,38,76,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,38,12,50,76,50,101,114,63,114\n42,42,10,10,21,0,0,0,0,0,0,0,0,0,0,10,0,0,10,10,21,31,42,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,31,10,63,127,95,95\n66,48,18,12,12,12,6,0,6,0,6,6,0,0,0,6,6,6,0,12,18,18,12,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,6,24,12,60,66,127,120\n31,127,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,31,95,0,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,0,31\n0,12,24,12,0,0,0,0,0,0,0,0,0,0,0,12,12,96,127,102,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,12,12\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,42,42,28,14,127,42,0,0,42,0,28,28,14,0,0,0,0,28,0,14,14,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,36,36,72,127,36,54,54,18,18,90,54,36,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,42,42,70,112,42,84,0,14,14,0,0,0,14,0,0,0,14,0,14,28,28,14,56,127,84,0,0,28,14,84,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,90,108,54,127,18,54,54,0,0,0,0,0,0,18,18,18,0,0,18,0,54,36,36,108,72,18,36,0,18,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,84,0,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,84,84,127,0,0,84,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,42,0,84,127,42,0,0,0,0,0,0,0,0,0,0,0,0,42,0,84,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,127,98,42,28,84,28,84,42,28,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,98,70,56,28,14,14,0,14,0,14,0,0,14,0,14,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,47,111,111,31,63,47,111,0,63,63,47,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,0,0,0,15,79,127,63,95,15,47,47,31,0,47,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,84,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,0,42,0,0,0,0,0,0,0,0,42,0,42,0,42,42,127,42,84,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,0,0,42,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,127,0,0,42,42,42,0,0,0,0,0,0,0,0,0,42,127,84,84,42,127,84\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,127,11,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,25,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,50,50,50,127,50,50,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,14,0,0,0,0,0,0,0,0,28,0,0,56,112,84,42,127,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,63,31,0,0,0,63,127,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0\n9,0,4,4,6,1,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,29,59,85,127,75,54,25\n10,6,9,6,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,29,58,90,127,77,49,27\n0,127,42,21,21,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,21,0,0,0,84,127,84,63,42\n0,11,23,23,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,69,127,115,69,69,34\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,31,0,95,95,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,25,25,0,25,0,0,0,0,0,0,0,0,0,0,0,50,25,25,101,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,21,63,0,21,21,63,21,127,42,42,63,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,95,0,95,31,0,0,127,0,63,31,95,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,42,0,42,127,127,127,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n19,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,19,9,0,9,68,78,127,78,19\n42,14,7,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,105,84,127,70\n31,0,0,0,0,0,31,63,0,0,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,31,0,31,0,31,31,31,0,31,63,127,63,0\n63,63,0,0,0,0,0,63,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,63,0,63,63,63,63,0,127,0,0\n0,0,84,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,127,84,0,42,42\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,76,127,76,0,25,50,76,0,0,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,84,127,42,42,42,21,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,42,127,21,0,0,21,0\n101,76,101,0,101,76,50,50,76,25,25,50,127,0,0,0,25,101,25,50,25,25,25,25,50,50,50,50,76,50,50,76,50,25,0,101,50\n30,60,25,20,30,10,40,15,5,15,10,5,10,0,5,15,0,10,20,20,45,50,55,111,127,116,96,40,35,20,5,20,5,5,20,0,30\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,12,38,63,127,101,88,0,50,0,12,12,0,12,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,11,5,28,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,6,6,31,40,127\n36,0,0,0,127,36,18,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n28,14,14,0,14,127,112,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,105,102,67,91,42,52,21,7,0,0,0,0,0,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,81,74,27,29,31,17,24,13,6,1,0,1,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n56,14,0,28,0,42,42,0,0,14,14,14,0,0,0,0,14,28,0,0,0,56,42,84,112,127,70,70,56,0,0,0,0,0,0,14,0\n127,15,55,7,31,0,0,15,0,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,28,0,0,0,0,7,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,42,105,127,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,0,31,31,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,31,63\n31,31,63,95,127,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,31,127,127,63,31\n99,18,18,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,9,9,27,36,127\n63,127,63,31,0,31,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,63,63,63,31,31\n50,76,127,50,0,25,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,50,101,0\n90,36,18,0,0,0,36,0,0,0,0,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,54,0,127,127\n127,108,0,54,18,18,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,18,0,0,0,54,108,54\n127,109,87,70,52,43,33,26,19,15,11,10,5,3,3,3,2,1,4\n127,68,61,98,88,100,91,59,37,56,49,49,51,29,29,28,19,17,28\n127,80,71,55,25,16,8,0,0,0,0,0,4,8,8,0,0,4,0\n13,6,6,127,40,13,0,0,13,0,0,0,0,0,0,0,0,0,0\n1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,5,14,22,29,32,38,58,79,106,127\n21,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,10,10,74,31,84,127,84,105,95,0,42,105,63,0,10,63\n112,127,77,56,35,31,0,3,7,7,3,0,0,0,0,0,0,0,0\n63,31,127,0,63,63,0,0,0,0,31,95,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,4,75,127\n127,75,11,2,16,7,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,63,31,95,63,0,31,63,127,63\n40,38,45,52,65,98,127,98,114,95,62,40,28,28,18,16,16,7,17\n5,0,0,4,6,2,0,0,0,0,0,2,0,0,0,0,0,0,0,0,2,0,1,5,17,35,63,103,127,111,114,115,67,41,15,33,30\n28,98,28,112,56,127,42,84,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,127\n127,31,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,1,0,2,1,0,1,1,2,2,13,6,16,15,32,65,97,127,97,94,64,43,25,17,12,5\n6,0,0,0,0,1,1,0,0,1,0,4,1,3,0,1,0,0,2,0,4,6,10,19,37,66,122,127,122,79,89,46,26,11,6,4\n25,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,50,76,76,76,76,101,127,76,76\n25,50,0,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,25,0,0,50,25,0,50,127,76,76,50\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,7,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,7,7,14,0,0,14,42,77,42,127,98,70,63,105,35,21,21,14,7\n8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,8,8,8,0,0,8,0,0,25,42,59,76,93,127,67,33,0,33,8,16,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,42,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,76,50,0,0,101,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,127,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n10,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,21,10,0,21,31,95,116,127,42,52,42,21\n7,14,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,0,0,0,22,29,67,127,44,59,22,14\n70,42,42,14,0,42,70,56,28,0,28,0,28,0,98,112,56,127,112,84,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,14,0,0,0\n15,47,111,15,31,79,63,0,15,47,0,31,15,47,63,31,95,95,127,111,47,63,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,15\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,63,21,21,21,42,84,127,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,84,0,0,0,84,84,127,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,26,3,23,26,15,42,127,123,119,103,88,80,80,38,34,30,80,80,46,34,46,38,53,30,11,11,11,50,34,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,9,1,2,1,8,17,45,41,30,39,34,30,10,8,9,30,68,127,39,25,16,9,8,13,2,6,3,10,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,63,127,21,0,42,21,0,0,21,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,0,50,127,25,25,25,101,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,127,127,95,127,31,0,31,0,0,31,0,0,31,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,47,31,127,31,15,0,0,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,31,31,31,127,0,63,95,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,63,63,31,127,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n9,11,5,9,7,1,1,3,1,7,11,7,7,13,19,31,37,56,62,93,111,76,121,127,97,72,74,64,64,46,54,23,23,23,17,5\n17,27,17,9,0,2,4,2,12,7,14,12,24,17,22,49,39,72,77,107,82,127,114,109,117,89,89,92,62,49,27,47,32,17,24,22\n2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,6,5,14,15,19,6,7,13,10,14,6,11,42,43,84,110,127,67,56,40,24,15,4\n3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,8,11,17,11,9,9,8,13,9,11,11,39,47,76,103,127,78,42,42,21,13,6\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,31,31,95,63,31,63,127,0,31,31,95,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,95,63,95,127,127,31,31,63,63,31,31,0,31,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,105,7,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,106,13,0,0,13,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,1,0,47,127,96,27,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,2,1,33,127,69,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,9,9,4,4,9,0,22,127,86,4,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,4,4,4,4,0,4,4,23,127,89,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n8,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,8,0,0,0,0,8,33,101,127,110,93,93,42,25\n0,23,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,15,7,0,0,0,15,31,119,103,127,111,79,55,47\n0,3,3,3,1,0,0,0,0,0,1,1,3,3,9,15,11,17,13,42,127,91,31,5,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,33,3,48,33,9\n0,2,6,2,2,0,0,0,0,0,2,2,4,11,13,9,18,20,20,50,127,113,18,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,39,2,41,48,16\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,5,5,37,63,63,47,100,74,68,42,10,37,42,127,63,52,58,26,21,10,5,5,10,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,8,25,8,25,101,101,127,101,118,110,110,42,42,93,93,110,50,84,59,42,16,0,8,16,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n5,0,0,0,0,0,0,0,0,0,0,0,0,0,17,11,0,5,17,46,51,34,23,11,28,17,40,127,98,34,46,5,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,17,17,11,34,17,23,11,23,17,51,57,127,75,17,17,5,5,5,0,5\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,25,76,76,76,0,127,25,25,76,127,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,127,127,0,63,127,127,0,63,127,63,0,0,63,63,127,0,0,63,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,19,127,6,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,127,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,127,74,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,3,0,50,127,69,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,63,31,31,31,31,31,31,31,0,0,0,0,0,63,0,95,0,127,0,0,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,31,31,63,31,0,31,31,0,0,0,63,0,0,0,127,95,127,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,127,30,13,30,4,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,127,36,13,27,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,50,101,127,25,0,25\n0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,127,127,25,50,50\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,21,52,10,0,10,31,10,10,21,31,21,21,10,10,10,0,0,0,0,10,21,10,0,10,31,74,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,127,111,31,0,15,31,63,0,15,31,15,15,47,0,15,15,0,0,0,0,0,31,15,0,0,79,95,47,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,57,127,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,18,18,18,72,18,127,36,36,36,0,0,0,108\n63,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,127,95,127,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0\n114,117,127,59,39,39,74,57,117,62,32,34,49,27,0,2,0,0,0\n46,80,11,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,23,0,46,127,69,46,69,46,115,46\n93,127,80,84,16,25,29,8,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,19,11,0,127\n0,0,7,0,47,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,103,39,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,21,0,68,127,58,0,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,63,0,63,0,63,0,127,42,84,42,21,0,0,0,0,0,0,0\n0,0,0,14,0,0,0,14,14,0,42,84,112,84,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,14,70,127,56\n0,0,0,18,0,0,0,0,0,18,0,108,127,54,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,108\n0,0,0,0,101,50,0,0,0,0,0,0,0,0,0,0,0,25,50,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,0,101,50,50,0,0,0,0,0,0,0,0,25,25,0,76,127,0,0,0\n0,23,0,0,0,0,0,0,0,0,0,0,23,127,47,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95\n12,5,1,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,5,5,15,43,127\n33,6,0,30,33,13,60,36,33,20,10,0,6,0,0,0,0,0,3,3,0,0,13,0,0,3,10,13,23,13,16,33,70,86,90,116,127\n5,5,0,0,4,0,1,1,0,15,25,18,11,1,0,0,0,4,1,0,1,2,4,1,1,5,7,1,1,1,1,4,0,8,14,11,127\n127,92,53,19,14,9,0,0,4,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,63,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,63,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,84,63,21,0,0,0,0,0,0,0,0,0,0\n108,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,63,127,63,127\n0,0,0,0,0,0,0,0,0,7,97,127,97,59,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,14,14,74\n0,0,0,31,31,31,95,0,31,127,95,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,24,29,63,127,4,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n50,25,76,25,50,0,127,25,25,0,0,0,0,0,0,0,0,0,0\n127,114,25,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,12,0,0\n127,105,42,42,0,0,0,0,42,0,21,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,63,0,63,31,95,95,127\n0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,21,0,21,42,42,21,127,0,42\n0,0,0,0,0,0,0,63,127,127,63,0,127,0,0,0,0,0,0,0,127,0,63,0,0,0,0,0,0,0,0,0,0,0,63,0,0\n0,0,0,0,0,0,0,0,0,0,42,0,127,42,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,4,28,127,70,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,25,0,0,0,0,25,76,0,0,76,0,25,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,50,101\n0,0,0,0,0,0,0,0,0,0,36,0,127,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,42,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,0,50,127,50,25,101,25,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,42,127,0,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,127,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,69,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,21,35,87,127\n0,0,0,0,0,0,0,0,0,0,0,0,127,84,127,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,0,127,42,42,0,84,0,42,42,0,42,0,42,0,0,0,0,0,0,0\n127,0,12,0,12,12,0,38,0,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,25,0,0,12,12,12,0,12,0\n0,0,0,34,0,23,0,11,0,34,46,46,103,57,80,57,11,57,92,46,23,69,127,34,34,11,23,11,11,11,11,0,0,23,0,0\n0,0,0,0,0,0,50,0,25,101,127,25,0,0,0,50,127,25,0,0,0,0,0,0,0,0,0,0,0,0,25,50,76,76,50,25,0\n127,105,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,79,47,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,95,127\n9,0,0,0,0,0,0,0,4,4,4,127,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,105,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,105,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,54,90,127,99,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,9,9,0\n0,0,0,0,0,0,0,0,0,0,63,0,31,0,127,31,63,31,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,31,63,31,63\n0,0,0,0,0,0,0,0,0,0,0,10,5,0,0,5,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,10,21,58,95,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,63,101,50,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,42,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127\n0,21,0,84,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,21,0,42,42,0,0,0,0,0,21,0,21,0,0,0,0,42,0,0,0,0,0,0,0,127\n0,0,0,0,25,0,50,0,0,0,50,50,25,0,0,25,0,0,25,0,0,127,0,25,0,0,0,0,0,0,0,0,25,0,0,0\n0,0,0,0,0,0,42,84,42,42,42,127,42,0,0,0,42,0,42,42,0,84,42,0,0,0,0,0,0,0,0,0,0,0,0,42\n0,0,0,0,31,0,63,63,31,127,63,31,31,31,31,0,31,0,0,0,31,63,63,31,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,127,63,0,127,63,63,0,0,0,0,0,0,63,0,95,0,0,0,0,0,0,0,0,95,0,0,0,0,0,0\n0,0,0,0,0,0,0,127,0,0,42,0,0,0,0,42,0,0,0,42,0,0,0,0,0,0,0,0,42,0,0,0,0,0,84,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,127,0,0,0,0,0,0,0,25,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,25,0,0,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,50,0,0,0,25,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,45,127,72,81,54,0,18,9,0,0,0,0,0,0,0,0,0,0,9,0,18,27,45,18,0,45,54\n0,0,0,0,42,0,0,84,84,84,42,84,84,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0\n0,0,0,0,0,0,0,0,0,0,0,0,63,31,31,63,63,95,0,0,0,31,0,0,0,0,0,0,0,0,31,0,0,0,0,95,127,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,0,0,0,0,0,0,0,0,0,0,63,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,127,101,50,76,76,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,127,95,0,127,0,0,0,0,0,31,0,0,127,63,95,0,0,0,0,31,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,63,63,95,127,31,0,0,0,0,31,0,31,63,127,95,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,63,63,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,0,0\n0,0,0,0,0,0,0,0,0,0,0,84,127,42,84,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0\n0,0,0,0,0,0,0,0,6,0,6,12,31,25,6,19,19,12,0,0,44,12,6,38,12,12,12,12,19,38,63,127,82,19,50,50,50\n0,0,0,0,0,0,0,0,0,12,76,50,63,127,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,50\n0,0,0,0,0,7,0,14,14,0,0,0,0,127,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,15,15,47,47,31,31,47,15,15,15,15,127,15,95,31\n42,84,63,52,42,26,42,127,26,42,10,10,15,0,0,0,0,0,10\n63,63,95,63,95,63,31,31,31,63,127,127,63,63,0,0,0,0,0\n0,0,14,7,7,21,49,84,49,112,127,105,49,49,35,49,14,7,0\n127,116,77,65,51,42,22,14,2,0,0,0,0,0,0,0,0,0,0\n46,46,46,46,11,23,23,69,103,92,103,127,57,34,0,0,0,0,0,0,0,11,46,11,69,34,80,23,23,23,46,57,23,11,11,127,46\n107,127,78,43,43,24,14,34,24,9,9,19,14,48,73,78,4,39,78\n28,28,28,24,21,35,52,127,63,88,59,28,28,0,3,7,0,0,0\n0,0,0,0,0,0,0,0,28,0,14,56,14,56,70,28,0,28,0,14,0,14,0,0,0,28,28,127,42,28,56,42,42,0,28,28,112\n127,33,0,3,3,15,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,58,29,4,0,0,0,0,0,0,0,4,4,0,0,0,9,9,0,4,0,4,0,0,4,4,0,4,4,4,4,4,29,24,14,9,9\n127,127,63,0,0,0,0,0,0,127,0,63,0,0,0,0,0,0,0,0,127,0,0,0,0,0,127,127,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,34,80,127,11,11,0,0,0,0,0,0\n84,127,56,56,14,14,0,14,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,14,0,14,14,0,112\n42,105,63,84,0,42,84,0,0,42,42,21,21,42,0,42,21,84,0,63,21,42,42,21,0,0,63,0,0,0,42,0,0,42,0,63,127\n42,127,28,7,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,14,0,35,14\n0,42,63,0,0,84,0,0,0,0,0,0,0,0,21,0,63,21,0,0,0,21,0,0,0,21,0,42,42,84,63,105,0,0,0,21,127\n0,0,0,0,0,0,0,0,0,0,0,0,63,95,31,63,127,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,31,95,95,127,127,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,9,0,0,9,19,0,58,0,58,48,107,127,87,117,39,29,29,19,19,9,29,19,0,9,0,0,9,0,0,0,0,0,0,0\n0,0,0,0,0,0,16,42,42,59,127,59,59,84,84,93,67,16,25,16,42,8,42,8,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,63,0,63,63,63,0,0,0,127,0,0,63,0,63,0,0,127,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,31,0,63,31,0,127,0,63,95,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,119,127\n0,0,0,0,0,0,0,0,9,0,0,27,27,127,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,27,117,127,9,0,0,0,0,0,9,27,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,25,69,127,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,6,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,12,38,0,12,0,38,12,12,50,38,38,12,12,0,12,0,12,0,12,0,0,0,0,12,0,0,12,38,25,38,38,38,127,25,101\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,127,25,50,101,101\n0,0,0,0,0,0,0,0,0,9,9,90,108,81,72,9,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,9,9,45,127\n0,0,0,0,0,18,108,127,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,12,0,38,12,12,12,127,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,31,63,0,31,31,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,63,0,0,127\n0,0,0,0,0,0,0,0,0,15,111,63,95,15,111,47,15,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,15,47,63,111,127\n0,0,21,42,0,21,0,0,127,127,0,42,0,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,31,31,127,63,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,63,63\n0,0,42,0,42,0,0,42,0,42,42,127,127,42,0,0,0,0,0,0,84,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n50,127,0,25,25,25,25,0,76,101,25,0,0,0,0,0,0,0,0\n0,0,127,21,63,42,21,42,0,0,0,0,63,0,0,0,0,0,0\n0,0,0,0,0,0,0,21,0,21,63,63,63,127,105,42,84,42,42\n63,0,0,0,63,31,31,31,127,31,31,0,0,31,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,31,0,0,127,31,63,127,63,31,63\n127,42,42,0,21,42,42,42,42,21,0,0,0,0,0,0,0,0,0\n0,0,0,31,0,63,0,63,0,127,0,127,95,63,0,0,0,0,0\n0,0,0,0,0,0,0,25,50,0,0,25,25,50,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,127,50,50\n0,0,0,0,0,0,31,0,0,0,0,0,95,31,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,31,127\n23,0,7,7,11,31,39,83,55,83,127,63,51,19,43,23,35,39,23\n127,0,0,0,0,95,31,0,63,0,95,31,0,95,31,0,0,31,0\n0,0,0,0,0,0,0,0,0,0,0,63,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127\n84,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,42,127,42,42,42,42,42,42,0\n0,31,31,63,0,63,127,31,31,63,127,63,31,0,0,0,0,31,0\n0,0,6,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,26,127,60,6,53,0,46,13,0,0,0,0\n63,0,0,0,0,0,0,0,0,0,127,0,63,63,127,0,63,0,0,63,0,0,63,0,0,0,63,0,127,127,0,0,0,63,0,63\n63,0,0,0,0,0,0,0,0,0,63,0,63,63,63,127,0,63,63,0,0,0,63,0,0,0,127,63,63,63,0,0,0,0,63,63\n0,0,0,0,0,0,0,0,0,0,21,21,42,21,21,0,0,0,21,0,21,0,0,0,0,0,0,0,0,0,0,0,0,127,63,21,0\n0,0,50,50,0,25,25,50,127,50,50,0,50,25,101,76,76,50,50,0,0,0,50,25,0,50,50,25,76,76,50,76,50,25,25,76,101\n101,101,50,50,0,0,0,50,0,50,0,0,0,0,50,50,25,0,50,50,101,127,50,76,50,50,25,76,76,0,0,0,76,25,0,25,101\n127,127,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,127,127,0,0,0,127,0,127,0,0,0,0,0,0,0,0\n0,21,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,0,0,127,0,0,21,0,0,0,0,0,0,0\n0,1,1,1,5,10,21,40,24,40,59,93,121,105,65,44,29,10,7,5,1,1,0,0,3,0,0,0,0,1,1,17,12,22,61,75,127\n0,0,0,0,0,0,0,0,0,0,31,15,31,127,15,63,0,0,31,0,0,0,0,0,0,0,0,0,0,15,0,15,0,31,0,15,95\n0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,63,63,0,0,0,0,0,63,0,0,0,0,0,31,0,31,31,0,31,127,95,0\n0,0,0,0,10,10,0,10,10,127,21,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,25,0,0,25,0,50,25,25,25,25,25,0,0,0,25,76,0,0,0,0,0,0,0,0,25,0,25,0,0,25,25,0,127,101,0\n0,0,0,0,0,14,0,63,21,14,91,127,70,105,77,35,21,14,14,0,0,0,0,0,0,0,0,0,0,0,0,14,35,28,28,98,70\n0,0,0,0,0,0,0,0,0,76,101,76,50,127,76,76,0,25,0,0,0,0,0,0,0,25,0,0,0,0,0,50,0,0,25,127,101\n0,0,0,0,21,0,0,0,63,127,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,31,0,0,0,127,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,0,0\n84,127,105,42,0,0,84,42,0,42,0,0,0,0,0,0,0,0,0\n0,21,21,63,63,42,63,127,127,63,21,0,21,63,21,0,63,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,127,47,63,79,95,15,0,0,0,31,15,31\n0,0,0,0,31,0,95,31,63,127,31,95,31,0,0,0,0,0,0\n0,0,0,42,42,0,0,0,0,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,42,0,0,0,0,42,42,0,0\n127,0,15,0,0,95,47,47,63,0,0,0,0,0,0,0,0,0,0\n0,18,0,0,18,18,54,72,127,90,54,108,108,36,127,108,72,36,36\n127,63,10,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,18,0,0,18,36,90,54,127,54,0,18,18,18,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,18,18,0,36,0,0,54,127,72,36,36,36,18,0,54,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,95,127,31,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,42,42,0,127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,21,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,127,50,25,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,21,0,0,127,84,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,21,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,36,127,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0\n63,31,0,0,0,0,0,31,31,63,127,0,95,31,0,0,31,0,0\n127,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,31,31,15,47,47,79,15,63,31,31,127,63,47,31,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,127\n0,0,0,0,0,0,0,0,0,0,0,0,127,127,21,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,42,84,84,84,127,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,11,0,34,80,103,127,80,80,46,127,80,69\n76,127,76,88,0,0,12,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127\n0,0,0,0,0,0,0,0,0,31,0,127,95,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,63\n0,0,0,0,0,0,0,33,16,50,42,127,59,16,50,59,59,16,33\n0,0,0,0,0,0,0,0,0,0,0,42,21,84,127,42,84,63,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,21,0,0,0,21,63,127,63,63,42,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,84,127,8,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,15,127,47,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127\n0,0,0,0,0,21,0,127,63,84,42,0,0,0,0,0,0,0,0\n0,16,16,8,0,16,0,16,33,59,42,127,101,33,50,59,67,67,16\n0,14,127,0,0,14,14,14,0,0,14,0,0,14,0,0,0,0,0\n0,50,25,50,127,25,25,50,25,101,101,0,101,25,0,25,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,84,0,0,42,84,127,84,0,0,0,0,0,84,42,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,18,36,54,90,127,90,127,18,36,0,36,54,54,0,0\n0,0,0,0,0,0,0,0,14,14,0,14,14,56,70,127,98,56,14,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,42,0,0,21,0,21,105,42,127,63,21,42,0,21,21,21,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,69,127,103,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,127,95\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,127,106\n127,72,45,27,72,63,63,72,63,54,27,9,9,9,9,9,18,45,0\n0,5,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,10,5,15,21,68,127,47,74,26,52,42\n127,59,35,15,19,15,3,0,0,0,0,0,0,0,0,0,0,0,0\n18,16,39,47,63,72,105,98,127,109,92,75,68,49,17,27,14,18,16\n0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,5,9,29,57,101,127,86,108,62,77,40,40,22,27,11,0\n63,31,47,63,127,47,79,111,79,111,127,127,47,15,47,0,0,0,0\n127,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,47\n47,55,127,55,71,31,7,55,15,15,15,23,63,79,79,7,71,55,79,79,111,87,63,71,47,47,71,39,103,71,39,79,87,111,71,63\n37,67,104,37,59,37,29,7,0,0,22,7,59,29,44,14,22,52,37,67,52,82,112,59,52,119,74,52,82,104,52,127,89,82,59,52\n63,63,63,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,63,127,0,0,127,63,127,127,63,63,63,0,63,0,127,0,0,127,0,0,63,0\n63,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,127,127,0,0,127,0,63,63,0,63,127,0,0,0,63,0,63\n31,31,95,47,15,15,0,0,0,0,15,0,0,0,0,0,0,0,0,31,15,111,79,63,15,63,127,15,0,0,15,0,0,31,15,0\n36,18,127,36,54,72,36,0,0,0,18,0,0,0,0,0,0,0,18,36,36,72,72,36,72,108,54,18,0,0,0,0,0,18,54,36\n0,0,0,42,0,84,0,42,0,42,42,42,0,0,0,0,0,0,0,0,0,84,0,0,84,0,84,0,0,84,84,42,127,0,42,0\n0,42,42,0,0,0,0,0,0,0,42,0,0,42,0,0,42,84,0,0,0,42,0,84,42,84,42,0,84,42,127,0,0,0,0,84\n50,50,50,25,127,50,0,0,0,0,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,16,25,76,67,8,8,59,16,0,8,16,0,0,0,0,0,8,0,8,33,25,42,33,84,127,118\n0,0,0,0,0,0,0,0,0,10,0,0,0,21,10,0,0,0,0,0,0,0,0,0,10,0,0,0,0,10,0,0,0,21,52,95,127\n0,0,0,0,0,0,0,0,0,0,0,5,23,51,34,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,51,17,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,34,127,86,11,5,11,5,11,17,5,0,0\n0,0,0,0,0,0,0,0,0,0,5,5,28,51,57,23,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,46,127,86,34,11,11,23,28,5,0,0,5\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,31,127,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,42,0,0,84,42,127,42,42,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,127,63,127,127,63,127,63,0,127,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,95,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,31,0,31,31,127,79,0,31,63,31,15,31,31,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,47,63,127,79,0,15,0\n0,0,0,25,0,76,25,50,127,101,0,76,25,0,0,0,0,0,0\n0,0,0,6,6,30,6,24,96,60,96,66,60,127,36,42,30,30,0\n0,0,0,0,0,0,0,0,0,31,63,95,63,127,79,63,47,15,0\n112,84,127,98,28,14,14,0,42,14,0,42,0,28,0,0,0,0,0\n7,7,0,7,7,14,28,35,77,105,77,70,35,56,28,21,21,42,35,56,28,28,14,91,63,127,56,63,77,35,28,0,28,0,0,7\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,101,76,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,4,0,0,0,0,4,0,0,4,19,92,127,122,127,73,29,9,9\n0,0,0,0,0,0,18,18,18,6,0,0,0,0,0,0,0,0,6,6,0,0,0,12,54,114,60,127,78,66,18,24,12,0,6,18,24\n28,38,29,13,13,49,115,127,77,43,19,14,7,8,0,1,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,3,15,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,6,17,68,127,58,12,2,8,4,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n63,127,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31\n0,0,0,0,25,0,0,50,76,127,25,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,101,76,101,76,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n63,0,31,31,95,127,63,0,0,31,63,63,31,0,31,0,63,31,0\n42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,84,127,0,0,0,0,84,0,0,42,42,42\n0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,42,42,42,84,127,84,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,31,31,31,31,63,63,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,63,63,0,127,127,0,0,0,0,63,0,0,0,0,0,127,63,0,0,0,0,0,0,127,0,0,0,0,63,0,63,0\n18,0,9,9,72,18,18,36,9,36,127,36,63,27,9,0,18,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,21,63,127,42,63,0,0\n0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,31,0,47,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,84,127,0,127,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127\n0,0,0,0,0,0,0,0,0,31,127,63,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,127,63\n0,84,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,84,0,42,0,127,0\n127,42,21,63,0,105,0,63,42,0,42,21,0,21,0,21,21,21,42\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,18,127,72,72,72,36,54,0,0,18,0,0\n0,0,11,0,0,11,23,46,127,69,34,11,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,76,101,127,0,0,0,0,0,0,0,0,25,0,25,25,76,0\n31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,63,95,0,31,0,0,0,0,0,0,31,0,31,63,127,95,31\n0,0,0,0,0,0,0,0,0,0,127,0,50,0,0,0,0,50,0,0,0,0,0,50,0,0,0,0,0,0,0,0,0,0,0,50,0\n0,0,0,0,0,0,0,0,0,0,0,0,84,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,127,84,0,0,42,0,42,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,42,0,127,127,0,42,0,0,0,0,42,0,0,0,0,0\n0,0,0,0,0,0,0,0,25,50,76,25,25,50,127,25,50,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,76,76,25,76,50\n0,0,2,2,2,2,8,8,0,27,19,91,127,91,38,24,33,22,16,0,0,0,2,0,0,2,0,0,0,0,0,5,16,24,49,85,127\n0,0,0,0,0,0,0,0,31,31,0,63,63,95,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,31,0,31,63\n0,0,0,0,0,127,0,0,0,84,0,42,84,127,42,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84\n0,0,0,0,0,0,0,0,0,0,50,0,50,101,25,127,76,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,0\n0,0,12,0,0,0,0,0,25,38,25,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,38,63,76,76,114,50,63,38,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,50,38,76,127\n0,0,0,0,0,0,0,0,9,36,54,127,90,63,99,27,18,9,0,0,0,0,0,0,0,0,0,0,0,0,0,9,27,9,36,54,36\n0,50,0,50,76,50,76,0,76,25,0,0,25,0,0,50,0,101,25,101,0,0,0,0,50,0,50,127,50,25,25,76,76,50,25,25,0\n0,0,0,0,0,0,0,0,0,18,18,108,54,36,54,36,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,36,127,72\n0,0,0,0,0,0,0,0,0,0,101,50,127,101,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0\n0,18,0,0,0,36,36,18,0,72,72,127,54,90,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,25,25,0,0,25,50,50,76,25,76,25,50,25,0,0,0,0,0,0,0,0,0,0,0,0,50,0,0,127,50,0\n0,0,0,0,0,0,42,84,0,0,42,127,42,84,42,42,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,63,0,0,31,95,127,127,63\n63,42,21,42,42,63,21,42,63,63,42,42,84,127,105,105,21,84,21,0,63,63,21,42,21,42,21,21,0,42,0,84,63,42,42,21\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,127,95,63,31,31,63,0,63,0,0,31,0\n15,51,31,31,83,63,67,127,95,67,67,87,43,15,11,0,3,7,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,127,42,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,63,0,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127\n0,0,0,0,0,0,0,0,0,42,127,0,0,0,0,42,105,42,21,0,0,0,21,0,0,0,0,21,0,0,0,21,63,42,21,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,127\n0,0,0,0,0,0,0,0,0,11,11,34,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,127,63,0,63,63,0,63,0,63,63,0,63,63,127,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,42,127,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,127,63,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,21,0,0,0,0,42,127,63,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,63,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,0,42,0,0,0,0,0,0,0,0,0,0\n84,0,0,0,0,0,84,42,0,0,42,42,42,0,42,0,42,0,84,42,0,0,0,0,0,0,0,0,0,0,42,0,42,0,42,127,0\n0,0,0,0,0,0,0,0,5,5,28,80,127,46,23,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,5,11,28,80\n0,0,0,0,0,0,0,18,18,36,90,36,90,54,127,36,18,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,54,108,18,36\n0,0,0,0,0,0,0,0,0,0,0,21,105,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,127\n3,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,1,1,0,3,1,127\n0,0,0,0,0,0,11,0,0,0,11,127,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n1,3,2,1,2,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,2,0,1,10,6,127\n13,10,6,1,1,0,3,3,1,0,0,0,0,0,0,0,1,0,1,0,0,0,0,3,3,1,0,1,5,3,1,3,18,21,38,41,127\n0,9,9,9,18,9,18,0,27,9,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,9,0,0,0,0,9,127\n0,9,0,0,0,9,9,14,4,34,24,127,83,83,53,34,14,14,0,9,0,4,0,9,0,14,0,0,4,4,4,19,4,9,19,34,19\n0,63,31,31,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,127,42,0,0,0,0,0,0,127,127,0,84,0,0,84,0,0,0\n0,0,50,25,25,25,12,0,12,38,63,127,25,12,12,12,38,0,0,25,0,0,0,25,0,0,0,0,25,0,25,0,0,12,38,101,50\n0,0,0,0,0,0,0,0,127,0,127,0,0,63,127,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,127,0,0\n0,42,0,42,0,42,0,84,84,84,42,42,0,42,0,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,0,42,0,42,42,0,42,42,0,84,0,0,0,42,0,42,0,0,127,0,0,0,0,42,0,42,0,0,0,0,0,0,42,42,0,0\n0,42,0,84,0,42,0,42,42,0,84,84,42,42,0,0,0,42,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,84,0,42,0,0,0,42,127,42,42,84,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,42,0,42,42,0,42,0,0,0,0,42,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,18,127,90,72,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,25,0,127,76,25,25,12,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n28,42,0,0,0,0,28,0,28,70,28,127,112,56,28,42,28,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,42,0,84,84\n0,0,47,0,0,0,0,0,0,127,15,0,0,0,0,15,0,0,0,15,0,0,15,31,79,15,0,0,0,0,0,0,15,0,15,0,31\n9,23,9,42,28,23,47,32,51,47,56,89,23,4,14,4,4,0,0,0,4,0,0,9,0,0,0,0,0,4,4,0,0,28,28,127,94\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,16,127\n18,36,36,36,27,54,127,72,81,81,127,90,36,36,27,18,18,0,0,9,0,0,9,9,0,0,18,27,0,0,0,0,9,27,0,72,18\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,9,0,0,9,9,9,0,0,0,0,0,0,0,0,9,0,9,54,127,36,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,42,0,14,0,14,14,0,0,0,0,0,0,0,0,28,0,14,127,127,56,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,50,50,50,0,0,0,0,0,0,0,0,0,0,0,25,0,25,0,25,50,101,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,21,0,63,42,127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,42,0,0,84,127,0,0,42,42,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,42,0\n0,0,0,0,0,0,0,0,0,31,95,31,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,31,127\n0,0,0,0,0,0,14,7,7,0,21,56,98,14,0,0,0,7,0,7,0,7,0,0,0,7,0,0,0,14,14,0,0,0,7,35,127\n23,11,11,34,69,115,127,127,57,23,0,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,5,2,2,5,32,17,56,85,127,41,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,18,54,81,36,9,0,9,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,99,127\n0,0,0,63,0,0,0,0,0,95,31,31,0,0,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,127,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,63,0,63,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,42,84,127,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,84,42,0,0,0,0,0,0,0,0,0,0,42\n0,0,0,0,0,0,0,0,0,0,0,0,18,108,36,90,54,0,18,0,0,0,0,0,0,0,0,0,0,18,72,0,72,127,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,18,90,72,54,36,0,0,0,0,0,0,0,0,0,0,0,0,36,72,36,54,127,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n15,0,0,0,15,0,31,15,15,31,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,15,15,0,0,31,15,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,31,0,0,0,0,0,0,0,15,79\n0,50,50,25,0,0,25,25,25,25,25,25,0,0,0,0,25,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,50,25,0,0,101,127,50,0,0,0,0,25,0,0,0,0,0,0,25,0,0,25,0,0,25,25,25,50,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,50,50,76,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,101,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,21,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,69,16,8,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,69,22,15,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,21,10,21,42,52,116,63,127,10,21,10,21,0,0,10,0,0,10,10,127\n127,80,25,11,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,21,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,103,31,23,15,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,28,5,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,25,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,12,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,63,12,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,127\n42,63,127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,42\n0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,21,10,0,0,21,74,127\n127,105,74,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,63,95,31,31,31,31,127,31,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,31,0,0,0,31,95,0,0,31,31,63,95,31,63,63,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0\n76,127,50,50,50,25,0,25,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,25,0,50,0,0,50,25,101,0,25,76,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,101,25\n36,18,54,108,18,18,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,127,88,88,101,12,25,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,127,47,0,15,0,0,15,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n111,31,0,0,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,31,15,0,15,15,15,0,31,0,0,0,0,15,0,0,0,0,0,15,0,95,127,63,31,111\n127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,15,15,63,0,0,15,0,0,15,0,0,0,0,0,15,0,0,15,15,15,63,79,31,95\n0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,21,0,0,0,21,21,0,21,21,42,21,21,84,105,127,42,63,21\n50,127,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,25,25,25,0,0,0,0,0,0,0,0,25,0,25,0,0,0,0,25,25,76,25,76\n21,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,21,42,21,127,42,42\n0,42,52,127,127,127,31,21,10,21,0,0,0,0,0,10,10,0,10,0,0,10,0,42,31,0,21,10,0,0,10,0,0,10,0,0,0,0,0,0,0,0,0,0,10,0,10,10,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n7,7,63,127,91,21,42,35,0,0,0,0,0,7,0,0,0,0,0,0,7,0,7,14,0,14,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7\n5,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,26,127\n127,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,5,5,12,17,18,11,2,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,2,7,26,48,127\n0,0,0,0,0,0,0,0,0,0,0,0,63,0,31,31,127,63,0,31,0,31,31,0,0,0,0,0,0,0,0,0,31,95,95,63,31,95,95,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,6,32,127,37,3,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,23,127,32,3,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,63,15,31,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,1,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,3,9,61,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,21,84,127,66,18,5,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,3,1,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,17,100,127,73,17,2,0,0,5,0,0,2,0,0,0,0,2,0,0,0,5,2,8,0,5,5,5,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,54,127,54,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,3,6,15,58,127,113,30,9,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,12,6,0,0,0,31,76,127,82,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,50,44,19,19,0,0,0,0,0,0,0\n28,14,0,14,0,0,14,84,70,42,70,127,112,28,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,98,112,14,14,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,42,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,84,42,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,42,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,18,18,36,18,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,36,127,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,25,25,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,50,101,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,15,127\n0,0,0,0,0,0,0,1,0,9,18,38,127,88,68,28,5,0,0,0,0,2,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,4,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,6,18,18,9,22,5,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,1,1,5,6,21,45,111,127,85,54,2,2,0,2,0,0,0,0,2,0,0,0,0,0,0,0,0,1,0,3,5,8,2,3,2,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,12,7,21,20,25,5,1,0,0,0,0,0,1,0\n0,0,0,0,0,0,0,25,0,0,25,25,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127,101,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,63,31,31,0,31,95,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,95,127,127,31,63,63,31,63,0,95,0,31,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,5,29,127,39,1,2,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,3,28,127,63,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,16,50,25,25,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,33,127,59,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,44,22,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,74,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,29,127,14,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,15,64,127,67,55,13,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,17,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,10,68,127,89,21,5,5,0,0,0,0,0,0,0,0,5,5,0,0,0,0,0,0,10,10,26,26,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,42,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,5,10,7,4,3,5,3,1,0,0,0,0,0,0,0,0,1,0,1,4,20,55,118,127,55,12,3,2,1,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,14,13,12,7,3,1,0,0,0,0,0,0,0,0,0,0,0,3,2,13,40,95,127,79,18,0,1,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,14,29,19,14,14,0,9,0,0,0,0,0,0,0,0,0,0,4,0,0,24,24,127,78,34,9,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,8,39,21,4,0,8,8,0,0,0,0,0,0,0,0,0,0,0,4,13,39,39,127,87,35,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,0,0,0,0,0,0,0,0,0,0,0,127,25,76,0,0,0,50,50,25,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,18,127,90,72,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,108,72,54,18,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,18,18,72,127,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,18,127,90,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,127,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,31,127,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,95,31,63,0,31,0,31,0,0,0,0,0\n0,0,0,0,0,0,0,0,42,0,42,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,127,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,36,36,0,18,0,127,0,18,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,127,0,84,84,42,0,0,84,42,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,84,127,42,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,0,0,0,42,0,0,0,0,0,42,0,0,0,0,0,42,42,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,31,0,63,31,31,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,0,0,0,95,0,0,31,0,0,0,0,0,0,0,0,0,0,31,31,0,0,63,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0\n127,117,9,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,7,7,21,28,14,7,7,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,17,28,63,92,66,77,8,2,2,0,2,0,0,0,0,0,0,0,0,0,0,0,0,8,5,37,57,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,14,0,0,3,0,39,43\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,127,29\n0,0,0,0,1,1,1,1,4,6,49,127,23,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,7,0,7,0,0,39,15,39,103,127,79,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n12,9,9,9,0,0,0,9,3,30,30,127,65,12,0,3,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,21,127,0,21,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,21,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,38,127\n0,0,0,0,0,0,0,0,0,0,0,7,127,29,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,15,63,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,4,4,0,0,8,4,4,0,8,21,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,71,93,127,12,12,0,0,0,0,0,0,0\n0,0,0,5,0,0,0,0,0,11,11,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,127,115,93,33,5,5,5,0,0,0,0,0\n0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,84,42,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,127,127,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,47,0,0,0,0,0,0,0,0,0\n127,106,55,23,9,3,1,0,0,0,0,0,0,0,0,0,0,0,0\n28,18,12,9,8,5,2,7,6,6,4,3,4,2,2,2,1,1,0,1,1,2,2,2,3,6,7,8,9,11,10,14,16,19,33,71,127\n127,65,43,38,15,18,19,31,43,42,71,64,78,82,88,75,73,96,103\n127,53,27,11,3,0,0,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,4,4,1,4,10,17,74,62,127\n115,127,66,40,30,16,13,6,5,5,7,5,4,6,3,5,7,9,6,8,6,8,7,3,3,8,6,6,4,6,6,10,13,14,22,33,38\n127,63,0,42,21,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,21,0,21,0,21,0,21,42,42,21,0,0,0,42,84,127\n106,113,73,40,40,13,33,40,6,0,20,6,13,0,6,6,20,0,33,33,40,53,40,26,20,20,33,26,46,33,20,33,40,40,127,66,53\n127,74,23,17,7,7,3,0,2,1,1,0,0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,1,2,3,6,9,20,38,51,61,65\n26,40,26,26,6,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,13,6,40,80,40,40,86,127,120\n112,127,56,38,38,38,63,24,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,109,84,30,30,21,5,3,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,4,6,19,64,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,9,30,63,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,12,53,127\n127,54,27,4,4,18,18,4,18,9,4,18,9,9,4,22,0,9,9,9,22,9,9,9,9,18,13,13,9,9,0,0,0,0,0,4,18\n84,68,47,15,15,0,5,0,5,0,0,5,5,0,0,0,5,5,0,0,0,0,0,0,0,0,5,5,5,10,5,26,31,37,52,121,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,15,42,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,53,127\n0,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,42,105,127\n19,24,9,2,4,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,7,12,34,51,127\n127,70,30,13,4,2,2,0,0,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,4,8,15,26\n127,90,54,33,35,17,17,11,13,5,2,5,16,8,4,8,5,2,13,2,2,8,11,10,5,2,2,11,4,10,11,16,8,22,35,29,70\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,12,42,127\n53,53,48,46,21,38,21,18,11,10,8,10,4,11,14,9,7,32,21,51,39,49,66,94,118,109,120,118,112,104,110,105,96,104,121,127,89\n7,14,32,21,3,0,0,18,0,7,0,50,0,0,3,10,3,7,3,3,18,21,36,18,14,72,87,54,76,76,127,72,39,29,32,21,14\n0,0,21,0,0,21,0,0,0,0,0,0,0,0,0,0,0,42,21,21,0,0,84,42,21,84,105,0,21,84,21,42,84,0,21,0,127\n0,0,0,21,0,63,42,0,0,0,0,0,0,0,0,0,21,0,0,0,21,0,21,0,0,63,21,84,21,63,127,84,42,42,21,0,0\n78,84,18,24,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,6,0,6,18,18,18,24,12,36,12,18,24,12,18,12,18,12,0,18,6,0,12,12,6,24,18,12,18,18,24,18,12,18,24,12,24,30,30,36,60,42,127,84,102,102,66,48,114,114,96,78\n73,46,80,20,13,6,0,0,6,0,0,0,0,0,0,0,0,13,0,0,0,0,13,0,6,0,20,13,20,26,6,20,6,20,0,6,0,20,6,0,0,0,13,13,6,13,40,6,13,26,13,20,33,13,26,13,13,33,66,53,40,40,86,60,20,113,127,46,40,120,93,66\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,0,21,21,127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,84,0,84,0,0,127,42,0,84,0,0,0,42,0,0,42,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n76,25,76,101,50,25,127,127,0,0,25,0,0,0,0,0,25,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,7,47,39,31,15,47,15,15,23,7,7,0,7,39,63,71,103,127,87,39,55,39,15,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,42,118,25,25,25,0,8,16,8,25,42,25,16,50,59,118,84,127,67,42,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,56,127,0,14,14,0,0,0,0,14,0,42,28,42,42,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,105,0,0,0,0,0,0,0,0,0,42,63,42,63,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n22,9,18,13,4,0,0,4,0,4,4,9,0,0,4,4,0,4,13,18,4,9,0,18,13,4,0,0,27,9,9,22,13,0,4,4,0,13,0,0,0,9,9,0,4,9,4,0,13,0,18,4,22,9,22,9,9,4,4,13,18,31,40,45,86,72,90,104,127,81,31,36\n31,19,19,6,6,19,0,0,0,6,0,6,0,6,0,0,0,12,0,0,0,6,6,0,0,12,0,12,19,12,6,6,6,0,0,0,0,6,0,19,12,6,12,12,0,12,12,12,25,38,12,12,12,44,25,6,6,0,6,19,6,12,50,69,82,127,88,101,82,107,57,44\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,84,42,0,0,0,0,0,0,84,0,127,84,84,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n63,0,63,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,63,0,0,0,0,127,0,63,0,63,63,63,0,63,0,0,63,0,63\n63,63,0,63,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,63,0,0,0,127,0,0,0,63,0,63,63,127,0,0,0,0,0,0,0,0\n103,63,87,47,43,63,39,23,31,47,31,19,51,35,15,71,71,43,127\n0,33,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,13,26,40,127,40,93,33,26,13,6,6,46,13,13\n36,0,0,0,90,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,127,50,50,127,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,84,84,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,5,15,31,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,42,127\n0,0,0,0,0,0,0,0,0,21,0,127,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,21,42\n0,0,0,0,0,50,0,0,0,25,50,127,127,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,101,127,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,25,127,76,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,50,0,76,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,21,105,63,0,0,0,0,0,0,0,0,0\n0,21,0,0,0,0,0,0,0,0,0,21,116,127,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,105\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,127,0,4,0,0,0,0,0,19,9\n0,0,0,0,0,0,0,0,0,0,0,21,105,127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,21,0,84,84,127,127,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,18,36,127,127,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,127,47,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,127,120\n84,127,63,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,0,63,0,0,42,0,0,0,21,0,0,0,0,0,0,0,0,0,84\n0,0,0,0,0,0,0,4,0,6,22,81,124,127,102,22,11,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,22,58,72\n0,0,0,0,0,0,0,0,0,0,0,0,0,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,31,63,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,63,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,21,42,21,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,63,63,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,21,42,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,25,0,0,0,0,0,0,25,127,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,25,101,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,50,76,127,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,101,25,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,25,0,127,127,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,0,0,0,0,0,0,0,0,0,0,0\n127,127,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,31,63,0,31,0,31,0\n0,0,5,0,0,0,2,2,4,22,46,99,127,69,36,8,8,3,2,1,0,0,0,0,0,0,0,0,0,0,0,0,2,5,12,14,23\n0,0,0,0,0,0,0,3,3,24,63,127,51,6,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,45,27,127,72\n1,3,5,3,6,5,10,22,27,75,125,127,59,9,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,50,0,0,101,0,0,0,127,25,50,127,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,12,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,8,4,21,127,67,50,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,2,0,2,4,11,0,2,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,25,84,127,68,9,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,9,4,31,9,13,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,4,0,4,0,0,0,0,40,113,127,122,18,0,4,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,22,16,5,0,27,127,33,11,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,16,3,127,52,6,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,61,127,10,0,0,0,3,3,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,90,108,90,127,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,14,26,127,35,11,5,2,14,2,0,5,0,0,0,0,2,0,0,0,0,0,0,0,0,0,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,8,15,127,15,5,1,8,3,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,15,15,15,0,15,15,15,0,47,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,47,0,15,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,10,5,0,2,7,0,0,0,0,0,0,0,0,0,5,5,5,12,22,25,40,96,127,35,15,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,14,5,2,2,0,8,0,2,0,2,0,0,0,0,2,5,5,14,31,31,53,59,127,56,14,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,10,21,21,127,42,10,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,10,0,10,0,0,10,10,127,31,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,25,0,0,50,50,25,25,127,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,63,0,0,0,0,0,0,0,0,0,31,0,0,31,0,0,0,127,95,63,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,101,127,76,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,101,101,25,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,36,90,127,54,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,18,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,108,0,36,18,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,3,29,127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,7,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,25,127,6,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,15,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,31,0,0,0,0,0,0,0,0,0,31,0,0,95,31,31,31,0,95,127,63,0,31,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,0,0,0,0,0,0,0,0,42,0,42,0,0,0,42,84,42,42,42,0,127,42,84,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,10,10,10,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,25,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,25,0,127,50,25,0,25,25,0,0,0,0,0,0,25,25,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,23,0,0,23,0,0,0,0,0,0,11,0,11,0,23,23,46,57,103,127,92,57,103,11,11,0,0,11,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,9,9,0,0,0,0,0,0,0,0,0,9,9,18,9,99,54,127,27,63,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,18,0,18,18,0,0,18,18,54,18,72,127,72,18,54,18,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,0,0,0,0,25,50,25,0,25,0,25,25,76,127,25,101,50,76,50,50,50,0,0,0,0,0,0,0,0,0,0,0\n127,40,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,115,87,61,44,12,13,6,3,1,1,0,0,0,0,0,0,0,0\n127,79,25,20,12,11,5,8,2,11,7,3,5,4,9,1,4,3,3,5,9,5,6,4,6,5,5,7,2,11,5,8,7,7,10,34,30\n127,33,2,0,2,0,8,5,30,8,49,27,33,33,24,44,38,55,71\n84,84,63,42,0,63,21,0,42,21,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,21,0,42,127,127,21,63,84,84\n0,108,18,18,127,0,0,0,36,0,54,0,18,36,0,0,54,18,36,18,18,54,18,36,18,72,36,54,0,72,36,36,72,18,18,108,0\n0,63,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,63,0,0,0,0,63,0,127,0,127,0,0,0,0,0,0,63,0\n84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,42,0,0,0,0,0,42,84,0,127,42,0,84,84,0,0,42,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,42,63,74,127\n0,50,0,0,0,0,0,76,0,0,50,25,50,0,127,25,50,25,25,0,0,25,25,25,0,25,25,0,25,0,0,0,25,0,0,0,50\n0,0,0,12,0,0,0,0,0,0,0,12,0,12,25,38,63,101,127,88,38,0,12,12,25,25,12,0,0,25,0,0,0,0,0,25,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,31,31,127,63,31,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,42,42,84,127,84,0,42,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,23,57,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,23,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,36,72,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,36\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,15,0,111,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,127,84,21,105,105,105,0\n30,96,127,35,60,45,40,55,10,71,91,71,10,25,40,20,25,45,0,15,0,5,0,0,10,15,0,0,0,15,0,0,5,10,10,10,0\n127,119,39,15,63,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n117,97,68,97,39,127,48,58,58,48,48,29,29,9,9,0,29,19,9,19,19,29,0,0,19,19,29,0,0,9,19,39,0,9,19,0,39\n58,127,107,29,0,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n63,63,63,0,0,127,0,0,63,0,0,0,0,127,127,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,0,63,63,0,0,0,63,0,63,0,0\n0,0,63,0,0,63,63,0,127,63,63,63,0,63,127,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,63,0,0,0,0,63,0,63,0,63\n0,21,21,0,63,42,42,21,0,127,21,42,21,63,42,42,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,127,0,0,127,127,0,0,0,0,127,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,21,42,105,127,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,0,42,0,0,0,0,127,0,0,0\n0,0,0,0,0,0,0,0,0,1,0,1,2,8,18,30,55,85,127\n0,0,0,0,0,0,0,0,0,0,0,0,7,7,3,26,74,67,127,93,89,59,63,48,59,85,59,26,11,22,3,11,18,11,33,14,7\n127,25,15,19,19,3,6,9,19,9,6,3,12,9,3,6,6,19,19\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,127,28,0,0,0,0,0,14,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,63,0,0,0,63,127,63,0,63,127,0,63,0,0,0,63,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,127,84,0,84,42,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0\n63,63,31,127,95,63,63,31,0,63,31,0,31,0,95,95,95,31,0,0,0,31,0,63,31,0,0,31,31,31,0,0,0,0,0,31,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,127,25,25,76,50,25,25,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,14,0,7,14,127,42,14,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,15,0,63,31,0,0,31,0,0,31,31,47,47,63,0,127,0,0,0,47,0,0,15,0,15,15,31,31,0,15,31,47,31,0,31,31\n0,0,0,0,0,0,63,0,127,0,127,63,127,0,0,63,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,0,0,63,0,0,63,0,0,0,0,0,63,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0\n127,39,11,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,71,103\n7,19,5,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,1,1,7,19,78,127\n127,63,42,0,0,0,0,0,21,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,63,42\n127,55,15,15,0,39,0,15,55,0,39,7,7,7,15,39,7,31,7,0,7,0,0,7,15,7,7,31,15,31,23,15,0,31,31,55,95\n42,0,0,0,0,0,0,0,0,0,42,42,42,0,127,42,42,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n84,42,0,0,0,0,0,0,0,0,42,0,0,0,42,0,0,84,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0\n0,0,0,0,0,63,0,0,0,0,63,0,0,63,63,0,0,63,127,63,63,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,127,0,63,0,0,0,0,0,0,0,0,0,0,0,0,63,0\n0,0,0,0,0,0,0,0,0,0,84,0,0,0,0,0,84,42,42,0,0,0,0,0,0,0,0,0,0,84,0,127,42,0,0,0,0\n0,0,0,0,0,0,0,42,42,0,0,0,0,84,0,0,0,127,127,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,63,0,0,63,127,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,63,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,84,84,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,42,42,84,84,84,127\n63,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,15,0,0,15,15,0,0,0,0,0,0,0,0,0,15,0,63,63,127\n0,0,0,0,0,0,63,0,0,0,0,0,31,95,31,0,0,0,31,31,0,0,0,0,0,0,0,0,0,0,31,63,0,31,0,127,63\n0,0,0,0,0,0,0,0,0,0,0,25,25,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,50,127,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,74,127,127,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,127,42,42,127,127,0,0,0,0,0,0,0,0,0,0\n127,105,0,84,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,42,0,21,63,21,42,21,105,42,21,84,127,63,105,42,42,0,42,21,0,0,0,21,21,0,21,21,42\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,108,127,108,72,90,18,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,5,40,34,5,23,17,0,5,0,0,0,0,0,0,0,0,0,0,11,11,11,5,34,75,127\n0,0,0,39,0,0,7,15,15,47,111,127,87,39,23,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,9,9,0,107,58,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,58,19,0,127,58,0\n0,0,0,0,0,0,0,4,4,39,29,58,97,127,102,68,68,19,4,9,0,0,0,0,0,0,0,0,0,9,4,14,19,19,53,92,68\n0,0,0,0,0,0,0,0,0,0,21,21,84,42,42,21,42,127,63,21,0,0,21,0,0,0,0,0,21,21,0,0,21,21,21,0,0\n0,0,0,0,0,0,0,0,7,14,14,35,28,21,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,56,49,127\n0,0,0,0,0,0,25,0,0,0,25,127,25,50,76,50,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,101,101\n0,0,25,0,0,25,25,127,25,25,0,50,127,50,0,25,0,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,31,31,63,31,63,0,63,31,127,95,31,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n36,72,36,72,127,18,72,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,1,0,0,0,0,0,2,1,2,8,15,27,60,127,64,7,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,2\n0,63,0,63,0,0,0,63,0,63,127,63,0,0,127,127,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,11,80,0,57,34,69,11,69,0,23,23,23,0,0,0,0,0,0,0,0,0,23,23,57,23,34,127,92\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,0,42,0,0,127,42,84,84,42,0,0,42,84,0\n127,127,84,63,21,84,105,21,0,42,0,0,0,0,0,0,0,0,0\n0,0,25,0,0,0,25,50,25,25,127,76,127,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,50,0,50,0,76,25,25,127,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n31,63,0,31,0,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,31,127,0,63,63,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,31,0,31,0,0,31,0,127,31,0,0,63,31,0\n0,0,42,42,0,127,0,0,42,127,42,84,0,42,84,42,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,31,31,95,31,63,31,31,0,0,0,0,0,0,31,63,63,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,50,0,25,76,127,127,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,42,21,105,127,127,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,95,127,63\n127,105,116,95,116,95,116,105,10,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,99,99,36,99,72,117,99,36,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n84,42,63,63,21,42,63,0,0,0,0,21,0,0,0,21,0,0,0,0,0,0,84,42,63,42,105,127,63,42,0,0,21,0,0,0,0\n84,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,0,0,0,42,63,0,127,0,42,0,0,0,21,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,63,127,0,0,0,0,31,31,0,0,0,0,0,0,0\n63,127,31,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,7,15,50,96,127,55,23,8,7,3,2,0,0,0,0,0,0,0,0,0,0,2,1,0,1,15,34,68,100\n0,0,0,0,0,0,0,0,0,22,29,37,127,29,52,29,29,44,7,0,7,0,0,0,0,0,0,0,0,7,0,7,22,22,67,52,119\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,1,11,29,47,127\n0,0,0,0,1,0,0,0,1,4,33,127,68,4,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,11,0,0,11,34,80,103,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,127,115\n127,109,86,60,39,34,21,11,9,4,2,1,1,0,0,0,0,0,0\n11,13,7,3,6,5,7,8,15,12,1,4,2,3,3,2,1,0,1,0,0,1,1,3,3,6,6,7,7,11,4,8,7,8,24,57,127\n127,115,47,23,19,5,1,5,9,5,27,29,37,41,47,73,57,67,79\n127,110,98,91,79,77,49,47,37,11,4,2,2,2,0,0,0,0,0\n0,0,0,0,0,0,0,0,31,31,0,95,0,63,95,31,95,31,0,31,0,127,31,63,0,31,95,127,63,63,0,31,31,63,31,127,0\n127,56,13,5,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n105,127,109,68,53,20,15,7,2,3,2,2,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,5,8,15,41,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,10,0,10,10,10,21,0,84,95,105,95,127\n51,62,49,70,91,118,127,91,75,40,18,9,2,1,1,0,0,0,0\n0,6,9,2,6,9,4,13,50,34,55,53,55,39,46,32,32,16,4,16,18,43,27,30,50,64,78,55,32,39,78,16,87,127,69,64,46\n4,2,8,4,10,8,24,6,10,34,47,43,59,71,65,63,98,100,127\n127,48,12,5,7,2,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,4,4,4,9,11,30,127\n86,29,24,9,4,11,6,0,0,2,2,13,2,0,2,6,4,2,4,0,0,0,0,0,0,4,0,0,2,15,11,4,9,38,74,77,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,7,7,15,39,31,55,31,127\n0,0,0,0,0,0,0,0,0,0,0,0,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,21,21,84,84,127\n127,65,23,11,9,7,5,4,5,2,3,1,2,1,0,2,7,2,0,4,2,3,1,4,1,2,4,1,3,3,1,1,2,3,9,9,28\n0,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,15,15,0,0,15,31,0,15,31,0,0,0,47,31,127\n127,73,52,37,14,5,3,1,1,0,0,0,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n56,0,127,84,98,42,70,70,0,0,14,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n66,40,60,60,106,127,113,13,6,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,46,13,4,5,5,4,3,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,84,63,0,0,21,0,0,0,42,63,42,42,42,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,84,84,84,21,42,21,0,42,0,21,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,0,0,0,0,0,0,0,0,0,0,2,0,1,5,14,22,54,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,0,0,0,5,7,63,114,127,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,3,0,13,30,36,26,30,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,10,33,72,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,3,0,6,0,12,12,24,66,111,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,3,40,63,96,100,100,127\n127,47,10,0,0,0,0,5,0,5,5,5,0,0,0,0,0,5,15,15,10,0,5,0,0,0,0,0,0,0,5,0,0,0,0,0,0\n127,63,9,1,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,27,18,27,63,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,5,5,21,47,68,121,127\n0,6,13,0,6,6,6,13,60,26,20,0,6,13,6,0,0,0,6,0,6,6,13,6,20,6,13,33,73,100,93,113,127,86,73,13,53\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,50,50,50,101,76,50,127,25,25,0\n110,76,63,42,12,16,12,16,12,25,16,33,16,21,33,29,42,33,63,127,29,59,29,33,50,38,38,12,42,33,12,21,33,8,4,0,0\n127,31,31,31,31,0,0,0,0,0,0,0,0,31,31,0,0,31,127,0,95,63,63,0,31,31,63,0,63,31,31,31,0,0,0,0,0\n80,121,127,57,57,28,11,11,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,15,63,79,63,47,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,63,8,6,4,2,2,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,127,76,76,50,25,50,0,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,40,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,7,23,39,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,4,3,8,24,69,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,4,19,29,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,31,0,0,0,0,0,0,0,31,31,0,0,0,95,31,127,31,63,0,0,0,0\n0,63,0,21,42,0,21,0,21,0,0,21,21,42,42,105,21,0,127,84,105,42,0,21,21,42,0,0,0,21,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,10,43,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,51,80,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,0,0,4,9,13,36,127\n7,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,24,21,52,127\n95,127,79,63,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,15,47,47,31\n118,127,50,8,59,67,25,33,16,8,8,0,33,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,16,8,33,16,67,101,93,50\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,0,0,25,0,25,0,101,127,127,50\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,20,69,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,25,79,127\n0,28,0,0,0,0,0,0,14,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,14,0,56,42,56,98,127,0,14,56\n127,38,114,12,38,25,38,0,50,12,12,25,0,0,0,0,0,0,0,0,0,0,12,12,0,0,0,12,0,0,0,0,12,0,0,0,0\n58,68,48,58,58,39,29,39,58,58,9,58,0,39,39,29,0,9,0,0,0,9,0,19,39,68,117,127,48,58,58,39,9,29,29,19,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,4,0,24,63,127\n50,61,43,58,18,21,14,3,0,0,3,7,3,3,3,0,3,7,3,10,10,39,43,54,79,72,112,108,123,108,127,112,90,119,65,83,101\n0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,12,0,0,38,50,50,50,127,25,0,0,12,0,0,12,0\n0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,5,0,11,11,16,38,33,22,99,33,82,66,127,99\n127,53,41,13,7,7,2,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,79,57,31,6,3,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,9,6\n127,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,6,8,2,4,20,33,53,73,100,86,127,71,84,55,71,51,71,84\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,11,0,0,11,0,57,46,92,127,103,103,69,11,23,0,11,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,127,108,127,36,18,0,0,0,18,54,18,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,50,76,127,50,101,0,0,0,0\n12,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,12,12,0,50,12,0,0,50,0,0,0,12,12,0,12,0,0,0,0,25,12,0,12,0,12,12,12,0,12,0,12,0,0,25,12,63,12,0,25,38,38,101,63,114,127,76,63\n31,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,15,15,31,15,15,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,15,15,0,15,15,15,0,15,15,0,31,31,15,47,0,95,15,31,127,15,47,0,15,95,79,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,0,127,84,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,18,18,108,72,36,127,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,95,0,127,31,63,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n112,112,52,67,29,22,7,7,7,14,7,14,14,22,14,0,0,14,52,7,7,0,0,14,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,59,127\n127,90,27,54,9,0,9,0,36,0,18,18,0,9,18,9,0,18,36,45,9,18,9,9,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,99,54\n0,0,0,42,42,0,42,0,0,127,42,42,0,0,0,42,0,0,127,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,16,9,9,29,16,39,45,29,16,26,29,16,32,9,6,35,22,58,87,71,97,110,127,107,91,55,6,9,3,9,0,3,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,8,2,25,16,8,16,14,31,28,8,16,16,19,14,8,22,16,31,87,73,76,127,98,98,53,33,22,2,0,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,31,0,0,0,0,0,0,0,0,0,31,127,31,63,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,84,0,0,42,0,0,127,42,84,84,0,0,0,84,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,14,0,14,14,42,42,56,0,0,0,14,0,0,28,28,14,28,14,14,56,56,127,98,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,14,14,28,14,0,0,0,0,14,0,0,42,14,28,70,84,42,14,127,14,14,0,28,28,14,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,9,39,9,0,0,0,0,0,0,0,0,0,39,87,127,29,9,19,29,78,87,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,76,76,127,25,50,25,0,0,0,0,0,0,0,0,25,25,76,101,25,101,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,0,0,25,0,25,50,76,0,0,0,0,0,127,50,25,101,101,76,101,50,25,0,25,0,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,76,127,50,0,0,50,0,0,0,127,50,127,76,25,25,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,42,0,0,42,127,42,0,0,0,42,42,0,0,0,0,42,0,0,0,127,127,127,84,42,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,63,0,31,0,31,0,63,31,0,0,95,95,0,63,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,21,10,21,42,0,74,31,21,31,63,10,63,52,31,31,63,31,105,31,63,95,105,127,116\n50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,12,12,0,25,0,12,50,25,50,12,25,63,50,63,63,101,50,63,50,76,38,50,76,114,114,127,101\n0,0,42,84,127,127,42,42,42,0,0,0,0,0,84,0,0,0,42,0,42,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,10,10,10,21,21,0,0,42,42,63,10,21,21,10,52,63,127,116,74,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,18,54,18,9,54,18,45,27,18,54,18,18,18,36,27,72,127,27,9,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,31,31,31,47,47,0,15,15,0,0,15,0,0,15,0,31,79,79,127,111,63,0,31,15\n0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,50,76,0,0,0,0,50,0,25,0,50,25,25,127,50,101,50,25,25\n127,107,94,48,47,22,18,3,0,2,0,0,0,0,0,0,0,0,0\n84,127,42,28,0,0,70,84,42,14,28,0,14,0,0,0,0,0,0,0,14,0,0,0,0,14,28,42,0,42,0,14,0,0,0,0,28\n0,0,0,0,0,0,0,25,0,0,25,25,76,127,50,25,50,25,0\n110,58,45,30,36,51,85,111,127,100,76,36,30,20,8,6,6,3,3\n0,0,0,0,0,0,0,21,0,42,42,21,42,21,42,0,0,0,42,0,21,63,63,42,21,127,21,42,21,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,18,0,0,18,0,0,18,18,72\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,101,25,25,25,0\n127,31,3,0,0,9,9,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,36,8,13,24,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,31,21,127,63\n127,127,87,47,28,8,0,1,0,0,0,0,0,0,0,0,0,0,0\n127,36,0,63,18,0,27,45,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,9,0,0,0,45,27,27,9,0,0,9,0\n0,25,0,0,0,0,0,76,88,76,101,76,127,114,0,25,63,88,101\n114,122,103,120,122,105,127,88,55,29,16,6,2,0,0,0,0,0,0\n127,127,0,0,0,0,95,31,95,31,31,63,0,0,63,0,0,63,0,0,0,0,0,0,0,63,127,0,0,0,31,0,31,0,0,0,0\n127,52,10,3,3,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,127,31,31,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,54,9,0,9,9,27,27,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,9,0,18,0,36,18\n127,42,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,11,27,127\n24,43,69,113,113,104,115,115,127,121,114,100,61,68,52,30,13,13,8,8,3,2,2,8,9,5,1,2,5,4,5,6,2,9,15,18\n14,38,51,70,71,86,90,108,104,127,115,88,53,43,36,18,17,9,3,5,2,2,0,8,12,1,0,1,0,4,2,6,6,5,7,16\n0,20,45,121,127,116,96,96,45,86,50,55,25,25,20,5,10,20,0,10,35,15,5,5,10,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,5,10,15,0,5,0,0,5,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n7,11,44,97,127,119,82,37,63,22,44,26,18,26,29,11,7,3,0,3,0,7,3,3,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,3,3,7,11,7,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,47,47,127,47,47,15,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,15,7,7,23,15,127,39,23,15,0,15,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n3,3,10,14,54,72,94,127,116,65,10,14,7,0,10,3,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7\n2,5,5,26,29,59,70,127,82,64,29,11,0,0,0,2,0,0,0,8,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,25,50,101,76,76,127,50,0,25,0,0,0,0,0,0,0,0,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,18,36,27,63,127,45,9,0,0,18,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,25,25,0,0,76,76,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,31,31,0,31,127,127,0,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,18,36,0,18,0,0,18,0,18,0,0,0,18,18,0,0,0,0,72,127,36,54,18,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,42,0,21,0,0,0,0,0,0,21,21,0,0,0,0,21,0,0,63,84,0,42,127,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n5,17,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,11,17,17,28,5,40,51,80,51,51,51,40,17,23,17,23,28,127,63,51,63,40,23,28\n7,22,14,14,22,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,7,0,7,22,29,59,89,112,52,44,52,59,59,29,14,14,7,104,127,82,59,119,59,44,14\n14,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,28,56,127,56,42,28,0,0,0,0,42,14,42,84,98,28,14,28,84,14\n42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,84,127,42,84,0,84,42,0,84,42,0,84,84,42,84,84,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,25,0,12,0,88,101,127,101,12,12,25,0,12,12,12,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,42,28,14,98,112,127,56,14,14,14,42,28,0,28,28,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,127,28,14,0,0,14,0,14,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,31,0,31,31,0,0,127,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n27,45,27,45,36,36,63,72,72,99,127,45,54,72,45,9,36,18,27,0,18,54,18,18,9,9,9,18,0,18,27,27,45,18,18,18\n48,29,48,48,58,68,97,78,97,107,78,39,127,39,48,19,9,0,9,9,19,0,9,9,0,9,9,29,19,39,9,29,48,19,19,9\n0,0,95,127,31,127,0,31,31,63,0,31,31,63,31,63,0,0,31,63,127,63,31,0,0,0,31,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,31,0,0,31,0,0,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,76,25,127,50,101,50,25,25,25,50,25,25,0,0,76,50,0,0,50,101,50,25,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,25,25,0,0,0,0,0,0,0,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25\n0,0,0,0,0,0,31,31,0,31,0,63,127,31,0,31,95,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,42,42,42,0,0,84,127,0,0,42,0,0,42,42,42,0,0,42,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,127,63,127,0,0,127,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,92,34,80,127,92,80,103,23,0,11,23,11,0,11,11,0,0,0,0,80,11,23,46,23,0,11,0,0,0,0,0,0,0,0,0,0,11,11,0,11,0,23,69,11,34,46,92,46,92,57,23,11,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n12,38,76,25,38,12,50,88,63,12,12,38,0,0,12,0,0,0,12,12,12,0,0,12,0,0,12,0,0,0,0,0,0,0,0,0,0,0,12,0,12,0,0,12,38,127,88,101,63,50,50,38,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12\n0,0,0,0,0,0,0,42,127,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,84,42,127,84,0,42,42,0,42,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,95,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,31,0,63,127,63,31,63,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,47,31,15,31,127,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,14,56,127,0,0,0,28,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n31,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,63,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,0,0,0,127,0\n0,0,0,31,63,63,63,31,0,0,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n84,0,84,42,127,0,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42\n0,21,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,21,84,105,127,63,0,21,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,21,105,0\n50,50,0,0,76,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,50,76,127,0,0,0,0,0,0,0,0,0,25,25,0,0,0,0,0,25,0,25,0\n21,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,84,21,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42\n0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,31,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,127,63,63\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,0,0,31,0,0,31,0,31,0,0,127,95,0,31,0,0,0,0,0,0,31,0,0,31,0\n105,21,127,42,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,21,63\n42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,127,42,0,42,84,42,0,0,0,0,0,42,0,0,0,0,42,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,18,0,36,127,72,72,18,18,36,54,36,36,108,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,10,42,127,21,31,63,10,42,42,0,42,10,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,46,57,127,57,23,0,23,34,0,0,0,23,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,31,52,74,42,10,31,42,84,42,63,21,84,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,84,0,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,42,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,63,63,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31\n0,127,31,95,127,31,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,31,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,31,0,0,0,63,0,0,63,0,31,0,0,0,31,31,0,0,0,0,0,0,0,0,0,0,31,63,31,95,95,31,127,63,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,127,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,31,0,0,95,95,95,31,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,0\n0,7,23,15,39,39,31,31,23,7,0,7,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,15,23,63,71,127,39,7,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,25,25,0,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,50,127,25,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,21,0,0,0,21,63,21,0,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,127,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,63,63,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,63,0,63,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,63,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,50,0,50,25,127,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,14,0,84,127,14,0,14,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,101,0,0,0,0,0,0,0,0,0,0,127,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,9,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,127,99,9,18,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,88,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,0,0,12,101,127,0,12,25,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,10,10,0,10,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,10,105,127,95,21,10,0,10,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,42,42,52,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,31,21,127,105,21,0,10,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,2,3,16,4,3,0,0,0,0,0,1,0,0,0,0,0,1,3,0,2,2,7,16,45,127,85,7,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,5,20,11,13,3,7,3,1,0,3,0,0,1,0,0,0,3,0,0,1,7,17,34,70,127,73,53,9,15,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,16,0,8,0,0,0,0,8,0,16,33,110,127,110,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,31,127,47,127,63,95,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,76,25,25,0,0,0,0,25,0,0,76,0,25,0,0,25,50,0,25,50,127,50,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,18,9,0,0,0,0,0,9,9,0,0,0,9,0,0,0,18,18,108,127,63,18,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,0,0,0,0,0,0,0,25,0,0,0,0,0,0,101,127,101,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,14,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,49,35,127,14,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,95,0,63,127,31,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,127,63,95,95,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,21,58,127,47,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,28,28,0,0,14,14,0,0,0,0,0,0,0,0,0,14,0,0,0,14,14,14,70,127,56,56,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,18,18,36,54,127,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,63,95,63,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,31,63,63,95,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n25,0,25,0,25,0,50,0,0,101,127,25,25,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,0,0,25,0,0,0,25,0,25\n18,0,0,0,0,36,0,0,0,36,72,54,72,18,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,36,127,108,36,18,0,36,0,36,36,36,0,0\n42,21,84,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,63,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,127,84,127,84,42,42,0,0,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,50,0,101,0,127,127,127,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,31,0,0,0,0,0,0,31,31,127,127,127,127,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,7,0,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,49,105,127,112,35,7,0,7,0,0,0,0,0\n0,0,0,0,9,0,0,0,0,0,18,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,127,117,108,18,9,9,9,9,9,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,7,21,7,21,7,0,21,7,0,0,0,0,7,0,0,7,7,42,84,127,105,42,7,7,0,7,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,6,24,6,6,0,6,6,6,6,12,6,6,18,0,0,0,0,0,0,30,12,84,127,114,42,12,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,0,0,15,15,0,15,0,0,0,0,31,15,0,0,0,0,15,15,63,47,127,79,15,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,1,1,1,2,7,14,33,127,29,11,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,5,5,4,9,18,16,2,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,3,19,92,127,115,50,61,7,0,3,0,3,0,3,0,3,7,0,3,3,7,11,11,23,42,65,38,11,15,3,7,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,95,63,127,63,63,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,6,13,26,26,53,127,20,6,0,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,46,0,92,103,127,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,23,23,0,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,63,31,127,31,31,0,31,63,31,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,25,0,25,0,25,25,127,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,0,50,50,25,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,18,18,18,127,0,18,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,36,36,54,72,36,36,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,76,25,76,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,42,0,127,84,42,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,0,0,0,12,12,38,38,0,0,0,0,0,0,0,0,12,38,63,12,127,12,25,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,15,0,15,0,0,0,0,0,0,0,0,0,0,0,0,31,127,47,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,12,12,25,63,127,101,38,12,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,10,0,10,63,127,116,63,31,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,127,84,0,0,0,0,0,0,0,0,0,0,0,0\n0,2,2,0,0,0,0,0,2,6,37,100,122,124,80,37,24,0,4,0,0,0,0,0,0,0,0,2,0,8,4,11,11,35,91,102,127,84,17,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,4,0,22,35,44,13,6,2,2,2,0,0,0,0\n0,0,0,0,0,0,0,0,4,0,24,60,127,112,42,12,14,4,6,6,8,2,4,0,0,0,0,4,2,2,4,8,16,42,60,124,120,94,34,18,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,6,32,30,20,22,10,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,127,15,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,47,63,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,84,127,63,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,69,127,57,34,46,0,23,11,11,0,0,11,11,0,11,11,11,0,34,11,0,11,11,34,57,57,57,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,15,0,15,79,111,31,15,31,63,95,79,31,47,47,47,31,31,31,31,15,31,0,0,31,47,31,79,127,127,47,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,101,12,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,5,26,47,121,127,37,10,0,0,0,5,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,6,26,53,93,127,40,26,20,20,20,26,6,6,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,72,127,0,36,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,42,21,63,84,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,105,127,84,0,0,0,0,0,0,21,63,0,0,0,0,0,0,0,0,0,42,0,0,84,84,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,10,15,2,2,0,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,85,127,38,12,0,7,5,2,0,0,2,0,0,0,0,0,0,0,0,0,5,0,2,5,5,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,76,76,127,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,7,23,63,127,111,95,103,7,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,71,87,7,39,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,7,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,20,73,127,86,53,20,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,20,80,60,20,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,26,13,6,6,0,6,0,0,0,0,0,0\n118,127,80,42,16,0,8,0,0,4,0,0,0,0,4,0,0,0,0,0,4,0,0,8,12,12,16,12,12,8,12,0,4,12,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,50,127,127\n0,2,11,5,19,57,127,44,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,31,31,63,63,31,95,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n19,0,9,9,9,127,127,48,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n42,127,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,127,42\n0,0,0,0,0,0,127,84,0,42,84,42,0,0,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,42,127,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,4,9,9,4,18,47,103,127,89,23,23,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,0,0,4,4,4,4,9,9,27,72,127,113,54,27,13,9,9,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,31,0,31,31,95,31,95,31,63,63,95,0,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,31,0,31,31,31,63,63,95,127,63,31,0,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,0,42,0,127,0,127,0,0,42,0,127,0,42,84,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,10,10,5,0,10,20,81,127,30,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,19,0,0,12,38,101,127,69,12,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,1,7,2,2,5,31,58,100,127,108,55,24,4,4,2,0,0,0,0,0,0,0,0,0,0,0,0,5,6,15,26,64,78\n0,0,0,0,0,0,0,36,36,90,90,0,54,54,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,3,9,62,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,4,0,14,127\n0,1,3,5,7,9,1,1,13,57,81,127,115,19,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,3,0,3,0,10,0,10,3,3,32,54,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,14,7,0,7,14,42,127,91,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,21,56\n0,0,0,0,0,0,0,12,12,12,0,127,114,127,38,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,38,0\n0,0,0,0,14,0,0,0,0,70,28,112,127,98,28,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,70,70,28,42,42,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,14,0,14,0,0,0,0,0,0,0,0\n0,0,12,0,0,0,12,12,0,12,50,88,127,38,38,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,38,25,12,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,38,25,12,12,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,7,7,7,84,84,127,49,21,0,14,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n3,0,0,0,0,0,0,0,0,3,127,63,75,11,7,7,3,7,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,47,31,127,31,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,58,0,0,0,0,0,9,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,11,0,0,0,0,127,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,3,0,5,8,26,93,127,40,16,6,4,5,5,0,2,1,1,1,0,1,3,0,2,6,8,12,31,98,84,19,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,3,1,1,5,25,78,127,52,18,11,3,1,0,1,3,1,0,0,0,0,2,3,3,6,3,12,46,84,73,20,1,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,42,127,21,0,0,21,21,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,31,52,10,52,74,127,21,31,31,10,21,10,0,10,10,10,21,0,0,10,0,0,10,31,63,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,9,9,29,48,29,39,127,87,9,9,0,29,0,0,0,0,0,0,0,0,9,0,0,0,0,0,19,19,9,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,7,35,98,127,84,7,7,7,0,0,0,0,0,7,7,7,7,28,7,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,5,23,75,127,63,23,0,0,17,0,0,0,5,0,0,0,5,0,0,17,5,17,17,11,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,56,127,112,28,42,0,0,0,0,0,0,28,0,0,14,0,0,0,0,0,0,0,14,14,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,7,0,0,0,14,127,7,7,7,0,0,0,0,0,7,0,0,0,0,0,7,0,0,0,7,22,7,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,22,71,35,17,17,12,5,5,12,12,10,0,0,0,0,2,0,0,5,2,15,45,33,88,127,43,7,0,0,5,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,4,28,45,37,26,8,4,4,10,8,15,10,0,0,0,4,0,0,2,0,13,30,78,100,127,28,6,2,0,2,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,25,127,76,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,0,0,0,0,0,0,0,0,0,0,15,31,0,15,0,0,0,0,111,111,127,15,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,31,0,0,31,127,95,63,31,95,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,63,31,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,9,29,29,19,29,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,58,78,78,29,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,29,29,127,29,48,19,29,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,25,101,88,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,38,101,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,12,127,12,12,0,12,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,31,31,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,63,95,63,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,54,36,18,54,36,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,36,127,0,0,18,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,25,101,76,101,25,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,50,0,0,0,0,25,0,0,0,0\n0,0,0,0,0,0,0,0,0,4,0,26,86,127,45,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,4,0,4,7,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,2,2,19,127,104,37,0,4,2,2,0,0,0,0,0,0,0,0,0,0,0,0,4,0,4,4,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,127,63,63,127,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,63,127,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,63,63,127,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,127,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,21,0,0,42,127,63,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,42,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,0,42,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,42,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,84,42,42,42,0,0,0,0,0,0,0,0,0\n50,0,50,0,25,50,0,25,127,25,101,127,25,25,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,50,25,25,101,101\n0,0,25,0,0,0,0,0,0,25,50,101,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,50\n0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,18,9,54,36,81,18,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,0,42,0,0,42,42,127,84,0,42,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,25,0,25,76,25,0,127,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,3,29,108,101,23,3,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,10,67,127\n0,0,0,0,0,0,0,0,0,0,0,7,7,37,29,74,127,7,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,14,0\n0,0,0,0,0,0,0,0,0,0,2,4,7,2,7,7,9,11,4,0,7,7,0,0,0,0,0,0,0,0,0,0,14,21,44,87,127\n63,31,0,31,0,95,31,127,31,63,0,95,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,29,0,19,58,78,127,117\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,10,0,10,42,0,42,42,127\n0,47,15,0,0,31,0,31,95,127,31,47,31,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,14,28,127,14,0,28,0,28,56,0,14,70,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n11,5,7,4,7,26,39,73,72,127,69,94,70,26,11,1,0,1,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n20,5,5,10,15,18,23,12,41,51,127,44,12,7,0,0,5,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,14,31,31,43,85,46,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,14,53,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,95,31,31,0,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127\n0,0,0,0,0,0,0,0,5,10,5,26,47,26,42,31,21,0,5,0,5,0,0,0,0,0,0,0,0,0,5,5,0,21,42,37,127\n0,0,0,0,0,0,0,0,9,36,36,45,63,63,63,45,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,54,36,63,127\n36,0,0,0,0,0,0,18,127,36,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,14,14,0,0,0,0,14,0,0,28,42,56,127,98,84,42,14,14,14,0,0,0,0,0,0,0,14,0,0,28,14,14,14,98,127,84\n0,0,0,0,0,0,21,0,63,0,42,21,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,3,5,2,3,4,27,27,97,127,84,27,3,1,2,0,0,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n14,0,7,0,0,14,29,37,127,104,82,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,84,42,127,42,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,95,63,31,31,0,0,0,0,0,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,63,31,31,63,0,31,0,0,0,0\n0,0,0,0,50,0,0,0,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,76,127,0,101,25,0,0,25,25,25,25,0\n18,0,0,0,0,0,0,0,18,72,36,18,127,72,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,36,108,90,36,90,36,18,18,0,0,18,18\n0,0,0,0,0,0,0,25,12,25,0,25,38,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,12,63,12,76,127,63,38,38,0,0,0,0,0\n0,0,0,0,18,0,0,0,18,72,72,54,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,18,54,18,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,36,54,18,36,18,127,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,25,0,50,50,76,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,76,25,0,0,0,127,25,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,25,127,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,101,76,0,0,0,0,0,0\n84,127,98,14,42,42,70,14,28,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,18,0,0,18,18,127,108,0,54,18,36,54,36,36,72\n0,26,5,68,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,127,84,28,28,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,14,14,56,0,127,112\n127,101,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50\n0,42,0,84,127,0,0,0,84,42,42,0,0,0,42,84,84,42,42,42,42,42,84,0,84,0,84,0,0,0,0,42,0,42,42,84,0\n108,18,18,54,36,36,54,36,36,18,0,36,18,90,36,36,18,127,90,36,90,18,108,18,36,18,18,36,54,0,90,18,36,72,36,18,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,127,0,0,127,63,127,0,0,0,0,127\n0,31,127,0,0,127,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,63,0,15,15,0,63,63,127,31,0,15,15,0,31,0,0,31,15,15,0,0,0,0,0,15,0,0,0,31,0,31,0,15,0,95,0\n84,0,42,42,42,0,0,127,0,0,0,0,0,42,0,0,0,42,0,84,0,0,0,0,42,42,0,42,0,84,0,84,84,0,42,0,84\n0,0,0,0,0,0,0,0,0,0,63,0,127,31,63,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,12,57,95,12,6,19,0,0,6,0,0,0,0,0,0,0,6,0,0,0,0,0,0,6,127,114\n0,0,0,0,0,0,0,0,0,0,0,0,0,33,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,84,0,0,0,127,42,84,84,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84\n31,127,0,63,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,31,31,31,31\n63,63,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,127,63,63,0,127,0,0,63,0,0,0,63,0,0,0,0,0,0,0\n0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,63,0,0,0,0,0,0,63,0,127,63,63,63,127,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0\n0,0,0,0,0,21,21,21,42,42,42,84,105,63,0,63,42,105,84,127,63,63,21,105,84,21,0,42,84,0,21,0,21,0,0,21\n127,57,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,9,38\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,95,127,95,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,63,63,0,0,0,0,0,0,0,0,0,0,63,63,0,0,0,0,127,63,0,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,42,42,0,0,42,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,42,127,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,63,42,127,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n101,84,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,31,95,0,31,0,0,0,63,0,0,0,0,31,63,0,31,31,0,31,0,0,0,0,0,0,0,0,127,95,0,0,0,0,0\n127,42,25,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,55,12,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,4\n127,68,26,79,21,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,52,52\n127,54,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,52,74,95,68,10,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,0,10\n0,0,15,47,79,63,63,31,15,15,0,0,0,0,0,0,15,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,15,63,63,47,127\n127,12,0,0,6,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n36,90,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,36,0,127,72\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,127,0,63,63,63,0,0,0,0,63,0,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0\n23,127,23,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,27,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n72,117,127,36,18,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,79,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,84,84,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,127,127,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,101,127,76,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,101,25,50,25,25,0,0,0,0,0,0,0,0,0\n127,9,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,127,36,18,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,18,0,18,36,18,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,127,18,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,27,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,127,36,9,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,11,0,0,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,46,34,127,11,0,0,0,0,0,0,0,0,0,0\n127,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n101,127,76,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,21,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,127,21,0,21,0,0,0,0,0,0,0,0,0,0\n127,34,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,114,31,12,12,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,51,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,15,0,0,0,0,0,0,0,0,0,15,0,0,15,63,63,95,127,15,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,31,0,0,0,0,0,0,0,0,0,0,31,63,63,31,31,127,63,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,63,127,31,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,76,127,0,25,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,50,0,50,50,127,0,0,0,0,0,0,0,0,0\n127,56,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,127,81,36,18,9,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,63,0,25,12,38,12,0,0,12,0,12,12,12,25,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n101,127,38,0,0,12,12,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,14,127,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,127,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127,0,0,0,0,0,0,0,0,0,0,0,0\n0,31,63,31,31,127,127,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,54,127,18,18,36,36,36,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,31,63,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0\n69,92,127,46,115,34,11,0,11,23,11,0,34,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,11,11,23,80\n77,98,77,127,105,35,35,14,14,21,28,7,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,49,0\n127,76,101,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25\n0,101,127,127,50,127,50,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,0,0\n46,23,80,103,69,34,57,11,0,11,11,23,0,0,0,0,11,0,0,0,0,11,0,0,0,0,0,11,11,11,0,69,23,80,127,115\n78,58,117,58,78,39,9,29,39,39,0,39,9,29,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,9,19,39,78,68,127,97\n127,42,127,42,0,0,127,42,127,0,42,0,42,0,0,0,0,84,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42\n46,127,46,69,34,11,34,0,57,0,0,11,0,11,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,23,11,23,11,11,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,23,46\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,42,42,127,42,42,0,0,0,0,0,0,0,0,84,0,84,127,84,0,42\n31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,63,63,95,63,0,0,0,0,0,0,0,0,0,0,63,31,127,63,0,0\n0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,6,42,96,127,66,36,6,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,14,7,77,127,112,70,28,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,39,23,39,47,127,71,23,23,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,27,63,72,127,72,9,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,84,84,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,127,0,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,18,36,18,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0\n18,27,9,0,9,18,27,108,72,81,9,18,9,9,18,54,117,72,18,36,9,0,18,0,0,9,0,0,9,27,9,45,127,63,72,36,0\n0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,0,0,0,0,0,0,31,95,31,63,31,31,0,31,31,0,31,63,127,127,31,63\n127,0,63,0,63,63,127,0,63,0,0,0,63,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,84,0,42,0,0,42,0,0,0,42,42,0,127,127,127,0,0,0,84,0,0,0,84,0,0,0,0,0,0,0,0,0,42,0,0\n0,31,63,0,0,31,0,0,0,0,0,63,127,31,31,31,63,0,0,0,0,31,31,0,0,0,0,0,0,0,31,63,63,31,0,31,0\n63,6,6,12,31,25,19,63,25,50,101,88,101,127,82,69,69,44,57,38,19,12,38,6,12,12,31,25,19,38,38,0,44,44,76,107,25\n56,14,28,0,0,42,42,42,42,42,28,0,84,28,70,70,84,56,28,0,56,42,14,14,0,0,28,42,56,84,56,28,70,84,127,42,112\n0,0,0,0,0,0,0,0,0,0,0,1,2,6,5,10,15,19,12,8,7,9,9,6,9,8,14,14,22,23,22,32,52,68,89,94,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,9,9,0,0,9,0,9,27,36,63,127,63,81,117,117,108,108\n0,21,21,0,0,0,21,63,105,0,21,21,63,21,127,63,21,21,0,21,21,21,21,0,63,21,21,0,0,21,0,63,63,42,42,63,42\n0,0,0,0,0,0,0,0,0,0,0,21,0,21,21,0,0,0,21,0,21,63,21,21,0,21,0,42,21,0,21,63,63,105,127,105,127\n0,0,0,0,0,0,0,0,0,9,4,0,9,13,9,9,9,4,9,0,9,0,9,18,18,4,9,9,13,22,27,95,45,104,108,72,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,21,0,0,63,42,0,21,127\n127,0,0,0,63,63,0,127,0,0,0,63,0,63,63,0,0,0,0,127,0,0,63,0,0,0,127,63,0,0,63,0,63,0,63,63,0\n0,111,79,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,95,127,31,15,0,0,15,0,0,0,0,0,0\n0,3,3,0,0,0,0,23,7,47,31,127,103,119,99,23,11,19,3,0,0,3,0,0,3,0,0,0,7,3,11,11,31,23,95,103,55\n0,0,0,0,0,0,36,54,0,72,54,72,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0\n0,0,0,0,4,0,24,14,29,48,48,127,63,43,29,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,0,0\n0,0,0,0,14,0,0,14,0,70,42,112,84,127,56,14,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,28,0\n0,0,0,0,0,36,0,18,0,72,0,127,72,18,36,0,0,0,0,0,0,0,36,0,0,0,0,18,36,0,0,0,18,18,18,72,36\n0,0,0,0,0,0,0,0,25,0,0,0,50,127,25,25,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,76,0\n0,0,0,0,0,12,0,0,0,0,0,25,25,0,25,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,50,0,127\n0,42,42,127,0,42,0,42,0,0,84,84,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,11,11,23,23,34,127,11,46,23,69,23,23,0,0,23,0,11,11,0,0,0,0,23,23,0,11,0,23,57,46,115\n0,0,0,127,127,63,63,0,0,0,0,127,0,0,63,0,0,63,63,0,63,0,0,0,127,127,63,63,63,0,0,0,63,127,0,0\n0,0,0,0,0,0,0,0,0,84,127,42,127,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,84\n0,0,21,21,0,0,0,42,21,127,127,42,63,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,37,127,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,127,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,42,0,0,42,0,0,0,0,0,0,0,0,0,0,42,0,0,84,42\n0,0,0,0,0,0,0,0,0,42,127,42,63,63,63,10,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,10,0,10,31,95,63\n0,0,0,0,0,0,0,0,31,0,0,63,0,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,63,63,127\n0,0,0,0,0,0,0,0,42,0,84,127,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,127,84\n0,0,0,0,0,0,0,5,5,17,40,80,127,75,51,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,40,86,46\n0,0,0,0,0,0,0,0,0,0,6,63,127,69,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,57,114\n0,0,0,0,0,0,5,0,0,0,8,41,127,60,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,24,110\n0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,21,127,63,21,21,21,0,0,0,0\n0,54,0,54,127,108,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,31,95,127,127,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n72,0,36,0,0,0,0,18,0,0,0,0,0,0,18,18,0,0,0,0,0,0,0,36,0,0,18,36,0,0,18,36,108,54,36,127,108\n0,0,0,0,0,0,0,63,0,95,95,0,0,0,0,0,0,0,0,31,31,63,31,95,31,31,31,127,0,31,0,31,31,31,0,63,0\n117,127,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,39,78\n127,63,0,10,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,21,31,42,84,105\n127,76,41,12,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,9,22,22,31\n25,0,38,0,0,12,12,0,0,0,0,12,0,0,0,0,0,25,12,0,0,0,0,0,0,0,0,12,0,0,0,12,0,25,25,38,127\n96,127,73,48,37,46,16,7,16,5,5,3,0,1,0,0,0,1,1,3,1,5,1,1,0,1,0,3,1,5,1,5,5,3,7,10,19,16,14,25,8,8,5,1,0,3,3,0,1,1,0,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,3,10,16,32,84\n127,106,106,83,93,53,10,10,6,16,20,20,3,0,0,0,0,0,3,3,3,0,3,3,13,0,3,6,3,3,3,6,10,3,13,13,13,26,10,20,16,6,0,3,3,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,0,10,6,23,66,80\n42,127,127,98,14,14,0,14,14,28,0,0,14,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,42,28\n63,0,127,105,84,0,21,21,0,0,0,0,21,0,21,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,63\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,0,0,42,127,127,0,127,0,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,63,84,0,21,21,0,0,0,127,42,21,21,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n82,104,127,112,52,59,29,7,7,0,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,7,7,0,0,14,0,7,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,7,22,52\n46,73,127,127,86,60,13,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,13,0,6\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,48,78,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,0,127,39,19,9,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,127,70,15,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,20,17,16,2,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,2,3,37,127,127,28,3,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,39,127,79,15,47,23,15,0,0,0,0,0,0,0,0,7,0,7,0,0,0,7,23,71,87,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,127,42,84,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,127,25,101,76,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,127,90,90,72,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,10,31,105,127,31,52,52,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,10,10,31,21,0\n0,0,0,0,0,0,72,84,0,6,6,127,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,14,0,0,42,14,84,42,14,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,127,0\n0,0,0,0,0,0,0,0,0,0,8,84,127,62,11,15,6,2,4,15,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,33,20,0,13,127,40,33,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,27,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,9,9,36,9,18,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,36,27,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,9,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,127\n109,127,75,51,28,5,5,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,11,23,28,57,69,109,40,28,5,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,0,5,0,0,5,0,28,63,86\n100,106,53,40,26,33,26,13,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,6,13,13,13,26,46,20,33,40,6,13,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,80,127\n0,21,84,63,42,63,42,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,0,0,0,127,63,63,42,0,84,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,11,23,23,46,69,127,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,11,11,11,11,34,0,11,23,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,15,15,0,0,15,31,127,31,63,47,0,15,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,127\n0,0,0,0,0,0,50,101,127,127,127,50,0,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,0,25,0,50\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,31,111,15,15,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,63,127,63,127,0,127,0,0,0,63,63,63,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,1,1,0,1,1,0,1,1,1,1,0,0,3,5,15,23,46,83,127\n0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,8,0,0,17,28,83,92,127\n0,2,0,3,2,0,0,0,1,3,2,4,5,5,4,6,7,5,16,6,7,6,4,9,8,10,17,5,15,11,13,25,37,42,45,91,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,63,0,127,63,63,63,0,63,0\n0,0,0,0,31,31,0,31,31,0,0,0,0,0,0,31,0,0,127,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,95,31,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,63,0,63,63,63,127,63,63,0,0,0,0,0,0,63,127,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,127,0,0,84,0,42,0,0,0,84,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,42,84,0,0\n0,0,0,0,0,0,0,0,127,79,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,0,0,0,0,0,0,0,0,18,36,72,127,72,18,90,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,21,84,127,127,21,127,0,0,0\n0,0,0,0,0,18,36,18,18,127,0,0,0,0,0,36,72,54,18,18,18,0,0,0,0,0,0,0,0,0,0,18,36,18,72,36,72\n127,63,0,0,0,0,0,0,0,0,0,0,0,0,63,0,63,0,0,0,0,0,0,0,0,0,0,0,0,63,63,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,8,17,48,74,122,127,74,26,8,52,13,26,17,13,13,21,0,8,8,4,8,0,13,26,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,63,95,15,127,63,111,95,127,95,15,15,0,15,15,0,0,0,0,0,63\n0,0,0,0,0,0,0,0,0,0,0,18,0,36,127,72,36,72,36,54,0,18,0,18,18,18,18,36,54,18,0,54,54,0,54,54,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,7,39,87,63,79,111,127,111,87,103,39,31,15,0,15,7,15,7,23,7,31,31\n0,0,0,0,0,0,0,0,0,1,0,0,18,32,123,127,65,36,13,8,6,9,1,3,1,0,3,1,1,3,4,1,4,8,11,1,0\n0,0,0,0,0,0,0,0,0,0,12,51,72,117,127,99,66,45,30,12,24,15,6,3,3,15,12,12,9,6,3,9,9,0,27,6,6\n0,0,0,0,0,0,0,0,88,25,0,0,25,101,0,127,25,12,12,0,0,0,0,0,0,0,0,0,0,12,0,38,12,50,76,50,76\n0,0,0,0,0,0,0,0,35,127,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,42,0,0,0,0,21,127,42,42,21,63,21,0,0,42,0,0,84,0,0,0,0,0,0,0,21,0,0,21,42,105,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,127,50,76,0\n84,63,84,21,84,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,63,127,84,127,127,105,63,21,21,0,0,0,0,0,0,0\n0,2,2,0,2,2,9,18,23,32,37,127,89,101,39,25,21,16,11,2,0,0,0,0,0,0,0,0,2,2,9,14,18,28,39,103,98\n14,14,43,14,9,29,29,43,58,63,127,92,78,48,14,48,9,4,0,0,9,0,0,0,0,0,0,4,0,4,4,0,14,29,43,48,14,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,24,39,34,48,53,68,112,73,53,102,78,34\n18,14,26,3,7,22,33,48,52,74,74,59,104,26,7,26,11,0,7,0,0,0,0,0,0,0,0,3,0,0,7,0,14,22,14,14,11,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,11,11,22,29,18,26,33,63,70,127,59,56,14\n18,0,0,36,18,0,54,108,18,36,36,127,90,54,18,36,0,18,0,18,0,0,0,0,0,0,0,0,36,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,36,18,18,72,72,72,54,127,108,54\n72,18,54,0,54,36,18,72,18,18,18,72,108,18,108,0,0,18,0,0,0,18,0,18,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,18,127,36,108,127,36,90,54\n0,0,0,0,0,0,0,0,0,0,0,0,0,13,13,4,17,8,4,0,0,0,0,0,0,4,0,0,4,8,17,48,127,61,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,10,10,15,26,10,0,0,0,0,0,0,0,5,0,10,0,15,10,52,127,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,0,0,0,0,0,0,0,0,42,84,0,84,0,0,0,84,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,0,0,0,0,0,31,0,0,31,0,0,95,0,0,31,31,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,47,15,15,31,63,111,127,63,79,0,0,0,0,31,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,15,0,0,0,15,0,31,0,0,15,31,79,0\n0,0,0,21,10,10,52,52,127,63,95,31,0,0,0,10,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,42,10,0\n12,12,0,38,0,25,12,25,50,76,50,88,101,25,0,0,25,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,38,114,76,127,50,25,38,12,25,0,0,25\n14,0,0,42,0,0,0,42,70,42,84,28,84,0,42,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,28,0,42,14,28,14,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,14,28,56,98,98,127,84,70,28,28,28,0,0,42\n9,9,0,0,0,0,9,48,127,39,0,9,0,0,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0\n25,0,0,0,0,12,0,76,127,88,0,0,12,0,12,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0\n0,0,31,0,0,63,0,31,31,31,63,127,31,31,31,0,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,36,36,36,18,63,63,54,27,27,0,0,0,0,0,0,0,0,0,0,0,18,9,0,0,63,0,27,108,127\n0,0,0,0,0,0,0,0,11,11,34,127,92,57,57,11,23,0,23,0,0,0,0,0,0,0,0,0,0,0,0,0,11,57,80,103,46\n0,0,0,0,0,0,0,0,28,14,14,0,0,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,28\n0,0,0,0,0,0,0,0,0,15,26,42,127,116,26,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,58,95,74\n0,0,15,0,0,0,0,15,0,15,47,111,31,31,15,47,15,0,0,0,0,0,0,0,0,0,0,15,0,0,0,15,15,127,79,79,31\n0,0,0,0,0,0,0,0,31,0,127,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,95,95,127,95,0,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,31,63,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,31,0,0,127,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,127,95,127,31,0,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,31,31,63,63,0,0,0,0,0,0,0,0,0,0\n127,0,0,21,21,28,0,42,28,0,0,0,0,0,0,7,0,0,0\n12,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,9,127\n0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,89,127,59\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,1,2,4,127\n127,2,0,0,0,0,0,0,0,0,8,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5\n63,15,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,31,79,127\n63,127,31,31,0,0,0,0,0,0,63,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0\n127,63,12,12,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,111,31,15,0,15,15,0,0,15,15,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,84,105,21,0,21,0,42,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,42,84,21,0\n0,63,31,95,95,63,95,63,31,31,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,0,127,63\n0,0,127,0,63,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,63,127,0,0,63,127,127,0,0,63,0\n127,127,63,31,0,0,0,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,63,0,0,0,0,0,31,127\n0,0,0,0,47,0,0,0,0,15,15,0,15,15,0,0,0,0,31,47,0,0,15,31,0,0,15,0,0,0,0,0,0,0,0,0,127\n63,0,0,31,0,0,0,63,0,0,0,127,95,31,63,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,25,25,76,76,25,127,0,50,76,50,25,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,84,63,127,42,21,21,105,63,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n31,127,31,95,63,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n95,95,111,47,127,15,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,39,29,78,39,87,127,58,68,97,87,78,48,29,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,29,19\n0,0,0,0,0,0,0,0,0,25,0,38,50,88,76,50,0,0,0,0,0,0,0,0,0,0,12,0,0,12,50,50,12,127,76,38,50\n0,0,0,0,0,0,0,0,0,0,50,127,0,76,0,25,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,101,127,76,0,50\n0,0,0,0,14,42,28,14,84,127,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,21,42,63,84,127,21,21,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,21,21,63,63,42\n0,0,0,0,0,0,0,0,0,95,0,127,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,63,31,0\n0,0,0,0,0,0,0,0,0,21,0,105,63,21,21,0,21,0,0,0,0,0,0,0,0,0,0,21,0,42,0,42,63,63,42,21,127\n2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,4,6,20,31,47,127\n7,3,0,0,0,0,0,0,3,0,10,10,14,0,0,0,0,3,3,0,0,0,7,3,29,39,61,127,108,105,61,39,39,36,3,7,14\n0,0,0,0,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,31,0,0,0,63,0,0,127,0,0,31,63,0,0,0\n0,0,0,0,0,0,0,0,0,15,31,0,0,15,0,0,0,0,15,0,47,15,15,31,15,47,47,63,31,15,0,0,0,0,0,15,127\n127,19,7,19,3,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n50,127,25,76,50,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0\n8,15,4,0,2,0,0,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,4,10,21,63,85,122,127\n0,127,84,21,63,63,21,0,0,0,0,21,0,21,21,21,0,21,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,25,38,38,12,12,0,0,0,12,25,0,12,0,0,0,0,0,0,0,0,0,0,0,25,38,0,25,38,38,12,50,12,12,12,127\n127,127,63,0,15,0,15,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0\n0,84,84,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,42,0,0,0,0,0,0,0,42,0,0,0,84,0,0,42,0,0\n63,91,39,15,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,7,83,87,55,127\n40,127,80,93,33,13,26,33,0,0,0,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,6,0,6,6,6,6,13\n50,50,127,25,25,50,0,50,50,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n50,38,63,127,76,101,76,12,38,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,25,25,25\n0,0,0,0,0,63,127,127,31,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n31,127,79,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n36,54,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,99,54,127,108\n0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,54,54,127,54,36,127,127,72,108\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,6,13,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,14,70,56,42,56,70,14,127,70,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,63,4,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,73,19,14,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0\n0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,79,127\n42,127,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,10,10,127\n63,0,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,0,63,127,63,0\n63,15,31,0,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,47,15,0,15,0,31,127\n0,0,0,4,12,33,46,55,12,16,4,8,0,12,8,0,0,0,4,8,0,0,4,0,8,0,0,0,0,0,0,0,0,0,4,0,127\n0,0,0,0,0,0,0,0,0,0,0,31,31,63,31,0,0,31,95,31,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63\n0,0,0,0,0,0,0,0,0,0,31,31,0,0,0,31,0,127,63,95,63,0,31,63,31,31,63,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,9,0,0,18,0,18,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,9,127\n25,0,0,0,0,0,0,0,12,25,12,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,63,63,31,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,63,63,127,95,31,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,84,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,7,3,3,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,127\n0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,42,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,84,84,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,63,21,127,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,84,63,63,42,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,14,127,28,14,28,14,28,0,28,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,1,0,0,1,1,0,0,0,2,1,52,127,109,38,31,25,12,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,23,123,127,63,35,67,35,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,21,63,42,21,0,42,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127,21,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,50,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,127,101,50,25,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,84,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,84,0,0,42,0,42,0,42,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,16,25,16,33,16,16,0,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,33,25,127,50,25,16,16,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,0,0,0,0,0,0,0,0,42,42,0,0,0,0,42,42,127,127,84,84,0,84,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,50,76,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127,50,0,0,0,0,0,0,0,0,0,0\n0,42,0,0,0,42,42,42,42,42,0,42,0,84,84,42,42,0,42,0,0,0,0,0,0,84,127,127,0,84,84,42,0,0,0,84,42,0,0,0,42,42,42,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,63,0,0,0,63,0,0,63,0,127,63,63,63,63,63,127,0,0,0,0,0,0,0,127,63,0,127,0,127,0,0,0,63,127,0,127,127,127,0,63,0,0,0,63,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,0,0,0,0,0,63,127,63,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,12,63,76,127,50,12,0,0,12,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,127,69,69,23,11,34,11,23,23,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,54,0,0,0,18,54,127,18,36,36,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,84,0,127,42,84,127,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,63,0,31,31,31,127,95,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,31,63,127,31,0,0,0,31,0,31,0,63,0,0,0,31,0,0\n0,0,0,0,0,31,31,31,0,95,0,0,0,127,0,31,31,31,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,76,127,12,12,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,40,127\n0,127,84,84,84,84,0,0,42,0,42,0,0,84,84,0,42,127,84\n0,63,63,0,63,63,0,127,63,63,0,63,0,0,63,0,63,63,0\n127,25,50,12,38,12,0,12,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,9,12,12,22,92,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,84,0,0,84,0,42,84,0,0,42,127,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,0,47,58,37,127\n0,0,0,0,0,0,0,0,0,0,0,54,108,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,36,18,0,0,0,0,0,0,0,0,0\n50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,76,0,50,25,25,50,0,25,127,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,36,0,127,18,0,0,0,18,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,127,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,47,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,127,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,63,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,84,0,127,42,42,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,0,0,0,42,0,42,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,127,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,127,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,50,0,25,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127,0,50,50,0,0,0,0\n0,0,0,0,0,0,31,0,0,63,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,127,63,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,127,25,25,0,50,25,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,127,0,25,67,0,8,8,0,0,0,0,0\n0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,92,11,23,127,23,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,9,39,127,19,9,19,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,25,25,0,25,25,0,127,76,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,25,0,0,0,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,101,25,50,0,0,0\n31,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,127,31,31,63,63,0\n127,78,44,26,3,15,5,3,0,0,0,0,0,0,0,0,0,0,0\n127,42,0,0,0,21,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,42,42,0,42,21,42\n0,0,0,0,12,0,50,63,127,38,50,50,50,76,38,25,0,12,0\n127,15,0,0,0,15,15,31,15,31,47,47,0,0,0,0,0,15,0\n0,0,0,0,0,0,0,0,42,0,42,42,0,42,0,84,0,0,0,42,42,0,0,0,42,0,0,0,0,0,0,42,0,42,0,127,0\n127,123,90,60,36,27,21,15,27,21,6,9,12,9,12,18,21,15,24\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,52,52,127,116,74,105,31,52,127,74,31,0,10,0,0,0,0,0,0,0\n69,127,69,115,57,11,23,11,0,23,23,57,46,69,11,46,80,23,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,4,0,0,2,1,0,1,1,0,1,4,37,127\n14,44,48,112,127,89,108,123,78,89,89,37,33,18,7,7,11,11,18,3,14,11,11,18,3,11,3,14,7,44,74,115,108,89,108,127,82\n60,127,60,66,54,36,24,18,18,42,18,6,18,0,0,0,18,0,6,6,12,0,0,6,0,0,6,6,12,6,0,6,0,0,0,6,0\n11,0,22,55,66,127,88,66,55,71,27,27,11,11,16,11,5,0,0\n0,0,21,0,0,0,0,0,0,42,21,42,21,42,0,42,0,21,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,63,127,63,0,0,0,0,127,0,0,63,63,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,14,0,0\n18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,90,36,90,90\n127,21,10,0,0,21,0,10,10,10,10,10,10,10,0,0,0,0,0\n127,77,40,27,9,13,0,0,0,4,4,0,4,0,0,0,0,0,0\n42,127,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,31,9,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,38,12,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,2,3,1,9,31,127\n127,41,3,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,76,0,12,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n28,127,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,79,127\n84,127,34,9,4,2,22,47,29,19,2,7,0,0,0,0,0,0,4\n127,50,101,101,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,108,0,36,9,9,0,0,0,0,0,0,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,52,10,0,21,42,21,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n92,23,127,23,0,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,4,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,22,45,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127\n0,0,0,0,0,0,0,21,32,10,58,127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,42,0,127,0,84,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,81,53,46,25,14,8,4,0,0,0,0,0,0,0,0,0,0,0\n28,56,98,28,42,84,70,127,70,98,28,28,14,14,14,28,0,14,28\n0,0,0,0,0,0,0,0,23,7,79,15,15,31,31,39,87,47,127\n67,67,59,71,78,127,110,114,105,69,27,23,33,14,12,8,10,6,8\n42,0,42,0,21,21,21,0,21,42,84,42,127,42,84,127,42,21,21,21,0,0,21,21,42,42,21,63,0,21,63,42,63,42,84,0,0\n0,0,0,0,0,0,0,0,0,0,21,42,0,63,42,42,42,127,0\n0,0,0,0,0,0,0,25,50,127,84,93,42,76,84,59,59,67,16\n0,0,0,0,0,3,7,19,3,0,7,7,7,11,15,84,76,127,84\n0,0,0,0,0,0,0,0,0,0,76,0,0,25,50,25,25,0,0,25,50,50,25,127,76,50,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,39,63,127,119,31,0,15,0,0,0,23,15\n127,72,26,8,13,0,4,2,2,0,2,2,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,83,71,51,30,24,14,3,1,2,0,0,0,0,0,0,0,0,0\n20,18,10,2,6,8,12,4,12,10,6,6,4,0,0,0,4,0,2,2,4,4,0,0,4,8,20,14,10,10,6,2,10,22,30,61,127\n72,36,0,0,18,9,0,36,0,0,0,0,18,0,18,9,18,45,127\n26,17,14,27,35,73,100,123,127,62,53,35,14,13,2,1,2,6,2\n0,0,0,0,0,0,0,0,7,91,105,63,42,70,49,56,14,21,21,42,28,42,21,14,42,21,35,21,21,0,14,28,21,70,56,49,127\n0,0,0,0,0,0,0,0,0,0,0,15,15,0,31,127,31,31,31\n127,95,41,28,6,6,6,3,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,14,127\n0,0,0,0,0,3,3,127,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,63,0,0,0,0,127,63,63,127,63,0,127,63,0,0,0,0,63,0,0,0,0,63,0,0,0,0,0,0,0,0,0\n0,63,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,63,0,63,0,0,63,127,0,127,63,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,84,42,84,84,42,84,127,0,84\n25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,127,25,101,50,0\n116,127,111,74,42,52,52,37,26,47,47,37,58,42,47,84,68,79,52\n127,52,21,10,10,21,21,0,0,0,0,0,0,0,0,0,0,10,0,10,42,31,21,21,21,74,74,105,31,95,95,52,0,31,21,10,21\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,101,127,101,25,0,0,12,63,38,0,0,0,0,0,12,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,18,127,90,90,54,72,72,0,18,36,18,36,36,18,36,18,0,0,18,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,84,127,42,0,42,42,42,42,42,0\n127,63,21,84,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,14,42,98,28,127,127,28\n0,0,0,31,0,0,31,31,31,0,127,31,31,95,0,31,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,127,63,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,50,127,0,76,25,0,0,25,0,0,0,0\n112,127,87,88,95,90,98,73,47,26,20,17,13,14,7,9,5,4,4\n0,0,0,31,0,0,95,0,31,95,95,95,63,95,63,95,0,127,31,31,63,95,0,31,95,0,63,31,31,31,31,0,31,63,31,0,0\n36,0,0,0,0,0,0,18,0,0,0,0,54,72,127,127,36,54,36\n119,127,119,97,82,59,67,22,59,7,22,22,0,0,0,0,0,0,0\n112,98,70,42,42,127,70,70,14,14,14,14,0,84,42,28,70,84,84\n120,109,127,120,83,79,58,60,40,2,4,4,2,0,0,2,0,0,0\n0,39,48,9,39,58,68,39,68,107,19,39,9,9,9,29,19,9,9,9,9,9,29,29,78,127,87,68,68,39,68,19,9,29,19,19,0\n0,0,0,0,0,0,0,23,0,7,39,55,55,23,55,23,31,15,127\n32,49,38,44,46,59,78,93,120,127,92,74,45,46,28,20,9,13,8\n0,0,0,0,0,0,0,14,0,0,42,42,84,127,56,42,98,56,42,56,28,70,42,42,84,28,14,14,14,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,3,26,52,63,123,127,127\n127,79,79,63,47,15,15,79,63,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n84,0,0,0,0,0,0,0,21,0,0,127,21,84,21,21,0,0,42,0,21,0,0,21,0,21,0,21,21,0,0,0,0,0,0,0,0\n95,47,127,15,31,15,0,15,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,31\n25,12,12,12,12,25,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,12,25,12,12,38,12,127\n21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,31,10,21,21,31,31,52,95,52,127,63\n42,8,16,4,4,4,4,4,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,0,0,0,21,16,29,127,59\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,84\n0,0,0,0,0,0,0,0,0,95,95,127,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,31,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,21,21,0,42,127,0,21,0,42,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,50,50,50,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127,10,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,127,16,0,0,0,0,0,0,0,0,0\n0,0,0,31,31,0,0,0,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,95,63,63,127,0,31,31,0,0,0\n0,84,0,0,0,0,0,42,42,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,127,42,84,42,42,42,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,0,127,63,0,0,63,0,127,63,0,127,0,0,63\n0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,42,84,127,127,127,42,84,84,84,84,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,84,0,42,42,0,0,42,127,84,84,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,84,0,0,0,42,42,42,0,0,84,42,127,42,0,0,0,0,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,127,0,127,0,84,42,0,42,0,0,0,0,0,42,0,0,42,0,0,0,0,0,0,42,42,42,42,84,42,0,0,0,42,42,42,0\n0,0,0,0,63,63,0,127,127,0,0,0,0,0,0,63,63,0,63,63,63,63,0,63,0,0,0,0,0,0,0,63,63,0,0,0,127\n0,0,0,0,0,0,0,0,15,15,47,127,63,63,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,0,31,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,31,127,31,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,25,76,25,0,25,127,0,0,0,0,0,0,0,50,0,0,0,0,0,0,0,25,101,25,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,54,72,127,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n36,9,0,0,0,9,18,99,127,36,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,13,0,0,0,0,0,20,66,127,66,6,0,0,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,25,0,127\n0,18,0,54,127,18,0,0,0,0,36,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127,25,76,25,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,84,84,127,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,127,42,84,0,0,84,0,0,0,0\n0,63,63,0,31,0,31,31,31,0,31,63,0,0,0,0,0,0,127\n0,0,0,0,0,0,0,0,31,0,31,127,95,31,95,63,95,0,63,0,63,31,0,0,63,31,0,0,0,0,31,0,63,0,127,31,63\n127,81,33,12,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,9,0,3,18\n0,0,0,0,0,31,63,95,15,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,47,0,0,127,0,0,79,0,0,15,0\n72,127,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,36\n92,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,69\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,28,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,15,0,0,0,0,0,0,0,0,127,79,47,47,31,0,0,0,0,0,0,0\n0,0,6,13,127,26,80,33,0,0,0,0,0,0,0,0,0,0,0\n84,127,70,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,25,25,76,25,127,25,0,0,0,0,0,0,0,0,0,0,0,0\n26,46,53,93,33,66,106,127,86,46,6,13,20,0,6,0,0,0,0\n0,0,0,31,0,0,0,0,0,31,0,0,0,0,0,31,31,31,0,0,31,31,31,0,31,31,0,0,0,95,0,0,0,0,0,63,127\n0,0,0,0,0,0,31,15,15,31,31,31,63,127,15,79,15,0,31\n0,0,0,0,0,0,0,0,12,0,0,0,0,0,6,25,63,101,127\n127,47,55,23,23,31,15,0,0,31,7,7,7,0,0,0,0,0,0\n50,0,0,0,0,50,76,0,127,76,101,76,50,50,50,25,0,0,50\n127,52,21,63,21,21,10,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,10,95,95,127\n63,95,63,63,31,31,127,31,0,31,0,0,31,0,0,0,0,0,0\n0,63,0,0,0,63,63,63,63,127,127,127,0,63,0,0,0,0,0\n0,0,0,0,0,0,21,0,0,105,127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,27,36,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,36,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,69,127\n0,42,42,127,0,0,127,84,127,42,84,0,0,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,42,0,0,84,0\n74,127,127,14,29,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,30,48,127,75,24,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,14,28,42,28,70,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,14,28,0,28,56,56,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,63,63,63,127,127,0,63,0,63,63,0,0,63,0,127,63,0,63,63,63,0,63,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,5,0,2,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,15,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,42,127,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,0,0,127,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,63,0,63,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,63,0,127,0,0,63,63,0,63,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,6,0,12,0,127\n0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,0,0,84,127,84,42,127,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,116,52,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,95,95,127,31,31,31,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,63,0,0,0,95,127,31,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,18,72,127,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,54,36,0,0,0,0,0,0,0,0,0,0,0,0\n46,34,0,11,11,0,57,80,92,127,92,46,46,46,57,0,23,103,115\n12,30,127,96,60,18,0,12,0,0,0,0,0,0,0,0,0,0,0\n0,42,127,127,42,84,42,42,0,127,127,84,0,0,42,0,0,0,0\n0,127,76,50,127,25,76,50,0,25,0,0,0,0,0,0,0,0,0\n127,114,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n101,127,12,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n84,127,63,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,21,42,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42\n72,90,36,127,72,36,54,127,18,0,18,18,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,127\n0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,0,0,42,0,127,42,0,127,84,0,0,0,84\n127,58,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,127,0,0,63,63,0,63,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,127,0,0,0,63,0,127,63,0,63\n127,92,61,39,25,4,0,7,3,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,1,3,16,26,93,127\n0,127,47,0,0,0,79,15,0,15,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,47,15,79,15,95,127\n127,57,25,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,9,77,127\n127,45,38,35,10,0,3,0,0,0,3,3,0,0,0,3,0,0,0\n0,0,15,15,15,127,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,42,127,42,0,0,0,42,84,127,0,0,0,0,42,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,84,127,84,127,127,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,84,84,127,42,42,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,25,12,25,0,12,76,127,76\n0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,21,84,127,63,0,21,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,84,127,105,84,0,0,0,0,0,0,0,0,0\n0,90,18,0,36,36,127,36,36,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,84,127,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,63,47,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,114,101\n127,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,127,0,0,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,63,31,0,31,0,0,0,31,0,0\n127,21,0,0,0,0,21,21,42,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,63,21,21,0,42,42,105,127\n0,0,0,0,0,0,21,21,21,0,0,0,0,0,0,0,0,0,0,21,0,21,42,0,0,21,21,0,0,0,21,0,0,21,21,21,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,1,2,7,127\n127,53,26,30,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,127\n21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,63,127,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n52,78,56,52,13,4,4,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,17,39,74,65,127,105\n95,47,15,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,31,95,95,127\n127,111,63,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,47,63\n127,38,0,0,12,0,25,12,12,0,0,0,0,25,12,0,0,12,0,0,0,0,0,12,0,0,12,0,0,0,0,0,0,0,0,0,25\n84,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,31,31,105\n127,95,52,14,14,17,14,0,10,0,3,7,0,0,0,0,0,0,0,0,0,3,0,0,3,0,10,14,0,7,21,10,3,7,31,42,49\n127,85,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,8,44\n127,31,19,12,12,3,0,0,0,3,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,6,9,6,0,9,12,9,38,69\n108,127,27,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,4,4,0,4,40,63\n117,127,19,29,0,9,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,9,9,9,19,0,0,29,29,117\n0,127,84,84,42,84,42,42,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,84,0,0\n0,0,0,0,0,0,0,0,0,63,0,0,63,0,0,0,63,63,63,0,0,0,0,0,0,0,63,63,63,0,0,0,63,0,63,0,0,63,63,63,0,0,0,0,0,0,63,63,0,127,63,63,0,63,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,0\n0,0,63,0,0,0,0,0,0,63,0,0,0,0,0,0,63,0,0,0,0,63,0,0,0,0,0,0,63,0,127,63,63,0,0,63,0,0,0,0,0,0,0,0,0,0,0,63,0,127,63,0,63,0,63,0,0,63,63,0,0,0,0,0,63,0,63,0,63,63,0,0\n118,82,83,70,127,101,59,43,24,5,0,0,0,0,0,0,0,0,0\n127,76,38,12,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,38,12,25,50\n127,127,50,50,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,12,0,12,25,25\n0,0,0,0,0,42,0,0,84,84,42,127,84,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,69,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,88,69,6,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,68,68,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,13,20,20,127,6,13,40,0,13,0,6,0,0,6,40,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,36,127,54,36,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n28,14,14,0,0,0,0,0,0,0,28,0,84,98,28,42,42,42,14,14,14,0,0,0,0,0,0,28,0,0,0,14,28,112,42,127,84\n0,0,0,0,0,0,9,9,14,127,122,89,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,3,0,0,0,0,0,3,10,10,14,17,45,14,17,17,14,7,0,7,0,10,0,0,3,0,17,24,7,10,28,49,52,70,127\n0,0,0,0,0,0,14,14,70,127,84,14,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,21,0,0,0,42,21,21,84,105,0,127,21,21,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42\n0,0,0,0,0,0,0,0,0,127,21,105,0,0,0,0,0,0,0,0,0,0,0,0,0,63,21,84,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,84,0,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,42,84,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,42,0,0,0\n0,0,0,0,0,0,0,0,0,84,84,42,0,84,127,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,5,19,59,127,97,24,10,10,1,0,3,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,84,42,127,42,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,29,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,127,28,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,31,63,63,127,95,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,127,84,84,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,0,42,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,25,0,0,0,25,0,76,50,127,50,0,0,25,0,0,25,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,36,117,81,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,63,31,63,0,31,0,95,127\n0,42,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,0,0,127,127,0\n32,10,7,9,4,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,4,10,42,81,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,127,127\n127,43,15,3,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,2,17,61,127\n127,84,63,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,21,84\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,63,127,127\n31,23,39,15,23,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,7,71,127,79,71,111,63\n31,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,79,127,111,127,31\n127,81,26,5,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,33,8,76,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,49,70,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,79,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,10,10,10,79,127\n127,38,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,23,11,11,34,80,127,127,115\n0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,127,0,0,63,63,63,0,0,63,63,0,0,0,0,0,0,0,0,63,0,0,0,0,127,0,63,0,0,127,127,127,0,0,0,0,63,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,31,0,0,31,0,127,127,63,63,0,0,95,63,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,63,0,63,0,127,0,127,127,0,63,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,1,3,2,1,0,1,4,12,21,44,90,127\n10,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,21,5,0,0,10,74,47,5,0,21,5,0,10,10,5,37,127,42,37,52,74\n127,63,8,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,9,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,9,27,54,127,18\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,42,63,127,84\n127,37,10,0,0,0,0,0,0,0,10,0,0,0,5,5,5,0,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n84,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,21,0,0,21,0,21,63,63,127,84\n127,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,68,5,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,87,127\n0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,0,95,63,63,127,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,56,127\n67,127,37,41,22,7,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,18,59,82\n53,42,25,28,1,1,5,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,3,1,5,15,53,100,127\n101,114,50,25,50,127,63,12,50,0,12,0,0,12,0,0,0,0,0,0,0,0,0,0,0,12,12,0,0,0,0,12,12,0,0,0,0\n0,84,42,127,127,127,42,84,0,127,42,0,0,42,42,0,0,0,42,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,14,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,19,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,10,0,0,10,121,68,127\n0,0,36,0,0,0,0,18,0,18,0,36,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,36,18,0,54,54,127,36,36,18,108\n127,91,20,0,0,0,0,0,0,2,2,0,2,2,2,5,5,0,0,0,2,5,2,2,0,2,0,2,0,0,2,2,0,2,53,106,66\n127,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,58,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,21,0,31,21,10,52,31,116,127\n27,5,38,49,38,55,77,115,88,127,82,82,38,60,22,16,5,5,0,5,5,5,11,11,11,5,11,22,0,11,16,27,11,44,11,27,27,44,71,88,44,44,49,38,22,33,11,11,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,11\n10,12,21,34,68,83,72,106,100,127,86,89,56,36,39,40,32,18,7,10,7,10,17,3,15,4,17,14,15,14,12,14,12,34,17,21,25,51,54,84,79,79,81,75,62,53,18,1,3,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,1,3,1,1\n0,0,0,0,0,84,42,84,0,42,84,0,0,0,84,0,42,0,127,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,42,0,42,0,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,8,33,93,84,84,127,67,8,8,8,8,0,8,8,0,0,0,8,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n21,0,21,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,42,84,21,63,127,84,42,21\n18,72,127,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,0,0,0,0,0,18,0,0,0,0,18,0,36,72,72,90,36,127,127,36,108\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,14,28,0,56,0,0,0,14,28,14,28,28,42,28,56,98,42,70,127,127,98,56,56,14,56,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,32,42,14,28,18,0,42,28,65,56,32,32,32,4,23,32,42,127,65,51,32,28,32,18,9,18,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n14,0,0,42,28,70,127,70,42,28,14,14,0,0,14,0,0,0,0,0,0,0,0,14,14,14,0,0,0,14,14,0,14,14,14,0,0,0,14,0,14,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,14,14,14,0,14,0,14,0\n0,0,12,25,12,25,88,25,38,25,25,12,0,25,0,0,0,0,0,12,0,0,0,0,0,0,12,0,12,0,12,12,12,0,12,0,0,0,50,0,127,63,38,12,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,12,0,38,0,0,12,0,0\n18,18,54,36,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,127,127\n127,84,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,21,21,0,21,0\n63,63,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,63\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,0,63,127,95,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,42,42,127,84,84,127,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n120,127,55,32,21,4,4,13,4,0,4,4,12,2,5,1,2,1,0\n50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,0,0,0,25,0,0,0,0,25,0,0,0,0,0,25,0,101,127,50\n127,63,45,13,18,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,9,47,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,127,31,63,31,63,63\n127,95,56,77,42,10,7,0,3,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,3,0,0,3,0,0,3,0,10,24,35,42\n127,48,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,2,6,24,58,127\n119,119,127,56,0,3,10,3,0,0,0,0,0,0,0,0,0,0,0\n127,11,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,18,18,127\n63,127,95,63,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,22,127\n0,0,0,0,0,0,0,0,0,0,0,31,31,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,95,0\n127,51,17,11,11,17,5,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,47,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,15,15,0,0,0,0,0,0,0,0\n127,27,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,31,0,95,127,0,63,127,95,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n10,21,68,89,127,121,89,84,100,89,52,63,15,52,10,10,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,5,0,0,0,15\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,58,95,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,90,127,72,36,18,108\n127,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n108,127,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,127\n0,0,127,63,0,0,0,47,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,95\n0,0,84,0,42,84,0,42,127,84,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,31,116,127,42,74,95,52,21,21,42,10,0,10,0,0,21,0,0,0,21,0,10,21,10,0\n36,0,0,0,0,0,0,0,0,0,36,54,127,0,36,18,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,18,36,36,72\n0,0,0,0,0,0,0,0,0,0,0,63,63,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127\n50,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,21,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,127,42,63,42,0,0,21,21,0,0,0,0,0,0\n0,0,4,0,0,0,18,2,2,4,32,100,106,94,45,6,6,4,4,0,0,0,2,0,0,0,2,0,0,0,0,2,0,16,47,75,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,10,33,127\n0,0,0,0,0,0,21,0,42,127,42,105,127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n9,1,3,1,3,0,7,10,23,21,61,127,95,12,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,127,76,101,101,25,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,50,101\n0,0,0,0,0,0,0,31,127,95,63,0,31,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,15,47,127,15,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,31,0\n0,0,0,0,0,0,0,0,0,0,10,10,105,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,58,117,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n63,63,63,127,0,0,0,0,0,0,63,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,63,0,127,63,0,0,0,0,0,0,0\n127,106,102,94,83,84,53,25,14,6,0,0,0,0,0,0,0,0,0\n8,17,17,17,17,17,56,35,52,52,30,21,8,0,0,8,4,4,0,0,4,0,0,4,4,30,21,26,13,21,91,48,26,21,83,127,43\n0,0,0,0,0,0,0,0,31,47,0,15,63,79,127,15,95,95,127\n13,3,5,3,5,18,42,82,127,116,109,71,42,23,10,4,1,4,1\n0,0,0,0,0,0,0,0,0,21,56,42,63,70,127,56,42,7,21,35,7,42,21,49,14,42,21,7,21,49,28,0,14,0,0,7,0\n0,0,0,0,0,0,0,0,0,0,28,0,0,70,98,98,0,127,112\n0,46,0,0,0,46,23,69,115,127,80,80,11,0,0,11,0,0,0\n0,0,0,0,0,0,0,0,0,15,0,0,0,47,127,0,0,31,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,7,95,103,95,127,55,79\n127,33,46,33,80,11,35,57,11,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,50,127,38,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,0,76,127,127,127,127,25,0,0\n127,95,31,0,0,0,0,31,0,0,31,0,31,0,31,0,0,0,0,0,0,0,0,0,0,63,0,31,31,0,0,0,0,31,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,127,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,0,0,15,0,15,0\n0,0,0,0,42,0,0,0,0,0,0,0,42,0,42,84,0,0,42,0,0,0,127,84,42,84,84,42,0,0,0,42,0,0,0,42,0\n63,127,63,47,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,42,42,0,127,21,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n46,80,23,23,11,0,0,34,46,34,103,92,92,127,115,115,103,69,46\n0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,50,50,25,127,25,101,50,101,50,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,42,0,21,0,63,84,63,21,42,21,21,63,63,21,105,105,127\n120,127,101,77,51,43,34,29,21,17,9,4,4,1,0,1,0,0,0\n0,1,1,1,0,1,1,1,5,5,7,3,0,2,1,0,0,0,0,0,0,0,0,1,0,0,2,5,5,1,3,2,1,3,27,64,127\n39,39,39,9,9,0,9,0,0,9,48,58,58,127,87,58,0,9,0\n127,102,87,68,68,78,87,78,39,29,9,4,0,9,19,4,4,4,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,127,31,84\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,18,127,18,18,18,54,90,108,72,108\n127,127,0,31,31,31,63,95,127,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,41,16,7,5,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,21,105,127,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,15,15,0,15,47,0,31,127\n0,0,9,4,13,4,4,4,27,13,22,13,77,95,63,90,63,72,127\n0,0,0,0,0,0,0,0,0,0,0,127,0,127,0,42,42,0,0,84,42,0,42,42,0,0,0,0,0,0,42,0,0,0,0,0,0\n70,91,81,100,127,118,85,72,52,43,63,43,54,81,50,65,52,30,30\n0,0,0,0,0,0,0,3,0,7,0,3,0,3,7,30,0,0,0,3,3,3,15,26,3,3,3,0,3,0,0,0,11,3,46,127,76\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,10,10,0,0,21,10,84,63,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,42,127,101,25,0,8,33,59,25,33,0\n0,25,25,50,101,25,127,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n56,56,42,98,112,127,70,84,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n121,127,88,95,81,40,12,10,1,3,0,1,0,0,0,0,0,0,0\n14,0,3,7,17,14,10,7,0,7,0,10,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,3,7,0,0,3,10,17,28,127\n0,0,0,0,0,0,0,0,14,0,0,14,42,42,70,127,14,0,0\n39,25,31,47,50,76,98,127,127,70,56,33,14,5,5,11,0,2,11\n0,0,0,0,0,0,31,0,0,0,0,31,0,95,0,0,0,0,0,31,31,0,31,0,31,0,0,0,0,0,0,31,0,31,63,127,63\n0,0,0,0,0,0,0,0,0,15,0,0,15,15,47,63,95,111,127\n127,21,42,74,74,21,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,21,0,0,21,31,31,10,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,10,127\n127,63,23,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,3,0,39,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,7,10,7,33,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,63,127\n108,72,127,9,27,0,9,18,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,42,0,42,0,0,84,0,0,0,42,0,42,42,42,0,0,0,0,84,84,127,127,0,0,0,0,0,0\n84,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,31,95,95,63,127\n127,127,31,31,0,0,0,0,0,0,0,31,31,0,0,0,0,0,31,0,0,31,0,0,0,0,0,0,31,0,0,31,0,0,31,0,0\n0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,84,127,42,42,84,42,0,0,84,42,0,84,0\n127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,84,21,42,0,0,21,21,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0\n63,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,127,127,0,127,95,95,31,0,0,0,31,127,63,63\n127,74,10,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,114,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,18,0,0,0,18,0,0,0,0,18,0,0,0,0,0,0,0,0,36,72,36,127,90,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,31,31,0,0,0,31,0,0,31,31,0,95,63,0,127,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n19,19,40,23,52,71,127,107,95,91,67,50,23,28,14,23,9,14,9\n0,0,0,0,42,0,0,0,42,0,0,42,0,0,0,0,84,42,0,0,0,0,42,42,42,127,84,0,0,42,0,0,0,42,0,0,0\n17,17,21,12,17,33,32,59,94,110,119,127,82,109,85,64,46,57,53\n0,0,0,0,0,0,0,0,0,0,42,0,127,42,42,0,0,42,84,0,84,42,42,127,127,42,42,84,42,42,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,31,31,0,95,0,127,63,95,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,127,72,108,36,36,0,0\n127,40,20,33,20,6,6,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,118,106,82,92,47,22,10,4,0,0,0,0,0,0,0,0,0,0\n115,63,11,34,51,46,28,17,11,5,11,0,0,0,0,0,0,0,0,0,11,17,0,0,0,11,5,0,0,17,11,63,34,69,40,51,127\n127,0,0,0,15,0,0,0,31,31,31,79,15,31,31,63,15,15,63\n60,35,42,37,50,77,116,127,97,74,37,26,11,8,2,3,0,0,3\n0,0,0,0,0,0,21,42,63,127,63,0,21,42,21,21,0,21,0,0,0,0,21,21,0,0,21,21,21,0,0,21,21,42,63,21,42\n0,0,0,0,0,0,0,0,0,0,63,63,127,127,63,127,127,63,0\n3,1,6,1,33,67,100,127,127,102,81,45,15,10,12,6,8,3,0\n0,0,0,0,0,0,0,15,15,47,31,47,0,47,31,0,31,31,15,47,47,0,0,31,31,127,95,63,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,6,16,56,89,127,123,115,75,62,57,44,38,35\n0,0,0,0,0,0,0,0,0,127,95,63,127,63,127,127,0,31,0,31,63,0,0,31,63,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,15,23,15,15,23,15,63,127,95,95\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,7,7,7,7,23,103,63,55,47,127\n127,49,42,21,0,21,21,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,49,0,4,45,4,18,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n50,50,0,127,0,0,0,0,0,0,0,0,0,0,50,0,50,0,0,25,25,0,0,0,0,0,0,25,0,25,0,0,0,0,25,0,101\n0,0,0,0,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,54,54,127,54,36,36,0,18,0,0,0\n115,127,103,46,11,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,11,23\n0,0,0,0,0,31,0,0,0,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,31,63,31,63,31,31,0,0,0,0,0,127\n127,45,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,68,32,27,23,7,2,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,6,3,3,7,4,4,2,8,4\n127,47,0,31,0,47,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,47,0,31,0,15,0,0,0,0,0,0\n0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,21,21,42,21,127,63,21,42,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,42,42,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,56,0,0,0,0,0\n42,0,0,0,0,21,21,42,42,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,105,84,127,42,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,63,127,95,31,31,0,0,0,0,0,0,0\n20,36,39,51,60,92,86,85,113,127,126,105,96,68,43,36,35,24,21,19,14,23,18,22,31,30,18,23,16,8,15,7,13,18,10,16\n22,34,53,48,60,71,90,119,122,127,118,107,99,67,45,39,35,43,23,16,28,29,16,25,33,28,20,21,11,10,4,7,10,6,8,16\n42,63,63,0,127,42,105,84,63,84,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,21,21\n50,76,101,76,127,127,50,76,127,101,25,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,31,37,58,74,127,116,31,68,79,42,31,47,15,31,10,21,0,21,47,52,58,74,31,10,5,5,5,5,0,0,0,0,0,0,0,0,0,5,0,0,5,26,31,58,21,5,31,42,5,21,5,5,0,0,5,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,5\n0,29,42,29,71,127,76,88,42,80,71,21,16,16,12,16,21,8,12,38,63,97,88,46,16,4,4,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,12,29,25,8,0,29,12,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4\n0,0,0,42,0,42,0,42,84,105,127,105,127,63,42,0,21,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,28,28,42,84,127,56,98,42,14,0,14,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,3,13,35,42,71,65,113,127,117,32,29,16,26,3,3,0,9,3,6,0,6,3,3,0,0,0,0,0,3,0,0,0,3,0,6\n0,8,11,17,20,32,100,127,103,59,94,32,17,5,8,5,2,2,0,8,8,2,8,0,0,0,0,2,0,0,0,0,5,0,2,0\n0,84,84,127,63,21,21,63,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0\n0,31,31,31,95,127,63,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,28,0,14,14,28,42,127,98,42,0,0,14,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,36,36,72,36,54,127,36,72,0,18,0,0,36,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,12,6,0,18,0,18,18,18,12,24,42,90,84,42,60,54,102,48,78,127,48,48,6,6,6,0,12,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,40,15,0,0,5,0,5,15,5,15,5,45,60,86,30,30,76,127,111,71,50,86,40,15,10,0,5,0,5,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,63,31,95,0,31,95,0,127,63,0,31,127,127,95,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,21,21,42,42,127,42,0,42,42,21,84,105,42,42,0,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,42,0,42,127,84,0,0,127,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,25,25,127,101,25,50,76,50,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,23,11,46,46,80,92,57,115,46,34,57,80,127,34,127,11,69,0,11,11\n0,0,0,0,27,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,9,9,27,45,27,127,90,18,72,36,63,63,63,127,117,63,63,27,27,9,18\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,0,31,0,127,95,63,0,0,0,0,31,0,31,63,31,0,63,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,63,0,127,105,127,21,0,0,0,21,21,42,63,21,0,21,0,21,0,0\n25,31,31,82,50,57,114,101,82,88,107,76,127,63,31,57,76,57,82,25,69,50,63,63,31,31,31,38,19,19,19,25,12,12,0,25\n23,23,40,34,23,57,98,103,86,121,121,127,46,98,86,86,51,75,75,28,57,51,69,57,57,23,23,17,28,23,11,17,23,5,11,28\n0,0,25,25,25,127,101,25,25,25,50,25,25,0,0,0,101,25,76,50,76,25,76,76,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,50,50,50,0,25,0,0,0,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n21,42,63,63,42,127,84,63,42,42,42,21,0,21,0,21,42,42,84,84,63,21,63,42,63,42,0,21,0,21,0,0,0,0,0,0,0,0,0,0,0,0,21,21,21,42,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21\n0,0,0,0,11,115,127,34,23,0,23,23,34,0,11,23,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,31,21,127,21,42,74,31,0,0,0,10,10,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,16,0,0,0,0,0,0,8,8,25,0,42,50,0,33,33,16,127,59,16,33,25,25,50,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,15,15,15,47,47,63,79,0,15,0,127,47,111,127,79,95,79,31,0,47,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,36,90,127,54,36,18,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,15,127,31,31,15,31,79,63,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31\n0,0,95,31,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,127,127,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31\n0,84,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,84,42,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,84,84,0,84,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,0,63,63,127,63,127,0,63,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,31,31,0,0,127,95,31,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,31,0,0,0,0,0\n127,63,95,63,0,127,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0\n0,42,127,42,127,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,84\n0,127,84,42,84,42,42,127,42,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,42,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n14,28,32,89,127,65,61,56,14,18,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,4\n5,15,52,116,127,42,58,21,15,21,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,5,5,0\n21,21,0,63,127,63,21,21,0,0,0,0,42,21,0,0,0,21,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,21,21,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,42,84,42,84,0,42,42,0,0,42,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,127,42,127,42,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,14,0,0,0,0,14,28,127,28,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,8,0,25,25,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127,93,33,0,8,0,0,0,8,0,0,0\n0,0,0,0,0,0,0,11,11,34,23,46,92,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,46,127,34,11,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,47,127,47,79,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,18,0,9,18,9,45,127,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,25,0,0,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,50,101,76,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,76,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,31,31,95,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,63,63,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,29,44,29,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,14,104,112,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,15,0,0,0,0,0,0,0,0,0,0,15,0,15,0,15,15,15,47,79,127,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,25,25,50,127,101,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,4,4,4,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,127,100,21,8,13,4,0,0,0,0,0,0\n0,0,0,0,0,4,0,0,0,4,0,13,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,95,127,27,13,9,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,127,63,31,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,127,127,127,42,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,127,69,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,80,127,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,31,127,95,111,79,0,31,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n25,0,0,0,25,0,0,50,0,0,101,50,76,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,14,28,14,0,14,14,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,112,127,84,56,56,0,14,14,0,42,0,0\n0,42,14,0,0,0,14,0,56,28,127,112,42,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,84,98,14,42,14,14,14,14,28,14,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,47,87,55,23,7,15,0,0,0,0,0,23,7,0,0,0,0,0,0,7,23,7,23,127,23,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,12,38,25,76,88,50,12,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,76,127,63,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,18,108,18,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,36,127,18,36,18,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,25,50,50,25,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,0,76,127,127,25,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,42,127,127,84,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,31,31,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,63,0,127,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,21,63,105,63,42,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,21,127,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,21,21,42,127,84,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,63,0,0,0,63,63,0,0,127,63,0,63\n0,0,0,0,0,0,0,0,0,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,127,95,31,31,0,0,63,31,0,31\n40,17,0,0,0,5,5,17,23,63,86,127,86,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,63,46,34,23,5,0,17,0,0,0,0,11\n13,18,4,0,4,9,4,9,40,58,127,108,49,13,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,36,54,18,9,9,0,0,0,4,9,0,9\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,127,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,1,0,3,6,36,88,127,84,46,26,5,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,5,16,50,87,40,13,5,0,0,0,0,0,0,0,1,3,1,0,0,0,0,0,0,1,0,3,19,56,56,39,14,10,5,0,1,0,0,0,1\n0,0,0,0,0,0,3,0,11,7,19,71,127,111,99,27,11,7,3,3,0,0,0,0,0,0,0,0,3,11,7,3,3,7,23,99,51,75,19,11,0,0,0,7,0,0,0,0,11,7,0,0,0,0,0,0,0,3,3,39,31,47,51,7,23,0,3,3,0,0,3,0\n0,0,0,0,0,0,0,0,0,0,9,0,18,54,18,0,9,0,0,0,0,0,9,0,0,0,0,0,0,0,9,9,27,127,36,0,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,9,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,31,95,31,31,127,63,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,50,127,101,50,25,0,0,0,0,0,0,0\n0,0,0,0,0,14,0,0,0,0,0,0,98,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,98,127,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,28,84,56,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,21,0,74,63,31,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,31,21,127,31,31,21,0,0,0,0,10,0,0,10,10,0,0,0,0,0,0,0,0,21,84,10,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,102,127,0,2,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,9,48,68,127,48,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,127,127,127,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,63,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,7,15,55,47,103,127,103,0,15,0,0,0,0,0,0,0,0,0,0,0,0,7,7,0,0,7,39,23,55,47,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,7,23,23,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,5,10,40,96,127,25,40,5,5,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,10,15,15,40,30,15,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,0,20,5,0,0,0,0,0,0,5,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,127,9,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,127,127,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,31,79,79,31,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,15,15,15,31,15,0,0,0,0,0,0,0\n0,0,95,31,31,95,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,63,42,21,63,63,63,127,105,63,42,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,101,12,76,76,38,127,63,50,12,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,95,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,3,12,39,78,99,127,127,81,21,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,9,45,111,96\n0,0,0,0,0,0,0,0,12,12,101,88,127,114,38,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,12,25,12,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,49,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,127\n0,1,0,0,0,0,0,2,5,21,73,127,12,5,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,84,84,42,0,0,84,127,127,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,3,27,43,75,87,127,51,31,11,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,19,27,63\n0,0,0,0,0,0,11,0,0,23,92,127,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,21,0,0,42,63,105,127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,42,0,0,42,127,127,84,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,54,72,108,127,72,36,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,14,70,127,127,98,14,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,2,0,0,4,14,29,127,97,43,14,7,4,4,0,0,4,0,0,0,4,4,2,0,0,2,4,51,92,95,53,7,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,5,10,37,127,99,35,13,8,5,2,10,0,5,0,2,0,0,0,0,0,0,2,18,35,75,91,64,10,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,12,127,25,0,0,0,0,0,0,0,0,0,0,0,0,38,0,12,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,95,63,31,0,0,0,0,0,0,0,0,0,0,31,0,31,0,0,0,0,31,31,127,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,127,95,63,0,63,0,0,0,0,0,0,0,0,0,0,0,31,0,0,63,0,127,95,31,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,25,25,50,0,0,0,0,0,0,0,76,101,0,0,0,0,25,0,0,25,0,127,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,14,14,14,42,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,14,42,14,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,127,56,28,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,54,127,108,72,72,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,72,54,72,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,54,127,127,0,18,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,18,36,36,18,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,18,54,127,36,0,54,0,0,0,0,0,0\n0,0,0,0,0,0,42,0,42,84,0,84,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,84,127,84,127,42,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,127,57,23,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,11,46,57,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,70,127,56,14,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,8,0,8,8,0,8,0,8,25,25,33,8,0,0,0,0,0,0,0,0,8,0,0,0,0,8,16,8,16,8,8,0,67,127,33\n0,31,0,0,31,0,0,0,0,0,0,0,31,15,31,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,31,0,0,95,95,127,95\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,47,0,47,31,95,47,79,79,127,31\n0,0,127,0,63,0,127,0,0,0,0,0,0,31,0,0,0,31,0,63,0,0,0,0,0,0,0,0,0,0,31,0,0,31,63,63,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,0,23,11,103,127,11,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,42,21,21,84,21,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,42,0,0,0,0,42,0,0,0,0,0,42,0,42,0,0,0,0,0,0,0,42,0,0,42,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,127,42,84,0,0,42,42,42,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,12,0,0,25,12,38,12,63,63,127\n127,47,0,111,15,15,79,63,0,15,15,15,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,0,31\n0,12,12,25,25,38,38,12,38,76,76,127,114,88,38,50,38,63,50,38,0,0,0,0,0,0,0,0,0,25,0,0,12,12,25,38,25\n0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,21,21,10,21,74,10,31,127,42,42,63\n0,31,0,0,31,0,63,31,31,63,95,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,15,0,0,15,0,79,127,63,31,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,127,63,0,95,0,0,31,0,63,63,127,63,31,31,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,0,63,0,31,127,31,31,63,31,95,31,63,31,31,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,50,0,127,50,127,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,63,0,0,63,0,0,63,63,63,63,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,127,0,63,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,63,0,63,0,0,0,0,0,0,63,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,127,63,0,63,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,84,127,0,0,14,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,15,31,47,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,10,5,26,37,52,15,42,26,10,10,5,0,10,15,0,0,0,0,0,0,0,0,0,0,0,0,0,47,127,63\n0,0,0,0,0,0,0,0,0,0,18,108,72,127,54,54,54,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,90,18,0\n0,0,0,1,0,1,0,1,2,16,76,127,118,60,15,6,3,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,1,5,9,26,40\n0,0,0,0,0,0,0,0,0,0,0,0,18,0,36,0,36,0,54,0,0,0,0,0,0,0,0,0,0,0,0,0,18,72,54,127,72\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,47,127,95\n0,0,0,11,0,0,11,0,11,23,23,80,127,57,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,31,47,111,47,79,79,47,79,47,31,0,0,0,47,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,28,0,0,112,127,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,63,63,0,0,63,127,63,127,127,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127\n0,0,0,0,0,0,0,3,0,3,6,44,92,127,54,13,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,13,6,6,41\n127,95,31,31,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,42,42,127,105,21,21,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127\n0,0,0,0,0,31,0,31,31,31,31,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,36,0,36,127,127,54,90,72,36,18,36,0,0,0,0,0,0,0,0,0,0,0,0,18,54,108,18,0,0\n0,0,0,0,0,0,0,18,18,127,0,54,108,54,54,36,90,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,90,127,18,0\n0,0,0,0,0,42,0,0,21,0,63,127,63,105,63,42,21,21,0,21,0,0,21,0,63,21,21,0,0,0,0,0,0,21,127,42,0\n0,0,0,0,0,0,0,6,6,6,13,60,127,80,46,6,0,6,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,6,6,33,80\n0,0,31,31,0,0,63,31,31,127,127,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,31,31,0,47,15,63,79,95,95,127,0,0,0,0,47,47,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,14,56,28,70,70,127,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,14,28\n0,0,0,0,0,0,0,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,84,127,84,0,42,42,0,0,0,0,0\n0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,90,127,108,72,0,0,0,0,0,0,0,0\n52,61,48,55,58,71,74,127,65,74,26,6,9,3,0,0,0,0,0\n0,10,0,0,10,0,10,31,127,127,95,105,52,42,21,31,10,31,0\n0,0,0,0,0,0,6,3,0,20,13,23,33,43,36,76,56,70,127\n0,8,0,4,8,0,16,32,122,77,127,102,69,20,49,36,16,12,8\n0,0,0,0,0,0,0,0,14,28,70,0,0,28,14,112,42,14,14,28,0,127,0,14,14,0,42,28,42,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,2,12,39,53,106,127\n0,0,0,0,0,2,2,15,48,83,111,120,127,81,66,56,46,54,54\n0,0,0,0,0,0,0,0,3,23,67,127,75,115,87,63,91,87,79\n0,0,0,0,0,0,0,0,7,11,46,38,76,26,42,50,65,127,123\n127,38,76,88,63,12,25,88,63,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,127,79,15,47,63,79,111,111,15,95,0\n127,105,98,56,49,35,31,14,3,0,0,0,0,0,0,0,0,0,0\n127,96,54,24,15,10,9,8,10,15,18,22,19,17,16,16,15,14,18\n1,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,1,3,4,8,11,26,53,82,127,84,61,25,18,13,10,19,17,23,38\n0,0,0,101,101,127,0,0,0,50,0,0,0,0,76,25,0,0,0\n0,0,0,0,0,1,2,1,2,8,32,30,59,61,71,90,127,121,107\n127,118,55,50,97,67,46,46,71,101,50,33,25,4,12,0,0,0,0\n0,0,0,0,0,0,0,0,0,1,6,9,18,32,43,63,79,106,127\n127,63,87,23,31,15,0,0,0,0,0,7,7,0,0,0,0,0,0\n56,70,63,84,56,42,49,63,98,91,127,98,42,91,91,84,112,77,112\n0,0,0,0,0,0,0,0,0,0,18,0,18,0,0,0,0,18,54,127,18,0,54,18,36,18,54,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,5,5,20,0,30,96,66,127,101\n0,0,0,0,0,0,0,0,0,2,7,0,0,0,0,4,28,110,127\n127,47,10,10,0,0,0,0,0,0,0,0,0,5,5,0,0,0,0\n0,48,48,0,29,9,127,68,107,78,87,19,0,48,39,19,0,9,9,19,0,0,29,0,39,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,3,8,6,3,7,24,19,20,16,12,22,21,15,18,52,127\n84,93,127,42,0,8,50,8,33,33,67,42,8,25,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n58,19,30,30,22,24,32,29,53,55,87,102,100,127,109,79,89,74,87\n0,0,16,16,0,0,8,16,16,8,16,33,42,67,76,93,59,67,127,127,93,50,118,8,25,8,0,0,0,8,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,31,0,95,31,63,127,127,63\n9,6,6,4,0,0,0,4,4,25,18,13,25,43,76,127,122,96,23,6,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,7,1,9,7,7,10,12,43,127\n0,31,31,0,0,0,0,31,31,0,127,0,0,31,31,0,0,63,0\n9,15,16,32,41,66,101,123,127,102,95,74,54,35,34,22,25,22,24\n26,33,0,0,13,13,0,0,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,13,73,93,127,40,46,20,13,40,100,40,93\n0,0,0,0,9,9,19,48,48,48,97,78,78,127,78,48,9,9,58\n63,127,127,15,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,10,21,52,74,21,116,127,127,10,21\n0,0,0,0,0,0,0,0,0,0,5,0,13,29,13,15,42,84,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,5,14,9,7,11,55,25,18,35,58,74,53,48,62,80,127\n0,0,21,0,7,0,0,56,127,35,63,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,31,31,63,127,95,31,0,95,0,0,0,0,0,0,0,0,0\n34,69,127,115,34,11,0,11,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,0\n29,52,127,52,14,7,0,0,7,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,37,0,0,7\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,14,10,4,12,53,127,30,14,20,22,22,16,22,32,18,10,10,0,0,6,4,4,2,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,3,6,30,127,113,17,24,27,30,68,30,58,54,41,17,17,13,3,3,13,10,6,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n6,12,6,0,0,0,6,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,6,38,25,19,127,107,12,19\n4,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,28,32,127,47,0,0\n55,45,32,20,3,1,8,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,13,8,16,35,64,93,127,116\n69,41,36,14,4,8,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,6,13,37,47,112,127,84\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,0,0,0,0,0,0,0,0,0,0,84,84,127,127,0,0,0,42,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,0,0,25,0,0,0,0,0,50,0,25,0,127,50,25,0,0,25,25,25,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,14,127,98,0,0,0,28,70,112,28,98,127,84,112,28,0,14,0,14,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,9,9,36,45,0,0,0,18,45,45,63,27,127,81,63,18,36,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,84,84,42,42,42,42,42,127,42,84,84\n0,0,0,0,0,0,0,0,31,31,63,63,0,63,127,63,31,0,0\n127,90,81,108,63,63,63,45,18,36,36,27,63,18,45,54,90,72,90\n127,71,25,33,33,16,8,8,8,21,16,12,21,16,12,12,38,8,8\n0,0,25,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,76,25,0,25,0,0,0,127,0,50,0,0\n0,0,0,0,0,0,0,0,9,9,9,68,127,78,29,0,0,0,0\n127,17,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,63,0,63,31,0,31,31,127,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,15,0,0,0,15,15,47,63,31,47,63,79,127\n127,64,33,54,28,17,13,2,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,36,5,1,3,1,8,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n50,0,25,76,50,25,101,50,25,50,76,0,0,76,101,127,76,50,0\n101,127,50,25,25,0,76,76,50,25,0,76,0,50,0,76,0,25,50\n0,25,25,25,50,127,101,0,0,0,0,0,0,0,0,0,0,0,0\n127,72,54,36,40,13,4,4,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n72,108,36,90,127,36,36,90,36,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,18,18,18,0,0,0,0,0,0,0,0,0,36,18,0,18,0,18,0,0,18,0,0,72,127,18,0,0,0,0,18,0,0,18,0,36\n66,62,127,71,11,7,5,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,67,21,17,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,31,0,0,0,0,0,63,0,0,31,95,31,95,0,31,0,31,31,0,0,0,0,127,63,0,0,31,0,0,0,0,0,0,0,0\n84,84,127,0,0,42,42,0,0,0,0,0,0,0,0,42,0,42,0,0,0,0,0,0,0,42,127,0,0,0,0,42,0,0,0,0,0\n127,70,49,14,21,21,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,39,15,23,7,31,47,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,63,0,0,0,31,31,0,0,0,0,0,0,0,31,0,31,63\n127,37,5,21,21,10,15,10,0,0,0,5,0,0,0,0,0,0,0\n16,8,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,4,0,8,29,38,29,42,50,33,93,114,105,127\n127,100,86,23,3,5,3,1,1,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,4,1,3,28,68,73,127,98,82,37,19,2,1,1,1,1,0,0,0,1,2,1,4,10,3,11,32,52\n0,63,63,127,31,0,31,63,31,0,31,0,0,0,0,0,0,0,0\n127,88,38,88,38,25,12,12,0,0,0,0,0,0,0,0,0,12,0\n127,76,41,24,16,9,6,2,2,1,0,0,0,0,0,0,0,0,0\n23,0,0,0,0,23,0,11,11,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,11,0,23,127,115\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,7,31,47,95,127\n0,1,0,0,0,0,0,0,0,5,1,18,10,5,29,7,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,38,127\n0,0,0,0,11,46,23,34,46,46,34,127,103,69,23,115,115,92,115\n0,0,0,0,0,0,0,0,0,2,0,0,5,5,14,11,2,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,31,72,69,127\n0,63,105,105,63,127,42,105,21,21,21,0,0,42,21,0,0,0,0\n127,123,40,11,8,5,6,11,15,11,6,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,1,3,18,25,66,96,83\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,35,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,39,127,39,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,37,127,44,0,0,0,0,0,0,0,0,0,0\n14,0,7,0,7,0,7,0,14,0,49,77,127,63,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,7,21,7,7,0,0,14,0,0,0,0\n0,0,0,0,0,25,8,8,0,0,42,67,127,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,25,25,16,0,0,8,0,0,0,0,16\n0,8,8,8,0,0,0,8,0,16,59,127,110,25,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,8,25,8,0,0,0,0,0,0,0,0\n0,0,5,5,0,5,0,0,15,5,15,127,96,30,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,10,35,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,15,31,79,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,47,127,31,15,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,42,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,127,84,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,84,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,0,0,0,0,63,0,127,127,63,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,6,6,6,54,127,66,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,18,0,24,6,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,9,9,127,117,39,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,19,9,0,9,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,101,101,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,95,0,0,0,31,0,0,0,0,0,31,0,0,0,0,0,31,63,95,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,0,0,127,0,0,0,0,0,0,42,0,0,0,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,127,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,127,127,42,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,0,21,0,0,0,0,0,0,42,0,0,0,0,0,0,0,21,127,84,127,42,21,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,101,127,76,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,63,0,0,95,31,127,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,101,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,127,12,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,42,0,0,0,0,0,42,0,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,84,0,84,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,42,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,42,0,0,0,0,0,42,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,84,127,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,127,0,0,42,0,0,0,0,0,0,0,0,0\n21,0,21,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,0,0,0,84,84,127,0,42,0,21,21\n0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,127,63,0,63,0,63,0,0,63,127,0,0,0,0,0,63\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,84,84,42,127,127,42,42,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,42,28,0,70,42,127,42,14,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,69,34,127,0,0,34,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,127,76,0,12,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,76,127,0,50,50,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,76,0,25,25,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127,25,0,25,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,63,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,95,0,31,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,42,0,0,42,42,0,42,42,0,0,0,0,0,0,0,0,0,0,42,42,0,42,42,0,0,0,0,84,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,0,63,0,63,0,0,63,127,31,63,31,0,0,0,0,0,0,63,0,0,0,0,0,0,0,31,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,0,42,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,127,42,42,42,84,0,127,0,42,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,84,0,0,0,0,0,0,0,0,42,127,84,42,0,84,0,42,0,42,0,0,0,0,0,0,0,0,0,0,0\n11,15,11,0,3,0,3,3,0,3,0,3,11,7,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,7,35,43,127,55,59,59,55,43,19,27,11,27\n15,10,5,5,5,20,15,0,10,0,15,5,15,0,20,15,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,10,10,10,40,91,91,127,101,45,66,111,91,25,35,10\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,18,18,18,127,54,0,0,0,0,0\n0,12,0,12,0,0,12,50,101,50,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,25,114,127,76,38,76,38,0,0,0,0,0,0,0,0,0,0,0,0,0,12,12,50,50,63,50,50,12,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,9,9,18,99,90,45,36,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,72,72,108,27,63,18,9,0,0,0,0,0,0,0,0,0,0,0,0,9,18,9,54,127,63,63,9,0,9,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,6,20,40,93,60,60,80,80,127,60,73,26,20,0,6,0,0,0,0,0\n0,0,0,0,0,0,5,0,0,0,0,0,0,0,5,15,5,15,52,42,95,127,58,84,100,47,31,21,21,26,5,15,5,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,108,127,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,8,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,67,67,127,33,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,0,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,101,76,25,0,0,0,0,0,0,0\n0,42,0,42,127,0,84,84,0,42,42,42,42,0,0,0,42,84,0,127,42,0,0,0,0,0,0,42,0,42,127,0,42,42,84,0\n25,25,25,0,25,127,25,50,50,101,101,101,0,0,50,0,0,76,25,25,0,0,0,0,0,0,0,0,0,0,0,50,25,25,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,18,36,36,54,54,36,108,127,36,18,18,0,36,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,105,42,127,42,42,42,21,21,0,0,0,0,0,0,0,0,0,0\n77,16,44,16,0,5,0,0,5,5,0,0,0,16,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,33,71,93,55,127,49,49,33,71,27,27,38\n63,37,21,15,0,0,10,5,0,0,0,0,10,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,63,37,127,100,95,52,63,42,21,26,37,42\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,15,31,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127,101,25,0,25,25,25,50,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,14,56,0,127,0,28,28,42,28,56,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,18,0,90,72,18,18,72,127,36,0,0,0,0,0,0,18,18,0,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,42,42,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,0,127,127,0,42,84,42,0,0,42\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,42,84,42,0,84,0,0,0,84\n0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,127,31,0,0,31,127,127,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,127,0,31,0,0,0,31,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,84,42,42,42,84,0,0,42,127,42,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,31,31,31,0,31,31,127,127,63,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,21,0,0,0,0,0,21,0,0,21,0,21,0,0,21,21,0,127,105,42,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,31,0,0,31,63,31,127,95,63,31,0,0,0,0,0,0,0,0,0,0,0,0\n15,0,0,0,0,0,0,0,0,15,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,0,95,111,79,79,31,127,31,15\n42,0,0,21,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127,21,63,21,105,63,84,21\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,127,63,127,0,127,127,63,63,0,0\n42,0,0,0,0,0,0,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,42,42,42,0,42,0,0,84,84,0,42,42\n12,0,6,6,0,0,0,0,12,6,19,25,44,44,31,12,19,6,0,0,6,0,0,0,0,6,12,0,6,0,25,19,19,25,19,50,127\n127,84,31,21,31,52,10,0,21,0,0,0,0,0,0,0,0,21,10,0,10,10,0,31,31,42,31,31,31,10,21,0,0,10,0,0,42\n127,90,90,45,36,18,9,9,27,9,0,0,9,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,42,21,0,0,21,42,0,0,0,0,0,0,0,0,42,127,0,42,0,84,0,42,0,0,42,0,84,42,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,9,27,72,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,127,72\n0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,21,42,105,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,29,12,63,127,105,33,16,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,8,33,50,50,101,127,59,25,25,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,25,67,67\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,10,127\n0,0,0,0,0,0,0,0,0,0,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,6,0,26,26,106,127,73,33,40,40,46,13,20,53\n0,0,0,0,0,0,0,0,0,0,38,38,50,50,63,127,127,101,50\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,9,127,72,36,36\n0,0,0,0,0,0,127,7,0,0,14,82,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,43,127,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,31,127,127,31,0,31,31,0\n127,47,79,31,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,21,127,42,0,42,0,21,0,0,0,0,0,0,0,0,0,0,0\n0,31,0,0,0,0,31,63,127,95,31,0,0,0,0,0,31,0,0\n84,0,21,42,0,0,21,84,105,63,63,63,127,21,21,42,0,0,42\n0,0,0,0,0,0,0,9,39,39,127,87,78,48,48,29,19,39,19\n3,3,3,7,10,3,35,45,77,59,88,127,74,63,63,42,28,10,24,28,7,17,17,14,0,3,3,0,7,0,0,3,0,3,0,3\n0,7,0,2,9,9,9,34,43,70,58,127,70,39,58,56,46,17,19,14,4,4,9,4,4,4,2,2,4,0,0,0,0,0,0,0\n0,0,0,0,25,25,127,101,101,76,0,0,0,101,50,50,50,25,50,50,0,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,76,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,25,76,0,25,0,25,50,25,0,50,76,76,25,0,0,25,0,0,0,0,25,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,50,0,25,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,25,0,0,0,25,25,127,25,0,0,0,25,0,0,0,25,0,50,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,84,0,0,42,0,0,127,42,0,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,21,0,0,0,0,42,63,0,21,127,63,42,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0\n0,21,21,0,0,21,0,0,21,84,0,127,63,0,42,42,0,21,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,15,15,111,111,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15\n14,0,84,42,127,127,56,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n31,63,31,0,0,0,0,0,0,0,31,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,63,31,0,0,0,0,0,0,0,31,0\n0,0,0,0,0,0,0,0,0,0,0,55,127,42,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,33,63,16,21,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,33,29,29,33,21,42,4,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,25,50,101,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,101,50,25,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,76,76,76,50,127,0,0,0,0,0,0\n0,63,127,84,42,63,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,5,0,77,77,127,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,5,38,27,44\n0,0,0,0,0,0,0,0,0,0,0,0,76,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,50,50\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,127\n0,0,0,0,0,0,0,4,4,15,127,70,4,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,127,101,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,127,84,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,63,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,127,95,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,25,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,127,76,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,17,5,40,75,69,127,34,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,0,57,109,69\n0,0,0,0,0,0,0,0,0,64,127,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,5,33,66,121,127,60,5,5,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,84,56,14,0\n0,0,0,0,0,0,0,0,0,0,0,59,22,37,29,29,112,127,74\n0,0,0,0,0,0,21,0,0,0,0,0,105,63,127,63,105,127,0\n0,21,21,21,63,127,0,21,84,42,42,0,21,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,63,127,0,0,0,0,0,0,0,0,0,31,31,0,0,0,63,127,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,13,26,127,66,33,93,106\n0,0,0,0,0,0,0,0,0,0,0,0,1,14,44,70,101,122,127\n0,0,0,0,0,0,0,0,0,0,0,101,127,50,76,127,50,0,50\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,114,88,127\n0,0,0,0,0,0,0,0,0,31,0,15,47,0,0,31,63,31,127\n0,0,0,0,0,0,0,0,0,0,0,9,4,13,49,22,81,90,127\n0,0,0,0,0,0,0,0,0,0,0,1,1,1,3,7,36,90,127\n0,0,0,0,0,0,0,0,0,31,0,31,0,31,0,0,31,0,31,0,31,31,0,0,0,31,127,0,0,0,0,0,31,0,0,0,0\n0,0,0,0,0,0,0,0,11,0,23,23,23,23,69,103,127,115,115\n0,0,0,0,0,0,0,0,0,21,21,42,21,0,21,21,0,42,127\n95,127,79,79,47,31,63,15,15,15,15,15,0,0,0,0,0,15,31\n12,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,31,15,9,3,3,31,107,127\n0,0,0,0,0,0,0,0,0,0,17,30,118,109,127,74,52,35,30,4,4,0,0,0,0,0,0,0,0,0,0,17,30,30,70,61,122\n0,0,0,0,0,0,0,0,0,21,74,21,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127\n0,0,0,0,0,0,0,0,0,31,15,127,47,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,38,88,127,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,12,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,91,127,56,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,63,31,0,31,0,0,0,0,63,63,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,127,63,31,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,1,6,27,97,127,71,23,5,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,5,25,73,126\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,91,119,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,127\n0,0,4,1,0,0,0,4,2,3,56,127,22,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,9,22,76,82,69,31,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,9,47,127,127\n0,0,0,0,0,0,0,9,48,127,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n108,127,72,72,0,18,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,36,36,0,36,0,18,18,0,18,18,0\n127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,105,84,42,42,84,21,105,21,42,0\n127,68,68,31,13,13,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,97,74,59,11,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,3,0,18,11,7\n127,50,101,63,50,19,12,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,12,31,76\n127,79,47,0,15,47,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,15,31,0,31,0,0,31,31,47,31\n0,54,90,90,90,54,18,127,36,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,95,39,71,23,7,0,0,0,0,0,0,0,0,0,0,0,0,0\n104,44,59,67,59,82,127,97,119,67,22,7,7,0,0,0,7,0,0\n127,127,63,31,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,10,0,0,0,0,0,10,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,47,127,42,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,32,127,29,6,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19\n0,0,0,0,0,0,0,0,0,0,0,0,4,8,16,16,38,59,127,55,38,21,25,0,8,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,54,127,54,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,34,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,36\n127,29,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24\n0,0,0,0,0,0,0,8,8,59,25,16,127,118,101,59,25,8,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,63,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,19,63,127\n9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,18,9,22,49,127\n0,0,0,18,0,0,18,36,127,0,0,18,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,63,0,63,63,63,127,63\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,84,105,127\n127,49,5,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,25,0,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,63,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,42,21,0,0,0,42,0,84,0,0,0,0,21,105,0,0,0,0\n42,84,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,42,127,127,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n63,127,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21\n63,127,0,0,31,31,31,0,31,0,0,0,0,0,31,0,0,0,0,0,0,0,31,31,63,0,31,0,0,0,31,0,0,0,0,63,63\n0,0,0,0,63,0,0,0,0,0,0,0,42,42,21,0,21,0,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,17,17,0,127\n0,31,0,31,127,15,0,0,0,0,0,47,0,0,0,0,0,0,0\n42,42,84,21,0,0,0,0,0,0,0,21,0,42,21,127,21,21,0\n0,0,0,0,63,63,0,127,0,0,0,63,127,63,127,127,0,0,0\n0,0,0,0,0,0,0,0,0,95,31,63,63,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,63,63,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,42,21,105,52,95,127\n127,56,14,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,127,12,0,0,12,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,105,0,0,0,0,0,0,0,0\n0,84,42,42,105,21,84,63,42,42,42,42,42,42,0,42,42,63,21,127,63,84,63,127,105,127,42,21,63,42,63,63,42,21,42,0,0\n0,21,0,21,42,42,42,0,63,0,42,21,0,105,127,63,0,0,0\n127,127,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,63,0,0,63,0,0,0,0,0,0,0,0,0,0,0,63,127,63,0,0,0,0,127,127,0,63,0,0,63,0,0,0,0,0,0\n0,127,50,50,0,25,0,0,50,0,0,0,0,25,25,0,25,0,25,0,0,25,50,25,25,0,0,25,0,25,50,25,0,0,50,127\n0,0,0,0,0,0,0,0,0,25,0,0,25,0,25,50,25,127,101,50,25,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,12,0,12,38,0,127,76,101,50,12,38,12,25,12,0,0,12,0,0,76,76,63,76,25,12,38,0,12,12,0,0,12\n0,0,0,0,0,6,6,0,6,13,33,73,113,53,33,13,40,20,33,0,26,13,53,93,127,120,46,13,13,0,6,0,0,6,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,27,36,45,18,127,36,36,45,9,9,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,18,0,9,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,0,0,0,0,0,0,0,9\n57,80,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127\n127,36,36,36,0,0,18,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,54,0,18,0,36,0,36,54\n0,36,0,0,0,0,18,0,0,127,54,108,108,54,72,36,0,0,36\n0,0,0,0,0,0,0,0,0,0,0,0,0,63,21,63,42,63,127\n63,31,0,0,0,0,0,0,0,31,0,0,127,0,31,0,31,127,127\n0,0,0,0,0,0,0,0,0,1,0,4,3,3,13,56,78,127,64\n0,0,0,0,39,29,29,0,48,68,127,117,39,68,39,29,29,39,19\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,101,0,101,127,101,101,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,38,63,101,127,63,63,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,25,25,0,127,25,25,50,50,50,25,25,0,0,25,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,25,25,50,50,0,25,50,101,50,127,50,0,25,0,25,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,72,72,127,0\n127,39,23,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,55,103,55,15,23,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15\n97,37,22,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,22,7,14,44,127,29,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0\n127,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,101\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,36,127\n123,127,42,15,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0\n127,84,70,56,105,56,70,63,14,28,7,14,0,0,0,0,0,0,0,21,0,0,0,0,7,0,0,0,7,0,0,0,0,0,0,0,14\n127,77,21,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,63,9,18,9,0,9,18,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,97,50,29,4,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8\n50,127,12,25,0,0,12,50,0,12,12,12,0,0,12,0,0,0,0,0,0,12,0,0,0,12,38,25,38,38,114,12,25,38,0,50,25\n0,0,0,0,0,0,0,0,0,31,31,0,63,0,0,31,0,0,0,0,0,0,31,0,63,0,31,63,127,63,31,0,0,0,0,0,0\n63,127,87,31,23,0,0,0,7,0,0,0,0,0,0,0,0,0,0,7,0,0,7,0,0,0,7,0,0,0,0,0,0,0,23,23,31\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,63,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,127,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,63,63,127,63,63,0,0,63,63,63,127,63,0,0,63,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,63,0,0,0,0,63,0,0,0,0,63,63,0,0,0,0\n63,0,0,63,0,0,63,0,63,0,0,63,63,0,63,63,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,127,63,0,0,0,0,0,0,0,0,63,0,63,63,0,0,0,0,0,63,127,0,63,63,63,0,0,63,0,0\n0,0,0,0,0,0,42,42,127,0,14,14,0,0,0,14,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n72,127,54,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,41,11,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,114,101,127\n127,127,39,7,15,7,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,127,101\n0,95,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,31,31,0,0,0,0\n31,127,0,7,7,0,0,0,0,7,0,0,0,0,0,0,0,0,0\n84,127,84,42,42,0,42,0,42,0,0,42,0,42,42,0,0,0,0\n63,95,31,63,63,63,63,31,0,0,0,0,0,31,0,31,127,0,127\n84,0,0,84,42,42,127,42,84,42,42,0,0,0,0,0,0,0,0\n0,0,0,0,18,18,36,0,0,0,127,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,0,18,0,0,0,18,0,0,18,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,127,58,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,127,98,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n11,11,27,27,38,99,127,60,77,38,38,38,27,33,11,11,5,5,11\n0,0,76,0,0,76,0,0,0,25,127,76,76,50,50,50,25,0,25,0,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,65,17,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,12,0,12,12,12,0,0,0,0,0,0,0,0\n127,0,31,95,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,31,0,95,31,0,0,0,0,0,0,0,0,63,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,31,63,127,63,31,95,0\n127,56,56,49,49,7,7,21,0,14,0,0,0,0,0,0,0,0,0\n127,63,0,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,127,0,0,0,0,0,0,0,0,0,0,127,0,127\n127,96,52,37,24,9,9,3,0,0,0,0,0,0,0,0,0,0,0\n127,90,29,4,4,2,2,2,7,2,2,0,0,0,0,0,2,0,2,0,0,2,0,0,0,2,2,2,0,7,0,7,2,9,29,51,73\n0,127,95,31,0,0,0,63,0,0,0,31,0,0,0,0,0,31,0\n76,25,127,50,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,38,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,114,127\n127,0,0,0,0,127,0,0,0,0,0,0,0,0,63,0,127,0,63,0,127,0,0,63,127,0,63,0,63,0,0,0,0,0,0,63,0\n0,50,25,0,0,0,25,0,0,0,76,76,25,127,50,50,76,50,25,25,0,25,50,101,101,0,76,0,50,25,0,0,0,0,0,0\n0,50,0,0,0,25,0,25,50,25,25,50,50,76,101,0,76,0,0,50,25,76,127,50,50,50,50,25,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,42,84,0,84,42,127,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,114,25,38,25,38,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,0,25,50,76,76,127,76,50,76,0,0,0,0,0,25,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,25,50,101,50,127,25,25,25,0,0,0,25,25,0,0,0,0,0,0\n0,0,0,0,0,0,0,7,7,14,52,37,37,44,67,74,127,22,7,0,0,0,0,0,0,0,7,22,14,14,7,0,0,29,22,37,14\n0,0,0,0,0,0,42,84,0,127,42,84,0,42,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0\n0,0,0,0,0,0,5,0,0,0,0,0,15,5,42,37,84,127,116\n0,0,0,0,0,0,0,0,0,0,0,0,10,0,21,37,63,127,79,79,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,5,26,127,52,5,0,0,0,0\n0,2,4,17,9,14,27,7,22,37,54,62,27,72,127,62,34,12,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,76,127,25,101,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,50,25,127,76,25,50,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,50,76,50,25,25,127,76,0,0,50,0,25,0,0,0,0,0,0,0\n0,1,1,0,0,3,3,10,92,127,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,127,127,127,42,84,84,0,42,42,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127,105,42,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,84,127,0,42,42,0,84,0,0,0,0,84,0,0\n39,107,127,78,68,68,48,29,19,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,9,29,107,58\n63,0,31,0,31,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,127,95,0\n84,127,84,84,42,127,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,31,31,63,39,31,31,55,15,47,47,95,127,15,31,7,0,7,15,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,7,15,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,29,29,19,117,107,127,48,68,48,29,58,19,39,29,0,58,29,19,0,19,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,31,0,0,0,31,0,0,0,95,127,31,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,29,19,127,68,19,19,9,29,39,39,19,39,29,9,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,105,84,127,42,63,0,21,0,21,21,63,63,21,21,0,0,21,21,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,127,63,0,63,63,31,0,0,0,31,31,0,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,0,0,84,84,127,127,0,84,42,42,0,0,0,0,0,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,0,42,42,0,42,42,127,42,0,0,84,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n63,0,0,63,63,127,127,63,0,0,63,0,0,63,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,127,0,0\n31,31,0,63,31,127,0,0,31,31,63,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0\n84,0,0,42,84,84,127,42,84,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,9,32,84,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,63,90,54,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,33,127,118\n42,21,42,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,23,80,127,115,115,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,127,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,63,63\n0,0,31,0,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,127,31,127\n101,76,50,25,0,0,0,0,0,0,25,25,25,0,25,0,0,0,25,25,25,0,0,50,50,127,0,0,25,0,0,0,25,25,0,0,50\n16,8,25,0,0,76,33,16,42,42,25,50,127,110,50,59,8,33,16,25,16,16,16,16,33,8,16,16,16,8,8,33,33,59,0,67,118\n63,63,0,95,63,63,31,0,0,0,31,0,0,0,31,0,0,31,0,0,63,95,95,95,127,0,31,95,95,31,0,0,0,63,0,0,0\n0,18,18,72,54,18,0,0,54,36,0,0,127,0,18,18,18,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,5,5,11,23,5,40,127\n0,15,0,127,111,15,15,15,31,0,15,0,0,0,0,0,0,15,31\n0,0,0,0,0,0,0,0,14,14,28,42,28,56,84,98,84,127,84\n0,0,0,0,0,0,0,0,0,0,0,14,0,84,127,42,14,0,0,0,42,28,28,28,14,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,21,21,0,21,127,105,63,21,0,0,21,21,21,63,21,21,0,0,0,0,0,0,0,0,0,0,0\n80,66,120,127,40,73,40,0,20,13,0,0,0,0,0,0,0,0,0,0,6,6,0,0,0,0,0,0,6,6,26,20,13,0,33,93,26\n63,31,31,15,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,127,63,95,31,0,95,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,0,0,0,0,0,0,0,63,0,0,0,0\n105,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,10,10,31,63,127,95,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,31,10,105,127\n68,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,29,39,78,87,78,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,19,9,39,87,68,127\n0,0,0,0,0,0,0,0,0,31,95,0,95,31,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,127,63\n0,0,0,0,0,0,0,0,0,42,127,21,84,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,42\n31,63,21,31,42,21,42,0,10,10,31,21,10,42,52,63,42,10,31,10,0,10,21,31,31,74,63,63,31,63,42,127,74,74,31,63\n16,0,8,8,42,33,25,33,8,25,16,8,42,59,25,127,118,42,50,25,16,25,16,25,16,50,8,8,16,25,16,8,50,25,42,33\n0,0,0,0,0,0,0,0,18,36,36,127,0,0,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,36,36,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,21,63,127,21,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,63,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,18,0,18,0,54,54,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,0,54,127,36,0\n0,0,0,0,0,0,0,0,0,0,0,84,84,84,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,84\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,105,127\n0,0,127,63,63,0,63,0,0,63,63,63,63,63,0,63,63,0,0,0,0,127,127,0,0,63,0,0,0,0,63,63,127,0,63,0\n0,0,0,0,0,0,0,0,31,31,0,31,31,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,63,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,31,63,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,42,0,84,42,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,84,0,0,127,42,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,36,127,108,0,36,54,54,36,72,36\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,63,127,0\n39,0,9,9,9,29,39,68,87,117,127,78,39,0,0,9,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,127,15,47,31,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,101,127,50,101\n0,0,0,21,21,42,0,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,127,63,0,0,127,63,63,63,0,63,63,63,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,15,15,95,127,63\n0,0,0,0,63,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,95,127,63\n0,0,0,0,0,0,0,0,0,0,21,21,42,105,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,127\n0,0,0,0,0,0,0,0,0,25,0,127,76,0,25,101,25,0,0\n0,0,0,0,0,0,0,0,0,0,0,38,88,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,127\n0,0,0,0,0,127,127,127,0,63,0,0,0,63,0,0,0,0,0,0,0,0,0,63,63,0,0,0,0,63,0,0,63,0,0,0\n0,0,0,0,0,0,0,0,0,42,105,127,105,42,21,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,63,42\n127,127,127,0,63,0,0,0,0,63,0,0,63,0,0,0,0,0,63,0,0,0,127,63,127,0,0,0,63,0,63,63,0,63,0,63,0\n84,42,127,84,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,42,84,84\n0,0,0,0,0,0,0,0,0,0,28,56,127,84,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,56,0\n79,60,33,14,9,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,7,16,22,59,84,127\n29,4,14,29,0,0,4,14,9,9,19,9,9,14,9,14,24,19,14,43,9,9,0,4,19,14,4,29,0,53,14,14,48,14,92,53,127\n66,57,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,12,30,69,127\n63,63,6,12,0,12,6,6,6,12,12,6,25,0,0,0,12,0,0,0,6,6,0,19,0,0,12,12,6,6,31,12,12,31,38,114,127\n127,69,28,11,5,11,0,0,11,5,5,0,5,0,0,0,5,11,5,23,5,0,5,5,0,0,0,0,0,0,0,0,0,0,5,0,0\n25,25,9,12,3,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,3,3,31,25,47,127\n127,84,84,42,0,0,0,0,0,0,0,0,0,21,84,42,63,42,42,84,42,0,21,42,21,0,21,0,0,0,0,0,0,0,21,0,0\n0,63,31,31,0,0,15,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,15,0,0,0,0,0,15,63,15,31,47,127,79,111,127\n127,72,16,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,13,24,26\n127,69,20,4,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,2,2,7,12,23,32\n127,100,40,20,6,6,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,6,0,0,0,0,6,6\n112,127,56,70,42,42,28,28,28,28,56,28,0,0,0,0,28,28,0,0,0,14,0,0,0,0,28,14,14,42,14,0,28,56,56,84,28\n127,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,68,45,18,4,22,18,13,4,0,0,0,4,0,0,0,0,0,0,0,0,4,0,0,0,4,4,0,0,4,13,4,18,4,27,54,36\n0,3,7,3,3,3,15,3,23,3,15,59,19,63,39,43,39,59,39,31,27,0,3,3,0,0,3,7,7,7,3,3,7,19,11,47,127\n127,35,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,42,21,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n97,94,72,127,61,76,58,83,65,47,43,18,7,14,10,3,21,29,7,14,14,21,3,3,3,7,10,25,43,21,14,10,3,10,10,14,10,7,25,32,21,7,32,50,21,25,14,10,3,0,3,0,10,0,0,0,0,0,0,0,0,0,0,3,3,7,10,10,36,25,54,39\n95,82,104,120,99,110,127,95,62,62,35,14,13,6,8,5,12,4,8,10,5,12,10,13,6,10,13,20,41,29,20,18,6,16,13,20,20,20,28,24,22,32,60,20,32,33,17,2,2,5,4,2,9,1,1,1,0,1,1,0,1,0,1,4,5,6,9,10,29,41,48,72\n0,72,18,54,90,90,72,127,108,0,18,0,18,18,0,18,0,0,0,0,0,0,0,0,0,18,18,0,0,0,0,0,0,0,0,0,0,18,18,18,18,18,0,18,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,18\n0,14,56,14,28,127,14,56,70,28,42,0,0,0,0,0,28,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,42,0,42,127,84,84,0,42\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,95,31,95,31,63,0,31,31,31,0,0,0,0,31,63,127,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,127,84,84,0,0,127,0,42,0,42,42,42,42,0,127,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,63,21,127,63,42,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,21,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,0,0,21\n15,15,79,0,127,47,31,15,0,0,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,15,15,15\n42,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,39,127,68,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,63,127,38,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,9,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,127,127,81,127\n127,59,11,7,3,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,84,84,84,127,127,84\n127,69,34,11,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,95,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,31,31,31,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,31,0,0,63,0,127,31,0,0,0,0,0,0,63,31,127,95,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,21,31,10,127,95,63,95,31,31,31,0,21,21,0,74,21,10,42,21,84,95,84\n52,18,22,0,11,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,3,3,11,44,127,119\n0,42,0,0,0,0,0,42,0,42,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,84,0,42,84,42,127,0\n127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,36,18,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,18,0,36,54,127,108\n127,14,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,28,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n6,38,25,6,38,19,38,19,6,19,0,0,12,12,0,0,0,0,12,6,12,6,0,6,6,25,6,0,0,0,0,6,12,12,38,63,101,127,82,69,6,50,38,25,19,19,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n18,0,0,27,36,36,18,36,45,9,9,9,9,9,9,27,0,0,9,27,0,0,0,0,0,18,9,0,0,0,0,0,0,9,36,63,127,81,117,99,27,27,54,72,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n42,0,0,21,127,127,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,42,0,42,0,21\n0,42,0,127,84,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,42,0,0,42,0,0,0,0,0,0,0,0,0,42,42,0,0,0,0,0,42,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,31,0,0,31,31,127,0,0,0,63,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,63,31,0,95,63,0,0,0,0,31,0,0,0,0,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,31,95,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,50,0,25,0,50,0,25,0,0,25,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,25,101,50,76,127,25,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,63,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,9,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,39,127,58,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,127,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,42,42,42,0,0,0,0,127,42,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,72,127,108\n0,127,76,50,50,50,25,0,0,0,0,0,0,0,0,0,0,0,0\n127,113,65,35,10,9,4,3,1,1,1,1,1,0,0,0,0,1,0\n0,127,84,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,127,84\n93,105,63,42,38,21,16,8,0,4,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,21,8,25,21,21,63,127,110\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,19,14,58,29,63,127\n73,61,36,38,28,14,4,0,2,0,0,0,2,0,2,0,0,2,2,0,0,2,0,4,6,2,0,0,8,8,22,40,65,49,69,118,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,127,63,47\n127,47,63,111,95,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,79,127,111,0\n84,63,127,0,0,0,21,0,0,0,0,42,0,0,0,21,0,0,0\n108,127,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n74,68,37,10,5,0,0,5,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,5,31,68,127\n127,49,69,34,20,17,5,5,8,0,5,0,0,0,0,0,0,0,0\n0,127,63,0,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,12,12,76,25\n63,95,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,95,0\n6,48,60,48,54,78,127,36,84,6,6,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,6,0,24,18,30,18,24,18,54,18,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,18,12\n77,49,60,115,127,57,49,46,15,2,2,2,2,0,0,0,2,0,0,0,0,0,0,2,0,0,4,0,0,0,0,4,2,0,4,11,17,22,37,62,80,37,53,40,28,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,2,0,17,4,6,77,37\n127,99,52,24,9,3,1,0,0,0,0,0,0,0,0,0,0,0,0\n127,80,41,25,21,22,24,30,23,19,13,8,7,4,4,2,2,1,2,1,1,2,4,7,8,15,18,25,28,31,31,22,23,22,23,25,33\n90,53,22,14,5,31,8,25,36,36,36,62,67,59,62,56,70,127,107\n30,20,5,10,5,7,2,2,2,2,0,0,0,5,2,0,2,5,0,2,12,2,0,0,0,5,7,5,2,0,0,2,2,7,15,50,127\n42,21,21,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,42,127\n53,60,23,16,3,20,6,10,3,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,13,6,3,36,50,76,127\n127,39,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,71,95\n80,11,5,11,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,11,11,0,23,11,34,23,0,127\n127,95,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,63,0,31,63,63,127\n50,50,25,57,12,6,6,6,12,25,12,19,12,12,0,19,19,0,31,0,6,0,6,6,25,12,6,19,12,6,31,6,44,57,50,82,127\n127,127,63,48,48,41,44,33,26,18,3,7,14,11,0,7,3,11,0,11,7,3,11,11,18,22,18,56,56,52,26,59,37,56,56,70,112\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,0,25,127,101,101,76,25,50,0,50,0,25,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,0,0,50,0,76,25,127,101,101,25,25,50,25,50,50\n0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,0,42,84,42,127,42,127,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,84,84,84,84,42,0,84,0,84,42\n127,101,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,12,76\n0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,21,10,0,127\n127,76,50,12,63,50,0,25,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,0,12,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,101\n101,127,127,88,63,84,50,8,29,8,8,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,8,4,4,50,0,0,0,4,4,8,0,0,4,0,4,12,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,16,8,33,97,93,110\n0,25,50,50,50,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25\n108,54,54,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,9,36,54,108,127,72\n63,127,42,10,21,0,0,0,0,10,0,0,21,0,0,21,10,0,0,10,10,0,0,0,0,0,52,0,10,0,10,10,0,0,10,10,0\n0,47,31,15,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,127,0\n58,127,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,48,97\n127,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0\n101,127,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,50,0\n0,127,0,0,0,0,0,0,36,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,18,0,0,0,0,18,0,0\n31,31,63,95,31,63,31,63,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,31,63,0,0,0,31,0,63,31,63,95,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,63,0,0,0\n74,52,65,56,52,96,48,127,26,30,21,17,4,4,4,0,4,0,0,0,0,13,0,0,0,0,0,17,0,4,4,4,0,13,8,13,26,35,35,21,43,21,52,56,21,8,8,8,0,4,0,0,4,0,0,0,0,0,0,0,0,0,0,4,17,13,13,4,13,8,8,21\n95,127,47,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,36,0,0,0,0,18,0,0,108,36,54,72,72,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,36,90,108,127,54,18,18,36,0,18,0\n25,12,12,25,0,12,0,0,0,38,12,76,25,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,12,0,12,76,127,12,25,25,25,38,12,0\n0,0,0,0,0,0,42,0,42,0,0,0,42,127,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,0,0,0,0,0,0,42,0,0,0,0,0\n0,42,0,0,42,0,42,0,127,0,84,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,42,0,0,0,0,0,0,0\n0,6,0,0,0,0,0,6,0,0,0,19,25,19,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,82,127\n0,0,0,0,0,0,0,0,0,0,18,18,0,36,72,0,36,127,18,18,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,25,127,50,101,127,76,50,0,25,0,0,0,0,0,0,0,25,0,0,25,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,42,127,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,63,0,127,95,127,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,108,127,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,41,127,76,37,9,4,8,11,5,1,2,1,0,0,0,0,2,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,25,0,25,50,25,127,50,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,111,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,47,15,47,15,0\n127,63,9,9,18,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,127,56\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,76,76,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,4,0,14,37,56,47,75,127,98,98,28,56,37,47,37,9,28,18,42,37,37,9,18,42,14,65,98,122\n84,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,84,127,84,127,127,0,0,0,0,0,0,0,0,0,0,0\n42,42,84,105,21,127,0,42,42,21,0,0,21,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,14,42,127,56,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,16,67,50,127,67,25,50,33,25,25,16,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,14,98,70,127,70,42,70,14,42,42,42,28,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,7,39,79,127,63,47,7,15,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,1,0,4,7,30,89,127,99,72,50,25,15,10,11,3,4,1,2,0,0,0,0,0,0,0,1,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,8,50,25,12,127,88,46,38,38,8,8,8,4,0,0,0,4,0,0,0,4,0,0,0,0,0\n0,0,0,0,0,0,0,0,23,39,127,79,19,0,7,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,5,38,69,127,96,96,33,20,4,4,2,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,42,31,10,52,63,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,10,84,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,15,47,15,0,0,0,0,0,0,0,0,0,0,0,31,0,15,63,31,95,127\n0,0,0,0,0,0,0,0,27,0,27,127,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,25,25,101,25,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,127,101\n0,0,0,0,0,0,0,0,0,0,0,0,50,25,50,76,25,127,101,0,25,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127,42,21,63,42,63,0,0,63,0,0,0,42,21,84,63,63,21,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,54,36,127,36,54,0,0,0,0,0,0,0,0,18,0,0,18,0,54,0,54,0,0,0,0,0,0,0,0,0,0,0,0\n63,37,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,31,127\n0,0,0,0,0,0,0,0,0,0,0,0,14,84,127,14,28,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,3,6,34,83,127,105,114,6,30,0,0,0,0,0,0,0,6,0,3,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,8,2,0,37,57,89,127\n127,88,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,15,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,31,31,31,127,0,79,63,15,63,63,31\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,31,31,31,31,63,0,63,31,31,0,0,0,31,31,127,0\n127,118,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n3,1,5,0,1,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,15,33,71,127\n127,77,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n58,127,19,9,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,13,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,14,14,14,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,28,0,28,14,28,56,127,84,42,28,56,28\n0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,12,0,50,38,76,127,12,12,12,12,12,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,25,25,0,76,127,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,42,84,127,42,84,21,63,42,42\n127,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,72,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,31,2,4,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,58,127\n0,0,0,28,14,0,14,28,14,28,0,14,0,14,14,14,14,14,14,0,14,28,28,14,28,28,14,14,56,14,0,0,42,56,127,28,84\n0,42,127,84,42,42,0,21,0,0,0,0,21,42,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,21,0,0\n127,56,18,3,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,50,21,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,46,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0\n29,48,9,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,4,14,48,127\n72,127,72,18,0,0,0,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,32,15,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,74,52,31,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n72,127,99,27,27,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,9,36\n0,28,14,127,70,56,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,42,14,42,14,28,98,112\n31,79,31,127,63,47,79,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,50,25,50,127,0,101,25,25,0,0,0,0,0,0,0,0,0,0,0,0,50,0,25,0,0,0,0,0,0,0,0,0,0,0\n127,47,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,28,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,31,31,63,31,127,31,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,0,0,31,0,31,0,0,0,0,0,63,31,0,0,0,0,63,0,31,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n25,50,101,50,76,127,76,0,101,25,0,50,0,25,0,0,0,0,25,25,101,25,25,76,25,25,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n21,63,127,84,84,84,84,63,84,0,21,0,0,0,0,0,0,0,0,42,21,21,42,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21\n127,63,31,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,15,0,31,0,0,0,0,15,15,127\n112,127,42,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,28\n127,15,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31\n127,74,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,21,21\n127,63,36,9,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,9,0,27,36,54\n127,31,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,31,0,0,0,0,0,0,0,0,31,0\n0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,42,0,42,42,42,42,42,0,0,0,0,0,0,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,50,101,25,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,10,21,10,42,21,31,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,21,52,42,105,95,63,42,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,42,84,127,31,10,10,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,31,0,15,31,15,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,47,47,127,79,95,63,15,0,0,0,0,0,0,0,0,0,0,0,15,0,0,47,47,63,111,79,63,47,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,127,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,15,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,7,0,0,14,28,70,14,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,42,35,127,127,35,14,0,7,0,0,0,0,0,0\n8,0,0,0,0,0,0,8,0,42,8,16,8,25,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,33,8,16,16,25,101,127,50,8,0,8,0,8,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,21,42,21,63,21,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,21,63,84,127,84,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,12,12,25,25,50,63,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,12,12,88,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,63,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,63,63,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,63,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,127,0,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,42,42,84,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,84,42,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,84,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,14,14,0,98,98,112,127,56,42,28,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,56,14,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,14,14,84,56,42,70,0,14,0,0,0,0,0,0\n0,0,0,0,0,0,7,0,7,22,14,29,104,127,104,0,7,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,22,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,7,22,37,14,37,37,0,22,14,7,0,7,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,29,0,48,127,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,63,42,21,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,5,11,11,11,5,0,0,5,0,0,0,0,0,0,0,0,0,0,0,5,0,11,49,127,88,71,33,16,5,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,13,3,10,3,10,13,0,3,0,0,0,0,0,0,0,0,3,6,6,0,36,33,90,127,110,86,56,10,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,12,12,0,25,25,127,88,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,76,38,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,18,0,18,72,127,90,72,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,54,18,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,31,0,63,63,127,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,63,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,31,127,127,47,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,25,25,0,25,25,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,76,127,50,25,25,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,11,34,23,34,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,34,57,57,23,127,23,11,23,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,31,63,31,127,79,31,47,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,31,47,0,15,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,36,36,90,90,127,72,72,18,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,54,72,72,36,108,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,25,0,25,0,127,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,50,0,0,0,0,0,0,0,0\n0,0,0,0,31,0,0,31,0,0,63,31,31,0,63,0,63,0,31,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,0,95,31,63,63,0,63,31,31,0,31,31,0,0,31,31,0,0,0,31,0,31,63,95,63,127,63,95,0,0,0,0,0,0,0,0,0\n0,42,0,0,0,0,0,0,0,0,0,42,42,127,42,42,0,42,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,84,84,0,84,0,0,0,84,42,42,0,0,0,0,0,0,0,0,0,0,42,42,0,84,42,0,0,42,0,42,0,0,0,0,0,0,0,0\n127,90,42,16,5,1,1,0,0,0,0,0,0,0,0,0,0,0,0\n9,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,9,4,13,4,9,27,72,127,108,99\n127,90,25,11,6,0,1,1,0,0,0,0,0,0,0,0,0,0,0\n127,86,69,71,8,4,2,4,0,0,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,79,57,31,3,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,8,27,70,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,101,127,50,101\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,6,18,53,92,127\n127,75,25,16,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,1,3,5,9,16,38,39\n127,57,23,5,5,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,11,11,5,0,5,23,23,34\n127,66,9,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,58,2,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,5,4,19,63,115,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,11,27,81,92,127\n63,63,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,127,95,63\n78,127,87,87,39,68,0,68,78,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n40,127,106,13,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,123,66,19,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,4,29,127\n127,84,54,26,9,9,8,9,7,2,1,1,1,0,0,2,1,1,3\n0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,0,0,0,0,0,0,8,8,8,16,93,33,33,33,76,84,127,101\n101,127,118,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,5,17,59,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,31,74,84,63,10,21,127\n127,77,41,16,5,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,1,5,3,6,5,7,3,9,5,6\n127,95,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,20,62,127\n42,21,42,127,127,0,21,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,11,103,127\n76,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,76,76,127\n95,127,31,0,31,31,15,0,15,15,0,31,0,0,0,0,0,0,0\n72,18,0,0,54,127,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,11,29,67,127\n0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,127,95,0,95,95,63,63\n0,23,39,31,79,127,47,47,55,0,7,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,3,0,0,19,127\n72,127,127,54,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0\n63,95,127,63,31,0,0,0,0,0,15,0,0,0,15,31,15,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,5,51,127\n0,21,31,127,95,21,105,10,31,31,31,31,42,31,21,31,10,52,21,21,10,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n16,20,69,127,57,86,61,28,40,65,45,57,90,57,28,32,20,20,8,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,63,31,31,31,63,0,0,63,31,0,0,0,0,0,31,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,63,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n15,79,95,47,47,15,0,47,79,63,31,63,127,111,111,47,47,47,31,47,15,15,15,15,15,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,0,31,79,31,31,0,0,31,0,15,0,0,0,15,0,0,0,0,0,0,0,0,0,15,15\n0,0,0,0,0,0,0,0,63,63,127,63,0,63,127,63,0,127,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0\n0,0,0,0,0,25,0,0,0,25,25,76,76,127,25,0,0,76,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,63,31,63,127,0,127,0,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,127,0,42,84,127,0,0,0,0,42,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n15,47,47,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,31,15\n0,63,127,95,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,31,127,0\n0,0,0,0,0,0,0,0,0,0,0,42,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,84,127,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,31,95,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,25,12,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,34,127,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,57,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,57,127,23,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,11,46,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,127,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,95,0,95,63,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,21,127,84,21,42,0,0,0,0,0,0,0,0,0\n77,77,78,92,106,127,124,85,51,37,25,16,14,6,5,4,4,3,6\n127,98,40,26,17,15,18,24,27,21,26,25,26,24,25,10,18,18,13,13,16,19,26,39,50,49,45,44,33,25,12,18,13,15,18,30,36\n8,2,6,2,4,2,4,6,31,33,52,41,24,35,45,89,95,127,104\n127,47,11,4,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,8,24,49,32,51,84,127\n127,67,28,3,3,0,7,3,5,1,5,3,3,0,1,7,3,7,9,1,1,5,11,7,5,5,7,11,0,1,3,0,0,3,1,1,22\n127,77,22,6,2,2,1,0,4,10,4,0,2,4,1,0,0,0,0,2,4,2,2,4,9,16,13,14,22,10,13,9,5,1,2,1,0\n127,99,30,0,3,0,0,3,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,87,34,19,7,2,9,7,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,3,8,46,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,18,127,108\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,38,127\n127,84,21,0,0,0,0,0,0,0,0,0,21,0,21,42,0,0,21,105,21,21,0,42,21,0,0,0,0,0,0,0,0,0,0,0,0\n0,127,21,42,0,21,21,0,0,0,0,0,0,21,0,0,21,0,0,0,0,0,42,0,0,63,0,42,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,3,0,0,5,5,3,5,29,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,10,2,0,0,0,0,0,2,2,38,127\n0,31,15,0,15,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,47,0,15,127\n127,95,95,63,63,0,15,0,0,0,15,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31\n56,28,42,42,14,28,28,0,28,0,14,0,14,0,14,28,0,0,14,14,0,0,0,0,42,14,42,42,14,28,14,0,14,28,70,127,56\n127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,9,52,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,4,1,2,0,0,0,2,53,127\n0,0,0,3,2,2,1,0,0,0,1,0,1,3,0,1,0,3,0,1,0,1,4,4,4,15,32,58,51,67,71,85,84,105,121,118,127\n0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,25,0,12,12,0,0,25,0,12,38,0,12,12,76,76,50,50,50,101,88,127\n127,114,0,88,25,12,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,112,56,28,0,0,14,28,0,14,28,42,14,42,28,56,127,70,14,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,25,0,0,0,0,0,0,0,25,0,0,0,0,0,0,25,0,0,0,0,0,0,25,0,0,0,0,50,0,0,0,25,25,76,127,25,50,76,0,25,127,101,50,127,25,25,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,50,0,101,25,127,101,101,50,127,76,0,101,76,25,25,0,0,0\n0,31,63,0,0,31,63,31,31,0,31,0,31,0,0,0,31,95,127,63,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,0\n31,0,31,0,31,0,95,31,0,0,0,0,31,0,0,63,31,127,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,22,0,0,0,22,22,52,127,59,44,22,52,22,14,14,44,59,67,44,29,22,67,14,7,7,0,7,89,82,22,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,16,16,0,16,0,42,33,59,110,127,93,8,16,33,8,33,25,50,110,67,25,25,59,59,16,8,8,8,59,67,59,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,84,127,42,0,127,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,6,6,0,0,0,0,0,0,0,0,0,0,0,6,6,0,0,0,0,0,0,0,0,0,0,6,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,6,19,0,0,6,12,25,12,50,38,69,63,127,57,31,6,31,44,6\n0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,11,0,0,0,0,11,11,23,34,92,127,57,46,92,69,69,11,23,11\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,42,0,0,0,0,0,0,84,84,84,42,42,127,42,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,0,0,84,42,0,0,0,42,127,42,84,0,0,0,0,84,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,80,78,22,26,7,4,1,0,0,0,0,0,0,0,0,0,0,0\n127,53,26,9,5,3,3,5,3,0,3,0,0,0,0,1,0,0,0,0,0,0,0,3,3,0,1,1,17,7,0,1,1,0,0,3,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,25,127,101\n127,117,49,19,4,3,2,0,0,0,0,0,0,0,0,0,0,0,0\n127,72,42,12,12,6,0,0,0,3,0,3,0,0,0,0,0,0,3,0,0,0,0,3,6,3,9,0,6,15,0,9,6,15,3,21,6\n101,25,101,25,0,0,0,0,0,0,25,127,76,101,25,50,101,25,50\n127,71,47,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,49,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,0,105,42\n0,0,0,0,0,63,127,127,0,0,0,127,0,0,127,63,0,63,0,0,127,0,0,63,0,0,0,0,0,0,0,0,63,0,63,127,127\n0,0,31,0,31,63,0,63,127,31,0,31,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,31,0,63,0,0\n76,76,25,25,25,50,25,0,50,25,0,25,0,0,0,0,25,25,25,0,0,101,76,25,50,127,50,76,25,0,25,0,0,25,25,50\n0,63,42,0,84,63,63,0,0,21,0,42,63,0,21,21,21,0,21,21,21,21,84,42,127,105,21,0,0,0,0,105,84,21,0,21\n0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,127,0,0,127,127,0,0,0,0,0,127,127,127,0,0,0,0,0,0,127,0,127,127\n0,0,0,0,42,0,0,0,0,127,0,42,0,127,84,127,127,84,0,0,42,42,0,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n25,0,0,0,0,0,0,0,0,25,25,0,50,127,127,50,76,0,25,25,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n63,63,31,0,31,31,0,127,31,0,0,31,31,31,31,0,0,0,0\n127,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n31,0,52,0,21,0,0,0,10,0,10,0,10,0,0,0,0,0,0,0,0,0,10,10,0,10,21,42,10,52,42,84,127,74,52,31\n50,50,38,0,50,25,0,0,12,0,0,0,12,0,0,0,0,0,0,0,12,0,0,0,0,0,0,50,0,50,50,63,101,114,127,101\n21,0,42,21,63,21,127,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,42,127,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,69,57,127,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,127,10,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,127,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,15,0,31,47,127\n84,0,42,0,0,0,0,0,0,0,84,127,84,127,84,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,0,0\n0,0,0,0,0,84,0,0,0,42,127,127,84,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,16,16,76,76,127,76,16,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,8,25,16\n0,0,0,0,0,0,0,0,0,0,0,0,63,127,31,15,15,0,0,0,0,0,0,0,0,0,15,15,31,31,0,0,15,0,31,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,42,127,42,10,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,10,10,10,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,0,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,101,127,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,18,72,54,72,36,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,72,127,54,36,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,28,28,70,70,14,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,14,28,127,0,14,0,0,14,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,5,33,30,55,66,53,43,10,25,5,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,5,12,30,127\n0,0,0,0,0,0,0,0,25,25,50,50,127,25,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,63,63,0,0,0,63,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,63,0,0,127,127,63,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,18,36,127,36,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,9,36,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,18,27,127,45,9,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,9,9,27,27,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,10,10,0,10,0,0,31,127,127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0\n0,0,0,0,0,31,0,63,31,63,0,63,0,127,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,21,0,0,0,0,0,63,0,0,0,0,105,21,105,127,42,63,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,84,84,0,42,0,0,0,0,0,0,0,0,0,0,0,84,42,0,0,84,127,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,76,76,127,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,28,127,56,14,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,28,28,127,14,98,28,28,14,14,14,14,14,28,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,72,72,72,36,36,72,18,18,0,54,18,36,36,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,63,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n36,127,72,0,0,0,18,18,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,18,36,54,54,127,36,18,0,0,18,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,31,31,0,127,127,63,95,0,95,0\n0,0,0,0,0,0,0,0,0,0,84,63,84,21,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,0\n0,0,0,0,0,0,0,0,0,0,0,0,127,95,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,31,111,127,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,12,12,127,50,38,12,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,84,127,84,42,84,42,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,84,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,127,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,84,127,33,84,25,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,15,0,15,47,0,15,47,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,95,127,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,9,48,127,78,117,9,48,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,6,0,0,0,24,72,54,66,72,127,127,90,12,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,95,63,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,79\n90,36,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,54,54,18,54,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127\n127,31,42,10,21,10,10,0,0,0,0,0,0,0,0,0,0,0,0\n31,0,31,31,63,0,31,63,0,31,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,15,79,127,127\n0,0,0,0,0,0,0,31,0,0,31,127,63,31,0,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,21,84,105,127,116,105,42,0,10,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,21,63,63\n0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,0,42,127,63,42,127,105,21,0\n0,63,127,105,0,0,0,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,112\n127,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,42,105,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,63,63,0,63,95,0,127,31,95,63,31,95,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n42,63,127,105,42,21,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,21,0,0,0,127\n0,0,0,0,15,15,0,47,95,127,31,47,15,63,15,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0\n0,0,0,0,15,15,15,0,0,0,31,95,127,31,31,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n74,37,37,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,52,44,67,127,112,74,37,22,0\n127,95,38,12,12,25,6,0,6,19,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n36,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,72,36,18,54,127,0,0,0,0,0\n127,50,25,12,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,63,63,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n50,76,127,127,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,63,105,127,84,0,0,21,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,21,0,0,42,21,0,42,63,127,63,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,25,50,50,25,0,0,25,0,50,0,127,0,0,0,50,0,25,0,0,0,0,0,0,0,0,0\n127,49,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,91,68,60,10,10,0,5,0,2,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,15,30,25\n42,105,0,42,0,21,0,21,21,42,21,42,0,0,21,42,0,0,0,0,0,0,0,21,0,0,0,42,21,0,21,42,127,84,42,84,127\n127,55,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0\n42,0,63,0,0,0,42,42,0,21,21,0,0,0,0,0,0,0,21,21,0,42,0,21,0,0,0,0,21,127,42,84,127,0,0,21,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,127,127,50,25,25,76,0\n0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,33,127,33\n63,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,31,31\n0,0,0,42,0,0,0,0,0,0,42,0,42,42,0,0,0,0,84,84,84,42,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,45,9,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,127,84,42,0,42,84,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,81,54,45,127\n0,0,0,0,31,95,0,0,0,0,63,0,127,31,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,127\n0,0,0,0,0,0,0,0,25,25,0,50,127,76,76,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,127,47,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,31,31,31,31,0,63,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,42,42,42,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,127,42,0,0,0,0,0,0,0,0,0\n0,0,42,0,0,0,0,42,127,84,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n31,23,7,0,15,7,0,23,71,127,87,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,84,42,0,0,127,42,42,84,0,84,0,0,42,0,0,0,0,0,0,0,0,0,0,0,42,0,42,0,0,0\n0,0,0,0,28,14,14,127,84,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,61,49,34,15,18,18,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n42,42,52,105,127,52,95,63,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,10,0,0,5,0,0,0,0,0,0,0,0,0,0,5,5,5,5,0,5,0,21,10,0,0,0,0,0,0,0,0,21,31,89,74,127\n0,12,101,76,50,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,101,127,101,38,0\n127,69,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,11,34\n127,0,42,42,0,84,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42\n0,0,0,0,0,0,0,0,0,0,18,54,90,127,72,72,36,0,0,18,18,0,18,0,0,0,0,0,0,0,0,0,0,36,0,36,0\n0,0,0,0,0,0,0,0,39,127,68,78,78,58,19,39,87,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,63,63,127,63,63,63,63,63,127,0,0,63,0,0,0,0,0,0,0,0,0,0,0,63,127,63,63,0\n0,0,0,0,0,0,0,6,20,127,120,100,46,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,14,0,0,70,127,42,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,21,42,127,63,21,105,21,0,21,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0\n0,0,0,0,0,0,9,9,68,97,9,127,97,0,0,0,29,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,63,0,0,63,0,63,127,0,0,127,127,0,63,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,25,0,0,0,101,0,25,0,0,0,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,25,25,25,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,76,50,101,127,0,25,0,0,0,0,0\n0,0,0,0,0,0,0,0,25,50,25,0,25,50,76,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,0,0,25,0,0,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,50,76,50,127,0,0,25,0,25,25,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,127,95,0,31,31,31,31,0,31,0,0,0,0,0,0,0,31,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,21,63,0,0,21,21,21,0,0,0,0,0,0,0,0,0,21,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,21,10,0,0,21,21,21,10,0,21,10,31,10,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,10,21,95,63,63,127,84,21,0,10,10,0,0,0,21\n0,0,0,23,23,0,11,0,23,46,11,23,46,23,0,11,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,11,34,34,46,115,127,0,11,23,11,0,0,0,11\n14,21,28,21,7,28,21,35,0,35,28,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,7,21,35,42,127\n0,0,0,0,0,0,0,31,0,15,0,15,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,127\n0,0,0,0,0,0,0,0,0,31,63,31,63,127,127,63,63,31,0,0,0,0,0,31,0,0,31,0,0,0,0,0,0,0,0,31,0\n0,0,0,0,0,0,0,0,0,0,0,0,21,68,127,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,15,21,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,18,0,0,0,0,0,0,0,0,18,36,127,36,54,0,0,0,0,0,0,18,0\n56,127,56,84,14,28,56,0,42,42,84,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,127,127,0,0,127,63,0,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,127,127,0,63,127,127,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,0,0,0,0,0,0,0\n0,0,0,0,0,63,31,0,0,63,0,31,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,63,0,0,0,63,63,31,0,0,63,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,31,31,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,31,63,15,127,31,31,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0\n0,13,0,3,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,6,3,6,26,6,10,30,30,120,127\n0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,38,0,25,127\n0,0,42,0,21,63,0,42,21,63,0,0,21,0,0,63,0,84,21,84,63,21,0,21,21,42,21,21,21,0,0,0,21,42,63,21,127\n0,6,0,6,0,0,6,0,6,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,12,44,31,127,101\n0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,8,15,66,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,10,0,0,0,21,21,0,10,21,74,74,127\n0,0,0,0,0,0,0,0,0,0,0,0,42,42,127,0,0,0,42,0,42,0,0,42,42,84,42,42,84,84,0,0,42,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,0,0,0,4,29,63,127\n0,0,0,21,21,42,127,84,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,18,18,0,54,127,36,72,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,74,52,24,49,21,7,10,0,3,0,0,0,0,0,0,0,0,0\n12,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,18,24,57,78,127\n0,0,3,3,3,0,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,10,3,26,30,33,46,36,36,23,56,66,127\n28,49,21,14,0,0,14,0,0,7,0,0,0,7,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,14,7,21,21,14,21,56,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,0,0,21,0,63,42,42,127\n0,0,0,0,0,0,95,31,127,0,0,0,0,0,0,0,0,31,0,31,31,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,117,111,72,45,66,33,54,45,30,21,12,21,6,6,3,3,3,0\n127,41,19,9,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0\n72,54,127,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n98,127,42,7,0,0,0,0,14,0,0,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,10,10,0,63,127,42\n127,81,38,0,0,0,0,3,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,63,0,0,12,0,127\n84,127,14,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,127,63,63,63\n127,76,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n72,72,90,81,127,90,99,36,27,0,9,0,18,0,0,0,0,0,0\n127,73,18,14,6,1,2,0,0,0,2,0,0,1,0,0,0,0,0\n56,127,47,9,9,14,14,14,4,0,0,0,4,0,4,0,0,9,0\n127,105,84,31,0,31,10,74,42,42,21,0,0,0,0,10,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,63,63,0,0,127,0,0,0,0,0,63,0,63,0,0,127,127,0,0,63,0,63,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,29,67,74,29,59,127,119,37,14,14,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,66,66,20,53,127,113,13,26,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,21,21,21,127,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,127,0,0,0,21,42,21,42,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,50,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,25,50,0,0,101,101,25,50,25,0,25,25,25,0,0,0,25,0,0,0,25,0,0\n0,0,0,0,0,0,0,0,0,42,0,0,0,0,84,42,42,0,84,42,0,0,127,42,0,42,0,84,0,84,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,42,84,0,84,84,42,42,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,127,84,0,0,42,84,84,42,42,0,0,0,42,0,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,42,84,84,0,42,84,42,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,42,0,0,0,0,0,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,0,0,0,84,84,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,0,0,0,63,0,63,0,63,0,63,127,63,0,63,0,0,0,0,0,0,0\n95,127,119,55,103,31,7,0,0,0,0,0,0,0,0,0,0,0,0\n127,74,31,21,10,10,21,31,63,52,31,52,31,63,21,10,31,10,0\n127,74,0,10,10,21,0,0,0,0,0,0,0,0,0,0,0,0,0\n111,79,119,71,127,71,55,55,71,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,19,44,127,107,88,6,6,0,0,0,0,0,0,0,0\n40,127,80,13,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n84,84,105,127,21,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,72\n0,0,0,0,0,0,0,42,0,127,84,0,0,84,84,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,42,42,42,84\n127,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,39\n50,0,0,0,12,12,12,12,38,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,25,0,0,0,0,127\n27,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,45,54,127\n127,101,114,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,12,0\n0,0,0,0,0,0,0,0,0,31,127,15,0,0,15,95,0,47,0,0,0,31,31,0,0,0,15,0,0,0,15,0,0,0,0,0,63\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,21,105,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,12,12,114,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,127\n127,47,15,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,15,0,15,111,63\n127,63,26,10,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,4,13,15,43,91\n63,127,15,47,15,47,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,31,0,31,31,63,0\n46,80,46,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,11,127,92\n127,79,63,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,15,0,31,63\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,63,15,15,63,127\n70,21,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,7,0,0,0,7,7,7,14,14,14,7,56,127,112\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,10,21,15,31,42,95,127\n0,0,0,0,0,0,0,14,56,84,42,127,14,84,112,98,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,28,28,0\n0,0,0,0,0,0,0,0,0,31,0,63,63,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,127,63,63\n0,0,0,0,11,0,0,0,69,69,127,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,31,0,31,95,63,31,63,127,63,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,3,12,3,15,19,28,25,34,9,19,15,6,3,0,0,3,0,0,0,0,0,0,0,0,0,0,6,12,22,25,50,76,127\n0,0,0,0,0,9,36,27,72,117,117,127,45,36,54,9,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,72,18,0,0\n0,23,0,0,0,0,0,34,11,46,127,0,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,31,0,0,31,0,0,0,127,0,95,95,31,95,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,95,31,0,127,0\n127,103,60,30,14,6,2,1,0,0,0,0,0,0,0,0,0,0,0\n127,112,99,69,60,56,58,30,18,14,5,2,2,2,4,2,3,2,1,1,1,7,4,8,9,24,4,0,0,1,1,0,1,2,4,8,15\n127,103,67,21,11,11,13,17,3,33,59,115,73,59,27,31,19,13,31\n127,91,60,51,55,56,55,52,40,27,11,8,3,2,1,0,1,1,0\n73,63,30,24,33,34,55,91,127,81,48,45,16,7,3,2,1,1,0,0,2,0,0,0,11,7,3,3,1,0,0,0,0,0,0,6,60\n0,5,5,0,0,0,11,11,17,23,34,63,103,127,86,34,51,5,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,6,30,30,6,9,17,17,26,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,5,2,4,7,8,17,127\n127,39,66,102,17,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,23,19,25,11,1,1,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n11,0,0,0,2,0,0,8,2,13,8,11,30,0,2,0,0,0,0,0,0,0,0,0,0,0,0,5,0,2,0,2,8,24,27,104,127\n15,7,2,2,0,0,0,0,5,7,21,15,0,2,0,5,0,0,0,0,2,0,2,0,0,0,0,0,0,0,2,0,0,0,13,31,127\n0,0,0,0,12,12,12,19,25,6,12,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,6,0,0,31,19,31,107,127\n3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,8,18,83,127\n0,5,5,0,0,0,0,0,0,5,11,23,17,17,5,5,0,5,0,0,0,0,0,0,5,0,23,11,0,11,11,5,0,17,28,46,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,63,21,84,105,84,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,38,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,18,9,0,9,45,54,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,3,4,3,25,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,29,58,9,97,48,127,97\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,41,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,15,15,0,0,0,15,31,47,47,31,63,127\n127,46,33,29,12,21,12,25,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,21,7,3,3,3,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,92,25,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,12,16,3,0,0,0,2,2,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,15,31,47,0,15,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,19,13,21,7,4,3,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,31,21,10,0,0,21,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,6,6,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,6,6,0,60,33,93,33,127,80\n0,21,21,0,0,21,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127,42\n0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,21,0,0,0,0,0,21,21,0,0,21,21,0,84,42,21,0,105,63,42,127,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,18,27,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,12,88,127\n127,28,7,0,35,0,14,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,23,3,0,7,3,11,7,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,116,127\n39,9,9,29,9,14,4,0,0,0,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,39,92,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,101,127,50\n42,127,63,0,0,0,0,21,0,21,0,21,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,21,21,0,21,42,105,105,42\n127,127,47,31,23,7,23,7,15,31,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n23,0,0,0,0,0,0,11,11,11,11,11,46,57,0,0,0,0,0,0,0,0,0,23,11,11,23,127,57,34,23,23,0,0,0,0,0\n1,2,3,2,3,4,8,12,29,51,98,127,88,40,11,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,9,18,28\n0,0,0,0,0,0,0,15,63,79,127,127,79,63,15,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0\n23,19,19,34,23,46,46,50,50,127,80,123,80,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n63,31,15,63,71,111,79,127,79,23,47,63,7,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,9,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,21,127,84,21,0,42,0,42,127\n2,5,0,0,0,2,9,17,16,64,124,127,113,83,17,4,1,4,2,0,1,0,0,0,0,0,0,0,0,0,0,0,3,3,9,21,13\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,127,23,0\n0,0,0,0,0,0,0,0,3,24,80,127,54,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,0,3,42,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,18,0,0,45,127\n0,0,0,0,0,0,0,11,11,34,46,69,34,34,0,0,0,0,0,0,0,0,0,0,0,80,127,0,0,0,0,0,0,0,23,34,23\n0,0,0,0,0,0,0,0,7,4,14,12,59,72,102,127,39,29,19,27,22,4,2,2,0,2,2,7,7,12,14,22,39,37,32,12,17,2,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,2,4,0,0,7,7,2,0,4,0,0,0,0\n0,0,0,0,0,0,0,0,9,13,13,26,107,87,91,127,74,45,26,16,29,0,0,3,13,13,22,3,9,6,22,3,3,13,13,6,3,3,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,6,6,0,3,0,6,9,6,9,0,3,0,3,0,0,0,0\n0,0,0,0,0,0,0,0,0,63,63,47,31,63,15,15,47,0,47,127,79,15,47,0,0,0,0,0,0,15,0,15,0,0,0,31,31,31,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,0,0\n0,0,0,0,0,0,0,0,0,0,0,15,0,79,0,0,0,0,15,127,0,31,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,0,3,2,2,5,11,127,18,17,3,1,0,1,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,0,0,1,2,8,14,127,18,8,4,1,0,1,1,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,3,24,127,120,20,44,13,3,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127,101,101,101,50,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,18,18,127,18,90,0,36,0,0,0,0,18,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,28,56,28,0,14,127,127,14,14,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,13,57,117,127,39,21,20,8,2,2,2,0,0,3,4,1,1,1,2,1,2,6,9,9,23,32,15,6,1,0,1,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,2,5,5,50,127,116,36,27,24,9,5,1,2,2,4,8,3,3,1,1,1,3,1,3,7,30,111,83,23,16,7,2,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,0,31,127,15,15,47,0,0,0,15,0,0,0,0,0,15,0,0,47,63,31,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,84,0,0,84,0,84,84,0,42,0,0,0,0,0,0,0,0,0,0,0,84,0,42,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,29,47,127,39,13,1,7,1,3,5,1,9,25,15,7,0,1,1,1,7,3,17,1,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,15,43,127,102,24,9,0,21,3,3,6,6,21,24,21,18,0,0,3,3,0,6,6,3,3,9,0,0,0,0,0,0,0,0,0,0,0,0,0\n1,0,0,0,0,0,1,3,7,12,36,127,31,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,16,13,7,3,2,1,0,0,0,0,0\n0,0,0,0,0,0,1,1,10,14,37,127,31,11,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,14,10,5,3,1,0,0,0,0,0,0\n31,31,0,0,0,63,0,0,0,31,0,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,127,95,63,0,0,0,0,0\n0,0,0,0,31,0,0,31,31,0,63,95,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,63,0,31,127,0,0,0,0,0,0\n2,2,3,0,0,1,0,3,12,21,70,127,42,16,4,2,4,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,6,9,10,6,0,0,0,2,1,1\n0,2,8,5,2,2,8,17,20,56,76,127,79,26,5,2,0,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,20,35,0,0,11,2,2,2,5,2\n0,0,0,0,0,1,0,1,7,32,127,115,30,7,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,4,1,1,1,0,0,0,0,0,1\n0,0,1,0,1,3,2,7,10,19,54,127,58,14,2,0,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,5,11,4,3,2,2,0,0,0,1,0\n0,0,0,0,0,63,0,0,0,127,31,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,0,0,0,0\n0,0,0,0,0,0,0,0,0,21,63,127,84,84,42,21,84,21,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,15,31,127,31,15,15,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0\n4,8,1,0,4,11,12,17,25,20,31,103,127,118,19,9,2,1,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,10,4,10,4,2,0,0,0,0,0\n2,3,3,1,2,2,5,5,18,35,35,66,127,108,26,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,6,14,17,2,0,0,2,0,0\n127,21,42,42,42,42,0,0,0,0,42,63,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21\n23,23,11,0,0,0,0,11,0,0,57,127,80,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,11,11,0,0,11,23,0\n0,0,0,0,0,0,0,0,0,21,21,21,21,42,127,63,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,72,127,72,54,90,72,0,0,0,0,0,0,0,0,0,0,0,0,36,0,0,0,0,0,54,72,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,36,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,127,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,105,105,42,21,21,0,0,0,0,0,0,0,0,0,0,0,21,42,21,42,84,63,21,63,63,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,9,0,14,83,127,83,9,0,0,0,4,0,0,0,0,0,0,0,0,0,4,14,24,39,4,19,29,4,0,0,0,0,4,0,0,0,0,0\n0,0,10,5,5,5,15,5,55,127,127,66,15,10,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,20,0,0,0,15,40,25,20,25,0,0,5,0,0,0\n0,7,0,0,7,0,21,0,56,119,127,56,14,28,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,14,0,0,7,7,0,42,63,21,0,0,0,0,0,7\n0,0,0,0,25,50,76,76,50,127,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,25,0,0,0,0\n0,0,0,0,0,0,0,0,18,127,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,0,0,0,0,0,0\n0,0,0,0,0,0,31,0,15,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0\n0,0,2,0,0,0,0,0,0,4,14,42,72,89,92,82,14,9,2,2,2,2,0,0,0,0,0,0,2,4,4,19,24,74,87,127,42,32,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,4,14,4,7,14,4,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,15,31,89,87,76,42,15,5,2,5,7,0,2,0,0,0,0,0,0,5,7,31,50,79,113,127,68,39,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,15,10,5,13,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,25,0,50,25,0,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,50,50,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,26,43,127,52,0,4,2,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,59,64,127,57,0,0,2,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,111,127,31,0,0,0,0,0,0,15,0,15,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,15,0,31,63,63,95,95,127,47,31,15,0,0,0,0,0,0,0,0,0,0,0,47,79,111,111,127,63,15,31,31,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,19,9,19,9,117,87,68,68,39,9,9,9,0,9,0,0,0,9,0,0,0,0,0,0,39,39,127,87,19,9,39,9,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,63,127,95,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,1,0,1,1,4,17,42,127,32,8,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,4,7,6,4,2,0,0,0,0,0,0\n0,1,1,0,1,0,1,2,9,18,41,127,44,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,8,12,2,2,3,0,0,0,1,0,0\n0,0,0,0,0,10,0,0,84,63,31,95,127,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,10,0,0,0,10,0,10,0\n0,0,0,0,0,7,0,37,29,97,52,127,74,22,7,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,29,7,14,7,0,0,0,22,0\n0,0,0,0,0,0,0,0,0,0,0,31,95,63,127,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,127,63,63,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,25,50,101,127,50,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,50,101,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,50,50,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,25,0,76,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,7,0,7,22,37,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,74,127,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,63,84,127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,105,63,42,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,9,58,127,107,58,39,9,0,9,0,0,0,0,0,0,0,0,0,48,0,29,0,9,9,9,9,29,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,27,45,108,127,81,36,27,0,9,0,0,0,0,0,0,0,9,0,0,0,18,0,18,0,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,72,127,99,117,108,54,63,18,9,0,0,0,9,18,0,9,0,0,0,0,9,9,18,63,27,18,0,18,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,6,0,6,40,60,100,127,66,60,46,13,6,0,0,6,13,20,6,0,0,0,0,0,0,13,0,40,20,26,40,33,33,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,12,12,12,127,63,0,0,0,0,0,0,0,0,12,25,12,12,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,23,0,11,127,57,11,0,0,0,0,0,0,0,11,23,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,18,27,45,99,45,45,27,9,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,36,127,27,18,0,9,0,0,0,0,0\n0,0,0,0,0,0,0,19,9,127,117,48,9,9,9,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,39,58,48,9,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,63,127,63,95,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0\n0,0,0,0,0,21,0,21,127,105,127,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n105,56,49,21,7,10,5,10,3,3,7,8,15,12,10,35,26,49,37,79,75,127,104,79,63,42,24,35,12,0,1,0,0,0,0,0,0\n0,0,7,0,7,0,0,0,0,0,0,15,0,7,7,7,47,71,71,127,87,15,55,15,0,0,7,0,0,0,0,0,0,0,0,0,0\n127,63,31,95,0,31,0,0,0,0,0,0,31,31,0,31,0,0,95,0,31,63,0,31,0,0,31,0,0,0,0,0,0,0,0,0,0\n8,0,0,0,1,0,0,0,0,4,7,10,1,8,13,33,45,65,127,86,102,100,55,55,40,20,13,8,7,0,5,0,0,1,2,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,12,12,127,63,38,50,12,0,12,0,0,12,12,0,0,0,0,0,0,0\n0,0,0,0,0,0,12,0,0,0,0,50,25,25,63,63,63,101,127,38,63,0,12,0,38,12,0,0,0,0,0,0,0,0,0,0,0\n33,47,58,127,58,24,15,8,5,8,4,0,3,5,3,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n4,20,11,52,127,68,9,4,2,0,0,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,21,0,127,105,21,0,0,21,0,42,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n58,57,82,127,75,36,32,28,8,19,10,3,7,12,7,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n9,29,68,53,127,43,24,58,39,19,9,0,29,34,9,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n61,65,127,105,65,39,21,61,8,4,8,30,17,0,21,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,7,9,9,11,17,43,65,127,85,68,21,5,14,3,7,5,3,8,9\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,11,16,5,5,22,38,16,127,60,44,27,27,0,16,11,16,11,22,11\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,2,1,0,1,9,31,83,127,52,12,5,2,0,0,1,0,0,2\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,95,127,63,63,0,0,0,95,0,0,31,63,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,7,15,9,18,17,67,127,103,79,51,70,54,47,63,47,39,26,15\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,6,0,33,46,33,26,40,60,127,127,40,0,6,6,13\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,29,22,29,29,89,89,74,127,112,89,52,29,67,44,22,7,22,44,89\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,31,95,127,0,31,0,31,31,0,31,0,0,0,0\n127,81,54,45,18,9,27,0,0,0,0,0,18,18,18,18,18,36,127,81,90,72,90,108,81,27,9,9,0,27,9,0,0,0,0,0,0\n0,0,0,7,0,0,0,7,0,7,7,7,0,7,0,7,44,44,89,127,119,89,67,59,44,22,7,0,7,7,7,0,0,0,0,0,0\n127,101,76,25,0,0,0,12,12,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,36,36,9,9,9,9,0,0,0,0,0,0,0,0,9,0,18,18,18,54,36,45,0,27,0,0,0,0,9,9,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,3,3,0,3,6,9,31,53,85,107,50,85,127,50,31,12,3,3,3,0,0,0,0,0,0,0\n48,39,83,92,122,127,53,4,9,19,0,4,9,4,24,9,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,127,127,31,127,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,42,127,105,77,21,49,21,28,7,35,7,0,56,28,14,7,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,31,31,31,95,127,63,95,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,63,0,0,63,127,127,21,42,127,42,63,63,84,21,21,84,127\n0,0,0,0,0,25,0,0,0,0,0,0,0,25,0,0,50,127,25,76,0,0,0,50,0,0,25,0,0,0,0,0,0,0,0,0,0\n127,46,17,0,11,5,0,5,0,0,5,0,11,5,5,0,0,5,11,34,34,28,40,11,5,17,5,5,0,0,0,0,0,0,0,5,23\n87,61,46,17,21,7,29,4,9,7,0,4,9,7,9,17,48,31,53,70,80,127,119,87,39,2,0,4,0,0,0,0,0,0,2,0,0\n0,0,0,0,0,63,0,0,31,0,0,0,0,0,127,127,63,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,38,22,9,6,12,22,41,28,31,12,3,12,6,12,6,3,3,0,22,41,127,88\n0,0,2,0,1,1,2,1,0,0,2,2,4,15,27,72,117,127,122,109,108,74,39,20,10,0,0,0,0,0,1,0,0,0,0,0,0\n25,0,50,76,127,38,38,38,12,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,74,127,10,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n4,24,78,127,85,43,28,10,6,10,8,6,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,56,70,127,56,28,28,0,14,0,0,14,28,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,6,6,0,6,38,127,95,25,19,25,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,12,50,50,127,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,14,0,14,28,77,84,127,56,42,0\n127,31,47,31,15,15,31,0,0,15,15,15,0,31,47,0,0,0,0,15,15,31,15,15,31,0,0,15,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,29,9,19,68,97,29,127,48,39,29,39,39,58,117,117,78,97,19,0,0,39,0,0,0,0,0,9,0\n127,89,67,46,15,12,8,3,4,1,0,0,0,0,0,0,0,1,2,2,5,6,8,6,8,8,5,4,2,2,4,0,1,1,1,1,1\n42,127,21,63,21,0,0,0,0,0,84,0,0,0,0,0,0,0,84,0,0,0,21,21,0,21,0,0,0,0,0,0,0,0,0,0,0\n127,100,82,89,48,37,48,33,29,11,7,0,3,3,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,11,0,22\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,2,7,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,6,3,13,127\n127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,63,63,127,0,127,0,63,0,0,0,0,0,0,0\n95,15,127,47,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n15,15,15,15,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,5,5,31,74,105,116,127,58,68,26,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,5,5,0,0\n7,0,0,7,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,22,14,52,74,127,97,74,59,37,52,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,14,22,0,0,14,14\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,21,21,105,127,42,84,21,63,21,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,0,127,31,0,95,0,0,0,31,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,127,127,9,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,8,0,110,127,16,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,33,127,8,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,57,127,0,0,0,0,0,0,0,0,0,0\n35,23,67,127,27,75,39,19,7,31,23,23,7,7,35,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,3,3,11,11,7,35,35,15,27,111,59,35\n26,15,29,108,127,47,26,13,0,7,7,0,7,10,21,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,5,0,5,5,7,13,18,5,29,39,29,37\n76,25,76,25,76,0,25,0,25,0,0,25,76,127,25,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,76,25,25,25,0,25,25,50,25\n101,25,0,101,76,0,50,0,0,0,25,0,25,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,25,25,50,0,0,0,0,25\n0,0,0,0,31,127,0,0,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,95,31,0,31,0\n0,0,25,127,0,50,0,25,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,50,0,0,0,25,25\n5,21,74,84,127,52,5,26,0,15,10,10,5,5,15,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,5,37,52,63,15\n14,52,44,127,89,67,82,22,14,37,44,7,14,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,7,14,22,89,97,22,37\n95,0,31,127,31,95,0,0,0,0,0,0,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,0,0,0,0\n42,0,84,84,0,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,0,42,84\n0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,23,80,127,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,10,10,31,31,10,52,127,84,63,74,74,31,21,0,31,42,63,31,0,0,0,10,21,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,21,0,0,42,127,42,63,21,21,63,21,21,84,63,127,63,63,21,21,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,42,63,63,42,21,21,0,21,127,42,63,42,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,28,14,84,14,14,0,56,84,127,98,0,0,0,14,0,14,14,14,28,28,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,19,19,107,127,58,97,68,48,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,9,19\n50,0,0,0,12,0,0,0,0,0,0,0,0,0,12,0,0,0,0,12,0,88,63,114,88,127,88,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,12,0,0,12,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,12,25,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,127,127,31,31,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,50,0,101,50,127,76,25,50,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,81,0,5,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,127,54,0,4,0,0,0,0,0,0,0,0\n38,25,63,50,88,25,12,12,25,0,38,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,25,127,63,50,63,63\n12,25,88,127,114,63,38,12,12,0,25,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,12,88,50,114,12,63,63,38\n7,0,87,127,87,47,39,23,7,0,31,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,55,23,39,23,63,7\n25,25,63,76,63,12,127,12,0,38,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,63,50,76,76,38,12\n0,14,14,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,14,0,42,42,127,98,127,98,70,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0\n0,14,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,14,98,70,98,84,127,70,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,42,0,42,42,42,0,0,0,0,0,0,0,42,127,0,42,127,127,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,31,0,63,0,0,31,0,31,63,0,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n14,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,42,28,14,56,0,42\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,63,47,0,15,15,47\n22,19,10,9,6,10,9,10,12,17,21,27,39,52,72,83,109,125,127\n0,0,0,0,1,1,1,0,1,2,1,3,7,14,15,41,75,100,127\n81,28,19,10,7,5,7,4,5,6,14,10,13,26,25,38,48,60,98,127,118,69,47,24,13,7,3,2,1,1,0,0,0,0,0,1,0\n108,18,0,9,0,0,0,0,0,0,0,0,0,9,27,72,108,127,63,36,18,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n3,0,0,0,0,0,0,0,0,0,0,0,1,4,7,19,37,71,127\n0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,19,6,44,127\n20,39,82,127,68,54,82,66,24,11,3,1,5,15,11,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,19,58,127,127,68,19,39,9,0,9,0,0,0,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,16,39,18,13,10,20,28,45,73,81,78,127,118,90,58,47\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,24,69,32,32,12,32,32,81,94,127,98,90,61,24,32,24\n23,62,42,59,51,65,47,57,108,72,69,67,67,97,82,112,127,115,98\n6,4,4,4,5,3,2,4,3,7,14,23,18,16,21,28,52,94,127,77,47,50,33,21,14,10,9,4,5,2,0,0,0,0,0,0,0\n0,0,0,0,0,0,1,0,3,2,17,61,91,109,25,22,39,127,103\n127,14,10,14,0,0,0,17,31,123,21,7,21,17,35,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,71,88,29,4,42,16,12,46,46,21,16,16,25,50,127\n127,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,24,127\n21,10,0,10,0,0,0,127,105,105,74,21,21,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21\n0,0,0,0,0,0,0,0,0,0,0,23,0,46,46,80,127,46,34,34,46,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,46,46,46,57,103,80,46,46,11,11,0,0,0,0,0,0,0,0,0,0\n127,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,45,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0\n0,0,0,0,0,0,0,0,12,0,12,12,25,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,95,0,0,0,95,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0\n0,0,63,127,127,63,0,0,127,0,0,0,63,0,0,127,0,63,0\n127,68,63,52,52,21,15,15,26,37,5,10,0,5,10,26,0,10,10\n127,83,105,109,76,10,2,4,2,4,0,0,6,2,4,2,10,6,8,4,21,8,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,9,9,0,19,9,48,19,117,127,68,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,98,127,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,21,0,127,42,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,127,90,36,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,31,31,0,0,31,31,127,31,31,31,127,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,9,0,0,9,0,19,19,127,19,78\n71,71,44,40,10,27,35,40,82,82,120,112,127,103,88,86,71,46,38,31,44,21,21,12,4,2,4,4,6,0,0,0,2,0,0,0,0\n90,54,18,9,9,0,0,0,0,0,0,27,18,18,9,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,54,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,11,39,21,35,75,49,54,39,72,94,101,105,75,127\n0,31,0,0,31,31,0,63,0,63,95,31,95,95,0,0,0,127,31,31,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,7,22,14,0,0,0,22,104\n0,42,28,0,0,28,42,28,14,14,14,14,56,56,84,127,28,70,56,14,14,14,0,28,0,28,0,0,14,42,0,0,0,0,0,0,84\n101,127,50,0,25,0,25,0,0,12,12,12,0,0,0,12,0,0,0,25,12,25,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,31,31,31,0,0,0,0,95,63,127,63,63,63,0,31,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,14,0,14,0,0,0,0,14,0,0,0,14,28,127,14,0,42,14,0,0,0,0,0,0,14,14,28,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,0,50,50,0,101,0,25,127,25,50\n0,0,0,0,0,0,0,0,0,0,0,7,71,127,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,15,7,7,0,0,7,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,18,72,127,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,18,9,0,0,9,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,8,25,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,9,0,18,127,36,9,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n63,127,31,31,0,0,0,0,0,0,0,0,0,0,0,0,63,0,127,31,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,0,63,0,127,63,0,0,0,0,0,0,0,0,31,31,31,31,0\n127,63,81,90,36,36,27,36,9,9,9,0,0,0,0,0,9,0,36,18,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,15,15,0,47,15,63,127\n0,0,0,0,0,31,31,31,63,127,95,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,25,0,12,0,0,0,0,0,12,76,38,88,127\n0,0,0,0,0,0,0,0,0,0,0,0,31,15,15,0,63,63,127\n0,7,5,4,4,5,8,10,14,15,35,28,62,73,105,122,127,112,121\n4,9,9,11,9,2,11,16,19,23,14,19,19,21,59,31,67,71,64,76,127,112,62,14,28,11,11,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,4,2,9,20,49,92,127\n0,0,0,0,0,0,0,0,5,5,0,0,11,11,22,127,66,115,66\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,90,108,127,54,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,127,84,28,56,28,0,0,56,28,14,0,0,14,0,0,0\n0,0,0,0,63,127,21,21,84,42,42,63,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n36,127,0,18,54,18,18,0,0,0,0,0,0,0,0,0,0,0,0,18,54,54,18,54,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,12,88,101,127,63,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,25\n0,0,31,31,95,0,63,63,127,95,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,15,0,0,0,0,0,0,0,15,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,127,0,15,15,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,31,0,31,0,95,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,63,0,0,0,0,0,0,0,0,31,0,31\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,27,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,127\n127,62,25,4,3,4,2,3,2,2,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,2,0,4,5,4\n127,45,11,3,1,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,7\n127,72,25,4,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0\n127,39,31,0,7,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,38,50,127,88,76,12,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,21,127,21,0,21,0,0,21,0,0,0,0,21,0,0,0,0,0,0,21,63,127,127,105,105,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,84,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,63,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,31,31,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,25,0,0,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,76,127,76,0,76,0,25,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,23,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,7,31,127,71,55,0,7,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,9,9,9,18,9,9,0,0,0,0,0,0,0,0,0,0,9,9,0,0,0,9,0,127,127,45,0,9,9,9,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,42,84,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,0,0,127,105,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,52,31,0,0,0,0,0,0,0,0,0,0,0,10,10,0,0,0,10,0,31,127,63,31,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,29,39,0,0,0,0,0,0,0,0,0,0,0,9,19,0,0,0,48,0,58,127,19,9,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,127,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,42,84,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,127,50,25,50,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,31,0,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,63,63,127,63,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,12,127,76,101,0,0\n0,4,6,4,6,10,12,24,14,24,14,51,20,49,30,26,20,30,20,10,14,16,8,4,0,4,6,2,2,0,10,8,10,10,32,98,127\n127,31,0,23,7,23,7,15,7,15,31,47,47,31,15,15,7,15,15,39,15,23,7,0,0,7,0,0,0,0,0,7,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,8,5,0,8,25,95,127,107,36,5\n127,0,63,31,0,31,127,31,0,0,31,31,0,0,0,63,31,31,63,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,88,60,36,53,32,24,17,20,24,26,26,36,31,28,22,27,28,47\n109,127,63,33,23,22,16,2,7,4,2,7,6,3,7,6,8,16,14,6,8,2,17,9,4,1,1,0,0,1,1,0,0,0,0,0,0\n0,5,5,0,0,0,0,0,0,0,5,20,20,30,127,81,111,81,20\n11,11,2,0,2,0,2,5,2,0,0,0,5,11,14,34,86,103,127\n50,50,50,25,0,0,0,0,0,0,0,25,0,25,127,76,101,101,101,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n50,76,76,127,50,25,101,25,76,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,12,29,28,29,7,26,31,61,68,82,24,37,51,70,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,95,63,31,63,0,95,127,31,95,0,0,0\n78,105,105,90,58,68,105,95,75,58,46,58,65,63,41,43,61,75,127\n32,40,20,20,15,7,3,2,17,27,30,13,17,19,24,21,35,27,43,46,51,78,66,64,95,127,106,92,74,45,23,6,0,0,0,0,0\n0,0,0,0,0,2,2,5,21,27,62,83,70,127,56,62,51,56,32\n39,39,0,9,9,48,68,78,127,97,9,0,0,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,6,10,1,0,16,85,127,90,84,43,15,6,25,62\n127,34,11,0,5,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,5,0,0,0,0,0,0,0,5,5,0,0\n0,0,0,14,0,0,0,0,0,4,0,0,0,0,0,4,9,19,19,19,4,14,14,4,9,9,9,0,4,14,24,24,29,58,68,48,127\n127,13,12,2,1,3,1,8,13,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,23,55,127,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,21,0,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,0,84,42,127,84,105,63,63,0,42,21,42,21,0\n127,63,105,21,21,0,0,0,21,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,105,21,84,42,21,42,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,105,0,0,21,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,21,21,84,21,0,42,0,0,0,0,21,0,21,0,0,0,0\n0,0,0,0,0,25,0,0,12,0,12,12,0,0,0,12,0,0,50,63,76,101,127,76,50,114,127,50,76,12,12,38,50,88,25,63,0\n11,11,3,3,11,41,65,127,26,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,19,19,44,19,6,6,12,6,50,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,76,127,127,50,25,25,0,127,0,50,0,0,0\n127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,10,10,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,0,42,127,42,21,84,42,0,0,21,0,0,0,0,42,42,21,0,42,42\n0,0,0,0,0,0,0,4,0,0,4,0,4,0,4,9,24,34,24,43,53,127,39,68,9,4,4,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,2,0,2,33,127,64,47,38,7,16,7,9\n0,0,0,0,0,0,31,0,0,0,0,0,0,0,31,0,0,0,127,0,95,95,95,63,31,63,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,127,38,63,76,50,114,38,50,0,0,0,0,0,12,0,0,0,0,0,0\n0,0,9,19,19,68,78,39,107,97,127,68,58,9,0,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,9,48,58,0\n0,13,0,6,26,46,60,60,40,73,127,73,53,33,20,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,33,33,80\n0,0,0,0,0,0,0,18,18,36,0,54,36,36,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,72,127,72,18,0,0,18,0,0,0,0\n0,0,0,46,34,0,0,11,57,46,46,115,11,46,0,11,0,11,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,23,127,57,11,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,0,127,0,84,42,84,42,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,42,0,42,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,63,0,0,63,63,0,95,0,0,0,31,0,0,0,0,0,0,31,31,31,0,63,127,63,31,95,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,0,31,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,21,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,36,18,0,127,108,36,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,36,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,50,25,0,25,0,76,127,101,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,50,50,127,0,25,25,0,25,25,0,0,0,50,0,25,25,0,50,25,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,63,0,0,63,0,127,0,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,63,63,63,0,0,63,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,127,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,42,127,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,42,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,31,127,127,0,127,0,0,0,0,31,0,0,0,0,0,0,0,0,31,0,63,0,63,0,0,0,0,0,31,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0\n0,0,50,25,0,25,25,0,25,0,25,25,50,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,127,25,0,0,0,0,0\n0,0,12,0,38,0,50,50,127,12,0,0,0,0,25,0,12,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,63,88,12,50,0,0,12,0,0\n56,28,14,14,0,0,0,0,28,14,0,0,0,0,42,56,127,112,56\n127,45,90,90,18,0,27,9,27,0,18,0,9,0,9,9,0,9,0,27,0,36,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,18,0,18,0,36,72,90,127,90,127,0,0,0\n127,105,21,0,31,10,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,7,0,15,15,39,79,79,55,127\n0,0,0,0,0,11,0,0,23,11,0,5,17,17,98,51,51,51,17,98,127,40,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,56,42,84\n0,0,18,18,18,0,0,0,0,0,0,0,0,0,0,0,0,18,0,18,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0\n84,28,14,35,49,35,63,63,49,84,91,63,98,84,84,91,35,127,112\n127,63,76,0,12,0,0,0,0,0,0,0,0,0,12,0,0,0,0,12,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,38,25,0,0,12,0,0,0,12,0,0,12,0,25,38,38,101,127\n39,58,58,58,43,34,14,9,48,4,14,34,24,14,39,43,87,107,127\n80,127,80,66,46,13,20,20,0,0,0,0,20,6,6,20,33,53,33,46,53,73,26,26,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,25,0,0,25,25,25,50,127,50,0,101,101\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,0,63,63,0,0,127,63,0,127,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,50,0,25,76,127,50,25,0,25,0,25,25,0,0,25,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,0,0,42,0,84,42,42,0,0,84,0,42,127,84\n0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,95,63,127,63,31,63,63,0,31,0,0,0,0,0,0,0,0,0,0,0\n0,31,31,31,127,63,0,31,127,63,31,0,127,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,63\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,84,127\n0,0,0,0,0,0,0,0,0,0,0,50,12,12,12,50,38,63,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,127,58\n5,0,2,0,0,14,14,19,31,107,112,127,59,67,16,19,2,14,2,0,2,0,0,0,0,0,2,0,0,0,0,0,0,0,2,2,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,25,0,25,0,0,25,0,25,0,25,50,50,127,25,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,0,42,127,63,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,0,0,0,0,0,0,0,0,0,0,0,5,5,0,0,0,0,0,0,11,60,127,66,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,6,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,53,127,100,20,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,15,15,0,0,63,127,47,31,0,15,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,21,0,0,63,63,0,127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,127\n0,0,0,0,0,0,0,0,84,42,42,42,0,42,127,0,42,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,42,21,42,63,0,0,0,0,0,0,0,0,0,0,0,0,0\n15,7,0,7,0,7,0,7,0,0,7,7,0,23,23,23,63,127,15\n0,0,0,0,0,0,9,0,0,0,9,0,0,0,9,0,19,29,39,127,127,29,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,42,105,63,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,0,0,0,5,127\n0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,7,15,0,7,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,7,0,7,23,127,15,15,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,95,0,15,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,31,111,127,15,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,9,0,0,127,27,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,90,127,54,9,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,15,7,87,23,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,119,127,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,95,0,63,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,84,0,127,84,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n31,127,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,84,127,21,21,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,76,76,127,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,21,10,10,63,42,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,10,10,95,127,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,6,36,30,24,0,6,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,6,6,127,72,12,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,25,50,127,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,101\n0,0,0,0,0,0,0,0,0,0,0,0,0,101,127,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,84,0,0,0,0,42,0,42,42,0,0,0,0,42,0,0,0,0,0,0,0,127,84,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,2,11,24,44,30,55,127\n0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,28,42,37,51,127,98,32,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,38,127,110\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,127,84,0,42,84,84,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,108,127,54,18,72,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,11,0,0,0,34,23,23,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,34,46,127,80,11,0,11,0,11,0,0,0,0,0,0,0,0,0,0,0,11,23,11,92,80,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,14,28,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,14,28,56,28,28,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,28,42,56,127,14,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,23,46,127,57,11,11,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,23,115,127,46,11,0,0,11,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,11,34,127,23,11,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,115,127,11,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,127,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,23,23,15,15,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,15,39,63,127,31,7,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,28,127,28,14,0,0,0,0,0,0,0,14,14,0,0,0,0,0,0,0,0,28,0,42,42,56,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,15,0,0,0,47,63,15,15,47,127,31\n0,0,0,0,0,42,42,0,0,0,0,0,0,0,21,63,0,21,42,127,105,63,105,0,21,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,10,21,15,52,79,52,89,127\n0,12,0,0,0,0,0,0,0,12,12,12,12,0,12,0,38,101,127,63,38,50,12,12,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,12,44,127\n0,0,63,31,31,0,0,0,0,0,31,0,127,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,9,0,0,0,58,0,58,127,19,19,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,31,0,127,0,95,63,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,127,0,0,31,0,0,0,31,0,0,31,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,84,127,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,105,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,42,127,127,0,84,0,0,0,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,0,0,0,84,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,127,90,68,23,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,11,127,99,58,28,5,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,4,1,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,25,127,88,55,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,2,39,127,87,51,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,127,18,36,18,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,15,0,31,47,63,31,127\n0,0,0,0,0,0,0,0,0,0,0,3,10,13,23,23,20,60,127\n0,18,0,18,18,36,36,18,54,0,127,108,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72\n0,0,0,0,0,0,0,0,25,25,127,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,127,50,25,50,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,5,25,15,15,30,81,60,127,45,20,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,5,0\n0,0,0,0,0,0,0,0,18,72,72,127,36,54,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,127,42,42,84,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,84,84,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,18,36,54,54,54,18,0,18,36,0,0,0,0,0,0,0,0,0,0,36,54,127,36,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127\n0,0,0,0,0,0,0,0,0,0,31,31,0,0,0,0,63,31,127,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,63,63,63\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,127,63\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,24,4,9,0,0,0,0,4,29,107,127,34,4,0,9,4,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,15,0,5,0,0,0,5,31,116,127,63,10,5,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,17,127,84,21,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,52,127,45,7,0,0,0,0,0,0,0,0,0,0,0\n9,0,0,0,0,0,0,0,0,4,9,127,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,4,0,0,0,0,0,0,0,0,0\n5,0,5,5,0,0,0,0,0,5,20,127,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,5,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,10,127,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,10,0,0,0,0,0,0,0,0,15,127,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,63,63,127,63,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,31,31,0,31,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,31,31,63,31,95,127,31,0,31,0,31,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,63,0,0,127\n0,0,0,0,0,0,0,0,0,63,0,127,95,0,127,127,0,95,127\n0,0,0,63,63,63,0,0,0,0,0,0,0,0,0,63,63,63,63,127,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,6,6,0,12,6,12,12,12,24,18,36,90,127,48,120\n127,21,42,42,21,21,21,42,0,0,21,0,0,0,0,42,21,21,0,21,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,50,0,101,25,0,0,0,0,25,127,76,76,76,50,0\n0,0,0,0,0,0,0,0,0,0,3,7,7,14,22,33,52,82,127\n95,15,0,0,0,0,15,0,0,0,0,0,0,0,31,15,47,127,63,15,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,34,127,69,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,50,114,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,78,127,84,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,8,67,127,73,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,42,42,21,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,127,19,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,127,50,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,111,0,0,0,0,0,0,0,31,95,127,15,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,79,0,0,0,0,0,0,0,63,127,79,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,127,87,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,127,78,9,9,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,12,0,0,127,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,105,63,84,0,0,0,0,21,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,71,55,31,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,31,15,7,15,0,0,0,7,95\n127,67,56,33,7,3,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,15,15,15,31,31,15,127,31,63\n127,91,31,14,2,2,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,4,0,0,2,14,2,47,79,79,59,43,6,4,0,4,0,2,0,0,0,0,0,4,0,2,2,4,0,2,16,20,36,69,65,16,12,2,0,0,2,2,0,0,0,0,0,2,0,0,0,4,8,24,98,127,57,22,6,2,0,2,0,4,0,0,0,0\n0,0,0,0,0,0,0,0,0,1,6,27,77,127,94,29,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,6,10,30,29,19,14,5,0,1,0,0,0,0,0,1,0,0,0,0,2,2,3,12,52,91,93,62,33,13,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,9,0,0,9,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,58,9,127,9,9,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,10,10,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,10,42,0,10,10,10,0,10,0,0,0,0,0,0,0,0,10,0,21,63,52,127,31,10,31,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,18,18,127,54,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,50,25,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,50,127,50,25,0,0,0,0,25,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,39,127,39,0,0,0,0,9,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,16,59,76,127,93,16,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,42,76,25,8,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,2,15,43,42,16,2,5,2,0,1,1,0,0,0,0,0,0,0,0,0,0,4,7,42,127,63,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,31,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,127,95,0,63,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,25,0,12,38,114,127,88,76,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,12,0,12,76\n0,0,0,0,0,0,0,0,0,0,31,0,31,0,31,31,63,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,95,127\n127,55,10,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,68,18,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,57,10,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,69,17,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,6,31,55,85,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,0,3,10,42,105,127,105,113,59\n0,0,0,0,0,0,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,1,8,17,31,63,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,30,38,50,123,127,107\n127,85,28,8,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3\n96,127,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,6,46,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,51,79,127,95\n127,48,10,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,67,31,12,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,27,25,40,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,18,72,127,36,0\n127,80,27,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,12,39,127\n127,77,31,11,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,5,6,15,28,39\n127,86,39,16,7,2,4,2,2,2,1,0,1,0,0,0,1,0,0,0,1,1,0,0,2,0,0,0,0,0,0,0,2,5,19,55,109\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,2,6,17,2,31,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,8,9,6,29,127\n127,91,57,38,27,23,18,12,11,8,8,6,3,2,3,4,4,4,3,4,3,3,4,3,6,5,6,5,5,6,5,3,2,4,5,5,5\n56,127,123,56,84,67,45,42,28,56,24,49,28,77,49,35,52,42,31,31,24,17,28,7,14,10,10,3,0,14,10,0,0,3,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,24,24,45,20,4,16,53,127,106,20,57,106,81,122,110,90\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,23,11,11,34,127,80,46,34,23,46,57,57,69,46\n127,117,98,119,68,72,35,30,11,14,7,7,7,18,16,9,11,11,23,16,18,21,35,18,11,9,9,0,4,23,7,7,14,2,7,9,4\n0,0,0,0,0,0,0,0,10,10,52,127,95,63,42,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,31,63\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,7,39,127\n0,0,0,0,0,11,11,23,11,0,11,57,127,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,57,92,92,46,11,0,11,0,0,0,0,0\n0,0,0,0,0,10,0,10,0,0,31,21,105,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,127,95,21,0,0,10,0,0,0,0,0\n0,0,0,0,0,15,0,0,0,0,15,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,47,95,127,15,0,0,0,0,0,0,0\n0,0,0,0,0,42,0,0,0,0,84,42,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,42,0,0,42,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,6,0,44,6,44,127\n0,0,0,0,0,0,0,0,0,14,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,14,0,0,0,0,0,0,0,0,0,0\n127,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18\n105,127,42,21,21,0,21,10,0,0,0,21,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,4,9,127\n127,7,15,7,7,0,7,0,0,0,0,0,15,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,2,1,1,18,63,117,127,113,72,41,40,25,21,43,33,20,14,5,2,4,0,0,6,0,9,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,8,8,2,1,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,8,30,83,127,92,57,33,41,16,15,6,6,3,4,1,1,0,0,4,3,0,2,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,5,2,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,14,14,42,98,127,42,28,14,14,42,0,42,0,0,0,28,28,0,14,0,0,0,0,0,14,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,25,88,127,25,38,12,12,38,12,12,0,0,12,12,12,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,63,21,0,42,105,42,21,21,21,63,127,21,0,0,21,0,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,63,21,105,127,0,21,0,21,0,0,0,21,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,42,84,42,127,84,42,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,18,0,0,54,18,54,127,18,36,90,0,0,36,36,0,18,0,0\n0,0,0,0,2,0,0,0,0,0,2,28,127,14,0,2,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,10,45,127,56,0,3,0,0,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,9,127,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0\n0,0,0,0,0,0,0,0,0,11,23,34,127,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,19,95,127,23,2,6,1,1,2,1,2,0,0,1,0,0,0,0,0,2,4,8,8,14,19,31,31,8,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,15,14,3,5,1,0,0,2,1,0,0,1,0,0,0,0,0,1,1,2,8,21,22,19,59,127,46,3,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,101,127,25,25,0,25,25,0,0,0,0,0,0,25,25,50,0,0,0,0,25,0,25,76,76,0,0,25,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,98,0,28,0,0,56,42,0,0,0,14,14,0,28,14,0,0,0,0,14,14,56,127,84,28,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,15,0,0,0,0,0,0,0,0,0,0,0,0,0,47,47,127,47,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,31,79,95,127,63,15,0,0,15,0,15,0,15,15,15,15,15,31,31,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,79,47,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,18,45,99,127,54,18,27,9,18,0,0,0,0,0,9,0,0,9,0,9,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,45,0,9,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,2,1,2,0,5,127,119,6,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,2,0,0,2,0,0,0,0,8,105,127,7,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,105,21,21,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,31,0,0,63,63,0,95,127,0,63,31,31,0,31,0,0,0,0,0,63,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,5,0,15,5,0,111,127,79,31,68,10,0,0,0,0,10,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,0,0,0,0,0,18,36,0,18,18,0,18,18,0,0,0,0,0,18,36,18,90,90,108,36,127,36,18,0,0,0,18,18,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,21,0,0,0,63,42,21,0,0,21,21,0,0,0,0,21,42,21,21,42,0,63,42,42,127,0,0,0,0,21,0,0,0,0,0,0,0,0\n109,127,83,43,21,13,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,13,30,41,48,52,91\n15,2,1,0,5,5,0,0,1,0,0,0,0,0,0,0,2,0,0,1,0,0,0,0,0,0,0,5,0,3,0,1,5,17,45,73,127\n127,97,79,44,31,28,17,19,7,5,8,17,5,4,4,2,5,5,10,23,8,13,5,22,20,17,13,5,20,5,20,11,20,20,36,42,35\n63,31,63,0,63,63,95,0,31,0,31,0,31,0,0,31,63,0,0,0,0,127,0,0,0,0,0,0,31,31,0,0,0,0,0,0,0\n31,79,111,127,79,47,31,47,95,15,47,47,15,0,0,95,15,79,111,15,15,47,31,31,15,31,15,31,31,0,0,15,0,0,47,31,0\n127,33,7,6,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,50\n127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,50\n127,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31\n127,28,42,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,28,112\n111,127,11,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,15,99\n0,0,0,0,0,0,0,0,0,105,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,63,0,0,127,0,0,0,63,63,0,0,0,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,63,63,63,0,127,63,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n101,101,76,101,127,127,76,76,50,0,50,76,25,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,25,76,50,0,50,76,76,127,127,101,76,101\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,0,0,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,0,0,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,95,31,127,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,63,0,63,95,63,0,0,0,127,31,0,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,31,31,95,31,95,31,127,63,31,63,0,63,95,0,0,31,0,0,0,0,31,0,0,31,0,0,31,0,0,0,0\n127,90,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90\n127,61,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,69\n127,105,42,0,21,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,42,21,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,21,42,0,0,0,42,105\n127,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,38,127,63,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,42,0,0,42,63,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,127,127,42,42,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,19,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,0,0,76,0,76,76,101,127,25,127,50,50,50,0,25,0,25,50,25,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,84,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,40,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,63,15,63,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n80,127,73,46,53,53,26,20,6,6,6,6,0,20,0,0,20,20,33,40,33,13,0,0,6,6,0,6,0,13,0,20,6,6,20,0,13\n84,98,112,127,14,28,0,14,0,14,0,0,0,0,0,0,0,14,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,42,28,28,56\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,84,84,127,42,0,0,84,0,0,42,0,0,0,0,0,0,0,0,0,0\n127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,42\n25,0,0,76,25,50,25,127,25,25,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,0,25,25,101,25,0,0,25,25\n63,31,0,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,31\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,18,90,127,24\n0,42,84,127,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,0,0,42,0\n127,63,15,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n65,51,32,16,8,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,2,3,34,127\n127,34,20,9,4,3,3,3,2,0,1,0,0,0,0,0,0,0,0\n119,23,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,15,23,79,127\n30,45,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,15,53,93,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,15,127\n72,45,72,27,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,127,127\n0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127\n46,20,10,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,83,127\n127,74,74,52,63,21,10,10,0,0,0,0,0,0,31,0,10,0,31,21,21,10,42,31,0,31,42,31,10,0,10,10,0,0,0,0,0\n84,84,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,127,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,0,0\n127,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,0,0,42,42,42,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84\n111,106,87,76,71,65,77,91,97,93,97,108,104,117,111,117,123,127,120\n127,99,45,43,24,16,11,18,14,11,4,11,8,9,5,23,36,41,40,61,33,58,62,43,29,29,17,10,5,4,1,2,0,1,0,0,0\n1,2,0,1,0,0,0,0,1,1,0,4,14,21,71,72,78,127,124\n0,34,11,103,92,11,46,127,80,23,11,46,0,11,34,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,25,59,59,21,12,16,84,76,105,55,50,84,127,55,21,0\n0,0,0,0,0,9,9,0,0,9,0,0,0,0,9,9,9,72,72,72,127,54,81,63,36,45,9,18,36,18,27,0,9,0,0,0,0\n127,81,51,15,18,3,6,0,0,0,0,0,3,3,0,0,3,3,6,6,9,15,24,27,51,48,21,21,6,3,0,0,0,0,0,0,0\n0,127,127,63,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,63,0,63,127,0,0,63,0,0,0,0,0,0,0,0\n0,11,92,127,34,0,80,57,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,15,63,79,127,47,95,47,31,0,15,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,27,9,27,108,117,127,45,36,18,0,0,0,0,9,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,42,84,84,0,0,42,0,0,42,0,42,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,127,127,63,0,0,127,0,63,63,0,63,0,63,0,0,0,0,0,0,0\n127,127,42,42,21,0,21,0,21,0,0,0,0,0,0,42,21,0,0,42,105,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,127,0,12,0,0,12,0,12,0,12,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,84,84,127,84,0,0,0,0,84,0,42,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,63,0,0,0,0,127,63,63,31,0,0,0\n0,0,0,0,0,0,1,2,6,17,69,127,104,49,15,5,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,12,42,64\n0,0,0,0,0,0,0,0,0,56,127,28,70,42,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,28,28\n0,0,0,0,0,0,63,63,95,0,95,127,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,10,0,10,63,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127,0,21,0,0\n0,0,0,0,0,0,0,0,0,11,127,93,121,16,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,11,22\n0,0,0,0,0,0,0,0,0,0,0,36,108,127,72,36,18,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,0,90,36,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,36,36,18,36,36,18,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,47,63,79,95,127,31,31,15,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,63,47,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,79,47,63,31,31,47,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,127,0,0,0,0\n0,0,0,0,0,0,0,7,3,19,59,123,127,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,35,39,19,0,3,3,3,0,0,0,0\n0,0,0,0,0,0,7,0,14,52,97,127,89,22,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,112,59,59,29,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,63,127,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,31,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,18,127,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,18,72,18,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,56,42,14,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,127,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,0,0,127,63,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,127,63,63,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,42,0,0,21,63,42,42,63,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,18,18,18,127,72,18,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,54,18,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,25,0,25,127,76,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,101,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,10,95,127,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,21,52,10,0,0,10,0,0,0,0,0,0\n127,56,8,5,2,1,0,0,0,1,1,0,0,0,0,2,0,0,0,0,0,0,0,1,0,1,0,1,0,0,2,1,0,3,3,4,0\n127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n44,77,41,33,8,5,24,16,2,0,2,5,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,27,33,46,127\n127,15,31,79,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,16,53,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,9,16,54,49,117,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,10,44,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,2,11,14,25,47,56,127,112,67\n127,64,14,5,7,2,5,3,3,3,0,0,2,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0\n127,107,69,41,24,4,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,8,10,9\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,3,27,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,1,10,13,75,127\n127,102,77,63,40,27,27,20,10,8,10,3,5,9,11,16,7,7,11,6,15,6,11,7,7,9,10,6,10,1,4,1,0,0,0,0,0\n89,82,127,112,59,29,22,7,14,7,7,14,0,7,22,14,52,52,29,22,22,0,7,7,0,7,0,0,0,0,0,0,0,0,0,0,0\n112,35,84,127,105,112,77,42,14,14,7,21,7,21,49,7,0,7,0,0,14,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,4,2,3,2,6,19,46,65,105,115,81,94,127,110,65,30,18,17,24\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,2,2,20,28,24,22,27,100,127,95,58,13,6,9,12\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,2,2,2,1,1,9,25,38,83,111,127,97,95,60,43,37,41,18,17,22,26\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,5,0,10,35,127,96,116,81,25,45,15,20,15,20,15,20,20\n105,127,74,52,63,42,52,0,0,10,10,10,10,0,10,10,0,10,52,31,42,105,105,52,42,52,21,21,10,0,42,10,0,0,10,10,0\n127,96,65,52,26,14,10,5,2,3,4,2,2,2,3,2,0,2,1,3,3,6,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,78,66,30,15,15,3,3,0,3,0,0,0,0,6,3,12,15,6,3,3,6,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,10,8,0,1,4,7,10,24,43,90,127,37,12,7,2,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,3,11,34,103,127,100,34,3,0,3,0\n127,111,119,55,55,63,15,7,0,0,0,0,0,0,0,0,7,0,0,0,0,0,7,0,7,0,0,0,0,0,0,0,0,0,0,0,0\n127,80,8,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,15,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,69,11,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,11,5,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,2,10,4,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,14,3,25,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,27,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,25,12,25,38,127\n127,59,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,17\n127,60,17,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,25,38,40\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,21,0,42,42,105,105,84,84,42,63,84,127,21,21,42,42,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,0,42,42,105,21,21,127,127,105,42,84,21,21,21,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0\n66,55,60,27,0,22,0,0,0,0,5,0,0,5,5,0,0,0,0,0,0,0,0,5,11,0,5,0,5,0,0,0,0,0,0,0,5,0,11,5,22,16,5,27,22,33,49,127,82,99,77,27,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27\n46,75,23,17,11,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,11,5,0,5,5,0,11,11,0,11,0,0,0,11,0,0,5,0,0,17,11,0,5,40,46,57,69,127,63,46,46,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,5,51\n0,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,31,0,0,127,31,95,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31\n84,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,42,127,0,0,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,42\n0,0,0,0,0,0,25,0,0,0,127,101,25,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,9,9,9,0,9,0,108,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,38,0,0,12,0,127,50,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,42,31,21,63,63,31,63,63,127,105,127,21,31,0,0,0,21,0,21,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,7,7,0,7,47,87,103,39,95,55,47,103,127,47,47,7,23,0,15,0,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,42,127,127,42,84,42,0,42,84,84,127,42,42,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,70,127,14,42,0,0,0,14,14,14,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,5,5,10,15,30,35,35,10,35,66,35,86,127,71,66,25,71,45,60,10,20,10,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,34,80,46,69,34,57,57,46,103,80,92,115,127,46,34,34,23,11,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,50,76,0,127,0,0,25,25,50,127,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,63,21,63,0,42,105,21,21,21,21,42,63,127,63,0,0,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n1,0,0,0,0,0,0,2,2,14,14,30,49,33,14,9,6,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,8,21,46,59,46,18,17,18,12,5,8,3,2,2,0,0,1,0,2,4,3,8,21,42,80,127,114,81,27,9,2,1,0,0,0,0,0,0\n0,0,0,0,1,1,2,2,2,7,21,23,28,31,16,11,3,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,2,5,5,17,20,36,26,25,13,7,3,0,5,5,0,2,3,0,1,0,2,0,3,8,14,38,85,112,127,73,26,9,0,2,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,50,0,0,50,0,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,0,25,25,25,0,50,0,0,50,0,0,50,25,0,25,25,0,0,0,25,101,127,76,25,50,0,76,0,0,0,25,0,0,0,0,0\n0,0,0,0,0,0,0,0,25,50,0,0,50,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,101,0,50,50,50,0,0,0,0,0,0,0,0,0,25,0,0,0,76,50,50,50,101,101,101,127,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,7,15,0,7,15,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,7,0,23,7,7,7,7,7,0,0,0,0,0,0,0,0,15,15,7,23,15,7,63,103,127,111,47,0,7,7,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,9,19,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,4,0,4,0,9,0,0,4,9,0,0,9,0,9,14,0,0,4,9,39,127,92,63,29,19,14,4,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,72,18,0,0,0,0,0,0,0,18,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,2,5,2,5,5,2,16,51,67,127,16,5,2,0,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,6,0,3,0,3,0,35,58,127,29,6,3,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,18,27,127,63,18,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,12,38,127,76,44,0,0,12,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,31,31,63,127,15,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,12,12,0,127,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,1,1,16,22,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,9,66,127,38,5,4,0,0,0,0,0,0,0\n1,0,0,0,0,1,0,0,2,4,20,20,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,4,9,62,127,32,2,0,2,1,0,1,0,1,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,63,76,25,12,12,0,0,0,0,0,0,0\n0,18,0,18,0,0,0,18,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,108,127,18,18,0,0,18,0,0,0,0,18\n0,0,0,14,0,0,0,0,0,14,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,14,42,127,112,70,14,0,0,0,0,0,0,14\n0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,11,0,0,11,127,23,23,11,11,11,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,1,3,17,42,30,15,14,6,1,0,0,0,0,0,0,4,5,7,2,3,2,4,5,15,46,127,91,18,8,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,3,12,26,43,26,12,4,3,0,0,0,0,0,0,0,0,0,0,0,2,2,4,6,26,127,93,12,4,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,3,0,27,102,106,51,6,20,6,10,0,0,0,6,6,0,3,13,24,24,30,24,34,44,109,127,20,6,6,6,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,1,0,3,27,60,41,23,9,0,5,0,0,3,3,0,7,1,1,0,1,5,1,0,13,66,127,91,27,0,3,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,1,1,1,6,19,95,83,17,4,4,3,2,2,0,1,5,2,2,0,2,0,1,0,2,7,17,19,46,127,75,13,3,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,7,15,1,11,66,102,81,27,3,6,3,1,1,3,3,2,3,2,1,1,1,2,0,0,5,7,22,60,127,90,20,10,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,0,127,127,15,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,127,5,0,0,5,0,5,0,11,34,17,0,0,5,23,0,5,11,5,23,11,28,17,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,8,0,16,0,0,16,16,50,16,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,8,0,8,25,127,67,76,33,59,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,7,21,35,7,0,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,28,0,21,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,28,42,127,91,56,7,0,0,7,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,6,6,6,6,19,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,12,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,57,127,76,25,0,0,0,0,0,6,0,6,0,0\n0,0,0,0,0,0,0,0,7,56,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,5,127,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,9,0,0,0,0,0,0,0,0,27,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,127,117,0,27,9,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,25,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127,63,38,12,12,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,21,0,0,0,21,42,21,21,0,21,0,0,0,0,0,0,0,0,0,10,0,10,10,84,127,84,21,0,21,74,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,15,0,0,15,127,111,79,0,15,31,15,0,0,0,0,15,0,15,31,0,0,0,31,31,95,0,63,0,79,47,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,63,63,0,0,0,0,63,127,127,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,6,18,6,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,18,30,18,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,6,6,66,127,72,60,36,6,0,0,0,0,0,0,0,0\n0,0,0,0,0,3,0,0,0,0,0,0,10,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,6,6,20,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,3,0,6,10,56,90,127,23,3,3,0,0,0,0,0,0,0,0\n0,0,0,0,4,0,0,0,0,0,4,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,30,74,127,65,13,13,0,0,0,0,0,0,0\n0,0,0,0,0,0,4,0,0,4,14,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,9,43,68,127,83,29,4,0,0,0,4,0,0,0\n0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,36,127,45,18,18,18,9,0,0,0,0,0\n10,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,63,42,10,10,0,0,0,10,10,21\n0,0,0,0,0,0,0,0,0,0,25,25,0,50,127,76,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,76,76,127,25,76,25,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,15,0,15,0,31,111,127,15,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,15,15,79,31,95,31,15,0,15,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,127,0,31,0,0,0,0,0,0,0,0,0,0,0,63,0,0,31,31,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,31,63,127,0,31,0,0,0,0,0,0,0,0,0\n50,25,50,0,12,12,0,0,50,0,25,50,25,63,127,63,127,50,0,25,50,0,0,12,0,0,0,25,0,0,0,0,0,0,0,0,25\n0,0,0,0,0,42,0,0,0,0,21,84,42,42,63,42,21,0,0,0,21,21,0,0,0,0,0,0,0,21,0,0,0,21,42,21,127\n0,0,0,0,0,0,0,21,63,127,84,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,0,0,1,6,5,1,18,33,127,125,63,50,26\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,1,0,2,0,0,0,1,8,86,127,49,5,5,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,11,34,92,127,69,80,57,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,54,0,127,54,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,50,25,25,50,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,25,127,101\n0,0,0,0,0,0,0,0,25,63,38,12,50,38,50,25,50,0,0,0,0,25,0,0,0,0,0,0,12,0,0,12,0,50,63,38,127\n0,0,0,0,0,0,0,0,0,11,11,11,80,46,69,46,69,46,46,57,127,80,80,80,46,0,0,11,0,0,11,11,23,11,0,11,23\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,8,42,84,127,76,110,50\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,127,63,0,0,0\n127,87,36,12,4,1,1,0,0,0,0,1,1,1,1,1,1,1,0\n127,92,45,18,8,4,2,1,0,0,0,0,1,1,1,0,0,0,0,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0\n2,1,2,2,1,1,1,1,2,4,6,8,17,25,41,63,91,106,127\n33,23,10,10,8,16,6,19,6,4,2,6,6,8,8,33,44,76,127\n0,42,0,21,42,21,63,21,42,21,21,42,21,21,127,0,105,63,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,50,127,101\n127,31,10,16,18,11,6,2,3,0,1,0,0,0,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n34,47,60,92,127,72,89,30,18,18,9,0,1,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,1,3,6,10,14,18,17,35,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,14,9,1,1,4,4,6,12,58,103,92,127,84,65,56\n121,96,81,86,60,75,71,80,73,70,79,60,88,100,98,113,105,103,127\n127,72,71,53,50,33,46,31,30,21,30,17,24,27,24,47,43,41,52,47,60,52,69,30,29,22,21,5,0,1,0,0,1,0,0,1,0\n0,0,0,0,0,0,4,6,1,12,24,20,34,27,41,106,85,106,127\n127,55,25,6,10,25,23,21,8,8,4,1,0,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,8,3,1,1,3,21,19,8,8,12,25,38,59,127\n127,73,21,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,1,5,2,3,0,0,0,0,0,0,0,0,0,0,0\n127,70,13,0,0,3,0,0,1,0,0,0,0,1,1,1,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n42,42,12,12,12,0,4,4,8,4,4,4,8,8,16,8,33,25,42,25,80,42,101,105,101,93,55,29,33,29,21,25,46,59,76,127,67\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,39,79,127\n127,101,63,114,25,25,38,12,25,25,50,0,50,101,101,38,12,0,12,12,12,0,0,0,25,12,0,0,0,0,12,25,12,12,0,0,0\n127,18,5,9,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,66,30,3,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,18,90,90,127,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,31,45,25,9,6,3,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,27,36,45,36,36,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n55,63,119,127,75,39,19,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,39,95,79,31,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,54,127,36,54,72,72\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,28,0,14,42,127,84,127,112,56\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,63,127,63,127,127,127,0,0,0,63,0\n127,63,46,34,0,11,0,0,5,0,17,5,5,0,0,0,0,0,5,0,17,17,5,11,0,0,0,5,0,0,0,0,0,0,0,0,0\n0,0,10,0,10,0,10,0,10,0,0,0,10,0,21,84,74,84,127,74,31,74,63,63,63,52,21,0,10,21,0,10,21,0,21,21,21\n127,30,13,12,6,6,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n84,0,21,21,0,127,42,42,0,0,0,0,0,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,67,59,41,17,8,2,1,0,1,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n40,53,127,61,57,28,16,0,0,0,0,0,0,0,0,8,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,111,95,31,127,63,95\n0,127,21,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,42,0,42,42,0,0,0,0,0,0,0,21,0,0\n84,63,0,21,0,0,84,0,42,0,0,0,0,0,0,0,0,21,0,0,21,63,127,105,0,63,21,63,21,0,0,0,0,0,0,0,0\n127,16,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,71,31,9,0,1,0,0,0,1,1,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n84,127,14,56,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,7,11,23,11,23,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,8,25,21,63,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,31,127,95,31,95,0,0,63,0,0,0,0,0,0,0,0,0\n127,25,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,38,1,1,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,47,15,7,19,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,4,4,0,8,0,8,127,83,61\n0,0,0,28,0,0,0,0,0,0,0,0,0,0,14,70,28,84,98,28,0,98,127,84,127,98,56,56,0,28,14,14,0,84,0,42,0\n127,31,0,10,31,21,21,10,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,0,0,0,0,0,30,86,127,50,35,60\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,6,0,0,0,3,7,73,127,85,57,22\n127,55,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,127,115\n70,76,69,86,83,87,99,127,123,84,46,26,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,1\n0,0,14,28,14,14,14,14,56,42,127,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0\n92,103,69,46,127,98,46,17,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n84,127,76,101,67,84,50,0,25,8,8,16,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,6,14,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,1,0,2,1,4,11,127\n0,11,23,17,17,34,80,80,127,103,80,51,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n4,8,13,3,6,24,25,48,66,127,85,32,30,10,4,8,0,0,1,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0,2,2,0\n28,14,0,14,14,28,0,70,112,70,127,98,28,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,2,4,21,21,65,91,127,96,58,70,52,43,35,30,35,64,29,26,20,11,13,11,2,0,7,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,9,9,34,69,127,94,103,55,82,92,86,76,82,67,75,36,21,21,26,26,13,7,1,5,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,63,0,0,0,0,0,63,63,127,127,63,0,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,42,84,42,0,42,0,0,127,84,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,127,63,63,31,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,25,0,50,127,101,50,25,0,25,0,25,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,14,28,56,14,127,112,0,0,14,0,0,0,0,0\n1,2,0,1,3,4,3,5,8,16,17,32,127,109,35,4,2,0,1,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,6,2,2,2,2,2,1,0,0,1,1\n3,2,2,2,1,3,1,7,13,24,30,44,127,76,33,7,1,0,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,11,8,5,2,4,4,6,3,0,0,1,1\n0,0,16,25,8,8,25,25,8,42,42,50,118,127,16,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,0,0,0,0,0,8,0,0,8\n0,0,0,12,6,12,0,12,48,42,24,18,127,48,48,6,0,0,12,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,24,24,24,30,12,0,6,6,0,0\n0,3,1,0,0,0,1,2,5,1,8,52,127,13,5,1,0,0,1,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,1,1\n2,2,0,0,1,0,2,5,1,4,17,66,127,15,5,3,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,1,0,0,1,0,0,1,4,1\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,8,0,0,16,8,42,59,93,118,50,127,101,42,16,8,0,8,16,0,16,33,0,0,0,8,0,8,8,0,8,25,59,0,16,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,12,6,6,44,82,76,38,127,19,38,12,19,6,12,0,0,0,6,6,0,0,0,0,0,12,6,19,6,6,12,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,0,0,12,25,12,50,127,76,38,0,0,25,0,0,0,0,0,0,0,0,12,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,15,55,127,0,0,15,0,7,7,103,23,23,7,39,7,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,11,15,35,75,67,55,47,51,27,27,3,39,15,3,27,31,27,27,63,83,127,127,71,55,19,3,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,7,11,7,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,4,4,36,53,45,40,53,40,49,20,8,32,20,36,12,0,24,40,20,53,86,81,127,110,57,28,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,16,8,0,4,0,0,0,0,0,0,0,0,0\n0,0,10,3,17,24,13,17,6,41,72,30,127,106,54,3,0,10,0,3,0,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,13,30,17,6,3,0,13,0,0,6,0,6\n0,0,5,5,8,13,10,21,8,35,29,54,127,67,43,10,5,10,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,13,16,10,8,5,2,0,2,10,2,5,5\n0,0,0,0,0,0,0,42,0,42,63,105,127,21,21,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,12,50,12,127,88,50,12,0,0,0,0,0,12,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,76,25,0,25,76,76,76,25,127,0,0,0,0,25,25,0,0,0,0,25,25,25,0,25,127,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,50,0,25,0,0,76,25,101,50,76,0,0,0,0,0,0,0,0,0,0,25,0,25,25,25,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,127,21,10,10,21,31,31,21,21,0,10,0,10,10,10,0,21,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,25,76,50,12,25,50,38,38,12,0,0,12,12,0,38,0,0,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,5,0,15,15,10,10,63,74,127,68,10,10,0,0,0,0,0,0,0,0,0,10,0,5,0,0,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,76,76,127,50,76,50,0,0,25,0,0,0,0,0,0,0,0,0,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,31,31,127,95,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,95,95,31,0,31,31,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,25,50,127,0,0,0,0,0,0,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,0,0,0,0,0,0\n0,0,0,4,0,4,13,4,54,127,95,77,13,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,27,22,13,18,4,4,0,4,0,0\n0,0,0,0,0,9,0,48,87,117,127,87,9,0,0,29,9,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,19,48,39,39,19,9,9,19,0,0,0\n0,0,0,0,0,0,0,0,127,127,127,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,25,0,0,0,0,0,25\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,63,95,127,0,31,31,0,0,0,0,0,0,0,31,0,0,0,0,0,0,31,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,63,63,0,0,63,0,0,0,0,0,0,0,0,0,63,0,0,0,63,0,0,127,63,127,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,28,0,14,0,28,0,0,0,0,0,0,0,14,0,14,14,127,70,56,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,50,25,25,127,0,0,0,0,0,0,0,0,0,0,25,25,50,0,101,101,76,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,5,5,17,34,57,121,127,28,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,23,23,23,23,11,0,0,0,0,0\n0,0,5,0,5,0,5,11,22,60,60,127,22,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,22,11,5,16,5,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,15,95,127,63,63,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,15,15,31,15,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,127,127,31,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,12\n127,29,33,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,12,55,105\n0,84,0,42,42,84,84,42,84,84,0,42,84,42,127,42,42,42,0,0,0,0,0,84,42,0,42,42,0,0,42,42,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,76,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,25,0,0,0,0,0,0,0,0\n127,63,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,31,63\n127,39,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,25,50,25,25,25,25,25,25,0,127,0,25,25,25,0,0,0,25,25,76,0,0,0,76,0,50,0,0,0,0,0,0,0,0,0\n0,18,0,0,36,0,18,36,127,54,36,0,36,0,18,0,36,18,0\n31,0,15,15,0,0,31,0,15,0,15,0,63,31,0,31,47,111,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,63,21,0,0,42,21,0,0,0,0\n0,0,0,0,0,0,0,0,31,31,31,31,95,0,0,0,31,63,127\n50,59,42,101,84,127,84,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,7,19,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,3,20,27,3,13,0,10,34,99,127,92,102,85,82,102\n127,38,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,127,42,42,42,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,84,63,105,42,21,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,127,84,127,84,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,108,54,18,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,18,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,36,0,127,36,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,95,0,95,127,63,63,31,31,31,0,0,0,0,0,0,0,0,0,0,0,31,31,0,0,0,0,31,127\n0,0,0,0,0,0,0,12,0,0,0,0,0,12,0,0,0,38,63,101,25,12,12,0,0,12,38,127,38,25,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127,84,21,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,105,42,21,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,95,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127,50,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,54,36,90,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,84,127,0,42,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,80,127,69,127,46\n127,0,31,0,15,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,95\n0,0,0,0,0,0,0,0,0,0,0,0,11,103,127,23,34,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,23,23,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,5,5,5,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,15,0,0,5,0,42,89,127,47,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,127,84,0,0,84,0,0,0,84,42,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,7,0,3,0,3,7,3,22,29,48,127,97,104,115,104\n0,3,0,0,0,0,3,15,0,11,15,42,19,46,88,100,127,111,76,57,50,38,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,11,22,82,60,127,88,121\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,7,14,7,49,56,70,98,127,28,7,0,0\n0,0,0,0,0,0,0,0,0,0,0,42,0,127,84,42,84,0,84,0,42,0,42,127,84,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,0,42,84,84,127,0,0,127,42,0,0,42,0,0,0,0,42,0,0,0,0,0\n0,0,0,0,63,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,9,0,9,0,9,127,81,27,9,9,0,0,0,0,0,0,0,0,0,0,0,0\n65,127,97,116,83,119,94,32,36,3,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,42,127,84,42,0,42,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,19,127,29,39,9,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,7,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,0,23,127,39,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,54,127,18,9,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,9,27,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,31,127,23,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,7,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,95,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,95,95,63,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,127,42,84,21,21,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,18,0,18,54,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,127,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,36,54,127,72,54,36,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,12,12,0,0,76,38,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,25,114,127,25,0,12,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,127,31,0,0,15,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,34,69,127,69,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n63,79,0,31,47,0,15,31,0,15,79,47,15,47,31,31,31,79,127\n0,95,127,127,127,31,31,63,63,95,63,95,127,63,63,63,127,95,0,31,0,31,0,0,0,31,0,0,0,0,0,31,63,127,63,31,63\n0,0,0,0,2,1,1,1,0,1,1,2,3,16,37,127,46,20,23\n0,95,31,95,63,63,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,9,9,48,78,127,19,0,0,9,9,0\n0,0,21,42,84,42,42,42,21,127,63,42,42,21,21,21,63,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0\n0,0,0,0,0,0,0,0,0,0,0,25,0,25,0,0,50,25,101,76,127,50,50,25,50,76,25,25,0,76,25,25,0,0,25,25,0\n127,127,112,107,109,86,72,65,28,28,33,10,12,7,1,1,1,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,1,1,0\n12,0,0,0,0,0,0,0,0,25,25,12,12,12,25,12,25,101,127,127,101,88,127,25,76,38,38,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,7,7,7,49,0,0,0,35,21,28,63,42,127,42,91,35,14,14,7,14,14,7,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n25,0,0,0,0,0,0,0,25,127,76,0,25,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50\n0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,0,31,0,63,95,95,95,0,31,31,31,0,0,127,63,31,63,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,42,0,42,42,84,84,127,0,127,127,127,84,127,0,84,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,36,18,36,0,54,18,72,18,127,72,72,72,36,54,72,72\n15,23,7,23,23,15,23,31,63,39,31,127,15,7,39,15,23,15,15,23,15,0,0,0,0,7,39,0,23,15,7,0,0,0,0,0,0\n0,0,5,0,5,0,5,0,0,23,28,69,121,109,63,51,63,75,127\n8,10,21,10,24,7,23,36,34,24,31,34,46,53,80,80,93,127,121\n10,15,21,10,15,21,5,63,31,52,15,26,52,37,37,47,21,10,68,89,127,15,10,5,5,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,3,4,9,12,3,6,20,49,104,127,95\n0,0,0,0,0,9,0,0,0,0,18,54,54,90,54,127,63,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,6,6,0,0,13,0,13,26,0,0,26,20,86,127,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,84,127,93,76,16,33,0,0,0,8,0,0,33,8,0,16,50\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,92,127,47,4,11,9,20,27,27,20,15,9,6,4,2,13\n0,0,0,0,0,0,0,0,0,0,42,84,84,42,127,0,0,0,42,42,0,0,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0\n0,90,36,72,0,54,18,90,72,127,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,77,87,54,87,51,37,54,61,28,11,7,2,0,0,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,21,0,0,0,0,21,42,21,42,127,63,84,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,42,0,0,0,21,0,0,0,21\n0,0,0,0,0,0,0,0,0,31,0,95,127,127,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0\n63,0,0,63,0,63,0,63,63,0,63,127,0,0,0,0,0,127,127,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,63,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,127,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n84,127,127,84,84,0,84,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n84,84,42,0,42,0,0,0,0,0,0,0,0,0,42,42,84,84,127,127,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,116,74,42,21,0,21,21,0,0,10,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,42,42,0,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,127,127,127,0,84,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,36,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,72,18,54,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,36,72,36,90,127,54,72,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,42,127,127,42,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,50,127,76,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,50,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,50,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4\n127,51,17,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,76,25,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,63,37,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,63,12,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,5\n112,127,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n112,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,84,42,127,127,127,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,42,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,42,42,84,42,84,84,127,0,42,0,84,42,84,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,127,84,84,127,127,127,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,14,0,14,28,127,84,70,14,14,0,28,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,42,14,0,0,0,0,0,0,0,0,0,0,0\n69,127,34,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n76,127,38,12,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,63,95,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,127,63,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,84,63,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,105,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127,105,105,63,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,76,25,25,0,0,0,0,0,0,0,0,0,0\n127,76,38,12,12,12,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n89,67,82,74,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,22,127,127,89\n28,14,56,28,14,28,127,14,0,0,28,0,56,28,70,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,7,42,127,92,23,3,0,3,7,19,50,73,50,15,7,15\n72,108,127,102,96,12,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,63,63,127,63,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,21,0,0,42,63,63,21,42,105,127\n127,108,80,43,25,17,3,7,2,0,1,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,1,2,5,7,7,14,18,18,36\n127,79,22,5,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,74,8,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,16,8,21,55,67,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,0,0,0,42,127,42,0\n127,90,25,15,0,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127\n104,127,59,44,37,29,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,22,14,29,44,59\n127,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,101\n127,50,25,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,50\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,79,79,111,127,31,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,42,42,84,0,42,127,84,84,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,36,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36\n0,0,0,0,0,0,0,0,0,25,50,127,76,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,25,50,127,25,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,25,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,31,31,0,0,31,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,63,0,127,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127\n14,14,14,7,35,0,35,49,127,42,0,7,7,7,7,0,28,0,0,0,0,0,7,0,0,14,21,0,14,7,28,0,7,21,14,35,0\n0,0,0,0,0,0,0,0,63,42,21,42,127,0,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,42,63,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,63,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,95,63,95,95,31,127,31,0,0\n0,54,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,127,0\n127,72,63,90,45,36,0,0,0,0,0,0,18,0,0,0,0,0,0\n21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,21,31,127\n127,31,31,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,7,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,63\n127,25,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n101,50,0,0,0,0,0,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,0,0,50,76,127,101\n101,101,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,50\n127,50,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,81,30,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,58,87\n46,23,23,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,17,57,127\n127,111,74,21,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,42\n0,0,42,84,0,42,42,42,42,42,0,0,42,0,0,0,42,0,0,0,0,0,42,0,0,0,42,0,0,0,0,84,42,0,127,0,84\n9,4,2,8,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,7,20,57,112,127\n84,127,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,0,0,42,0,0,127,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,84,127,84,84,42,0\n0,0,0,0,0,0,0,0,0,0,0,0,27,27,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,9,81,127,36,27,0,0,0,0,0,0,0,0,0,0,9,0,0,0,9,0,27,90,54,63,18,63,0,0,9,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,5,0,5,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,15,5,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,21,52,74,127,68,10,0,5,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,10,42,127,10,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,52,21,0,10,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,8,76,127,42,8,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,16,16,42,67,33,16,0,8,8,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,36,0,0,54,18,0,54,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,36,18,18,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,31,127,0,127,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,0,0,0,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,42,21,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,42,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,105,127,105,21,0,21,0,0,0,0,0,0\n49,88,74,67,56,74,38,24,42,67,74,42,49,63,52,35,31,28,38,45,45,28,42,67,91,116,116,56,67,59,63,109,119,112,123,127,84\n0,63,42,0,0,0,42,21,21,0,0,42,0,0,0,0,0,63,21,42,21,105,127,105,42,42,0,21,0,21,0,0,0,0,0,0,0\n0,0,0,0,13,26,66,66,93,100,127,86,120,93,113,60,40,13,26,6,33,46,6,6,6,13,6,26,13,13,6,6,6,6,26,13,40\n0,0,0,0,0,0,0,0,0,0,0,0,36,72,127,36,0,18,0,0,0,18,18,0,0,18,18,0,0,0,0,0,0,0,0,18,0\n0,0,0,0,0,0,0,0,0,0,18,0,36,36,18,0,0,18,0,0,18,36,0,0,0,0,36,18,0,0,0,54,0,18,18,127,36\n0,0,0,0,0,0,0,0,0,0,0,54,127,18,18,0,0,18,18,18,0,36,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,18,0,0,18,0,0,0,0,18,0,127,54,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,0,0,0,0,0,0,95,63,63,127,0\n0,0,0,0,0,6,12,18,84,48,66,84,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,108,127,120\n0,0,0,0,1,2,0,2,1,6,12,22,34,71,81,74,104,127,100\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,7,14,21,35,127,24,17,17,0,3,7,3,0,0,0,0,3,3,7,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,11,80,127,69,14,11,2,0,2,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,35,91,52,43,96,17,87,127,30,8,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,0,50,76,0,101,50,127,0,25,25,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,3,3,7,11,7,7,11,127,111,23,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,8,8,0,33,0,8,0,127,50,84,50\n0,25,0,0,50,0,0,0,0,0,25,25,0,0,0,127,0,25,76,76,50,25,25,76,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,0,0,0,0,0,127,84,42,84,0,84,84,0,0\n0,0,0,0,0,0,0,0,0,0,0,13,127,43,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,6,33,116,60,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,15,108,43,6,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,12,3,3,46,127,43,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,72,127,9,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,54,108,9,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,127,2,0,4,3,2,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,127,10,0,5,5,2,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,63,0,0,0,0,21,0,0,0,0\n127,43,12,4,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,29,4,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n52,33,18,4,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,4,10,13,20,40,71,100,127\n127,74,30,9,4,0,0,2,0,0,0,0,0,0,0,0,0,4,0,0,0,1,0,2,0,4,2,0,1,2,0,1,1,1,1,3,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,21,21,63,127,42\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,0,0,2,8,8,8,51,127\n104,127,48,22,20,2,4,2,6,2,2,12,0,6,0,0,0,0,0,0,0,4,0,2,0,0,0,0,2,4,4,26,30,26,44,58,100\n127,74,20,12,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127,84,0,0,0,0,21,0,0,0,63,84\n127,87,31,7,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,7,23,31,71,15\n127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,39,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,42,95,127\n127,63,63,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,17,11,11\n63,127,10,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,105,105,84,127\n127,47,31,15,0,0,0,0,31,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,70,42,0,7,0,0,0,0,0,0,7,0,7,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,14\n127,63,47,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,42,10,5,26,15,10,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,69,34,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,84,0,42,42,0,84,42,0,0,0,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,127,127,127,127,127,0\n0,15,47,15,15,127,47,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n56,28,0,0,0,0,0,0,0,0,14,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,14,28,0,42,42,127,56\n72,127,54,18,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,18,18,18,0,0,0,0,0,0,0,36\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,0,0,12,12,38,127\n127,111,15,63,15,31,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0\n63,0,0,127,127,95,0,0,0,0,127,63,63,0,63,31,0,63,0\n127,45,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,127\n120,127,40,40,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,0,0\n127,28,20,14,2,0,0,0,2,2,2,0,2,0,0,0,2,0,5,0,11,14,2,11,2,2,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,63,21,0,0,42,84,127,21,21,42,42,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,50,76,25,127,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,14,28,56,0,14,14,0,14,0,0,0,0,14,0,0,0,14,28,127,98,56,0,42,28,0,0,0,0,0,0,0,0,0,0,0,0\n0,56,56,42,0,14,14,14,28,56,14,0,0,42,14,70,14,56,0,127,56,70,28,42,28,14,0,42,28,14,0,28,14,0,0,14,0\n79,127,71,39,15,15,7,7,7,15,0,0,0,0,23,15,15,23,15,0,23,15,31,15,0,0,7,0,0,0,7,0,0,0,0,0,0\n50,25,0,0,0,12,12,25,12,12,38,38,0,12,0,12,127,12,76,63,12,38,0,0,0,88,25,50,38,0,25,0,0,0,0,0,25\n0,0,84,0,0,0,0,0,0,0,0,42,42,0,0,42,0,42,127,42,84,42,84,84,42,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,31,0,0,0,0,0,0,95,95,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,28,127\n0,0,0,0,0,0,0,0,0,25,0,25,127,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,101,127,76,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,84,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,21,0,0,0,0,0,0,0,0,0\n127,82,39,26,27,25,21,8,7,15,8,8,6,3,2,0,0,1,0\n38,6,19,0,6,19,12,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,19,57,127\n84,84,63,0,63,63,63,42,0,21,127,42,42,63,63,127,84,21,42\n127,33,12,0,4,0,0,4,4,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,34,7,9,7,19,12,21,19,19,4,4,2,0,0,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,58,7,2,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,10,15\n127,127,26,21,21,21,15,31,26,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,81,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,103,63,31,31,15,0,15,7,0,0,0,0,0,0,0,0,0,0\n0,42,42,42,0,42,84,84,127,84,0,42,42,42,42,0,0,42,0\n67,0,16,8,16,127,76,0,8,33,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,76,25,0,0,0,0,127\n0,0,0,0,0,0,0,0,4,0,0,0,36,54,90,45,81,117,127\n0,0,0,0,0,0,0,0,0,0,0,0,14,14,127,28,28,14,0\n94,127,94,54,21,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,14,0,0,0,7,7\n0,0,0,0,0,0,0,0,0,0,0,12,12,101,50,127,25,63,38,38,38,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,21,105,63,84,127,63,0,21,0,42,42,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,9,0,0,9,29,127,29,78\n0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,127,63,31,0,31,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,42,63,0,127,0,42,21,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,21,10,21,52,63,52,127\n0,0,0,0,0,0,0,0,0,0,7,14,35,70,70,127,112,21,56,70,77,42,56,21,28,0,0,0,0,0,0,0,7,0,0,0,0\n15,0,0,0,7,7,15,15,23,23,79,127,31,0,7,7,15,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,3,0,0,7,7,11,7,3,3,7,3,0,11,3,3,3,0,0,7,0,3,7,44,85,82,127\n0,0,0,0,0,0,0,14,0,14,14,0,14,84,127,56,70,84,70,28,14,42,14,14,14,14,42,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,127,127,0,0,0,31,0,0,31,0,0,0,0,0,0,63,0,0,0,0,0\n0,0,0,0,0,0,2,8,5,8,13,32,37,62,127,64,54,51,70,59,32,40,27,16,18,29,8,5,18,8,2,2,2,2,13,10,10\n0,0,0,0,0,0,0,0,0,0,0,0,9,45,9,72,72,127,99,63,127,18,0,27,9,9,0,0,9,0,0,0,0,0,0,0,0\n7,14,7,7,3,10,3,0,3,3,21,39,58,72,90,101,116,87,127,123,79,79,39,32,7,0,0,0,0,0,0,0,0,3,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,28,0,28,127,28,0,14,28,56,112,70,70,84,28,84\n0,0,0,0,2,0,0,2,17,11,11,17,32,59,56,103,109,127,62,73,35,32,41,26,29,32,23,2,20,11,5,14,11,20,8,8,5\n0,0,2,0,0,0,2,4,7,4,7,9,12,14,27,42,59,82,127,97,74,57,42,32,2,4,4,2,0,0,0,0,0,0,2,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,0,42,0,0,0,0,0,0,0,0,0,63,0,0,84,42,84,84,127,63,42,21,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,54,54,127,72,36,54,18,0,0,0,0,18,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,6,40,6,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,20,127,60,20,33,20,86,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,51,40,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,34,11,28,5,0,0,11,127,34,17,28,5,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,31,31,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,21,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,105,42,127,21,0,0,0,0,0,0,0,0,0,0\n127,90,51,30,15,4,2,1,0,0,0,0,0,0,0,0,0,0,0\n93,81,45,47,23,16,13,10,3,4,2,3,0,1,0,2,0,0,0,0,0,0,4,4,3,1,2,0,2,1,1,1,4,3,4,13,127\n123,127,61,19,19,39,58,19,35,26,26,13,26,16,0,6,3,6,0\n127,79,111,15,31,15,15,0,15,15,0,79,0,0,15,0,0,0,0\n0,0,0,42,42,0,0,0,42,42,84,127,42,0,0,0,0,0,0,0,0,0,0,0,0,42,84,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,6,0,127,38,82,57,31,0,6,0,0,0\n127,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,95\n0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,40,127\n19,14,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,4,4,68,127\n127,80,46,20,12,6,4,2,1,0,0,0,0,0,0,0,0,0,0\n127,68,20,4,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0\n127,63,0,10,10,21,21,21,0,10,21,31,0,0,0,0,0,10,21\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,27,45,36,127\n127,72,15,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3\n127,56,10,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,26\n127,105,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0\n127,11,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n90,127,90,9,9,18,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,0,0,0,18,0,9,0\n127,36,39,3,9,12,9,9,15,0,3,0,0,6,3,6,0,0,0,0,0,0,0,3,0,6,3,6,6,0,0,0,0,0,0,0,0\n127,48,18,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127\n101,127,101,50,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n12,38,127,0,15,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,0,21,0,0,0,0,0,42,127,84\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,3,3,9,23,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,25,127,76,25,101,101\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,127,42,0,84,84,42,42,42,0\n0,33,127,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,127\n127,127,63,0,63,47,15,0,15,0,15,15,0,31,0,0,0,0,15,0,0,0,0,0,15,0,0,0,0,0,15,15,0,0,0,0,0\n127,22,40,18,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,27,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,15,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,11,11,0,0,0,23,0,11,0,0,0,0,0,0,23,11,11,0,23,46,57,127,103,69\n63,0,0,0,0,0,0,0,0,31,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,31,0,0,31,0,0,31,31,31,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,127,42,28,0,14,0,0,0,0,0,0,0,0,0,0,0,0,14,0\n72,9,0,54,127,72,45,54,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,7,0,28,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,25,25,101,127,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,0,0,42,42,0,42,42,42,127,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,42,0,0,42,0,127,127,84,42,84,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127,127,25,76,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,21,0,42,21,127,21,0,0,21,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,95,0,127,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,31,63,63,31,0,0,0,0\n0,0,0,0,0,0,18,0,0,36,36,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,54,0,127,0,0,36,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,63,127,127,0,0,0,0,0,0,0,0,0,0,127,0,63,0,0,0,63,0,127,0,0,63,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,14,0,0,0,0,0,0,0,0,28,98,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,28,42,127,98,56,0,0,28,28,28,0\n0,0,0,0,0,12,0,0,12,25,63,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,25,25,114,127,63,50,38,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,127,0,0,0,0,0,0,31,0,0,0\n0,0,0,0,42,0,0,0,0,0,0,0,0,42,127,42,0,42,42,84,127,42,42,42,0,0,42,0,0,42,42,127,0,0,0,0,0\n127,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,127\n127,88,76,19,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0\n127,111,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,42,63,0,0,21,42,63,0,0,0,21,0,21,21,0,0,0,0\n0,12,25,25,50,38,101,76,127,38,38,63,12,12,25,0,12,0,0,0,0,0,0,0,0,0,12,0,0,0,12,0,25,38,25,63,101\n127,45,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,36\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,127,31,31,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,84,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,42,105,21,0,0,0,0,0,0,0,0,0,0\n0,9,9,29,39,19,0,127,78,29,48,19,48,19,9,0,0,9,0,0,0,0,0,0,0,9,9,0,39,29,19,0,0,29,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,127\n23,51,63,127,34,46,51,46,63,46,28,11,40,11,17,5,0,5,11,17,5,11,0,0,11,0,0,0,0,0,0,5,5,5,5,5,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,7,0,27,127\n127,63,10,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n115,127,0,34,69,0,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,127,73,16,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,10,40,46\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,18,18,9,0,18,9,127\n127,44,6,12,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,38,63\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,29,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,127\n127,63,42,0,10,0,0,0,10,10,10,0,10,74,74,10,0,10,42,0,21,63,52,21,21,0,0,31,10,0,21,0,10,0,10,31,21\n0,0,0,0,0,0,0,0,0,127,0,0,21,21,0,0,0,0,0,0,0,0,0,0,0,42,21,0,42,0,0,0,0,0,0,0,0\n0,63,0,0,0,0,0,0,0,0,0,31,0,63,0,0,0,63,0,0,31,0,0,31,31,0,0,0,0,31,0,0,31,0,0,0,127\n0,0,0,0,0,0,0,0,0,0,0,0,39,39,55,127,87,111,111,79,15,0,0,15,0,0,0,0,0,0,0,0,0,7,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,84,127,63,21,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,127,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5\n127,76,12,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,127,50,0,63,76\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,127,0,127,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,61,127\n127,25,76,12,12,12,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,127,0,42,0,42,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0\n0,42,42,0,84,0,0,0,0,0,0,0,0,42,0,42,84,0,84,0,42,84,0,127,0,0,42,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,0,0,0,0,0,0,0,0,0,42,42,42,0,0,0,0,42,127,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,42,42,84,127,84,0,0,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,22,127,71,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,95,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,63,0\n127,31,95,127,63,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,127,63,127,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,25,31,38,127\n127,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,41\n0,0,0,84,0,42,42,0,42,0,127,127,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,12,12,12,0,0,0,0,0,0,0,38,25,25,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,5,15,127\n127,69,24,6,1,1,0,0,0,1,1,0,0,0,0,0,0,0,0,1,0,1,2,3,5,3,1,0,0,0,0,0,0,4,24,64,82\n42,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,21,105,127,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,6,33,127\n127,85,27,12,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,7,10,17\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,14,28,14,42,14,7,7,7,28,127\n63,31,31,23,7,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,7,15,63,87,127\n101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,12,12,0,101,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,58,127\n127,71,79,31,39,15,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,7,47,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,26,0,52,127\n0,47,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,79,31,127,63\n127,95,18,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,6,12,11\n127,70,18,37,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,48,48,52\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,43,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,0,0,0,54,36,0,0,0,18,0,36,0,0,0,0,0,54,127,127,90,0,0\n31,31,31,15,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,36,63,127,72,18\n36,18,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,36,18,36,72,54,127,18,0,36,36\n0,0,0,0,18,36,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,127,127,36,18,36,0,18,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,95,95,95,127,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n84,21,31,31,84,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,21,0,0,21,127,42,127\n127,61,22,3,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0\n68,127,73,9,14,4,0,0,0,4,0,0,0,0,4,0,0,4,0\n127,94,20,2,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,4\n72,72,18,36,18,127,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,0,31,31,127,63,63,0\n106,127,80,33,13,0,0,0,13,0,0,0,6,0,0,0,6,0,13,0,0,0,0,0,6,0,0,0,0,6,6,0,0,0,0,6,26\n127,66,79,53,34,12,12,3,3,9,0,3,3,9,0,6,3,0,3,6,0,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,7,7,0,0,55,127,63,0,7,55,95\n0,0,0,0,0,0,0,0,0,0,0,0,84,0,84,84,127,0,84,42,42,42,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,38,127,66,66\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,10,10,95,127\n63,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,31,127,63,31,0,0,0,0,0,0,0,0,0,0,0\n0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,4,19,19,58,102,127\n0,0,0,0,0,0,0,31,31,63,0,95,0,31,0,0,0,0,0,0,0,0,0,0,0,63,63,95,63,63,127,0,0,0,0,0,0\n127,47,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21\n0,95,127,63,63,63,63,31,31,0,31,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,0,31,0,0\n11,0,11,40,34,34,11,34,40,11,0,5,0,0,5,28,0,5,127\n127,95,31,31,31,0,0,0,0,0,31,127,31,0,0,0,0,0,0\n0,0,84,84,84,42,0,84,0,42,0,0,0,0,84,0,42,127,0\n63,63,63,31,0,0,31,0,0,0,63,95,127,31,63,95,63,0,0\n28,28,14,0,28,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,0,14,0\n101,101,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,101\n127,75,61,34,20,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,4,4,7,16\n127,50,12,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,6,0,0,0,0,6,82,88\n127,49,35,49,42,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,35,14,56\n63,127,42,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,21,31,84\n127,84,21,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,10,31,84\n127,60,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,62\n127,78,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,22,58\n127,57,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,6,127,127\n127,55,11,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,127\n127,86,68,37,35,26,18,13,7,10,16,0,1,1,0,0,1,3,0,0,0,3,4,2,2,3,0,1,3,10,8,14,12,17,29,26,24\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,9,11,13,2,2,6,0,13,24,4,29,27,27,24,52,127\n63,127,95,0,31,0,0,0,0,0,31,63,31,63,31,31,0,0,0,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,26,127\n127,77,39,17,4,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,13,37\n127,70,28,37,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,5,31,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,72,0,72,0,72,127,18,36\n127,84,38,15,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,6\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,4,4,2,0,4,6,25,63,127\n76,25,12,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,25,127\n88,127,38,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,28,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,7,14\n0,0,0,0,0,0,0,0,0,0,0,14,14,14,0,28,28,56,84,127,56,28,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,31,0,0,0,0,31,0,0,31,0,0,31,0,0,0,0,31,0,63,63,0,0,31,0,0,0,0,63,63,31,0,0,0,95,127\n31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,79,47,111,95,127,63,31,15,47,31,63,47,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,63,0,0,0,63,127,127,127,127,127,127,127\n127,58,14,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,85,83,35,11,4,2,2,0,0,0,0,0,1,0,0,0,0,0\n127,38,6,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,103,55,23,31,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,25,0,50,0,0,25,25,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,63,84,127\n127,46,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n88,44,41,127,63,19,28,9,3,0,3,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,34,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,55,127\n127,54,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127\n127,105,0,0,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,95,47,15,15,79,31,0,15,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,31,0,0,0,15,63,0,47,31,127\n118,127,100,38,35,8,8,5,0,0,2,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,5,5\n84,42,0,0,42,127,0,42,0,0,0,0,0,42,0,42,0,0,42,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n31,31,127,31,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,97,57,27,10,2,0,0,0,0,0,0,0,0,0,0,0,0,0\n14,14,7,7,4,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,49,127\n127,48,23,8,9,7,6,3,12,5,6,2,1,0,0,0,0,0,0\n127,57,0,28,11,0,5,0,0,0,0,5,0,0,0,0,0,0,0\n0,36,18,36,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,54,0,18,0,0,0,0,0\n127,90,90,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,13,9,5,21,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,29,57,127\n127,63,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,12,63,127\n63,26,2,12,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,4,34,127\n72,127,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0\n8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,39,52,127,122\n105,31,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,42,21,42,116,127\n84,42,127,84,84,42,0,0,0,0,0,0,0,0,0,0,84,0,42,0,42,42,42,42,42,84,0,42,42,42,0,0,0,0,0,0,0\n56,68,72,70,73,80,90,90,97,111,109,127,122,106,101,86,80,84,85\n109,98,109,76,54,45,54,21,26,12,26,31,7,24,21,19,29,34,48,45,61,78,127,92,84,96,69,89,100,76,35,9,2,3,1,0,2\n0,0,0,1,1,2,4,5,7,2,1,22,35,71,96,105,102,109,127\n2,19,47,43,26,10,7,5,5,1,8,65,127,16,7,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,10,26,37,67,46,15,24,19,31,31,42,68,127,104,24,15\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,127,127,63,0,63,63,31,0,0,0\n0,50,0,0,0,0,25,0,0,0,0,25,25,0,25,0,0,0,50,50,76,25,25,76,50,127,0,101,50,25,25,50,0,0,0,0,0\n46,127,69,69,11,0,0,11,0,0,0,0,0,0,0,0,0,11,11,34,23,0,103,92,69,80,57,92,34,80,0,23,0,0,0,0,0\n8,48,127,83,17,13,26,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n31,0,111,127,127,15,15,63,31,0,0,0,0,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,14,21,9,11,37,58,127,96,28,28,7,2,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,30,127,91,76,40,30,10,20,5,10,10,5,0\n127,39,39,23,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,23,23,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,63,0,127,0,31,31,63,31,31,0\n90,27,36,127,27,9,9,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n101,76,127,76,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,2,13,31,71,119,127,81,25,12,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,6,2,12\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,74,50,127\n0,0,0,0,0,0,0,0,0,33,42,127,67,16,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,21,21,0,105,84,127,105,42,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n7,7,11,19,7,0,2,0,9,26,23,127,62,4,4,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,7,4,47,57,14,11,21,23,0,0,0,0,11,14\n7,5,2,0,7,7,5,10,7,28,36,114,49,7,5,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,5,98,127,44,10,15,12,0,2,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127,25,25,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,50,0,0,0,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,25,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,21,21,42,21,21,0,0,0,0,0,0,0,0,0,0,21,0,42,42,21,21,42,42,127,42,0,0,0,21,21,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,25,50,0,0,25,0,0,0,0,0,0,0,0,0,0,0,25,0,0,25,50,50,127,25,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,34,80,57,46,23,0,11,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,11,115,115,127,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,34,23,11,34,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,8,59,33,33,8,25,16,0,0,8,0,0,0,0,0,0,0,0,0,0,0,8,8,42,59,93,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,8,33,0,8,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,63,0,0,0,0,0,0,0,0,0\n0,42,0,42,0,0,42,0,42,42,84,127,84,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,0,0,0,0,42,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,12,12,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,31,31,0,0,0,0,0,0,0,0,0,0,31,0,0,31,0,127,95,31,0,0,31,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,21,127,116,74,21,31,10,10,0,10,0,0,0,0,0,0,0,0,0,0,10,0,0,10,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,10,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,10,10,52,127,127,63,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,10,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,109,59,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,2,17,28,54,70\n127,50,50,38,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n97,127,48,9,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,19,39,39,48,9,29,39,58\n127,49,46,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,61,6,2,2,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,27\n127,127,21,0,21,0,42,0,0,0,0,0,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n47,0,0,7,0,7,0,15,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,7,0,0,15,79,127\n21,10,21,0,10,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127\n127,19,0,3,0,3,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n95,47,127,95,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,8,40,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,4,28,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,5,27,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,2,20,127\n0,0,0,0,0,0,0,0,0,0,0,25,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,25,50,0,76,127,50,0\n127,28,0,14,35,0,7,14,7,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,42,127\n127,84,26,0,5,0,0,5,0,5,0,0,0,5,0,5,10,5,10,26,26,5,21,37,37,15,5,5,10,0,0,0,0,0,0,5,0\n50,0,0,0,76,127,25,76,0,25,0,0,0,0,0,0,0,0,25,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,25,12,25,114,127,63,63,25,38,38,38,25,25,0,0,0,0,12,12,12,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,95,127,0,0,31,31,0,0,0,31,31,0,0,0,0,0,0,0,0,0,0\n0,0,10,0,10,10,21,31,0,0,0,0,0,10,127,10,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,6,13,43,90,110,127,20,13,16,6,6,3,6,10,6\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,127,14,84,70,28,70,0,0,14,56,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,10,0,0,10,37,42,68,79,84,127,37,95,63,37,10,37,37,21\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,42,21,42,127,84,21,84,105,0,21,0,0,42,105,84\n0,0,31,0,0,0,0,0,31,0,0,0,0,31,0,0,0,31,0,0,0,0,127,63,127,95,0,0,0,0,0,0,0,0,0,0,0\n127,0,127,63,127,63,0,0,0,0,0,0,0,63,0,0,0,127,63,63,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,28,0,7,0,21,35,35,127,63,63,14,14,28,7,0,0,7,0,0,0,0,0,0,0,0,0\n7,14,7,14,10,7,7,10,14,0,3,3,10,18,72,127,7,3,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,18,0,0,0,0,72,36,0,0,18,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,88,127,76,38,50,0\n0,25,0,0,25,0,25,0,0,25,0,0,0,25,25,25,0,0,25,25,25,127,25,0,25,50,0,0,25,25,25,25,0,25,0,0,0\n127,84,42,42,0,42,0,0,21,0,0,0,0,0,42,21,42,42,21,21,63,21,84,0,21,0,0,0,0,0,21,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,50,38,127,76,88,25\n42,0,21,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,0,127,21,0,0,0,0,0\n47,71,127,71,47,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,31,10,0,10,42,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,16,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,9,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,45,127\n127,84,21,42,0,10,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,10,10,0,63\n127,87,63,7,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,52,63,127,127\n0,0,0,42,127,0,0,84,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,42,84,42,42,84,84,84,127,42,84,84,0,127,84\n127,63,11,3,0,0,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,0,3,15,27,39,31\n127,46,23,14,2,0,0,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,2,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,0,0,63,95,0,0,95,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,6,25,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,95,0,31,63,0,127,31,63,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n42,42,31,21,21,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,10,0,0,0,0,0,0,10,0,0,0,0,10,0,31,0,10,63,95,95,127,105,63,42,10,10,0,10,0,0,10,0,0,0,0,0,0,0,0,0,0,0,10,10,63\n70,63,21,7,14,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,21,0,7,7,0,0,0,0,0,0,7,0,0,0,7,0,14,14,21,56,127,112,63,63,35,28,14,21,0,0,0,0,0,0,0,0,0,0,0,0,14,0,7,14,14,56\n0,0,0,0,0,0,10,0,0,10,10,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,10,0,0,0,10,127,10,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,10,0,0,0,0,127,52,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,9,0,127,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n18,72,54,54,127,108,36,36,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,18,18,0\n36,0,54,54,127,127,72,18,54,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,72,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,127,42,42,84,0,0,84,0,42,0,84,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,25,25,50,50,50,127,25,76,25,76,0,0,25,0,25,0,50,25,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,21,63,42,21,21,63,84,42,105,63,42,127,42,0,0,42,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,63,0,0,127,63,63,0,0,31,0,0,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n42,0,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,42,127,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,1,0,0,0,1,0,0,1,11,3,11,17,14,8,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,20,50,51,48,26,29,11,4,4,3,0,2,2,0,1,0,0,0,0,2,11,17,36,79,122,127,87,33,12,6,2,0,2,0,0,0,0\n0,2,0,0,0,3,1,1,1,1,6,10,17,9,10,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,24,43,37,48,40,19,17,9,2,3,1,0,0,0,1,0,1,0,1,2,7,7,25,80,106,127,69,43,18,14,3,1,6,0,1,0,0\n0,0,11,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,11,23,0,23,0,0,11,11,0,0,0,0,0,0,0,0,0,0,0,0,11,127,69,0,11,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,15,15,0,0,31,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,31,15,0,15,15,0,15,0,0,15,15,0,0,0,0,0,0,0,0,0,127,95,47,15,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,15,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,31,15,15,0,15,0,15,15,31,15,15,0,15,0,0,0,0,0,79,79,63,95,127,95,15,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,31,0,15,15,0,0,0,0,0,0,0,0,15,0,0,15,0,0,0,31,111,63,127,95,63,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,5,0,0,0,5,21,121,127,21,5,0,21,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,5,0,0,20,30,91,127,45,15,10,25,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,4,0,0,0,0,0,8,0,0,61,127,20,12,0,0,0,0,4,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,25,0,127,76,127,127,101,50,101,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n5,13,1,0,0,1,0,1,4,25,63,68,25,1,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,6,5,10,56,127,49,13,6,4,2,4,0,13,4,1\n1,14,0,1,0,0,0,1,10,32,71,75,33,5,3,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,3,5,14,60,127,55,46,14,5,1,3,14,7,0,0\n0,0,0,0,0,0,0,0,0,0,15,31,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,127,95,79,0,31,15,15,0,0,0,0,0\n0,0,0,0,0,0,0,0,12,12,88,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,25,25,38,127,38,12,12,25,12,0,0,0,0\n0,0,0,0,0,10,0,0,10,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,10,21,95,127,42,10,10,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,127,127,15,31,0,15,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,5,6,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,6,7,62,127,57,11,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,3,5,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,9,91,127,46,11,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,10,10,10,0,10,0,0,0,10,10,0,0,0,0,0,0,0,0,0,0,0,10,21,31,127,95,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,9,9,0,0,0,0,0,0,0,0,0,0,0,29,0,58,127,58,19,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,59,22,127,74,7,37,0,0,0,0,22,14,7,7,14,7,0,0,7,0,29,37,44,97,97,44,29,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,31,111,111,15,63,79,0,0,0,0,0,15,0,0,0,0,0,0,0,0,63,95,79,127,95,95,47,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,1,5,12,24,44,41,14,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,12,27,55,42,38,38,21,13,6,2,0,0,0,0,0,0,2,0,0,0,0,3,14,37,99,127,85,64,32,13,2,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,21,17,30,39,48,17,0,4,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,21,48,56,52,91,48,30,17,0,4,0,0,0,0,0,0,0,0,0,0,0,0,13,21,83,127,105,65,21,0,4,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,31,0,15,0,0,0,15,47,0,0,0,15,0,0,0,0,0,0,0,0,0,0,31,0,31,63,127,31,31,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,127,0,127,42,0,0,0,0,0,0,0,0\n0,0,0,4,4,0,4,18,42,47,94,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,9,9,32,117,127,9,9,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,12,50,76,38,12,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,25,88,114,127,12,0,12,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,56,56,127,28,14,0,0,0,0,0,0,0,0,0,0,0,0,0,42,56,56,28,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,12,38,101,63,50,0,0,0,0,0,0,0,0,0,0,0,0,12,12,127,101,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,111,111,127,47,0,0,0,0,0,0,0,0,0,15,0,0,15,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,4,9,9,9,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,24,29,39,43,19,9,0,0,0,0,4,0,0,0,0,0,0,0,0,0,9,14,29,127,73,39,14,4,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,6,12,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,24,42,36,36,42,6,0,0,0,0,0,0,0,0,0,0,0,6,6,0,0,78,60,127,102,36,42,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,14,0,127,70,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,9,15,0,0,12,0,6,41,120,101,31,6,0,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,12,9,0,25,107,127,107,41,28,12,3,0,0,0,0,3\n2,0,0,0,2,0,0,4,9,27,55,32,13,4,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,4,6,0,4,18,60,127,71,36,13,11,9,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,25,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,127,0,76,76,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,50,50,127,101,0,25,25,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,12,38,101,12,25,12,0,12,0,0,0,0,0,0,0,0,0,0,12,0,50,88,127,38,50,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,15,47,47,111,0,47,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,111,127,31,47,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,15,15,0,31,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,31,63,31,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,127,79,79,15,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,127,127,127,63,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,63,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,63,127,114,50,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,95,127,63,63,0,0,0,0,0,0,0\n72,30,18,0,12,18,18,12,12,30,12,54,30,54,78,127,102,30,54,48,0,12,24,12,30,0,6,0,0,0,6,0,0,6,6,36,36\n0,0,0,127,84,42,0,0,84,42,0,84,42,0,0,42,0,42,42,84,127,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,35,35,28,14,7,0,7,0,7,0,14,14,0,35,35,49,91,119,84,70,14,7,0,0,7,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,54,0,54,72,72,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,18,0,127,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,51,5,5,5,17,86,28,69,98,92,127,103,51,69\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,4,56,127,39,4,0,0,0\n0,0,21,0,21,21,42,0,0,21,0,42,63,21,127,63,21,84,0,0,0,0,0,0,0,0,21,0,42,21,0,0,21,0,0,21,84\n50,101,25,25,0,0,0,0,0,0,0,0,0,50,25,25,25,25,0,76,127,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n10,0,0,0,0,0,5,0,0,0,10,5,0,15,63,31,47,42,127,37,58,15,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,21,8,8,8,16,12,16,4,0,0,4,0,0,0,0,0,0,4,8,8,8,4,0,25,71,127\n0,31,0,63,31,0,63,0,31,0,0,31,127,63,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,21,0,21,21,0,21,0,0,21,63,127,105,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,3,6,9,18,12,12,0,9,27,57,123,127,57,27,12\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,24,87,127,71,26,4,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,39,58,127,87,68,19,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,70,127,127,14,14,0,0\n0,0,0,0,25,0,25,25,0,0,25,25,25,50,76,127,76,0,50,25,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,11,0,0,0,0,17,11,34,40,34,86,127,103,86,75,75,51,23,17,34,23,11,17,5,23,5,11,0,11,28,34,11,34,127\n14,7,0,7,0,0,0,0,0,14,28,21,42,14,35,28,84,77,127,56,42,35,14,14,7,0,0,0,0,0,0,0,0,0,0,7,0\n0,0,0,0,0,0,0,0,0,0,10,10,0,31,74,74,42,31,10,52,31,10,31,10,0,0,0,0,0,0,42,21,21,10,31,52,127\n0,0,0,0,0,15,0,0,0,0,0,0,15,47,95,127,95,0,111,47,15,47,47,0,0,0,0,0,0,0,0,0,0,0,47,0,31\n0,0,0,31,127,15,15,0,47,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,42,42,42,84,84,127,0,0,127,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,14,9,23,9,9,14,23,56,127,117,32,9\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,8,0,4,8,4,20,45,127,106,73,20,8\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,12,25,0,0,0\n0,0,0,0,0,0,0,0,0,63,127,127,63,127,0,0,127,63,63,63,63,63,0,63,63,63,0,63,0,0,0,0,127,0,127,63,0\n0,19,9,9,0,48,68,19,29,19,19,39,127,87,48,58,29,68,19,97,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,127,42,42,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,84\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,95,63,63,31,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n101,96,67,62,62,67,87,109,127,76,29,8,3,1,0,0,0,0,0\n94,85,43,38,38,59,71,107,114,127,69,23,12,3,4,2,0,0,0,0,1,0,2,4,1,3,2,3,2,1,0,0,3,3,2,2,0\n12,9,9,3,3,9,12,15,41,22,38,19,41,82,76,98,69,111,127\n0,10,3,4,1,10,13,25,33,74,92,127,116,98,98,78,68,83,69\n8,4,4,0,0,8,0,0,25,67,50,59,127,114,127,80,84,63,50,46,50,16,29,38,63,42,12,0,0,0,0,0,0,4,0,4,0\n0,0,0,0,0,0,0,0,0,0,1,8,20,29,42,65,117,122,127\n127,31,84,42,21,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,43,26,30,13,0,10,0,20,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,11,3,78,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,20,26,8,2,4,8,11,29,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,16,55,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,0,0,0,127,127,127,0,42,0,0,0,0,42,0\n127,21,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,43,48,6,4,2,0,4,4,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,15,1,5,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,117,96,73,64,63,64,62,40,34,24,14,9,5,5,4,3,3,5\n127,97,69,42,30,23,26,24,26,21,15,12,7,7,5,3,3,3,3,3,3,5,4,6,5,5,7,4,1,1,0,0,0,0,0,0,0\n59,52,67,37,82,29,37,14,37,7,7,22,14,37,127,74,74,37,44\n10,3,0,0,0,0,2,9,5,11,46,80,89,102,101,127,117,101,88\n117,127,87,58,48,48,9,9,19,29,19,0,9,0,0,0,0,9,0\n127,31,42,42,42,0,31,10,0,0,10,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n19,97,127,48,117,68,19,19,0,0,19,0,9,29,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,24,6,11,4,6,0,4,0,11,22,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n21,10,10,21,31,127,31,63,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,5,6,11,8,13,16,15,18,43,49,44,43,63,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,10,10,5,10,2,5,12,55,127,66,35,12,35,15\n127,113,109,88,97,105,115,106,112,79,54,41,30,14,14,9,6,8,0\n120,127,110,92,70,39,24,20,14,14,14,10,11,6,4,2,1,5,6,5,6,16,11,10,3,3,3,2,6,7,6,2,0,0,0,0,0\n0,0,0,31,0,0,95,95,63,127,127,63,0,31,0,0,0,0,0\n0,13,2,2,8,16,13,8,8,5,18,51,62,94,81,86,91,127,97\n127,47,47,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,72,0,18,18,36,27,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,53,46,11,3,5,13,15,22,18,12,8,34,127\n127,64,27,11,6,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,3,0,0,0,1,0,2\n44,29,7,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,82,123,127\n15,23,9,7,6,1,0,1,0,0,6,11,9,3,14,3,9,6,1,3,7,6,7,9,9,14,17,11,11,4,3,1,12,9,34,53,127\n127,11,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n68,64,109,127,47,5,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,63,127,31,95,63,31,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,31,47,31,63,127,127\n6,6,0,0,3,0,0,0,0,3,6,6,3,3,0,3,6,3,0,3,3,0,0,6,13,17,3,0,6,3,17,6,17,20,37,127,116\n127,21,25,8,2,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,118,101,50,8,4,0,4,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,76,82,26,7,10,5,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,5,2,5\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,14,28,37,70,127\n0,2,0,5,7,4,5,7,3,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,0,5,0,1,4,15,19,44,112,127\n127,74,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,88,84,21,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,22,18,52,127\n0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,11,17,11,5,5,5,0,0,28,34,103,127,103\n127,39,4,4,14,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,21,21,42,127,63,84\n0,0,0,0,42,0,0,0,0,42,0,42,0,0,42,0,42,0,0,84,84,0,0,84,0,0,0,0,127,0,0,84,0,42,0,42,84\n127,63,0,105,105,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,25,25,25,0,25,25,25,50,0,25,0,0,0,0,0,25,25,127,0,0,0,0,50,0,25,0,76,25,25,0,0\n0,0,0,9,11,9,5,39,66,85,127,80,42,19,9,1,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,1,0,5,15\n50,127,101,50,76,25,50,101,76,101,101,76,101,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0\n112,106,115,127,106,105,115,114,123,103,79,62,50,15,11,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,7,15,18,15\n0,15,31,15,47,63,127,47,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,101,101,127,101,25,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n108,127,90,54,72,36,72,54,36,72,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,54,36\n0,18,18,18,18,54,18,18,0,36,0,127,36,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n5,5,13,10,29,18,60,63,127,108,55,26,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,31,0,63,0,31,95,127,31,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,95,47,63,31,63,111,47,111,127,111,95,31,31,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,23,34,69,69,46,127,103,69,80,103,103,57,127,115,127,57,46,11,34,11,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n5,5,0,0,0,0,0,5,0,0,5,52,127,52,79,10,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,15,5,0,0,5,0,0,0,0,0,0,0,0\n0,0,0,0,0,6,0,6,0,6,6,80,127,73,20,0,6,0,6,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,6,0,0,6,0,0,6,0,0,0,0,0,0\n31,47,15,0,95,47,31,111,47,95,15,47,0,111,63,31,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,15,15,127,79,63,15,47,31,47,15\n11,23,0,92,34,69,46,80,46,92,11,34,23,127,46,23,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,23,23,11,34,80,34,34,23\n0,0,0,0,0,0,0,15,15,0,63,47,127,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,7,7,29,7,22,14,0,7,0,7,29,0,0,0,14,0,0,0,0,7,7,14,29,37,74,127,37,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,7,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,23,11,34,34,46,34,23,11,11,0,0,0,0,0,0,0,0,0,0,0,11,11,34,69,103,92,127,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,3,12,12,34,34,34,21,30,27,21,52,37,52,49,89,68,86,127,111,92,34,15,9,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,3,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,29,32,44,23,44,32,59,44,41,29,73,79,56,85,118,112,127,50,56,26,20,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,0,0,0,2,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,2,8,45,118,127,37,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,5,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,2,0,0,2,13,43,127,116,37,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,5,0,0,0,0,0,0,0,0,0,0\n7,15,0,0,23,55,7,7,15,39,23,0,7,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,55,71,127,63,55,7,15,23\n0,18,0,0,0,90,18,18,0,36,36,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,127,72,72,108,36,36,18,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,36,54,108,18,36,72,54,18,18,127,72,18,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,25,50,25,25,127,101,25,101,25,25,25,76,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,42,42,127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,127,111,15,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,63,21,63,21,21,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,21,42,42,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,0,42,42,0,0,0,0,0,0,0,0,42,0,84,42,127,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,12,0,0,0,0,12,12,50,88,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,38,25,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,31,31,31,31,31,95,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,0,0,0\n0,0,0,0,0,21,0,21,42,105,127,0,0,0,0,0,63,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,21,42,0,42,0,0,0,0,0,0\n0,0,0,36,0,0,0,36,54,72,127,90,36,18,0,18,54,18,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,36,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,14,14,42,7,14,0,0,0,0,0,0,0,0,0,0,7,21,63,14,49,49,63,127,49,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,11,34,11,23,57,46,0,34,0,0,0,23,0,0,0,0,0,11,34,34,23,46,103,127,46,46,11,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n7,0,0,0,0,23,39,15,79,119,127,63,39,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,7,39,23,15,7,7,23,0,7,0,0\n0,12,0,0,0,0,19,12,38,95,127,82,44,0,0,6,6,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,6,0,0,0,6,12,31,0,25,6,12,0,0,0,6\n0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,127,42,0,0,42,0,0,0,0,42,0,0,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,42,42,42,127,42,0,42,0,0,0,0,0,42,0,84,42,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,53,22,4,1,0,4,2,1,5,1,2,1,0,0,1,4,1,0\n127,93,35,30,22,17,7,7,7,5,12,20,10,15,12,0,2,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,0,0,31,0,63,0,127,95,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,10,0,0,0,31,116,127\n127,23,3,3,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,28,6,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n105,31,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,10,0,10,21,127\n0,63,0,0,63,0,0,0,0,0,0,0,0,63,0,127,0,0,0,63,0,0,0,63,63,63,63,0,0,0,63,0,63,63,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,12,55,127\n127,23,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,105,21,10,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n63,31,127,31,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0\n127,63,63,63,63,127,0,63,31,0,0,0,0,0,0,0,0,0,0\n3,6,7,11,18,29,60,118,127,117,98,68,29,8,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,2,11,27,26\n0,0,0,0,0,21,0,21,21,0,84,42,21,127,84,63,0,21,84\n0,0,0,0,0,0,0,1,2,2,3,8,9,15,30,46,77,99,127\n127,42,63,42,52,116,42,63,42,10,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42\n0,0,0,0,0,0,0,0,0,0,0,2,6,8,8,17,26,72,127\n0,0,0,0,0,0,0,0,0,0,0,0,9,27,86,99,99,127,45,45,27,13,27,18,13,9,0,0,9,0,4,4,0,9,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,10,42,127\n0,0,0,0,0,0,0,0,0,10,10,127,127,13,3,13,3,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,2,0,1,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,63,34,34,69,103,127,92,86,69,92,109,75,40,86,40,17,34,28,17,5,5,0\n6,4,5,8,10,10,6,7,11,9,40,127,77,15,7,3,2,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n24,0,0,6,12,6,30,12,54,24,54,72,127,12,0,0,6,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,42,0,0,0,42,127,0,127,84,0,0,42,0,0,0,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,1,1,4,7,21,67,114,127,75,26,9,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,6,11\n0,0,0,0,0,0,0,0,0,21,0,63,21,21,21,127,21,63,0\n0,0,0,0,3,2,2,6,4,7,16,21,29,49,66,87,125,127,121\n0,9,0,0,0,0,0,0,0,0,0,9,9,18,18,32,51,70,127,122,89,61,47,14,9,4,4,0,0,4,0,0,14,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,42,105,127,75,117,75,90,66,33,24,0,6,3,0,0,9,15,9,3,0,3,6,6,12\n19,9,4,19,34,29,39,53,73,73,83,34,4,9,34,127,63,9,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,1,0,1,1,3,6,30,38,80,127,126,82,54,25,12,6,3,2,0,0,0,0,1,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,10,74,31,31,84,63,63,74,31,52,52,10,10,31,127,31,52,52,10,21\n3,1,1,2,7,6,6,5,10,23,73,127,68,14,3,1,2,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,63,63,63,31,0,31,63,127,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,6,1,8,11,13,21,36,45,61,102,113,127,83,74,48,33,24,8,3,2,4,1,1,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,95,95,63,63,0,63,0,0,0,0,0,0,0,0,0,63,127\n0,11,11,46,11,11,0,92,80,127,92,57,11,0,0,11,11,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n43,9,4,1,3,3,11,13,18,12,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,5,0,2,2,3,29,127\n0,0,0,0,0,9,0,0,0,0,29,9,19,19,48,127,87,107,97\n0,0,0,0,0,0,0,7,0,7,7,0,14,44,67,59,127,97,119\n8,4,4,6,2,6,4,2,20,12,29,52,41,97,83,127,127,122,62\n0,0,0,14,0,0,0,0,0,0,7,14,7,7,14,0,49,70,127\n5,27,11,12,5,5,4,6,1,4,15,4,15,18,15,40,30,50,61,78,127,69,40,15,6,0,1,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,63,127,95,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,1,3,3,9,21,42,73,116,127,123\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,21,21,63,42,21,0,21,127,42,105,63,42,42\n8,12,29,50,59,114,93,127,59,29,16,4,8,25,33,12,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,5,18,13,10,26,15,39,42,44,23,23,39,31,52,68,97,124,127\n8,4,4,10,6,8,2,8,10,2,8,2,19,12,21,38,58,55,127,111,114,71,60,21,40,8,2,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,1,2,1,5,14,13,20,20,29,46,100,127,108,105\n0,63,63,0,127,63,63,127,0,0,0,63,0,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,9,0,0,0,0,9,9,54,127,36,0,18,9,0,9,0,0,9,18,9,9,0,0,0,9,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,9,9,0,0,0,0,0,0,0,0\n0,0,0,0,0,10,0,0,0,0,0,10,0,74,127,31,0,21,0,0,0,0,31,21,21,10,10,0,0,0,10,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,10,10,0,0,0,0,0,0,0,0,10\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,7,31,39,127,95,15,31,7,7,23,7,0,0,0,0,0,0,0,0,0,0,0,15,15,23,31,55,63,7,0,31,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,9,9,0,45,45,127,90,36,18,18,9,0,0,0,0,0,0,0,0,18,0,9,0,0,0,0,9,18,54,81,0,0,18,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,2,3,53,127,24,7,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,2,2,1,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,3,5,50,127,23,8,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,2,0,0,0,0,0,0,0,0,0,0\n0,0,4,0,0,0,4,8,49,24,20,57,127,73,73,69,8,0,12,12,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0\n0,0,2,0,0,0,2,0,0,2,8,37,127,40,49,37,0,0,8,28,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,2,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,3,0,0,0,0,37,127,34,10,3,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,3,43,127,32,10,3,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,42,84,127,105,0,0,0,21,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,36,18,127,0,54,18,18,0,0,0,0,0,0,18,0,18,18,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,7,39,127,87,15,15,0,0,23,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,7,23,0,23,103,63,47,7,7,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,28,127,70,23,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,18,0,4,9,14,56,47,14,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,23,46,46,57,23,80,46,57,92,80,46,23,23,23,0,0,11,0,11,23,34,46,23,34,11,23,0,0,0,11,0,0,0,0,0,0,0,0,34,11,0,11,11,23,34,46,127,69,69,23,23,11,11,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,11,46,46,46,46,69,127,57,34,34,11,23,11,0,0,23,34,0,11,11,34,0,34,11,34,0,0,0,0,0,0,0,0,0,0,0,0,11,0,11,0,0,69,23,92,80,103,92,34,23,34,11,11,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,42,0,127,28,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,10,0,0,3,3,13,0,6,54,127,54,27,10,10,10,0,17,44,13,3,3,0,0,0,0,0,0,0,0,0,0,3,6,6,3,0,3,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,11,3,0,0,0,19,3,27,63,127,91,31,19,3,0,3,3,23,11,3,0,0,0,3,0,0,0,0,0,0,0,0,7,19,7,3,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,5,44,127,33,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,4,6,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,1,4,47,127,29,2,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,5,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,14,28,127,98,28,28,0,42,0,0,28,14,70,14,42,70,56,28,0,42,70,42,28,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,14,0,42,14,28,14,14,14,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,9,19,68,127,58,58,9,48,19,0,19,29,19,9,29,19,0,9,0,0,19,78,19,19,0,0,0,0,0,0,0,0,9,0,0,0,9,0,0,0,9,0,19,9,9,19,9,29,19,9,29,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,0,0,0,0,2,17,127,10,2,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,17,0,0,0,0,3,52,127,12,3,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,84,84,0,0,0,127,84,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,42,0,42,0,0,42,0,42,84,42,0,0,84,84,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,0,42,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,31,31,63,63,127,63,0,0,0,0,0,0,0,31,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,50,25,127,101,50,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0\n127,123,72,58,27,26,20,3,1,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0\n91,127,79,79,62,28,26,28,16,19,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n42,127,63,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,31,0,63,127,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n42,0,42,21,21,42,21,84,127,42,42,21,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,84,0,0,21,84,84\n76,25,50,0,0,0,0,50,50,76,50,0,0,0,25,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,25,50,50,50,50\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,58,52,42,74,127,105,79,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,50,50,76,127,114,88,76,38,63,38,12,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,12,0,0,0,0,0,0\n127,0,0,0,0,0,84,84,84,0,42,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,42,0,0,0,0,42\n0,0,0,0,0,50,0,76,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,50,0,0,0,0,25\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,127,76,76,0\n4,5,7,8,5,9,6,10,10,9,10,19,26,32,53,54,75,127,119\n123,51,17,24,6,10,20,13,3,0,6,3,3,10,6,48,68,68,92,102,116,127,102,82,41,34,20,13,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,4,8,4,25,67,63,78,120,93,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,33,80,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,127,101,76,76,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,101,127\n0,0,28,127,42,14,0,0,0,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,18,0,0,0,0,0,0,0,0,0,36,127,90,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,14,42,0,0,0,14,0,0,0,28,42,127,42,14,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,31,0,0,31,0,0,0,31,63,0,31,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,0,127,108,18,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,127,59,2,0,0,0,0,0,0,0,0,0\n0,3,3,0,3,0,0,7,19,30,34,127,107,30,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,3,0\n63,63,108,54,36,0,0,0,9,9,0,63,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,90,0,9,63,18,0,0,0,0,0,127\n18,6,0,0,12,0,0,0,0,0,30,66,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,127,18,0,0,6,0,0,0,0,6,0\n25,0,0,127,50,0,0,0,0,0,0,76,25,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,0,0,0,0,0,25,0,25,0\n0,0,0,0,0,0,0,0,0,42,42,42,127,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,127,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,18,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,54,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,7,14,14,18,52,108,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,63,127\n127,36,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,12,12,127\n101,50,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,12,12,6,0,127,101\n0,0,0,0,0,0,0,0,0,0,2,8,59,94,99,10,8,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,27,29,113,127,75,16,16,0,0,0,8,2,0,2,0,0,0,0,0,0,24,18,29,54,86,108,48,2,5,2,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,5,0,0,5,31,31,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,15,10,52,127,47,21,15,0,10,0,10,5,0,0,0,5,0,0,0,0,5,63,5,26,52,95,68,5,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,127,127,84,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,76,127,50,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,54,36,54,127,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,3,127,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,18,90,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,79,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n24,34,3,0,0,0,0,0,3,0,12,15,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,30,127,21,12,0,3,0,3,3,18,34,12\n0,0,0,0,0,0,0,0,0,0,0,29,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,4,0,63,127,24,14,4,0,0,9,19,4,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,4,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,57,127,28,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,55,127,25,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,10,5,15,100,100,95,52,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,10,15,47,74,127,68,68,0,84,42,0,10,0,0,0,0,0,0,0,0,0,0,5,63,15,42,63,79,5,10,0,0,0,5,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,84,70,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,127,84,127,98,56,14,0,28,0,0,0,0,0,0,0,0,0,0,0,28,28,0,14,28,70,28,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,31,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,127,63,31,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,50,76,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,127,127,63,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127,127,0,76,0,0,0,0,25,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,127,76,25,25,0,0,0,0,0,25,0,0\n0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,31,127,95,0,95,0,31,0,0,31,0,63,0,63,0,0,0,0,31,63,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,21,105,127,52,74,0,63,42,10,10,0,10,0,0,0,0,0,0,0,0,0,0,0,0\n0,63,127,63,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,95,127,31,0,31,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0\n84,84,63,105,42,0,42,127,105,63,21,21,63,21,21,0,42,42,0\n0,0,0,0,0,0,0,15,0,15,0,31,0,0,0,0,0,15,15,0,15,95,47,127,0,15,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,11,0,0,0,0,0,0,23,57,46,127,34,92\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,12,0,0,25,12,25,0,38,25,63,0,127\n127,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,25,0,0,12,0,0,0,0,25,0,0,38,25,127\n0,0,2,1,2,0,4,9,11,37,51,80,127,72,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,5\n0,0,0,0,0,0,0,3,0,3,18,127,67,37,7,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,18,11,11,3,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,4,127,97,9,4,0,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,19,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,36,54,108,127,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,12,0,0,0,0,0,0,12,0,0,0,0,12,0,12,0,25,0,50,101,127,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n3,4,5,10,13,12,20,44,67,99,127,114,95,46,12,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,4,17,41,61\n0,95,63,31,95,31,0,31,127,63,31,63,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,35,115,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,2,127\n0,0,0,6,0,2,14,21,38,69,99,127,101,114,74,16,4,4,0,0,0,0,0,0,0,0,0,2,4,0,0,0,0,4,6,27,33\n0,0,0,0,0,0,0,0,0,1,23,127,54,8,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,4,25,2,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,4,27,127,66,7,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,1,1,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,25,127,101,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,25,0,127,101,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,84,127,0,0,0,0,0,0,0,0,0,0,0,0,84,42,84,84,0,42,84,0,42,127,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,9,9,0,0,0,54,27,117,108,127,72,36,63,36,45,54,0,27,0,0,0,0,0,0,0,0,0\n0,0,25,25,76,127,76,50,0,0,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n46,127,51,92,34,63,40,34,28,11,5,0,0,11,40,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,127,127,0,95,31,31,31,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,29,48,127,127,39,107,68,0,19,19,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,21,127,84,42,42,21,0,0,0,21,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,127,25,25,76,50,127,76,0,25,76,0,0,0,0,0,25,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,101,101,127,101,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,42,127,127,42,42,0,0,42,0,0,0,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n15,7,7,11,11,3,3,3,3,11,11,11,7,42,34,34,57,42,73,96,123,127,84,80,38,19,3,23,11,3,0,7,3,0,0,0,0\n18,4,28,18,0,9,4,0,9,14,0,4,0,14,14,0,14,28,23,98,127,79,79,9,4,0,4,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,69,69,127,57,34,57,34,11,11,0,0,0,0,0,11,0,0,0,0,0,0\n0,0,5,0,0,0,0,0,0,0,0,0,0,0,5,20,30,71,127,106,60,55,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,60,16,27,5,22,71,55,44,44,38,33,11,27,22,127,104,49,99,93,110,77,93,33,71,33,38,16,38,0,11,5,22,0,16,0,0\n127,54,36,0,0,9,18,0,27,9,0,0,0,9,0,0,18,36,36,63,27,36,45,36,18,0,0,0,0,0,0,0,0,9,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,84,21,42,127,63,0,21,84,0,42,21,0,0,0,0,21,0,42,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,18,0,18,0,0,18,0,54,36,127,90,108,18,0,0,18,0,0,0,0,0,0,0,0,0,0\n63,79,15,127,47,95,39,31,31,31,15,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n18,0,18,0,0,0,0,36,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,127,108,72,18,0,18\n0,0,0,0,18,36,18,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,36,127,90,127,18,36,36,18\n2,1,1,0,0,1,0,1,2,2,0,11,21,26,47,82,100,97,127\n25,12,0,8,0,8,0,0,0,0,0,0,0,0,0,8,12,33,55,127,76,46,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,16,46,127\n42,84,105,0,63,127,42,0,42,63,42,21,0,0,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,45,18,3,6,0,18,42,127,117,12,9,3,9,0,0,0\n12,3,6,3,8,5,5,6,8,4,6,8,13,24,43,49,78,90,127\n0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,29,44,44,44,127,37,37,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,25,50,0,12,0,12,25,0,0,0,0,0,0,0,0,0,0,0\n127,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n43,19,8,0,0,2,0,0,0,2,2,0,0,0,0,2,2,0,0,0,0,0,0,0,0,0,0,0,0,2,2,0,0,2,26,83,127\n28,23,5,2,5,2,0,5,0,0,2,0,0,2,0,2,2,5,0,2,0,2,0,0,0,0,0,0,0,5,2,11,5,31,49,72,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,15,45,127\n50,50,50,127,25,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,25,50,0\n0,0,0,0,0,0,0,0,0,15,0,0,15,15,0,31,127,95,63\n127,66,19,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1\n127,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,42\n0,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,127,84,127,84\n0,0,0,0,101,0,127,0,50,25,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,95,31,31,42,63,21,127\n127,43,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,39,127\n95,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,95\n127,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7\n127,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,105,63\n127,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34\n127,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,56\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,127\n127,0,0,7,23,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,72,0,0,127,36,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,63,42,21,0,21,42,21,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,25,25,25,76,76,76,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,31,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,84,116,31,31,0,10,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,7,55,39,15,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,74,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,28,28,14,56,84,14,70,127,14,42,84,0,14,0,0,0,0,0,0,0,28,0,0,0,0,0,0,28,0,0\n0,0,0,0,31,31,63,31,127,31,0,0,31,0,63,63,63,0,31,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,25,38,127,38,0,0\n0,18,0,0,0,36,0,54,72,36,54,127,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,13,33,6,127\n63,0,0,0,31,0,0,95,127,95,63,63,31,95,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,112,42,127,28,84,14,56,56,0,0,0,0,0,14,0,0,0,14,14,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,31,47,47,127,15,31,31,0,0,0,0,0,0,0,15,0,31,15,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,63,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,127,127,63,63,127,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,63,0,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,63,63,127,127,0,63,0,0,0,0,0,0,0\n127,19,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,29,127\n127,89,37,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,127\n127,40,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,45,127\n23,127,34,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,11,69\n127,89,43,14,11,14,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,127\n127,127,95,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,74,63,21,10,21,10,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,81,9,0,0,3,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,84,21,21,10,0,52,42,63,31,0,42,10,0,0,0,0,0,0,0,0,42,42,21,10,10,31,0,0,10,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,93,127,18,7,3,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,31,31,0,0,0,0,31,0,0,31,31,127,0,63,0\n0,36,36,0,18,0,0,0,72,54,18,18,36,0,0,18,0,18,0,0,54,18,0,0,0,0,0,0,0,0,0,0,0,0,18,127,72\n0,63,0,0,0,127,127,63,63,127,0,0,0,0,0,0,0,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,127\n0,0,9,0,0,0,9,90,127,90,54,36,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,54,36\n31,0,0,47,15,111,15,127,47,127,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,15,0,0,31\n0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,33,10,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,52,10,10,127,74,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,127,127,0,31,31,0,0,31,31,0,31,0,31,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n101,127,76,0,0,0,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n16,29,59,71,127,84,110,50,88,101,88,55,76,55,76,88,118,50,25\n29,39,83,50,94,90,94,79,94,87,54,36,68,97,101,127,58,43,58,43,14,21,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,11,11,0,11,34,34,127,23\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,31,0,0,0,127,127,31,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,63,95,95,95,127,31,31,95,31,0,0,31,31,31,0,0,0,31,0,0,0,0\n0,0,0,15,0,0,0,127,63,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,127,25,0,25,0,25,0,25,50,0,0,0,0,0,0,0,0,0,0\n28,84,56,0,28,56,127,56,28,56,42,28,14,14,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n42,94,84,82,127,82,87,91,58,61,21,9,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4\n127,63,0,0,63,63,127,63,127,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0\n50,25,25,50,127,0,127,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,63,0,0,31,31,0,95,63,63,31,31,63,63,127,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,42,127,84,0,0,84,42,84,84,42,0,0,42,0,42,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,42,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,36,127,18,72,36,36,18,90,36,72,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,63,105,42,105,105,127,42,63,21,21,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,84,127,127,0,42,0,0,0,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,50,127,50,0,0,0,0,76,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,72,36,0,54,0,36,18,36,18,54,54,127,54,72,18,36,90,36,54,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,95,0,0,31,0,95,31,31,0,63,63,31,0,63,127,63,63,127,63,95,95,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,63,0,31,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,19,0,48,29,29,48,29,48,0,39,9,68,68,127,117,39,29,58,29,29,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,47,31,31,111,15,31,47,15,15,47,15,79,127,47,111,127,63,127,15,15,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,127,127,63,0,0,63,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,21,127,105,127,42,0,42,21,0,0,21,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,127,63,0,95,0,0,0,31,0,0,31,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,42,0,0,0,42,0,42,84,84,42,0,42,0,84,127,0,0,0,0,42,42,84\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,21,42,35,28,56,127,56,70\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,54,0,0,36,18,54,54,127,90,72,90,127,36,0\n0,0,0,0,0,0,0,0,0,0,0,0,2,22,33,41,71,113,127,121,107,91,55,52,35,49,24,55,60,88,57,33,22,16,2,2,5\n0,0,0,0,0,0,0,0,0,0,0,76,101,127,76,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,1,12,18,27,29,36,24,11,22,23,11,14,13,32,43,51,80,110,127,48,37,26\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,14,7,21,77,28,63,77,56,112,77,127,56,14,28,14\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,0,15,0,0,0,0,0,0,0,0,31,31,31,0,127,0,15,0\n0,0,0,0,0,0,0,0,0,6,0,6,6,12,18,30,48,54,78,66,42,42,114,72,78,42,72,54,96,60,127,120,48,66,0,6,12\n0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,9,18,0,72,27,9,18,0,18,27,9,0,9,0,27,0,36,81,127,117,99,90\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,14,112,98,56,84,70,14,0,14,127,56,98,14,42,70,127,56,56,14,28,14,28\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,22,14,52,82,127,89,44,14,7,37,7,44,67,0,14,14,7,14,14,7,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,95,63,63,31,63,95,95,0,63,63,127,31,31,0,31,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,21,0,0,42,0,21,42,127,21,42,0,42,63,0,0,0\n42,127,84,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,0,0,0,0,50,127,76,101,0,25,0,0\n101,101,25,127,127,25,25,50,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,38,12,12,25,38,50,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,63,15,31,15,127,0,15,15,31,0,0,0,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,127,95,95,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,21,84,127,84,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,63,52,31,10,31,0,21,0,42,21,31,0,0,0,0,0,0,0\n31,127,47,95,111,47,15,0,0,15,15,0,15,0,0,0,0,0,0,0,0,0,0,15,0,15,0,0,0,0,15,0,0,0,0,0,0\n0,0,0,0,0,0,5,0,0,0,0,17,11,5,23,11,57,51,127\n0,127,50,101,127,25,0,25,25,50,25,0,50,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,87,71,66,60,34,34,15,26,18,26,10,7,7,2,5,5,0,0\n127,95,95,95,127,31,63,31,95,31,31,0,63,31,0,0,0,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,25,0,0,0,0,0,25,0,0,76,127,101\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,63,31,95,31,0,0,0,0,0,0,0,31,31,31,127\n58,97,73,117,97,127,92,73,29,29,48,14,9,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,101,0,50,25,25,50,101,76,0,76,0,0,76,127,0,50,50,25,50,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,31,0,95,127,63,63,63,31,63,95,63,0,31,95,31,127,63,31,0,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,7,29,44,67,59,112,67,82,74,127,59,44,44,67,89,59,37,7,74,14,22,0,7,0,0\n0,0,0,5,0,11,0,11,22,44,127,77,44,16,0,11,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,63,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,15,15,19,34,15,15,30,34,30,61,53,73,127,65,92,61,15,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,19,29,29,68,87,127,107,48,39,97,97,68,78,48,68,39,19,0,9,0,0\n0,0,14,14,0,0,0,14,28,56,42,127,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,25,0,0,0,0,0,0,0,0,0,0,0,25,0,0,25,25,50,50,101,127,25,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,50,0,50,76,76,0,76,76,25,25,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,14,127,42,14,70,42,14,14,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,14,42,42,28,42,14,28,70,14,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,127,63,31,0,0,0,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,84,84,42,127,42,84,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n84,42,21,0,0,0,0,0,0,21,21,0,42,21,63,42,84,127,127,127,21,42,63,42,105,42,42,0,21,0,42,0,0,0,0,21,0\n127,42,21,21,0,21,0,84,21,0,31,0,10,0,10,0,21,31,0,105,95,63,21,52,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,42,127,93,0,0,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,127,50,76,0,0,0,0,0\n0,0,0,0,0,0,0,14,0,0,0,14,84,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,14,0,14,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,70,14,127,112,42,14,28,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,42,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,42,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,84,127,0,0,42,0,0,0,0,0,0,0,0\n80,127,73,46,13,13,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,6,40,13\n127,42,31,8,2,2,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,38,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,42,84,84,42,0,42,127\n63,31,31,15,31,0,15,0,0,0,0,0,0,0,0,15,0,15,0,15,0,47,0,15,15,0,15,31,31,0,0,0,0,0,127,79,63\n127,119,111,15,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,10,74,0,0,0,0,10,42,127\n127,42,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,21,31,10,0\n127,51,28,5,5,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,127,80,57,27,11,2,8,5\n101,50,76,0,50,50,101,127,127,0,0,25,0,25,0,0,0,0,0,25,25,0,25,0,25,0,50,50,50,25,101,25,0,0,0,25,0\n127,0,0,0,63,63,63,63,127,0,63,0,127,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,63,0,0,63,0\n127,42,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,10,10,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,95,127,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,18,0,18,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,54,54,0,0,0,0,0,0,0,0\n127,127,84,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,15,63,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,111,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,127,127,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,31,127,31,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,31,31,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,31,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,127,0,127,95,0,0,0,127,0,31,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,127,0,127,63,63,0,127,0,0,0,0,127,0,0,63,0,63,0,0,0,0,0,0,0,0,0\n0,15,0,15,0,47,15,0,0,0,0,0,0,95,0,0,63,63,127,47,31,0,31,47,63,0,15,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,18,108,0,127,18,0,72,108,18,90,18,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,84,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,21,63,63,84,42,42,127,42,63,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,21,0,21,0\n127,105,63,42,0,0,21,0,21,21,21,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,0,0,76,127\n0,63,42,127,63,105,105,21,42,105,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,25,25,25,76,0,25,25,50,76,50,25,127,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,63,63,0,0,127,127,127,0,0,63,0,127,0,0,0,0,0,0,63,63,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,92,127,0,11,11,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,23,127,46,11,11,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,127,0,11,0,0,0,0,0,0,0,0,0\n0,90,127,54,0,0,0,0,0,0,0,0,0,0,0,18,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n101,127,50,12,25,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25\n127,73,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,6\n127,42,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,95,45,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n108,127,99,75,55,29,16,8,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,4,2,12,8,5,7,8,8\n0,0,0,0,0,0,0,0,15,15,127,31,31,0,47,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,79,15,127\n101,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,76,50,127,101\n127,79,47,39,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n84,42,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,116,95,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n55,35,30,11,14,7,5,9,1,2,1,1,1,2,1,1,1,0,3,2,6,0,6,2,0,3,3,0,0,1,2,10,17,33,72,115,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,50,76,127,25,63,38,50,50\n0,0,15,31,15,0,0,0,0,15,0,0,15,31,0,0,0,0,0,0,0,15,15,0,0,0,0,0,0,0,0,0,0,31,79,127,31\n127,71,20,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,94,46,23,6,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,9,16,35,72,94,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,112,28,56,127,84\n127,86,51,23,12,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,29,78,39,68,19,127,39,58\n127,73,29,9,0,4,9,0,4,0,0,4,0,0,0,0,0,9,4,0,0,0,0,0,4,0,0,0,0,0,0,4,0,0,0,0,0\n127,88,48,23,3,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,2\n127,121,97,41,20,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,10,11,14,14\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,9,27,86,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,38,38,127\n127,80,27,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,7\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,18,90,72\n127,124,68,50,66,34,2,2,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,15,0,5,31,39,34,23,74\n127,49,42,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,14,21,0\n72,54,27,0,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,9,0,45,127\n111,103,47,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,23,127\n12,31,31,82,31,44,88,82,114,101,63,50,95,107,31,44,25,19,44,19,12,25,69,44,82,95,127,95,82,31,50,31,19,57,0,25,25\n0,0,0,36,18,0,0,0,54,18,0,54,0,18,36,72,18,90,0,36,0,127,54,18,0,18,36,18,0,18,0,54,0,0,0,0,36\n127,86,76,63,26,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,0,3,6,0,0\n127,55,79,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n105,127,89,15,52,26,21,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,15,21,37,10,0\n84,21,63,63,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127\n0,0,0,0,0,0,42,127,0,0,42,0,0,0,0,42,42,42,84,42,0,42,0,0,42,42,0,0,0,0,0,0,84,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,42,0,42,0,0,0,0,0,84,42,0,42,42,42,84,0,0,0,0,127,0,0,0,0,0,0,42,42,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,0,0,42,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,127,0,101,101,25,0,0,0\n0,0,0,0,0,0,0,0,25,0,50,76,101,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,25,0,0,0,0,0\n95,127,79,47,47,15,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,47,0,0,15,15,0,0,0,0,0\n127,106,72,20,25,5,2,0,0,0,0,0,0,0,0,0,0,0,0,2,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,66,10,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,20,29\n0,0,0,0,0,0,0,0,6,3,9,9,12,15,12,9,0,0,3,0,3,0,0,0,0,0,0,0,0,0,0,0,0,3,0,15,15,21,9,9,9,3,0,0,0,0,0,0,0,0,0,0,0,3,3,0,6,43,55,127,80,58,27,12,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,8,16,12,16,33,38,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,8,8,38,25,4,8,4,4,0,0,0,0,0,0,0,0,0,0,4,4,4,21,59,88,118,127,67,29,12,4,8,0,4,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,42,0,14,14,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,14,0,127,112,42,0,0,0,0,0,0,0,14,0\n0,0,0,0,0,0,0,0,0,0,0,25,12,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,127,101,38,12,0,0,0,12,0,12,0,0\n0,0,0,0,0,0,0,0,0,0,0,7,31,87,55,31,7,0,0,7,0,0,0,0,7,0,0,0,0,0,0,0,0,7,23,127,87,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,19,127,29,39,9,0,0,19,0,0,0,0,0,9,0,0,0,9,0,0,9,19,9,68,97,29,9,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,10,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,10,84,127,105,42,10,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,37,127,37,7,14,7,7,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,101,127,76,25,0,0,0,0,0,0,0,0\n0,0,0,0,0,7,0,0,0,29,14,67,119,127,59,89,44,37,22,29,14,7,0,0,7,0,0,7,0,0,14,7,0,7,14,7,44\n127,28,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,88,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0\n0,0,0,0,0,0,0,0,0,0,0,0,28,56,84,98,28,127,56\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,48,127,114,30,6,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,29,9,9,9,9,29,127,48,29,68,29,29,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,10,0,0,0,10,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,42,21,0,21,63,105,127,84,42,21,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,16,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,33,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,44,7,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,39,127\n127,56,13,23,3,0,0,0,0,0,0,0,0,0,6,3,0,3,0,3,6,0,0,0,0,3,0,3,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,15,0,15,31,127,127\n127,68,17,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,82,27,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,74,20,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,49,14,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,38,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,36,54,45,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,53,97,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,16,55,127\n127,59,12,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,84,22,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,15,57,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,47,84,127\n127,69,18,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,95,31,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,10,42,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,53,127,39,0\n127,69,19,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,28,70,127,84\n127,56,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,44,10,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,95,42,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,0,18,0,72,36,0,36,90,127,72,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,127,42,0,84,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,31,127,63,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,25,0,0,0,0,0,0,0,25,0,25,25,101,25,127,25,101,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,127,72,54,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,79,63,0,0,0,0,0,0,0,0,0,0,0,0\n127,74,52,25,18,10,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,92,34,10,7,7,7,5,2,10,2,5,0,2,2,0,0,0,0,5,0,0,2,2,5,7,0,5,2,5,0,0,0,7,2,7,10\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,31,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,1,23,127\n127,125,76,64,51,46,44,57,44,52,33,53,32,35,22,24,11,15,15,13,6,9,4,5,3,1,1,0,0,0,0,0,0,1,1,1,8\n0,28,28,14,42,42,70,14,14,42,56,84,112,70,84,127,42,56,42,28,14,28,0,0,0,0,14,28,14,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,10,15,30,54,55,26,16,25,38,66,97,127,116,95,81,95,85,88\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,16,16,42,0,0,0,0,8,8,42,42,127,110,25,42,8,16,16\n23,75,127,63,51,80,46,57,80,69,51,34,46,57,86,63,46,51,46,40,23,28,11,5,5,0,11,0,0,28,11,17,11,17,40,5,11\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,103,127,57,34,34,0,0,23,34,34,11,46,23,57,57,46\n112,127,14,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,14,28\n0,0,25,25,0,0,0,25,0,0,50,0,0,0,50,50,76,0,25,0,0,0,0,0,0,0,0,0,0,50,0,50,0,50,50,127,101\n0,0,0,0,0,0,0,0,63,63,0,0,127,63,0,127,127,0,63,0,63,0,0,0,63,0,0,0,0,0,0,0,0,127,63,0,0\n0,0,0,0,0,0,0,0,0,0,36,108,127,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,14,127,84,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,50,25,0,12,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,50,127,63,88,0,12,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,42,21,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,21,63,127,21,105,21,21,21,21,0,0,0,0,0,0,0\n127,6,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,127,18,18,36,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,31,0,31,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,11,0,11,11,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,23,11,0,0,11,0,0,0,0,0,0,0,0,0,0,11,0,23,34,92,127,57,34,11,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,36,18,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,127,108,36,54,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,127,36,0,0,0,0,0,0,0,0,0\n127,103,71,63,55,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,7,0\n0,0,0,0,0,0,0,0,0,0,11,17,25,40,46,51,101,127,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,127,127,101,50,25,76,25,25,0,0,0,0,0,0,0,0,0,0,0,0\n127,97,21,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n42,84,63,21,0,0,21,21,0,0,0,21,63,127,127,0,0,21,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,31,63,127,15,47,0,0,0,31,15,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127,50,0,0,25,76,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,54,72,36,72,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,25,0,127,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,50,0,0,0,0,0,0,0,0,0,25,25\n0,0,0,0,0,0,0,0,31,0,31,63,0,0,63,127,31,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,0,0,0,0,0,0,31,0\n23,0,0,0,23,23,23,0,0,0,0,0,0,0,11,127,46,0,0,0,0,0,0,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,127,69,0,0,0,11,0,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0\n0,31,21,21,52,31,42,127,52,84,74,52,10,10,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,56,70,127,84,84\n0,0,0,0,0,0,0,0,0,42,0,127,42,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,84,0,42,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,42,0,0,84,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,84,127,0,42,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,50,127,0,0,0,0,25,0,0,25,0,25,0,0,0,25,25,101,0,0,0,25,76,50,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,63,95,0,0,0,31,31,31,0,0,0,0,0,0,31,63,0,0,31,63,31,0,31,31,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,15,0,0,0,0,15,0,31,63,127,47,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,18,0,0,0,0,0,0,0,0,18,18,127,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,7,56,127\n127,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,11\n127,40,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,9,27\n127,50,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,12\n127,45,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,0,36,0\n12,6,18,6,12,6,6,18,12,6,18,24,30,6,24,24,24,6,18,12,0,12,0,12,6,18,12,6,12,48,18,24,78,30,96,127,96\n127,63,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,63,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,10,0,0,10,10,52,95,116,116,84,63,116,63,74,31,31,10,21,10,21,21,31,52,10,52,31,21,63,116,127\n0,0,0,31,0,0,31,0,0,31,0,95,0,0,31,31,0,31,0,31,31,63,95,63,127,31,31,0,31,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,50,0,25,0,25,0,50,127,25,25,0,0,0,0,0,0,0,25,0,25,0,0,0,0,0,0,0\n0,42,0,127,127,127,0,0,0,0,0,0,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,6,3,13,53,127,76,40,3,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,20,23,63,43,23,13,3,3,0,0,0,0,0,0,0,0,0,0,0,0,3,6,20,33,66,60,50,13,6,3,3,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,3,17,61,127,78,24,44,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,27,24,89,102,61,20,6,3,0,0,3,0,0,0,0,0,0,0,0,0,10,3,13,37,92,109,82,82,92,17,3,0,0,0,0,0,0,0\n0,0,0,0,0,0,15,0,0,31,15,47,15,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,127,31,15,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,31,63,127,15,0,15,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,71,39,7,15,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,50,101,76,76,25,50,0,0,0,0,0,0,0,0,0,25,25,0,0,0,0,0,0,127,76,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,14,56,70,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,14,56,70,127,28,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,12,0,0,25,38,0,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,25,12,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,12,76,127,127,50,12,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,25,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,101,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,101,76,127,50,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,21,0,21,42,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,63,0,21,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,15,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,127,95,47,0,0,0,0,0,0,0,0,0\n127,58,14,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,5,25\n127,72,10,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,12,0,0,0,0,0,0,12,25,88,25,25,12,50,127\n127,119,115,71,44,38,34,11,3,0,1,5,0,0,5,0,1,1,0,0,0,0,0,1,0,1,1,0,0,1,3,13,5,3,13,7,3\n127,55,79,19,7,7,0,0,23,0,3,11,3,0,7,15,11,35,3,3,7,0,3,3,0,7,0,0,0,0,0,0,3,0,3,7,15\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,2,16,2,0,0,0,0,0,0,0,0,2,16,44,127\n127,62,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,73,12,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,18,9,0,18,27,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,57,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,51,17,28,8,8,5,0,0,0,0,0,2,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,10,42,21,95,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,79,127\n127,54,13,9,4,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,63,127\n36,36,127,72,108,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,21,0,0,0,0,0,0,0,0,21,42,0,0,0,21,0,0,0,0,0,42,0,21,0,0,0,0,0,0,42,21,21,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,0,0,0,0,2,0,10,64,127,120,90\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,95,95,0,127,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,23,34,77,127,115\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,12,0,12,0,0,0,12,0,12,0,12,25,12,25,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,101,127,25,76,0,0,0,25,50,25,0,0,0,25,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,9,9,27,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,7,7,39,71,71,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,36,18,108,72,90,90,127,18,72,18,0,18,18,36,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,10,10,52,127,84,63,10,10,42,10,0,10,31,10,10,21,0,10,10,31,10,10,21,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,10,0,10,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,15,31,111,111,127,63,47,31,15,15,0,15,0,31,47,47,31,0,47,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,15,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,63,0,63,63,63,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,0,0,0,0,0,0,0,0,0,0\n0,31,0,0,0,0,0,0,63,0,127,31,127,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,0,0,31,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,71,127,87,16,6,26,9,0,0,3,0,0,0,0,0,0,0,0,0,9,0,0,6,6,9,3,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,31,127,52,10,21,15,15,0,0,0,0,5,0,0,0,0,0,0,0,0,10,15,5,0,15,10,26,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,42,0,127,0,84,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,21,42,105,21,127,21,0,0,0,0,21,0,21,21,0,0,21,0,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,21,21,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,31,0,31,63,95,127,31,63,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,63,63,0,95,127,31,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,31,0,127,127,31,31,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,95,0,31,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,21,0,127,42,42,21,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,63,0,0,21,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,50,101,25,0,0,0,0,0,0,0,50,127,101,25,50\n63,127,95,15,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,21,21,127,105,105,63,42,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,7,7,31,31,47,23,111,127,0,7,0,15,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,7,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,7,7,14,37,44,37,52,127,22,7,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,9,9,127,63,18,27,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,95,95,127,127,95,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,31,31,0,127,127,127,63,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,127\n0,0,0,0,0,0,0,0,0,9,63,36,108,54,127,117,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,18,36,18,81,27,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,23,80,127,103,57,46,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,23,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,34,69,34,23,23,11,0,0,0,0,0,0,0,0\n0,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,57,127\n127,45,18,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n56,28,98,127,84,56,84,42,14,14,28,42,28,0,28,14,28,14,42,98,28,70,14,0,0,0,0,0,14,0,0,14,42,28,0,28,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,12,63,0,0,0,0,38,63,127,25,0,0,0,0,0,0,0,0\n127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,21\n0,0,0,0,0,5,10,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,5,26,58,127\n50,50,50,127,25,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,102,58,34,53,29,14,4,9,14,0,0,9,4,4,19,14,4,14,4,39,9,4,0,0,0,0,0,0,4,4,0,0,14,24,39,48\n0,25,0,25,0,25,0,0,25,25,76,0,76,0,127,0,25,76,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n101,127,0,25,0,50,25,25,0,0,0,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,21,0,42,0,0,42,42,63,84,21,0,42,0,0,0,21,0,21,84,0,42,127,42,42,42,21,0\n0,0,0,0,5,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,5,0,15,10,26,21,47,47,74,100,116,127,47,37,26,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,7,0,7,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,7,0,7,7,7,29,22,14,52,89,127,52,89,44,14,14,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,14,14,0,42,127,42,14,14,14,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,63,63,127,95,0,95,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,31,31,0,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,127,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,67,19,8,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,93,35,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,63,31,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,68,92,14,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,80,51,11,23,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,57,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,57,31,25,19,6,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,127,95\n84,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,127,84\n127,47,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,47,0,63\n14,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,127\n127,31,63,63,0,31,31,0,0,0,0,0,0,0,0,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,38,50,127,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,40,28,17,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,42,21,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0\n127,102,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,9,73,78\n127,0,31,0,0,31,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n14,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,3,14,21,43,127,94\n127,77,7,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,7,0,0,0,0,0,0,0,0,7,14\n0,127,25,0,0,50,0,0,25,0,0,0,0,0,0,0,0,50,0,0,0,0,0,50,0,0,0,0,0,0,0,0,25,0,0,0,0\n0,0,9,0,0,0,58,39,127,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,127\n25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,63,127\n108,54,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,18,127,36\n63,63,31,63,63,0,0,0,0,0,0,0,0,0,0,0,31,0,31,31,31,127,127,31,31,0,31,31,0,0,0,0,0,0,0,0,0\n31,0,0,0,31,0,31,15,47,63,15,47,0,0,15,15,15,63,79,31,47,15,15,0,31,47,79,15,63,79,79,127,79,0,0,0,0\n108,18,54,0,36,0,0,0,0,0,0,18,0,18,0,0,18,0,54,54,127,90,90,72,36,0,0,0,0,18,0,18,54,0,18,0,0\n0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,7,7,0,15,15,0,7,0,3,3,39,75,127\n127,87,34,7,4,4,9,9,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,1,3,0,4,6,13,30,31,45\n127,22,3,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,6,0,6,0,6,0,19,6,38,31,127\n0,36,18,0,18,0,0,18,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,54,90,72,90,127,127,72\n127,102,63,33,12,27,9,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,3,0,3,3,9,18,24\n54,27,36,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,45,0,54,108,127\n127,127,95,47,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,31\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,3,3,15,43,23,79,127\n127,35,7,7,0,7,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,14,56\n127,31,47,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,64,27,3,2,0,1,0,0,0,0,0,0,0,0,0,0,0,0\n127,99,27,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,62,50,22,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,31,0,127,63,127,0,63,31,31,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0\n0,0,10,10,0,0,0,10,0,10,0,31,10,52,10,42,42,84,127,116,21,52,42,0,0,0,10,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,9,0,4,4,4,9,39,83,127,48,29,19,29,19,68,29,0,19,19,0,0,0,0,0,0,0,19,19,39\n0,0,0,0,0,0,0,0,0,0,0,0,0,2,8,8,44,33,127,52,24,5,22,16,11,2,0,2,5,41,27,0,0,2,2,2,0\n0,0,0,0,0,0,0,0,0,0,0,50,50,50,127,50,127,50,50,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,112,21,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,37,5,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n28,14,0,28,0,0,0,0,14,0,28,70,42,70,14,84,127,84,56\n0,36,0,36,0,0,0,0,0,36,18,18,0,18,36,108,127,36,36\n0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,46,46,127,69\n34,23,11,5,17,0,0,0,0,23,17,34,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,63,127,92\n127,63,127,0,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n38,57,127,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0\n127,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,42,63,0,21,95,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,39,26,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,0,45,127\n127,47,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,18,18,72,72,0,54,0,0,0,0,0,18,0,0,0,0,18,18,0,0,18,0,0,0,0,36,18,18,18,127,54,0,0,0,36\n0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,0,127,0,31,63,31,0,63,0,0,0,31,0,0,0,0,0,0,0,63,0,0\n0,0,0,0,0,31,31,63,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,31,127,0,63,0,31,31,0\n127,74,28,15,24,10,6,0,8,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,2,4,10,6,8,10,37,87\n127,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,31,10,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,2,0,7,53,127\n0,0,0,0,0,95,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,63,127,0,63,31,0\n127,68,43,9,24,9,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,19,0,19,4,34,63,19\n127,111,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,127\n15,15,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,7,127\n0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,63,0,0,0,0,0,31,0,31,63,31,95,127,31,0,0,0,0,63\n36,0,0,0,0,36,0,127,36,0,36,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,18,36,18,0,90,90,36,18,18,0,36\n127,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14\n21,9,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,26,75,127\n127,63,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,63,29,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,59,0,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n101,76,127,0,25,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,25,25,50\n72,127,96,120,12,15,18,3,3,0,0,0,0,0,0,0,0,0,0\n127,127,47,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,63,63,0,0,63,63,63,63,0,0,0,63,127,0,0,127,0,63,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,80,127,11,0\n127,79,15,79,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,38,38,63,25,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,50\n56,46,15,15,10,3,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,2,53,69,127\n127,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,63,111,111,47,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0\n127,84,63,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,0,24,0,4,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,0,0,0,0,0,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,127,63,127,127,0,63,0,63,127,63,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,31,15,47,127,47,47,15,63,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,108,18,0,127,0,0,0,18,0,18\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,31,95,127,0,63,0,0,0,31,0,63\n0,0,0,0,0,0,0,0,0,0,28,127,112,112,70,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,31,95,127,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,42,0,42,0,0,42,127,42,84,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,31,0,0,0,15,0,15,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,15,0,0,15,0,0,0,15,31,15,0,0,0,31,0,0,31,47\n63,63,31,31,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,127,63,0,0,31,0,0,31,31,0,0,0,63,63,63\n31,0,31,0,31,0,31,31,0,0,31,31,95,95,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0\n63,12,12,50,25,38,0,0,0,12,127,0,0,50,63,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,25,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,76,25,127,25,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,42,21,0,21,0,0,0,0,0,21,21,0,0,21,0,0,0,42,21,21,42,127,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,63,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,31,63,31,31,127,111,127,63,15,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,31,0,79,0,0,127,63,47,0,15,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,14,42,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,28,70,127,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,11,0,11,0,0,0,0,0,0,0,11,11,0,0,80,127,46,34,80,0,11,34,0,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,127,95,0,0,31,127,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,42,0,0,42,0,0,127,84,42,0,42,84,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,72,0,0,18,127,36,54,0,18,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,18,36,18,0,18,127,36,18,36,0,18,18,0,18,90,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,63,127,127,63,63,0,0,0,63,63,0,127,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,47,47,63,127,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,84,127,127,84,42,84,0,0,0,42,0,0,0,0,0,0,0,0\n90,81,127,36,0,18,18,9,0,0,9,0,0,0,0,0,9,27,0\n0,31,127,0,63,0,0,31,0,0,0,0,63,0,31,127,63,0,0\n0,31,31,0,0,0,31,0,0,0,0,0,0,0,0,0,0,31,0,127,63,0,0,0,31,0,0,0,0,63,0,63,63,0,127,0,0\n127,63,31,21,10,0,0,0,0,0,0,0,21,0,21,10,10,21,21\n0,0,0,0,0,0,0,3,3,15,29,101,123,101,37,17,3,1,0,0,0,1,0,0,0,0,0,0,0,0,1,1,3,19,51,81,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,7,18,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,3,13,30,13,43,127\n0,0,0,0,3,0,0,0,0,10,3,50,127,58,18,14,0,0,0,3,0,3,0,0,3,7,0,0,0,0,0,0,3,3,25,21,14\n0,0,0,0,0,0,0,0,0,0,0,0,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127\n0,0,0,0,0,0,0,0,0,0,0,127,0,21,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,84\n0,1,1,1,0,0,0,2,5,29,77,14,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,52,127\n0,0,0,0,0,0,0,0,0,0,127,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,63,21,42,84,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,29,127\n0,0,0,0,0,0,0,0,25,66,30,45,127,71,25,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,20,20,20,40,30\n0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,51,63,127\n0,0,0,0,0,0,0,0,95,31,127,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0\n0,0,0,0,0,0,0,0,31,0,0,63,63,63,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,0,95,127\n127,0,0,0,0,0,0,0,0,0,0,3,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,14,124,127,38,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,10,8,77,127,34,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,22,127,42,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,127,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,9,0,0,19,29,9,9,29,39,127,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,19,0,9,0,0,0,0,0,0,0,9\n12,38,12,38,12,12,12,12,0,0,12,38,127,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,0,0,0,0,12,12,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,15,15,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,127,0,31,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,76,127,101,76,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,84,42,0,0,0,0,42,0,84,0,42,0,0,0,0,0,0,0,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,21,0,0,0,0,0,0,0,84,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,105,127,21,21,21,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,31,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,127,111,15,0,0,0,0,31,0,0,0\n0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,127,95,95,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,127,63,21,21,21,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,56,77,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,14,7,14,42,56,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,5,16,93,127,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,22,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,16,0,0,0,0,22,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127,42,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,21,105,127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,21,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,42,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,21,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,42,0,0,0,0,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,127,127,42,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,42,0,84,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,7,15,51,127,111,35,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,40,127,34,23,5,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,63,31,0,0,127,127,63,31,31,31,31,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,8,0,0,8,42,127,59,25,16,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,4,70,94,127,23,0,0,4,0,0,4,9,0,0,0,0,0,0,0,0,0,0,0,0,14,4,28,28,14,4,4,0,0,0,9,18,42,28,4,0,0,0,0,0,0,0,0,0,0,4,4,9,42,122,23,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,16,8,59,84,8,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,8,33,42,16,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,8,16,127,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,84,127,105,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,1,6,9,6,1,0,0,0,0,1,1,0,1,0,0,0,0,0,0,2,2,2,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,5,8,31,127,50,27,4,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,6,10,9,5,0,0,0,0,0,1,0,0,1,0,0,0,0,1,0,0,4,2,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,7,55,127,79,31,0,5,0,0,0,0,0,0,0,0\n0,0,1,0,2,2,7,9,17,60,107,127,83,16,0,1,5,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,2,0,18,35,45,24,14,8,1,5,1,1,1,0\n0,0,0,0,0,0,1,1,11,56,47,127,53,6,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,3,3,3,2,2,1,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,1,4,28,127,84,21,7,8,9,13,7,2,1,1,0,0,0,0,0,0,0,0,0,0,0,4,2,1,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,25,123,127,38,12,13,10,3,1,1,0,0,0,0,0,0,0,0,0,0,2,7,2,6,4,5,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,7,7,0,0,0,14,70,77,127,42,7,14,7,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,7,7,0,35,14,0,0,0,0,0,0,0,0\n2,2,0,0,0,2,4,8,15,25,49,127,55,19,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,15,19,10,0,0,0,0,0,2,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,127,39,31,31,0,7,0,0,23,15,0,7,15,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127,91,106,20,0,15,0,0,0,10,0,5,5,5,5,0,0,0,0,0,5,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,18,0,54,72,72,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,36,108,54,54,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,36,72,127,54,36,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,36,18,54,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,18,36,0,54,54,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,54,72,127,0,18,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,50,101,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,127,84,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,127,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,6,18,12,0,12,42,114,127,96,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,48,24,42,12,0,6,0,0,0,0,0\n12,0,0,0,6,6,12,12,38,25,127,127,88,38,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,38,44,12,19,0,6,0,6,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,84,127,0,0,42,0,0,0,42,0,0,0,0,0,0,0,0,0,0,42,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,127,0,31,0,63,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,31,0,95,95,95,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,84,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,127,127,84,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,127,105,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,21,42,21,84,0,0,0,0,21\n0,0,0,0,0,0,15,15,47,79,31,127,47,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,47,15,79,31,15,15,47,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,0,0,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,84,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,63,63,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,63,63,63,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,127,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n36,0,36,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,36,18,54,54,127,0,54,18,0,0,0,0,0,0,0,0\n42,105,127,21,42,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,105,84,63,127,63,0\n127,55,23,23,47,0,0,0,0,0,0,0,0,0,0,0,0,7,0,23,7,7,7,7,15,31,23,55,31,7,0,0,0,0,0,0,0\n0,42,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,42,0,84,42,42,0,42,84,127,0,0,0,0,42,0,0,0,0,0,0\n122,127,42,8,8,4,0,1,0,2,2,2,2,1,0,1,0,0,0,5,8,8,45,84,112,109,42,9,2,2,1,2,4,4,4,1,5\n127,0,0,15,0,31,15,63,0,47,15,63,31,0,0,63,63,15,31,31,0,15,63,15,15,31,31,0,31,0,15,15,15,95,15,47,31\n127,38,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,21,42,84,42,0,0,42,21,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,127,21,0,0,0\n84,0,0,127,42,84,0,0,0,0,0,0,42,0,0,0,0,0,84,0,84,42,42,0,0,0,0,0,0,0,0,42,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,3,11,17,65,127,123,27,20,4,0,1,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,127,90,72,72,54,54,0,0,54,36,18,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,15,15,79,63,87,103,127,63,63,39,31,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,31,95,95,127,0,0,0,0,0,0,0,0,0,0,0,0,0\n23,5,11,17,40,11,11,69,28,0,23,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n16,50,25,16,50,127,67,8,25,0,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n53,70,94,115,127,97,62,11,8,2,2,17,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,9,0,27,27,54,27,81,36,0,9,127,72,27,0,9,27,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,11,66,127,121,93,77,55,22,11,0,5,0,27,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,63,45,36,127,108,127,117,63,72,9,18,54,54,36\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,111,127,63\n72,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,18,127,0,72,36,72,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,127\n0,84,84,42,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,84,127,84,0,42,0,0,0,0,0,0,0,0,0\n0,63,0,63,0,0,0,0,0,0,63,0,127,0,127,0,63,0,63,0,0,0,0,0,0,63,0,63,0,0,127,0,63,63,0,63,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,95,0,0,0,31,127,63,0,0,0,0,0,0,0,0,0,0,0\n50,127,76,50,101,101,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,39,127\n0,42,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,0,127\n90,9,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,9,36,0,0,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,18,9,0,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,13,8,52,127,87,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,21,17,8,0,8\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,0,0,0,31,31,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,95\n127,98,70,70,56,28,42,0,14,14,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,28,42,70,28\n127,56,98,42,98,28,70,14,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,14,0,42,28,56,56,42\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,63,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,84,127,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n116,100,64,34,26,21,18,20,29,43,68,95,127,89,55,39,25,20,21\n0,0,6,0,6,0,6,12,12,12,12,19,25,19,25,44,44,76,127\n127,0,127,63,0,63,127,63,127,0,0,63,0,127,0,0,127,127,0\n5,2,5,5,10,2,0,2,5,0,10,15,7,15,23,39,74,82,127\n0,0,0,0,0,0,0,0,42,127,84,127,0,84,0,0,84,0,0\n127,77,22,9,8,6,3,1,2,3,4,3,4,3,1,3,2,1,2,2,10,12,17,76,120,64,17,9,4,3,3,4,1,3,4,3,5\n36,54,36,18,18,36,127,18,18,36,54,18,72,18,0,0,0,18,36\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,12,127\n127,46,23,11,34,28,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,127,21,0,42,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n60,120,102,127,84,90,54,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,52,42,74,42,95,10,31,95,21,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,15,17,1,10,12,25,34,56,77,119,114,127,101,49\n112,66,38,15,14,20,36,21,38,73,72,113,127,65,51,81,59,38,34\n0,31,0,15,15,15,0,31,0,47,0,0,31,15,31,95,63,79,127\n0,31,47,15,15,15,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,47,15,127,127,111,31,79,79,0,0,0,0,0,0,0,0\n127,31,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,6,0,9,45,44,62,35,34,20,19,29,77,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,57,0,34,127,0,0,0\n24,28,50,39,41,47,76,79,116,123,127,122,84,47,47,46,87,78,114\n0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,127,54,36,36,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,33,24,127\n127,34,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,28,14,28,127,42,28,28\n0,0,0,0,0,0,21,105,127,105,31,10,0,0,0,0,0,0,0\n0,25,0,50,0,50,25,0,101,127,50,76,0,76,76,25,76,101,101\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,127,104,37,14,7,7,0,0,0\n127,116,81,67,57,61,77,86,110,83,120,114,102,106,100,63,65,90,90\n0,21,21,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,63,42,21,0,0,21,0,21,0,63,42,0,127\n76,25,127,76,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,27,57,49,71,63,93,74,63,74,127,99\n127,63,127,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,63,127,127,63\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,0,0,127,127,63,63,63,0,127,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,127,104,66,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,127,71,71,10,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,9,0,0,9,18,9,18,49,22,22,31,127,31,22,31,9,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,19,6,6,57,12,63,25,25,38,38,127,25,12,6,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,25,25,0,0,0,101,127,101,101,101,127,101,25,0,25,0,0,0,0,0,25,0,0,25,0,0,0,0,0,25,0,0,25,25,0\n0,31,0,31,0,63,63,127,95,31,127,31,127,0,31,0,0,0,0,63,0,31,0,31,0,0,0,0,31,0,0,31,31,31,0,0\n42,0,0,84,0,42,42,0,0,42,0,84,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,127,84,84,42,42\n0,0,63,0,31,0,0,0,31,31,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,63,127,63,63,0,0\n127,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47\n127,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47\n0,0,0,127,63,0,0,0,0,0,63,63,0,127,0,127,0,0,127,127,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,50,0,0,0,0,0,0,25,50,50,25,0,25,0,0,25,127,76,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,52,112,127,82,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,28,61,127,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,42,127,84,0,0,0,84,28,28,14,70,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,70,70,0\n0,0,0,0,25,0,0,0,0,50,50,25,0,25,50,76,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,101,127,50,50\n0,0,0,0,0,0,21,0,0,0,21,84,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,63,42\n127,0,0,0,31,0,31,0,0,0,0,0,0,0,31,63,31,0,31,31,0,0,0,0,63,63,0,0,63,95,0,31,31,0,0,0,0\n0,0,0,0,0,0,0,0,25,0,0,25,25,50,0,76,127,0,50\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,127\n0,0,0,0,0,0,31,31,127,0,127,0,0,0,31,31,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,95,31,95,63,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n63,0,31,7,47,87,127,95,47,47,47,47,15,31,39,55,7,95,95,55,31,39,0,15,31,0,31,7,39,7,103,119,79,87,71,23,47\n0,0,0,0,0,0,0,0,0,18,18,0,0,0,36,72,54,54,0,127,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n50,127,38,88,0,38,38,38,12,25,12,12,25,25,0,25,12,25,25,12,63,63,76,101,101,38,76,38,12,0,50,12,25,38,12,76,76\n42,105,63,127,21,0,0,21,0,0,0,21,0,0,0,0,0,21,0\n127,83,83,35,107,37,10,30,10,15,10,21,17,10,0,2,8,0,4\n0,0,0,36,18,0,0,18,0,0,0,0,0,0,0,0,0,0,0,18,18,90,90,18,36,54,127,36,0,0,0,0,0,0,0,0,0\n0,4,0,4,0,4,0,0,0,0,4,0,4,0,4,4,127,122,18\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,7,77,127\n127,127,63,63,127,15,31,63,15,0,63,0,0,31,0,15,15,15,15,0,15,15,0,47,15,31,31,15,15,63,111,111,47,95,79,79\n36,127,45,9,45,9,18,18,0,18,18,0,18,9,0,0,0,27,9,18,0,0,0,18,18,0,9,9,18,18,36,36,99,54,81,72\n0,0,0,0,0,0,0,0,0,0,25,76,38,25,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,25,12,0,12,0,25,38,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,42,42,0,84,84,42,84,84,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,42,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,63,63,31,127,31,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,42,84,0,0,84,0,0,0,42,0,84,127,0,0,0,0,84,0,0,0,0,0,42,0,0,42,42,84,42,0,0,84\n0,0,0,0,0,0,0,63,0,63,127,0,0,0,63,0,63,0,0\n23,115,103,115,115,92,103,46,103,80,127,103,69,23,11,46,11,34,0\n0,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,127,31,127,63,31,95,0,0,0,0,0,0,0,0,0\n127,25,101,50,0,0,50,25,0,0,0,0,0,50,0,0,25,25,25,0,0,0,50,0,0,0,0,25,25,25,76,0,50,0,0,25\n63,95,0,63,0,0,63,31,0,0,0,0,63,31,0,0,31,0,0,0,0,0,0,0,31,0,63,95,63,63,63,127,31,0,0,31\n0,0,0,0,0,0,0,0,0,0,0,76,25,0,50,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,101\n0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,25,25,25,50,0,25,0,0,0,0,25,127,50,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,10,10,42,105,127,95,21\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,0,31,95,31,63,95,0,31,31,31,0,0,0,0,0,0,0,0,0,0\n0,14,0,0,0,28,0,14,14,42,127,84,42,0,14,28,0,42,0\n127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,42,42,42,0,0,42,0,42,42,0,0,0,0,0,0,0,0,127,42,42,42,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,63,95,0,31,31,63,127,0,31,0,0,0,0,0,0,0,0,0,0,0,0,31,63,0,31,63,0,0,127\n0,0,0,0,0,63,47,15,95,127,63,31,47,47,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,47,127\n0,63,0,31,0,0,0,31,0,63,31,31,0,0,63,31,95,0,127\n70,21,28,21,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,28,49,77,77,127,56,21,49,0,0,0,0,0\n0,0,0,0,0,0,31,31,0,0,0,127,31,0,31,63,0,0,31,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,63,0\n0,0,0,0,0,0,0,9,9,27,36,45,81,72,9,72,90,45,27,0,9,0,0,0,0,0,0,0,0,0,0,0,18,36,99,99,90,72,27,81,127,36,36,9,0,0,0,0,0,0,0,0,0,0,0,18,36,27,36,45,9,36,54,45,63,36,9,18,9,9,0,0\n0,0,0,0,0,0,0,0,10,31,63,31,42,42,42,95,52,116,31,0,0,0,0,0,0,0,0,0,0,0,0,10,21,84,42,127,116,63,105,95,95,95,0,10,0,0,0,0,0,0,0,0,0,0,0,0,21,42,52,42,63,42,95,42,63,42,31,21,10,10,0,0\n127,52,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,50,101,0,127,101,0,25,0,25,0,25,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,35,0,28,56,127\n0,0,0,0,0,0,0,0,9,9,0,0,0,0,9,27,63,117,127,72,27,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,76,25,0,0,0,76,127\n0,0,0,0,0,0,0,0,21,127,0,0,0,0,0,21,0,0,0,0,0,21,0,0,0,0,0,21,21,0,0,0,21,0,0,0,0\n42,21,42,21,0,0,0,0,42,21,0,0,0,0,0,42,0,0,0,0,0,0,0,21,127,42,21,21,42,0,21,0,0,0,0,0,0\n0,0,63,63,63,127,0,0,0,0,127,127,0,63,0,63,127,63,0\n0,31,0,0,0,0,0,0,31,31,0,0,31,0,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,31,127,0,31,0,63,0\n0,0,0,0,0,0,0,63,0,63,127,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,0,63,127,127,63\n0,0,0,0,0,0,0,0,42,84,84,127,127,0,42,0,0,0,0\n127,127,111,31,63,63,47,31,0,0,0,0,0,0,0,0,0,0,0\n0,76,127,76,0,0,127,50,50,0,76,101,50,76,25,25,0,25,0\n0,0,0,0,0,0,0,0,0,127,95,63,63,31,0,0,0,0,0\n36,18,0,0,0,0,72,36,18,36,18,18,0,0,18,18,36,18,72,36,18,36,0,54,36,18,18,36,54,127,72,18,54,36,72,18\n25,50,50,0,50,25,76,0,0,0,0,0,0,0,25,0,0,25,25,76,50,0,0,101,25,127,76,50,50,76,76,101,127,0,0,0\n42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,127,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0\n63,0,0,63,127,63,63,127,127,127,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,127,63,63,63,63,0,0,0,63,0,0\n0,0,0,0,31,63,127,31,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,31,31,0,0,63,63,127,0,31,0,0,0\n0,0,0,0,0,0,0,0,12,12,25,88,63,38,25,63,25,25,0,12,0,0,0,0,0,0,0,0,0,25,0,12,0,76,63,101,127\n0,0,0,0,18,18,18,18,0,36,127,36,18,54,18,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,36\n0,0,0,0,0,0,0,0,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,31,95,127\n0,0,0,0,0,0,0,0,0,0,0,0,31,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,0,127,63,31,95,0,31,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,127,84,42,42,0,0,84,42,0,0,0,0\n0,50,0,25,0,50,76,0,25,76,0,101,127,101,25,0,0,25,0\n14,7,0,7,7,0,0,7,14,22,29,127,82,37,14,29,0,0,0\n0,0,0,0,31,0,0,31,95,63,31,31,0,0,31,0,31,0,63,95,0,63,31,63,63,127,31,31,0,0,31,31,0,63,0,0\n0,0,0,0,0,63,63,31,31,95,95,127,31,0,0,0,31,0,95,0,63,63,0,0,63,95,0,31,0,0,0,0,0,63,0,0\n63,31,95,63,0,0,63,0,0,31,63,63,0,31,63,31,31,0,127\n0,127,84,42,84,84,42,0,42,127,42,127,42,42,127,42,127,0,0\n127,0,0,127,0,63,0,0,63,0,0,0,0,0,0,63,127,63,0,0,0,0,63,0,0,0,63,63,0,0,0,0,127,0,0,63\n127,0,63,127,63,0,0,0,0,0,0,0,0,127,0,127,127,63,63,0,0,0,63,0,0,0,0,0,0,0,0,0,0,63,0,0\n0,0,0,0,0,0,0,0,18,18,54,90,54,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,127,36\n0,31,31,0,31,0,0,0,0,0,31,127,95,31,31,0,0,0,0\n0,0,0,95,0,127,95,0,0,0,0,127,0,0,0,0,0,0,0\n25,19,38,76,38,38,76,69,63,69,127,63,69,31,31,6,12,12,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,55,127\n127,0,0,0,0,0,0,63,127,0,0,0,0,63,0,0,0,63,0\n72,18,0,36,36,36,18,127,72,90,108,54,72,72,54,36,0,36,0\n36,36,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,54,127,72,72,36,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127\n0,0,0,0,0,76,50,0,50,127,0,76,50,50,50,0,0,0,0\n0,0,0,31,127,31,63,31,95,127,127,63,63,0,31,0,31,0,0\n0,0,0,0,0,0,0,0,0,0,31,63,95,127,31,0,0,31,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,31,63,127,127\n0,0,14,14,14,0,0,42,42,42,127,56,42,14,14,0,0,0,28\n0,0,42,42,42,0,127,84,127,84,84,42,84,42,0,0,0,0,0\n0,0,0,0,63,0,0,0,63,63,0,127,0,0,0,0,63,0,0\n0,0,0,0,31,0,0,0,0,31,0,0,31,0,0,0,0,0,127,127,0,0,0,0,0,0,0,0,0,0,0,0,31,63,0,0,0\n31,15,15,127,79,79,63,0,31,0,0,31,31,95,79,31,95,31,95\n0,42,0,84,84,42,0,42,0,0,0,42,84,42,0,42,0,0,0,0,42,0,127,0,0,42,0,127,0,127,0,0,84,42,0,0\n0,31,0,95,0,31,0,0,0,31,0,127,31,0,31,0,0,0,0,0,63,0,95,0,31,0,0,31,0,31,0,63,63,31,0,31\n0,0,0,0,0,0,0,0,0,127,0,127,63,63,0,0,0,63,63,0,0,0,0,0,0,0,0,63,0,63,0,63,63,0,63,127,0\n127,42,42,63,42,21,0,21,0,42,21,21,0,84,84,42,21,0,127\n54,18,36,63,18,0,9,36,63,127,72,63,99,63,18,0,18,0,0\n127,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,70\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,127,56\n0,0,0,0,0,0,0,63,0,127,127,127,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,127,0,0,0\n0,0,0,0,0,18,36,0,9,9,72,127,99,45,27,18,36,0,0,18,0,0,18,0,0,0,9,0,0,27,27,18,0,0,0,18,0\n0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,63,127,63,63,127,0,0,31,0,31,0\n0,0,0,0,0,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,63,63,63,95,0,0,0\n127,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,63,0,63,127,127\n25,12,16,21,46,25,33,46,46,50,25,33,29,71,93,80,42,93,127\n117,87,58,68,68,48,29,9,0,0,0,0,0,0,0,0,9,9,19,29,58,48,97,58,58,127,97,87,68,29,9,0,9,0,0,0,0\n76,25,50,0,25,63,25,12,38,50,76,114,63,127,50,50,25,12,25\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,76,50,101,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,21,0,0,127,63,42,127\n70,70,28,28,56,49,63,35,98,49,28,35,56,70,70,56,84,127,84\n19,29,0,0,0,0,0,9,9,0,0,0,0,9,0,0,19,0,29,9,29,9,39,68,127,68,39,0,48,39,29,0,0,0,0,9,0\n0,0,0,0,0,0,0,0,0,38,0,38,88,127,38,25,0,12,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,36,54,18,18,0,18,36,72,36,72,0,72,127,72\n23,40,34,40,23,69,80,69,92,109,127,109,115,103,34,17,23,23,11\n0,0,0,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,42,42,0,42,21,0,0,0,21,21,0,0,0\n63,95,0,0,0,31,0,31,0,63,31,31,127,0,63,63,63,0,0\n89,127,52,48,52,56,78,67,97,85,108,127,97,100,74,74,63,48,22\n0,101,0,25,25,25,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,25,127,76,127,50,50,25,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,0,0,14,14,70,84,84\n50,76,76,76,76,127,50,25,25,50,0,76,25,101,25,0,0,0,0,25,0,50,0,0,0,0,0,0,25,0,0,0,25,0,0,0\n127,127,63,31,63,95,63,31,63,95,31,0,63,31,95,31,0,0,0,0,63,95,31,31,0,0,0,0,31,0,0,0,0,0,0,31\n0,0,0,0,0,0,42,0,84,0,0,0,0,0,0,0,84,127,42,0,0,0,0,0,0,0,0,84,0,0,0,84,127,0,0,0,0\n76,127,25,38,12,0,0,0,12,0,0,0,0,0,0,0,12,12,12,12,25,25,0,12,88,25,25,38,25,0,12,25,0,0,12,0,0\n63,47,31,79,63,79,127,79,31,47,31,15,47,31,0,47,15,79,0,15,15,111,47,15,47,31,47,47,15,111,79,95,15,63,0,95,31\n127,63,0,0,127,63,0,0,0,0,0,0,127,127,0,63,0,0,0,0,0,0,63,0,0,0,0,0,63,0,0,0,0,0,0,0,0\n0,0,0,42,42,42,0,0,0,0,0,0,42,0,127,42,0,42,42,0,42,42,42,84,84,42,0,127,84,84,84,84,0,84,42,0,0\n127,0,0,0,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,31,95,0,0,0,31,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,1,4,17,30,55,55,41,31,25,22,25,16,3,1,1,0,0,0,0,0,0,1,1,4,3,2,7,22,70,127\n0,0,0,0,0,0,63,42,0,42,0,63,0,63,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,63,127\n0,0,0,0,0,0,1,1,16,46,63,66,73,30,13,12,4,1,0,1,0,0,0,0,0,0,0,0,0,2,0,1,0,9,11,63,127\n0,0,0,0,0,0,0,11,0,23,11,46,127,103,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,23,69\n0,127,63,0,0,0,0,127,63,127,0,0,0,0,63,63,63,63,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,25,25,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,63,15,15,63,31,47,31,15,15,0,15,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,127,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,127,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,42,0,0,127,42,42,84,0,84,42,0,42,0,0,0\n84,0,0,0,0,0,42,84,42,84,127,127,127,0,0,42,0,0,0\n0,0,0,0,0,0,0,0,0,25,76,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,127,50\n0,0,0,0,0,0,0,0,0,0,0,101,50,25,0,76,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,101,50,25,0,25,127,76,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,101,50,101,0,50,50,25,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,21,63,42,21,63,127,42,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,63,63,0,21,21,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,21,0,42,84,21,42,21,21,42,21,0,0,0,0,0,0\n0,0,0,0,0,0,42,0,42,0,0,0,42,42,42,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,84,0,42,42,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,0,0,84,0,0,0,0,42,42,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,31,127,63,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,0,0,0,0,31,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,31,63,0,31,95,0,31,0,0,0,0,0,0,0\n0,0,0,21,42,127,63,0,21,42,21,42,63,0,21,0,0,0,0\n19,9,9,48,78,19,127,29,48,9,78,29,78,9,9,19,9,9,19\n71,45,116,91,60,127,127,76,55,76,30,30,40,40,71,71,91,96,71\n0,0,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,42,0,127,0,0,0,0,0,42,0,0,0,42,0,42,0\n0,42,0,42,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,84,42,0,0,0,0,0,0,0,0,0,0,42,42\n0,0,0,84,84,0,0,0,0,42,127,84,84,0,0,127,0,0,0\n0,63,31,63,63,31,0,0,63,0,95,31,31,31,95,0,0,0,127\n112,56,70,56,42,42,14,28,28,112,56,28,56,42,127,112,70,28,28\n0,0,0,0,0,0,5,16,77,49,5,0,0,0,22,127,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,60,71,0,0,0\n0,0,0,0,0,0,0,0,0,42,0,84,0,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,0,84,0,42,42,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,127,0,0,0,0,42,84,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,63,0,63,0,63,127,127,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,63,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,63,63,0,0,63,63,63,127,0,0,0,0,0,0,0,0\n0,42,0,42,0,0,84,0,0,0,127,84,42,42,42,127,0,42,0\n50,38,63,38,50,50,76,76,63,63,76,101,25,38,76,38,38,127,50\n0,0,0,5,0,15,0,20,25,76,106,127,91,10,5,5,0,0,0\n57,66,83,84,78,69,81,60,102,127,105,92,65,83,71,48,60,71,36\n50,76,50,12,0,12,12,0,25,0,0,0,0,0,0,0,0,0,0,0,0,25,38,50,127,101,76,12,0,12,0,76,0,0,0,0,0\n0,21,0,21,0,0,0,0,42,105,127,105,42,42,21,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,36,18,0,18,18,0,0\n0,0,0,0,25,25,25,25,25,76,127,101,25,76,25,0,0,25,0\n109,123,106,116,61,127,106,65,68,120,113,92,82,92,116,109,106,72,75\n101,25,76,127,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,25,76,76,25,25,50,0,0,0,0,0,0,0,25,0,0\n0,84,0,0,0,0,0,0,0,0,127,0,0,42,0,0,0,0,42,0,0,0,0,42,42,42,0,0,0,42,0,42,0,0,42,0,0\n0,0,0,0,0,0,18,0,0,72,0,18,108,72,90,18,36,36,0,0,0,0,0,0,0,0,0,0,0,0,0,18,36,36,127,54,36\n0,0,0,0,0,0,0,0,21,105,84,21,21,21,127,21,0,0,21,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,84,105,0\n0,42,0,0,42,0,42,127,0,0,42,42,42,0,0,42,42,42,0\n6,16,20,13,23,10,20,23,40,43,56,73,90,127,30,33,3,3,0\n0,42,84,84,0,127,0,0,0,42,42,0,0,0,42,0,42,42,0\n127,69,69,39,11,3,5,7,9,51,91,105,75,59,53,29,19,15,3\n22,50,60,68,57,100,127,118,100,75,60,49,33,55,60,64,92,111,114\n30,68,98,79,49,11,1,1,3,43,83,108,87,127,104,58,39,0,0\n84,63,84,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,127,72,0,36,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,95,31,63,127,0,0,63,0,0,0,0,0\n0,0,0,25,50,50,127,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,25,12,38,50,12,0,0,0,38,25,0,38,0,12,38,12,0,25\n63,0,95,31,31,31,127,31,95,31,63,31,63,0,0,31,0,0,0\n0,0,0,0,0,0,0,0,31,63,31,127,127,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,36,6,127,36,24\n0,0,14,56,0,28,14,70,0,42,84,28,56,98,28,28,42,14,28,70,28,14,14,0,0,0,14,84,28,14,14,14,127,112,28,0,28\n0,0,0,0,0,0,0,0,25,25,0,0,0,0,25,101,0,0,0,25,25,25,25,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,25,25,0,0,0,0,0,0,0,0,50,0,0,0,0,25,0,127,25,76,0,0,0,0,0,50,0\n0,0,0,0,0,0,0,0,50,0,0,0,25,25,0,50,25,0,0,0,0,0,50,76,0,0,0,0,0,0,0,0,25,25,0,0,0,0,0,50,0,25,0,0,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,50,0,0,127,50,50,0,25,25,50,0,0,0\n0,0,0,0,0,0,0,0,0,101,50,76,0,25,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,25,50\n106,103,96,100,95,103,98,110,121,101,103,94,70,96,84,86,82,103,127\n124,67,34,41,25,28,15,17,2,2,8,0,4,7,4,4,11,5,11,31,46,21,24,79,127,105,83,33,30,56,25,18,10,11,12,5,17\n69,23,69,34,92,92,92,127,115,92,34,57,80,57,0,11,23,92,46\n127,31,31,63,31,31,0,0,31,127,31,0,31,63,31,0,31,63,0,63,0,0,31,63,31,31,31,63,31,0,63,0,0,0,63,63,0\n127,63,84,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,63,42,42,63,105,0,0,42,0,0,0,0,0,0,0,0\n127,45,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,27,63,72,27,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,63,63,63,63,0,63,63,63,0,63,0,0,63,63,0,0,0,0,0,0,0,0,0,0,63,0,0,127,0,127,0\n0,42,0,127,42,0,0,42,0,0,0,0,0,0,0,0,0,0,42,0,0,0,42,0,84,84,0,0,0,0,0,42,42,0,0,0,0\n0,0,0,0,0,0,0,0,10,21,31,58,68,68,15,5,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,21,68,127\n0,0,0,0,0,42,0,42,42,42,0,42,42,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,42,0,127,42,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,76,25,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,25,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127,101,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,25,50,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,84,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,127,0,0,42,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,42,42,0,0,0,0,0,84\n0,0,0,0,0,0,0,42,0,0,0,0,84,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,0,0,42,42,42,0,0,0,0,42,0,0,0,0,0\n0,42,42,0,0,0,0,42,0,42,42,0,0,0,0,42,0,42,0,0,0,42,42,127,0,42,0,0,0,0,0,42,0,42,84,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,63,63,127,84\n0,0,0,0,63,63,0,63,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,63,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,127,0,63,0,0,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,63,0,63,0,0,0,0,0,0,0,0,0,0\n0,0,0,36,0,36,0,0,18,18,0,18,0,18,0,0,0,0,0,0,36,18,18,18,127,90,54,72,90,54,0,18,0,0,18,0,0\n0,0,0,0,0,0,0,0,0,0,42,0,42,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,0,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,127,42,42,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,0,127,63,127,63,63,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,127,127,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,25,50,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,127,101,0,0,0,0,0,0,0,0,0,0\n90,54,72,90,54,18,0,0,0,0,9,0,0,0,0,9,0,0,0,0,0,0,0,0,18,27,36,54,117,81,108,117,90,45,127,63,54\n63,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,95,31,127,63,0,31,31,31,31,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,42,42,42,42,0,0,42,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,29,0,9,39,68,97,78,127,107,58,19,9,9,0,9,9,0,9,19,0,0,0,0,9,9,19,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,127,0,21,42,21,0,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,28,14,0,14,70,14,28,14,0,28,28,0,28,0,14,0,14,0,42,112,112,56,127,98,70,28\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,21,31,0,42,10,31,52,10,10,0,10,21,21,10,0,0,10,21,31,42,95,116,127,74,52,31,42\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,63,0,63,0,127,0,0,0,0,0,0,0,0,0,63,127,63,0,127,63,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,42,0,0,84,127,84,42,84,42,0,42,0,42,0,0,0,84,84,0,0,0,0,0,0,0,127,42,42\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,0,0,0,0,0,0,31,63,0,0,127,63,0,0,31,0,63,31,95,31,31,0,0,31,0,31,0,31,31,31\n0,127,42,0,21,21,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n63,31,63,31,95,31,0,0,0,0,0,0,0,31,31,0,0,0,0,31,0,63,63,31,127,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31\n0,0,0,0,31,127,0,127,31,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,76,127,25,25,25,0,0,0,0,0,0,25,25,50,50,101,0,25,25,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,63,95,95,31,31,0,0,0,0,0,0,0,0,0,127,63,95,31,95,0,31\n0,0,0,127,50,50,25,25,0,0,25,0,0,0,0,0,0,0,50,0,0,25,25,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,12,76,127,50,12,0,38,0,0,0,0\n10,7,0,7,2,5,2,17,7,5,5,5,12,10,30,53,63,81,127\n0,0,0,0,0,0,0,28,0,0,0,0,0,0,0,0,14,14,28,56,70,127,0,14,28,0,0,14,14,0,0,0,0,0,0,0,0\n0,0,0,0,6,0,0,0,0,0,6,0,0,0,6,25,44,114,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,50,0,50,0,0,127,76,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,127,76,50,76,0,0,0\n0,0,0,9,27,9,9,0,9,36,18,18,27,18,54,63,27,127,108\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,50,0,127,0,50,0,25,0,0,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,38,12,25,0,0,12,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,28,127,112,70,28,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,34,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,105,42,127,63,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,72,108,127,36,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,127,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,50,25,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,63,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,63,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,127,63,31,0,63,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,9,9,29,127,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,29,19,39,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,12,0,25,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,25,12,12,0,0,0,0,0,0,0\n120,102,100,67,65,56,33,28,23,20,31,15,15,15,13,15,24,22,45,41,55,68,97,101,126,127,116,95,50,55,35,32,20,13,12,18,3\n63,0,0,15,31,15,0,0,15,15,0,0,15,15,47,15,15,31,31,0,47,63,0,15,79,47,15,15,15,31,127,0,47,0,0,15,0\n127,15,15,0,0,15,15,15,0,0,0,0,0,0,15,15,0,0,0,0,0,47,0,0,63,31,15,0,15,0,0,0,15,31,15,0,0\n30,40,50,45,35,20,15,20,20,0,10,30,15,35,40,40,76,111,106,50,71,86,127,81,91,66,81,50,15,30,35,5,5,10,5,10,0\n0,63,127,127,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,0,63,63,127,63,127,0,0,0,0,0,0,0,63,0\n97,127,58,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,39,21,42,74,31,50,23,39,127\n80,33,73,60,26,26,0,20,26,6,6,26,0,13,40,13,26,26,86,66,66,127,113,46,100,100,40,73,66,46,53,33,13,6,13,13,40\n127,90,90,81,18,36,18,0,0,0,0,0,0,0,0,0,0,0,0,0,9,0,9,9,18,9,0,18,18,0,18,9,0,9,0,9,36\n0,31,31,0,0,0,0,0,0,0,31,0,0,0,0,0,0,31,31,0,0,0,0,31,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,127,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,95,0,0\n0,0,0,0,42,127,0,0,42,0,0,0,0,0,0,0,0,42,42,84,42,42,0,0,0,0,0,84,42,0,42,0,42,0,0,0,0,0,42,42,0,0,42,0,0,0,0,0,0,0,0,0,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,42\n63,0,63,0,0,63,63,0,0,0,0,0,0,0,0,0,0,63,127,0,127,0,0,0,63,0,0,0,0,0,63,0,63,0,0,127,0,0,63,127,63,0,127,63,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,63,0,0,0\n0,0,0,0,0,0,0,0,0,0,31,47,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63\n0,0,0,0,0,0,0,0,0,0,0,127,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,95,63,31,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,14,14,70,127,84,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,14,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,95,127,63,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,101,127,25,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,6,13,13,33,6,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,86,127,113,6,20,26,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,23,57,69,46,11,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,103,92,103,127,46,11,46,0,11,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,0,0,127,50,0,25,0,25,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,42,21,127,21,21,21,21,0,0,0,0,0\n0,0,0,11,11,0,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,34,127,92,34,23,11,11,0,57,0,0,0,0,11\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,108,54,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,42,105,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,11,23,11,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,11,46,103,115,127,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,95,111,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,42,42,84,84,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,39,55,127,63,23,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,23,79,47,111,47,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,101,63,127,38,25,0,0,0,0,0,0,0,12,0,0,88,0,50,0,12,76,101,50,114,12,0,12,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,31,31,0,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,31,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,72,127,54,72,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,50,76,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,127,0,50,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,31,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,127,31,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,4,22,9,18,58,58,127,86,40,18,4,4,0,0,0,0,0,0,9,0,0,0,0,4,4,18,63,49,54,90,63,54,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,18,36,31,27,36,13,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,8,0,13,52,48,127,43,13,0,0,0,8,0,0,0,0,0,0,0,0,0,8,0,0,17,8,21,13,70,74,21,8,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,8,43,35,39,26,4,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,84,0,84,84,0,84,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,50,25,0,0,127,127,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,72,18,36,18,0,18,127,108,36,0,0,0,0,0,0,0,0,0,18,18,0,90,0,108,90,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,63,31,15,0,0,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,63,111,95,47,31,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,95,95,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,9,29,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,5,25,127,65,25,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,7,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,31,47,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,0,0,0\n0,42,84,42,42,127,42,0,42,0,42,0,42,0,0,42,0,42,0,0,0,0,127,0,42,42,0,42,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,31,31,63,127,111,127,0,15,0,15,15,0,31,0,0,0,31,47,0,0,0\n127,63,63,0,63,0,0,0,0,63,0,0,63,0,0,0,0,63,0,0,63,0,63,63,0,63,63,0,0,0,0,0,63,63,63,0,0\n0,0,0,0,0,0,0,0,0,63,63,63,63,127,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,127,0,0,127,0,127,0,127,0,127,0,0,0,0,0,0,0,0,0,0,0,0,127,0,127,0,127,127,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,127,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,31,0,0,0,127,95,95,95,63,0,63,31,63,0,63,63,31,63,31,63,0,95,95,63,95,63,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,63,95,63,127,0,63,0,0,31,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,84,0,0,0,0,0,0,42,0,42,0,127,0,0,84,127,42,42,84,127,0,42,42,0,0,0,0,0\n63,21,21,42,21,0,127,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,21,0,0,0,21,105\n0,0,0,0,0,0,0,0,0,2,4,12,19,42,49,75,86,95,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,42,127,84,84,70,42,28,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,1,0,1,0,2,15,24,62,109,127\n0,0,0,0,0,0,0,0,0,0,0,31,31,127,63,63,0,31,127\n0,0,0,0,0,0,5,1,1,3,10,14,21,40,36,44,83,123,127\n0,0,11,0,0,0,5,16,0,0,0,0,5,0,5,11,0,5,55,66,71,127,60,127,93,49,16,5,5,16,0,0,5,0,0,0,0\n0,0,0,0,0,0,25,0,25,50,76,127,50,101,127,50,0,25,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,5,5,5,17,51,121,127,127,40,5,86,69,34\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,19,39,127,87,107,68,39,9,9,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,36,72,18,72,72,36,36,72,36,72,54,127,90,54,72,72,90,90,90,18,0,0,0,0,0,0,0,0,0\n0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,72,18,127,36,18,18,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,63,63,0,63,0,127,63,127,0,0,63,127,63,63,127,0,63,0,0,0,0,0,63,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,84,84,127,105,84,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,18,63,127,82,22,37,26,18,7,14,0,3,3,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,18,36,18,127,90,54,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,3,0,0,3,0,12,21,45,69,87,102,127,42,27,9,6,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,3,24,27,18,66\n0,0,0,0,0,0,0,0,0,63,63,0,31,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,31,31,0,0,0,0,0,0,0\n0,0,0,0,0,0,50,25,0,0,50,25,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,42,0,84,0,42,0,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,42,42,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,42,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,31,31,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,127,31,31,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,31,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,84,0,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,0,42,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,42,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,12,63,127,50,19,25,38,19,12,6,12\n0,63,0,31,0,0,0,63,0,31,31,31,31,63,31,127,95,63,0\n71,39,43,23,15,27,27,31,43,51,39,75,63,79,127,103,63,95,79\n63,31,0,31,31,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,95,127,127,0,63,0,95,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,12,38,25,127,12,12,38,0,0,0,0\n0,0,0,0,0,0,25,25,0,76,25,25,101,50,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,127,101,127,101\n25,50,127,127,50,76,76,25,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,76\n63,31,63,127,0,0,31,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,127\n50,50,127,76,50,25,25,0,0,0,0,50,0,25,0,25,25,0,0,0,50,0,0,0,0,0,0,0,0,25,25,0,101,25,50,25\n76,50,25,101,76,127,50,50,25,101,0,25,0,0,25,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,0\n0,63,63,21,0,0,0,0,0,0,0,42,21,0,0,0,21,42,21,0,21,42,84,63,21,21,42,21,42,42,21,127,21,21,42,0,0\n23,127,34,34,23,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,11,11,0,0,0,0,0,34,57,23\n0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,63,31,127,31,0,95,0,0,31,0,0,0,0,0,0,0,0,0,0\n0,25,38,25,12,0,0,12,0,12,0,25,25,38,63,127,63,38,25\n127,63,0,7,0,0,0,7,0,0,23,23,71,95,111,39,39,55,63\n0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,42,0,84,0,0,42,127,42,42,0,0,0,0,0,0,0\n28,42,28,84,42,28,42,28,28,0,14,0,14,0,28,14,14,14,28,14,42,127,14,70,56,14,42,0,14,42,42,14,14,14,42,0,0\n0,0,42,0,127,42,0,0,0,0,0,42,0,0,0,0,0,0,0,42,42,0,42,0,42,0,0,0,0,0,84,0,0,42,0,0,0\n42,42,63,21,21,42,42,21,0,0,21,21,21,42,42,0,21,21,0,21,84,105,21,42,21,127,21,63,21,0,63,63,0,0,21,42,0\n0,0,0,101,25,0,0,0,0,0,0,0,0,127,50,0,50,0,0\n0,31,0,31,0,0,31,0,0,31,0,0,0,0,0,31,0,31,0,0,31,0,0,63,0,0,0,0,0,0,0,31,63,0,31,31,127\n121,93,71,22,33,49,38,33,27,22,22,0,11,11,16,5,44,22,27,82,66,115,110,104,121,127,93,77,99,88,44,38,5,16,38,16,44\n127,105,63,21,0,21,0,0,0,0,0,0,0,0,42,42,21,42,84,21,21,63,105,63,21,42,21,0,0,21,0,0,0,21,0,0,0\n0,31,0,31,0,31,31,0,0,0,95,0,0,0,0,0,0,0,0,0,0,31,0,31,31,0,31,127,31,63,31,0,0,31,0,0,127\n127,66,31,51,25,5,14,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n107,127,95,51,29,11,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,14,0,42,42,77,91,127,98,112,21,7,42,28,56,84,14\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,42,0,127,0,42,84,84,84,84,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,3,13,27,45,64,107,127,118,118,118,125,99,69,64,78,114\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,0,5,23,0,34,23,46,75,109,127,109,109,121,121,115\n0,0,0,0,25,25,25,0,0,0,0,0,25,0,0,25,0,0,0,0,50,25,127,50,50,50,76,0,0,0,25,25,0,0,0,0,0\n16,0,8,0,0,0,0,16,8,0,0,8,0,8,0,8,0,0,50,67,127,59,16,0,0,16,0,8,8,8,0,8,8,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,25,101,25,25,0,101,76,101,127,0\n127,0,0,31,0,15,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,0,15,0,0,31,0,0,0,0,0,0,0,0,0\n42,63,42,52,52,31,21,31,31,10,10,0,0,0,21,0,10,0,21,10,63,10,31,21,42,127,95,21,42,42,21,0,31,10,10,31,0\n127,127,111,0,0,15,15,0,15,0,0,0,0,0,0,0,15,31,0,15,47,15,15,0,0,0,15,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,127,95,31,0,63,127,63,63\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,7,7,0,0,23,15,31,31,79,103,119,127,95,87,63,15,0\n63,31,0,0,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,31,63,31,31,31,63,31,127,63,31,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,42,63,127,42,21,0,21,0,63,0,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,127,63,63,63,21,21,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,27,99,127,72,36,9,0,0,0,9,0,9,27,18,0,9,18,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,84,56,42,14,14,28,14,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,9,27,27,54,9,18,18,18,27,9,0,0,0,0,0,0,18,18,18,54,81,127,27,18,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,12,25,12,0,0,0,12,25,12,0,12,38,0,0,0,25,50,63,114,127,101,101,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,31,0,31,0,31,127,63,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,84,84,127,127,0,42,0,42,0,0,0,0,84,42,84,127,84,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,0,50,76,25,76,0,0,25,0,0,0,0,25,0,50,76,50,127,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,0,0,0,0,0,0,0,21,21,63,105,127,84,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,76,50,0,25,0,0,25,0,0,25,25,25,50,127,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,14,0,14,127,28,14,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,14,0,14,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,15,47,95,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,127,50,76,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,95,127,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,84,42,21,0,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,42,42,127,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,42,0,0,42,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,11,46,80,80,127,69,46,11,0,0,0,0,0,0,0,11,11,0,0,0,0,0,0,23,80,57,46,80,92,92,69,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,46,11,57,115,115,103,11,11,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,7,39,103,55,15,31,55,31,7,0,0,0,0,0,7,7,0,0,0,0,0,0,0,15,31,47,47,55,111,23,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,31,39,79,127,63,7,7,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,127,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,42,42,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,18,127,36,9,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,127,56,42,42,84,14,0,14,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,47,95,111,95,127,95,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,105,84,42,21,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,127,127,95,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,70,56,98,84,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,14,70,14,28,14,28,14,0,14,28,14,14,0,0,0,0,0,0,0,0,14,127,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,127,31,42,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,42,52,21,10,10,0,0,0,0,0,84,21,10,10,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,18,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,0,127,18,36,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,21,31,63,31,10,0,0,0,0,0,0,0,0,0,0,0,0,10,21,10,52,52,42,127,42,10,10,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,7,87,0,0,0,23,39,7,0,0,0,0,0,0,0,0,0,0,0,23,23,47,79,127,31,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,3,8,71,119,35,14,7,1,3,3,0,0,0,1,3,3,0,0,1,0,12,12,23,67,127,96,28,7,3,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,2,13,109,64,18,7,2,0,0,0,0,0,0,5,1,0,0,0,0,0,0,11,13,55,127,72,16,9,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,31,127,63,31,0,0,0,0,0,63,0,0,0,0,0,0,31,0,0,0,95,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,31,0,0,0,0,0,0,0,127,31,31,0,0,63,0,31,0,63,0,127,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,63,95,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,14,14,14,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,28,42,56,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,14,56,127,127,14,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,25,50,25,50,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,76,127,50,25,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,127,117,19,9,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,18,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,81,127,72,9,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,13,6,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,13,100,113,127,40,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,25,127,76,127,76,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,50,25,50,0,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,97,81,64,47,28,33,27,37,17,20,7,6,9,11,6,3,5,1\n95,79,95,63,31,15,127,47,47,79,31,31,15,31,0,31,0,0,63\n127,63,67,33,4,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,4,16,16,46,38,29,8,8,25,8,8,12,12,12,0\n84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,84,127,42,42,42,0,42,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,79,15,0,0,15,15,0,79,31,47,127,31,31,63\n127,90,86,97,73,104,108,82,84,57,59,55,22,25,27,15,28,33,38\n122,127,83,30,4,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,17,13,39,39,26,61,52,48,43,21,13,43,4,4,0,35\n0,0,0,0,0,0,0,25,127,76,76,50,0,0,0,0,0,25,50\n127,58,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,0,0,0,0,0,0,0,0,0,0,10,42,10,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,63,31,0,0,63,63,63,0,0,0,31,31,0,0\n28,17,34,11,0,0,11,5,0,5,5,0,5,0,0,0,0,0,0,0,0,0,0,5,5,5,5,28,11,57,63,109,80,127,75,51\n19,25,31,0,12,0,6,6,0,0,0,0,0,0,0,0,6,0,0,0,6,0,0,6,12,12,6,6,44,44,82,101,82,127,57,95\n0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,63,0,127,0,0,0,0,0,0,0,0,63,63,63,127,63,0,0,127,63,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,14,0,42,0,28,56,28,56,0,28,70,42,84,112,84,127,70,42,42,0,14\n18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,0,90,18,0,18,18,54,18,54,18,18,36,90,36,54,72,72,127,90,0,18,72,72\n25,0,0,0,25,0,127,50,0,0,0,0,0,0,0,25,25,25,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,42,127,42,84,84,0,84,127,42,0,0,0,0,42,0,0,84,0,42,42,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n65,66,127,73,53,70,39,15,22,8,6,5,6,6,12,8,5,3,12,6,13,15,12,30,34,51,32,41,65,53,66,53,29,46,60,53\n114,99,114,52,44,54,34,39,19,24,17,4,7,2,12,7,4,12,19,12,22,49,42,64,127,102,69,69,87,79,49,82,62,94,79,94\n36,36,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,54,108,36,18,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0\n28,28,14,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,42,127,70,14,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,14,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,42\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,127,0,42,42,42,0,0,84,42,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,127,0,0,0,63,127,127,63,127,63,63,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,127,0,63,31,0,63,0,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,36,36,36,36,127,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,21,21,21,0,52,21,52,84,31,42,116,21,42,0,0,0,10,10,21,21,10,10,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,74\n115,69,34,11,34,23,23,69,80,57,34,127,11,11,0,0,0,11,23,23,11,11,11,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,34,80\n42,0,21,0,0,0,21,21,0,42,21,42,21,0,0,0,21,21,21,21,0,0,0,0,0,0,0,21,21,63,63,105,127,105,63,42\n31,47,15,47,0,0,15,0,0,47,47,15,31,0,0,31,0,15,15,15,0,0,0,0,0,0,0,0,0,47,127,111,47,15,63,31\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,11,57,127,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,46,127,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,0,5,22,127,82,66,93,66,82,16,27,11,11,0,22,0,0,38,5\n0,5,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,5,0,0,15,127,76,66,101,50,81,25,10,5,10,0,20,0,0,30,10\n127,25,88,25,12,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,63,63,25,0,25,25,12,12,0,0,0,0,0\n0,0,0,0,0,50,127,50,0,0,0,25,25,25,25,0,0,0,0,0,0,0,0,0,0,0,76,127,50,0,0,0,0,0,0,25,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,95,0,127,95,0,31,0,63,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,42,127,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,127,0,63,127,0,63,0,0,127,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,127,0,0,50,25,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0\n42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,127,0,0,63,0,0,0,0,0,0,0,0,31,63,0,31,31,31,0,31,0,0,0\n0,0,0,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,101,127,25,50,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,17,21,33,64,36,18,6,1,0,1,0,0,0,0,0,0,0,0,0,0,1,0,1,1,8,39,52,127\n0,0,0,0,0,0,18,0,0,36,0,0,0,18,18,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,72,72\n0,0,0,0,0,0,0,0,0,112,127,0,28,14,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,42,14\n0,0,0,0,0,0,33,30,30,33,73,127,23,3,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,16,60,113\n0,0,0,0,0,0,0,0,0,0,63,0,21,42,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,42,42,127\n0,0,0,0,0,0,0,0,0,54,0,54,127,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,15,0,15,127,15,47,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,127,112,28,56,14,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,18,18,27,90,18,18,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,72,127,108,54,45,9,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,31,95,95,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,47,47,111,127,63,15,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,21,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127,105,0,0,0,0,21,0,0,0,0,0\n0,0,0,0,0,0,0,14,14,28,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,28,28,84,127,70,28,0,0,42,0,70,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,15,0,7,7,0,0,0,47,127,95,71,7,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,90,18,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,0,0,0,54,127,90,72,54,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,95,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,0,0,127,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,25,50,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,101,127,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,42,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,84,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,84,84,127,0,0,0,0,0,0,0,0,0,0\n0,0,42,42,0,0,0,0,0,0,42,127,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,79,127,47,15,47,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,45,127,72,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,8,67,50,118,127,93,33,59,0,8,0,8,0,0,0,0,0,8,0,0,0,8,8,76,50,25,16,33,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,78,96,102,127,78,18,24,30,12,12,6,6,0,0,6,6,0,12,12,12,6,0,36,0,18,30,30,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,10,0,0,0,0,0,0,5,0,5,0,0,0,0,0,0,5,15,30,50,111,127,10,20,10,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,63,95,31,127,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,127,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,92,127,28,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,28,17,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,42,0,84,127,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,31,127,111,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,15,31,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,36,127,108,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,31,0,0,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,127,31,31,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,21,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,84,63,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,105,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,127,127,63,95,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,23,46,0,0,0,0,11,11,0,0,11,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,103,127,34,11,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,42,84,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,0,127,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,84,42,42,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,6,0,0,24,42,78,127,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,18,12,36,24,12,0,0,0,6,0,0,0,0\n0,0,0,0,0,5,11,5,0,17,63,115,127,34,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,40,40,5,0,5,11,5,5,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,0,0,31,63,63,0,0,127,127,95,0,31,0,31,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,14,14,28,0,127,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,42,56,70,14,28,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,21,21,21,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,127,127,105,42,127,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,42,127,84,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,47,127,47,31,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,101,127,25,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,50,25,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,7,28,56,127,119,77,21,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,52,10,31,127,116,31,0,0,10,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,25,25,127,12,25,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,84,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,25,50,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,25,25,0,0,0,0,0,0,0,0,0,0,0,25,25,0,0,76,50,25,25,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,18,127,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,36,18,0,0,0,18,0,0,0,0,18,0,0,0,0,0,0,0,0,36,0,36,18,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,31,0,63,0,0,0,0,0\n0,0,0,0,0,0,0,0,84,0,0,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,15,31,31,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,63,0,31,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,31,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,36,36,90,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,127,108,54,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,0,0,36,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127,42,0,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,21,0,0,0,21,0,0,0,0,21,0,21,0,0,0,0,0,21,0,0,0,0,0,63,0,0,21,0,21,0,0,0,0,0,0,127\n0,0,0,0,0,0,0,7,0,14,44,59,127,29,52,14,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,7,29,52,119\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,9,13,30,55,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,21,42,21,105,21,127\n0,0,0,0,0,0,0,0,31,127,31,63,0,31,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0\n0,0,0,0,0,0,0,0,0,8,8,127,127,101,33,42,33,8,16,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,8,16,0\n0,0,0,0,0,0,0,0,0,47,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,15,63,127,95\n127,42,42,21,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,0,0,42,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,42,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,42,84,42,127,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,42,0,84,84,127,84,0,42,105,0,42,0,0,0,42,42,0,0,42,0,0,0,0,0,0,0,0,0,0,0,42,42,0,0,0\n0,0,0,0,0,25,25,25,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,101,0,0,0,0,127,101,25,0,0,25,0,0\n0,0,0,0,0,0,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,25,127,101,25,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,127,25,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,127,28,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,42,42,0,0,0,0,0,127,42,84,127,42,0,84,0,0,42,0,0,0,0,42,42,0,127,42,42,84,0,84,0,0\n0,0,0,0,0,25,0,0,0,0,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,127,0,25,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,63,63,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,63,127,0,63,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,25,25,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,25,50,127,50,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,50,50,25,0,0,0,25,0,0,0,0,0,0,0,0\n95,31,31,31,63,63,127,47,15,31,15,31,63,31,31,79,111,95,127\n71,87,61,68,74,58,61,52,104,127,71,78,113,61,26,39,32,35,52\n0,63,63,0,0,0,0,0,63,0,63,0,63,0,0,0,0,0,63,0,0,63,127,0,63,0,0,0,127,0,0,63,0,0,63,0\n0,42,42,0,42,0,42,42,42,0,42,42,0,0,0,0,0,0,0,0,0,0,42,0,42,42,0,0,127,0,0,0,0,0,0,0\n40,26,26,26,40,0,0,0,0,6,6,0,6,13,33,20,26,13,26,26,6,33,53,46,33,40,46,13,26,33,46,33,86,100,127,73\n74,22,14,0,7,14,0,0,0,0,7,14,7,29,7,14,14,14,29,14,7,59,59,37,67,29,67,37,59,7,82,59,59,104,127,112\n0,0,0,0,0,7,2,18,23,68,47,87,108,63,50,47,66,50,60,5,5,0,5,0,0,0,0,5,0,10,0,10,2,26,95,92,127\n0,0,0,0,0,0,0,0,0,0,31,31,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,95,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,42,42,84,84,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,84,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,117,90,9,63,9,18,9,27,0,18,9,0,0,9,0,0,9,0\n84,127,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,42,42,0,0,42,0,42,127,0,42,42,0\n74,52,97,87,119,127,83,75,70,62,49,39,49,35,29,26,26,22,11\n9,29,34,4,0,0,0,0,4,4,4,0,0,0,0,0,0,4,0,0,9,34,39,39,68,19,78,92,127,43,39,43,29,24,24,9,0\n101,50,0,25,25,127,25,0,0,50,127,25,25,25,25,50,25,25,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,127,55\n89,99,75,102,41,44,30,13,10,24,6,44,20,13,6,6,6,10,3,3,13,6,0,13,6,13,20,30,37,51,58,72,82,92,102,127\n108,87,116,61,54,39,50,43,18,25,14,21,7,3,10,18,18,0,0,7,7,7,3,7,18,7,29,32,65,65,72,79,76,112,101,127\n0,50,127,0,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,101,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,25,0,25,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0\n127,31,31,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,0,95,63,63,0,63,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31\n63,31,63,31,63,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,95,31,127,63,0\n42,127,42,84,0,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,127,0,42,42,42,42,84,127\n0,63,0,127,127,63,0,0,0,31,31,0,0,31,0,31,31,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0\n63,0,95,127,63,31,31,0,0,0,0,0,0,31,0,0,0,0,0,0,0,31,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0\n0,31,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,31,127,31,0,0,31,0,95,63,63,63,31,0,95,31,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,42,42,21,63,21,42,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,127,127\n0,0,0,0,0,0,0,0,18,0,9,0,0,18,0,9,0,0,9,0,0,0,0,0,0,0,0,0,0,0,9,27,18,54,45,108,127\n0,0,0,0,0,0,0,0,0,0,0,0,42,21,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,21,42,42,0,21,42,0,127,0,0,21,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,42,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,0,0,42,127,84,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,21,21,127,63,42,42,0,0,0,0,0,63,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,76,101,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n63,111,15,47,63,15,15,15,15,63,127,127,47,95,63,0,31,0,0\n50,76,76,76,25,25,0,25,127,25,0,0,0,0,0,25,25,25,101\n127,72,54,17,18,8,17,22,34,61,106,54,82,46,32,17,6,15,27\n57,57,57,46,69,34,23,46,11,11,11,11,23,11,23,0,0,23,0,11,0,11,0,46,46,57,127,46,23,46,0,23,0,11,34,57\n101,63,63,38,25,25,25,12,25,0,0,25,25,0,0,25,0,0,0,38,0,0,38,25,50,88,127,114,25,0,0,12,12,0,50,76\n23,23,23,34,103,103,57,103,34,34,92,127,103,23,23,11,46,46,69\n127,31,0,0,31,31,0,0,0,63,31,0,31,31,63,31,0,0,0\n84,42,0,0,42,42,0,42,0,0,84,42,127,42,42,0,84,0,42,0,42,0,0,42,0,0,42,42,42,0,0,42,0,42,0,84,84\n127,74,0,0,0,0,0,21,10,0,10,0,0,0,10,0,0,10,10,0,0,10,31,0,42,52,10,10,10,0,10,21,0,0,0,0,21\n0,0,0,0,0,0,0,63,0,0,63,0,127,0,0,0,0,0,63,0,0,0,0,63,0,63,0,63,63,0,0,0,0,0,127,63,0\n0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,127,42,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,11,0,46,34,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,46,23,46,23,23,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,127,57,23,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,31,52,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,95,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,42,74,127,105,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,10,42,84,74,52,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,95,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,127,127,42,10,0,0,0,0,0,0,0,0,0\n0,0,0,0,50,0,25,50,127,25,0,0,0,0,0,0,25,0,0,25,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0\n25,0,0,0,25,101,50,127,25,25,0,0,50,0,0,0,25,0,0,76,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,25\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,12,25,25,25,12,63,25,50,25,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,42,0,21,127,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,127,31,127,63,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,104,73,42,63,33,19,7,9,1,3,1,3,1,0,0,0,1,3,3,6,4,4,4,7,15,20,15,33,22,9,22,14,7,19,20,9\n84,127,127,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,84,42,84,42,0,42,0\n0,50,50,76,25,0,0,0,0,0,0,0,0,0,0,25,0,0,0,25,0,0,76,0,50,101,127,0,50,0,25,50,25,50,0,0,0\n89,127,97,29,14,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,14,22,14,14,14,22,52,0,67,7,14,29,7,29,22,0,22,0,7,0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,14,14,14,22,59,82,37,104\n42,42,21,63,21,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,21,42,0,21,0,0,42,0,21,0,21,42,21,0,42,21,0,21,63,0,21,0,0,21,0,0,0,0,21,21,0,0,0,0,0,0,0,0,21,21,0,0,0,0,21,21,0,42,0,127,84,21\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,42,0,0,0,0,84,84,0,0,0,0,0,0,42,0,0,84,42,0,0,0\n63,15,15,31,15,15,0,0,0,0,0,0,0,15,31,0,15,0,0,0,0,31,15,15,0,0,0,31,0,31,0,95,15,15,0,47,15,0,0,0,0,15,0,0,0,0,0,15,0,0,31,0,31,0,15,0,0,0,0,0,0,15,0,0,0,15,15,15,111,95,95,127\n50,25,25,25,50,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,50,76,127,50,25,0,25,0,25,0,0,0,0,0,25,0,0,0,0,25,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,101,127,101,76,25\n0,63,0,0,0,0,31,31,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,31,0,0,0,63,127,31,0,0,31,31,0,0,0,31,31,0,0,0,0,0,0,0,63,0,0,0,31,0,0,0,31,0\n63,0,0,0,0,127,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,63,0,63,0,0,0,0,0,0,0,63,0,0,63,0,63,0,0,127,127,0,63,63,0,0,0,63,0,0,63,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,63,63\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,127,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,21,84,127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,127,63,63,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,127,36,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,127,84,84,127,0,42,0,0,0,42,84,42,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,31,127,84\n63,127,79,0,0,15,0,0,15,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,0,79,31\n0,0,0,0,1,2,3,2,2,14,25,28,45,64,78,100,112,119,127\n0,0,0,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,29,0,29,82,52,127,74,7,7,7,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n71,71,101,35,86,66,86,81,35,91,60,71,66,101,127,66,60,86,71\n127,42,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,105,42,0,31,0,0,0,0,0,0,0,0,0\n0,6,0,0,0,0,0,6,0,40,20,73,127,106,46,20,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,20,26,53,80\n93,120,86,80,60,127,106,46,86,33,40,13,13,13,13,0,13,26,53\n127,79,63,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,0,0,47,15,0,63,15,31,15,0,0\n127,84,21,21,21,0,0,0,0,0,0,0,0,0,42,0,0,21,42\n72,127,18,36,18,0,18,0,0,0,0,18,0,18,0,0,90,18,0,36,0,0,0,0,18,18,0,18,0,0,0,0,0,0,0,0,0\n127,95,127,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n84,127,0,84,0,0,0,0,0,0,42,42,127,0,0,0,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,21,0,0,42,0,0,42,84,63,42,42,0,21,0,0,0,0,21,0,0,0,21,0,21,42,21,21,63,127\n0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,127,0,0,0,0,0,0,0,0,0,0,0\n0,0,50,50,0,25,0,25,25,50,127,25,0,0,0,0,0,0,0\n63,95,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,0,63,127,31,95,63,0,0,0,0,0,0,0,0,0,0\n57,31,37,48,57,50,83,55,51,56,54,39,61,62,59,52,86,102,127\n72,42,12,6,0,2,0,1,0,0,0,0,0,0,0,0,0,0,0,4,8,11,27,127,83,71,9,6,7,3,1,2,3,2,2,2,0\n36,0,0,36,18,36,127,54,54,0,0,18,0,54,18,0,18,18,0\n127,0,63,127,63,63,63,63,63,127,0,63,0,63,63,127,0,63,0,0,0,63,127,0,0,0,0,63,63,127,63,63,0,63,63,63\n0,42,84,42,42,84,42,127,42,84,0,42,0,84,0,84,0,42,0,42,0,0,0,0,0,0,0,84,84,42,0,0,0,0,42,0\n0,14,7,0,0,7,0,59,59,59,127,14,14,22,0,0,0,0,22,0,0,0,0,0,0,0,0,0,0,7,29,29,37,37,22,29,0\n0,0,0,31,0,0,31,31,0,63,0,0,0,0,31,31,31,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,31,127\n0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,25,0,0,0,0,0,0,0,0,25,0,0,0,76,50,127,76,25,0,25,0\n84,84,127,31,31,42,21,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,21,0,0,0,42,127,21,0,84,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,84,84,0,84,42,0,0,0,0,0,0,0,0\n97,39,58,68,68,48,107,127,107,58,48,68,39,39,39,78,19,39,39\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,63,127,84\n0,0,50,76,25,50,25,50,0,0,0,127,76,25,0,0,0,0,0\n0,0,0,10,0,21,0,84,127,74,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n50,50,25,50,25,0,0,127,76,25,0,25,25,50,76,0,0,25,50\n0,31,31,95,0,95,127,63,0,31,0,31,0,31,63,31,95,63,0\n0,9,0,0,0,9,0,0,0,0,0,0,0,9,0,18,18,54,127\n0,95,31,0,63,31,0,31,0,0,0,0,0,31,31,0,63,0,0,0,31,0,63,63,0,63,127,0,95,31,0,31,63,63,0,0,63\n0,127,63,31,95,31,0,0,31,0,31,0,31,0,0,0,0,0,0,31,0,0,0,0,0,0,0,31,31,31,31,95,127,31,31,63,63\n0,0,0,84,84,0,127,127,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,27,81,108,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,54,108,90,127,54,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,84,84,84,127,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,18,18,0,36,0,18,36,0,18,54,18,54,72,127,36,54,72,72\n7,3,0,0,0,0,0,0,0,0,0,0,1,0,1,5,50,92,127\n0,25,0,50,0,0,0,25,50,25,101,76,50,127,50,50,101,50,50\n0,0,25,0,0,0,25,0,0,0,0,25,127,0,0,0,0,0,0,0,0,0,25,25,25,25,0,0,0,0,0,0,0,0,0,0,50\n84,84,84,42,84,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,63,42,84,127,127,63,63,21,21,21,0,0,21,0,0,0\n0,0,0,0,0,0,0,0,0,31,31,31,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,95,127,63\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127\n0,50,76,0,0,0,0,0,0,0,25,0,0,0,0,25,0,0,0,0,0,0,25,25,127,127,25,0,0,25,0,0,0,0,0,0,0\n127,12,0,0,25,63,12,12,0,0,0,0,0,12,0,0,12,12,12,12,0,0,12,38,50,50,50,25,0,0,25,0,0,0,0,0,25\n0,0,0,0,0,0,0,0,0,0,0,127,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,21,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,42,0,127,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,42,0,0,0,0,84,84,0,0,0,0,0,0,0,0,0,42,0,42,42,0,127,0,84,42,0,84,0,0,42,42,0,0,0\n0,0,0,0,63,0,63,0,0,63,0,63,0,0,63,0,63,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,127,0,0,63,0,0,63,0,0,63,0,0,0,0,0,0,63,0,0,0,127,0,0,0,63,0,0,127,63,127,0,0,0,0,0,127,63,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,10,0,10,0,26,79,127\n0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,127,25\n127,0,0,21,0,42,0,0,21,0,21,0,21,0,0,0,21,42,0\n13,0,20,13,0,0,0,6,20,46,66,26,73,86,53,60,86,127,80\n36,0,36,0,18,54,54,18,0,18,90,54,36,18,54,0,18,0,36,72,18,18,72,72,72,127,54,0,0,54,36,0,0,0,0,0\n21,42,21,0,21,42,0,42,21,42,42,42,42,21,63,21,21,21,63,0,0,84,84,105,42,127,63,21,21,0,21,21,63,21,21,21\n63,31,127,0,0,95,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,63,127,127,0,63,127,0,0,0,63,0,63,63,127,0,0,127,0\n50,127,0,0,0,0,50,0,0,25,0,76,76,76,127,76,101,0,101\n0,0,0,0,0,0,63,0,0,0,0,0,0,127,0,0,31,31,63,0,95,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0\n0,127,42,42,42,42,127,84,42,0,0,0,0,0,0,84,0,0,84\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,127\n0,42,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,0,42,84,42,0,127,0,0,0,0,0,0,42,0\n0,36,36,36,18,0,0,18,18,54,18,127,0,18,0,0,0,0,36\n0,127,25,0,0,25,25,0,0,50,25,0,0,0,0,25,0,0,25,76,0,25,0,25,25,76,25,0,25,0,50,25,0,0,0,0,0\n0,0,0,63,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,63,0,0,63,63,63,63,0,0,127,63,0,0,0,0,0,127,0\n0,42,0,84,0,0,0,0,0,0,0,0,0,0,0,84,42,0,0,0,42,0,0,0,0,127,0,42,0,0,0,0,42,42,0,0,0\n108,127,0,54,9,9,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,127,63,84,84,63,21,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n63,127,84,63,74,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,15,47,111,127,63\n127,63,105,84,21,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n84,127,42,8,8,8,0,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,81,60,27,10,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,7,23,57,86,127\n0,42,84,84,84,0,0,0,0,0,0,0,0,0,0,0,0,42,127,84,42,0,42,0,42,0,0,0,42,0,0,0,0,42,0,0,0\n18,0,9,0,0,0,9,0,9,13,0,31,18,36,36,77,31,40,36,18,27,40,27,63,127,90,81,27,18,13,31,9,4,0,0,0,9\n0,0,0,0,0,0,0,0,0,0,25,0,50,25,25,50,127,0,0,0,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,42,0,0,0,42,127,42,0,84,42,127,42,42,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,105,42,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,42,84\n0,50,0,0,101,50,50,0,50,76,25,25,50,0,50,50,0,25,25,25,25,50,25,25,76,127,76,25,0,76,50,50,25,50,25,0,0\n0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,42,21,21,63,84,105,127,42,0,63,42,42,0,42,0,0,0,0,0,0,0,0\n0,0,50,0,25,0,25,127,0,0,0,0,25,0,0,0,0,0,0,0,0,0,25,25,0,25,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,9,9,0,18,0,0,0,9,27,99,45,127,117,36,18,0\n0,0,15,0,15,0,15,0,15,15,47,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,12,12,25,114,50,127\n0,0,0,0,0,0,0,0,9,9,48,48,127,48,107,39,39,48,0,0,0,0,0,9,19,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,50,127,127,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,21,21,21,42,84,127,63,63,0,21,0,21,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,21,0,0,127,0,42,63,42,21,21,42,0,0,21,0,0,21,21,21,0,0,0,0,0,0,0,0,0\n25,127,50,25,76,0,25,0,50,25,0,0,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,25,0,0,0,0,25,0,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0\n31,0,127,95,0,31,31,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,0,0,0,0,0,0,31,0,0,0,63,0,31,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,31,31,31\n127,68,37,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,127,42,127,84,42,0,0,0,0,0,0\n3,0,5,3,0,0,6,4,1,0,0,0,1,0,0,0,0,0,0,0,0,1,4,3,6,2,17,50,65,97,127,93,59,30,19,12,9\n0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,42,42,84,127,42,0,127,42,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,4,0,4,0,0,4,9,9,9,29,48,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,127,127,127,0,0,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127,88,63,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,31,31,127,95,127,0,95,63,0,31,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,25,25,50,25,25,50,0,127,50,25,25,0,0,25,0\n0,0,0,63,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,63,0,0,127,0,0,0,63,0,0,0,63,63,0,63,0,0,127,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,63,63,63,0,63,63,127,0,63,0,0,0,127,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,23,127,34,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,56,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,127,56,28,127,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,127,63,0,0,127,0,127,63,0,63,0,63,0,0,0,63,127,127\n0,31,31,95,0,127,31,31,0,0,0,95,63,31,0,0,0,95,127\n63,47,31,31,0,0,0,0,31,15,0,0,0,15,0,0,0,0,47,0,31,63,15,63,127,127,0,15,31,0,0,0,0,0,0,0,31\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,63,105,127,21,42,21,0,0,0,42,42\n63,0,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,127,95,31,0,31,0,31,0,0,0,0,0,31,63\n31,63,47,15,15,15,31,31,0,15,79,31,0,0,0,31,15,47,15,15,15,0,47,47,31,95,31,47,0,15,63,31,15,0,15,127,127\n101,76,76,76,50,0,0,0,0,0,0,0,0,0,0,0,25,0,0,25,0,50,76,25,76,50,50,127,76,0,0,0,0,25,0,0,0\n0,0,0,0,0,0,0,0,0,12,24,72,72,84,42,12,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,12,60,127,60,24,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,30,42,120,90,30,6,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,19,97,78,87,19,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,48,68,39,0,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,19,48,48,127,29,0,9,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,127,101,25,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,0,42,42,42,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,12,127,88,88,25,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,127,76,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,72,54,36,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,108,18,90,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,31,63,127,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,127,31,31,31,31,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,42,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,42,127,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,0,0,84,0,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,84,127,127,42,0,42,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,18,127,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,36,18,18,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,105,127,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,5,11,16,5,27,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,44,127,44,38,11,0,0,5,0,0,11,0\n0,0,0,0,0,0,0,7,0,23,63,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,39,127,111,0,0,7,0,7,0,0,0,0\n124,98,127,116,77,85,69,54,51,57,54,46,46,20,25,15,7,5,25\n112,84,56,127,56,42,0,0,0,0,0,0,0,0,0,0,0,14,14,28,0,14,14,0,70,84,28,98,0,14,28,0,14,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,14,56,42,42,56,84,127,84,84,56\n103,93,88,85,62,88,64,62,72,127,114,77,90,64,72,28,49,44,31\n0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,127,25,0,101,0,101,0,0,0,0,0,0\n127,103,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,36,0,0,18,0,54,127,54,18,36,18\n15,0,15,15,15,0,31,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,15,0,15,15,15,127,31,63,111,31,0,15\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,63,0,63,127,95,31,95,0,63,31,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,0,0,0,0,84,42,127,127,0,84,0,0,0\n38,76,127,63,88,50,25,50,50,12,63,50,38,38,50,50,12,25,63,38,12,76,63,25,63,38,38,76,38,63,88,50,38,38,38,38\n45,127,9,72,54,27,36,18,18,45,45,45,81,45,36,18,9,36,18,9,36,0,18,27,54,54,27,36,36,81,36,9,72,45,36,36\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,7,11,22,63,70,127,63,56,14,22,3,7,11,11,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,3,3,6,27,48,65,127,68,41,27,6,3,13,10,3,0,0\n0,63,31,95,63,31,31,127,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,0,63,63,0,0,63,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,3,3,43,127,91,75,79,3,11,0,0,0,0,0,0,0,0,23,0,0,0,0,0,0,0,3,3,15,63,87\n0,0,0,0,0,0,15,0,0,0,0,15,63,127,15,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,47,0\n0,0,0,0,0,0,0,0,0,0,0,25,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,42,0,0,0,42,0,42,127,0,42,84,0,0,0,0,0,0,0,42,0,0,0,0,0,0,42,84,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,14,14,28,127,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,112,0,14,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,63,63,63,63,0,63,63,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,127,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,42,0,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,84,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,127,84,42,84,84,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,127,0,34,11,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,33,127,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,25,76,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,25,25,127,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,63,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,127,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,21,42,42,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,84,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,42,0,127,42,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,42,0,0,127,127,0,0,42,0,0,42,0,0,0,0,0,0,0,0,0,0,42,0,42,0,0,84,42,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0\n63,0,31,0,0,0,0,0,0,63,31,127,63,31,63,0,0,0,0,0,0,0,0,63,63,31,0,0,31,0,0,0,0,31,31,127,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,31,127,52,52,0\n0,0,0,0,0,0,0,0,0,0,0,21,21,127,42,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,31,31,31,31,0,0,0,0,0,31,0,63,31,31,0,31,0,31,0,0,0,31,63,63,63,31,0,0,31,0,0,31,31,63,127,63\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,127,0,63,63,127,127,127,127\n54,18,0,0,9,9,0,0,36,45,81,72,54,36,45,0,36,45,9,9,0,0,18,0,0,9,0,0,0,0,9,0,0,0,36,18,127\n127,21,42,21,84,21,21,0,0,0,21,21,21,0,0,21,0,21,0,21,63,42,42,21,63,63,63,21,21,42,0,21,0,21,42,0,0\n0,0,0,0,12,0,0,25,0,0,0,38,50,63,0,38,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,50,0,38,12,127\n0,0,31,95,127,63,95,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,15,0,15,63,127,47,47,79,79,31\n3,6,5,6,6,15,18,27,45,57,62,66,56,80,127,120,57,29,10,6,1,0,0,0,0,0,0,0,0,0,0,3,2,0,2,4,0\n0,0,0,33,5,5,0,5,0,16,71,127,71,44,77,33,49,66,5,11,0,5,0,0,0,11,11,5,0,5,0,0,5,0,0,0,0\n0,0,0,0,0,0,2,1,5,4,12,9,3,1,1,5,0,0,1,1,0,0,0,0,1,2,4,5,2,6,7,24,70,105,127,63,30\n0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,76,0,127,76,0,0,0,0,0,0,0,25,0,0,0,0\n0,0,0,0,0,0,31,95,31,63,95,31,63,0,31,0,63,31,0,31,0,0,0,0,0,0,0,31,0,0,0,0,0,31,31,31,127\n127,0,15,63,15,0,63,15,0,0,31,15,31,47,0,31,63,15,0\n115,34,11,23,0,0,23,23,11,0,34,0,11,0,0,0,23,11,11,11,0,23,46,57,127,34,23,11,34,0,23,34,11,11,0,11,0\n127,31,63,95,63,31,0,0,0,0,127,63,63,95,31,0,0,0,0\n0,0,0,0,0,0,0,19,63,25,38,63,127,12,44,19,6,6,0,0,0,0,0,0,0,0,0,0,0,0,6,0,38,31,44,76,38\n65,45,36,8,45,36,24,16,24,32,61,86,127,127,36,40,16,12,24\n0,0,0,0,0,0,0,0,0,0,0,72,127,54,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,54,72\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,127,127,42,84,42,42,0\n50,25,25,63,38,12,76,25,12,127,38,50,63,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n63,63,0,0,31,63,31,127,0,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,63,0,0,0,0,0,0,0,0,63,127,63,0,0,0,0,0,0,0,0,127,0,0,63,0,63,0,0,0,0,0,0,63,63,127\n0,0,0,0,42,0,42,42,0,0,0,42,0,0,0,0,42,0,127,42,42,0,0,0,0,42,42,0,0,42,42,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,72,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n25,25,0,0,0,0,0,0,0,0,0,50,76,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,0,0,0,0\n0,0,63,63,63,63,0,0,0,0,63,63,0,0,63,127,63,127,0\n11,3,11,3,11,20,43,127,119,100,81,62,37,22,3,0,1,0,3\n0,0,0,0,0,0,0,0,0,0,31,31,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,11,11,103,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,12,12,114,127,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n76,38,50,25,0,12,0,25,38,50,38,88,127,38,25,25,0,0,76\n0,0,0,0,0,0,0,0,0,63,0,31,127,95,127,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,31,0,63,63\n0,63,127,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,31,95,95,0,63,0,31,0,0,0,0,0,0,63\n0,63,0,0,63,63,0,0,63,0,0,0,63,63,63,0,127,63,127,0,63,0,0,0,0,0,63,63,63,127,63,63,63,0,63,63,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,63,31,63,0,0,31,95,95,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127\n0,63,0,42,42,127,21,0,21,0,21,21,21,0,0,0,84,42,0,0,21,0,0,42,21,0,0,21,0,84,21,21,0,21,0,0\n127,31,31,63,0,47,15,15,0,15,15,0,0,0,31,0,31,0,0,0,0,0,0,0,0,0,0,0,15,31,31,0,31,15,31,15\n0,0,42,84,127,42,84,0,84,0,42,0,0,0,0,0,0,0,42,0,0,42,0,0,42,0,84,0,42,42,42,42,0,42,84,0\n63,0,31,95,31,127,63,0,31,63,0,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,95,31,0,0,0,31\n0,63,0,0,0,0,63,63,127,0,63,127,127,0,0,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,127,95,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,95,63,31,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,25,25,50,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,127,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,0,50,50,127,0,25,0,0,0,0,0,0,0\n0,0,0,31,0,31,0,31,31,31,0,0,0,31,0,0,0,0,0,0,31,0,0,0,0,0,31,63,0,127,0,0,31,0,31,0,0\n0,42,42,0,0,42,127,0,127,84,42,42,0,42,0,42,0,84,0,0,0,42,0,42,0,0,0,42,42,42,42,84,127,42,0,42,0\n44,22,52,59,44,14,22,37,67,82,37,52,0,29,29,127,44,29,29\n0,0,0,31,0,31,31,31,63,0,0,0,63,0,31,0,63,0,0,63,0,0,0,0,0,0,0,0,31,31,0,127,95,31,31,63,0\n0,5,0,5,0,0,5,0,2,0,2,28,63,25,11,2,5,5,5,0,0,0,0,2,0,5,5,0,0,5,2,5,5,5,14,28,127\n0,0,0,0,0,0,63,31,63,31,0,31,0,0,0,0,95,127,0\n0,25,50,0,0,76,50,0,0,25,25,0,0,0,0,0,0,127,76,0,0,0,76,0,0,25,25,0,0,25,50,50,25,0,25,0,0\n0,0,0,0,0,0,0,0,0,42,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,127,21,0,0\n0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,63,0,0,0,0,0,0,63,127,0,0,0,0,0,0,0,0,0,63,127,0,0,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0\n0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,0,0,0,0,63,0,63,0,0,0,0,0,0,0,0,63,127,0,63,127,127,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,63,0,0,127,127,63,63,63,0,0,0,63,0,63,0,0,127,0,0,63,63,0,0,63,0,0,63,63,0,0,63,0,0\n0,0,0,0,0,0,29,0,22,127,14,0,0,0,7,52,74,7,14,0,0,0,0,0,0,0,0,0,0,0,0,22,52,44,7,0,0\n0,0,0,0,0,0,25,0,50,25,0,0,127,0,0,0,0,50,25,0,25,0,0,0,25,0,0,25,0,0,25,50,0,0,25,127,0\n0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,63,0,0,0,0,63,0,63,0,0,63,0,0,0,0,63,0,0,0,0,63,0,0,0,0,0,63,63,0,0,0,63,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0\n0,0,0,0,0,15,31,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0\n0,0,0,0,0,54,18,0,0,18,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,63,0,63,63,0,0,0,127,0,0,63,127,127,0,0,0,0,0,0,0,0,63,0,0,0,63,0,0,0,0\n0,0,0,63,63,127,0,0,0,0,0,0,63,0,0,0,0,0,0,63,63,63,0,0,63,0,0,0,127,63,0,0,0,0,0,0,0\n84,0,0,0,0,0,0,42,0,0,0,127,0,84,127,0,0,0,42,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,84,0\n0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,36,18,0,0,0,18,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,15,0,0,0,0,0,0,0,0,0,15,0,31,15,15,111,127\n0,47,15,47,0,0,63,63,15,63,127,31,0,15,0,63,47,63,31,15,15,0,31,15,15,0,31,31,0,31,111,47,15,63,15,0,31\n0,25,76,25,50,76,50,127,25,0,0,0,0,0,0,0,0,25,25,25,127,25,76,0,0,25,0,0,50,50,0,76,25,0,0,0,0\n127,21,42,63,127,105,0,63,0,0,21,0,0,0,0,0,0,21,0,84,42,84,42,21,21,42,0,42,0,63,42,0,21,21,0,0,0\n0,0,0,63,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,63,127,127,0,63,0,63\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,63,0,63,127,63,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,63,0,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,63,63,0,0,0,127\n95,47,0,15,0,0,0,0,0,0,0,0,127,31,15,0,0,0,0\n127,63,63,63,31,0,0,127,95,31,127,95,63,31,63,31,31,63,0\n0,0,0,0,0,0,0,0,0,0,127,25,101,0,0,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,50,101\n118,95,88,127,99,118,76,46,48,50,40,35,38,71,38,61,52,55,59\n0,127,31,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,0,31,0,127,31,95,0,31,31,0,0,95,63,63\n127,42,84,21,63,84,0,0,42,21,0,21,0,42,42,21,21,0,63,0,21,42,42,21,21,42,0,21,21,42,42,42,42,42,105,42\n90,72,127,0,18,36,18,72,36,0,0,54,18,36,36,0,18,36,36,18,0,0,18,18,18,18,0,36,54,18,0,18,36,36,72,36\n31,63,0,0,0,0,31,0,0,0,0,0,0,0,31,0,0,0,31,63,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31\n0,127,0,25,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,76,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25\n0,0,0,0,0,0,0,0,0,10,10,31,31,31,10,21,0,0,42,0,0,0,0,0,0,0,10,0,0,0,0,0,10,0,10,52,127\n0,0,0,0,0,0,0,0,0,42,42,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,84,42,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,84,0,0,127,42,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,42,0,42,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,127,42,42,84,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,42,0,0,42,0,42,84,0,0,0,0,0,0,0,0,0\n0,0,0,84,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,21,0,0,84,42,127\n0,0,0,0,0,0,63,31,0,0,63,127,63,31,0,0,31,31,0\n112,70,112,56,70,14,42,28,42,70,112,70,127,42,42,127,56,56,28\n81,102,120,92,49,24,18,34,29,63,70,106,127,95,47,34,40,81,104\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,34,34,127,46\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,101,50,0,0,0,0,0,50,25,101,127,50\n31,31,0,0,0,0,31,0,0,0,31,31,0,63,31,31,0,63,0,0,31,63,0,63,95,63,31,63,63,31,127,0,31,31,0,31\n0,31,31,0,63,0,0,0,0,0,0,31,31,31,31,63,31,0,0,31,31,0,31,63,31,0,0,0,31,127,63,95,0,63,0,0\n72,36,18,54,36,18,0,18,54,54,36,36,18,18,0,18,0,18,0,0,18,54,36,127,72,18,36,18,54,0,18,0,18,108,90,54\n21,42,21,84,42,0,21,0,0,84,21,21,0,63,21,0,42,21,0,21,63,84,84,21,21,63,127,105,105,0,0,0,0,84,63,63\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,127,0,0,63,31,31,31,31,0,31,0,0,0,0,0,0,31,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,127,0,42,42,127,0,127,0,0,0,0,0,0,0,0,42,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,79,127,79,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,63,127,0,0,0,0,0,0,0,0,0,0\n63,0,0,0,31,0,63,31,0,31,63,31,127,95,127,0,31,63,127\n84,84,0,0,84,0,84,0,127,42,42,127,42,127,127,84,84,42,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,72,18,18,127,18,18,0,0,0,0,0,0\n105,10,21,10,10,10,10,21,10,84,105,52,0,127,74,21,0,21,0\n63,95,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,63,0,0,0,0,0,0,0,0,0,0,0\n127,27,18,36,36,18,45,45,9,18,0,0,0,0,0,9,0,0,18,27,54,18,0,27,27,18,0,36,36,0,45,9,9,0,0,0,0\n0,63,31,31,31,31,0,31,31,0,0,63,0,0,31,31,0,31,127\n127,54,72,0,18,9,9,9,27,72,45,63,99,36,45,18,18,18,18\n0,63,63,0,63,0,0,63,0,0,0,0,63,63,127,0,0,0,0,63,0,0,127,0,0,0,0,0,0,0,0,0,0,63,0,0\n0,42,127,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,42,0,84,0,42,42,0,0,0,0,0,0,0,0,0,42,0,0\n127,0,0,0,42,0,63,63,0,0,0,0,0,21,0,0,0,0,21,0,0,0,0,0,0,21,0,0,0,0,0,0,21,0,0,0,0\n101,25,25,50,101,0,25,25,25,0,0,0,0,0,0,25,50,25,50,25,25,25,127,0,25,101,0,50,25,0,76,0,0,0,0,25,0\n127,49,56,89,54,58,35,25,37,11,23,11,30,28,44,47,44,32,56\n0,0,0,42,0,0,42,127,42,0,0,0,0,42,0,0,0,0,0,0,0,84,0,0,42,0,0,0,42,0,0,42,0,0,0,42\n0,0,63,0,63,63,0,63,0,0,0,63,0,0,0,0,63,0,0,0,63,63,0,0,0,0,0,0,0,0,63,127,63,127,0,0\n127,31,0,63,52,63,0,52,21,52,21,0,21,42,105,0,0,21,0\n0,0,0,0,0,63,63,0,0,0,0,127,63,0,63,0,0,0,0\n0,14,0,0,42,42,0,42,14,0,14,14,42,28,56,14,14,28,28,70,14,0,28,14,0,0,0,14,14,42,14,127,14,14,14,42,0\n0,0,0,0,0,0,0,0,21,42,0,0,0,0,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,127,0,0,0\n0,0,0,0,0,63,0,0,63,127,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,63,63,0,63,0,0,0,63,0,0,0,0,0,0,0,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,63\n0,0,63,0,0,0,0,0,63,0,0,0,0,0,0,63,127,0,0,63,0,0,0,0,0,0,0,0,63,0,0,63,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,63,0,63,0,63,0,0,0,63,0,0,0,0,0,0,63,63,0,0,0,0,0,0,127\n0,0,0,0,0,84,0,0,0,0,0,0,0,0,0,0,0,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,42,0,42,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,42,0,0,0,127,0,0,0,0,0\n0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,127,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,63,0,0,0,63,0,63,0,63,0,63,0,0,0,0,0,0,0,0,0,0,63,0,0,63,0,0,0,0\n0,0,0,0,0,0,84,127,0,0,0,0,42,0,0,0,0,42,0,84,0,0,0,0,0,0,0,42,0,0,0,42,0,0,0,0,84\n0,47,0,0,0,0,0,111,79,63,95,111,47,79,15,79,15,31,47,31,0,15,0,15,0,15,0,0,0,31,79,31,31,95,111,95,127\n63,63,0,31,95,127,31,31,0,31,0,0,31,0,0,0,0,0,95,0,31,63,31,0,63,31,63,0,31,31,0,0,0,0,0,0,0\n50,25,101,25,0,0,76,0,50,76,101,76,50,76,25,25,0,101,50,0,25,76,0,50,0,25,50,127,0,101,25,50,76,25,101,101,0\n127,63,84,105,105,21,0,0,21,0,0,0,0,0,0,0,21,0,0,0,42,0,0,42,105,105,63,63,0,21,21,0,0,0,0,21,0\n0,127,0,0,84,0,0,0,0,0,84,0,0,0,0,127,0,42,0,0,0,84,84,42,84,42,127,127,42,0,42,0,0,0,0,0,0\n0,0,0,42,127,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,42,0,42,0,0,84,84,84,0,0,0,0,0,0,0,0\n0,0,0,31,0,0,15,15,0,15,0,0,15,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,15,0,0,31,15,79,127\n0,127,31,31,31,0,31,0,0,0,0,31,0,0,0,0,0,31,0,0,31,63,31,63,63,31,31,0,31,0,0,0,0,0,0,0,0\n0,0,0,0,63,0,63,0,0,0,0,0,0,63,0,0,0,0,0,127,0,63,0,0,0,0,0,63,0,127,0,0,63,63,0,63,0\n0,21,0,0,0,0,0,0,21,42,0,42,127,21,63,21,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,63,0\n127,63,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,21,0,21,21,21,21,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,14,14,127,42,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,84,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,14,28,112,28,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,18,18,0,0,36,36,36,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,36,72,0,54,18,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,54,127,90,36,18,18,0,0,0,0,0,0,0\n0,31,0,31,63,63,127,0,0,0,31,63,0,31,0,0,0,0,31,31,63,0,0,63,31,0,0,95,0,31,0,0,0,31,0,0,0\n105,85,61,65,45,27,21,18,34,23,21,14,3,7,3,7,3,12,12,10,12,16,21,29,34,32,45,96,125,127,65,43,19,29,12,10,7\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,31,0,0,0,0,31,31,0,31,127,95,0,0,0,31,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,31,0,47,127,111,127\n127,95,0,63,0,31,31,0,127,63,31,0,0,0,0,0,0,0,0,0,0,0,0,31,31,31,0,31,31,0,0,31,0,0,0,0,0\n54,127,0,54,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,18,18,0,36,36,90,0,36,18,18,0,18,18,36,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,72,36,54,36,36,90,72\n54,18,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,18,72,36,54,72,36,54,0,0,36,18,36,18,18,0,0,0,0,0,18,0,18,0,0,0,18,18,0,0,0,0,18,0,0,0,0,54,0,0,18,72,72,54,90,127,72\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,42,42,0,0,0,0,42,42,0,0,0,0,42,42,42,127,127,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,0,31,0,0,0,0,0,0,127,0,31,63,95,31,0\n63,31,31,31,0,63,31,31,31,63,0,31,63,0,0,0,0,0,127,0,31,0,0,31,0,0,31,31,31,31,31,31,63,31,0,0,0,0,0,31,0,0,0,31,31,0,63,31,31,0,31,0,0,0,0,0,127,0,0,31,0,0,0,31,31,0,63,0,31,95,31,31\n25,50,0,50,25,0,0,0,0,0,0,0,25,0,25,0,0,0,0,0,0,0,0,0,25,50,25,25,0,25,50,0,0,0,0,25,0,0,25,0,25,0,25,76,76,0,0,25,0,0,0,0,25,50,50,0,25,25,0,25,0,0,0,0,25,0,127,25,50,76,50,76\n0,29,0,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,9,9,19,0,39,48,9,48,68,9,68,97,127,97\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,127,127,42,42,127,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,31,127,0,0,0,0,0,31,0,31,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,42,0,0,127,0,42,0,42,42,84,0,0,42,0\n0,63,0,0,63,63,63,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,63,0,63,63,0,127,127,0\n76,38,38,12,50,63,25,50,25,63,50,50,25,25,38,38,25,0,38,12,50,50,63,50,127,114,101,101,50,12,63,12,0,12,25,25,0\n0,0,0,0,31,0,0,0,0,0,0,0,31,31,0,31,0,63,95,127,31,63,63,95,63,127,31,0,31,0,0,0,0,0,0,0,0\n0,31,95,0,127,95,63,31,0,0,0,31,0,0,31,63,31,31,31,31,0,0,63,0,31,0,0,0,31,31,0,31,0,31,0,0,0\n42,127,42,0,21,0,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,42,0,21,0,21,0,0,0,0,21,0\n0,0,0,0,0,0,0,0,0,0,8,8,33,110,118,101,76,110,127,110,93,33,33,16,0,0,0,0,16,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,29,19,87,58,58,87,127,117,39,9,19,19,9,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,127,84,127,42,42,42,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,63,0,0,0,31,95,63,127,31,0,63,95,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,4,13,27,58,122,127,63,72,81\n0,0,0,0,0,0,0,0,0,0,7,14,7,0,7,35,70,91,127\n0,0,0,0,0,0,0,0,0,0,0,10,31,42,84,127,63,127,31,52,42,0,0,21,10,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,14,70,14,42,42,127,70,14,14,28,14,0,0\n0,0,0,0,0,0,0,15,0,0,111,79,127,47,95,15,31,0,0\n0,0,0,0,0,1,0,1,4,4,10,16,49,95,127,112,77,57,44\n0,0,0,0,0,0,0,0,0,0,9,27,36,86,127,90,99,63,45,27,36,4,9,4,13,0,0,4,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,3,11,64,127,15,3,5,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,2,2,13,28,61,115,124,127,84,66,37,33,17,15,15,7,2,7,2,1,1,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,101,76,76,25,127,0,25,0,0,0,0,0,0,0,0,25,0,0,0,25,0\n0,0,0,0,0,0,0,0,0,0,0,47,63,31,63,63,127,47,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,18,0,0,0,18,0,18,90,127,72,72,72\n0,0,0,0,0,0,0,0,0,0,0,0,0,47,47,47,15,127,63\n0,0,0,0,0,0,0,0,0,0,0,7,0,3,18,41,78,127,63,33,33,33,14,14,11,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,1,1,1,29,44,52,102,127,98,82,77\n0,0,0,0,0,1,1,2,2,6,9,15,21,30,41,53,87,114,127\n0,0,5,2,5,4,0,2,0,1,0,1,0,1,2,10,13,17,35,29,51,80,127,121,90,51,42,5,3,1,1,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,12,6,19,31,88,63,127,50,25,38,12\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,10,10,5,4,11,67,127,107,64,44,14,38,16,11\n0,0,0,0,0,36,36,127,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,127,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,10,0,0,0,0,0,0,10,5,0,10,26,127,21\n10,0,5,15,0,26,5,15,21,15,0,21,42,42,42,42,79,58,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,15,31,47,15,47,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,127,25,0,25,50,76,0\n0,4,0,37,14,28,9,37,37,42,98,122,108,127,47,56,79,47,0\n0,0,25,0,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,127,50,0,25,0,25,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,31,63,127,63,63,63,0,0,0\n42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,84,0,0,0,127,42,0,0,42,42,42,0,42,42,42,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,25,101,127,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,42,0,0,127,42,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,84,42,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,0,42,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,25,0,50,0,50,25,25,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,76,0,0,50,25,0,0,25,50,127,25,0,0,0,25,50,0,76,0,50,76,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,25,0,0,127,25,0,0,25,25,0,0,0,0,0,50,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n84,127,105,105,105,63,84,42,42,21,21,21,21,0,0,0,0,21,0,0,0,0,0,21,21,42,84,0,0,21,21,21,42,63,21,63\n54,54,54,54,127,72,90,90,18,108,0,36,36,0,0,18,0,0,18,18,0,0,0,0,0,18,18,0,36,0,18,18,18,36,0,18\n0,31,95,0,0,0,127,95,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0\n0,25,127,0,0,0,0,25,0,0,0,0,25,50,0,0,0,25,25,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n31,0,0,95,95,31,63,0,127,95,127,63,0,0,0,0,31,0,31,0,0,0,0,0,0,0,0,31,0,0,0,31,31,0,31,31\n63,127,63,31,63,31,31,63,0,0,63,0,63,0,0,0,0,0,0,0,0,0,0,0,63,0,0,31,63,0,31,31,63,63,31,0\n106,118,127,90,81,40,32,20,24,24,20,36,57,36,24,16,16,24,36,45,73,40,69,94,114,122,86,36,57,36,40,36,20,49,45,36,16\n0,0,42,0,0,0,0,42,21,0,21,63,84,127,105,21,21,0,63,0,0,0,0,21,0,0,21,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,127,127,76,101,50,50,50,0,50\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,9,10,0,7,10,17,64,79,61,52,44,90,127,94\n0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,18,0,36,18,54,36,36,0,127,54,36,90,0,54,18,18,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,14,0,0,84,98,14,56,127,56\n127,63,31,0,0,127,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,31,63,31,0,0,0,0,31,0,0,31,0,0\n0,31,0,31,0,31,31,95,63,31,127,31,95,95,0,0,95,63,31,0,63,31,63,63,31,63,0,31,31,95,0,31,31,63,31,31,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,21,21,21,21,0,127,63,21,63,84,21,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,18,18,18,18,18,127,18,72,54,54,18,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,63,63,42,127,63,42,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,21,21,127,0\n0,0,0,0,0,0,0,63,0,0,127,127,0,127,0,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0\n0,0,0,0,0,0,0,0,0,0,0,12,12,12,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,25,25,127,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,38,101,12,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,25,76,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,127,50,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,50,0,50,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,42,42,42,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,42,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,127,42,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,127,31,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,127,23,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,21,0,127,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,105,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,127,0,21,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,127,90,0,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,36,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,36,18,18,0,18,0,0,0,0,0,0,0,0\n36,36,27,9,0,0,9,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,9,0,0,9,0,18,9,45,54,127\n0,63,47,63,0,63,0,47,0,0,47,47,0,0,0,0,15,15,0,0,0,0,0,0,15,0,0,31,15,0,0,15,127,47,0,15,63\n0,0,0,0,0,31,0,0,0,31,31,0,31,0,0,31,0,31,0,0,0,0,0,0,0,31,31,0,0,0,0,0,31,127,63,31,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,127,90,36,0,0,0,0,0,0,0,18,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,57,127,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,127,31,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,101,127,76,50,101,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,101,0,25,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,21,84,127,21,42,0,42,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,42,0,21,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,21,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,84,0,0,0,84,84,42,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,42,84,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,31,47,79,47,47,127,63,31,31,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,47,31,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,15,31,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,31,95,47,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,47,127\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,63,42,0,0,0,42,63,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,28,56,127,0,0\n63,63,0,0,0,0,0,0,0,0,0,127,0,31,0,0,63,31,0,31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,31,31,0,95,63,0,127,31,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,3,11,67,127,52,37,3,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,41,97,108,74,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,82,112,14,7,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,17,57,127,40,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,34,86,86,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,34,69,63,17,0,0,0,0,0,0,0,0\n127,34,23,11,57,46,11,23,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,34,57\n127,42,63,42,0,0,0,0,0,0,0,0,0,21,0,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,95,127,127,0\n127,127,0,95,63,31,31,63,31,31,0,0,0,95,127,31,31,31,0\n46,69,127,127,57,34,57,34,46,0,34,0,0,0,23,23,11,57,23,46,23,23,11,0,0,11,34,11,11,11,11,0,0,34,46,80\n39,97,127,97,68,29,97,19,9,19,19,9,0,9,0,0,9,9,19,0,19,0,9,19,9,9,9,19,0,29,39,29,19,48,58,29\n0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,10,10,74,127,63\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,54,72,127,54,0,18,18,0\n0,31,0,47,0,127,95,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n38,38,38,63,88,12,63,88,63,12,12,12,50,12,0,0,0,0,0,0,12,25,12,0,38,63,63,127,25,50,12,25,12,0,12,12\n0,42,84,21,105,63,105,42,21,42,105,42,63,0,21,21,0,21,0,0,0,21,21,42,42,21,84,105,63,127,21,0,42,0,84,63\n0,108,127,0,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18\n0,0,42,42,42,0,0,0,0,0,0,42,42,127,42,84,0,0,0,0,0,0,0,0,84,84,42,0,42,42,0,0,0,0,0,0\n0,63,63,63,0,0,0,0,0,0,0,0,127,31,31,0,0,0,0,0,0,0,0,0,0,31,63,31,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,63,0,0,0,0,95,63,0,0,31,0,0,0,127,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84,84,0,42,0,0,127,84,42,0,84,0,0,42,42,0,0,0\n0,0,0,0,0,0,72,127,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,21,0,0,0,0,0,0,0,0,63,0,42,127,84,21,0,0,0,0,0,0,0,0,0,0,21,21,105,42,0,0,0,0,0,0\n0,84,0,0,0,0,0,0,0,42,0,42,84,127,84,42,0,0,0,0,0,0,0,0,0,0,42,84,84,84,84,42,84,0,42,42\n0,0,0,127,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,31,47,47,31,15,0,0,0,47,15,15,47,15,0,15,0,15,0,0,47,15,31,79,31,63,47,0,0,31,31,31,47,0,0,31,0\n0,0,0,0,0,0,0,0,0,31,31,127,95,95,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,31,0,95,0\n127,63,54,18,18,9,27,27,18,63,63,36,81,36,81,27,36,18,27,0,9,27,127,45,127,81,54,45,18,9,18,81,81,36,54,54,36\n0,0,0,0,0,0,63,0,31,31,31,63,63,95,127,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,95,0\n0,42,0,0,0,127,42,42,0,0,0,0,42,42,0,42,0,42,84,0,0,0,0,84,42,42,0,0,0,0,42,42,42,0,0,0,0\n127,71,33,21,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,127,56,70,127,84\n50,25,127,101,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,79,63,127,111,95,95,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,84,28,35,14,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,127,0,84,0,42,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,84\n0,0,0,0,0,0,0,0,0,0,14,127,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n19,9,0,0,0,0,0,0,19,19,9,39,127,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,63,63,84,21,21,21,0,0,0,0,0,0,0,21,0,0,21,0\n0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,76,127,25,50,76,0,25,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,76,76,127,50,25,0,0,25,0,0,0,0,25,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,18,18,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,54,127,72,36,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,12,12,38,38,127,12,38,0,25,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,38,63,127,25,12,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n72,127,108,72,36,36,0,54,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,63,63,0,127,0,63,0,0,0,0,0,0,0,0,0,0\n127,31,63,127,63,31,127,0,0,63,95,0,127,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,50,127,25,25,76,25,25,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,50,88,127\n50,0,0,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,50,76,25,0,0,127,76,25,25,25,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,18,0,0,36,72,72,127,90,18,72\n127,63,31,15,15,15,0,79,0,31,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n127,95,79,31,79,31,0,15,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n10,5,15,5,10,25,76,76,40,71,35,40,5,10,5,20,10,10,10,5,5,10,10,15,15,81,121,127,111,91,50,20,20,10,10,15,0\n0,0,0,95,63,0,95,31,95,95,31,31,63,95,0,63,0,0,0,0,31,0,127,95,31,31,31,0,95,95,31,127,31,0,0,31,0\n127,44,76,38,57,44,82,107,50,25,25,50,57,25,50,44,69,50,25\n0,42,0,84,84,42,42,0,0,127,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,8,50,118,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,0,63,84,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,54,127,90,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,25,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,14,127,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,88,12,12,12,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,101,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,127,15,7,0,0,0,0,0,0,7,7,7,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,33,118,127,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,101,0,101,0,0,0,0,0,0,0,0,127,101,25,25,0,0,0,0,0,0,0,0,0,0\n45,27,40,27,22,4,0,4,13,4,9,9,40,36,36,36,54,77,127\n0,0,0,0,0,0,0,0,0,0,0,0,25,0,0,50,101,127,50\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,25,25,0,50,0,25,25,127,76,0\n31,79,0,15,0,0,15,0,0,0,0,15,31,47,0,95,47,79,127\n0,38,12,25,25,0,76,127,88,76,12,25,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,21,63,84,127,63,63,127,84,42,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21\n21,0,0,0,0,0,21,42,127,42,42,63,63,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,15,47,127,0,31,47,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0\n0,0,31,0,0,31,63,0,31,31,63,63,31,127,31,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,21,42,21,127,84,21,0,0,0\n0,0,0,0,0,0,0,0,54,18,0,127,108,54,72,0,0,0,0\n31,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,63,47,0\n127,47,55,55,7,23,7,15,15,23,0,0,15,7,0,0,7,0,7,7,7,0,31,15,47,23,31,7,15,47,31,55,55,79,63,87,111\n28,14,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,42,28,0,0,0,0,0,0,28,0,0,14,56,28,56,127,56\n36,0,0,0,18,36,36,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,18,127,0,0,18,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,0,0,0,0,18,0,18,0,18,0,36,54,36,18,0,0\n0,0,0,0,0,0,0,127,0,0,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,63,0,0,0,0,63,0,0,0,63,63,0,0,0,0,0,0,63,0,0,0,0,0,0,0,0,63,63,0,0,0,0,0,127,63\n0,127,127,0,0,127,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,127,0,0,0,0,0,0,127,0,0,0,0,0,0,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,0,127,127,127,127\n95,0,0,31,31,0,31,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,0,0,0,0,0,0,31,0,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0\n0,0,0,0,0,0,0,0,0,0,25,50,25,76,127,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,79,79,127,63,15,0,15,0,0,0,0\n0,0,127,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,127,127,127,127,127,0,0,0,0,127,127,0,0,127,127,0,127,0\n0,0,0,0,0,0,0,127,63,127,63,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n63,0,0,0,63,63,0,0,63,0,0,0,63,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,63,0,0\n0,0,0,0,0,76,127,50,50,0,0,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,56,28,28,56,98,127,84\n0,0,0,0,0,0,0,0,0,0,0,0,76,0,101,25,0,127,0\n127,31,31,0,0,31,0,0,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,63,31,0,31,31,31,31,0,0\n0,7,15,7,111,127,15,7,15,0,0,0,0,15,31,23,31,71,31\n0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,23,11,0,57,46,127,46,57,57,11,23,11,0,0,0,0,11,0,0,0,0\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,31,0,0,31,0,31,127,63,63,31,63,0,0,31,31,31,0,127,63\n0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,127,42,127,127,0,42,0,0,0,0,42,0,0,0,0,42,0',Klb),l);for(B=0;B<A.length;B++){C=A[B];w=dlb.Iab(a.c,C);if(!w){w=new elb.Aw((s=alb.Pgb('<').length,Zkb.c5(alb.Pgb(C).substr(alb.Pgb(C).length-s,s),'<')||(t=alb.Pgb('>').length,Zkb.c5(alb.Pgb(C).substr(alb.Pgb(C).length-t,t),'>'))?0:(u=alb.Pgb('-').length,Zkb.c5(alb.Pgb(C).substr(alb.Pgb(C).length-u,u),'-')||(v=alb.Pgb('+').length,Zkb.c5(alb.Pgb(C).substr(alb.Pgb(C).length-v,v),'+'))?1:(r=alb.Pgb('=').length,Zkb.c5(alb.Pgb(C).substr(alb.Pgb(C).length-r,r),'=')?3:2))));dlb.keb(a.c,C,w);}if(d!=null){c=Zkb.n5(d[B],',');w.a=gW(Ykb.Y0,znb,6,c.length,15,1);for(i=0;i<c.length;i++)w.a[i]=Zkb.P3(c[i],wnb,32767)<<16>>16;}if(q!=null){k=Zkb.n5(q[B],',');w.d=eW(Ykb.Y0,[apb,znb],[13,6],15,[k.length,2],2);for(i=0;i<k.length;i++){j=Zkb.h5(k[i],s5(45),1);w.d[i][0]=Zkb.P3(Zkb.p5(k[i],0,j),wnb,32767)<<16>>16;w.d[i][1]=Zkb.P3(Zkb.o5(k[i],j+1),wnb,32767)<<16>>16;}}if(g!=null){h=Zkb.n5(g[B],',');w.c=gW(Ykb.Y0,znb,6,h.length,15,1);for(i=0;i<h.length;i++)w.c[i]=Zkb.P3(h[i],-128,127)<<24>>24;}if(f!=null){e=Zkb.n5(f[B],',');w.b=gW(Ykb.wX,Fnb,6,e.length,15,1);for(i=0;i<e.length;i++)w.b[i]=Zkb.P3(e[i],-128,127)<<24>>24;}}};elb.Iv=function Iv(a){var b,c,d,e;a.a=15;for(e=(c=new dlb.hab(a.c).a.dc().rb(),new dlb.oab(c));e.a.ec();){d=(b=e.a.fc(),b.ic());elb.yw(d);}};elb.Jv=function Jv(){this.c=new dlb.seb();this.b=0;};elb.Kv=function Kv(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o,p,q;d=gW(Ykb.yX,emb,6,2,15,1);n=elb.Nv(a,c);for(i=0;i<2;i++){if(c[3*i]!=-1){f=2-i;o=3-3*i;j=0;for(m=0;m<3;m++){g=clb.vn(a,c[f],m);if(g!=n[1-i]&&a.C[g]!=1){c[o]=g;b?d[j++]=elb.iv(b,c):d[j++]=clb.Jj(a,c);}}c[o]=-1;return elb.Mv(d);}}e=gW(Ykb.yX,emb,6,2,15,1);k=0;for(h=0;h<3;h++){p=clb.vn(a,c[1],h);if(p!=n[0]&&a.C[p]!=1){c[0]=p;l=0;for(m=0;m<3;m++){q=clb.vn(a,c[2],m);if(q!=n[1]&&a.C[q]!=1){c[3]=q;b?e[l++]=elb.iv(b,c):e[l++]=clb.Jj(a,c);}}d[k++]=elb.Mv(e);}}c[0]=-1;c[3]=-1;return elb.Mv(d);};elb.Lv=function Lv(a,b){if(b[0]!=-1&&b[3]!=-1)return elb.iv(a,b);return elb.Kv(a.o,a,b);};elb.Mv=function Mv(a){var b,c;c=(a[1]+a[0])/2;b=$wnd.Math.abs(a[1]-a[0]);if(b>Fmb)return c;return c<0?c+Fmb:c-Fmb;};elb.Nv=function Nv(a,b){var c,d,e;e=gW(Ykb.AX,gmb,6,2,15,1);if(clb.tn(a,b[1],b[2])!=-1){e[0]=b[2];e[1]=b[1];}else {c=gW(Ykb.AX,gmb,6,16,15,1);d=clb.Rn(a,c,b[1],b[2],15,null,null);e[0]=c[1];e[1]=c[d-1];}return e;};elb.Ov=function Ov(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r;clb.Gt(a,7);j=0;for(e=0;e<a.g;e++){if(clb.Hk(a,e)==1&&!(e<a.g&&clb.sr(a.p,e))&&clb.On(a,a.D[0][e])>1&&clb.On(a,a.D[1][e])>1&&(a.F[e]&64)==0&&!((a.F[e]&128)!=0&&(!!a.p&&e<a.g?clb.ir(a.p,e):0)<=5)){b[e]=true;++j;}}g=gW(Ykb.AX,gmb,6,2,15,1);n=gW(Ykb.AX,gmb,6,2,15,1);f=null;for(d=0;d<a.g;d++){if(b[d]&&(f==null||!f[d])){c=0;for(l=0;l<2;l++){g[l]=a.D[l][d];n[l]=a.D[1-l][d];p=n[l];while(clb.mn(a,g[l])==2&&clb.On(a,g[l])==2&&clb.uk(a,g[l])<10){for(m=0;m<2;m++){h=clb.vn(a,g[l],m);if(h!=n[l]){i=clb.xn(a,g[l],m);if(b[i]&&clb.Hk(a,i)==1){b[i]=false;--j;}n[l]=g[l];g[l]=h;++c;break;}}if(g[l]==p){c=0;break;}}}if(c!=0){b[d]=false;--j;if(clb.On(a,g[0])>1&&clb.On(a,g[1])>1){q=clb.co(a,n[0],g[0]);r=clb.co(a,n[1],g[1]);k=q<r?0:1;o=clb.tn(a,n[k],g[k]);f==null&&(f=gW(Ykb.Z0,Amb,6,a.g,16,1));f[o]=true;b[o]=true;++j;}}}}return j;};elb.Pv=function Pv(a){var b;b=elb.Gv(elb.Fv,a);return !b?null:elb.vw(b);};elb.Qv=function Qv(a,b,c,d){elb.pw(d,a,b);if(c!=null){c[0]=d.f[0];c[1]=d.b[0];c[2]=d.b[1];c[3]=d.f[1];}return d.d;};elb.Rv=function Rv(a){var b;b=elb.Gv(elb.Fv,a);return !b?null:elb.ww(b);};elb.Sv=function Sv(a){var b;b=elb.Gv(elb.Fv,a);return !b?null:elb.uw(b);};elb.Tv=function Tv(){var a;!elb.Fv&&(elb.Fv=new elb.Jv());(elb.Fv.b&1)!=0&&elb.Fv.a!=15&&(Zkb.O5(),String.fromCharCode(10));a=1&~elb.Fv.b;if(a!=0){elb.Hv(elb.Fv,a);a==1&&elb.Iv(elb.Fv);}};U1(268,1,{},elb.Jv);_.a=0;_.b=0;Ykb.CY=w3(268);elb.Uv=function Uv(a,b){var c,d;for(d=0;d<a.b.length;d++){c=$wnd.Math.abs(a.b[d]-b.b[d]);if(c>bpb&&c<a.a[d]-bpb)return c<a.a[d]/2^a.b[d]<b.b[d]?1:-1;}return 0;};elb.Vv=function Vv(a,b){var c,d;for(d=0;d<a.b.length;d++){c=$wnd.Math.abs(a.b[d]-b.b[d]);if(c>bpb&&c<a.a[d]-bpb)return false;}return true;};elb.Wv=function Wv(a,b){this.b=a;this.a=b;};U1(205,1,{205:1,27:1},elb.Wv);_.qb=function Xv(a){return elb.Uv(this,a);};_.lb=function Yv(){var a,b;b=new Zkb.J5();for(a=0;a<this.b.length;a++){b.a+=a==0?'Torsions: ':', ';Zkb.G5(b,(slb.IT(),slb.JT(this.b[a],3)+'('+vX($wnd.Math.round(this.a[a]+0.5))+')'));}return b.a;};Ykb.EY=w3(205);elb._v=function _v(){elb._v=W1;elb.$v=oW(aW(Ykb.yX,1),emb,6,15,[Emb,Fmb,cpb,pnb]);elb.Zv=oW(aW(Ykb.AX,2),Dnb,7,0,[oW(aW(Ykb.AX,1),gmb,6,15,[0,0,0,2]),oW(aW(Ykb.AX,1),gmb,6,15,[0,0,1,2]),oW(aW(Ykb.AX,1),gmb,6,15,[0,1,1,3]),oW(aW(Ykb.AX,1),gmb,6,15,[2,2,3,2])]);};elb.aw=function aw(a,b,c,d){var e,f,g,h;if(d==1&&!elb.fw(a,b)){if(clb.wn(a.b,b)==3)return -1;if(clb.wn(a.b,b)==3){e=elb.dw(a,b,c);if(clb.Rt(a.b,e[0])==clb.Rt(a.b,e[1]))return e[2];return clb.Rt(a.b,e[0])==clb.Rt(a.b,e[2])?e[1]:e[0];}}g=-1;h=-1;for(f=0;f<clb.wn(a.b,b);f++){e=clb.vn(a.b,b,f);if(e!=c&&g<clb.Rt(a.b,e)){g=clb.Rt(a.b,e);h=e;}}return h;};elb.bw=function bw(a){var b,c,d,e,f;a.a=eW(Ykb.AX,[Dnb,gmb],[7,6],15,[a.d.length,4],2);a.c=eW(Ykb.AX,[Dnb,gmb],[7,6],15,[a.d.length,2],2);a.e=gW(Ykb.AX,gmb,6,a.d.length,15,1);b=gW(Ykb.AX,gmb,6,2,15,1);for(e=0;e<a.d.length;e++){for(f=0;f<2;f++){b[0]=clb.zk(a.b,1-f,a.d[e]);b[1]=clb.zk(a.b,f,a.d[e]);elb.lw(a.b,b[1])&&elb.jw(a.b,b[0],b,null);a.a[e][1+f]=b[1];a.c[e][f]=b[0];}c=elb.cw(a,a.a[e][1],a.c[e][0]);d=elb.cw(a,a.a[e][2],a.c[e][1]);a.e[e]=elb.Zv[c][d];a.a[e][0]=elb.aw(a,a.a[e][1],a.c[e][0],c);a.a[e][3]=elb.aw(a,a.a[e][2],a.c[e][1],d);}};elb.cw=function cw(a,b,c){var d;if(clb.wn(a.b,b)==2)return 1;d=elb.dw(a,b,c);if(clb.wn(a.b,b)==3){return clb.Rt(a.b,d[0])==clb.Rt(a.b,d[1])?elb.fw(a,b)?2:1:elb.fw(a,b)?1:0;}if(clb.wn(a.b,b)==4){if(clb.Rt(a.b,d[0])==clb.Rt(a.b,d[1])&&clb.Rt(a.b,d[0])==clb.Rt(a.b,d[2]))return 3;if(clb.Rt(a.b,d[0])==clb.Rt(a.b,d[1])||clb.Rt(a.b,d[0])==clb.Rt(a.b,d[2])||clb.Rt(a.b,d[1])==clb.Rt(a.b,d[2]))return 1;}return 0;};elb.dw=function dw(a,b,c){var d,e,f;f=0;d=gW(Ykb.AX,gmb,6,clb.wn(a.b,b)-1,15,1);for(e=0;e<clb.wn(a.b,b);e++)clb.vn(a.b,b,e)!=c&&(d[f++]=clb.vn(a.b,b,e));return d;};elb.ew=function ew(a,b){var c,d,e;e=gW(Ykb.zX,cob,6,a.d.length,15,1);d=gW(Ykb.zX,cob,6,a.d.length,15,1);for(c=0;c<a.d.length;c++){e[c]=elb.kw(elb.Lv(b,a.a[c]),a.e[c]);d[c]=elb.$v[a.e[c]];}return new elb.Wv(e,d);};elb.fw=function fw(a,b){if(clb.mn(a.b,b)==1&&clb.uk(a.b,b)<10||clb.lo(a.b,b)||clb.so(a.b,b,true))return true;return false;};elb.gw=function gw(a){elb._v();this.b=a;clb.Gt(this.b,63);this.d=elb.iw(a);elb.bw(this);};elb.hw=function hw(a,b){elb._v();this.b=a;clb.Gt(this.b,63);this.d=b;elb.bw(this);};elb.iw=function iw(a){elb._v();var b,c,d,e,f;clb.Gt(a,7);e=gW(Ykb.Z0,Amb,6,a.g,16,1);d=0;for(c=0;c<a.g;c++){if(elb.mw(a,c)){e[c]=true;++d;}}f=gW(Ykb.AX,gmb,6,d,15,1);d=0;for(b=0;b<a.g;b++)e[b]&&(f[d++]=b);return f;};elb.jw=function jw(a,b,c,d){var e,f,g;for(e=0;e<2;e++){f=clb.vn(a,c[1],e);if(f!=c[0]){if(f==b)return false;g=clb.xn(a,c[1],e);c[0]=c[1];c[1]=f;if(a.j[f]==1)return false;d!=null&&!clb.il(a,c[0])&&!clb.il(a,c[1])&&(d[0]=$wnd.Math.max(d[0],g));if(!(a.j[f]==2&&a.o[f]==2&&a.C[f]<=7))return true;return elb.jw(a,b,c,d);}}return false;};elb.kw=function kw(a,b){var c;c=elb.$v[b]/2;while(a<-c)a+=Emb;while(a>=c)a-=elb.$v[b];return a;};elb.lw=function lw(a,b){return a.j[b]==2&&a.o[b]==2&&a.C[b]<=7;};elb.mw=function mw(a,b){var c,d,e,f,g,h,i,j,k,l,m;if(clb.Hk(a,b)!=1||b<a.g&&clb.sr(a.p,b)||(!!a.p&&b<a.g?clb.ir(a.p,b):0)==3)return false;c=gW(Ykb.AX,gmb,6,2,15,1);for(h=0;h<2;h++){c[h]=a.D[h][b];if(clb.il(a,c[h])||clb.On(a,c[h])<=1)return false;}if(elb.lw(a,c[0])||elb.lw(a,c[1])){l=gW(Ykb.AX,gmb,6,1,15,1);l[0]=b;d=gW(Ykb.AX,Dnb,7,2,0,2);for(i=0;i<2;i++){if(elb.lw(a,c[i])){d[i]=gW(Ykb.AX,gmb,6,2,15,1);d[i][0]=c[1-i];d[i][1]=c[i];if(!elb.jw(a,c[1-i],d[i],l))return false;}}if(b!=l[0])return false;for(j=0;j<2;j++)d[j]!=null&&(c[j]=d[j][1]);}for(g=0;g<2;g++){f=clb.wn(a,c[g]);if(f==1)return false;m=0;for(k=0;k<f;k++){e=clb.vn(a,c[g],k);(a.u[e]&Gnb)!=0||++m;}if(m<2)return false;}return true;};U1(202,1,{},elb.gw,elb.hw);Ykb.DY=w3(202);elb.ow=function ow(){elb.ow=W1;elb.nw=oW(aW(Ykb.AX,2),Dnb,7,0,[oW(aW(Ykb.AX,1),gmb,6,15,[0,0,1]),oW(aW(Ykb.AX,1),gmb,6,15,[0,2,3]),oW(aW(Ykb.AX,1),gmb,6,15,[1,3,3])]);};elb.pw=function pw(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V;clb.Nj(a.c);a.d=null;clb.Gt(b,63);if(clb.Hk(b,c)!=1||c<b.g&&clb.sr(b.p,c))return false;if(clb.uk(b,b.D[0][c])==1||clb.uk(b,b.D[1][c])==1)return false;I=(b.F[c]&128)!=0;if(I&&(!!b.p&&c<b.g?clb.ir(b.p,c):0)<6)return false;e=gW(Ykb.Z0,Amb,6,b.f,16,1);a.a=0;for(A=0;A<2;A++){a.b[A]=b.D[A][c];a.e[A]=b.D[1-A][c];while(clb.mn(b,a.b[A])==2&&clb.On(b,a.b[A])==2&&clb.uk(b,a.b[A])<10){for(J=0;J<clb.wn(b,a.b[A]);J++){g=clb.vn(b,a.b[A],J);if(g!=a.e[A]&&b.C[g]!=1){if(b.j[g]==1||a.a==16)return false;e[a.b[A]]=true;a.e[A]=a.b[A];a.b[A]=g;++a.a;break;}}}K=clb.On(b,a.b[A]);if(K>4||K==1)return false;e[a.b[A]]=true;}for(B=0;B<2;B++){for(J=0;J<clb.wn(b,a.b[B]);J++){g=clb.vn(b,a.b[B],J);b.C[g]!=1&&(e[g]=true);}}a.g=gW(Ykb.AX,gmb,6,b.f,15,1);clb.Zm(b,a.c,e,true,a.g);for(C=0;C<a.g.length;C++)a.g[C]!=-1&&(a.i[a.g[C]]=C);clb.lm(a.c,true);if(I){f=clb.tn(a.c,a.g[a.b[0]],a.g[a.b[1]]);if(f!=-1){clb.im(a.c,f,256,true);R=(clb.Gt(b,7),b.p);for(Q=0;Q<R.i.a.length;Q++){if(clb.ur(R,Q,c)){for(D=0;D<2;D++){for(J=0;J<clb.wn(b,a.b[D]);J++){g=clb.vn(b,a.b[D],J);if(g!=a.e[D]){if(clb.tr(R,Q,g)&&b.C[g]!=1){clb.im(a.c,clb.tn(a.c,a.g[a.b[D]],a.g[g]),256,true);break;}}}}}}}}for(F=0;F<2;F++){clb.so(b,a.b[F],true)&&clb.Ul(a.c,a.g[a.b[F]],jnb,true);i=false;for(J=0;J<clb.wn(b,a.b[F]);J++){g=clb.vn(b,a.b[F],J);if(g!=a.e[F]&&b.C[g]!=1){r=clb.tn(a.c,a.g[a.b[F]],a.g[g]);if(clb.Kk(a.c,r)==64){i=true;}else if(b.C[g]==6&&!clb.lo(b,a.b[F])){q=g<b.f&&clb.rr(b.p,g)?2:4;clb.Ul(a.c,a.g[g],q,true);}h=clb.xn(b,a.b[F],J);S=!!b.p&&h<b.g?clb.ir(b.p,h):0;(S==3||S==4)&&clb.im(a.c,r,S<<17,true);if(h<b.g&&clb.sr(b.p,h)||clb.yn(b,a.b[F],J)==2){K=clb.On(b,g);v=K==3;!v&&K==2&&(b.u[g]&bob)==0&&(v=clb.eo(b,a.b[1-F],h)!=-1);v?clb.Ul(a.c,a.g[g],Vmb,true):h<b.g&&clb.sr(b.p,h)&&clb.Ul(a.c,a.g[g],Umb,true);}clb.yn(b,a.b[F],J)==1&&(clb.On(b,g)==4?clb.Ul(a.c,a.g[g],Zmb,true):b.C[g]==6&&clb.Ul(a.c,a.g[g],Wmb,true));}}i||(clb.lo(b,a.b[F])?clb.Ul(a.c,a.g[a.b[F]],2,true):clb.Ul(a.c,a.g[a.b[F]],4,true));}clb.Gt(a.c,191);for(w=0;w<2;w++){s=a.g[a.b[w]];if(clb.ok(a.c,s)==3){if(clb.ok(b,a.b[w])==3){return false;}else {L=clb.nn(a.c,s);clb.jm(a.c,L,257);if(clb.zk(a.c,0,L)!=s){clb.am(a.c,1,L,clb.zk(a.c,0,L));clb.am(a.c,0,L,s);}clb.Gt(a.c,191);}}}m=a.g[a.b[0]];n=a.g[a.b[1]];O=a.g[a.e[0]];P=a.g[a.e[1]];j=clb.ik(a.c,m);k=clb.ik(a.c,n);if(clb.$k(a.c,m)&&clb.$k(a.c,n)){if((j!=0||k!=0)&&(j!=k||clb.hk(a.c,m)!=clb.hk(a.c,n)))return false;}l=false;if(clb.$k(a.c,m)&&j!=0){clb.Nl(a.c,m,0,-1);l=true;}if(clb.$k(a.c,n)&&k!=0){clb.Nl(a.c,n,0,-1);l=true;}l&&clb.Gt(a.c,191);M=clb.Rt(a.c,m);N=clb.Rt(a.c,n);if(M<N){V=a.b[0];a.b[0]=a.b[1];a.b[1]=V;V=a.e[0];a.e[0]=a.e[1];a.e[1]=V;V=m;m=n;n=V;V=O;O=P;P=V;}H=false;if(clb.$k(a.c,m)||clb.$k(a.c,n)){clb.$k(a.c,m)?H=clb.Ht(a.c,m)==1:clb.$k(a.c,n)&&(H=clb.Ht(a.c,n)==1);if(H){for(d=0;d<a.c.q;d++)clb.Yl(a.c,d,-clb.rk(a.c,d));clb.Gt(a.c,191);}}o=elb.rw(a,m,O);p=elb.rw(a,n,P);a.f[0]=o==-1?-1:a.i[o];a.f[1]=p==-1?-1:a.i[p];G=clb.Ot(a.c);if(G==null)return false;t=elb.qw(a,m,O);u=elb.qw(a,n,P);t==0&&u==0&&(a.c.I&Mnb)==Gnb?U=2:U=elb.nw[t][u];T=U==0?H?'<':'>':U==1?H?'-':'+':U==3?'=':'';a.d=G+T;return true;};elb.qw=function qw(a,b,c){var d,e,f,g;if(clb.wn(a.c,b)==2)return 1;d=elb.sw(a,b,c);if(clb.wn(a.c,b)==3){return clb.Rt(a.c,d[0])==clb.Rt(a.c,d[1])?clb.mn(a.c,b)==1&&clb.uk(a.c,b)<10||clb.lo(a.c,b)||clb.so(a.c,b,true)?2:1:clb.mn(a.c,b)==1&&clb.uk(a.c,b)<10||clb.lo(a.c,b)||clb.so(a.c,b,true)?1:0;}if(clb.wn(a.c,b)==4){for(e=0;e<d.length;e++){g=clb.Rt(a.c,d[e]);for(f=e+1;f<d.length;f++)if(g==clb.Rt(a.c,d[f]))return 1;}}return 0;};elb.rw=function rw(a,b,c){var d,e,f,g,h,i,j,k,l,m;k=-1;l=-1;m=-1;f=gW(Ykb.Z0,Amb,6,clb.wn(a.c,b),16,1);for(i=0;i<clb.wn(a.c,b);i++){if(!f[i]){e=clb.vn(a.c,b,i);if(e!=c){g=clb.Rt(a.c,e);if(l<g){h=false;for(j=i+1;j<clb.wn(a.c,b);j++){d=clb.vn(a.c,b,j);if(d!=c&&clb.Rt(a.c,d)==g){f[j]=true;if(h)return e;h=true;}}if(h){m=e;}else {l=g;k=e;}}}}}if(k==-1)if(clb.mn(a.c,b)==1&&clb.uk(a.c,b)<10||clb.lo(a.c,b)||clb.so(a.c,b,true))return m;return k;};elb.sw=function sw(a,b,c){var d,e,f;f=0;d=gW(Ykb.AX,gmb,6,clb.wn(a.c,b)-1,15,1);for(e=0;e<clb.wn(a.c,b);e++)clb.vn(a.c,b,e)!=c&&(d[f++]=clb.vn(a.c,b,e));return d;};elb.tw=function tw(){elb.ow();this.c=new clb.Zt(24,29);this.i=gW(Ykb.AX,gmb,6,24,15,1);this.b=gW(Ykb.AX,gmb,6,2,15,1);this.e=gW(Ykb.AX,gmb,6,2,15,1);this.f=gW(Ykb.AX,gmb,6,2,15,1);};U1(197,1,{},elb.tw);_.a=0;Ykb.FY=w3(197);elb.uw=function uw(a){var b,c,d,e,f,g,h,i,j;b=null;switch(a.e){case 1:b=gW(Ykb.Y0,znb,6,2*a.a.length,15,1);for(d=0;d<a.a.length;d++){b[d]=a.a[d];b[a.a.length+d]=180+a.a[d]<<16>>16;}return b;case 2:e=a.a[0]==0?1:0;f=a.a[a.a.length-1]==180?a.a.length-1:a.a.length;j=f-e;b=gW(Ykb.Y0,znb,6,a.a.length+j,15,1);for(g=0;g<a.a.length;g++)b[g]=a.a[g];for(h=e;h<f;h++)b[b.length-1-h+e]=360-a.a[h]<<16>>16;return b;case 3:e=a.a[0]==0?1:0;f=a.a[a.a.length-1]==90?a.a.length-1:a.a.length;j=f-e;b=gW(Ykb.Y0,znb,6,2*a.a.length+2*j,15,1);for(i=0;i<a.a.length;i++){b[i]=a.a[i];b[a.a.length+j+i]=180+a.a[i]<<16>>16;}for(c=e;c<f;c++){b[a.a.length+j-1-c+e]=180-a.a[c]<<16>>16;b[b.length-1-c+e]=360-a.a[c]<<16>>16;}return b;default:return a.a;}};elb.vw=function vw(a){var b,c,d,e,f,g,h,i,j,k;b=null;k=a.c.length;switch(a.e){case 1:b=gW(Ykb.Y0,znb,6,2*k,15,1);for(d=0;d<k;d++){b[d]=a.c[d];b[k+d]=a.c[d];}return b;case 2:e=a.a[0]==0?1:0;f=a.a[k-1]==180?k-1:k;j=f-e;b=gW(Ykb.Y0,znb,6,k+j,15,1);for(g=0;g<k;g++)b[g]=a.c[g];for(h=e;h<f;h++)b[b.length-1-h+e]=a.c[h];return b;case 3:e=a.a[0]==0?1:0;f=a.a[k-1]==90?k-1:k;j=f-e;b=gW(Ykb.Y0,znb,6,2*k+2*j,15,1);for(i=0;i<k;i++){b[i]=a.c[i];b[k+j+i]=a.c[i];}for(c=e;c<f;c++){b[k+j-1-c+e]=a.c[c];b[b.length-1-c+e]=a.c[c];}return b;default:return a.c;}};elb.ww=function ww(a){var b,c,d,e,f,g,h,i,j,k;b=null;k=a.d.length;switch(a.e){case 1:b=eW(Ykb.Y0,[apb,znb],[13,6],15,[2*k,2],2);for(d=0;d<k;d++){b[d][0]=a.d[d][0];b[d][1]=a.d[d][1];b[k+d][0]=180+a.d[d][0]<<16>>16;b[k+d][1]=180+a.d[d][1]<<16>>16;}return b;case 2:e=a.a[0]==0?1:0;f=a.a[k-1]==180?k-1:k;j=f-e;b=eW(Ykb.Y0,[apb,znb],[13,6],15,[k+j,2],2);for(g=0;g<k;g++){b[g][0]=a.d[g][0];b[g][1]=a.d[g][1];}for(h=e;h<f;h++){b[b.length-1-h+e][0]=360-a.d[h][1]<<16>>16;b[b.length-1-h+e][1]=360-a.d[h][0]<<16>>16;}return b;case 3:e=a.a[0]==0?1:0;f=a.a[k-1]==90?k-1:k;j=f-e;b=eW(Ykb.Y0,[apb,znb],[13,6],15,[2*k+2*j,2],2);for(i=0;i<k;i++){b[i][0]=a.d[i][0];b[i][1]=a.d[i][1];b[k+j+i][0]=180+a.d[i][0]<<16>>16;b[k+j+i][1]=180+a.d[i][1]<<16>>16;}for(c=e;c<f;c++){b[k+j-1-c+e][0]=180-a.d[c][1]<<16>>16;b[k+j-1-c+e][1]=180-a.d[c][0]<<16>>16;b[b.length-1-c+e][0]=360-a.d[c][1]<<16>>16;b[b.length-1-c+e][1]=360-a.d[c][0]<<16>>16;}return b;default:return a.d;}};elb.xw=function xw(a,b,c,d,e,f){var g,h,i,j,k,l;a.a[c]=b<<16>>16;a.c[c]=a.c[c]+a.c[d]<<16>>16;a.d[c][0]=e<<16>>16;a.d[c][1]=f<<16>>16;l=a.a.length-1;i=gW(Ykb.Y0,znb,6,l,15,1);j=gW(Ykb.Y0,znb,6,l,15,1);k=gW(Ykb.Y0,apb,13,l,0,2);h=0;for(g=0;g<a.a.length;g++){if(g!=d){i[h]=a.a[g];j[h]=a.c[g];k[h]=a.d[g];++h;}}a.a=i;a.c=j;a.d=k;};elb.yw=function yw(a){var b,c,d,e,f,g,h,i,j,k,l,m;b=0;while(a.a.length!=0){if(a.a.length==1){if(a.e==1||a.e==0)break;else if(a.e==2&&(a.a[0]==0||a.a[0]==180))break;else if(a.e==3&&(a.a[0]==0||a.a[0]==90))break;}m=a.a[0]!=0&&(a.e==2||a.e==3)?-1:0;l=-1;k=Qlb;for(g=m;g<a.a.length;g++){i=g+1;c=g>=0?a.a[g]:-a.a[0];d=i<a.a.length?a.a[i]:a.e==1?a.a[0]+180:a.e==2?360-a.a[a.a[g]==180?g-1:g]:a.e==3?180-a.a[a.a[g]==90?g-1:g]:a.a[0]+360;if(k>d-c){k=d-c;l=g;}}if(k>15)break;f=l;h=f+1;if(f==-1){b+=a.c[0];a.a[0]=0;a.c[0]=a.c[0]*2<<16>>16;a.d[0][0]=-a.d[0][1];}else if(h<a.a.length){j=elb.zw(a,f,h,a.a[h]);elb.xw(a,j,f,h,a.d[f][0],a.d[h][1]);}else if(a.e==1){h=0;j=elb.zw(a,f,h,a.a[h]+180);j<=180?elb.xw(a,j,f,h,a.d[f][0],a.d[h][1]+180):elb.xw(a,j-180,h,f,a.d[h][0],a.d[f][1]-180);}else if(a.e==2){h=a.a[f]==180?f-1:f;if(a.a[f]<180){b+=a.c[f];a.a[f]=180;a.c[f]=a.c[f]*2<<16>>16;a.d[f][1]=360-a.d[f][0]<<16>>16;}else {Zkb.O5();j=elb.zw(a,f,h,a.a[h]);elb.xw(a,j,h,f,a.d[h][0],a.d[f][1]);}}else if(a.e==3){h=a.a[f]==90?f-1:f;if(a.a[f]<90){b+=a.c[f];a.a[f]=90;a.c[f]=a.c[f]*2<<16>>16;a.d[f][1]=180-a.d[f][0]<<16>>16;}else {Zkb.O5();j=elb.zw(a,f,h,a.a[h]);elb.xw(a,j,h,f,a.d[h][0],a.d[f][1]);}}else {h=0;j=elb.zw(a,f,h,a.a[h]+360);j<=360?elb.xw(a,j,f,h,a.d[f][0],a.d[h][1]+360):elb.xw(a,j-360,h,f,a.d[h][0],a.d[f][1]-360);}}if(b!=0)for(e=0;e<a.c.length;e++)a.c[e]=vX($wnd.Math.round(100*a.c[e]/(100+b)))<<16>>16;};elb.zw=function zw(a,b,c,d){return vX($wnd.Math.round((a.a[b]*a.c[b]+d*a.c[c])/(a.c[b]+a.c[c])));};elb.Aw=function Aw(a){this.e=a;};elb.Bw=function Bw(a){var b;this.e=a.e;if(a.a!=null){this.a=gW(Ykb.Y0,znb,6,a.a.length,15,1);for(b=0;b<this.a.length;b++)this.a[b]=360-a.a[this.a.length-b-1]<<16>>16;}if(a.d!=null){this.d=eW(Ykb.Y0,[apb,znb],[13,6],15,[a.d.length,2],2);for(b=0;b<this.d.length;b++){this.d[b][0]=360-a.d[this.a.length-b-1][1]<<16>>16;this.d[b][1]=360-a.d[this.a.length-b-1][0]<<16>>16;}}if(a.c!=null){this.c=gW(Ykb.Y0,znb,6,a.c.length,15,1);for(b=0;b<this.c.length;b++)this.c[b]=a.c[this.c.length-b-1];}if(a.b!=null){this.b=gW(Ykb.wX,Fnb,6,a.b.length,15,1);for(b=0;b<this.b.length;b++)this.b[b]=a.b[this.b.length-b-1];}};U1(149,1,{149:1},elb.Aw,elb.Bw);_.e=0;Ykb.GY=w3(149);elb.Cw=function Cw(a,b){var c,d,e,f;c=b[1];d=b[2];e=a.j[c]-1;f=a.j[d]-1;if(e>3||f>3){this.b=gW(Ykb.Y0,znb,6,4,15,1);this.b[0]=45;this.b[1]=135;this.b[2]=225;this.b[2]=315;this.c=eW(Ykb.Y0,[apb,znb],[13,6],15,[4,2],2);this.c[0][0]=30;this.c[0][1]=60;this.c[1][0]=120;this.c[1][1]=150;this.c[2][0]=210;this.c[2][1]=240;this.c[2][0]=300;this.c[2][1]=330;this.a=gW(Ykb.Y0,znb,6,4,15,1);this.a[0]=25;this.a[1]=25;this.a[2]=25;this.a[3]=25;}else if((a.o[c]==0||a.C[c]>9)&&(a.o[d]==0||a.C[d]>9)){if(e==3&&f==3||e==3&&f==2||e==3&&f==1||e==2&&f==3||e==1&&f==3||e==2&&f==2&&(b[0]!=-1||b[3]!=-1)){this.b=gW(Ykb.Y0,znb,6,3,15,1);this.b[0]=60;this.b[1]=180;this.b[2]=300;this.c=eW(Ykb.Y0,[apb,znb],[13,6],15,[3,2],2);this.c[0][0]=45;this.c[0][1]=75;this.c[1][0]=165;this.c[1][1]=195;this.c[2][0]=285;this.c[2][1]=315;this.a=gW(Ykb.Y0,znb,6,3,15,1);this.a[0]=33;this.a[1]=33;this.a[2]=33;}else if(e==1&&f==2&&b[3]==-1||e==2&&f==1&&b[0]==-1){this.b=gW(Ykb.Y0,znb,6,3,15,1);this.b[0]=60;this.b[1]=180;this.b[2]=300;this.c=eW(Ykb.Y0,[apb,znb],[13,6],15,[3,2],2);this.c[0][0]=45;this.c[0][1]=75;this.c[1][0]=165;this.c[1][1]=195;this.c[2][0]=285;this.c[2][1]=315;this.a=gW(Ykb.Y0,znb,6,3,15,1);this.a[0]=40;this.a[1]=20;this.a[2]=40;}else if(e==1&&f==1||e==1&&f==2&&b[3]!=-1||e==2&&f==1&&b[0]!=-1||e==2&&f==2&&b[0]==-1&&b[3]==-1){this.b=gW(Ykb.Y0,znb,6,3,15,1);this.b[0]=60;this.b[1]=180;this.b[2]=300;this.c=eW(Ykb.Y0,[apb,znb],[13,6],15,[3,2],2);this.c[0][0]=45;this.c[0][1]=75;this.c[1][0]=165;this.c[1][1]=195;this.c[2][0]=285;this.c[2][1]=315;this.a=gW(Ykb.Y0,znb,6,3,15,1);this.a[0]=25;this.a[1]=50;this.a[2]=25;}}else if((a.o[c]==0||a.C[c]>9)&&a.o[d]==1||(a.o[d]==0||a.C[d]>9)&&a.o[c]==1){if(e==3||f==3){this.b=gW(Ykb.Y0,znb,6,6,15,1);this.b[0]=0;this.b[1]=60;this.b[2]=120;this.b[3]=180;this.b[4]=240;this.b[5]=300;this.c=eW(Ykb.Y0,[apb,znb],[13,6],15,[6,2],2);this.c[0][0]=-15;this.c[0][1]=15;this.c[1][0]=45;this.c[1][1]=75;this.c[2][0]=105;this.c[2][1]=135;this.c[3][0]=165;this.c[3][1]=195;this.c[4][0]=225;this.c[4][1]=255;this.c[5][0]=285;this.c[5][1]=315;this.a=gW(Ykb.Y0,znb,6,6,15,1);this.a[0]=16;this.a[1]=16;this.a[2]=16;this.a[3]=16;this.a[4]=16;this.a[5]=16;}else if(e==1&&f==1){this.b=gW(Ykb.Y0,znb,6,2,15,1);this.b[0]=120;this.b[1]=240;this.c=eW(Ykb.Y0,[apb,znb],[13,6],15,[2,2],2);this.c[0][0]=105;this.c[0][1]=135;this.c[1][0]=225;this.c[1][1]=255;this.a=gW(Ykb.Y0,znb,6,2,15,1);this.a[0]=50;this.a[1]=50;}else if(a.o[c]==1&&e==2&&f==1||a.o[d]==1&&f==2&&e==1){this.b=gW(Ykb.Y0,znb,6,2,15,1);this.b[0]=90;this.b[1]=270;this.c=eW(Ykb.Y0,[apb,znb],[13,6],15,[2,2],2);this.c[0][0]=75;this.c[0][1]=105;this.c[1][0]=255;this.c[1][1]=285;this.a=gW(Ykb.Y0,znb,6,2,15,1);this.a[0]=50;this.a[1]=50;}else if(a.o[c]==1&&e==1&&f==2&&b[3]==-1||a.o[d]==1&&f==1&&e==2&&b[0]==-1){this.b=gW(Ykb.Y0,znb,6,3,15,1);this.b[0]=0;this.b[1]=120;this.b[2]=240;this.c=eW(Ykb.Y0,[apb,znb],[13,6],15,[3,2],2);this.c[0][0]=-15;this.c[0][1]=15;this.c[1][0]=105;this.c[1][1]=135;this.c[2][0]=225;this.c[2][1]=255;this.a=gW(Ykb.Y0,znb,6,3,15,1);this.a[0]=60;this.a[1]=20;this.a[2]=20;}else if(a.o[c]==1&&e==1&&f==2&&b[3]!=-1||a.o[d]==1&&f==1&&e==2&&b[0]!=-1){this.b=gW(Ykb.Y0,znb,6,3,15,1);this.b[0]=0;this.b[1]=120;this.b[2]=240;this.c=eW(Ykb.Y0,[apb,znb],[13,6],15,[3,2],2);this.c[0][0]=-15;this.c[0][1]=15;this.c[1][0]=105;this.c[1][1]=135;this.c[2][0]=225;this.c[2][1]=255;this.a=gW(Ykb.Y0,znb,6,3,15,1);this.a[0]=20;this.a[1]=40;this.a[2]=40;}else if(e==2&&f==2){if(b[0]==-1||b[3]==-1){this.b=gW(Ykb.Y0,znb,6,2,15,1);this.b[0]=0;this.b[1]=180;this.c=eW(Ykb.Y0,[apb,znb],[13,6],15,[2,2],2);this.c[0][0]=-15;this.c[0][1]=15;this.c[1][0]=165;this.c[1][1]=195;this.a=gW(Ykb.Y0,znb,6,2,15,1);this.a[0]=50;this.a[1]=50;}else {this.b=gW(Ykb.Y0,znb,6,2,15,1);this.b[0]=90;this.b[1]=270;this.c=eW(Ykb.Y0,[apb,znb],[13,6],15,[2,2],2);this.c[0][0]=75;this.c[0][1]=105;this.c[1][0]=255;this.c[1][1]=285;this.a=gW(Ykb.Y0,znb,6,2,15,1);this.a[0]=50;this.a[1]=50;}}}else if(a.o[c]==1&&a.o[d]==1){if(e==1&&f==1){this.b=gW(Ykb.Y0,znb,6,2,15,1);this.b[0]=0;this.b[1]=180;this.c=eW(Ykb.Y0,[apb,znb],[13,6],15,[2,2],2);this.c[0][0]=-15;this.c[0][1]=15;this.c[1][0]=165;this.c[1][1]=195;this.a=gW(Ykb.Y0,znb,6,2,15,1);this.a[0]=10;this.a[1]=90;}else {this.b=gW(Ykb.Y0,znb,6,6,15,1);this.b[0]=0;this.b[1]=50;this.b[2]=130;this.b[3]=180;this.b[4]=230;this.b[5]=310;this.c=eW(Ykb.Y0,[apb,znb],[13,6],15,[6,2],2);this.c[0][0]=-15;this.c[0][1]=15;this.c[1][0]=35;this.c[1][1]=65;this.c[2][0]=115;this.c[2][1]=145;this.c[3][0]=165;this.c[3][1]=195;this.c[4][0]=215;this.c[4][1]=245;this.c[5][0]=295;this.c[5][1]=325;this.a=gW(Ykb.Y0,znb,6,6,15,1);this.a[0]=40;this.a[1]=5;this.a[2]=5;this.a[3]=40;this.a[4]=5;this.a[5]=5;}}else {this.b=gW(Ykb.Y0,znb,6,1,15,1);this.b[0]=180;this.c=eW(Ykb.Y0,[apb,znb],[13,6],15,[1,2],2);this.c[0][0]=165;this.c[0][1]=195;this.a=gW(Ykb.Y0,znb,6,1,15,1);this.a[0]=100;}};U1(198,1,{},elb.Cw);Ykb.HY=w3(198);elb.Fw=function Fw(){elb.Fw=W1;elb.Ew=oW(aW(Ykb.zX,1),cob,6,15,[1,dpb,epb,2.119999885559082,1.9800000190734863,1.909999966621399,1.7699999809265137,fpb,1.5,gpb,1.5800000429153442,2.5,2.509999990463257,2.25,2.190000057220459,1.899999976158142,1.8899999856948853,hpb,1.8300000429153442,2.7300000190734863,2.619999885559082,2.5799999237060547,ipb,jpb,kpb,kpb,lpb,mpb,mpb,2.380000114440918,2.390000104904175,npb,opb,1.8799999952316284,hpb,ppb,2.25,3.2100000381469727,2.8399999141693115,2.75,2.5199999809265137,2.559999942779541,kpb,lpb,ipb,lpb,2.1500000953674316,qpb,rpb,2.430000066757202,jpb,spb,1.9900000095367432,2.0399999618530273,2.059999942779541,3.4800000190734863,3.0299999713897705,2.9800000190734863,tpb,upb,2.950000047683716,upb,2.9000000953674316,vpb,wpb,xpb,vpb,ypb,wpb,xpb,zpb,2.740000009536743,2.630000114440918,qpb,2.569999933242798,rpb,2.4800000190734863,2.4100000858306885,opb,npb,kpb,spb,2.5999999046325684,2.5399999618530273,2.5,2.5,2.5,2.5,2.5,zpb,2.930000066757202,tpb,2.7100000381469727,2.819999933242798,ypb,wpb,Apb,3.4000000953674316,Apb,2.700000047683716]);elb.Dw=oW(aW(Ykb.zX,1),cob,6,15,[0.25,0.3199999928474426,0.46000000834465027,Bpb,1.0199999809265137,0.8500000238418579,0.75,0.7099999785423279,0.6299999952316284,0.6399999856948853,0.9599999785423279,1.600000023841858,Cpb,1.2599999904632568,Dpb,Epb,1.0299999713897705,0.9900000095367432,Fpb,Gpb,Hpb,1.4800000190734863,Ipb,Jpb,Kpb,1.190000057220459,Dpb,Epb,1.100000023841858,dpb,dpb,Lpb,Mpb,Mpb,Dpb,1.1399999856948853,Mpb,2.0999999046325684,Npb,Opb,1.5399999618530273,Ppb,1.3799999952316284,Qpb,1.25,1.25,dpb,Cpb,Rpb,gpb,Spb,Spb,Ipb,Bpb,1.350000023841858,npb,Gpb,$ob,Opb,Tpb,1.7400000095367432,Upb,Vpb,Wpb,Xpb,Wpb,Ypb,fpb,Zpb,1.6399999856948853,$pb,_pb,1.5199999809265137,gpb,aqb,1.309999942779541,bqb,Kpb,1.2300000190734863,Lpb,1.4199999570846558,1.5,Rpb,1.5099999904632568,cqb,Ppb,cqb,2.2300000190734863,2.009999990463257,ppb,1.75,Xpb,$pb,Hpb,Vpb,fpb,fpb,Wpb,Wpb,Zpb,Ypb,Upb,Tpb,1.6100000143051147,dqb,1.4900000095367432,epb,1.409999966621399,Jpb,bqb,Qpb,Mpb,aqb,Ipb,epb,_pb,1.75,Zpb,dqb]);};flb.Hw=function Hw(){flb.Hw=W1;flb.Gw=clb.Nm('X',32);};flb.Iw=function Iw(a,b){flb.Hw();var c,d,e,f,g;for(e=0;e<a.q;e++){g=clb.Kt(a);clb._l(g,e,flb.Gw);clb.Gt(g,15);for(d=0;d<g.f;d++){if((g.u[d]&Xnb)!=0&&clb._n(g,d)==-1){f=(clb.Gt(g,7),g.o[d]==2&&g.j[d]==2?clb.Go(g,d,false):clb.Io(g,d,false));if(f!=-1){a.H[f]=257;a.T=0;if(a.D[1][f]==d){c=a.D[0][f];a.D[0][f]=d;a.T=0;a.D[1][f]=c;a.T=0;}clb.Nl(a,d,b,0);}}}}};flb.Jw=function Jw(a){flb.Hw();var b,c,d,e;flb.Iw(a,1);d=a.q;c=gW(Ykb.l_,Xlb,2,d,6,1);for(b=0;b<d;b++){e=clb.Kt(a);clb.Ll(e,b,(clb.wj(),clb.qj)[e.C[b]]+'*');e.C[b]==1?clb._l(e,b,flb.Gw):clb.Sl(e,b,e.A[b]+5);flb.Kw(e);c[b]=clb.Gf(new clb.bg(e,8));}return c;};flb.Kw=function Kw(a){var b;clb.Gt(a,15);for(b=0;b<a.q;b++){(a.u[b]&3)!=0&&clb.Nl(a,b,1,0);}};flb.Gw=0;flb.Lw=function Lw(a,b,c){var d,e;d=eW(Ykb.l_,[Llb,Xlb],[29,2],6,[a.f,b],2);clb.Gt(a,7);for(e=0;e<a.f;e++){d[e]=flb.Mw(a,e,b,c);}return d;};flb.Mw=function Mw(a,b,c,d){var e,f,g,h,i,j,k,l,m,n,o,p;i=new clb.Zt(a.f,a.g);k=new dlb.sfb();n=0;m=0;g=gW(Ykb.Z0,Amb,6,a.f,16,1);f=gW(Ykb.AX,gmb,6,a.f,15,1);for(p=0;p<c&&m<a.f;p++){if(m==0){f[0]=b;g[b]=true;m=1;}else {o=m;for(j=n;j<m;j++){e=f[j];for(l=0;l<a.j[e];l++){h=a.i[e][l];if(!g[h]){switch(d){case 0:g[h]=true;f[o++]=h;break;case 1:if(!(flb.Ow(a,e)&&flb.Ow(a,h))){g[h]=true;f[o++]=h;}}}}}n=m;m=o;}clb.Zm(a,i,g,true,null);dlb.pfb(k,clb.Gf(new clb.bg(i,8)));}return dlb.rfb(k,gW(Ykb.l_,Xlb,2,k.a.a.length,6,1));};flb.Nw=function Nw(a,b,c){var d,e,f,g,h;g=clb.bp(new clb.mp(true),a);e=-1;for(f=0;f<g.q;f++){d=g.t==null?null:g.t[f]==null?null:Zkb.a5(g.t[f]);if(d!=null&&(h=alb.Pgb('*').length,Zkb.c5(alb.Pgb(d).substr(alb.Pgb(d).length-h,h),'*'))){e=f;break;}}if(e>=0){return flb.Mw(g,e,b,c);}return gW(Ykb.l_,Xlb,2,0,6,1);};flb.Ow=function Ow(a,b){if(a.C[b]!=6)return false;if(a.s[b]!=0)return false;if(clb.Kn(a,b)+a.j[b]!=4)return false;return true;};flb.Zw=function Zw(){flb.Zw=W1;flb.Pw=$wnd.Math.cos(qnb);flb.Uw=$wnd.Math.sin(qnb);flb.Rw=$wnd.Math.cos(eqb);flb.Ww=$wnd.Math.sin(eqb);flb.Tw=$wnd.Math.cos(pnb);flb.Yw=$wnd.Math.sin(pnb);flb.Qw=$wnd.Math.cos(fqb);flb.Vw=$wnd.Math.sin(fqb);flb.Sw=$wnd.Math.cos(dob);flb.Xw=$wnd.Math.sin(dob);$wnd.Math.cos(gqb);$wnd.Math.sin(gqb);};flb.$w=function $w(a){flb.Zw();var b,c;clb.Gt(a,1);c=a.f;for(b=0;b<c;b++){flb._w(a,b);}};flb._w=function _w(a,b){flb.Zw();var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G,H,I,J;A=clb.Kn(a,b);I=a.J[b].a;J=a.J[b].b;switch(A){case 1:{C=a.j[b];if(C==0){k=clb.rn(a,true);n=0;}else {k=I-clb.rk(a,a.i[b][0]);n=J-clb.sk(a,a.i[b][0]);}if(C==1){t=clb.xj(a,I+flb.Sw*k+flb.Xw*n,J-flb.Xw*k+flb.Sw*n,0);}else if(C==2){k=I-0.5*(clb.rk(a,a.i[b][0])+clb.rk(a,a.i[b][1]));n=J-0.5*(clb.sk(a,a.i[b][0])+clb.sk(a,a.i[b][1]));t=clb.xj(a,I+k,J+n,0);}else if(C==3){F=a.i[b][0];for(r=1;r<3;r++){h=a.k[b][r];(a.H[h]==129||a.H[h]==257)&&(F=a.i[b][r]);}c=$wnd.Math.abs(clb.Mm(clb.Lm(a.J[b].a,a.J[b].b,clb.rk(a,a.i[b][0]),clb.sk(a,a.i[b][0])),clb.Lm(a.J[b].a,a.J[b].b,clb.rk(a,a.i[b][1]),clb.sk(a,a.i[b][1]))));d=$wnd.Math.abs(clb.Mm(clb.Lm(a.J[b].a,a.J[b].b,clb.rk(a,a.i[b][0]),clb.sk(a,a.i[b][0])),clb.Lm(a.J[b].a,a.J[b].b,clb.rk(a,a.i[b][2]),clb.sk(a,a.i[b][2]))));e=$wnd.Math.abs(clb.Mm(clb.Lm(a.J[b].a,a.J[b].b,clb.rk(a,a.i[b][1]),clb.sk(a,a.i[b][1])),clb.Lm(a.J[b].a,a.J[b].b,clb.rk(a,a.i[b][2]),clb.sk(a,a.i[b][2]))));D=true;if(c>d&&c>e){if(d+e<Fmb){D=false;k=I-0.5*(clb.rk(a,a.i[b][0])+clb.rk(a,a.i[b][1]));n=J-0.5*(clb.sk(a,a.i[b][0])+clb.sk(a,a.i[b][1]));}}else if(d>c&&d>e){if(c+e<Fmb){D=false;k=I-0.5*(clb.rk(a,a.i[b][0])+clb.rk(a,a.i[b][2]));n=J-0.5*(clb.sk(a,a.i[b][0])+clb.sk(a,a.i[b][2]));}}else {if(c+d<Fmb){D=false;k=I-0.5*(clb.rk(a,a.i[b][1])+clb.rk(a,a.i[b][2]));n=J-0.5*(clb.sk(a,a.i[b][1])+clb.sk(a,a.i[b][2]));}}if(D){G=a.i[b][0];j=Unb;for(q=0;q<3;q++){f=a.i[b][q];if(f!=F){i=$wnd.Math.pow(a.J[b].a-a.J[f].a,2)+$wnd.Math.pow(a.J[b].b-a.J[f].b,2);if(i<j){G=f;j=i;Zkb.O5();}}}t=clb.xj(a,(a.J[F].a+a.J[G].a)/2,(a.J[F].b+a.J[G].b)/2,0);}else {t=clb.xj(a,I+k,J+n,0);}}else {t=clb.xj(a,I+k,J+n,0);}clb._l(a,t,1);clb.Aj(a,b,t,1);}break;case 2:B=a.j[b];if(B==1){k=I-clb.rk(a,a.i[b][0]);n=J-clb.sk(a,a.i[b][0]);t=clb.xj(a,I+(flb.Tw*k-flb.Yw*n)*0.7,J+(flb.Yw*k+flb.Tw*n)*0.7,0);clb._l(a,t,1);clb.Aj(a,b,t,1);t=clb.xj(a,I+(flb.Qw*k-flb.Vw*n)*0.7,J+(flb.Vw*k+flb.Qw*n)*0.7,0);clb._l(a,t,1);clb.Aj(a,b,t,1);}else if(B==2){l=I-clb.rk(a,a.i[b][0]);o=J-clb.sk(a,a.i[b][0]);m=I-clb.rk(a,a.i[b][1]);p=J-clb.sk(a,a.i[b][1]);v=$wnd.Math.sqrt(l*l+o*o)*0.7;w=$wnd.Math.sqrt(m*m+p*p)*0.7;k=l+m;n=o+p;u=$wnd.Math.sqrt(k*k+n*n);g=(v+w)/2;k=k/u*g;n=n/u*g;H=clb._n(a,b);t=clb.xj(a,I+flb.Pw*k-flb.Uw*n,J+flb.Uw*k+flb.Pw*n,0);clb._l(a,t,1);H>-1?clb.Aj(a,b,t,1):clb.Aj(a,b,t,257);t=clb.xj(a,I+flb.Rw*k-flb.Ww*n,J+flb.Ww*k+flb.Rw*n,0);clb._l(a,t,1);clb.Aj(a,b,t,1);}else {for(s=0;s<A;s++){t=clb.xj(a,I,J,0);clb._l(a,t,1);clb.Aj(a,b,t,1);}}break;case 3:{if(a.i[b][0]>0){k=(I-clb.rk(a,a.i[b][0]))*0.7;n=(J-clb.sk(a,a.i[b][0]))*0.7;t=clb.xj(a,I+k,J+n,0);clb._l(a,t,1);clb.Aj(a,b,t,1);t=clb.xj(a,I-n,J+k,0);clb._l(a,t,1);clb.Aj(a,b,t,1);t=clb.xj(a,I+n,J-k,0);clb._l(a,t,1);clb.Aj(a,b,t,1);}else {k=clb.rn(a,true);n=clb.rn(a,true);t=clb.xj(a,I+k,J+n,0);clb._l(a,t,1);clb.Aj(a,b,t,1);t=clb.xj(a,I-n*flb.Tw,J+k*flb.Yw,0);clb._l(a,t,1);clb.Aj(a,b,t,1);t=clb.xj(a,I-n*flb.Tw,J-k*flb.Yw,0);clb._l(a,t,1);clb.Aj(a,b,t,1);}}break;default:{for(s=0;s<A;s++){t=clb.xj(a,I,J,0);clb._l(a,t,1);clb.Aj(a,b,t,1);}break;}}};flb.ax=function ax(a){flb.Zw();var b,c;clb.Gt(a,1);c=0;for(b=0;b<a.q;b++){a.C[b]==1?++c:c+=a.e[b]-a.j[b]+clb.Kn(a,b);}return c;};flb.Pw=0;flb.Qw=0;flb.Rw=0;flb.Sw=0;flb.Tw=0;flb.Uw=0;flb.Vw=0;flb.Ww=0;flb.Xw=0;flb.Yw=0;glb.cx=function cx(a,b,c){var d,e,f;f=b.length;d=new glb.Jy(a.f,f,false);d.a[0]=0;d.b[0]=0;for(e=0;e<f;e++){d.k[e]=128-f;d.e[e]=b[e];}f<8?glb.lx(d):glb.jx(a,d,b,c);glb.Tx(a.d,d);};glb.dx=function dx(a,b,c,d,e){var f,g,h,i,j,k,l,m;g=gW(Ykb.AX,gmb,6,e,15,1);for(f=0;f<a.f.q;f++){for(i=0;i<clb.gn(a.f,f);i++){m=c[clb.vn(a.f,f,i)];for(j=0;j<i;j++)if(m<g[j])break;for(k=i;k>j;k--)g[k]=g[k-1];g[j]=m;}l=clb.gn(a.f,f);clb.sg(b[f],f);clb.pg(b[f],d,Ykb.m1(c[f]));clb.pg(b[f],(e-l)*(d+1),0);for(h=0;h<l;h++)clb.pg(b[f],d+1,Ykb.m1(g[h]));}};glb.ex=function ex(a){var b,c,d,e,f,g,h,i,j,k,l;d=clb.cg(a.f.f);i=2;for(c=0;c<a.f.f;c++)i=$wnd.Math.max(i,clb.gn(a.f,c));f=(62+2*d+i*(d+1))/63|0;e=gW(Ykb.MX,Enb,110,a.f.q,0,1);for(b=0;b<a.f.q;b++){e[b]=new clb.tg(f);clb.sg(e[b],b);}l=gW(Ykb.AX,gmb,6,a.f.q,15,1);for(g=0;g<a.f.g;g++){h=clb.Ik(a.f,g);if(h==1||h==2){clb.qg(e[clb.zk(a.f,0,g)],Ykb.m1(h));clb.qg(e[clb.zk(a.f,1,g)],Ykb.m1(h));}}j=glb.fx(e,l);do{k=j;glb.dx(a,e,l,d,i);j=glb.fx(e,l);}while(k!=j);return l;};glb.fx=function fx(a,b){var c,d;d=0;dlb.icb(a,0,a.length,null);for(c=0;c<a.length;c++){(c==0||clb.rg(a[c],a[c-1])!=0)&&++d;b[a[c].a]=d;}return d;};glb.gx=function gx(a){var b,c,d,e,f,g,h,i,j,k,l,m;for(i=0;i<a.d.a.length;i++){h=dlb.Bi(a.d,i);for(j=0;j<h.f.length;j++){d=h.f[j];if(clb.Hk(a.f,d)==2){!clb.Co(a.f,d)&&(clb.Ik(a.f,d)==3||clb.Ik(a.f,d)==0)&&clb.hm(a.f,d);if(!clb.zo(a.f,d)&&clb.wn(a.f,clb.zk(a.f,0,d))>1&&clb.wn(a.f,clb.zk(a.f,1,d))>1&&(clb.Ik(a.f,d)==1||clb.Ik(a.f,d)==2)){m=gW(Ykb.AX,gmb,6,2,15,1);e=gW(Ykb.AX,gmb,6,2,15,1);for(k=0;k<2;k++){m[k]=a.f.M;e[k]=clb.zk(a.f,k,d);for(l=0;l<clb.gn(a.f,e[k]);l++){f=clb.vn(a.f,e[k],l);f!=clb.zk(a.f,1-k,d)&&m[k]>f&&(m[k]=f);}}g=glb.ny(h.a[h.g[e[0]]],h.b[h.g[e[0]]],h.a[h.g[e[1]]],h.b[h.g[e[1]]]);b=glb.ny(h.a[h.g[m[0]]],h.b[h.g[m[0]]],h.a[h.g[e[0]]],h.b[h.g[e[0]]]);c=glb.ny(h.a[h.g[e[1]]],h.b[h.g[e[1]]],h.a[h.g[m[1]]],h.b[h.g[m[1]]]);glb.nx(g,b)<0^glb.nx(g,c)<0^clb.Ik(a.f,d)==2&&glb.xy(h,d);}}}}};glb.hx=function hx(a){var b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r;m=new dlb.Qi();r=new dlb.Qi();d=new dlb.Qi();for(f=new dlb.Obb(a.d);f.a<f.c.a.length;){e=dlb.Nbb(f);g=0;alb.igb(d.a,0);for(h=0;h<e.e.length;h++){b=e.e[h];c=a.i[b];if(c!=0){dlb.wi(d,new glb.py(e,h,c));g+=c;}}if(g!=0){dlb.Ni(d,new glb.Yx());for(j=new dlb.Obb(d);j.a<j.c.a.length;){i=dlb.Nbb(j);if(g*i.b>0){c=$wnd.Math.abs(g)>=$wnd.Math.abs(i.b)?i.b:g;g-=c;dlb.wi(c<0?m:r,new glb.py(e,i.a,c));if(g==0)break;}}}}if(m.a.length==0||r.a.length==0)return null;dlb.Ni(r,new glb.ay());dlb.Ni(m,new glb.ey());for(p=new dlb.Obb(r);p.a<p.c.a.length;){n=dlb.Nbb(p);for(l=new dlb.Obb(m);l.a<l.c.a.length;){k=dlb.Nbb(l);if(n.b==-k.b){a.i[glb.By(n.c,n.a)]-=n.b;a.i[glb.By(k.c,k.a)]-=k.b;return new glb.ky(n.c,k.c,n.a,k.a);}}}for(q=new dlb.Obb(r);q.a<q.c.a.length;){n=dlb.Nbb(q);for(l=new dlb.Obb(m);l.a<l.c.a.length;){k=dlb.Nbb(l);if(n.b>-k.b){a.i[glb.By(n.c,n.a)]+=k.b;a.i[glb.By(k.c,k.a)]-=k.b;return new glb.ky(n.c,k.c,n.a,k.a);}}}for(o=new dlb.Obb(r);o.a<o.c.a.length;){n=dlb.Nbb(o);for(l=new dlb.Obb(m);l.a<l.c.a.length;){k=dlb.Nbb(l);if(n.b<-k.b){a.i[glb.By(n.c,n.a)]-=n.b;a.i[glb.By(k.c,k.a)]+=n.b;return new glb.ky(n.c,k.c,n.a,k.a);}}}return null;};glb.ix=function ix(a){if(a.d.a.length<2)return null;return new glb.jy(dlb.Bi(a.d,0),dlb.Bi(a.d,1));};glb.jx=function jx(a,b,c,d){var e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C;k=oW(aW(Ykb.yX,2),Llb,12,0,[oW(aW(Ykb.yX,1),emb,6,15,[20]),null,null,oW(aW(Ykb.yX,1),emb,6,15,[0,10]),null,null,oW(aW(Ykb.yX,1),emb,6,15,[-4,12]),oW(aW(Ykb.yX,1),emb,6,15,[0,0,-7.5]),null,null,null,null,oW(aW(Ykb.yX,1),emb,6,15,[8,-8]),null,null,null,oW(aW(Ykb.yX,1),emb,6,15,[-2.4])]);l=oW(aW(Ykb.AX,2),Dnb,7,0,[oW(aW(Ykb.AX,1),gmb,6,15,[146]),oW(aW(Ykb.AX,1),gmb,6,15,[627]),null,oW(aW(Ykb.AX,1),gmb,6,15,[2457,1170]),null,oW(aW(Ykb.AX,1),gmb,6,15,[2451,8643,2519]),oW(aW(Ykb.AX,1),gmb,6,15,[9362,14798]),oW(aW(Ykb.AX,1),gmb,6,15,[34377,-2147448999,26214]),null,oW(aW(Ykb.AX,1),gmb,6,15,[37449,137313,95703,34371,37815,54891,132867,-2147309741,54857,55129,-2147449005,-2147449065]),null,oW(aW(Ykb.AX,1),gmb,6,15,[530697,531819,899169,137289,694617,-2146951863,-2146952797,-2146939175,-2146929547,-2146929564,-2146625111,-2146931799,-2146940503,-2146931935]),oW(aW(Ykb.AX,1),gmb,6,15,[1007293,610915]),oW(aW(Ykb.AX,1),gmb,6,15,[542985,137283,2122017,530691,2206773,-2144711351,219209,2840841,137555,-2146871031,-2147264167,613705,-2145360543,-2146625271,694611,2454837,-2145356703,-2147345133,-2146928951,-2146931805,-2144641719,-2146951869,-2146625237,-2146624183,2841963,1074905,-2146625117,2799955,-2144723645,138583,859225,-2145264843,-2145216253,-2146624149,-2144700727,-2146928917,-2143905527,-2144045771,-2146789097,2288547,544407,2104323,-2146911977,-2144479405,3633737,-2146870089,-2146952169]),null,oW(aW(Ykb.AX,1),gmb,6,15,[8487297,2172633,2116611,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8829813]),oW(aW(Ykb.AX,1),gmb,6,15,[14071213])]);s=1<<b.e.length;g=0;i=0;if(b.e.length>7){for(n=0;n<b.e.length;n++){h=glb.rx(a,c,d,n);h==1?g+=s:h==2&&(i+=s);g>>>=1;i>>>=1;}}v=b.e.length-9;if(b.e.length>=9&&b.e.length<=25&&l[v]!=null){for(C=0;C<l[v].length;C++){r=(oob&l[v][C])==0;j=Qlb&l[v][C];for(p=false;!p;p=!p){if(p){if(r)break;t=0;for(e=1;e!=s;e<<=1){t<<=1;(j&e)!=0&&(t|=1);}j=t;}for(w=0;w<b.e.length;w++){if((j&g)==0&&(~j&i)==0){f=0;m=hqb*(k[v]==null?0:k[v][C]);u=0;A=j;q=true;for(o=0;o<b.e.length;o++){q&&++u;(A&1)==0&&(q=!q);A>>>=1;}B=u>(b.e.length/2|0);for(n=1;n<b.e.length;n++){b.a[n]=b.a[n-1]+$wnd.Math.sin(f);b.b[n]=b.b[n-1]+$wnd.Math.cos(f);(j&1)==0&&(B=!B);f+=m+(B?pnb:fqb);j>>>=1;}return;}(j&1)!=0&&(j|=s);j>>>=1;}}}}glb.mx(b,g,i);};glb.kx=function kx(a){var b,c,d,e,f,g,h,i,j,k;b=null;j=null;for(g=0;g<a.f.g;g++){if(clb.Kk(a.f,g)==32){c=clb.zk(a.f,0,g);e=-1;h=0;for(;h<a.d.a.length;h++){e=glb.Cy(dlb.Bi(a.d,h),c);if(e!=-1)break;}d=clb.zk(a.f,1,g);f=-1;i=0;for(;i<a.d.a.length;i++){f=glb.Cy(dlb.Bi(a.d,i),d);if(f!=-1)break;}if(h!=i){if(h>i){k=h;h=i;i=k;k=e;e=f;f=k;}j==null&&(j=gW(Ykb.NY,Llb,340,a.d.a.length,0,2));j[i]==null&&(j[i]=gW(Ykb.NY,{340:1,4:1,5:1,8:1},81,i,0,1));if(j[i][h])glb.hy(j[i][h],e,f);else {kW(j[i],h,new glb.ky(dlb.Bi(a.d,h),dlb.Bi(a.d,i),e,f));!b&&(b=new dlb.Qi());dlb.wi(b,j[i][h]);}}}}return b;};glb.lx=function lx(a){var b,c;b=Fmb-Fmb*(a.e.length-2)/a.e.length;for(c=1;c<a.e.length;c++){a.a[c]=a.a[c-1]+$wnd.Math.sin(b*(c-1));a.b[c]=a.b[c-1]+$wnd.Math.cos(b*(c-1));}};glb.mx=function mx(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o,p,q,r;if(b==0||(b&c)!=0){glb.lx(a);return;}q=-1;r=0;f=1<<a.e.length-2;e=1<<a.e.length-1;h=1;g=2;for(j=0;j<a.e.length;j++){if((c&(e|h))==0&&(b&(e|h))!=0&&(b&f)==0){o=0;(c&f)!=0&&(o+=4);(b&e)!=0&&(o+=2);(b&h)!=0&&(o+=1);if(r<o){r=o;q=j;}}f=e;e=h;h=g;g=1<<(j+2<a.e.length?j+2:j+2-a.e.length);}if(q==-1){glb.lx(a);return;}m=0;m|=1<<q;n=2;while(n<a.e.length-1){l=q+n<a.e.length?q+n:q+n-a.e.length;e=1<<(l==0?a.e.length-1:l-1);if((c&e)!=0){++n;continue;}h=1<<l;if((b&e)!=0){if((c&h)!=0){glb.lx(a);return;}m|=h;n+=2;continue;}g=1<<(l+1<a.e.length?l+1:l+1-a.e.length);if((b&h)!=0&&(c&g)!=0){m|=h;n+=3;continue;}++n;}if(m==0){glb.lx(a);return;}d=Fmb-Fmb*(a.e.length-2)/a.e.length;for(k=1;k<a.e.length;k++){a.a[k]=a.a[k-1]+$wnd.Math.sin(d*(k-1));a.b[k]=a.b[k-1]+$wnd.Math.cos(d*(k-1));}h=1;p=2*$wnd.Math.sin(d/2);for(i=0;i<a.e.length;i++){if((m&h)!=0){a.a[i]+=p*$wnd.Math.cos(d*(i-0.5));a.b[i]-=p*$wnd.Math.sin(d*(i-0.5));}h<<=1;}};glb.nx=function nx(a,b){var c;c=a-b;while(c<_nb)c+=Emb;while(c>Fmb)c-=Emb;return c;};glb.ox=function ox(a,b,c){var d,e;d=0;for(e=0;e<clb.gn(a.f,c);e++){glb.Ey(b,clb.vn(a.f,c,e))&&++d;}return d;};glb.px=function px(a,b,c,d){var e,f,g,h,i;h=glb.Cy(b,d);i=glb.Cy(c,d);glb.Iy(c,b.a[h]-c.a[i],b.b[h]-c.b[i]);e=glb.Ox(a,b,d);f=glb.Ox(a,c,d);g=0;glb.ox(a,b,d)==1&&glb.ox(a,c,d)==1&&(g=pnb);glb.Hy(c,c.a[i],c.b[i],e-f+g+Fmb);return glb.ux(a,b,c,1);};glb.qx=function qx(a,b,c,d,e){var f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G,H,I,J,K,L;t=gW(Ykb.AX,gmb,6,e,15,1);u=gW(Ykb.AX,gmb,6,e,15,1);for(p=0;p<e;p++){t[p]=glb.Cy(b,d[p]);u[p]=glb.Cy(c,d[p]);}F=0;H=0;G=0;I=0;for(q=0;q<e;q++){F+=b.a[t[q]];H+=b.b[t[q]];G+=c.a[u[q]];I+=c.b[u[q]];}F/=e;H/=e;G/=e;I/=e;glb.Iy(c,F-G,H-I);j=gW(Ykb.OY,Ulb,32,e,0,1);l=gW(Ykb.OY,Ulb,32,e,0,1);f=gW(Ykb.OY,Ulb,32,e,0,1);g=gW(Ykb.OY,Ulb,32,e,0,1);for(r=0;r<e;r++){j[r]=new glb.my(F,H,b.a[t[r]],b.b[t[r]]);l[r]=new glb.my(F,H,c.a[u[r]],c.b[u[r]]);f[r]=new glb.ly(j[r].a-l[r].a,j[r].b*l[r].b);g[r]=new glb.ly(j[r].a+l[r].a,j[r].b*l[r].b);}w=glb.Sx(f,e);A=glb.Sx(g,e);K=0;L=0;for(s=0;s<e;s++){for(v=0;v<clb.gn(a.f,d[s]);v++){h=clb.vn(a.f,d[s],v);glb.Ey(b,h)&&!glb.Ey(c,h)&&++K;!glb.Ey(b,h)&&glb.Ey(c,h)&&++L;}}k=gW(Ykb.OY,Ulb,32,K,0,1);m=gW(Ykb.OY,Ulb,32,L,0,1);n=gW(Ykb.OY,Ulb,32,L,0,1);K=0;L=0;for(o=0;o<e;o++){for(v=0;v<clb.gn(a.f,d[o]);v++){h=clb.vn(a.f,d[o],v);if(glb.Ey(b,h)&&!glb.Ey(c,h)){i=glb.Cy(b,h);k[K]=new glb.my(b.a[t[o]],b.b[t[o]],b.a[i],b.b[i]);++K;}if(!glb.Ey(b,h)&&glb.Ey(c,h)){i=glb.Cy(c,h);J=new glb.my(c.a[u[o]],c.b[u[o]],c.a[i],c.b[i]);m[L]=new glb.ly(w.a+J.a,J.b);n[L]=new glb.ly(A.a-J.a,J.b);++L;}}}B=glb.Sx(k,K);C=glb.Sx(m,L);D=glb.Sx(n,L);if($wnd.Math.abs(glb.nx(B.a,C.a))>$wnd.Math.abs(glb.nx(B.a,D.a))){glb.Hy(c,F,H,w.a);}else {glb.wy(c,F,H);glb.Hy(c,F,H,A.a);}return glb.ux(a,b,c,e);};glb.rx=function rx(a,b,c,d){var e,f,g,h,i,j;f=d==b.length-1?0:d+1;h=d==0?b.length-1:d-1;g=f==b.length-1?0:f+1;if(clb.Hk(a.f,c[d])==2){e=clb.Ik(a.f,c[d]);if(e==1||e==2){glb.zx(a,b[h],b[d],b[f])^glb.zx(a,b[g],b[f],b[d])&&(e=e==1?2:1);return e;}}if(clb.Co(a.f,c[d])){i=clb.or(clb.Xn(a.f),c[h],c[d]);j=clb.or(clb.Xn(a.f),c[f],c[d]);if(i!=-1||j!=-1)return i==j?2:1;return 2;}return 0;};glb.sx=function sx(a,b){var c,d,e,f,g,h,i,j,k,l,m,n;e=gW(Ykb.AX,gmb,6,a.f.q,15,1);f=gW(Ykb.AX,gmb,6,a.f.q,15,1);g=gW(Ykb.AX,gmb,6,a.f.q,15,1);h=gW(Ykb.AX,gmb,6,a.f.q,15,1);e[0]=b;g[b]=1;h[0]=-1;d=0;i=0;while(d<=i){if(d==0||!a.b[e[d]]){for(j=0;j<clb.gn(a.f,e[d]);j++){c=clb.vn(a.f,e[d],j);m=clb.xn(a.f,e[d],j);if(g[c]==0&&!a.c[m]){e[++i]=c;f[i]=m;g[c]=g[e[d]]+1;h[i]=d;}}}if(d==i){n=new glb.oy(g[e[d]]);k=d;for(l=0;l<n.a.length;l++){n.a[l]=e[k];n.b[l]=f[k];k=h[k];}return n;}++d;}return null;};glb.tx=function tx(a){var b,c,d,e;e=0;d=null;for(c=new dlb.Obb(a);c.a<c.c.a.length;){b=dlb.Nbb(c);if(e<b.b[0].e.length*b.b[1].e.length){e=b.b[0].e.length*b.b[1].e.length;d=b;}}return d;};glb.ux=function ux(a,b,c,d){var e,f,g,h,i;f=new glb.Jy(a.f,b.e.length+c.e.length-d,b.i|c.i);e=0;for(h=0;h<b.e.length;h++){f.e[e]=b.e[h];f.k[e]=b.k[h];f.a[e]=b.a[h];f.b[e++]=b.b[h];}for(g=0;g<c.e.length;g++){i=glb.Cy(b,c.e[g]);if(i==-1){f.e[e]=c.e[g];f.k[e]=c.k[g];f.a[e]=c.a[g];f.b[e++]=c.b[g];}else {if(f.k[i]<c.k[g]){f.k[i]=c.k[g];f.a[i]=c.a[g];f.b[i]=c.b[g];}}}return f;};glb.vx=function vx(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o;h=gW(Ykb.AX,gmb,6,a.f.q,15,1);i=gW(Ykb.AX,gmb,6,a.f.q,15,1);j=gW(Ykb.AX,gmb,6,a.f.q,15,1);k=gW(Ykb.AX,gmb,6,a.f.q,15,1);h[0]=c;j[c]=1;k[0]=-1;g=0;l=0;while(g<=l){for(m=0;m<clb.hn(a.f,h[g]);m++){e=clb.vn(a.f,h[g],m);o=clb.xn(a.f,h[g],m);if(e==b){f=j[h[g]];d=gW(Ykb.AX,gmb,6,f,15,1);d[0]=o;for(n=1;n<f;n++){d[n]=i[g];g=k[g];}return d;}if(j[e]==0){h[++l]=e;i[l]=o;j[e]=j[h[g]]+1;k[l]=g;}}if(g==l)return null;++g;}return null;};glb.wx=function wx(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o;c=clb.zk(a.f,0,b);d=clb.zk(a.f,1,b);g=gW(Ykb.AX,gmb,6,a.f.q,15,1);h=gW(Ykb.AX,gmb,6,a.f.q,15,1);i=gW(Ykb.AX,gmb,6,a.f.q,15,1);j=gW(Ykb.AX,gmb,6,a.f.q,15,1);g[0]=c;g[1]=d;h[1]=b;i[c]=1;i[d]=2;j[0]=-1;j[1]=0;f=1;k=1;while(f<=k){for(l=0;l<clb.wn(a.f,g[f]);l++){e=clb.vn(a.f,g[f],l);if(f>1&&e==c){o=new glb.oy(i[g[f]]);h[0]=clb.xn(a.f,g[f],l);m=f;for(n=0;n<o.a.length;n++){o.a[n]=g[m];o.b[n]=h[m];m=j[m];}return o;}if(i[e]==0&&clb.yo(a.f,e)){g[++k]=e;h[k]=clb.xn(a.f,g[f],l);i[e]=i[g[f]]+1;j[k]=f;}}++f;}return null;};glb.xx=function xx(a,b,c,d){var e,f,g,h,i,j;g=gW(Ykb.AX,gmb,6,a.f.q,15,1);h=gW(Ykb.AX,gmb,6,a.f.q,15,1);g[0]=c;g[1]=b;h[c]=1;h[b]=2;f=1;i=1;while(f<=i){for(j=0;j<clb.wn(a.f,g[f]);j++){e=clb.vn(a.f,g[f],j);if(e==d)return 1+h[g[f]];if(h[e]==0&&clb.yo(a.f,e)){g[++i]=e;h[e]=h[g[f]]+1;}}++f;}return 0;};glb.yx=function yx(a,b){var c,d,e,f,g,h,i;h=(b.T&15)!=0;i=b.T&248;!a.g&&(a.g=new dlb.Ydb());(a.e&2)!=0&&clb.Jo(b,false);a.f=b;clb.Gt(a.f,7);a.d=new glb.Vx();a.b=gW(Ykb.Z0,Amb,6,a.f.q,16,1);a.c=gW(Ykb.Z0,Amb,6,a.f.r,16,1);a.i=gW(Ykb.AX,gmb,6,a.f.q,15,1);for(c=0;c<a.f.q;c++)a.i[c]=clb.dk(a.f,c);(a.e&12)!=0&&glb.Jx(a);(a.e&1)==0&&!!glb.bx&&glb.Lx(a,glb.bx);glb.Ix(a);glb.Ex(a);glb.Gx(a);glb.Ex(a);for(e=new dlb.Obb(a.d);e.a<e.c.a.length;){d=dlb.Nbb(e);glb.Fy(d);}glb.gx(a);glb.Mx(a);glb.Kx(a);glb.Dx(a);glb.Bx(a);glb.Fx(a);for(f=0;f<a.d.a.length;f++){d=dlb.Bi(a.d,f);for(g=0;g<d.e.length;g++){clb.Yl(a.f,d.e[g],d.a[g]);clb.Zl(a.f,d.e[g],d.b[g]);clb.$l(a.f,d.e[g],0);}}if(h){clb.Mo(a.f,i);clb.Po(a.f);}a.a&&clb.xl(a.f);};glb.zx=function zx(a,b,c,d){var e,f;for(f=0;f<clb.wn(a.f,c);f++){e=clb.vn(a.f,c,f);if(e!=d&&e<b)return false;}return true;};glb.Ax=function Ax(a,b,c){var d;glb.iy(b,c,(a.e&12)!=0);d=glb.ux(a,b.b[0],b.b[1],0);glb.Px(a,b.b[0],b.b[1],d);};glb.Bx=function Bx(a){var b;b=glb.hx(a);while(b){glb.Ax(a,b,1.5);b=glb.hx(a);}};glb.Cx=function Cx(a,b,c,d){var e,f,g,h,i;e=gW(Ykb.AX,gmb,6,d,15,1);f=0;for(g=0;g<b.e.length;g++)for(h=0;h<c.e.length;h++)b.e[g]==c.e[h]&&(e[f++]=b.e[g]);i=d==1?glb.px(a,b,c,e[0]):glb.qx(a,b,c,e,d);glb.Px(a,b,c,i);};glb.Dx=function Dx(a){var b,c;c=glb.kx(a);while(c){b=glb.tx(c);glb.Ax(a,b,1.2);c=glb.kx(a);}};glb.Ex=function Ex(a){var b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s;while(true){s=0;n=0;q=null;r=null;for(g=1;g<a.d.a.length;g++){d=dlb.Bi(a.d,g);for(h=0;h<g;h++){e=dlb.Bi(a.d,h);b=0;c=0;o=0;p=0;for(k=0;k<d.e.length;k++){for(m=0;m<e.e.length;m++){if(d.e[k]==e.e[m]){++c;b=d.e[k];o<d.k[k]&&(o=d.k[k]);p<e.k[m]&&(p=e.k[m]);}}}if(c>0){f=c==1&&glb.ox(a,d,b)==1&&glb.ox(a,e,b)==1?0:1;o>p?i=(f<<24)+(o<<16)+(p<<8)+c:i=(f<<24)+(p<<16)+(o<<8)+c;if(s<i){s=i;n=c;o=0;p=0;for(l=0;l<d.e.length;l++)o<d.k[l]&&(o=d.k[l]);for(j=0;j<e.e.length;j++)p<e.k[j]&&(p=e.k[j]);if(o>p){q=d;r=e;}else {q=e;r=d;}}}}}if(s==0)break;n==q.e.length?dlb.Ji(a.d,q):n==r.e.length?dlb.Ji(a.d,r):glb.Cx(a,q,r,n);}};glb.Fx=function Fx(a){var b;b=glb.ix(a);while(b){glb.Ax(a,b,1.8);b=glb.ix(a);}};glb.Gx=function Gx(a){var b,c,d,e,f,g,h;while(true){f=null;for(b=0;b<a.f.q;b++){h=0;for(e=0;e<clb.gn(a.f,b);e++)a.c[clb.xn(a.f,b,e)]||++h;if(h==1){g=glb.sx(a,b);(!f||g.a.length>f.a.length)&&(f=g);}}if(!f)break;c=new glb.Jy(a.f,f.a.length,false);for(d=0;d<f.a.length;d++){a.b[f.a[d]]=true;d<f.a.length-1&&(a.c[f.b[d]]=true);c.e[d]=f.a[d];c.a[d]=$wnd.Math.cos(qnb)*d;c.b[d]=(d&1)==1?0:0.5;c.k[d]=128+f.a.length;}glb.Tx(a.d,c);}};glb.Hx=function Hx(a,b,c){var d,e,f,g,h,i,j,k,l,m;for(f=0;f<a.f.r;f++){d=clb.zk(a.f,0,f);e=clb.zk(a.f,1,f);if(clb.zo(a.f,f)||clb.Hk(a.f,f)!=1||clb.gn(a.f,d)==1||clb.gn(a.f,e)==1)continue;if((a.e&4)!=0&&clb.il(a.f,d)&&clb.il(a.f,e))continue;l=false;for(j=0;j<2;j++){g=clb.zk(a.f,j,f);if(clb.gn(a.f,g)>2){m=true;i=-1;for(k=0;k<clb.gn(a.f,g);k++){h=clb.vn(a.f,g,k);h!=clb.zk(a.f,1-j,f)&&(i==-1?i=c[h]:i!=c[h]&&(m=false));}if(m){l=true;break;}}}l||((a.e&8)!=0&&clb.il(a.f,d)&&clb.il(a.f,e)?b[f]=1:b[f]=2);}};glb.Ix=function Ix(a){var b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G,H,I,J,K,L,M;for(d=0;d<a.f.f;d++){if(clb.gn(a.f,d)>4){m=new glb.Jy(a.f,1+clb.gn(a.f,d),false);m.a[clb.gn(a.f,d)]=0;m.b[clb.gn(a.f,d)]=0;m.k[clb.gn(a.f,d)]=32;m.e[clb.gn(a.f,d)]=d;a.b[d]=true;for(o=0;o<clb.gn(a.f,d);o++){j=clb.vn(a.f,d,o);m.a[o]=$wnd.Math.sin(pnb*o-cpb);m.b[o]=$wnd.Math.cos(pnb*o-cpb);m.k[o]=32;m.e[o]=j;a.b[j]=true;a.c[clb.xn(a.f,d,o)]=true;}glb.Tx(a.d,m);}}I=clb.Xn(a.f);for(H=0;H<I.i.a.length;H++){J=dlb.Bi(I.j,H).length;F=dlb.Bi(I.i,H);K=false;if((a.e&12)!=0){K=true;for(o=0;o<J;o++){if(!clb.il(a.f,F[o])){K=false;break;}}}if(!K){r=false;for(p=0;p<J;p++){if(clb.qn(a.f,F[p])==J){r=true;break;}}if(r){G=dlb.Bi(I.j,H);glb.cx(a,F,G);for(o=0;o<J;o++){a.b[F[o]]=true;a.c[G[o]]=true;}}}}for(h=0;h<a.f.g;h++){if(clb.zo(a.f,h)&&!a.c[h]){M=glb.wx(a,h);F=M.a;G=M.b;glb.cx(a,F,G);for(o=0;o<M.a.length;o++){a.b[F[o]]=true;a.c[G[o]]=true;}}}for(i=0;i<a.f.r;i++){if(!a.c[i]&&clb.Hk(a.f,i)==3){e=clb.zk(a.f,0,i);f=clb.zk(a.f,1,i);w=clb.gn(a.f,e)+clb.gn(a.f,f);if(w>2){m=new glb.Jy(a.f,w,false);k=0;for(p=0;p<clb.gn(a.f,e);p++){j=clb.vn(a.f,e,p);if(j!=f){m.e[k++]=j;a.b[j]=true;a.c[clb.xn(a.f,e,p)]=true;}}m.e[k++]=e;m.e[k++]=f;for(q=0;q<clb.gn(a.f,f);q++){j=clb.vn(a.f,f,q);if(j!=e){m.e[k++]=j;a.b[j]=true;a.c[clb.xn(a.f,f,q)]=true;}}for(o=0;o<w;o++){m.a[o]=o;m.b[o]=0;m.k[o]=1;}a.b[e]=true;a.b[f]=true;a.c[i]=true;glb.Tx(a.d,m);}}}for(g=0;g<a.f.r;g++){if(!a.c[g]&&clb.Hk(a.f,g)==2){b=gW(Ykb.AX,gmb,6,a.f.q,15,1);for(o=0;o<2;o++){b[0]=clb.zk(a.f,o,g);b[1]=clb.zk(a.f,1-o,g);if(clb.mn(a.f,b[0])==1&&clb.mn(a.f,b[1])==2&&clb.gn(a.f,b[1])==2){a.b[b[0]]=true;a.b[b[1]]=true;a.c[g]=true;v=1;do{A=clb.vn(a.f,b[v],0)==b[v-1]?1:0;b[v+1]=clb.vn(a.f,b[v],A);if(clb.mn(a.f,b[v+1])==2&&clb.gn(a.f,b[v+1])>2)break;a.b[b[v+1]]=true;a.c[clb.xn(a.f,b[v],A)]=true;++v;}while(clb.mn(a.f,b[v])==2&&clb.gn(a.f,b[v])==2);w=clb.gn(a.f,b[0])+clb.gn(a.f,b[v])+v-1;m=new glb.Jy(a.f,w,false);for(t=0;t<=v;t++){m.a[t]=t;m.b[t]=0;m.k[t]=64;m.e[t]=b[t];}l=v+1;n=false;for(u=0;u<clb.gn(a.f,b[0]);u++){j=clb.vn(a.f,b[0],u);if(j!=b[1]){m.a[l]=-0.5;m.b[l]=n?$wnd.Math.sin(pnb):-$wnd.Math.sin(pnb);m.k[l]=64;m.e[l]=j;++l;n=true;}}n=false;for(s=0;s<clb.gn(a.f,b[v]);s++){j=clb.vn(a.f,b[v],s);if(j!=b[v-1]){m.a[l]=v+0.5;m.b[l]=n?-$wnd.Math.sin(pnb):$wnd.Math.sin(pnb);m.k[l]=64;m.e[l]=j;++l;n=true;}}glb.Tx(a.d,m);}}}}for(c=0;c<a.f.q;c++){if(clb.gn(a.f,c)==4){B=gW(Ykb.AX,gmb,6,4,15,1);C=gW(Ykb.AX,gmb,6,4,15,1);D=0;for(p=0;p<4;p++){B[D]=clb.vn(a.f,c,p);C[D]=clb.xn(a.f,c,p);clb.gn(a.f,B[D])==1&&!a.c[C[D]]&&++D;}if(D==2){m=new glb.Jy(a.f,3,false);for(o=0;o<2;o++){a.b[B[o]]=true;a.c[C[o]]=true;m.e[o]=B[o];m.k[o]=32;}m.a[0]=-0.5;m.b[0]=0.866;m.a[1]=0.5;m.b[1]=0.866;m.a[2]=0;m.b[2]=0;m.k[2]=32;m.e[2]=c;glb.Tx(a.d,m);}if(D==3){for(q=0;q<2;q++){if(clb.Hk(a.f,C[q])==1){L=B[q];B[q]=B[2];B[2]=L;L=C[q];C[q]=C[2];C[2]=L;}}m=new glb.Jy(a.f,4,false);for(o=0;o<3;o++){a.b[B[o]]=true;a.c[C[o]]=true;m.e[o]=B[o];m.k[o]=32;}m.a[0]=-1;m.b[0]=0;m.a[1]=1;m.b[1]=0;m.a[2]=0;m.b[2]=1;m.a[3]=0;m.b[3]=0;m.k[3]=32;m.e[3]=c;glb.Tx(a.d,m);}}}};glb.Jx=function Jx(a){var b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v;h=0;for(c=0;c<a.f.q;c++)clb.il(a.f,c)&&++h;if(h<2)return;l=0;j=0;for(k=0;k<a.f.r;k++){d=clb.zk(a.f,0,k);e=clb.zk(a.f,1,k);if(clb.il(a.f,d)&&clb.il(a.f,e)){a.c[k]=true;a.b[d]=true;a.b[e]=true;j+=clb.Fk(a.f,k);++l;}}l!=0&&j!=0?j/=l:j=clb.vk(a.f);for(f=0;f<a.f.q;f++)clb.il(a.f,f)&&!a.b[f]&&--h;if(h<2)return;t=gW(Ykb.AX,gmb,6,a.f.q,15,1);m=clb.En(a.f,t,true,true);s=gW(Ykb.AX,gmb,6,m,15,1);for(g=0;g<a.f.q;g++)t[g]!=-1&&++s[t[g]];r=gW(Ykb.SY,Ulb,40,m,0,1);for(o=0;o<m;o++)r[o]=new glb.Jy(a.f,s[o],true);i=gW(Ykb.AX,gmb,6,m,15,1);for(b=0;b<a.f.q;b++){p=t[b];if(p!=-1){r[p].k[i[p]]=Nmb;r[p].e[i[p]]=b;r[p].a[i[p]]=clb.rk(a.f,b)/j;r[p].b[i[p]]=clb.sk(a.f,b)/j;++i[p];}}u=-1;v=0;for(q=0;q<m;q++){if(v<s[q]){v=s[q];u=q;}}glb.Tx(a.d,r[u]);for(n=0;n<m;n++)n!=u&&glb.Tx(a.d,r[n]);};glb.Kx=function Kx(a){var b,c;for(b=0;b<a.f.q;b++){if(!a.b[b]&&clb.gn(a.f,b)==0){c=new glb.Jy(a.f,1,false);a.b[b]=true;c.e[0]=b;c.a[0]=0;c.b[0]=0;c.k[0]=0;glb.Tx(a.d,c);}}};glb.Lx=function Lx(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s;o=null;o=new clb.js();clb.ds(o,a.f);g=gW(Ykb.Z0,Amb,6,a.f.f,16,1);for(q=b.rb();q.ec();){p=q.fc();n=null;s=p.b;clb.bs(o,s);clb.Rr(o,4,8)!=0&&(n=o.D);if(n){for(m=new dlb.Obb(n);m.a<m.c.a.length;){l=dlb.Nbb(m);r=0;for(d=l,e=0,f=d.length;e<f;++e){c=d[e];g[c]&&++r;}if(r<=1){i=p.c;a.a?i=false:a.a=true;j=new glb.Jy(a.f,l.length,i);for(k=0;k<l.length;k++){c=l[k];i&&clb.Rl(a.f,c,true);j.k[k]=256;j.e[k]=c;j.a[k]=clb.rk(p.b,k)/p.a;j.b[k]=clb.sk(p.b,k)/p.a;g[c]=true;a.b[c]=true;}for(h=0;h<s.g;h++)a.c[clb.tn(a.f,l[s.D[0][h]],l[s.D[1][h]])]=true;glb.Tx(a.d,j);}}}}return g;};glb.Mx=function Mx(a){var b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u;b=glb.ex(a);f=gW(Ykb.wX,Fnb,6,a.f.r,15,1);glb.Hx(a,f,b);for(e=0;e<a.f.r;e++)f[e]==2&&(clb.yo(a.f,clb.zk(a.f,0,e))||clb.yo(a.f,clb.zk(a.f,1,e)))&&(f[e]=3);for(n=0;n<a.d.a.length;n++){l=dlb.Bi(a.d,n);i=glb.Ay(l);r=l.c;q=new glb.Ky(l);p=-1;for(m=0;m<224&&i.a.length!=0;m++){j=dlb.Vdb(a.g,i.a.length);h=(alb.Dgb(j,i.a.length),i.a[j]);g=glb.vx(a,h[0],h[1]);c=gW(Ykb.AX,gmb,6,g.length,15,1);d=0;if(m<32){for(o=1;o<g.length-1;o++)f[g[o]]==3&&(c[d++]=g[o]);}else if(m<96){for(o=1;o<g.length-1;o++)f[g[o]]>=2&&(c[d++]=g[o]);}else {for(o=1;o<g.length-1;o++)f[g[o]]>=1&&(c[d++]=g[o]);}if(d!=0){t=c[0];if(d>1){do{t=c[dlb.Vdb(a.g,d)];}while(t==p);}if(t!=p){p=t;glb.xy(l,t);i=glb.Ay(l);if(r>l.c){r=l.c;q=new glb.Ky(l);}}}}dlb.Li(a.d,n,q);l=q;k=1;do{s=9999;for(o=0;o<l.e.length;o++){u=b[l.e[o]];u==k?glb.Gy(l,o):u>k&&u<s&&(s=u);}k=s;}while(s!=9999);}};glb.Nx=function Nx(a,b){a.g=new dlb.Zdb(b);};glb.Ox=function Ox(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t;e=gW(Ykb.yX,emb,6,clb.gn(a.f,c)+1,15,1);g=gW(Ykb.AX,gmb,6,clb.gn(a.f,c)+1,15,1);h=gW(Ykb.AX,gmb,6,clb.gn(a.f,c)+1,15,1);q=glb.Cy(b,c);f=0;for(j=0;j<clb.gn(a.f,c);j++){g[f]=clb.vn(a.f,c,j);h[f]=clb.xn(a.f,c,j);l=glb.Cy(b,g[f]);l!=-1&&(e[f++]=glb.ny(b.a[q],b.b[q],b.a[l],b.b[l]));}if(f==1)return e[0]+Fmb;for(k=f-1;k>0;k--){for(m=0;m<k;m++){if(e[m]>e[m+1]){r=e[m];e[m]=e[m+1];e[m+1]=r;s=g[m];g[m]=g[m+1];g[m+1]=s;t=h[m];h[m]=h[m+1];h[m+1]=t;}}}e[f]=e[0]+Emb;g[f]=g[0];h[f]=h[0];n=-100;o=0;for(i=0;i<f;i++){d=e[i+1]-e[i];if(f>2&&clb.zo(a.f,h[i])&&clb.zo(a.f,h[i+1])){p=glb.xx(a,g[i],c,g[i+1]);p!=0&&(d-=100-p);}if(n<d){n=d;o=i;}}return (e[o]+e[o+1])/2;};glb.Px=function Px(a,b,c,d){var e;e=$wnd.Math.min(dlb.Di(a.d,b,0),dlb.Di(a.d,c,0));dlb.vi(a.d,e,d);dlb.Ji(a.d,b);dlb.Ji(a.d,c);};glb.Qx=function Qx(){glb.Rx.call(this,2);};glb.Rx=function Rx(a){this.e=a;(a&1)==0&&!glb.bx&&!glb.bx&&(glb.bx=new glb.sy());};glb.Sx=function Sx(a,b){var c,d,e,f,g;g=0;c=0;for(d=0;d<b;d++){g+=a[d].b*$wnd.Math.sin(a[d].a);c+=a[d].b*$wnd.Math.cos(a[d].a);}if(c==0)f=g>0?Gmb:mnb;else {f=$wnd.Math.atan(g/c);c<0&&(f+=Fmb);}e=$wnd.Math.sqrt(g*g+c*c)/b;return new glb.ly(f,e);};U1(74,1,{},glb.Qx,glb.Rx);_.a=false;_.e=0;Ykb.MY=w3(74);glb.Tx=function Tx(a,b){var c,d;for(d=new dlb.Obb(a);d.a<d.c.a.length;){c=dlb.Nbb(d);if(glb.vy(c,b))return false;}return alb.ggb(a.a,b),true;};glb.Ux=function Ux(a,b){return glb.Tx(a,b);};glb.Vx=function Vx(){dlb.Qi.call(this);};U1(240,18,Pnb,glb.Vx);_.add=function Wx(a){return glb.Ux(this,a);};Ykb.IY=w3(240);glb.Xx=function Xx(a,b){var c,d;c=$wnd.Math.abs(a.b);d=$wnd.Math.abs(b.b);return c<d?-1:c==d?0:1;};glb.Yx=function Yx(){};U1(241,1,{},glb.Yx);_.pb=function Zx(a,b){return glb.Xx(a,b);};_.ib=function $x(a){return this===a;};Ykb.JY=w3(241);glb._x=function _x(a){var b,c;b=a.c.e.length;c=a.c.e.length;return b<c?1:b==c?0:-1;};glb.ay=function ay(){};U1(242,1,{},glb.ay);_.pb=function by(a,b){var c;return glb._x((c=a,c));};_.ib=function cy(a){return this===a;};Ykb.KY=w3(242);glb.dy=function dy(a){var b,c;b=a.c.e.length;c=a.c.e.length;return b<c?-1:b==c?0:1;};glb.ey=function ey(){};U1(243,1,{},glb.ey);_.pb=function fy(a,b){var c;return glb.dy((c=a,c));};_.ib=function gy(a){return this===a;};Ykb.LY=w3(243);glb.hy=function hy(a,b,c){a.c[0]+=glb.yy(a.b[0],b);a.d[0]+=glb.zy(a.b[0],b);a.c[1]+=glb.yy(a.b[1],c);a.d[1]+=glb.zy(a.b[1],c);++a.a[0];++a.a[1];};glb.iy=function iy(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w;d=gW(Ykb.yX,emb,6,2,15,1);for(j=0;j<2;j++){a.c[j]/=a.a[j];a.d[j]/=a.a[j];d[j]=glb.ty(a.b[j],a.c[j],a.d[j],a.b[1-j].e.length,b);}glb.Hy(a.b[0],a.c[0],a.d[0],Gmb-d[0]);glb.Hy(a.b[1],a.c[1],a.d[1],4.71238898038469-d[1]);w=Unb;v=-1.7976931348623157E308;g=a.d[0]-a.d[1];for(k=0;k<a.b[1].b.length;k++){a.b[1].b[k]+=g;w>a.b[1].b[k]&&(w=a.b[1].b[k]);v<a.b[1].b[k]&&(v=a.b[1].b[k]);}t=v-w+2*b;e=vX($wnd.Math.ceil(t));w+=(t-e)/2-b;r=gW(Ykb.yX,emb,6,e,15,1);for(l=0;l<e;l++)r[l]=a.c[1]+b;for(m=0;m<a.b[1].b.length;m++){u=a.b[1].b[m]-w;s=vX(u-b);h=$wnd.Math.min(vX(u+b),e-1);for(q=s;q<=h;q++){r[q]>a.b[1].a[m]&&(r[q]=a.b[1].a[m]);}}for(n=0;n<e;n++)r[n]-=b;f=a.c[0]-a.c[1];for(o=0;o<a.b[0].a.length;o++){p=vX(a.b[0].b[o]-w);p>=0&&p<r.length&&f<a.b[0].a[o]-r[p]&&(f=a.b[0].a[o]-r[p]);}for(i=0;i<a.b[1].a.length;i++)a.b[1].a[i]+=f;if(c){glb.Hy(a.b[0],a.c[0],a.d[0],d[0]-Gmb);glb.Hy(a.b[1],a.c[0],a.d[0],d[0]-Gmb);}};glb.jy=function jy(a,b){var c,d;this.b=gW(Ykb.SY,Ulb,40,2,0,1);this.b[0]=a;this.b[1]=b;this.c=gW(Ykb.yX,emb,6,2,15,1);this.d=gW(Ykb.yX,emb,6,2,15,1);this.a=gW(Ykb.AX,gmb,6,2,15,1);for(c=0;c<2;c++){for(d=0;d<this.b[c].e.length;d++){this.c[c]+=glb.yy(this.b[c],d);this.d[c]+=glb.zy(this.b[c],d);}this.a[c]=this.b[c].e.length;}};glb.ky=function ky(a,b,c,d){this.b=gW(Ykb.SY,Ulb,40,2,0,1);this.b[0]=a;this.b[1]=b;this.c=gW(Ykb.yX,emb,6,2,15,1);this.d=gW(Ykb.yX,emb,6,2,15,1);this.c[0]=glb.yy(this.b[0],c);this.d[0]=glb.zy(this.b[0],c);this.c[1]=glb.yy(this.b[1],d);this.d[1]=glb.zy(this.b[1],d);this.a=gW(Ykb.AX,gmb,6,2,15,1);this.a[0]=1;this.a[1]=1;};U1(81,1,{81:1},glb.jy,glb.ky);Ykb.NY=w3(81);glb.ly=function ly(a,b){this.a=a;this.b=b;};glb.my=function my(a,b,c,d){var e,f;this.a=glb.ny(a,b,c,d);e=c-a;f=d-b;this.b=$wnd.Math.sqrt(e*e+f*f);};glb.ny=function ny(a,b,c,d){var e,f,g;f=c-a;g=d-b;if(g!=0){e=$wnd.Math.atan(f/g);g<0&&(f<0?e-=Fmb:e+=Fmb);}else e=f>0?Gmb:mnb;return e;};U1(32,1,{32:1},glb.ly,glb.my);_.a=0;_.b=0;Ykb.OY=w3(32);glb.oy=function oy(a){this.a=gW(Ykb.AX,gmb,6,a,15,1);this.b=gW(Ykb.AX,gmb,6,a,15,1);};U1(194,1,{},glb.oy);Ykb.PY=w3(194);glb.py=function py(a,b,c){this.c=a;this.a=b;this.b=c;};U1(152,1,{152:1},glb.py);_.a=0;_.b=0;Ykb.QY=w3(152);glb.ry=function ry(){glb.ry=W1;glb.qy=oW(aW(Ykb.l_,1),Xlb,2,6,['gkvt@@@@LddTTTrbTRTRTRRRRRRRRRRRRRrVRrIh\\IAaQxlY@gRHdJCJcRXlv_CfJx|A\\hRHejiLaQjTje^kSjtFcIhvXmVKMjt{lN{Kavy\\^wGjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjh@@vo@HBC@PhLN@bPhtFKCcpDbILaRhtzCIbsX\\nOO`JDbqDjSKdJeJmQjtz}Ahr[LVkMnpz\\nwGj{PBhBdBlBBBjBfBnBaBiBeBmBcBkBgBoB`bhbdblbbbjbfbnbabibebmbcbkbgbob`RhRdRlRbRjRfRnRaRiReRmRcRkRgRoR`rhrdrlrbrjrfrnrarirermrcrkrgror`JhJdJlJbJjJfJnJaJiJeJmJcJkJgJoJ`jhjdjljbjjjfjnjajijej` !BnkjyVwsVr|iQn|Q|goTZWPIJwbudnRkVYBez]siZymNJZUqNFBqZWxS~iCXVU]SeRjwrtSPAjkvXLpBAZauDPzq]PfMlecrMnkv|@\\SFD`m|mWiEoCXp`SIe_J[l|[XCbloTV`[Gc@FJGopyyoOlFQfUy^w\\Bgz|','gcrt@@@@LdbbbbTRbRbRbRRRRRRRRRRRRVRrVQIA`HtRGAaIxZAHfShTjCIbqylQGKgqdBaXeQJeruBiPitZmFoPZLFSYbvZlVGMnsZ]vWSmr{]UUUUUUUUUUUUUUUUUUUUUUUUUUUUUT@@[G`DAA`HTFG@QHTZCEaqxBQDfPiTZ]AdqYlNWGgpEBQXbUIerEReVhuZ]^`tYMfKUfwX]NW[jkPBhBdBlBbBjBfBnBaBiBeBmBcBkBgBoB`bhbdblbbbjbfbnbabibebmbcbkbgbob`RhRdRlRbRjRfRnRaRiReRmRcRkRgRoR`rhrdrlrbrjrfrnrarirermrcrkrgror`JhJdJlJbJjJfJnJaJiJeJmJcJkJgJoJ`jhjdjljbjjjfjnjajij` !B^cR]`]Fm]QkfljE\\p\x7FUVfgOmFXsQe_gXPyXis_wF|vUUX_XbxpzU]HUFgYViwFo~@uemc@}~T\x7FIEPioYVwr]JnM~[ZEC\\g}~o_pUfdo~irsklTLiyVJshnw^iVAsZ`_~}PYkckURH{FYMImFaRaccUlCZSHMfP','dml@@Dje^VGiyZjjjh@vtHSBinFU@ !BPTCTy[skMzUPF`AJbBixEZHS[Il','dml@@DjYVvGiyZjjjh@vtHSBinFU@ !BwLo~BJ~UquhXBinZ\\ykA@F_eMrT','dml@@LdfbbQX^fUZjjj`C[PaLJfxYT !BzxIHVc{OiJVRpprePho~]}y\x7FwLl','deL@@DjUYkfEijjjj@MeBDpj[ad !B\x7FaA\x7FMVr[AvkKzm_jKvVbD{sk','dil@@LddTQRl[NX^Fjjjj@MiBDpj[a@ !BPfL@\x7Fox@M~T@\x7Fox@\x7F`C~@@','daL@@DjYtKJqjynjjjj@MaBDpj[` !B`bL@_gx@@Gy~@Gx@_`@']);};glb.sy=function sy(){glb.ry();var a,b,c,d,e,f,g;dlb.Qi.call(this);f=new clb.zs();for(c=glb.qy,d=0,e=c.length;d<e;++d){b=c[d];a=clb.bp(new clb.ip(),b);clb.ss(f,a);g=new glb.Ly(a);g.a=clb.vk(g.b);alb.ggb(this.a,g);}};U1(267,18,Pnb,glb.sy);Ykb.RY=w3(267);glb.ty=function ty(a,b,c,d,e){var f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G;if(a.e.length==1)return 0;C=e+$wnd.Math.sqrt(d);k=gW(Ykb.yX,emb,6,36,15,1);for(o=0;o<a.e.length;o++){f=glb.ny(b,c,a.a[o],a.b[o]);h=glb.uy(I1(p1($wnd.Math.round(f*36/Emb))));l=b-a.a[o];m=c-a.b[o];F=l*l+m*m;k[h]<F&&(k[h]=F);}v=-1;u=-1;for(p=0;p<36;p++){k[p]=$wnd.Math.sqrt(k[p]);if(v<k[p]){v=k[p];u=p;}}D=u-18<0?u-18+36:u-18>=36?u-18-36:u-18;for(q=0;q<=18;q++){k[D+q<0?D+q+36:D+q>=36?D+q-36:D+q]+=0.01*q;k[D-q<0?D-q+36:D-q>=36?D-q-36:D-q]+=0.01*q;}G=gW(Ykb.yX,emb,6,9,15,1);i=gW(Ykb.yX,emb,6,9,15,1);for(r=1;r<9;r++){G[r]=$wnd.Math.sin(r*iqb);i[r]=$wnd.Math.cos(r*iqb);}A=Unb;w=-1;for(g=0;g<36;g++){if(k[g]>=A)continue;t=k[g];for(n=1;n<9;n++){for(s=-1;s<=1;s+=2){B=g+s*n<0?g+s*n+36:g+s*n>=36?g+s*n-36:g+s*n;if(k[B]*i[n]<=t)continue;j=i[n]*$wnd.Math.min(k[B],C/G[n]);if(t<j){t=j;if(A<=t)break;}}if(A<=t)break;}if(A>t){A=t;w=g;}}return Emb*w/36;};glb.uy=function uy(a){return a<0?a+36:a>=36?a-36:a;};glb.vy=function vy(a,b){var c,d,e;if(b.e.length!=a.e.length)return false;d=glb.Dy(a);e=glb.Dy(b);for(c=0;c<d.length;c++)if(d[c]!=e[c])return false;return true;};glb.wy=function wy(a,b,c){var d,e,f;for(f=0;f<a.e.length;f++){e=$wnd.Math.sqrt((a.a[f]-b)*(a.a[f]-b)+(a.b[f]-c)*(a.b[f]-c));d=0-glb.ny(b,c,a.a[f],a.b[f]);a.a[f]=b+e*$wnd.Math.sin(d);a.b[f]=c+e*$wnd.Math.cos(d);}};glb.xy=function xy(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w;a.d==null&&(a.d=gW(Ykb.AX,Dnb,7,a.j.r,0,2));if(a.d[b]==null){n=gW(Ykb.AX,gmb,6,a.e.length,15,1);t=gW(Ykb.Z0,Amb,6,a.j.q,16,1);e=clb.zk(a.j,0,b);f=clb.zk(a.j,1,b);n[0]=e;t[e]=true;k=0;o=0;while(k<=o){for(q=0;q<clb.gn(a.j,n[k]);q++){g=clb.vn(a.j,n[k],q);if(!t[g]&&g!=f){n[++o]=g;t[g]=true;}}if(k==o)break;++k;}m=o+1>(a.e.length/2|0);if(a.i){i=false;h=false;for(q=0;q<a.e.length;q++){d=a.e[q];clb.il(a.j,d)&&d!=e&&d!=f&&(t[a.e[q]]?i=true:h=true);}i!=h&&(m=i);}j=2;a.d[b]=gW(Ykb.AX,gmb,6,m?a.e.length-o:o+2,15,1);for(r=0;r<a.e.length;r++){a.e[r]==e?a.d[b][m?0:1]=r:a.e[r]==f?a.d[b][m?1:0]=r:m^t[a.e[r]]&&(a.d[b][j++]=r);}}v=a.a[a.d[b][0]];w=a.b[a.d[b][0]];u=glb.ny(v,w,a.a[a.d[b][1]],a.b[a.d[b][1]]);for(p=2;p<a.d[b].length;p++){s=a.d[b][p];l=$wnd.Math.sqrt((a.a[s]-v)*(a.a[s]-v)+(a.b[s]-w)*(a.b[s]-w));c=2*u-glb.ny(v,w,a.a[s],a.b[s]);a.a[s]=v+l*$wnd.Math.sin(c);a.b[s]=w+l*$wnd.Math.cos(c);}};glb.yy=function yy(a,b){return a.a[b];};glb.zy=function zy(a,b){return a.b[b];};glb.Ay=function Ay(a){var b,c,d,e,f,g,h,i;a.c=0;c=new dlb.Qi();for(e=1;e<a.e.length;e++){for(f=0;f<e;f++){h=$wnd.Math.abs(a.a[e]-a.a[f]);i=$wnd.Math.abs(a.b[e]-a.b[f]);d=$wnd.Math.sqrt(h*h+i*i);if(d<0.8){b=gW(Ykb.AX,gmb,6,2,15,1);b[0]=a.e[e];b[1]=a.e[f];alb.ggb(c.a,b);}g=1-$wnd.Math.min(d,1);a.c+=g*g;}}return c;};glb.By=function By(a,b){return a.e[b];};glb.Cy=function Cy(a,b){var c;for(c=0;c<a.e.length;c++)if(b==a.e[c])return c;return -1;};glb.Dy=function Dy(a){if(a.n==null){a.n=dlb.Ubb(a.e,a.e.length);alb.jgb(a.n,alb.Pgb(X1(dlb.ucb.prototype.kc,dlb.ucb,[])));}return a.n;};glb.Ey=function Ey(a,b){var c;for(c=0;c<a.e.length;c++)if(b==a.e[c])return true;return false;};glb.Fy=function Fy(a){var b,c,d,e,f,g;d=0;for(f=0;f<a.e.length;f++){b=a.e[f];c=clb.gn(a.j,b);for(g=0;g<c;g++)clb.vn(a.j,b,g)>b&&++d;}a.f=gW(Ykb.AX,gmb,6,d,15,1);a.g=gW(Ykb.AX,gmb,6,a.j.q,15,1);d=0;for(e=0;e<a.e.length;e++){b=a.e[e];c=clb.gn(a.j,b);a.g[b]=e;for(g=0;g<c;g++)clb.vn(a.j,b,g)>b&&(a.f[d++]=clb.xn(a.j,b,g));}};glb.Gy=function Gy(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v;o=a.a[b];s=a.b[b];f=gW(Ykb.OY,Ulb,32,4,0,1);k=0;for(l=0;l<a.f.length;l++){if(k>=4)break;if(b==a.g[clb.zk(a.j,0,a.f[l])]||b==a.g[clb.zk(a.j,1,a.f[l])])continue;p=a.a[a.g[clb.zk(a.j,0,a.f[l])]];t=a.b[a.g[clb.zk(a.j,0,a.f[l])]];q=a.a[a.g[clb.zk(a.j,1,a.f[l])]];u=a.b[a.g[clb.zk(a.j,1,a.f[l])]];h=$wnd.Math.sqrt((p-o)*(p-o)+(t-s)*(t-s));i=$wnd.Math.sqrt((q-o)*(q-o)+(u-s)*(u-s));e=$wnd.Math.sqrt((q-p)*(q-p)+(u-t)*(u-t));if(h<e&&i<e){if(p==q){g=$wnd.Math.abs(o-p);g<0.5&&(f[k++]=new glb.ly(glb.ny(p,s,o,s),(0.5-g)/2));}else if(t==u){g=$wnd.Math.abs(s-t);g<0.5&&(f[k++]=new glb.ly(glb.ny(o,t,o,s),(0.5-g)/2));}else {m=(u-t)/(q-p);n=-1/m;c=t-m*p;d=s-n*o;r=(d-c)/(m-n);v=m*r+c;g=$wnd.Math.sqrt((r-o)*(r-o)+(v-s)*(v-s));g<0.5&&(f[k++]=new glb.ly(glb.ny(r,v,o,s),(0.5-g)/2));}continue;}if(h<0.5){f[k++]=new glb.ly(glb.ny(p,t,o,s),(0.5-h)/2);continue;}if(i<0.5){f[k++]=new glb.ly(glb.ny(q,u,o,s),(0.5-i)/2);continue;}}if(k>0){j=glb.Sx(f,k);a.a[b]+=j.b*$wnd.Math.sin(j.a);a.b[b]+=j.b*$wnd.Math.cos(j.a);}};glb.Hy=function Hy(a,b,c,d){var e,f,g;for(g=0;g<a.e.length;g++){f=$wnd.Math.sqrt((a.a[g]-b)*(a.a[g]-b)+(a.b[g]-c)*(a.b[g]-c));e=glb.ny(b,c,a.a[g],a.b[g])+d;a.a[g]=b+f*$wnd.Math.sin(e);a.b[g]=c+f*$wnd.Math.cos(e);}};glb.Iy=function Iy(a,b,c){var d;for(d=0;d<a.e.length;d++){a.a[d]+=b;a.b[d]+=c;}};glb.Jy=function Jy(a,b,c){this.j=a;this.i=c;this.e=gW(Ykb.AX,gmb,6,b,15,1);this.k=gW(Ykb.AX,gmb,6,b,15,1);this.a=gW(Ykb.yX,emb,6,b,15,1);this.b=gW(Ykb.yX,emb,6,b,15,1);};glb.Ky=function Ky(a){var b,c;this.j=a.j;this.i=a.i;this.e=gW(Ykb.AX,gmb,6,a.e.length,15,1);this.k=gW(Ykb.AX,gmb,6,a.e.length,15,1);this.a=gW(Ykb.yX,emb,6,a.e.length,15,1);this.b=gW(Ykb.yX,emb,6,a.e.length,15,1);for(c=0;c<a.e.length;c++){this.e[c]=a.e[c];this.k[c]=a.k[c];this.a[c]=a.a[c];this.b[c]=a.b[c];}if(a.f!=null){this.f=gW(Ykb.AX,gmb,6,a.f.length,15,1);for(b=0;b<a.f.length;b++)this.f[b]=a.f[b];}if(a.g!=null){this.g=gW(Ykb.AX,gmb,6,a.g.length,15,1);for(b=0;b<a.g.length;b++)this.g[b]=a.g[b];}};U1(40,1,{40:1},glb.Jy,glb.Ky);_.c=0;_.i=false;Ykb.SY=w3(40);glb.Ly=function Ly(a){this.b=a;this.c=false;};U1(193,1,{193:1},glb.Ly);_.a=0;_.c=false;Ykb.TY=w3(193);hlb.My=function My(a){a.c=new dlb.Qi();};hlb.Ny=function Ny(a,b,c,d,e,f){var g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F;t=-1;A=0;w=0;C=0;q=0;r=0;s=0;D=0;F=0;A=0;for(k=0;k<a.d;k++)A+=d[k]*d[k];A=$wnd.Math.sqrt(A);if(A>f)for(l=0;l<a.d;l++)d[l]*=f/A;w=0;for(m=0;m<a.d;m++)w+=d[m]*a.e[m];if(w>=0)return t;C=0;for(n=0;n<a.d;n++){B=$wnd.Math.abs(d[n])/$wnd.Math.max($wnd.Math.abs(b[n]),1);B>C&&(C=B);}s=1.0E-7/C;q=1;p=0;while(p<1000){if(q<s){t=1;break;}for(o=0;o<a.d;o++)e[o]=b[o]+q*d[o];a.k=ilb.Mz(a,e);if(a.k-c<=jqb*q*w)return 0;if(p==0)D=-w/(2*(a.k-c-w));else {u=a.k-c-q*w;v=F-c-r*w;g=(u/(q*q)-v/(r*r))/(q-r);h=(-r*u/(q*q)+q*v/(r*r))/(q-r);if(g==0)D=-w/(2*h);else {i=h*h-3*g*w;i<0?D=0.5*q:h<=0?D=(-h+$wnd.Math.sqrt(i))/(3*g):D=-w/(h+$wnd.Math.sqrt(i));}D>0.5*q&&(D=0.5*q);}r=q;F=a.k;q=$wnd.Math.max(D,0.1*q);++p;}for(j=0;j<a.d;j++)e[j]=b[j];return t;};hlb.Oy=function Oy(a,b,c){var d,e,f,g;g=1;for(e=0;e<a.g.q;e++){a.i[3*e]=clb.rk(a.g,e);a.i[3*e+1]=clb.sk(a.g,e);a.i[3*e+2]=clb.tk(a.g,e);}g=hlb.Py(a,b,c);if(g==0){for(d=0;d<a.g.q;d++){clb.Yl(a.g,d,a.i[3*d]);clb.Zl(a.g,d,a.i[3*d+1]);clb.$l(a.g,d,a.i[3*d+2]);}}for(f=new dlb.Obb(a.c);f.a<f.c.a.length;){dlb.Nbb(f);null.vc();}return g;};hlb.Py=function Py(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G,H,I,J,K,L,M,N,O;a.e=gW(Ykb.yX,emb,6,a.d,15,1);d=gW(Ykb.yX,emb,6,a.d,15,1);j=gW(Ykb.yX,emb,6,a.d,15,1);B=gW(Ykb.yX,emb,6,a.d,15,1);O=gW(Ykb.yX,emb,6,a.d,15,1);s=gW(Ykb.yX,emb,6,a.d*a.d,15,1);for(l=0;l<a.d;l++)B[l]=a.i[l];h=ilb.Mz(a,a.i);ilb.Nz(a);D=0;for(m=0;m<a.d;m++){s[m*a.d+m]=1;O[m]=-a.e[m];D+=a.i[m]*a.i[m];}A=100*$wnd.Math.max($wnd.Math.sqrt(D),a.d);H=(Zkb.O5(),p1(Date.now()));for(u=1;u<=b&&!a.f;u++){C=hlb.Ny(a,a.i,h,O,B,A);if(C<0)return 2;h=a.k;L=0;for(n=0;n<a.d;n++){O[n]=B[n]-a.i[n];a.i[n]=B[n];J=$wnd.Math.abs(O[n])/$wnd.Math.max($wnd.Math.abs(a.i[n]),1);J>L&&(L=J);d[n]=a.e[n];}if(L<1.2E-7){return 0;}i=ilb.Nz(a);L=0;K=$wnd.Math.max(a.k*i,1);for(o=0;o<a.d;o++){N=$wnd.Math.abs(a.e[o])*$wnd.Math.max($wnd.Math.abs(a.i[o]),1);L=$wnd.Math.max(L,N);d[o]=a.e[o]-d[o];}L/=K;if(L<c){return 0;}e=0;g=0;F=0;G=0;for(p=0;p<a.d;p++){t=p*a.d;j[p]=0;for(v=0;v<a.d;v++)j[p]+=s[t+v]*d[v];e+=d[p]*O[p];g+=d[p]*j[p];F+=d[p]*d[p];G+=O[p]*O[p];}if(e>$wnd.Math.sqrt(3.0E-8*F*G)){e=1/e;f=1/g;for(q=0;q<a.d;q++)d[q]=e*O[q]-f*j[q];for(r=0;r<a.d;r++){t=r*a.d;for(v=r;v<a.d;v++){s[t+v]+=e*O[r]*O[v]-f*j[r]*j[v]+g*d[r]*d[v];s[v*a.d+r]=s[t+v];}}}for(k=0;k<a.d;k++){t=k*a.d;O[k]=0;for(v=0;v<a.d;v++)O[k]-=s[t+v]*a.e[v];}I=p1(Date.now());M=F1(I,H);if(s1(M,a.j)){for(w=new dlb.Obb(a.c);w.a<w.c.a.length;){dlb.Nbb(w);null.vc();}H=I;}}return 1;};hlb.Qy=function Qy(a){var b,c,d;hlb.My(this);d=0;for(b=0;b<a.f;b++){d+=clb.Kn(a,b);}if(d>0){throw c1(new Zkb.c4('molecule needs explicit hydrogen atoms for force field calculations'));}this.g=a;this.d=3*a.q;this.e=gW(Ykb.yX,emb,6,this.d,15,1);this.i=gW(Ykb.yX,emb,6,this.d,15,1);this.f=false;this.j=20;for(c=0;c<a.q;c++){this.i[3*c]=a.J[c].a;this.i[3*c+1]=a.J[c].b;this.i[3*c+2]=a.J[c].c;}};U1(222,1,{});_.d=0;_.f=false;_.j=0;_.k=0;Ykb.UY=w3(222);ilb.Ry=function Ry(a,b,c,d,e){this.a=c;this.b=d;this.c=e;this.d=jlb.qB(a.b,b.a[d]);this.f=jlb.jB(a.a,b,c,d,e);this.e=jlb.iB(a.a,b,c,d,e);};ilb.Sy=function Sy(a,b){var c,d,e,f,g,h;c=new dlb.Qi();for(d=0;d<b.q;d++){if(b.e[d]>1){for(e=0;e<b.e[d];e++){g=b.i[d][e];for(f=e+1;f<b.e[d];f++){h=b.i[d][f];dlb.wi(c,new ilb.Ry(a,b,g,d,h));}}}}return c;};U1(258,1,kqb,ilb.Ry);_.Ab=function Ty(a){var b,c;c=ilb.SA(new ilb.cB(a,this.b,this.a),new ilb.cB(a,this.b,this.c));b=c*lqb-this.f;if(this.d)return 143.9325*this.e*(1+$wnd.Math.cos(c));return mqb*this.e*b*b*(1+-0.006981317*b);};_.Bb=function Uy(a,b){var c,d,e,f,g,h,i,j,k,l;i=ilb.XA(new ilb.cB(a,this.b,this.a));j=ilb.XA(new ilb.cB(a,this.b,this.c));g=ilb.WA(new ilb.cB(a,this.b,this.a));h=ilb.WA(new ilb.cB(a,this.b,this.c));d=(i.a*j.a+i.b*j.b+i.c*j.c)/($wnd.Math.sqrt(i.a*i.a+i.b*i.b+i.c*i.c)*$wnd.Math.sqrt(j.a*j.a+j.b*j.b+j.c*j.c));l=1-d*d;k=nqb;l>0&&(k=$wnd.Math.sqrt(l));c=lqb*$wnd.Math.acos(d)-this.f;f=oqb*this.e*c*(1+-0.0104719755*c);this.d&&(f=-143.9325*this.e*k);e=oW(aW(Ykb.yX,1),emb,6,15,[1/g*(j.a-d*i.a),1/g*(j.b-d*i.b),1/g*(j.c-d*i.c),1/h*(i.a-d*j.a),1/h*(i.b-d*j.b),1/h*(i.c-d*j.c)]);b[3*this.a]+=f*e[0]/-k;b[3*this.a+1]+=f*e[1]/-k;b[3*this.a+2]+=f*e[2]/-k;b[3*this.b]+=f*(-e[0]-e[3])/-k;b[3*this.b+1]+=f*(-e[1]-e[4])/-k;b[3*this.b+2]+=f*(-e[2]-e[5])/-k;b[3*this.c]+=f*e[3]/-k;b[3*this.c+1]+=f*e[4]/-k;b[3*this.c+2]+=f*e[5]/-k;};_.a=0;_.b=0;_.c=0;_.d=false;_.e=0;_.f=0;Ykb.VY=w3(258);ilb.vz=function vz(a){Zkb.uz.call(this,a);};U1(147,41,{147:1,4:1,15:1,22:1},ilb.vz);Ykb.WY=w3(147);ilb.wz=function wz(){Zkb.sz.call(this);};U1(257,41,Vlb,ilb.wz);Ykb.XY=w3(257);ilb.xz=function xz(a,b,c){ilb.yz.call(this,a,b,b.D[0][c],b.D[1][c]);};ilb.yz=function yz(a,b,c,d){this.a=c;this.b=d;this.d=jlb.EB(a.d,b,c,d);this.c=jlb.DB(a.d,b,c,d);};ilb.zz=function zz(a,b){var c,d;d=new dlb.Qi();for(c=0;c<b.r;c++)dlb.wi(d,new ilb.xz(a,b,c));return d;};U1(184,1,kqb,ilb.xz);_.Ab=function Az(a){var b,c;c=ilb.UA(new ilb.bB(a,this.a),new ilb.bB(a,this.b));b=(c-this.d)*(c-this.d);return 71.96625*this.c*b*(1+-2*(c-this.d)+2.3333333333333335*b);};_.Bb=function Bz(a,b){var c,d,e,f;d=ilb.UA(new ilb.bB(a,this.a),new ilb.bB(a,this.b));e=d-this.d;c=143.9325*this.c*e*(1+-3*e+4.666666666666667*e*e);if(d>0){for(f=0;f<3;f++){b[3*this.a+f]+=c*(a[3*this.a+f]-a[3*this.b+f])/d;b[3*this.b+f]-=c*(a[3*this.a+f]-a[3*this.b+f])/d;}}};_.a=0;_.b=0;_.c=0;_.d=0;Ykb.YY=w3(184);ilb.Cz=function Cz(b){var c,d,e,f,g,h,i,j;c=null;try{c=new Alb.q2(new Alb.u2(b));i=Zkb.P3(Zkb.q5(Alb.p2(c)),oob,Qlb);e=Zkb.n5(Zkb.q5(Alb.p2(c)),',');j=eW(Ykb.f_,[Llb,Ulb],[8,1],5,[i,e.length],2);for(g=0;(f=Alb.p2(c))!=null&&g<i;g++){h=Zkb.n5(Zkb.q5(f),',');for(d=0;d<e.length;d++){switch(Zkb.X4(e[d],0)){case 105:kW(j[g],d,Zkb.t4(Zkb.P3(Zkb.q5(h[d]),oob,Qlb)));break;case 102:kW(j[g],d,alb.Pgb(Zkb.O3(Zkb.q5(h[d]))));break;case 99:kW(j[g],d,k3(Zkb.X4(Zkb.l5(Zkb.l5(Zkb.q5(h[d]),"'"),'"'),0)));}}}return j;}catch(a){a=b1(a);if(mX(a,73)){Zkb.O5();}else throw c1(a);}return eW(Ykb.f_,[Llb,Ulb],[8,1],5,[1,1],2);};ilb.Dz=function Dz(a){var b,c,d,e,f,g;g=ilb.Cz(a);f=g.length;b=g[0].length;e=eW(Ykb.AX,[Dnb,gmb],[7,6],15,[f,b],2);for(c=0;c<f;c++)for(d=0;d<b;d++)e[c][d]=g[c][d].a;return e;};ilb.Ez=function Ez(a,b,c,d,e,f,g){this.a=a;this.b=b;this.e=c;this.d=f;this.c=d*e/g;};ilb.Fz=function Fz(a,b,c,d,e,f){var g,h,i,j,k;h=new dlb.Qi();g=klb.RC(a,b);for(i=0;i<b.q;i++){for(j=0;j<i+1;j++){k=ilb.mA(c,new ilb.xA(i,j));(k==(ilb.tA(),ilb.oA)||k==ilb.sA)&&$wnd.Math.abs(g[i])>pqb&&$wnd.Math.abs(g[j])>pqb&&ilb.WA(new ilb._A(b,i,j))<d&&dlb.wi(h,new ilb.Ez(i,j,k,g[i],g[j],e,f));}}return h;};U1(259,1,kqb,ilb.Ez);_.Ab=function Gz(a){var b,c;c=ilb.WA(new ilb.cB(a,this.a,this.b));b=c+0.05;this.d&&(b*=b);return 332.0716*this.c/b*(this.e==(ilb.tA(),ilb.oA)?0.75:1);};_.Bb=function Hz(a,b){var c,d,e,f,g;f=ilb.WA(new ilb.cB(a,this.a,this.b));c=f+0.05;c*=this.d?c*c:c;d=-332.0716*(this.d?2:1)*this.c/c*(this.e==(ilb.tA(),ilb.oA)?0.75:1);for(g=0;g<3;g++){e=0.02;f>0&&(e=d*(a[3*this.a+g]-a[3*this.b+g])/f);b[3*this.a+g]+=e;b[3*this.b+g]-=e;}};_.a=0;_.b=0;_.c=0;_.d=false;Ykb.ZY=w3(259);ilb.Jz=function Jz(){ilb.Jz=W1;ilb.Iz=new dlb.Lcb();};ilb.Kz=function Kz(a){a.a=new dlb.Qi();};ilb.Lz=function Lz(a){return ilb.Mz(a,a.i);};ilb.Mz=function Mz(a,b){var c,d,e;e=0;for(d=new dlb.Obb(a.a);d.a<d.c.a.length;){c=dlb.Nbb(d);e+=c.Ab(b);}return e;};ilb.Nz=function Nz(a){var b,c,d,e,f,g;a.e=gW(Ykb.yX,emb,6,a.d,15,1);for(c=new dlb.Obb(a.a);c.a<c.c.a.length;){b=dlb.Nbb(c);b.Bb(a.i,a.e);}g=-100000000;d=0.1;for(f=0;f<a.d;f++){a.e[f]*=d;a.e[f]>g&&(g=a.e[f]);}if(g>10){while(g*d>10)d*=0.5;for(e=0;e<a.d;e++)a.e[e]*=d;}return d;};ilb.Oz=function Oz(a){ilb.Jz();ilb.Pz.call(this,a,qqb,new dlb.Lcb());};ilb.Pz=function Pz(a,b,c){ilb.Jz();var d,e,f,g,h;hlb.Qy.call(this,a);ilb.Kz(this);this.b=new ilb.Rz(a);clb.Gt(this.g,7);h=dlb.Y8(ilb.Iz,b);f=dlb.qdb(c.c,rqb)?Zkb.U3(dlb.rdb(c.c,rqb)):100;d=dlb.qdb(c.c,sqb)?Zkb.U3(dlb.rdb(c.c,sqb)):1;e=dlb.qdb(c.c,tqb)&&Zkb.c5(dlb.rdb(c.c,tqb),'distance');g=new ilb.nA(this.b);(!dlb.qdb(c.c,uqb)||Zkb.M2(dlb.rdb(c.c,uqb)))&&dlb.yi(this.a,ilb.Sy(h,this.b));(!dlb.qdb(c.c,vqb)||Zkb.M2(dlb.rdb(c.c,vqb)))&&dlb.yi(this.a,ilb.zz(h,this.b));(!dlb.qdb(c.c,wqb)||Zkb.M2(dlb.rdb(c.c,wqb)))&&dlb.yi(this.a,ilb.Fz(h,this.b,g,f,e,d));(!dlb.qdb(c.c,xqb)||Zkb.M2(dlb.rdb(c.c,xqb)))&&dlb.yi(this.a,ilb.Tz(h,this.b));(!dlb.qdb(c.c,yqb)||Zkb.M2(dlb.rdb(c.c,yqb)))&&dlb.yi(this.a,ilb.DA(h,this.b));(!dlb.qdb(c.c,zqb)||Zkb.M2(dlb.rdb(c.c,zqb)))&&dlb.yi(this.a,ilb.JA(h,this.b));(!dlb.qdb(c.c,Aqb)||Zkb.M2(dlb.rdb(c.c,Aqb)))&&dlb.yi(this.a,ilb.PA(h,this.b,g,f));};ilb.Qz=function Qz(a,b){ilb.Jz();dlb.Z8(ilb.Iz,a)||dlb._8(ilb.Iz,a,b);};U1(135,222,{},ilb.Oz,ilb.Pz);Ykb.$Y=w3(135);ilb.Rz=function Rz(a){clb.wj();var b,c,d,e,f,g;clb.$t.call(this,a);clb.Hn(this,clb.fn(this));g=(clb.Gt(this,7),this.p);this.b=gW(Ykb.bZ,gmb,6,g.i.a.length,15,1);for(e=0;e<this.b.length;e++)this.b[e]=2;b=false;c=true;while(!b&&c){b=true;c=false;for(f=0;f<g.i.a.length;f++){if(this.b[f]==2){this.b[f]=klb.OC(this,f);this.b[f]!=2&&(c=true);}this.b[f]==2&&(b=false);}}if(!b)throw c1(new ilb.wz());this.a=gW(Ykb.AX,gmb,6,this.q,15,1);for(d=0;d<this.a.length;d++){this.a[d]=-1;this.a[d]=klb.IC(this,d);if(this.a[d]==0)throw c1(new ilb.vz("Couldn't assign an atom type to atom "+d+' ('+clb.qj[this.C[d]]+')'));}};U1(223,25,Lob,ilb.Rz);Ykb._Y=w3(223);ilb.Sz=function Sz(a,b,c,d,e,f){this.d=c;this.a=d;this.b=e;this.c=f;this.e=jlb.dC(a.k,b,c,d,e,f);};ilb.Tz=function Tz(a,b){var c,d,e,f,g;g=new dlb.Qi();for(f=0;f<b.q;f++){if(b.e[f]!=3)continue;c=b.i[f][0];d=b.i[f][1];e=b.i[f][2];dlb.wi(g,new ilb.Sz(a,b,f,c,d,e));dlb.wi(g,new ilb.Sz(a,b,f,c,e,d));dlb.wi(g,new ilb.Sz(a,b,f,d,e,c));}return g;};U1(148,1,kqb,ilb.Sz);_.Ab=function Uz(a){var b,c,d,e,f;d=ilb.XA(new ilb.cB(a,this.d,this.a));e=ilb.XA(new ilb.cB(a,this.d,this.b));f=ilb.XA(new ilb.cB(a,this.d,this.c));c=ilb.XA(new ilb.ZA(d.b*e.c-d.c*e.b,d.c*e.a-d.a*e.c,d.a*e.b-d.b*e.a));b=lqb*$wnd.Math.asin(c.a*f.a+c.b*f.b+c.c*f.c);return mqb*this.e*b*b;};_.Bb=function Vz(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C;m=new ilb.cB(a,this.d,this.a);n=new ilb.cB(a,this.d,this.b);o=new ilb.cB(a,this.d,this.c);h=$wnd.Math.sqrt(m.a*m.a+m.b*m.b+m.c*m.c);i=$wnd.Math.sqrt(n.a*n.a+n.b*n.b+n.c*n.c);j=$wnd.Math.sqrt(o.a*o.a+o.b*o.b+o.c*o.c);m=ilb.XA(m);n=ilb.XA(n);o=ilb.XA(o);l=ilb.XA(ilb.TA(new ilb.ZA(-m.a,-m.b,-m.c),n));p=o.a*l.a+o.b*l.b+o.c*l.c;e=1-p*p;d=$wnd.Math.max(e>0?$wnd.Math.sqrt(e):0,nqb);c=lqb*$wnd.Math.asin(p);f=m.a*n.a+m.b*n.b+m.c*n.c;r=$wnd.Math.max(1-f*f,nqb);q=$wnd.Math.max(r>0?$wnd.Math.sqrt(r):0,nqb);g=oqb*this.e*c;s=new ilb.ZA(o.b*n.c-o.c*n.b,o.c*n.a-o.a*n.c,o.a*n.b-o.b*n.a);t=new ilb.ZA(m.b*o.c-m.c*o.b,m.c*o.a-m.a*o.c,m.a*o.b-m.b*o.a);u=new ilb.ZA(n.b*m.c-n.c*m.b,n.c*m.a-n.a*m.c,n.a*m.b-n.b*m.a);v=d*q;w=p/(d*r);A=oW(aW(Ykb.yX,1),emb,6,15,[(s.a/v-(m.a-n.a*f)*w)/h,(s.b/v-(m.b-n.b*f)*w)/h,(s.c/v-(m.c-n.c*f)*w)/h]);B=oW(aW(Ykb.yX,1),emb,6,15,[(t.a/v-(n.a-m.a*f)*w)/i,(t.b/v-(n.b-m.b*f)*w)/i,(t.c/v-(n.c-m.c*f)*w)/i]);C=oW(aW(Ykb.yX,1),emb,6,15,[(u.a/v-o.a*p/d)/j,(u.b/v-o.b*p/d)/j,(u.c/v-o.c*p/d)/j]);for(k=0;k<3;k++){b[3*this.a+k]+=g*A[k];b[3*this.d+k]+=-g*(A[k]+B[k]+C[k]);b[3*this.b+k]+=g*B[k];b[3*this.c+k]+=g*C[k];}};_.a=0;_.b=0;_.c=0;_.d=0;_.e=0;Ykb.aZ=w3(148);ilb.Wz=function Wz(a){if(a<3)return 0;else if(a<11)return 1;else if(a<19)return 2;else if(a<37)return 3;else if(a<55)return 4;return 0;};ilb.Xz=function Xz(a){var b;b=0;a==2?b=1:a>=3&&a<=10?b=2:a>=11&&a<=18?b=3:a>=19&&a<=36?b=4:a>=37&&a<=54&&(b=5);(a>=21&&a<=30||a>=39&&a<=48)&&(b*=10);return b;};Zkb.Yz=function Yz(a,b){return a.b-b.b;};Zkb.Zz=function Zz(a){return a.a!=null?a.a:''+a.b;};Zkb.$z=function $z(a){return a.b;};function _z(a,b){this.a=a;this.b=b;}U1(52,1,{4:1,27:1,52:1});_.qb=function bA(a){return Zkb.Yz(this,a);};_.compareTo=function aA(a){return Zkb.Yz(this,a);};_.equals=function cA(a){return this===a;};_.ib=function(a){return this.equals(a);};_.hashCode=function dA(){return alb.wgb(this);};_.kb=function(){return this.hashCode();};_.name=function eA(){return Zkb.Zz(this);};_.ordinal=function fA(){return Zkb.$z(this);};_.toString=function gA(){return this.a!=null?this.a:''+this.b;};_.lb=function(){return this.toString();};_.b=0;Ykb.V$=w3(52);ilb.hA=function hA(){return oW(aW(Ykb.bZ,1),gmb,6,15,[0,1,2]);};Ykb.bZ=x3(null,ilb.hA);ilb.iA=function iA(a,b,c,d,e,f){var g,h,i,j;c=$wnd.Math.max(0,c);d=$wnd.Math.min(f.Jb(),d);g=(d-c)/2|0;i=c;h=d;if(f.Ib(i,a)>b||f.Ib(h-1,a)<b)return -1;while(d>=c){g=c+((d-c)/2|0);j=f.Ib(g,a);if(j==b){if(e&&g>i&&f.Ib(g-1,a)==b)d=g;else if(!e&&g<h-1&&f.Ib(g+1,a)==b)c=g;else return g;}else j>b?d=g:j<b&&(c=g);if(d-c==1&&f.Ib(c,a)<b&&f.Ib(d,a)>b)break;}return -1;};ilb.jA=function jA(a,b){return ilb.iA(0,a,0,b.a.length,true,b);};ilb.kA=function kA(a,b,c){var d,e,f;if(a.length!=b.length)return -1;f=0;d=c.Jb();for(e=0;e<a.length-1;e++){f=ilb.iA(a[e],b[e],f,d+1,true,c);d=ilb.iA(a[e],b[e],f,d+1,false,c);if(f==-1||d==-1)return -1;}return ilb.iA(a[e],b[e],f,d+1,true,c);};ilb.lA=function lA(a){a.a=new dlb.Lcb();};ilb.mA=function mA(a,b){return dlb.X8(a.a,b)!=null?dlb.X8(a.a,b):(ilb.tA(),ilb.sA);};ilb.nA=function nA(a){var b,c,d,e,f,g,h,i,j,k;ilb.lA(this);for(b=0;b<a.q;b++){dlb.$8(this.a,new ilb.xA(b,b),(ilb.tA(),ilb.pA));for(c=0;c<a.e[b];c++){i=a.i[b][c];h=new ilb.xA(b,i);dlb.$8(this.a,h,ilb.rA);for(d=0;d<a.e[i];d++){j=a.i[i][d];g=new ilb.xA(b,j);(!dlb.T8(this.a,g)||uX(dlb.X8(this.a,g))===uX(ilb.oA))&&dlb.$8(this.a,g,ilb.qA);for(e=0;e<a.e[j];e++){k=a.i[j][e];f=new ilb.xA(b,k);dlb.T8(this.a,f)||dlb.$8(this.a,f,ilb.oA);}}}}};U1(224,1,{},ilb.nA);Ykb.dZ=w3(224);ilb.tA=function tA(){ilb.tA=W1;ilb.pA=new ilb.uA('ONE_ONE',0);ilb.rA=new ilb.uA('ONE_TWO',1);ilb.qA=new ilb.uA('ONE_THREE',2);ilb.oA=new ilb.uA('ONE_FOUR',3);ilb.sA=new ilb.uA('ONE_X',4);};ilb.uA=function uA(a,b){_z.call(this,a,b);};ilb.vA=function vA(){ilb.tA();return oW(aW(Ykb.cZ,1),Bqb,82,0,[ilb.pA,ilb.rA,ilb.qA,ilb.oA,ilb.sA]);};U1(82,52,{82:1,4:1,27:1,52:1},ilb.uA);Ykb.cZ=x3(82,ilb.vA);ilb.wA=function wA(a,b){if(a.a>b.a)return 1;if(a.a<b.a)return -1;if(a.b>b.b)return 1;if(a.b<b.b)return -1;return 0;};ilb.xA=function xA(a,b){this.a=a>b?a:b;this.b=a>b?b:a;};U1(71,1,{71:1,27:1},ilb.xA);_.qb=function yA(a){return ilb.wA(this,a);};_.ib=function zA(a){var b;if(a===this)return true;if(!mX(a,71))return false;b=a;return this.a==b.a&&this.b==b.b;};_.kb=function AA(){return new Zkb.h4(this.a).a^new Zkb.h4(this.b).a;};_.lb=function BA(){return this.a+','+this.b;};_.a=0;_.b=0;Ykb.eZ=w3(71);ilb.CA=function CA(a,b,c,d,e){this.a=c;this.b=d;this.c=e;this.i=jlb.jB(a.a,b,c,d,e);this.f=jlb.EB(a.d,b,c,d);this.g=jlb.EB(a.d,b,e,d);this.d=jlb.iC(a.n,b,c,d,e);this.e=jlb.iC(a.n,b,e,d,c);};ilb.DA=function DA(a,b){var c,d,e,f,g,h,i,j;j=new dlb.Qi();for(c=0;c<b.q;c++){d=b.a[c];if(b.e[c]<=1&&jlb.qB(a.b,d))continue;for(f=0;f<b.e[c];f++){h=b.i[c][f];for(g=0;g<b.e[c];g++){i=b.i[c][g];if(h>i)continue;if(ilb.GA(a,b,h,c,i)){e=new ilb.CA(a,b,h,c,i);($wnd.Math.abs(e.d)>jqb||$wnd.Math.abs(e.e)>jqb)&&(alb.ggb(j.a,e),true);}}}}return j;};ilb.GA=function GA(a,b,c,d,e){var f;f=b.a[d];if(jlb.qB(a.b,f)||c==e)return false;if(clb.tn(b,c,d)==-1||clb.tn(b,d,e)==-1)return false;return true;};U1(260,1,kqb,ilb.CA);_.Ab=function EA(a){var b,c,d,e;b=ilb.WA(new ilb.cB(a,this.b,this.a));c=ilb.WA(new ilb.cB(a,this.b,this.c));e=ilb.SA(new ilb.cB(a,this.b,this.a),new ilb.cB(a,this.b,this.c));d=oqb*(e*lqb-this.i);return d*(b-this.f)*this.d+d*(c-this.g)*this.e;};_.Bb=function FA(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q;k=ilb.WA(new ilb.cB(a,this.b,this.a));l=ilb.WA(new ilb.cB(a,this.b,this.c));n=ilb.XA(new ilb.cB(a,this.b,this.a));o=ilb.XA(new ilb.cB(a,this.b,this.c));d=n.a*o.a+n.b*o.b+n.c*o.c;q=1-d*d;p=$wnd.Math.max(q>0?$wnd.Math.sqrt(q):0,nqb);c=lqb*$wnd.Math.acos(d)-this.i;m=lqb*(this.d*(k-this.f)+this.e*(l-this.g));e=1/k*(o.a-d*n.a);f=1/k*(o.b-d*n.b);g=1/k*(o.c-d*n.c);h=1/l*(n.a-d*o.a);i=1/l*(n.b-d*o.b);j=1/l*(n.c-d*o.c);b[3*this.a]+=oqb*(n.a*this.d*c+e/-p*m);b[3*this.a+1]+=oqb*(n.b*this.d*c+f/-p*m);b[3*this.a+2]+=oqb*(n.c*this.d*c+g/-p*m);b[3*this.b]+=oqb*((-n.a*this.d-o.a*this.e)*c+(-e-h)/-p*m);b[3*this.b+1]+=oqb*((-n.b*this.d-o.b*this.e)*c+(-f-i)/-p*m);b[3*this.b+2]+=oqb*((-n.c*this.d-o.c*this.e)*c+(-g-j)/-p*m);b[3*this.c]+=oqb*(o.a*this.e*c+h/-p*m);b[3*this.c+1]+=oqb*(o.b*this.e*c+i/-p*m);b[3*this.c+2]+=oqb*(o.c*this.e*c+j/-p*m);};_.a=0;_.b=0;_.c=0;_.d=0;_.e=0;_.f=0;_.g=0;_.i=0;Ykb.fZ=w3(260);ilb.HA=function HA(a,b){this.a=new jlb.kB(this);this.e=new jlb.LB();this.b=new jlb.vB();this.c=new jlb.AB();this.d=new jlb.FB(this);this.f=new jlb.SB();this.i=new jlb.YB();this.g=new jlb.VB();this.j=new jlb.aC();this.k=new jlb.eC(this,a);this.n=new jlb.jC(this);this.o=new jlb.nC(this,b);this.p=new jlb.AC();};U1(122,1,{122:1},ilb.HA);Ykb.gZ=w3(122);ilb.IA=function IA(a,b,c,d,e,f){var g;this.a=c;this.b=d;this.c=e;this.d=f;g=jlb.mC(a.o,b,c,d,e,f);this.e=g.a;this.f=g.b;this.g=g.c;};ilb.JA=function JA(a,b){var c,d,e,f,g,h,i,j,k;k=new dlb.Qi();for(c=0;c<b.q;c++){for(g=0;g<b.e[c];g++){d=b.i[c][g];for(h=0;h<b.e[d];h++){e=b.i[d][h];if(c==e)continue;for(i=0;i<b.e[e];i++){f=b.i[e][i];if(d==f||c==f)continue;if(f>c){j=new ilb.IA(a,b,c,d,e,f);($wnd.Math.abs(j.e)>0.001||$wnd.Math.abs(j.f)>0.001||$wnd.Math.abs(j.g)>0.001)&&(alb.ggb(k.a,j),true);}}}}}return k;};U1(261,1,kqb,ilb.IA);_.Ab=function KA(a){var b,c,d,e,f,g,h,i,j;e=new ilb.cB(a,this.a,this.b);f=new ilb.cB(a,this.c,this.b);g=new ilb.cB(a,this.b,this.c);h=new ilb.cB(a,this.d,this.c);i=new ilb.ZA(e.b*f.c-e.c*f.b,e.c*f.a-e.a*f.c,e.a*f.b-e.b*f.a);j=new ilb.ZA(g.b*h.c-g.c*h.b,g.c*h.a-g.a*h.c,g.a*h.b-g.b*h.a);d=(i.a*j.a+i.b*j.b+i.c*j.c)/($wnd.Math.sqrt(i.a*i.a+i.b*i.b+i.c*i.c)*$wnd.Math.sqrt(j.a*j.a+j.b*j.b+j.c*j.c));b=2*d*d-1;c=d*(2*b-1);return 0.5*(this.e*(1+d)+this.f*(1-b)+this.g*(1+c));};_.Bb=function LA(a,b){var c,d,e,f,g,h,i,j,k,l,m;g=oW(aW(Ykb.jZ,1),Ulb,19,0,[new ilb.cB(a,this.b,this.a),new ilb.cB(a,this.b,this.c),new ilb.cB(a,this.c,this.b),new ilb.cB(a,this.c,this.d)]);m=oW(aW(Ykb.jZ,1),Ulb,19,0,[ilb.TA(g[0],g[1]),ilb.TA(g[2],g[3])]);d=oW(aW(Ykb.yX,1),emb,6,15,[ilb.WA(m[0]),ilb.WA(m[1])]);if($wnd.Math.abs(d[0])<pqb||$wnd.Math.abs(d[1])<pqb)return;m[0]=ilb.XA(m[0]);m[1]=ilb.XA(m[1]);c=ilb.VA(m[0],m[1]);k=1-c*c;j=k>0?$wnd.Math.sqrt(k):0;h=2*j*c;i=3*j-4*j*k;f=0.5*(-this.e*j+2*this.f*h-3*this.g*i);l=-f*($wnd.Math.abs(j)<pqb?1/c:1/j);e=oW(aW(Ykb.yX,1),emb,6,15,[1/d[0]*(m[1].a-c*m[0].a),1/d[0]*(m[1].b-c*m[0].b),1/d[0]*(m[1].c-c*m[0].c),1/d[1]*(m[0].a-c*m[1].a),1/d[1]*(m[0].b-c*m[1].b),1/d[1]*(m[0].c-c*m[1].c)]);b[3*this.a]+=l*(e[2]*g[1].b-e[1]*g[1].c);b[3*this.a+1]+=l*(e[0]*g[1].c-e[2]*g[1].a);b[3*this.a+2]+=l*(e[1]*g[1].a-e[0]*g[1].b);b[3*this.b]+=l*(e[1]*(g[1].c-g[0].c)+e[2]*(g[0].b-g[1].b)+e[4]*-g[3].c+e[5]*g[3].b);b[3*this.b+1]+=l*(e[0]*(g[0].c-g[1].c)+e[2]*(g[1].a-g[0].a)+e[3]*g[3].c+e[5]*-g[3].a);b[3*this.b+2]+=l*(e[0]*(g[1].b-g[0].b)+e[1]*(g[0].a-g[1].a)+e[3]*-g[3].b+e[4]*g[3].a);b[3*this.c]+=l*(e[1]*g[0].c+e[2]*-g[0].b+e[4]*(g[3].c-g[2].c)+e[5]*(g[2].b-g[3].b));b[3*this.c+1]+=l*(e[0]*-g[0].c+e[2]*g[0].a+e[3]*(g[2].c-g[3].c)+e[5]*(g[3].a-g[2].a));b[3*this.c+2]+=l*(e[0]*g[0].b+e[1]*-g[0].a+e[3]*(g[3].b-g[2].b)+e[4]*(g[2].a-g[3].a));b[3*this.d]+=l*(e[4]*g[2].c-e[5]*g[2].b);b[3*this.d+1]+=l*(e[5]*g[2].a-e[3]*g[2].c);b[3*this.d+2]+=l*(e[3]*g[2].b-e[4]*g[2].a);};_.a=0;_.b=0;_.c=0;_.d=0;_.e=0;_.f=0;_.g=0;Ykb.hZ=w3(261);ilb.MA=function MA(a,b){var c,d,e,f,g;f=jlb.zC(b.p,a.b);g=jlb.zC(b.p,a.d);c=jlb.vC(b.p,a.b);d=jlb.vC(b.p,a.d);e=(f-g)/(f+g);return 0.5*(f+g)*(1+(c==68||d==68?0:0.2*(1-$wnd.Math.exp(-12*e*e))));};ilb.NA=function NA(a,b,c){var d,e,f,g,h,i,j;f=jlb.wC(b.p,a.b);g=jlb.wC(b.p,a.d);d=jlb.uC(b.p,a.b);e=jlb.uC(b.p,a.d);h=jlb.yC(b.p,a.b);i=jlb.yC(b.p,a.d);j=c*c;return 181.16*f*g*d*e/(($wnd.Math.sqrt(d/h)+$wnd.Math.sqrt(e/i))*j*j*j);};ilb.OA=function OA(a,b,c,d){var e,f;this.b=b.a[c];this.d=b.a[d];this.a=c;this.c=d;e=ilb.MA(this,a);f=ilb.NA(this,a,e);this.e=jlb.vC(a.p,this.b);this.f=jlb.vC(a.p,this.d);if(this.e==68&&this.f==65||this.e==65&&this.f==68){e=e*0.8;f*=0.5;}this.g=e;this.i=f;};ilb.PA=function PA(a,b,c,d){var e,f,g,h,i;i=new dlb.Qi();for(f=0;f<b.q;f++){for(g=f+1;g<b.q;g++){e=new ilb.xA(f,g);h=dlb.X8(c.a,e)!=null?dlb.X8(c.a,e):(ilb.tA(),ilb.sA);(h==(ilb.tA(),ilb.oA)||h==ilb.sA)&&ilb.WA(new ilb._A(b,f,g))<d&&dlb.wi(i,new ilb.OA(a,b,f,g));}}return i;};U1(262,1,kqb,ilb.OA);_.Ab=function QA(a){var b,c,d,e,f,g,h,i,j;f=ilb.WA(new ilb.cB(a,this.a,this.c));g=f*f;h=g*g*g*f;b=1.07*this.g/(f+Cqb*this.g);c=b*b;d=c*c*c*b;i=this.g*this.g;j=i*i*i*this.g;e=1.12*j/(h+Dqb*j)-2;return d*e*this.i;};_.Bb=function RA(a,b){var c,d,e,f,g,h,i,j,k,l,m,n;e=ilb.WA(new ilb.cB(a,this.a,this.c));g=e/this.g;h=g*g;i=h*h*h;j=i*g;k=j+Dqb;l=1.07/(g+1.07-1);m=l*l;n=m*m*m*l;c=this.i/this.g*n*(Eqb*i/(k*k)+(Eqb/k+14)/(g+Cqb));for(f=0;f<3;f++){d=0.01*this.g;e>0&&(d=c*(a[3*this.a+f]-a[3*this.c+f])/e);b[3*this.a+f]+=d;b[3*this.c+f]-=d;}};_.a=0;_.b=0;_.c=0;_.d=0;_.e=0;_.f=0;_.g=0;_.i=0;Ykb.iZ=w3(262);ilb.SA=function SA(a,b){return $wnd.Math.acos((a.a*b.a+a.b*b.b+a.c*b.c)/($wnd.Math.sqrt(a.a*a.a+a.b*a.b+a.c*a.c)*$wnd.Math.sqrt(b.a*b.a+b.b*b.b+b.c*b.c)));};ilb.TA=function TA(a,b){return new ilb.ZA(a.b*b.c-a.c*b.b,a.c*b.a-a.a*b.c,a.a*b.b-a.b*b.a);};ilb.UA=function UA(a,b){return $wnd.Math.sqrt((a.a-b.a)*(a.a-b.a)+(a.b-b.b)*(a.b-b.b)+(a.c-b.c)*(a.c-b.c));};ilb.VA=function VA(a,b){return a.a*b.a+a.b*b.b+a.c*b.c;};ilb.WA=function WA(a){return $wnd.Math.sqrt(a.a*a.a+a.b*a.b+a.c*a.c);};ilb.XA=function XA(a){if($wnd.Math.sqrt(a.a*a.a+a.b*a.b+a.c*a.c)>0)return new ilb.ZA(a.a/$wnd.Math.sqrt(a.a*a.a+a.b*a.b+a.c*a.c),a.b/$wnd.Math.sqrt(a.a*a.a+a.b*a.b+a.c*a.c),a.c/$wnd.Math.sqrt(a.a*a.a+a.b*a.b+a.c*a.c));return new ilb.ZA(0,0,0);};ilb.YA=function YA(a,b){return new ilb.ZA(b.a-a.a,b.b-a.b,b.c-a.c);};ilb.ZA=function ZA(a,b,c){this.a=a;this.b=b;this.c=c;};ilb.$A=function $A(a,b){this.a=a.J[b].a;this.b=a.J[b].b;this.c=a.J[b].c;};ilb._A=function _A(a,b,c){ilb.aB.call(this,ilb.YA(new ilb.$A(a,b),new ilb.$A(a,c)));};ilb.aB=function aB(a){this.a=a.a;this.b=a.b;this.c=a.c;};ilb.bB=function bB(a,b){this.a=a[3*b];this.b=a[3*b+1];this.c=a[3*b+2];};ilb.cB=function cB(a,b,c){ilb.aB.call(this,ilb.YA(new ilb.bB(a,b),new ilb.bB(a,c)));};U1(19,1,{19:1},ilb.ZA,ilb.$A,ilb._A,ilb.bB,ilb.cB);_.ib=function dB(a){var b;if(a===this)return true;if(!mX(a,19))return false;b=a;return $wnd.Math.abs(this.a-b.a)<0.01&&$wnd.Math.abs(this.b-b.b)<0.01&&$wnd.Math.abs(this.c-b.c)<0.01;};_.kb=function eB(){return Zkb.X3(alb.Pgb(this.a))+Zkb.X3(alb.Pgb(this.b))+Zkb.X3(alb.Pgb(this.c));};_.a=0;_.b=0;_.c=0;Ykb.jZ=w3(19);jlb.fB=function fB(a,b,c,d,e,f){var g,h,i,j,k,l,m,n,o;o=oW(aW(Ykb.yX,1),emb,6,15,[0,0,0]);j=oW(aW(Ykb.yX,1),emb,6,15,[0,0,0]);h=oW(aW(Ykb.AX,1),gmb,6,15,[b.C[c],b.C[d],b.C[e]]);i=1.75;for(k=0;k<3;k++){switch(h[k]){case 1:o[k]=1.395;break;case 6:o[k]=2.494;j[k]=1.016;break;case 7:o[k]=2.711;j[k]=1.113;break;case 8:o[k]=3.045;j[k]=1.337;break;case 9:o[k]=2.847;break;case 14:o[k]=2.35;j[k]=0.811;break;case 15:o[k]=2.35;j[k]=1.068;break;case 16:o[k]=2.98;j[k]=1.249;break;case 17:o[k]=2.909;j[k]=1.078;break;case 35:o[k]=3.017;break;case 53:o[k]=3.086;}}l=jlb.EB(a.a.d,b,c,d);m=jlb.EB(a.a.d,b,d,e);g=(l-m)*(l-m)/((l+m)*(l+m));n=hqb*f;klb.FC(b,c,d,e,4)?i*=0.85:klb.FC(b,c,d,e,3)&&(i*=0.05);return i*o[0]*j[1]*o[2]/((l+m)*n*n*$wnd.Math.exp(2*g));};jlb.gB=function gB(a,b,c,d,e){var f;if(klb.FC(b,c,d,e,3))return 60;else if(klb.FC(b,c,d,e,4))return 90;f=b.a[d];switch(jlb.oB(a.a.b,f)){case 2:if(b.C[d]==8)return 105;else if(jlb.qB(a.a.b,f))return 180;break;case 3:if(jlb.uB(a.a.b,f)==3&&jlb.rB(a.a.b,f)==0){return b.C[d]==7?107:92;}break;case 4:return 109.45;}return 120;};jlb.hB=function hB(a,b,c,d,e){var f,g,h,i,j,k,l,m,n;f=b.a[c];h=b.a[d];i=b.a[e];k=klb.EC(a.a,b,c,d,e);m=-1;for(l=0;l<5&&m<0;l++){g=a.a.g.a[f-1][l];j=a.a.g.a[i-1][l];g>j&&(g=(n=Zkb.t4(j),Zkb.t4(j=g),n).a);m=ilb.kA(oW(aW(Ykb.AX,1),gmb,6,15,[2,1,3,0]),oW(aW(Ykb.AX,1),gmb,6,15,[h,g,j,k]),a);}return m;};jlb.iB=function iB(a,b,c,d,e){var f;f=jlb.hB(a,b,c,d,e);return f<0?jlb.fB(a,b,c,d,e,jlb.gB(a,b,c,d,e)):$wnd.Math.abs(Zkb.Q3(a.b[f][4]))<0.001?jlb.fB(a,b,c,d,e,Zkb.Q3(a.b[f][5])):Zkb.Q3(a.b[f][4]);};jlb.jB=function jB(a,b,c,d,e){var f;f=jlb.hB(a,b,c,d,e);return f<0?jlb.gB(a,b,c,d,e):Zkb.Q3(a.b[f][5]);};jlb.kB=function kB(a){this.b=ilb.Cz('2342\nint,int,int,int,float,float\n0,0,1,0,0.000,108.900\n0,1,1,1,0.851,109.608\n0,1,1,2,0.736,109.445\n0,1,1,3,0.777,107.517\n0,1,1,4,1.006,110.265\n0,1,1,5,0.636,110.549\n0,1,1,6,0.992,108.133\n0,1,1,8,0.777,108.290\n0,1,1,9,1.136,108.194\n0,1,1,10,1.050,109.960\n0,1,1,11,1.225,108.313\n0,1,1,12,1.056,108.679\n0,1,1,13,1.078,106.820\n0,1,1,14,0.980,109.945\n0,1,1,15,0.743,107.397\n0,1,1,17,1.089,108.578\n0,1,1,18,1.093,109.315\n0,1,1,19,0.755,115.436\n0,1,1,20,1.021,108.659\n0,1,1,22,1.001,110.125\n0,1,1,25,0.803,112.356\n0,1,1,26,0.833,109.879\n0,1,1,34,1.179,106.493\n0,1,1,37,0.756,108.617\n0,1,1,39,0.927,109.170\n0,1,1,40,1.130,108.678\n0,1,1,41,0.330,98.422\n0,1,1,43,1.135,108.019\n0,1,1,45,1.197,105.028\n0,1,1,54,1.173,106.424\n0,1,1,55,1.150,107.604\n0,1,1,56,1.199,110.371\n0,1,1,57,1.012,109.900\n0,1,1,58,1.179,106.327\n0,1,1,61,1.125,109.311\n0,1,1,63,1.006,110.058\n0,1,1,64,0.988,111.064\n0,1,1,67,1.216,104.557\n0,1,1,68,1.018,107.195\n0,1,1,73,1.160,104.658\n0,1,1,78,1.012,109.850\n0,1,1,80,0.947,113.327\n0,1,1,81,1.108,109.837\n0,2,1,2,1.113,111.453\n0,2,1,3,0.667,104.829\n0,2,1,4,1.022,109.873\n0,2,1,5,0.632,110.292\n0,2,1,6,1.074,108.699\n0,2,1,8,0.884,111.553\n0,2,1,9,1.118,109.577\n0,2,1,10,1.160,107.963\n0,2,1,11,1.192,110.419\n0,2,1,12,1.070,109.410\n0,2,1,15,1.078,109.560\n0,2,1,17,1.077,109.434\n0,2,1,18,1.188,105.110\n0,2,1,20,1.053,107.448\n0,2,1,22,0.942,114.020\n0,2,1,25,0.893,106.815\n0,2,1,26,1.029,99.065\n0,2,1,34,1.066,111.817\n0,2,1,37,0.985,111.446\n0,2,1,39,1.124,109.513\n0,2,1,40,1.149,108.270\n0,2,1,45,1.232,103.978\n0,2,1,63,0.935,114.692\n0,2,1,67,1.224,104.687\n0,3,1,3,0.974,111.746\n0,3,1,4,1.019,109.850\n0,3,1,5,0.650,108.385\n0,3,1,6,0.528,104.112\n0,3,1,8,1.197,105.837\n0,3,1,9,1.201,105.535\n0,3,1,10,0.634,102.655\n0,3,1,11,1.189,110.328\n0,3,1,12,1.136,106.064\n0,3,1,13,1.147,103.645\n0,3,1,14,1.048,106.404\n0,3,1,15,1.125,107.192\n0,3,1,17,1.092,108.602\n0,3,1,18,1.120,108.119\n0,3,1,20,0.969,111.830\n0,3,1,22,0.999,110.522\n0,3,1,26,0.742,116.555\n0,3,1,34,1.141,107.871\n0,3,1,37,1.011,109.833\n0,3,1,39,1.136,108.751\n0,3,1,40,1.174,106.941\n0,3,1,41,1.033,108.216\n0,3,1,45,1.221,104.281\n0,3,1,63,1.069,107.077\n0,3,1,64,1.028,109.186\n0,3,1,81,1.167,107.327\n0,4,1,4,0.954,114.186\n0,4,1,5,0.615,111.417\n0,4,1,6,1.273,109.977\n0,4,1,8,1.099,111.063\n0,4,1,9,1.187,106.750\n0,4,1,10,1.117,110.488\n0,4,1,13,1.021,110.047\n0,4,1,15,1.028,112.432\n0,4,1,18,1.187,105.351\n0,4,1,22,1.174,102.556\n0,4,1,26,0.853,108.999\n0,4,1,34,1.148,108.160\n0,4,1,37,0.993,111.424\n0,5,1,5,0.516,108.836\n0,5,1,6,0.781,108.577\n0,5,1,8,0.653,110.297\n0,5,1,9,0.733,109.894\n0,5,1,10,0.740,107.646\n0,5,1,11,0.875,107.897\n0,5,1,12,0.698,108.162\n0,5,1,13,0.613,106.049\n0,5,1,14,0.508,113.019\n0,5,1,15,0.576,109.609\n0,5,1,17,0.634,107.944\n0,5,1,18,0.663,106.855\n0,5,1,19,0.450,113.195\n0,5,1,20,0.706,111.000\n0,5,1,22,0.618,110.380\n0,5,1,25,0.487,109.486\n0,5,1,26,0.466,111.172\n0,5,1,34,0.872,106.224\n0,5,1,35,0.644,125.663\n0,5,1,37,0.627,109.491\n0,5,1,39,0.811,106.299\n0,5,1,40,0.719,109.870\n0,5,1,41,0.525,108.904\n0,5,1,43,0.692,109.083\n0,5,1,45,0.741,105.197\n0,5,1,46,0.719,106.735\n0,5,1,54,0.874,106.973\n0,5,1,55,0.861,108.507\n0,5,1,56,0.814,108.223\n0,5,1,57,0.626,110.420\n0,5,1,58,0.750,105.481\n0,5,1,61,0.710,109.227\n0,5,1,62,0.655,113.035\n0,5,1,63,0.621,110.467\n0,5,1,64,0.622,110.457\n0,5,1,67,0.732,106.474\n0,5,1,68,0.748,103.817\n0,5,1,72,0.547,116.576\n0,5,1,73,0.633,107.153\n0,5,1,78,0.640,109.078\n0,5,1,80,0.684,105.144\n0,5,1,81,0.721,107.870\n0,6,1,6,1.156,111.368\n0,6,1,8,1.333,112.223\n0,6,1,9,1.224,116.950\n0,6,1,10,1.432,108.568\n0,6,1,11,1.593,106.900\n0,6,1,15,1.273,112.012\n0,6,1,17,1.348,108.655\n0,6,1,19,0.906,117.214\n0,6,1,20,1.293,108.202\n0,6,1,22,1.287,108.913\n0,6,1,25,1.171,103.598\n0,6,1,26,0.888,118.433\n0,6,1,34,1.257,114.975\n0,6,1,37,0.878,107.978\n0,6,1,39,1.485,106.464\n0,6,1,40,1.371,110.779\n0,6,1,41,1.333,106.467\n0,6,1,45,1.523,104.438\n0,6,1,57,1.308,108.467\n0,6,1,63,1.351,106.535\n0,6,1,64,1.238,111.308\n0,8,1,8,1.203,110.856\n0,8,1,9,1.133,114.080\n0,8,1,10,1.258,108.683\n0,8,1,12,1.217,107.251\n0,8,1,15,1.120,112.356\n0,8,1,20,1.116,109.353\n0,8,1,25,1.143,98.698\n0,8,1,34,1.138,113.412\n0,8,1,37,1.090,110.992\n0,8,1,39,1.364,104.193\n0,8,1,40,0.964,123.962\n0,8,1,41,1.234,103.868\n0,8,1,43,1.137,113.596\n0,8,1,45,1.583,96.139\n0,8,1,57,1.038,114.266\n0,8,1,63,1.104,110.598\n0,8,1,64,1.156,108.127\n0,9,1,10,1.209,110.720\n0,9,1,12,1.173,109.152\n0,9,1,15,1.024,117.465\n0,9,1,25,1.060,102.432\n0,9,1,37,1.077,111.565\n0,9,1,40,1.084,116.728\n0,9,1,80,1.163,107.509\n0,10,1,10,1.191,111.995\n0,10,1,15,1.161,110.502\n0,10,1,17,1.269,105.509\n0,10,1,20,1.220,104.838\n0,10,1,22,1.132,109.262\n0,10,1,25,1.015,104.822\n0,10,1,37,1.107,110.423\n0,10,1,40,1.264,108.536\n0,10,1,41,1.087,110.961\n0,10,1,57,1.268,103.622\n0,11,1,11,1.638,106.081\n0,11,1,15,1.254,109.517\n0,11,1,20,1.243,107.637\n0,11,1,25,1.244,97.532\n0,11,1,34,1.338,108.669\n0,11,1,35,1.556,110.367\n0,11,1,37,1.151,112.278\n0,11,1,41,1.301,105.053\n0,11,1,45,1.550,100.991\n0,11,1,73,1.303,106.569\n0,11,1,75,0.884,114.378\n0,12,1,12,1.096,110.422\n0,12,1,15,1.146,111.064\n0,12,1,18,1.299,104.827\n0,12,1,19,0.932,108.971\n0,12,1,20,1.081,108.605\n0,12,1,22,1.097,108.028\n0,12,1,25,0.989,106.118\n0,12,1,37,1.076,109.030\n0,12,1,39,1.150,110.359\n0,12,1,45,1.353,101.430\n0,12,1,63,1.071,109.474\n0,12,1,64,1.093,108.338\n0,13,1,13,1.093,111.645\n0,13,1,20,1.084,106.534\n0,13,1,22,1.068,107.469\n0,13,1,45,1.305,101.383\n0,14,1,20,1.021,107.718\n0,15,1,15,1.147,111.896\n0,15,1,25,1.059,103.308\n0,15,1,34,1.222,107.318\n0,15,1,37,1.051,110.959\n0,15,1,40,1.149,111.005\n0,15,1,41,1.263,100.981\n0,15,1,63,1.060,110.596\n0,15,1,64,1.059,110.703\n0,15,1,73,1.289,105.029\n0,17,1,37,1.065,110.049\n0,18,1,20,1.121,107.960\n0,18,1,22,1.283,101.125\n0,18,1,37,1.203,104.390\n0,18,1,45,1.287,105.273\n0,18,1,64,1.093,109.683\n0,19,1,54,0.772,119.506\n0,20,1,20,1.229,99.084\n0,20,1,37,1.052,107.428\n0,20,1,45,1.169,106.335\n0,22,1,22,0.990,111.226\n0,22,1,25,0.885,107.293\n0,22,1,34,1.045,112.940\n0,22,1,37,1.037,108.586\n0,22,1,45,1.182,106.181\n0,25,1,25,0.551,127.138\n0,25,1,34,0.779,119.271\n0,25,1,37,0.784,113.945\n0,25,1,40,1.062,102.417\n0,25,1,58,0.916,110.234\n0,26,1,26,0.625,118.700\n0,34,1,34,1.216,109.167\n0,34,1,37,1.075,111.275\n0,34,1,41,1.048,112.238\n0,34,1,63,1.077,111.412\n0,34,1,73,1.142,110.240\n0,37,1,37,0.986,111.315\n0,37,1,40,1.129,109.188\n0,37,1,43,1.074,111.478\n0,37,1,45,1.259,102.800\n0,37,1,57,0.981,112.047\n0,37,1,64,1.175,102.239\n0,37,1,68,1.100,109.983\n0,37,1,78,1.005,110.638\n0,37,1,81,1.176,107.040\n0,39,1,39,1.260,108.547\n0,40,1,40,1.182,112.005\n0,40,1,55,1.322,105.786\n0,40,1,63,1.032,114.505\n0,40,1,64,1.000,116.376\n0,41,1,41,1.082,105.400\n0,41,1,63,1.061,107.112\n0,41,1,81,1.093,110.553\n0,45,1,45,1.391,102.088\n0,0,2,0,0.000,119.400\n1,0,2,0,0.000,118.200\n2,0,2,0,0.000,120.800\n3,0,2,0,0.000,62.600\n6,0,2,0,0.000,60.500\n0,1,2,1,0.752,118.043\n0,1,2,2,0.672,122.141\n1,1,2,2,0.684,116.929\n1,1,2,3,0.698,116.104\n0,1,2,4,0.828,125.045\n1,1,2,4,0.846,121.613\n0,1,2,5,0.446,120.108\n0,1,2,6,1.160,115.518\n0,1,2,10,1.015,116.707\n0,1,2,12,0.983,115.343\n0,1,2,13,0.964,115.395\n0,1,2,15,0.939,119.465\n0,1,2,17,0.883,121.868\n0,1,2,18,0.961,117.918\n0,1,2,20,0.880,118.310\n0,1,2,22,0.873,119.114\n0,1,2,30,0.826,124.605\n1,1,2,37,0.721,116.064\n0,1,2,40,0.982,118.515\n0,1,2,45,1.121,109.921\n0,1,2,56,1.006,117.192\n1,1,2,63,0.768,127.945\n1,1,2,64,0.966,113.884\n1,1,2,67,1.115,110.185\n1,2,2,2,0.747,121.550\n2,2,2,2,0.796,126.284\n6,2,2,2,0.173,60.549\n1,2,2,3,0.545,111.297\n2,2,2,3,0.893,118.456\n5,2,2,3,0.184,59.145\n1,2,2,4,0.902,121.053\n2,2,2,4,0.889,119.794\n0,2,2,5,0.535,121.004\n1,2,2,5,0.463,118.442\n0,2,2,6,1.117,121.267\n1,2,2,6,1.204,114.538\n1,2,2,9,0.960,123.536\n2,2,2,9,1.045,116.273\n0,2,2,10,1.003,120.828\n1,2,2,10,1.026,117.324\n0,2,2,11,1.089,119.100\n1,2,2,11,1.090,116.828\n0,2,2,12,0.931,120.132\n1,2,2,12,0.957,117.526\n0,2,2,13,0.867,122.717\n0,2,2,14,0.818,122.584\n1,2,2,14,0.819,122.344\n0,2,2,15,0.931,121.553\n1,2,2,15,0.949,119.466\n0,2,2,17,0.977,117.167\n0,2,2,18,1.044,114.561\n0,2,2,19,0.668,124.721\n0,2,2,20,0.931,117.784\n0,2,2,22,0.809,126.820\n3,2,2,22,0.149,66.165\n0,2,2,25,0.700,123.830\n0,2,2,34,1.066,116.151\n0,2,2,35,0.911,137.103\n1,2,2,37,0.598,117.508\n2,2,2,37,0.817,124.229\n1,2,2,39,0.976,122.360\n0,2,2,40,0.773,126.830\n1,2,2,40,0.976,120.132\n0,2,2,41,0.432,110.442\n0,2,2,43,1.144,111.808\n0,2,2,45,1.194,109.231\n1,2,2,45,1.062,113.984\n0,2,2,46,1.005,121.534\n0,2,2,55,0.995,121.154\n0,2,2,56,1.234,108.879\n0,2,2,62,0.808,135.269\n1,2,2,63,0.948,118.277\n1,2,2,64,0.866,123.528\n2,2,2,64,0.859,121.998\n1,2,2,67,1.132,112.136\n0,2,2,72,0.770,134.269\n1,2,2,81,1.078,116.541\n2,3,2,3,0.853,120.370\n2,3,2,4,0.878,119.739\n1,3,2,5,0.487,117.291\n1,3,2,6,1.142,116.738\n2,3,2,9,1.005,117.648\n1,3,2,10,1.039,115.698\n1,3,2,11,1.150,112.876\n1,3,2,12,0.997,114.732\n1,3,2,13,0.946,116.643\n1,3,2,14,0.891,117.111\n1,3,2,15,1.023,114.635\n1,3,2,20,0.870,119.265\n1,3,2,22,0.816,123.510\n1,3,2,30,1.025,112.209\n1,3,2,34,1.099,111.723\n1,3,2,35,1.141,118.767\n2,3,2,37,0.868,119.758\n1,3,2,40,1.024,116.408\n1,3,2,41,0.855,119.505\n1,3,2,43,1.046,114.257\n1,3,2,45,1.077,112.401\n1,3,2,46,1.066,114.841\n2,4,2,4,0.832,124.158\n0,4,2,5,0.573,121.000\n1,4,2,5,0.545,120.000\n2,4,2,9,0.973,120.845\n1,4,2,15,0.906,122.447\n1,4,2,18,0.947,119.537\n1,4,2,30,0.819,126.938\n2,4,2,37,0.864,121.093\n1,4,2,40,1.083,114.355\n1,4,2,45,1.158,109.426\n2,4,2,63,0.860,122.442\n0,5,2,5,0.365,119.523\n0,5,2,6,0.589,108.757\n1,5,2,9,0.643,117.000\n0,5,2,10,0.667,114.859\n0,5,2,11,0.795,108.186\n0,5,2,12,0.622,110.650\n0,5,2,13,0.566,113.513\n0,5,2,15,0.546,119.562\n0,5,2,17,0.492,124.000\n0,5,2,18,0.548,119.053\n0,5,2,22,0.534,120.000\n0,5,2,25,0.395,124.000\n0,5,2,30,0.572,120.000\n0,5,2,35,0.682,124.164\n1,5,2,37,0.491,117.423\n1,5,2,39,0.655,115.724\n0,5,2,40,0.568,112.322\n0,5,2,41,0.294,123.706\n0,5,2,45,0.728,107.774\n0,5,2,55,0.651,116.000\n0,5,2,62,0.568,125.344\n1,5,2,63,0.550,120.000\n1,5,2,64,0.546,120.000\n0,5,2,72,0.531,122.009\n1,5,2,81,0.665,115.000\n1,6,2,9,1.214,120.520\n0,6,2,10,1.311,115.921\n0,6,2,22,1.080,120.560\n0,6,2,35,1.172,132.391\n1,6,2,37,1.198,114.441\n0,6,2,40,1.239,119.073\n0,6,2,45,1.637,102.438\n1,9,2,10,1.098,119.802\n1,9,2,15,0.915,127.574\n2,9,2,37,0.981,119.536\n1,9,2,40,0.922,130.521\n0,10,2,12,1.144,112.723\n0,10,2,15,1.078,117.519\n0,10,2,25,1.144,100.818\n1,10,2,37,1.021,117.139\n0,10,2,40,0.988,126.034\n0,10,2,41,0.951,120.000\n0,12,2,12,1.012,119.105\n0,12,2,17,1.110,114.206\n0,12,2,18,1.201,110.553\n0,12,2,19,0.704,126.646\n0,12,2,20,0.903,120.563\n0,12,2,30,0.892,122.753\n1,12,2,37,0.976,116.136\n0,12,2,45,1.076,115.543\n0,13,2,18,1.132,113.616\n0,15,2,15,0.996,123.027\n0,15,2,35,0.950,133.654\n1,15,2,37,1.007,115.757\n0,15,2,40,0.895,128.924\n0,17,2,17,1.051,117.955\n1,18,2,37,1.183,106.608\n0,22,2,22,0.841,122.108\n3,22,2,22,0.180,58.963\n1,22,2,37,0.806,124.693\n1,30,2,37,0.849,123.816\n1,35,2,37,0.991,128.032\n0,40,2,40,0.949,128.436\n0,40,2,56,1.072,120.987\n1,40,2,63,0.922,124.268\n1,40,2,64,0.955,121.881\n0,40,2,72,0.820,135.317\n0,45,2,45,1.284,108.095\n2,64,2,64,0.888,120.342\n0,0,3,0,0.000,117.300\n1,0,3,0,0.000,115.800\n4,0,3,0,0.000,90.800\n7,0,3,0,0.000,91.100\n8,0,3,0,0.000,88.900\n0,1,3,1,1.151,118.016\n1,1,3,2,1.106,116.853\n1,1,3,3,1.214,114.612\n0,1,3,5,0.808,117.280\n0,1,3,6,1.043,109.716\n0,1,3,7,0.938,124.410\n0,1,3,9,0.978,119.788\n1,1,3,9,1.038,115.132\n0,1,3,10,0.984,112.735\n0,1,3,12,1.007,113.972\n0,1,3,15,1.024,113.612\n0,1,3,16,0.949,119.986\n0,1,3,18,0.732,134.097\n0,1,3,20,0.830,120.312\n0,1,3,22,0.928,115.001\n0,1,3,35,1.058,122.808\n1,1,3,37,1.051,115.191\n1,1,3,39,1.178,107.895\n0,1,3,40,0.979,118.457\n0,1,3,41,0.897,116.681\n0,1,3,43,1.046,113.731\n0,1,3,45,1.132,109.019\n0,1,3,51,1.160,116.573\n0,1,3,53,1.052,115.065\n0,1,3,54,1.135,111.322\n1,1,3,58,1.162,108.129\n0,1,3,62,1.119,111.523\n1,1,3,63,0.909,117.001\n1,1,3,64,0.887,118.253\n0,1,3,67,1.142,110.666\n0,1,3,74,1.010,116.851\n0,1,3,75,0.646,128.037\n2,2,3,2,0.976,112.562\n6,2,3,2,0.157,62.792\n2,2,3,3,0.957,113.239\n1,2,3,5,0.901,115.350\n1,2,3,6,0.932,106.510\n1,2,3,7,0.936,122.623\n1,2,3,9,0.831,122.253\n2,2,3,9,1.120,111.408\n1,2,3,10,1.042,111.721\n1,2,3,12,0.901,120.769\n1,2,3,15,1.057,112.105\n1,2,3,16,0.881,124.850\n1,2,3,22,0.969,113.027\n1,2,3,25,0.853,109.794\n2,2,3,37,0.973,112.935\n2,2,3,39,1.197,107.592\n1,2,3,40,0.910,123.437\n1,2,3,43,1.105,111.169\n1,2,3,53,1.082,114.032\n1,2,3,54,1.012,118.588\n1,2,3,55,1.186,107.278\n1,2,3,56,1.151,108.909\n2,2,3,63,0.918,116.947\n2,2,3,64,1.033,110.084\n1,2,3,67,1.022,117.597\n2,3,3,3,0.822,121.775\n8,3,3,3,1.280,89.965\n1,3,3,5,0.943,113.762\n1,3,3,6,0.935,103.030\n1,3,3,7,0.919,117.024\n1,3,3,9,1.050,115.704\n1,3,3,10,1.129,110.421\n1,3,3,12,1.053,111.492\n1,3,3,15,1.390,97.562\n1,3,3,16,1.092,111.888\n1,3,3,20,0.977,110.910\n1,3,3,22,1.010,110.295\n8,3,3,30,1.353,87.789\n2,3,3,37,0.932,114.949\n2,3,3,39,1.237,105.384\n1,3,3,40,1.003,117.124\n1,3,3,41,0.790,124.361\n1,3,3,45,0.919,121.023\n1,3,3,53,1.170,109.169\n2,3,3,63,0.981,112.685\n2,3,3,64,0.880,118.840\n1,3,3,67,1.119,111.860\n1,4,3,6,1.269,111.750\n1,4,3,7,1.126,120.852\n1,4,3,9,1.192,109.833\n2,4,3,37,0.964,114.081\n0,5,3,5,0.594,116.699\n0,5,3,6,0.819,108.253\n0,5,3,7,0.670,123.439\n0,5,3,9,0.623,119.491\n1,5,3,9,0.638,117.168\n0,5,3,10,0.874,111.761\n0,5,3,16,0.522,124.405\n1,5,3,37,0.564,116.400\n0,5,3,40,0.959,111.684\n0,5,3,53,0.644,118.000\n0,5,3,54,0.816,115.471\n1,5,3,63,0.559,118.000\n1,5,3,64,0.566,117.000\n0,5,3,67,0.700,113.698\n0,6,3,6,1.678,109.094\n0,6,3,7,1.155,124.425\n0,6,3,9,1.275,119.478\n1,6,3,9,1.416,111.868\n0,6,3,10,1.405,112.187\n0,6,3,16,1.269,116.317\n0,6,3,20,1.182,113.581\n4,6,3,20,1.495,93.130\n0,6,3,22,1.276,110.826\n7,6,3,30,1.530,93.191\n1,6,3,37,0.808,102.881\n1,6,3,39,1.611,104.655\n0,6,3,40,1.371,113.565\n0,6,3,41,1.477,102.658\n0,6,3,43,1.330,114.183\n0,6,3,48,1.315,115.328\n0,6,3,51,1.409,120.427\n0,6,3,54,1.495,110.510\n0,6,3,62,1.421,112.542\n1,6,3,63,1.339,109.082\n1,6,3,64,1.267,111.993\n1,6,3,80,1.256,113.698\n1,7,3,9,1.147,127.084\n0,7,3,10,0.907,127.152\n0,7,3,12,0.984,130.049\n0,7,3,15,1.101,123.313\n0,7,3,20,0.713,129.492\n0,7,3,22,1.093,121.851\n1,7,3,30,0.972,129.010\n1,7,3,37,0.734,119.968\n1,7,3,39,1.352,116.727\n0,7,3,41,1.281,112.087\n0,7,3,43,1.163,124.549\n0,7,3,48,1.114,127.879\n1,7,3,54,1.288,114.184\n0,7,3,55,1.258,120.056\n0,7,3,56,1.175,123.854\n1,7,3,58,1.323,117.081\n0,7,3,62,1.129,129.349\n1,7,3,63,1.036,126.456\n1,7,3,64,1.071,124.133\n1,7,3,78,0.955,132.047\n1,9,3,9,1.119,120.094\n2,9,3,9,1.021,124.131\n0,9,3,10,1.105,120.697\n1,9,3,10,1.154,116.608\n0,9,3,12,1.056,118.046\n0,9,3,15,1.036,119.679\n1,9,3,15,1.042,118.787\n1,9,3,16,0.936,127.665\n0,9,3,17,1.035,117.902\n0,9,3,18,1.121,114.698\n0,9,3,20,0.951,120.437\n0,9,3,22,1.040,116.861\n0,9,3,25,0.955,109.442\n0,9,3,35,1.054,134.470\n1,9,3,37,0.997,119.569\n2,9,3,37,1.060,114.740\n0,9,3,40,0.844,128.078\n1,9,3,40,1.018,124.152\n0,9,3,41,1.114,112.513\n0,9,3,45,1.497,102.140\n2,9,3,54,1.244,108.056\n1,9,3,57,1.038,118.096\n1,9,3,63,1.004,120.054\n1,9,3,64,1.053,117.060\n1,9,3,80,0.959,124.150\n0,10,3,10,1.612,114.923\n0,10,3,15,1.167,112.206\n0,10,3,16,1.005,123.150\n0,10,3,18,1.299,106.052\n0,10,3,20,1.019,115.213\n4,10,3,20,1.338,92.724\n0,10,3,22,1.076,113.651\n7,10,3,30,1.438,90.508\n0,10,3,35,1.223,122.649\n1,10,3,37,1.101,112.495\n1,10,3,39,1.434,104.419\n0,10,3,40,1.093,119.697\n0,10,3,43,1.144,115.929\n0,10,3,51,1.375,114.685\n0,10,3,55,1.286,109.590\n0,10,3,56,1.200,113.168\n1,10,3,63,1.075,114.623\n1,10,3,64,1.098,113.233\n1,10,3,78,1.182,109.543\n0,11,3,40,1.296,113.244\n0,11,3,75,0.850,120.964\n0,12,3,40,1.095,115.284\n1,12,3,63,0.965,117.217\n0,12,3,74,1.110,116.502\n0,15,3,15,1.109,115.620\n0,15,3,16,0.981,124.329\n0,15,3,17,1.191,110.607\n0,15,3,18,1.061,118.034\n4,15,3,20,1.345,91.041\n1,15,3,30,1.026,113.753\n1,15,3,37,1.037,113.305\n0,15,3,40,1.066,117.388\n1,15,3,57,0.896,122.260\n0,15,3,67,1.407,102.583\n0,15,3,74,1.076,119.117\n1,16,3,30,0.991,117.695\n0,16,3,35,1.030,130.230\n1,16,3,37,0.934,121.415\n1,16,3,39,1.004,123.196\n0,16,3,62,0.963,126.347\n1,16,3,63,1.006,117.454\n1,16,3,64,1.064,114.110\n0,17,3,17,0.939,123.528\n1,18,3,37,0.948,118.188\n4,20,3,20,1.495,94.800\n4,20,3,22,1.286,89.459\n7,20,3,37,1.282,89.733\n4,20,3,43,1.384,90.526\n0,22,3,22,0.932,115.334\n4,22,3,22,1.496,83.915\n1,22,3,37,0.940,114.995\n1,25,3,37,0.677,123.404\n0,25,3,67,0.661,131.520\n2,37,3,37,0.933,115.566\n1,37,3,40,0.987,118.790\n1,37,3,41,0.864,119.565\n1,37,3,43,1.125,110.383\n1,37,3,45,1.120,110.268\n1,37,3,54,1.033,117.645\n1,37,3,62,1.085,114.132\n2,37,3,63,0.934,116.163\n2,37,3,64,0.955,114.701\n1,37,3,67,1.084,114.460\n2,39,3,39,1.231,112.582\n0,40,3,40,1.146,117.002\n1,40,3,63,0.888,126.089\n1,40,3,64,1.145,110.889\n0,40,3,75,0.790,122.163\n0,45,3,53,1.382,105.849\n1,55,3,64,1.267,104.747\n2,64,3,64,0.989,113.280\n0,0,4,0,0.000,180.000\n1,0,4,0,0.000,180.000\n0,1,4,4,0.423,180.000\n0,1,4,42,0.463,180.000\n0,2,4,2,0.442,180.000\n1,2,4,4,0.432,180.000\n0,2,4,30,0.444,180.000\n1,2,4,42,0.474,180.000\n1,3,4,4,0.427,180.000\n1,3,4,42,0.469,180.000\n0,4,4,5,0.281,180.000\n0,4,4,6,0.551,180.000\n0,4,4,10,0.486,180.000\n1,4,4,37,0.430,180.000\n0,7,4,9,0.648,180.000\n1,9,4,42,0.537,180.000\n0,15,4,42,0.487,180.000\n0,20,4,42,0.469,180.000\n0,22,4,42,0.472,180.000\n1,37,4,42,0.472,180.000\n0,42,4,43,0.541,180.000\n1,42,4,63,0.474,180.000\n1,42,4,64,0.473,180.000\n0,0,6,0,0.000,110.400\n3,0,6,0,0.000,57.900\n4,0,6,0,0.000,90.200\n0,1,6,1,1.197,106.926\n0,1,6,2,0.967,103.614\n0,1,6,3,0.923,108.055\n0,1,6,6,1.884,103.905\n0,1,6,8,1.629,105.422\n0,1,6,9,1.628,106.496\n0,1,6,10,1.656,105.317\n0,1,6,15,1.480,111.230\n0,1,6,17,1.493,111.951\n0,1,6,18,1.370,116.346\n0,1,6,19,1.093,114.943\n0,1,6,20,1.316,112.833\n0,1,6,21,0.793,106.503\n0,1,6,22,1.391,109.759\n0,1,6,25,1.095,115.581\n0,1,6,26,1.170,112.081\n0,1,6,37,1.075,102.846\n0,1,6,40,1.719,103.733\n0,1,6,41,1.454,109.046\n0,1,6,43,1.642,105.462\n0,1,6,45,1.642,105.875\n0,1,6,63,1.449,109.545\n0,1,6,64,1.512,106.848\n0,2,6,2,1.354,113.339\n0,2,6,3,0.671,98.438\n0,2,6,18,1.365,117.169\n0,2,6,25,1.025,120.078\n0,2,6,29,0.816,105.727\n0,2,6,37,1.418,110.694\n0,2,6,57,1.341,114.785\n0,3,6,3,1.455,110.067\n0,3,6,4,1.409,112.404\n0,3,6,8,1.648,105.872\n0,3,6,10,1.596,108.437\n0,3,6,18,1.274,121.468\n0,3,6,19,1.019,119.840\n0,3,6,20,1.379,111.381\n4,3,6,20,1.748,91.216\n0,3,6,22,1.328,113.491\n0,3,6,24,0.583,111.948\n0,3,6,25,1.006,121.410\n0,3,6,29,0.876,111.417\n0,3,6,37,0.614,95.300\n0,3,6,64,1.424,111.483\n0,4,6,18,1.423,115.233\n0,6,6,21,1.362,95.697\n0,8,6,21,0.832,99.409\n0,9,6,21,1.115,101.592\n0,10,6,21,0.923,99.688\n0,18,6,18,1.334,125.242\n0,18,6,33,0.812,115.364\n0,18,6,37,1.429,114.473\n0,18,6,39,1.558,114.152\n0,18,6,43,1.710,108.479\n0,19,6,19,0.642,141.096\n0,19,6,21,0.597,118.204\n0,19,6,37,0.941,124.421\n4,20,6,20,1.339,89.100\n0,20,6,21,0.944,104.587\n0,20,6,37,1.394,110.394\n0,21,6,40,1.124,101.417\n0,21,6,43,1.058,103.253\n0,21,6,54,1.175,100.000\n0,21,6,55,1.139,101.000\n3,22,6,22,0.242,58.680\n3,22,6,43,0.279,57.087\n0,24,6,25,0.607,118.533\n0,25,6,25,0.777,129.375\n0,25,6,37,1.099,115.923\n0,26,6,37,1.090,116.692\n0,29,6,30,0.986,108.000\n0,29,6,37,0.726,105.409\n0,29,6,64,0.923,108.922\n0,37,6,37,1.462,108.967\n0,37,6,58,1.607,108.274\n0,0,8,0,0.000,110.400\n3,0,8,0,0.000,58.500\n4,0,8,0,0.000,95.000\n0,1,8,1,1.090,107.018\n0,1,8,6,1.297,102.829\n0,1,8,8,1.347,105.708\n0,1,8,9,1.182,114.240\n0,1,8,10,1.307,108.079\n0,1,8,15,1.085,118.283\n0,1,8,17,1.096,117.478\n0,1,8,19,0.779,122.759\n0,1,8,20,1.221,105.873\n0,1,8,22,1.147,109.200\n0,1,8,23,0.763,109.062\n0,1,8,25,0.865,117.482\n0,1,8,26,0.926,112.630\n0,1,8,40,1.363,105.609\n0,1,8,45,1.266,110.149\n0,1,8,46,1.265,111.092\n0,6,8,6,1.776,107.296\n0,6,8,17,1.664,105.334\n0,6,8,22,1.456,107.100\n0,6,8,23,0.861,100.510\n3,8,8,8,0.230,60.000\n0,8,8,23,0.792,108.917\n0,8,8,25,1.068,110.595\n0,8,8,26,1.047,110.816\n0,9,8,23,0.832,108.864\n4,10,8,20,1.805,84.690\n0,10,8,23,0.846,106.788\n0,12,8,22,1.227,107.439\n0,15,8,19,0.845,125.674\n4,17,8,17,1.198,110.056\n0,17,8,23,0.647,116.842\n0,19,8,23,0.542,112.000\n4,20,8,20,1.103,90.370\n0,20,8,23,0.684,113.359\n3,22,8,22,0.209,57.087\n0,22,8,23,0.697,110.033\n0,22,8,25,0.896,115.361\n0,23,8,23,0.595,105.998\n0,23,8,25,0.510,117.000\n0,23,8,26,0.553,110.959\n0,23,8,34,0.808,109.000\n0,23,8,39,0.757,111.820\n0,23,8,40,0.819,108.120\n0,23,8,43,0.857,106.222\n0,23,8,55,0.868,106.000\n0,23,8,56,0.876,105.092\n0,0,9,0,0.000,111.500\n1,0,9,0,0.000,109.100\n0,1,9,3,0.878,106.409\n0,1,9,9,1.306,110.005\n0,1,9,53,1.216,113.995\n0,1,9,67,1.391,106.413\n1,2,9,3,1.242,109.856\n1,2,9,9,1.306,112.528\n1,3,9,3,1.204,111.488\n1,3,9,4,1.194,113.272\n0,3,9,6,1.579,106.872\n0,3,9,8,1.386,108.822\n1,3,9,9,1.390,108.355\n0,3,9,10,1.365,109.548\n0,3,9,12,1.373,103.303\n0,3,9,15,1.265,110.780\n0,3,9,18,1.205,114.743\n0,3,9,20,1.198,109.751\n0,3,9,25,0.873,119.927\n0,3,9,27,0.818,108.779\n0,3,9,34,1.355,108.199\n0,3,9,35,1.511,109.907\n1,3,9,37,1.185,111.663\n1,3,9,39,1.396,108.538\n0,3,9,40,1.365,109.440\n0,3,9,41,1.169,112.551\n0,3,9,45,1.369,109.796\n1,3,9,53,1.351,110.578\n1,3,9,54,1.643,98.943\n0,3,9,55,1.431,106.195\n0,3,9,56,1.375,109.289\n1,3,9,57,1.125,115.780\n1,3,9,63,1.247,109.989\n1,3,9,64,1.302,106.461\n1,3,9,78,1.323,106.641\n1,3,9,81,1.567,101.581\n0,4,9,19,0.456,161.741\n1,4,9,67,1.402,108.868\n0,6,9,67,1.794,105.043\n0,9,9,10,1.518,109.154\n1,9,9,37,1.397,108.014\n0,9,9,40,1.594,106.413\n0,9,9,62,1.390,114.417\n1,9,9,63,1.320,112.325\n1,9,9,64,1.352,109.711\n1,37,9,53,1.343,110.162\n1,37,9,67,1.296,111.871\n0,40,9,67,1.538,108.056\n1,53,9,64,1.318,111.149\n0,0,10,0,0.000,117.500\n3,0,10,0,0.000,58.900\n4,0,10,0,0.000,92.900\n0,1,10,1,1.117,117.909\n0,1,10,2,1.004,118.916\n0,1,10,3,0.821,119.600\n0,1,10,6,1.179,108.865\n0,1,10,8,1.137,116.189\n0,1,10,9,1.132,117.005\n0,1,10,10,1.247,111.009\n0,1,10,17,1.014,122.388\n0,1,10,20,0.960,119.679\n0,1,10,25,0.745,125.390\n0,1,10,28,0.552,120.066\n0,1,10,37,1.038,116.332\n0,1,10,39,1.060,120.838\n0,1,10,40,1.194,113.314\n0,1,10,41,1.031,118.033\n0,1,10,45,1.268,109.599\n0,1,10,63,0.949,122.185\n0,1,10,64,0.960,121.315\n0,2,10,2,1.146,112.878\n0,2,10,3,1.000,120.703\n0,2,10,6,1.405,111.609\n0,2,10,20,1.132,111.544\n0,2,10,28,0.638,118.553\n0,2,10,37,0.977,121.506\n0,3,10,3,0.709,120.274\n0,3,10,4,0.864,130.236\n0,3,10,6,0.960,110.133\n0,3,10,8,1.168,116.075\n4,3,10,8,1.527,93.608\n0,3,10,9,1.174,116.443\n0,3,10,10,1.184,115.377\n0,3,10,13,0.998,118.867\n0,3,10,14,0.871,124.162\n0,3,10,15,1.076,118.969\n0,3,10,17,1.132,116.612\n0,3,10,20,0.936,122.540\n4,3,10,20,1.371,93.349\n0,3,10,22,0.975,120.929\n0,3,10,25,0.794,122.157\n0,3,10,26,0.848,117.912\n0,3,10,28,0.575,120.277\n0,3,10,34,1.251,112.201\n0,3,10,35,1.395,112.633\n0,3,10,37,1.023,118.596\n0,3,10,40,1.216,113.680\n0,3,10,41,1.098,115.913\n0,3,10,45,1.212,113.447\n0,3,10,63,1.091,115.381\n0,3,10,64,1.048,117.574\n0,4,10,20,0.816,131.702\n0,6,10,28,0.829,113.214\n0,6,10,37,1.393,111.476\n0,8,10,28,0.703,117.160\n0,8,10,37,1.167,115.599\n0,9,10,26,0.847,123.206\n0,9,10,28,0.751,114.501\n0,9,10,37,1.222,113.553\n0,9,10,39,1.310,115.309\n0,10,10,28,0.735,114.715\n0,10,10,41,1.237,113.743\n0,15,10,28,0.614,119.033\n4,20,10,20,1.381,91.694\n0,20,10,28,0.555,123.394\n0,20,10,37,1.006,117.703\n3,22,10,22,0.202,58.894\n0,22,10,28,0.605,119.583\n0,25,10,28,0.447,122.785\n0,28,10,28,0.435,115.630\n0,28,10,34,0.757,113.000\n0,28,10,35,0.836,114.000\n0,28,10,37,0.628,118.227\n0,28,10,40,0.754,113.000\n0,28,10,41,0.560,128.067\n0,28,10,63,0.640,118.099\n0,28,10,64,0.643,117.575\n0,37,10,40,1.232,112.412\n0,0,15,0,0.000,97.900\n4,0,15,0,0.000,80.200\n0,1,15,1,1.654,97.335\n0,1,15,2,1.321,97.853\n0,1,15,3,1.325,97.326\n0,1,15,4,1.344,97.370\n0,1,15,9,1.725,89.814\n0,1,15,15,1.377,100.316\n0,1,15,18,1.309,101.641\n0,1,15,19,1.007,102.069\n0,1,15,20,1.366,94.913\n0,1,15,22,1.268,99.768\n0,1,15,25,0.967,104.732\n0,1,15,30,1.379,95.613\n0,1,15,37,1.439,97.111\n0,1,15,40,1.555,94.643\n0,1,15,57,1.301,98.686\n0,1,15,63,1.304,98.330\n0,1,15,64,1.306,98.066\n0,1,15,71,0.931,96.494\n0,2,15,2,1.434,95.108\n0,2,15,3,1.318,98.813\n0,2,15,4,1.426,95.780\n0,2,15,15,1.457,97.789\n0,2,15,37,1.362,96.942\n0,2,15,43,1.709,90.872\n0,3,15,3,1.402,95.424\n0,3,15,6,1.804,94.075\n0,3,15,15,1.403,99.399\n4,3,15,20,1.666,79.842\n0,3,15,37,1.308,98.541\n0,3,15,63,1.390,96.051\n0,3,15,71,0.830,97.000\n0,6,15,37,1.679,97.231\n0,8,15,8,1.444,105.143\n0,8,15,37,1.446,98.976\n0,9,15,9,1.626,98.524\n0,9,15,64,1.504,97.105\n0,10,15,15,1.415,103.715\n0,12,15,37,1.428,97.534\n0,15,15,15,1.413,104.893\n0,15,15,18,1.563,99.173\n0,15,15,37,1.361,100.790\n0,15,15,64,1.332,102.040\n0,15,15,71,0.787,99.239\n4,20,15,30,1.978,73.428\n0,20,15,37,1.361,95.589\n0,25,15,25,0.947,99.505\n4,25,15,25,1.030,87.982\n0,25,15,26,1.002,96.851\n0,25,15,37,1.172,95.428\n0,26,15,37,1.144,96.710\n4,30,15,30,1.732,79.546\n0,37,15,37,1.295,98.802\n0,37,15,63,1.379,96.197\n0,37,15,64,1.286,99.423\n0,37,15,71,0.813,96.222\n0,71,15,71,0.734,93.377\n0,0,17,0,0.000,99.400\n4,0,17,0,0.000,78.400\n0,1,17,1,1.415,93.266\n0,1,17,2,1.387,94.732\n0,1,17,3,1.430,92.852\n0,1,17,6,1.863,92.132\n0,1,17,7,1.408,107.104\n0,1,17,8,1.661,91.498\n0,1,17,10,1.547,94.839\n0,1,17,20,1.453,91.368\n0,1,17,22,1.423,92.591\n0,1,17,37,1.376,94.911\n0,2,17,2,1.313,97.901\n0,2,17,7,1.478,105.412\n0,2,17,43,1.207,108.882\n0,3,17,7,1.513,103.431\n0,6,17,6,2.164,97.766\n0,6,17,7,1.850,107.431\n0,7,17,8,1.438,113.808\n0,7,17,10,1.525,110.549\n0,7,17,20,1.442,104.737\n0,7,17,22,1.449,104.928\n0,7,17,37,1.500,104.313\n4,8,17,20,1.891,78.354\n0,8,17,37,1.687,91.169\n0,37,17,37,1.487,91.633\n0,0,18,0,0.000,104.600\n4,0,18,0,0.000,80.300\n0,1,18,1,1.230,101.166\n0,1,18,2,1.264,100.420\n0,1,18,3,1.242,100.883\n0,1,18,6,1.744,95.671\n0,1,18,9,1.438,99.465\n0,1,18,20,1.224,101.315\n0,1,18,22,1.207,101.417\n0,1,18,32,1.446,107.066\n0,1,18,37,1.234,101.070\n0,1,18,43,1.449,98.014\n0,1,18,48,1.277,106.586\n0,1,18,62,1.374,102.402\n0,2,18,2,1.254,101.492\n0,2,18,6,1.664,98.668\n0,2,18,9,1.539,96.849\n0,2,18,32,1.422,108.979\n0,2,18,37,1.263,100.489\n0,2,18,48,1.083,116.668\n0,3,18,9,1.418,100.361\n0,3,18,32,1.557,103.453\n0,3,18,43,1.350,101.747\n0,6,18,6,1.922,103.052\n0,6,18,9,1.916,97.446\n0,6,18,32,1.837,108.063\n0,6,18,37,1.528,102.229\n0,6,18,43,1.644,103.815\n0,9,18,12,1.464,101.180\n0,9,18,32,1.583,109.945\n0,9,18,37,1.358,102.378\n0,9,18,43,1.323,109.227\n0,12,18,32,1.584,103.959\n0,12,18,37,1.376,98.976\n0,15,18,32,1.497,107.170\n0,15,18,37,1.324,101.399\n0,20,18,32,1.383,109.292\n0,20,18,37,1.108,106.508\n4,20,18,43,1.831,80.297\n0,22,18,32,1.465,105.247\n0,32,18,32,1.569,120.924\n0,32,18,37,1.497,105.280\n0,32,18,39,1.804,101.600\n0,32,18,43,1.569,108.548\n0,32,18,48,1.229,126.841\n0,32,18,55,1.509,112.548\n0,32,18,58,1.592,106.139\n0,32,18,62,1.326,121.426\n0,32,18,63,1.571,103.212\n0,32,18,64,1.634,101.771\n0,32,18,80,1.400,110.401\n0,37,18,37,1.157,104.380\n0,37,18,39,1.404,99.854\n0,37,18,43,1.416,99.200\n0,37,18,48,1.330,104.466\n0,37,18,55,1.397,100.926\n0,37,18,62,1.178,110.665\n0,37,18,63,1.202,102.735\n0,43,18,43,1.545,99.905\n0,43,18,64,1.285,104.868\n0,0,19,0,0.000,108.700\n4,0,19,0,0.000,89.900\n0,1,19,1,0.616,113.339\n0,1,19,5,0.390,110.795\n0,1,19,6,0.777,113.958\n0,1,19,8,0.716,111.521\n0,1,19,9,0.779,106.380\n0,1,19,12,0.729,108.947\n0,1,19,20,0.656,108.828\n0,1,19,40,0.754,108.858\n0,1,19,63,0.699,106.924\n0,1,19,75,0.530,111.633\n0,2,19,12,0.819,102.981\n0,5,19,5,0.258,108.699\n0,5,19,6,0.520,109.677\n0,5,19,8,0.461,109.070\n0,5,19,12,0.446,106.756\n0,6,19,6,1.051,111.280\n0,6,19,12,0.968,106.022\n0,6,19,37,0.870,108.096\n0,8,19,8,0.862,108.099\n0,8,19,12,0.786,110.683\n0,12,19,12,0.879,104.597\n0,15,19,15,0.816,108.681\n4,20,19,20,0.802,89.931\n0,37,19,37,0.726,105.045\n0,0,20,0,0.000,113.200\n4,0,20,0,0.000,88.800\n0,1,20,1,0.943,113.131\n0,1,20,3,0.906,114.940\n0,1,20,5,0.417,114.057\n0,1,20,6,1.231,110.677\n0,1,20,8,1.080,111.090\n0,1,20,10,1.100,110.057\n0,1,20,11,1.173,110.993\n0,1,20,12,0.976,114.773\n0,1,20,15,1.035,111.226\n0,1,20,18,0.978,115.383\n0,1,20,20,0.502,113.313\n0,1,20,22,0.915,115.201\n0,1,20,25,0.744,116.096\n0,1,20,26,0.721,117.611\n0,1,20,30,0.908,115.220\n0,1,20,34,1.090,110.505\n0,1,20,37,0.947,112.650\n0,1,20,41,0.973,111.787\n0,1,20,43,1.087,110.187\n0,1,20,45,1.132,108.074\n0,2,20,3,0.982,111.060\n0,2,20,5,0.596,113.035\n0,2,20,6,1.139,115.851\n0,2,20,12,0.951,116.750\n0,2,20,20,0.931,114.138\n0,3,20,3,0.982,109.919\n0,3,20,5,0.624,112.989\n0,3,20,6,1.157,113.611\n4,3,20,8,1.473,87.271\n0,3,20,10,1.016,113.988\n0,3,20,11,1.184,109.849\n0,3,20,12,0.969,114.891\n0,3,20,13,1.008,110.951\n0,3,20,20,0.849,118.273\n4,3,20,20,1.524,88.961\n0,3,20,34,1.137,107.667\n4,3,20,37,1.382,85.619\n0,3,20,43,0.960,116.707\n0,4,20,5,0.584,115.078\n0,4,20,20,0.920,115.312\n0,5,20,5,0.439,109.107\n0,5,20,6,0.818,111.352\n0,5,20,8,0.728,114.011\n0,5,20,9,0.657,112.826\n0,5,20,10,0.663,112.010\n0,5,20,12,0.339,114.117\n0,5,20,15,0.562,114.339\n0,5,20,17,0.561,113.000\n0,5,20,18,0.605,111.570\n0,5,20,20,0.564,113.940\n0,5,20,26,0.472,109.722\n0,5,20,30,0.688,116.038\n0,5,20,34,0.661,112.000\n0,5,20,37,0.552,115.670\n0,5,20,40,0.682,111.331\n0,5,20,43,0.655,111.686\n0,6,20,6,1.443,114.408\n0,6,20,10,1.225,116.666\n0,6,20,13,1.162,114.868\n0,6,20,20,1.109,116.117\n4,6,20,20,1.433,93.413\n0,6,20,22,1.106,117.205\n0,6,20,30,1.144,114.705\n4,6,20,30,1.658,87.873\n0,8,20,20,1.185,105.606\n4,8,20,20,1.486,91.244\n0,8,20,26,0.874,111.782\n0,9,20,20,1.103,109.640\n0,10,20,15,1.170,109.525\n0,10,20,17,1.127,110.564\n0,10,20,18,1.404,100.845\n0,10,20,20,1.032,113.170\n4,10,20,20,1.468,87.497\n4,10,20,30,1.507,86.657\n0,10,20,37,0.963,117.360\n0,11,20,11,1.504,108.020\n0,11,20,17,1.221,109.460\n0,11,20,20,1.051,116.673\n0,11,20,30,0.997,120.309\n0,12,20,12,1.020,117.603\n0,12,20,19,0.973,105.821\n0,12,20,20,0.866,118.108\n0,12,20,30,0.887,120.399\n0,13,20,13,1.077,113.361\n0,13,20,20,0.938,115.037\n0,14,20,20,0.837,112.888\n0,15,20,15,1.094,114.048\n0,15,20,20,1.058,109.793\n4,15,20,20,1.324,90.483\n0,15,20,30,0.960,115.468\n4,15,20,30,1.447,86.726\n4,17,20,17,1.309,94.977\n0,17,20,20,0.930,116.108\n0,18,20,20,1.007,113.480\n4,18,20,20,1.355,90.185\n0,18,20,41,1.241,102.656\n0,19,20,19,0.567,122.298\n4,19,20,19,0.921,88.477\n0,20,20,20,1.008,108.644\n4,20,20,20,1.149,90.294\n0,20,20,22,0.840,119.817\n4,20,20,22,1.364,86.669\n4,20,20,25,1.181,84.818\n0,20,20,30,0.994,109.745\n4,20,20,30,1.399,85.303\n0,20,20,34,1.069,111.143\n4,20,20,34,1.382,90.128\n0,20,20,37,0.833,119.709\n4,20,20,37,1.346,86.810\n0,20,20,40,1.097,110.254\n0,20,20,41,0.922,114.408\n0,20,20,43,0.964,116.540\n4,20,20,43,1.290,92.879\n0,20,20,45,1.083,110.090\n0,22,20,22,0.866,118.829\n4,22,20,22,1.649,79.399\n4,26,20,26,0.789,96.811\n0,26,20,34,0.843,113.805\n0,34,20,41,1.070,111.943\n0,37,20,43,0.954,117.365\n0,0,22,0,0.000,116.100\n3,0,22,0,0.000,59.400\n4,0,22,0,0.000,91.600\n0,1,22,1,0.903,116.483\n0,1,22,2,0.884,118.360\n0,1,22,3,0.836,121.424\n0,1,22,4,0.900,117.720\n0,1,22,5,0.604,111.788\n0,1,22,6,1.179,113.545\n0,1,22,8,0.973,117.469\n0,1,22,17,1.070,109.087\n0,1,22,18,1.097,108.265\n0,1,22,22,0.871,118.246\n0,1,22,37,0.882,118.041\n0,1,22,43,1.014,114.899\n3,2,22,2,0.263,48.820\n0,2,22,3,0.956,114.147\n0,2,22,4,0.784,126.957\n0,2,22,5,0.573,115.869\n0,2,22,6,1.012,123.319\n0,2,22,22,0.880,118.260\n3,2,22,22,0.166,60.845\n0,2,22,45,1.009,116.146\n0,3,22,3,0.819,122.977\n0,3,22,4,0.876,119.718\n0,3,22,5,0.559,116.738\n0,3,22,6,1.184,113.646\n0,3,22,8,1.072,112.261\n0,3,22,10,0.987,117.750\n0,3,22,12,0.930,118.047\n4,3,22,20,1.267,90.869\n0,3,22,22,0.861,119.252\n4,3,22,22,1.196,93.287\n4,3,22,30,1.301,89.217\n0,3,22,37,0.852,120.464\n0,3,22,40,1.033,114.288\n0,3,22,43,1.124,109.441\n0,3,22,45,1.117,110.033\n0,4,22,5,0.560,118.000\n0,4,22,6,1.200,113.650\n0,4,22,8,0.966,119.034\n0,4,22,15,0.931,120.455\n0,4,22,22,0.877,118.890\n0,4,22,45,1.089,112.227\n0,5,22,5,0.242,114.938\n0,5,22,6,0.683,117.836\n0,5,22,8,0.621,115.758\n0,5,22,10,0.658,113.806\n0,5,22,11,0.776,108.296\n0,5,22,12,0.620,109.865\n0,5,22,20,0.623,110.000\n0,5,22,22,0.583,117.875\n0,5,22,37,0.532,119.438\n0,5,22,40,0.653,112.855\n0,5,22,41,0.519,122.000\n0,5,22,43,0.658,112.128\n0,5,22,45,0.665,112.000\n0,6,22,12,1.136,118.409\n0,6,22,17,1.328,108.583\n0,6,22,18,1.381,107.009\n0,6,22,22,1.124,115.942\n3,6,22,22,0.205,60.711\n0,6,22,37,1.093,118.170\n3,6,22,43,0.179,68.138\n0,6,22,45,1.422,108.368\n0,8,22,22,0.925,120.144\n3,8,22,22,0.176,61.507\n0,10,22,22,0.916,121.411\n3,10,22,22,0.184,60.603\n0,11,22,11,1.610,102.859\n0,11,22,22,1.062,116.086\n0,12,22,12,1.067,114.988\n0,12,22,22,0.925,117.971\n0,13,22,13,1.085,113.473\n0,13,22,22,0.908,117.606\n0,15,22,22,0.918,120.404\n0,17,22,22,1.029,111.106\n0,18,22,22,1.078,109.054\n0,20,22,22,0.812,122.430\n4,20,22,22,1.198,92.930\n0,22,22,22,0.787,124.070\n3,22,22,22,0.171,60.000\n4,22,22,22,1.225,91.653\n0,22,22,30,0.777,124.514\n0,22,22,34,0.983,116.415\n0,22,22,37,0.847,120.135\n3,22,22,40,0.178,61.163\n0,22,22,41,0.886,118.045\n3,22,22,43,0.176,61.536\n0,22,22,45,1.022,114.380\n0,34,22,41,1.008,116.095\n0,37,22,37,0.846,120.774\n3,37,22,37,0.237,51.029\n0,37,22,43,0.936,119.789\n0,0,25,0,0.000,106.500\n4,0,25,0,0.000,89.100\n0,1,25,1,1.072,99.158\n0,1,25,3,1.268,91.423\n0,1,25,6,1.394,98.288\n0,1,25,8,1.150,101.775\n0,1,25,12,1.180,98.890\n0,1,25,15,1.074,103.431\n0,1,25,25,0.852,100.707\n0,1,25,32,1.186,107.891\n0,1,25,37,0.972,104.924\n0,1,25,40,1.358,93.644\n0,1,25,43,1.190,98.760\n0,1,25,71,0.537,109.363\n0,1,25,72,0.976,111.306\n0,2,25,6,1.302,102.892\n0,2,25,8,1.022,109.148\n0,2,25,10,1.629,85.839\n0,2,25,32,0.983,120.127\n0,2,25,72,0.863,119.249\n0,3,25,6,1.277,103.026\n0,3,25,32,1.164,109.307\n0,6,25,6,1.769,99.311\n0,6,25,8,1.419,104.161\n0,6,25,9,1.403,105.407\n0,6,25,10,1.448,102.194\n0,6,25,11,1.680,99.260\n0,6,25,12,1.489,98.818\n0,6,25,32,1.501,109.688\n0,6,25,37,1.312,102.280\n0,6,25,39,1.617,97.314\n0,6,25,40,1.380,105.601\n0,6,25,71,0.844,100.242\n0,6,25,72,1.219,112.058\n0,8,25,8,1.224,105.341\n0,8,25,10,1.214,104.893\n0,8,25,11,1.411,101.655\n0,8,25,20,1.010,108.094\n0,8,25,32,1.217,114.325\n0,8,25,37,1.106,104.742\n0,8,25,40,1.265,103.617\n0,8,25,72,0.977,117.767\n0,9,25,32,1.232,114.493\n0,10,25,10,1.346,98.856\n0,10,25,32,1.273,110.640\n0,10,25,72,1.021,114.624\n0,11,25,32,1.528,106.045\n0,12,25,12,1.303,99.224\n0,12,25,32,1.305,106.320\n0,15,25,15,1.113,107.673\n4,15,25,15,1.264,93.138\n0,15,25,32,1.248,107.964\n0,15,25,72,0.933,119.729\n4,20,25,20,1.220,85.039\n0,20,25,72,0.965,111.595\n0,25,25,72,0.890,106.612\n0,32,25,32,1.248,122.857\n0,32,25,37,1.097,113.430\n0,32,25,39,1.605,99.255\n0,32,25,40,1.122,119.057\n0,32,25,43,1.257,110.308\n0,32,25,57,1.219,108.740\n0,32,25,63,1.211,108.168\n0,32,25,71,0.642,117.733\n0,32,25,72,1.050,121.823\n0,37,25,37,0.947,107.124\n0,37,25,40,0.965,112.107\n0,37,25,72,0.868,118.776\n0,40,25,40,1.496,95.270\n0,40,25,72,1.035,114.441\n0,57,25,57,1.059,102.995\n0,63,25,63,1.032,102.950\n0,71,25,71,0.419,100.483\n0,0,26,0,0.000,98.100\n4,0,26,0,0.000,83.600\n0,1,26,1,1.085,98.054\n0,1,26,8,1.263,96.331\n0,1,26,10,1.115,102.175\n0,1,26,12,1.147,98.926\n0,1,26,15,1.141,100.260\n0,1,26,20,1.075,98.171\n0,1,26,26,0.997,92.571\n0,1,26,37,1.081,98.754\n0,1,26,71,0.672,97.353\n0,6,26,6,1.833,97.935\n0,6,26,11,1.663,100.061\n0,6,26,12,1.442,99.021\n0,8,26,8,1.189,105.662\n0,8,26,12,1.028,110.069\n0,8,26,34,1.509,93.096\n0,11,26,11,1.757,94.795\n0,12,26,15,1.271,99.730\n0,12,26,34,1.508,90.565\n0,12,26,40,1.165,103.783\n0,12,26,71,0.704,96.577\n0,15,26,26,1.047,96.592\n0,15,26,40,1.543,91.164\n4,20,26,20,1.252,83.624\n0,71,26,71,0.473,94.470\n0,0,30,0,0.000,134.200\n1,0,30,0,0.000,131.800\n4,0,30,0,0.000,97.700\n7,0,30,0,0.000,92.300\n1,2,30,3,0.778,128.756\n0,2,30,15,0.805,130.439\n0,2,30,20,0.727,132.187\n0,2,30,22,0.737,131.100\n1,2,30,30,0.751,132.225\n1,3,30,4,0.721,134.566\n1,3,30,5,0.410,135.975\n1,3,30,6,0.845,137.596\n1,3,30,20,0.714,130.677\n7,3,30,20,1.280,89.957\n1,3,30,30,0.857,122.418\n7,3,30,30,1.260,93.102\n0,4,30,20,0.690,136.444\n0,5,30,20,0.390,131.835\n0,5,30,30,0.364,132.652\n0,6,30,30,0.876,139.045\n0,15,30,15,0.876,130.718\n4,15,30,15,1.239,101.359\n0,15,30,30,0.782,132.228\n4,15,30,30,1.141,100.902\n4,20,30,30,1.117,95.513\n7,20,30,30,1.191,93.909\n0,20,30,40,0.769,134.526\n1,20,30,67,0.704,138.631\n4,22,30,22,1.179,93.007\n8,30,30,30,1.230,93.732\n0,30,30,40,0.706,145.470\n1,30,30,67,0.907,125.792\n0,0,34,0,0.000,109.400\n4,0,34,0,0.000,89.400\n0,1,34,1,0.862,112.251\n0,1,34,2,1.154,109.212\n0,1,34,8,1.330,106.399\n0,1,34,9,1.166,112.989\n0,1,34,10,1.388,104.291\n0,1,34,20,1.201,106.135\n0,1,34,26,0.913,112.004\n0,1,34,36,0.576,111.206\n0,1,34,37,1.141,109.045\n0,2,34,36,0.694,112.000\n0,8,34,36,0.796,109.753\n0,9,34,36,0.793,108.649\n0,10,34,36,0.828,108.000\n4,20,34,20,1.448,89.411\n0,20,34,36,0.665,112.526\n0,22,34,36,0.694,110.000\n0,36,34,36,0.578,107.787\n0,36,34,37,0.717,108.668\n0,36,34,43,0.840,108.000\n0,0,37,0,0.000,118.800\n1,0,37,0,0.000,115.900\n3,0,37,0,0.000,64.700\n4,0,37,0,0.000,91.800\n0,1,37,37,0.803,120.419\n0,1,37,38,0.992,118.432\n0,1,37,58,1.027,116.528\n0,1,37,63,0.837,123.024\n0,1,37,64,0.821,124.073\n0,1,37,69,1.038,115.506\n1,2,37,37,0.712,119.695\n1,2,37,38,1.029,117.220\n1,3,37,37,0.798,114.475\n7,3,37,37,1.320,90.784\n1,3,37,38,1.109,112.724\n1,3,37,58,1.134,111.566\n1,3,37,69,1.119,111.916\n1,4,37,37,0.906,119.614\n1,4,37,38,1.087,114.623\n0,5,37,37,0.563,120.571\n0,5,37,38,0.693,115.588\n0,5,37,58,0.699,113.316\n0,5,37,63,0.702,121.238\n0,5,37,64,0.523,121.446\n0,5,37,69,0.794,111.638\n0,5,37,78,0.563,119.432\n0,6,37,37,0.968,116.495\n0,6,37,38,1.324,115.886\n0,6,37,64,1.139,118.868\n1,9,37,37,0.974,121.003\n1,9,37,38,1.137,117.591\n0,10,37,37,1.025,117.918\n0,10,37,38,1.088,120.135\n0,10,37,58,1.077,120.925\n0,11,37,37,1.094,118.065\n0,11,37,38,1.223,117.328\n0,12,37,37,0.950,118.495\n0,12,37,38,1.126,113.859\n0,12,37,64,1.076,111.320\n0,13,37,37,0.917,118.117\n0,14,37,37,0.861,118.045\n0,15,37,37,0.755,121.037\n0,15,37,38,1.027,119.421\n0,15,37,64,0.976,117.125\n0,17,37,37,0.930,119.408\n0,17,37,38,1.179,110.828\n0,17,37,64,0.946,118.357\n0,18,37,37,1.029,113.991\n0,18,37,38,1.278,106.908\n0,18,37,64,0.975,117.029\n0,19,37,37,0.660,125.278\n0,20,37,37,0.744,129.614\n4,20,37,37,1.217,93.425\n0,22,37,37,0.805,125.777\n3,22,37,37,0.152,64.704\n0,22,37,38,0.904,124.494\n0,25,37,37,0.718,121.600\n0,26,37,37,0.691,122.967\n0,34,37,37,1.030,116.423\n0,34,37,64,1.074,113.905\n0,35,37,37,0.964,131.858\n0,35,37,38,1.187,124.980\n0,37,37,37,0.669,119.977\n1,37,37,37,0.864,122.227\n4,37,37,37,1.380,90.193\n0,37,37,38,0.596,126.139\n1,37,37,38,1.033,117.271\n0,37,37,39,1.038,117.619\n1,37,37,39,1.078,114.622\n0,37,37,40,1.045,121.633\n0,37,37,41,0.892,119.572\n0,37,37,43,1.013,117.860\n0,37,37,45,1.114,112.337\n0,37,37,46,0.999,120.038\n0,37,37,55,1.002,120.163\n0,37,37,56,1.020,117.801\n1,37,37,57,0.881,120.932\n0,37,37,58,1.014,120.052\n1,37,37,58,1.127,112.251\n0,37,37,61,1.072,115.515\n0,37,37,62,0.941,124.384\n0,37,37,63,0.478,111.243\n1,37,37,63,0.894,120.190\n0,37,37,64,0.423,112.567\n1,37,37,64,0.912,118.973\n1,37,37,67,1.064,114.980\n0,37,37,69,0.872,116.778\n1,37,37,69,1.042,116.438\n0,37,37,78,0.974,116.439\n0,37,37,81,1.034,115.664\n1,37,37,81,1.104,111.759\n0,38,37,38,0.725,128.938\n0,38,37,40,1.024,123.755\n0,38,37,43,1.165,115.355\n0,38,37,58,0.979,128.362\n1,38,37,58,1.257,111.356\n0,38,37,62,1.148,118.349\n0,38,37,63,1.095,115.386\n1,38,37,63,1.076,114.910\n0,38,37,64,1.070,116.605\n1,38,37,67,1.289,109.610\n0,40,37,58,1.103,119.417\n0,40,37,63,0.943,122.904\n0,40,37,64,0.931,123.541\n0,40,37,78,0.931,123.604\n0,41,37,58,0.967,120.535\n0,45,37,63,1.031,116.781\n0,45,37,64,1.156,110.199\n0,45,37,69,1.248,111.041\n0,58,37,62,1.016,125.987\n0,58,37,63,1.152,112.628\n0,58,37,64,1.291,106.250\n1,58,37,64,1.108,113.166\n0,58,37,78,1.188,110.842\n0,0,38,0,0.000,113.800\n0,37,38,37,1.085,115.406\n0,37,38,38,1.289,112.016\n0,37,38,63,1.230,110.181\n0,37,38,64,1.207,111.032\n0,37,38,69,1.238,114.692\n0,37,38,78,1.118,114.813\n0,38,38,38,1.343,118.516\n0,0,39,0,0.000,120.700\n1,0,39,0,0.000,125.400\n0,1,39,63,0.854,123.380\n0,1,39,65,1.111,118.049\n1,2,39,63,0.858,130.275\n1,2,39,65,0.900,133.220\n1,3,39,63,0.900,127.045\n1,3,39,65,1.126,118.909\n0,6,39,63,1.166,122.985\n0,6,39,65,1.396,117.707\n0,8,39,63,1.000,124.868\n0,8,39,65,1.057,127.145\n1,9,39,63,0.981,127.725\n1,9,39,65,1.170,122.487\n0,10,39,63,1.109,119.788\n0,10,39,65,1.118,124.961\n0,18,39,63,1.108,117.061\n0,23,39,63,0.551,127.770\n0,23,39,65,0.752,118.352\n0,23,39,78,0.581,124.000\n0,25,39,63,0.667,134.561\n0,25,39,65,0.944,118.135\n0,37,39,63,0.900,127.009\n1,37,39,63,0.922,125.312\n1,37,39,65,1.080,121.090\n0,40,39,63,0.984,126.832\n0,45,39,63,1.056,121.641\n0,45,39,65,1.354,112.464\n0,63,39,63,1.152,109.599\n1,63,39,63,0.887,128.078\n0,63,39,64,1.004,120.577\n1,63,39,64,0.899,126.936\n0,63,39,65,1.284,112.087\n1,63,39,65,1.146,117.990\n0,63,39,78,1.300,105.800\n0,64,39,65,1.007,126.117\n0,65,39,65,1.462,116.898\n0,0,40,0,0.000,115.000\n3,0,40,0,0.000,57.800\n0,1,40,1,1.064,113.703\n0,1,40,2,0.998,118.873\n0,1,40,3,1.007,118.319\n0,1,40,6,1.421,109.742\n0,1,40,9,1.203,113.198\n0,1,40,10,1.232,111.320\n0,1,40,11,1.436,104.665\n0,1,40,12,1.202,109.320\n0,1,40,20,1.047,114.970\n0,1,40,25,0.912,114.483\n0,1,40,28,0.689,112.374\n0,1,40,30,1.024,118.604\n0,1,40,37,0.835,107.349\n0,1,40,39,1.254,110.622\n0,1,40,40,1.183,114.011\n0,1,40,45,1.223,112.226\n0,1,40,46,1.025,122.982\n0,1,40,63,1.084,114.473\n0,1,40,64,1.064,115.483\n0,2,40,2,0.997,120.651\n0,2,40,3,0.981,121.660\n0,2,40,6,1.316,115.626\n0,2,40,9,1.118,119.196\n0,2,40,10,1.142,117.260\n0,2,40,19,0.732,128.087\n0,2,40,28,0.767,111.053\n0,2,40,37,1.049,117.022\n0,2,40,39,1.192,115.106\n0,2,40,40,1.060,122.253\n0,2,40,63,1.008,120.447\n0,3,40,3,0.883,128.240\n0,3,40,8,1.259,111.557\n0,3,40,9,1.106,119.822\n0,3,40,10,1.269,111.261\n0,3,40,12,1.146,112.718\n0,3,40,15,1.105,117.871\n0,3,40,20,1.130,112.139\n0,3,40,22,1.072,114.420\n0,3,40,25,0.820,121.724\n0,3,40,28,0.700,114.808\n0,3,40,37,1.056,116.655\n0,3,40,40,1.147,117.511\n0,3,40,64,1.132,113.602\n0,6,40,28,0.889,110.000\n0,8,40,28,0.764,111.915\n0,8,40,37,1.216,112.920\n0,8,40,63,1.351,108.085\n0,9,40,28,0.774,112.549\n0,9,40,37,1.236,112.751\n0,10,40,28,0.799,109.725\n0,10,40,37,1.316,108.686\n0,11,40,37,1.546,101.687\n0,15,40,15,1.154,121.497\n3,22,40,22,0.204,57.777\n0,22,40,37,1.066,114.220\n0,22,40,63,1.126,112.006\n0,25,40,28,0.485,120.000\n0,25,40,37,0.868,117.977\n0,26,40,28,0.506,118.000\n0,26,40,37,0.812,122.336\n0,28,40,28,0.560,109.160\n0,28,40,30,0.656,119.230\n0,28,40,37,0.662,110.288\n0,28,40,39,0.789,110.951\n0,28,40,40,0.782,111.731\n0,28,40,45,0.674,120.000\n0,28,40,54,0.738,118.714\n0,28,40,63,0.670,116.188\n0,28,40,64,0.659,117.057\n0,28,40,78,0.618,119.829\n0,37,40,37,1.004,119.018\n0,37,40,45,1.376,106.579\n0,37,40,54,1.394,107.777\n0,37,40,63,1.060,116.867\n0,45,40,64,1.283,111.332\n0,45,40,78,1.410,105.678\n0,46,40,64,1.189,116.345\n0,0,41,0,0.000,118.300\n0,1,41,32,1.209,114.689\n0,1,41,72,1.024,114.936\n0,2,41,32,1.309,115.461\n0,3,41,32,1.210,114.810\n0,5,41,32,0.912,113.960\n0,6,41,72,1.319,113.899\n0,9,41,72,1.089,117.795\n0,10,41,72,1.039,121.240\n0,20,41,32,1.090,120.965\n0,22,41,32,1.079,122.748\n0,32,41,32,1.181,130.600\n0,32,41,37,1.136,118.871\n0,32,41,41,1.401,107.694\n0,37,41,72,1.035,114.919\n0,55,41,72,0.982,123.972\n0,62,41,72,1.052,120.425\n0,72,41,72,0.912,130.128\n0,72,41,80,1.094,112.175\n0,0,43,0,0.000,113.300\n0,1,43,1,1.109,110.353\n0,1,43,2,1.052,114.321\n0,1,43,3,0.938,121.050\n0,1,43,4,0.927,123.204\n0,1,43,18,1.116,115.011\n0,1,43,25,0.853,115.637\n0,1,43,28,0.646,113.739\n0,1,43,37,1.083,112.511\n0,1,43,45,1.140,115.034\n0,1,43,64,1.025,116.188\n0,2,43,18,1.227,110.268\n0,3,43,18,1.011,121.488\n0,3,43,20,1.053,113.913\n4,3,43,20,1.327,93.575\n0,3,43,28,0.626,117.464\n0,4,43,28,0.616,122.000\n0,4,43,45,1.253,112.373\n0,6,43,18,1.673,104.311\n3,6,43,22,0.279,54.827\n0,6,43,28,0.868,110.000\n0,6,43,37,1.519,105.833\n0,6,43,43,1.603,108.652\n0,8,43,18,1.511,104.036\n0,8,43,28,0.794,110.320\n0,15,43,15,1.558,103.008\n0,15,43,18,1.409,108.458\n0,17,43,18,1.367,111.904\n0,18,43,18,1.144,120.463\n0,18,43,20,0.961,123.768\n4,18,43,20,1.451,92.867\n0,18,43,22,1.171,112.379\n0,18,43,28,0.628,116.881\n0,18,43,34,1.324,111.347\n0,18,43,37,1.185,112.132\n0,18,43,43,1.379,109.036\n0,18,43,64,1.108,116.279\n0,20,43,28,0.626,115.000\n3,22,43,22,0.209,57.032\n0,25,43,28,0.468,118.274\n0,28,43,28,0.477,112.596\n0,28,43,34,0.810,110.000\n0,28,43,37,0.669,113.350\n0,28,43,64,0.658,115.293\n0,0,44,0,0.000,91.600\n0,63,44,63,1.962,88.495\n0,63,44,65,2.261,94.137\n0,63,44,78,1.738,86.270\n0,63,44,80,1.748,86.194\n0,65,44,65,1.530,101.147\n0,65,44,80,1.629,93.534\n0,78,44,78,0.903,119.401\n0,0,45,0,0.000,116.700\n0,1,45,32,1.260,118.182\n0,2,45,32,1.294,118.082\n0,3,45,32,1.343,115.589\n0,6,45,32,1.787,111.682\n0,8,45,32,1.515,115.695\n0,9,45,32,1.339,123.850\n0,10,45,32,1.578,112.194\n0,20,45,32,1.245,118.893\n0,22,45,32,1.293,117.503\n0,32,45,32,1.467,128.036\n0,32,45,37,1.298,117.857\n0,32,45,39,1.715,107.633\n0,32,45,40,1.497,116.432\n0,32,45,43,1.545,113.711\n0,32,45,63,1.335,116.765\n0,32,45,64,1.330,116.908\n0,32,45,78,1.394,114.962\n0,0,46,0,0.000,111.000\n0,1,46,7,1.440,110.492\n0,2,46,7,1.489,112.709\n0,7,46,8,1.724,109.817\n0,7,46,37,1.519,110.569\n0,7,46,40,1.650,111.405\n0,0,48,0,0.000,118.400\n0,3,48,18,1.065,122.928\n0,18,48,28,0.736,113.969\n0,0,49,0,0.000,111.400\n0,50,49,50,0.522,111.433\n0,0,51,0,0.000,111.400\n0,3,51,52,0.913,111.360\n0,0,53,0,0.000,180.000\n0,3,53,47,0.574,180.000\n0,9,53,47,0.649,180.000\n0,0,54,0,0.000,119.500\n1,0,54,0,0.000,115.700\n0,1,54,1,0.923,121.439\n0,1,54,3,0.707,124.083\n0,1,54,36,0.294,122.881\n0,3,54,6,1.376,115.398\n1,3,54,9,1.128,114.457\n0,3,54,36,0.685,119.698\n1,3,54,40,1.105,116.439\n0,6,54,36,0.826,115.000\n0,9,54,40,1.195,123.403\n0,36,54,36,0.300,113.943\n0,0,55,0,0.000,120.800\n0,1,55,1,0.951,119.946\n0,1,55,36,0.307,126.448\n0,1,55,37,1.032,117.035\n0,1,55,57,0.751,120.606\n0,1,55,80,0.972,121.082\n0,2,55,3,1.041,116.994\n0,2,55,36,0.621,120.000\n0,2,55,57,1.047,118.847\n0,3,55,9,1.053,121.298\n0,3,55,36,0.567,124.000\n0,3,55,57,0.953,123.573\n0,3,55,62,1.041,122.163\n0,6,55,36,0.833,114.000\n0,6,55,57,1.408,112.958\n0,8,55,36,0.656,122.000\n0,8,55,57,1.259,113.209\n0,9,55,57,1.001,126.373\n0,18,55,36,0.578,125.000\n0,18,55,57,1.054,122.320\n0,36,55,36,0.355,117.729\n0,36,55,37,0.623,120.405\n0,36,55,41,0.485,134.689\n0,36,55,57,0.663,119.499\n0,36,55,64,0.632,118.000\n0,36,55,80,0.684,115.880\n0,37,55,57,1.110,115.816\n0,41,55,57,0.911,126.801\n0,57,55,62,1.054,123.366\n0,57,55,64,1.026,119.465\n0,0,56,0,0.000,119.100\n0,1,56,36,0.472,123.585\n0,1,56,57,0.774,119.267\n0,2,56,9,1.181,116.311\n0,2,56,36,0.582,124.037\n0,2,56,57,1.029,118.607\n0,3,56,36,0.585,121.521\n0,3,56,57,0.885,126.567\n0,8,56,36,0.785,111.009\n0,8,56,57,1.288,110.357\n0,9,56,36,0.683,120.258\n0,9,56,57,1.186,115.661\n0,36,56,36,0.450,117.534\n0,36,56,37,0.602,120.000\n0,36,56,57,0.646,120.649\n0,36,56,63,0.579,123.766\n0,36,56,80,0.625,120.000\n0,37,56,57,1.058,115.912\n0,57,56,63,1.019,118.915\n0,0,57,0,0.000,120.900\n1,0,57,0,0.000,118.100\n0,1,57,55,1.017,117.865\n1,3,57,55,1.085,115.034\n0,5,57,55,0.674,116.747\n0,6,57,55,1.279,119.257\n1,9,57,55,0.980,128.143\n0,12,57,55,1.058,118.327\n0,15,57,55,0.983,123.646\n0,25,57,55,0.790,122.889\n1,37,57,55,0.967,121.379\n0,55,57,55,0.855,126.476\n1,55,57,63,1.016,118.800\n1,55,57,64,1.039,117.166\n0,56,57,56,1.342,120.010\n0,0,58,0,0.000,119.000\n1,0,58,0,0.000,119.900\n0,1,58,37,1.003,119.236\n0,1,58,64,0.961,121.070\n1,3,58,37,0.983,121.506\n0,6,58,37,1.371,114.370\n0,18,58,37,1.005,120.665\n0,36,58,37,0.650,118.713\n0,36,58,63,0.650,118.000\n0,36,58,64,0.620,120.051\n0,37,58,37,0.996,122.710\n1,37,58,37,1.036,118.260\n0,37,58,63,1.087,116.989\n0,37,58,64,1.061,117.942\n0,0,59,0,0.000,105.600\n0,63,59,63,1.273,106.313\n0,63,59,65,1.750,107.755\n0,63,59,78,1.713,101.179\n0,63,59,80,1.599,105.341\n0,65,59,65,1.754,107.683\n0,65,59,78,1.644,107.142\n0,65,59,82,1.864,103.624\n0,0,61,0,0.000,180.000\n0,1,61,60,0.475,180.000\n0,37,61,42,0.536,180.000\n0,37,61,60,0.484,180.000\n0,0,62,0,0.000,108.300\n0,1,62,18,1.316,109.273\n0,2,62,23,0.817,105.542\n0,3,62,3,1.318,106.821\n0,3,62,18,1.311,111.144\n0,3,62,55,1.528,102.414\n0,9,62,18,1.515,107.660\n0,18,62,37,1.229,114.618\n0,18,62,41,1.366,108.722\n0,18,62,63,1.427,106.284\n0,18,62,64,1.317,110.366\n0,0,63,0,0.000,123.300\n1,0,63,0,0.000,124.300\n0,1,63,39,0.935,121.832\n0,1,63,44,0.902,122.101\n0,1,63,59,1.175,115.253\n0,1,63,64,0.737,131.378\n0,1,63,66,0.865,127.610\n1,2,63,39,1.027,117.864\n1,2,63,59,0.987,127.524\n1,2,63,64,0.730,133.818\n1,2,63,66,0.828,132.383\n1,3,63,39,0.900,125.395\n1,3,63,44,0.935,120.481\n1,3,63,59,1.158,117.219\n1,3,63,64,0.766,130.065\n1,3,63,66,0.950,123.049\n1,4,63,44,0.848,126.602\n1,4,63,59,1.211,114.804\n1,4,63,64,0.795,127.817\n0,5,63,39,0.617,121.127\n0,5,63,44,0.393,126.141\n0,5,63,59,0.784,114.076\n0,5,63,64,0.577,131.721\n0,5,63,66,0.643,125.134\n0,5,63,78,0.482,130.000\n0,5,63,81,0.588,124.000\n0,6,63,39,1.234,120.509\n0,6,63,59,1.564,113.514\n0,6,63,64,0.951,131.301\n1,9,63,39,1.068,121.741\n1,9,63,44,0.963,124.598\n1,9,63,64,0.804,134.237\n1,9,63,66,0.912,133.020\n0,10,63,39,1.084,120.356\n0,10,63,44,1.112,115.732\n0,10,63,59,1.307,116.218\n0,10,63,64,0.867,128.750\n0,10,63,66,0.981,127.617\n0,12,63,39,1.111,114.439\n0,12,63,44,1.035,119.321\n0,12,63,64,0.838,126.226\n0,12,63,66,0.980,122.280\n0,15,63,39,1.064,117.958\n0,15,63,44,0.952,125.654\n0,15,63,64,0.813,129.284\n0,15,63,66,0.962,124.490\n0,18,63,44,1.110,116.077\n0,18,63,64,0.740,135.028\n0,19,63,39,0.647,132.369\n0,19,63,64,0.517,141.986\n0,25,63,39,0.597,139.439\n0,25,63,66,0.776,122.699\n0,35,63,59,1.351,124.475\n0,35,63,64,0.808,145.098\n0,37,63,39,1.011,132.046\n1,37,63,39,0.934,123.481\n0,37,63,44,0.764,133.930\n1,37,63,44,0.915,121.637\n0,37,63,59,1.041,124.836\n1,37,63,59,1.214,114.211\n0,37,63,64,0.679,122.881\n1,37,63,64,0.742,131.784\n0,37,63,66,0.742,140.668\n1,37,63,66,0.871,128.130\n0,38,63,39,1.022,124.814\n0,38,63,64,0.910,126.513\n0,39,63,39,0.910,131.461\n1,39,63,39,1.105,119.174\n0,39,63,40,1.112,119.261\n1,39,63,44,1.144,114.126\n0,39,63,45,1.166,115.115\n1,39,63,57,0.931,123.222\n0,39,63,58,1.042,123.231\n1,39,63,63,0.949,122.353\n0,39,63,64,0.813,107.255\n1,39,63,64,0.943,123.441\n0,39,63,66,1.012,110.865\n1,39,63,66,1.095,120.834\n0,40,63,44,0.943,125.881\n0,40,63,59,1.298,117.078\n0,40,63,64,0.845,130.865\n0,40,63,66,0.940,130.926\n0,44,63,45,1.125,114.633\n0,44,63,56,1.030,120.178\n0,44,63,62,0.991,122.899\n1,44,63,63,0.894,123.341\n0,44,63,64,0.853,108.480\n0,44,63,66,0.854,114.516\n0,44,63,72,0.915,129.129\n0,44,63,78,1.217,106.254\n0,44,63,81,1.278,108.400\n0,45,63,59,1.467,108.824\n0,45,63,64,0.940,122.725\n0,45,63,66,1.164,116.157\n0,56,63,66,0.875,134.888\n1,57,63,66,0.945,123.246\n0,58,63,64,0.965,122.522\n0,59,63,64,1.035,110.108\n0,59,63,66,1.181,115.592\n0,62,63,66,0.976,128.662\n1,63,63,64,0.776,129.499\n1,63,63,66,0.929,124.689\n0,66,63,72,0.911,129.610\n0,0,64,0,0.000,121.400\n1,0,64,0,0.000,121.700\n0,1,64,63,0.776,128.041\n0,1,64,64,0.766,128.061\n0,1,64,65,0.963,120.640\n0,1,64,66,0.952,120.685\n0,1,64,81,1.050,114.735\n0,1,64,82,1.013,117.414\n1,2,64,63,0.861,122.947\n1,2,64,64,0.816,125.433\n1,2,64,65,0.907,125.781\n1,2,64,66,1.010,118.540\n1,2,64,82,0.923,124.473\n1,3,64,63,0.828,124.890\n1,3,64,64,0.774,128.286\n1,3,64,65,0.973,120.954\n1,3,64,66,0.949,121.821\n1,3,64,81,0.995,118.754\n1,4,64,63,0.845,123.889\n1,4,64,64,0.804,126.131\n1,4,64,65,1.036,117.401\n1,4,64,66,1.010,118.254\n0,5,64,63,0.501,126.170\n0,5,64,64,0.546,127.405\n0,5,64,65,0.664,118.412\n0,5,64,66,0.699,120.478\n0,5,64,78,0.482,127.331\n0,5,64,81,0.605,120.000\n0,5,64,82,0.597,122.000\n0,6,64,63,1.112,120.985\n0,6,64,64,1.043,123.922\n0,6,64,65,1.348,115.506\n0,6,64,66,1.156,123.890\n1,9,64,64,0.959,120.924\n1,9,64,65,1.098,119.529\n1,9,64,66,1.013,123.743\n0,10,64,63,0.937,123.695\n0,10,64,64,0.893,125.735\n0,10,64,65,1.016,124.788\n0,10,64,66,1.065,121.125\n0,12,64,63,0.845,126.259\n0,12,64,64,0.869,124.058\n0,12,64,65,1.020,120.198\n0,12,64,66,0.971,122.900\n0,13,64,63,0.845,123.004\n0,13,64,64,0.883,120.111\n0,15,64,63,0.870,124.581\n0,15,64,64,0.882,123.309\n0,15,64,65,1.008,121.049\n0,15,64,66,0.990,121.826\n0,18,64,65,1.065,118.404\n0,18,64,66,1.067,118.002\n0,37,64,63,0.906,117.966\n0,37,64,64,0.854,136.087\n1,37,64,64,0.772,128.673\n0,37,64,65,0.799,134.844\n1,37,64,65,0.942,122.866\n0,37,64,66,0.845,130.337\n0,37,64,78,0.706,135.432\n0,37,64,81,0.917,124.856\n0,37,64,82,0.946,123.684\n1,37,64,82,1.000,119.086\n0,38,64,63,0.988,121.242\n0,38,64,64,0.858,129.014\n0,38,64,65,0.989,127.335\n0,38,64,66,1.022,124.454\n0,39,64,64,1.086,114.312\n0,39,64,65,1.060,122.481\n1,39,64,65,1.204,114.188\n1,39,64,66,1.170,115.157\n0,40,64,63,0.948,123.538\n0,40,64,64,0.928,123.853\n0,40,64,65,0.958,129.125\n0,40,64,81,1.035,123.154\n0,40,64,82,1.183,115.934\n0,43,64,63,0.885,126.749\n0,43,64,64,0.898,124.876\n0,43,64,65,1.024,123.706\n0,43,64,66,1.017,123.409\n0,45,64,63,0.981,120.063\n0,45,64,64,0.921,123.014\n0,45,64,65,1.276,110.521\n0,45,64,66,1.199,113.371\n0,55,64,64,0.907,124.405\n0,55,64,65,1.002,125.220\n1,57,64,65,1.020,117.950\n1,57,64,66,0.959,121.017\n0,58,64,63,1.075,115.646\n0,58,64,64,0.815,131.812\n0,58,64,66,0.978,126.562\n0,62,64,64,0.885,126.560\n0,62,64,65,1.073,121.703\n0,63,64,64,0.866,108.239\n1,63,64,64,0.827,124.584\n0,63,64,66,1.038,111.621\n0,63,64,78,1.172,105.176\n0,63,64,81,1.164,110.895\n0,63,64,82,1.395,101.902\n0,64,64,64,0.967,115.037\n0,64,64,65,0.916,113.570\n1,64,64,66,1.003,118.067\n0,64,64,78,1.194,103.479\n0,64,64,82,1.210,108.553\n0,65,64,66,1.055,115.369\n0,65,64,81,1.168,116.240\n0,66,64,66,0.932,129.624\n0,0,65,0,0.000,104.500\n0,39,65,64,1.738,101.550\n0,39,65,66,1.589,106.360\n0,39,65,82,1.740,101.208\n0,44,65,64,1.430,103.829\n0,44,65,66,1.366,110.552\n0,44,65,78,1.419,104.213\n0,59,65,64,1.788,103.452\n0,59,65,81,1.774,104.872\n0,0,66,0,0.000,106.900\n0,63,66,64,1.206,103.779\n0,63,66,66,1.406,106.735\n0,63,66,78,1.339,105.365\n0,63,66,81,1.408,106.806\n0,64,66,65,1.709,107.658\n0,65,66,66,1.932,111.306\n0,0,67,0,0.000,119.900\n1,0,67,0,0.000,116.600\n0,1,67,3,0.982,120.683\n0,1,67,9,1.178,115.581\n0,1,67,32,1.233,119.589\n0,1,67,67,1.257,111.574\n1,2,67,32,1.118,126.320\n1,2,67,67,1.231,113.438\n0,3,67,23,0.567,128.000\n0,3,67,32,1.290,120.945\n1,3,67,37,1.122,113.631\n1,9,67,30,1.142,118.899\n0,9,67,32,1.325,125.531\n1,9,67,37,1.186,115.979\n0,23,67,32,0.805,120.000\n1,30,67,32,1.370,114.854\n1,32,67,37,1.240,120.019\n0,32,67,67,1.504,117.327\n1,37,67,67,1.310,110.017\n0,0,68,0,0.000,108.800\n0,1,68,1,1.159,108.238\n0,1,68,23,0.772,107.200\n0,1,68,32,0.958,110.757\n0,23,68,23,0.650,104.892\n0,23,68,32,0.659,112.977\n0,0,69,0,0.000,120.300\n0,32,69,37,1.123,121.777\n0,32,69,38,1.486,117.217\n0,37,69,37,1.223,116.447\n0,38,69,38,1.122,125.930\n0,31,70,31,0.658,103.978\n0,0,73,0,0.000,106.600\n0,1,73,32,1.590,100.180\n0,1,73,72,1.481,96.166\n0,32,73,32,1.665,115.012\n0,32,73,72,1.326,115.134\n0,0,74,0,0.000,113.000\n0,3,74,7,1.357,113.010\n0,0,75,0,0.000,94.900\n0,1,75,3,1.138,96.779\n0,3,75,19,1.044,91.970\n0,3,75,71,0.729,95.899\n0,0,76,0,0.000,107.600\n0,76,76,76,1.434,109.889\n0,76,76,78,1.493,103.519\n0,78,76,78,1.235,109.421\n0,0,77,0,0.000,109.500\n0,32,77,32,1.652,109.472\n0,0,78,0,0.000,121.900\n1,0,78,0,0.000,126.100\n0,1,78,78,0.744,130.960\n0,1,78,81,0.938,121.477\n1,3,78,78,0.827,125.468\n1,3,78,81,0.922,123.748\n0,5,78,76,0.584,123.407\n0,5,78,78,0.546,128.000\n0,5,78,79,0.617,122.000\n0,5,78,81,0.542,109.881\n1,9,78,78,0.863,129.501\n1,9,78,81,0.991,125.857\n0,37,78,76,0.770,137.282\n0,37,78,78,0.803,128.249\n0,37,78,81,0.864,128.714\n0,38,78,78,0.844,130.617\n0,38,78,81,1.023,123.532\n0,39,78,64,0.734,138.714\n0,39,78,78,1.202,109.426\n0,40,78,76,0.930,130.150\n0,40,78,78,0.778,135.746\n0,40,78,81,1.058,121.251\n0,44,78,63,0.677,141.902\n0,44,78,64,0.663,142.589\n0,44,78,66,0.816,134.701\n0,44,78,78,1.089,111.702\n0,45,78,76,1.199,114.467\n0,45,78,78,0.915,125.050\n0,45,78,81,1.216,112.926\n0,59,78,64,0.963,128.471\n0,59,78,65,1.097,128.375\n0,59,78,78,1.443,105.916\n0,63,78,64,0.942,117.779\n0,64,78,65,0.835,131.530\n0,64,78,78,1.038,111.834\n0,66,78,78,1.030,118.376\n0,76,78,76,1.245,113.179\n0,76,78,78,1.159,111.900\n0,78,78,78,1.336,99.459\n0,78,78,81,1.302,105.130\n0,79,78,81,1.217,114.792\n0,0,79,0,0.000,103.400\n0,78,79,81,1.569,102.043\n0,79,79,81,1.625,104.857\n0,0,80,0,0.000,121.900\n1,0,80,0,0.000,128.200\n0,1,80,81,0.864,127.147\n1,3,80,81,0.886,128.181\n0,5,80,81,0.651,125.682\n0,18,80,81,1.032,120.869\n0,41,80,81,0.909,125.057\n0,44,80,55,0.918,127.755\n0,44,80,81,1.184,112.411\n0,55,80,59,1.254,120.263\n0,55,80,81,0.991,127.612\n0,56,80,81,1.003,126.038\n0,59,80,81,1.439,112.030\n0,81,80,81,1.205,108.609\n0,0,81,0,0.000,119.500\n0,1,81,63,0.996,120.129\n0,1,81,64,0.978,119.970\n0,1,81,78,0.879,126.535\n0,1,81,79,1.144,116.113\n0,1,81,80,0.895,126.324\n1,2,81,78,0.927,125.080\n1,2,81,80,0.895,128.399\n1,9,81,78,1.015,124.270\n1,9,81,80,1.106,120.028\n0,36,81,64,0.522,130.295\n0,36,81,66,0.583,128.738\n0,36,81,78,0.578,124.658\n0,36,81,80,0.575,124.787\n0,37,81,64,0.929,122.408\n1,37,81,64,0.983,119.722\n0,37,81,65,1.184,114.158\n1,37,81,65,1.281,110.477\n1,37,81,78,0.884,126.208\n1,37,81,80,0.940,123.333\n0,63,81,64,1.115,114.945\n0,64,81,65,1.075,122.099\n0,64,81,80,1.143,113.176\n0,66,81,80,1.067,122.250\n0,78,81,80,0.957,110.556\n0,79,81,80,1.379,107.936\n0,32,82,59,1.666,114.660\n0,32,82,64,1.075,131.706\n0,32,82,65,1.238,129.293\n0,59,82,64,1.563,105.660\n0,64,82,65,1.281,112.955\n');this.a=a;};U1(280,1,{},jlb.kB);_.Ib=function lB(a,b){return Zkb.R3(this.b[a][b]);};_.Jb=function mB(){return this.b.length;};Ykb.kZ=w3(280);jlb.nB=function nB(a,b){return a.a[ilb.iA(0,b,0,a.a.length,true,a)][6]>0;};jlb.oB=function oB(a,b){return a.a[ilb.iA(0,b,0,a.a.length,true,a)][2];};jlb.pB=function pB(a){return a.a.length;};jlb.qB=function qB(a,b){var c;c=ilb.iA(0,b,0,a.a.length,true,a);return c>=0&&a.a[c][7]>0;};jlb.rB=function rB(a,b){return a.a[ilb.iA(0,b,0,a.a.length,true,a)][5];};jlb.sB=function sB(a,b){return a.a[ilb.iA(0,b,0,a.a.length,true,a)][4];};jlb.tB=function tB(a,b){return a.a[ilb.iA(0,b,0,a.a.length,true,a)][8]>0;};jlb.uB=function uB(a,b){return a.a[ilb.iA(0,b,0,a.a.length,true,a)][3];};jlb.vB=function vB(){this.a=ilb.Dz('95\nint,int,int,int,int,int,int,int,int\n1,6,4,4,0,0,0,0,0\n2,6,3,4,0,2,0,0,1\n3,6,3,4,0,2,0,0,1\n4,6,2,4,0,3,0,1,1\n5,1,1,1,0,0,0,0,0\n6,8,2,2,1,0,0,0,0\n7,8,1,2,0,2,0,0,0\n8,7,3,3,1,0,0,0,0\n9,7,2,3,0,2,0,0,1\n10,7,3,3,1,1,0,0,0\n11,9,1,1,1,0,0,0,0\n12,17,1,1,1,0,0,0,0\n13,35,1,1,1,0,0,0,0\n14,53,1,1,1,0,0,0,0\n15,16,2,2,1,0,0,0,0\n16,16,1,2,0,2,0,0,0\n17,16,3,4,0,2,0,0,0\n18,16,4,4,0,0,0,0,0\n19,14,4,4,0,0,0,0,0\n20,6,4,4,0,0,0,0,0\n21,1,1,1,0,0,0,0,0\n22,6,4,4,0,0,0,0,0\n23,1,1,1,0,0,0,0,0\n24,1,1,1,0,0,0,0,0\n25,15,4,4,0,0,0,0,0\n26,15,3,3,1,0,0,0,0\n27,1,1,1,0,0,0,0,0\n28,1,1,1,0,0,0,0,0\n29,1,1,1,0,0,0,0,0\n30,6,3,4,0,2,0,0,1\n31,1,1,1,0,0,0,0,0\n32,8,1,12,1,1,0,0,0\n33,1,1,1,0,0,0,0,0\n34,7,4,4,0,0,0,0,0\n35,8,1,1,1,1,0,0,0\n36,1,1,1,0,0,0,0,0\n37,6,3,4,0,2,1,0,1\n38,7,2,3,0,2,1,0,0\n39,7,3,3,1,1,1,0,1\n40,7,3,3,1,0,0,0,0\n41,6,3,4,0,1,0,0,0\n42,7,1,3,0,3,0,0,0\n43,7,3,3,1,0,0,0,0\n44,16,2,2,1,1,1,0,0\n45,7,3,4,0,2,0,0,0\n46,7,2,3,0,2,0,0,0\n47,7,1,2,0,2,0,0,0\n48,7,2,2,0,0,0,0,0\n49,8,3,3,0,0,0,0,0\n50,1,1,1,0,0,0,0,0\n51,8,2,3,0,2,0,0,0\n52,1,1,1,0,0,0,0,0\n53,7,2,4,0,2,0,1,0\n54,7,3,4,0,2,0,0,1\n55,7,3,34,0,1,0,0,0\n56,7,3,34,0,1,0,0,0\n57,6,3,4,0,2,0,0,1\n58,7,3,4,0,1,1,0,1\n59,8,2,2,1,1,1,0,0\n60,6,1,3,0,3,0,0,0\n61,7,2,4,0,3,0,1,0\n62,7,2,2,1,0,0,0,0\n63,6,3,4,0,2,1,0,1\n64,6,3,4,0,2,1,0,1\n65,7,2,3,0,2,1,0,0\n66,7,2,3,0,2,1,0,0\n67,7,3,4,0,2,0,0,1\n68,7,4,4,0,0,0,0,0\n69,7,3,4,0,1,1,0,0\n70,8,2,2,1,0,0,0,0\n71,1,1,1,0,0,0,0,0\n72,16,1,1,1,1,0,0,0\n73,16,3,3,0,0,0,0,0\n74,16,2,4,0,2,0,0,0\n75,15,2,3,0,2,0,0,1\n76,7,2,2,1,0,0,0,0\n77,17,4,4,0,0,0,0,0\n78,6,3,4,0,2,1,0,1\n79,7,2,3,0,2,1,0,0\n80,6,3,4,0,2,0,0,1\n81,7,3,4,0,1,1,0,1\n82,7,3,4,0,1,1,0,0\n87,26,0,0,0,0,0,0,0\n88,26,0,0,0,0,0,0,0\n89,9,0,0,0,0,0,0,0\n90,17,0,0,0,0,0,0,0\n91,35,0,0,0,0,0,0,0\n92,3,0,0,0,0,0,0,0\n93,11,0,0,0,0,0,0,0\n94,19,0,0,0,0,0,0,0\n95,30,0,0,0,0,0,0,0\n96,20,0,0,0,0,0,0,0\n97,29,0,0,0,0,0,0,0\n98,29,0,0,0,0,0,0,0\n99,12,0,0,0,0,0,0,0\n');};U1(275,1,{},jlb.vB);_.Ib=function wB(a,b){return this.a[a][b];};_.Jb=function xB(){return jlb.pB(this);};Ykb.lZ=w3(275);jlb.yB=function yB(a,b){return Zkb.Q3(a.a[b][3]);};jlb.zB=function zB(a,b){return Zkb.Q3(a.a[b][2]);};jlb.AB=function AB(){this.a=ilb.Cz('58\nint,int,float,float\n1,6,1.084,5.15\n1,7,1.001,7.35\n1,8,0.947,9.10\n1,9,0.92,10.6\n1,14,1.48,2.3\n1,15,1.415,2.95\n1,16,1.326,4.30\n1,17,1.28,4.3\n1,35,1.41,4.2\n1,53,1.60,2.7\n6,6,1.512,3.80\n6,7,1.439,4.55\n6,8,1.393,5.40\n6,9,1.353,6.20\n6,14,1.86,2.6\n6,15,1.84,2.7\n6,16,1.812,2.85\n6,17,1.781,2.75\n6,35,1.94,2.6\n6,53,2.16,1.4\n7,7,1.283,6.00\n7,8,1.333,5.90\n7,9,1.36,5.9\n7,14,1.74,3.7\n7,15,1.65,4.8\n7,16,1.674,3.75\n7,17,1.75,3.5\n7,35,1.90,2.9\n7,53,2.10,1.6\n8,8,1.48,3.6\n8,9,1.42,4.6\n8,14,1.63,5.2\n8,15,1.66,4.7\n8,16,1.470,9.90\n8,17,1.70,4.1\n8,35,1.85,3.4\n8,53,2.05,1.6\n9,14,1.57,6.4\n9,15,1.54,7.1\n9,16,1.55,6.9\n14,14,2.32,1.3\n14,15,2.25,1.5\n14,16,2.15,2.0\n14,17,2.02,3.1\n14,35,2.19,2.1\n14,53,2.44,1.5\n15,15,2.21,1.7\n15,16,2.10,2.4\n15,17,2.03,3.0\n15,35,2.21,2.0\n15,53,2.47,1.4\n16,16,2.052,2.50\n16,17,2.04,2.9\n16,35,2.24,1.9\n16,53,2.40,1.7\n17,17,1.99,3.5\n35,35,2.28,2.4\n53,53,2.67,1.6\n');};U1(287,1,{},jlb.AB);_.Ib=function BB(a,b){return Zkb.R3(this.a[a][b]);};_.Jb=function CB(){return this.a.length;};Ykb.mZ=w3(287);jlb.DB=function DB(a,b,c,d){var e,f,g,h,i,j,k,l,m,n,o,p;k=klb.PC(a.a,b,clb.tn(b,c,d));f=b.a[c];h=b.a[d];f>h&&(f=(o=Zkb.t4(h),Zkb.t4(h=f),o).a);m=ilb.kA(oW(aW(Ykb.AX,1),gmb,6,15,[1,2,0]),oW(aW(Ykb.AX,1),gmb,6,15,[f,h,k]),a);if(m>=0){return Zkb.Q3(a.b[m][3]);}else {e=b.C[c];g=b.C[d];e>g&&(e=(n=Zkb.t4(g),Zkb.t4(g=e),n).a);p=jlb.EB(a,b,c,d);j=ilb.kA(oW(aW(Ykb.AX,1),gmb,6,15,[0,1]),oW(aW(Ykb.AX,1),gmb,6,15,[e,g]),a.a.c);if(j>=0){l=$wnd.Math.pow(jlb.zB(a.a.c,j)/p,6);return jlb.yB(a.a.c,j)*l;}else {i=ilb.kA(oW(aW(Ykb.AX,1),gmb,6,15,[0,1]),oW(aW(Ykb.AX,1),gmb,6,15,[ilb.Xz(e),ilb.Xz(g)]),a.a.j);return $wnd.Math.pow(10,-(p-jlb._B(a.a.j,i,2))/jlb._B(a.a.j,i,3));}}};jlb.EB=function EB(a,b,c,d){var e,f,g,h,i,j,k,l,m,n,o,p,q,r,s;k=klb.PC(a.a,b,clb.tn(b,c,d));g=b.a[c];j=b.a[d];g>j&&(g=(q=Zkb.t4(j),Zkb.t4(j=g),q).a);o=ilb.kA(oW(aW(Ykb.AX,1),gmb,6,15,[1,2,0]),oW(aW(Ykb.AX,1),gmb,6,15,[g,j,k]),a);if(o>=0)return Zkb.Q3(a.b[o][4]);else {f=b.C[c];i=b.C[d];f>i&&(f=(p=Zkb.t4(i),Zkb.t4(i=f),p).a);e=ilb.jA(f,a.a.f);h=ilb.jA(i,a.a.f);r=jlb.RB(a.a.f,e);s=jlb.RB(a.a.f,h);m=jlb.PB(a.a.f,e);n=jlb.PB(a.a.f,h);l=f==1||i==1?0.05:0.085;return r+s-l*$wnd.Math.pow($wnd.Math.abs(m-n),1.4);}};jlb.FB=function FB(a){this.b=ilb.Cz('493\nint,int,int,float,float\n0,1,1,4.258,1.508\n0,1,2,4.539,1.482\n0,1,3,4.190,1.492\n0,1,4,4.707,1.459\n0,1,5,4.766,1.093\n0,1,6,5.047,1.418\n0,1,8,5.084,1.451\n0,1,9,4.763,1.458\n0,1,10,4.664,1.436\n0,1,11,6.011,1.360\n0,1,12,2.974,1.773\n0,1,13,2.529,1.949\n0,1,14,1.706,2.090\n0,1,15,2.893,1.805\n0,1,17,2.841,1.813\n0,1,18,3.258,1.772\n0,1,19,2.866,1.830\n0,1,20,4.650,1.504\n0,1,22,4.286,1.482\n0,1,25,2.980,1.810\n0,1,26,2.790,1.830\n0,1,34,3.844,1.480\n0,1,35,7.915,1.307\n0,1,37,4.957,1.486\n0,1,39,6.114,1.445\n0,1,40,4.922,1.446\n0,1,41,3.830,1.510\n0,1,43,3.971,1.472\n0,1,45,3.844,1.480\n0,1,46,3.813,1.482\n0,1,54,4.267,1.461\n0,1,55,4.646,1.454\n0,1,56,4.166,1.453\n0,1,57,4.669,1.461\n0,1,58,4.329,1.451\n0,1,61,4.845,1.424\n0,1,62,4.456,1.444\n0,1,63,4.481,1.471\n0,1,64,4.518,1.469\n0,1,67,4.188,1.459\n0,1,68,4.217,1.479\n0,1,72,2.956,1.801\n0,1,73,2.608,1.839\n0,1,75,2.547,1.858\n0,1,78,4.593,1.465\n0,1,80,4.373,1.477\n0,1,81,4.512,1.441\n0,2,2,9.505,1.333\n1,2,2,5.310,1.430\n1,2,3,4.565,1.468\n0,2,4,9.538,1.297\n1,2,4,5.657,1.415\n0,2,5,5.170,1.083\n0,2,6,5.520,1.373\n1,2,9,6.385,1.360\n0,2,10,6.329,1.362\n0,2,11,6.283,1.350\n0,2,12,3.390,1.720\n0,2,13,3.413,1.854\n0,2,14,2.062,2.025\n0,2,15,3.896,1.720\n0,2,17,3.247,1.773\n0,2,18,3.789,1.728\n0,2,19,3.052,1.811\n0,2,20,4.593,1.465\n0,2,22,4.926,1.448\n0,2,25,3.750,1.742\n0,2,30,8.166,1.331\n0,2,34,5.207,1.407\n0,2,35,10.343,1.250\n1,2,37,5.007,1.449\n1,2,39,6.164,1.368\n0,2,40,6.110,1.370\n0,2,41,3.746,1.505\n0,2,43,4.928,1.420\n0,2,45,4.725,1.430\n0,2,46,7.466,1.325\n0,2,55,6.164,1.368\n0,2,56,6.246,1.365\n0,2,62,7.105,1.336\n1,2,63,6.030,1.400\n1,2,64,5.754,1.411\n1,2,67,4.685,1.432\n0,2,72,4.179,1.700\n1,2,81,6.357,1.361\n1,3,3,4.418,1.489\n1,3,4,5.135,1.438\n0,3,5,4.650,1.101\n0,3,6,5.801,1.355\n0,3,7,12.950,1.222\n0,3,9,10.077,1.290\n1,3,9,6.273,1.364\n0,3,10,5.829,1.369\n0,3,11,6.570,1.340\n0,3,12,3.449,1.715\n0,3,15,3.536,1.748\n0,3,16,4.735,1.665\n0,3,17,2.888,1.808\n0,3,18,3.394,1.760\n0,3,20,3.298,1.530\n0,3,22,4.593,1.465\n0,3,25,3.164,1.792\n1,3,30,4.481,1.471\n0,3,35,11.012,1.237\n1,3,37,4.488,1.457\n1,3,39,5.978,1.375\n0,3,40,6.110,1.370\n0,3,41,4.286,1.482\n0,3,43,4.928,1.420\n0,3,45,4.531,1.440\n0,3,48,5.412,1.398\n0,3,51,8.562,1.290\n0,3,53,7.637,1.320\n0,3,54,10.333,1.280\n1,3,54,2.771,1.563\n0,3,55,4.886,1.422\n0,3,56,4.907,1.421\n1,3,57,5.492,1.422\n1,3,58,5.163,1.409\n0,3,62,7.568,1.322\n1,3,63,5.468,1.423\n1,3,64,5.288,1.431\n0,3,67,8.217,1.304\n0,3,74,5.204,1.639\n0,3,75,4.191,1.710\n1,3,78,5.705,1.413\n1,3,80,6.719,1.375\n0,4,4,15.206,1.200\n0,4,5,5.726,1.065\n0,4,6,7.193,1.328\n0,4,7,14.916,1.176\n0,4,9,15.589,1.172\n1,4,9,7.041,1.338\n0,4,10,6.824,1.345\n0,4,15,4.330,1.690\n0,4,20,5.178,1.436\n0,4,22,5.400,1.426\n0,4,30,10.227,1.282\n1,4,37,5.445,1.424\n0,4,42,16.582,1.160\n0,4,43,6.947,1.341\n1,4,63,5.633,1.416\n1,4,64,5.492,1.422\n0,5,19,2.254,1.485\n0,5,20,4.852,1.093\n0,5,22,5.191,1.082\n0,5,30,5.176,1.086\n0,5,37,5.306,1.084\n0,5,41,3.256,1.144\n0,5,57,5.633,1.076\n0,5,63,5.531,1.080\n0,5,64,5.506,1.080\n0,5,78,5.506,1.080\n0,5,80,5.633,1.076\n0,6,6,4.088,1.449\n0,6,8,5.059,1.450\n0,6,9,4.491,1.395\n0,6,10,5.982,1.410\n0,6,15,4.757,1.661\n0,6,17,5.779,1.608\n0,6,18,5.326,1.630\n0,6,19,4.661,1.660\n0,6,20,5.623,1.433\n0,6,21,7.794,0.972\n0,6,22,4.556,1.433\n0,6,24,7.403,0.981\n0,6,25,5.243,1.630\n0,6,26,5.481,1.618\n0,6,29,7.839,0.973\n0,6,30,9.359,1.271\n0,6,33,7.143,0.986\n0,6,37,5.614,1.376\n0,6,39,4.629,1.388\n0,6,40,4.609,1.389\n0,6,41,6.754,1.342\n0,6,43,3.937,1.426\n0,6,45,4.321,1.404\n0,6,54,5.117,1.365\n0,6,55,4.772,1.381\n0,6,57,7.128,1.330\n0,6,58,4.792,1.380\n0,6,63,7.324,1.324\n0,6,64,6.664,1.345\n0,7,17,8.770,1.500\n0,7,46,9.329,1.235\n0,7,74,9.129,1.490\n0,8,8,3.264,1.420\n0,8,9,4.581,1.342\n0,8,10,3.909,1.378\n0,8,12,3.371,1.761\n0,8,15,4.060,1.652\n0,8,17,3.901,1.663\n0,8,19,4.254,1.700\n0,8,20,5.107,1.456\n0,8,22,4.223,1.457\n0,8,23,6.490,1.019\n0,8,25,4.629,1.660\n0,8,26,4.027,1.699\n0,8,34,3.775,1.386\n0,8,39,3.435,1.408\n0,8,40,3.710,1.390\n0,8,43,3.977,1.374\n0,8,45,4.267,1.358\n0,8,46,5.519,1.301\n0,8,55,4.229,1.360\n0,8,56,3.995,1.373\n0,9,9,7.256,1.243\n1,9,9,3.808,1.384\n0,9,10,4.480,1.347\n0,9,12,3.635,1.739\n0,9,15,3.791,1.671\n0,9,18,4.465,1.626\n0,9,19,3.687,1.741\n0,9,20,4.401,1.447\n0,9,25,5.379,1.619\n0,9,27,6.230,1.026\n0,9,34,3.223,1.423\n0,9,35,5.095,1.366\n1,9,37,5.529,1.393\n1,9,39,4.685,1.337\n0,9,40,4.382,1.352\n0,9,41,5.650,1.388\n0,9,45,4.857,1.329\n0,9,53,7.291,1.242\n0,9,54,4.991,1.323\n0,9,55,3.825,1.383\n0,9,56,4.602,1.341\n1,9,57,6.824,1.345\n0,9,62,4.749,1.334\n1,9,63,6.824,1.345\n1,9,64,5.458,1.396\n0,9,67,6.752,1.258\n1,9,78,6.644,1.351\n1,9,81,3.909,1.378\n0,10,10,3.977,1.374\n0,10,13,3.110,1.878\n0,10,14,1.967,2.029\n0,10,15,3.593,1.686\n0,10,17,3.930,1.661\n0,10,20,4.240,1.456\n0,10,22,4.970,1.418\n0,10,25,3.820,1.714\n0,10,26,3.651,1.727\n0,10,28,6.663,1.015\n0,10,34,3.960,1.375\n0,10,35,4.898,1.375\n0,10,37,5.482,1.395\n0,10,39,4.382,1.352\n0,10,40,3.841,1.382\n0,10,41,7.466,1.325\n0,10,45,3.524,1.402\n0,10,63,6.137,1.369\n0,10,64,5.952,1.376\n0,11,20,6.339,1.348\n0,11,22,5.296,1.389\n0,11,25,6.019,1.583\n0,11,26,6.204,1.575\n0,11,37,6.511,1.342\n0,11,40,4.187,1.440\n0,12,15,2.978,2.031\n0,12,18,2.808,2.051\n0,12,19,2.838,2.050\n0,12,20,2.859,1.751\n0,12,22,3.056,1.750\n0,12,25,3.063,2.023\n0,12,26,2.448,2.100\n0,12,37,3.378,1.721\n0,12,40,3.737,1.731\n0,12,57,3.714,1.694\n0,12,63,3.413,1.718\n0,12,64,3.649,1.699\n0,13,20,2.767,1.920\n0,13,22,2.928,1.902\n0,13,37,3.031,1.891\n0,13,64,3.031,1.891\n0,14,20,0.884,2.332\n0,14,37,1.781,2.075\n0,15,15,2.531,2.050\n0,15,18,2.214,2.094\n0,15,19,2.022,2.146\n0,15,20,2.757,1.822\n0,15,22,3.802,1.727\n0,15,25,2.319,2.112\n0,15,26,2.359,2.106\n0,15,30,3.750,1.731\n0,15,37,3.565,1.765\n0,15,40,3.859,1.666\n0,15,43,3.221,1.717\n0,15,57,3.993,1.713\n0,15,63,3.724,1.733\n0,15,64,3.548,1.747\n0,15,71,4.014,1.341\n0,17,20,2.397,1.865\n0,17,22,2.566,1.844\n0,17,37,3.098,1.787\n0,17,43,4.900,1.601\n0,18,20,3.172,1.780\n0,18,22,2.757,1.822\n0,18,32,10.748,1.450\n0,18,37,3.281,1.770\n0,18,39,3.504,1.693\n0,18,43,3.301,1.710\n0,18,48,6.186,1.540\n0,18,55,4.432,1.628\n0,18,58,2.568,1.783\n0,18,62,5.510,1.570\n0,18,63,3.524,1.749\n0,18,64,3.856,1.723\n0,18,80,4.150,1.702\n0,19,20,2.288,1.900\n0,19,37,3.072,1.809\n0,19,40,4.470,1.686\n0,19,63,3.219,1.795\n0,19,75,1.600,2.226\n0,20,20,3.663,1.526\n0,20,22,4.251,1.484\n0,20,25,2.718,1.838\n0,20,26,2.588,1.853\n0,20,30,3.977,1.507\n0,20,34,4.171,1.460\n0,20,37,3.740,1.516\n0,20,40,4.784,1.427\n0,20,41,4.286,1.482\n0,20,43,3.737,1.487\n0,20,45,3.844,1.480\n0,22,22,3.969,1.499\n0,22,30,3.785,1.513\n0,22,34,4.103,1.464\n0,22,37,4.481,1.471\n0,22,40,4.188,1.459\n0,22,41,5.071,1.441\n0,22,43,4.070,1.466\n0,22,45,4.311,1.452\n0,23,39,7.112,1.012\n0,23,62,6.339,1.026\n0,23,67,6.610,1.019\n0,23,68,5.899,1.038\n0,25,25,1.514,2.253\n0,25,32,8.296,1.510\n0,25,37,3.586,1.755\n0,25,39,4.370,1.676\n0,25,40,4.629,1.660\n0,25,43,3.237,1.762\n0,25,57,4.356,1.699\n0,25,63,3.711,1.745\n0,25,71,3.001,1.411\n0,25,72,3.744,1.950\n0,26,26,1.414,2.279\n0,26,34,3.395,1.748\n0,26,37,3.207,1.788\n0,26,40,4.870,1.646\n0,26,71,2.959,1.415\n0,28,40,6.576,1.018\n0,28,43,6.265,1.028\n0,28,48,6.413,1.024\n0,30,30,9.579,1.343\n1,30,30,5.355,1.428\n0,30,40,8.447,1.298\n1,30,67,5.274,1.404\n0,31,70,7.880,0.969\n0,32,41,9.756,1.261\n0,32,45,9.420,1.233\n0,32,67,7.926,1.269\n0,32,68,4.398,1.348\n0,32,69,6.098,1.261\n0,32,73,8.427,1.510\n0,32,77,10.648,1.450\n0,32,82,8.594,1.252\n0,34,36,6.163,1.028\n0,34,37,4.347,1.450\n0,34,43,4.401,1.351\n0,35,37,9.767,1.262\n0,35,63,12.760,1.207\n0,36,54,6.529,1.022\n0,36,55,6.744,1.014\n0,36,56,6.490,1.017\n0,36,58,6.610,1.019\n0,36,81,6.980,1.016\n0,37,37,5.573,1.374\n1,37,37,5.178,1.436\n0,37,38,5.737,1.333\n0,37,39,5.978,1.375\n1,37,39,5.650,1.388\n0,37,40,6.168,1.398\n0,37,41,4.537,1.468\n0,37,43,4.764,1.428\n0,37,45,4.705,1.431\n0,37,46,6.191,1.367\n0,37,55,6.615,1.352\n0,37,56,5.055,1.414\n1,37,57,5.092,1.440\n0,37,58,7.432,1.326\n1,37,58,5.055,1.414\n0,37,61,5.724,1.385\n0,37,62,7.137,1.335\n0,37,63,6.095,1.372\n1,37,63,5.178,1.436\n0,37,64,6.161,1.379\n1,37,64,5.265,1.432\n1,37,67,4.725,1.430\n0,37,69,5.396,1.352\n0,37,78,6.719,1.375\n0,37,81,3.987,1.471\n1,37,81,4.531,1.440\n0,38,38,5.002,1.246\n0,38,63,7.299,1.330\n0,38,64,6.978,1.340\n0,38,69,5.036,1.321\n0,38,78,6.218,1.366\n0,39,40,4.101,1.367\n0,39,45,3.524,1.402\n0,39,63,6.301,1.364\n1,39,63,6.137,1.369\n0,39,64,6.357,1.361\n1,39,64,5.482,1.395\n0,39,65,5.513,1.339\n0,39,78,6.137,1.369\n0,40,40,4.248,1.359\n0,40,45,4.305,1.356\n0,40,46,4.727,1.335\n0,40,54,6.817,1.256\n0,40,63,6.733,1.348\n0,40,64,6.644,1.351\n0,40,78,5.900,1.378\n0,41,41,5.029,1.443\n0,41,55,5.577,1.391\n0,41,62,7.137,1.335\n0,41,72,4.519,1.678\n0,41,80,5.222,1.434\n0,42,61,16.223,1.087\n0,43,43,4.211,1.361\n0,43,45,3.710,1.390\n0,43,64,5.389,1.399\n0,44,63,3.589,1.717\n0,44,65,3.374,1.684\n0,44,78,3.711,1.734\n0,44,80,3.910,1.719\n0,45,63,5.119,1.411\n0,45,64,5.076,1.413\n0,45,78,5.724,1.385\n0,47,53,12.192,1.140\n0,49,50,6.812,0.991\n0,51,52,7.100,0.987\n0,55,57,7.227,1.319\n0,55,62,3.977,1.374\n0,55,64,5.529,1.393\n0,55,80,7.500,1.324\n0,56,57,4.137,1.383\n0,56,63,5.900,1.378\n0,56,80,6.470,1.357\n1,57,63,5.400,1.426\n1,57,64,5.135,1.438\n0,58,63,6.794,1.346\n0,58,64,6.164,1.368\n0,59,63,5.787,1.360\n0,59,65,4.756,1.388\n0,59,78,6.127,1.364\n0,59,80,7.064,1.332\n0,59,82,3.855,1.431\n0,60,61,15.749,1.170\n0,62,63,6.947,1.341\n0,62,64,6.273,1.364\n1,63,63,5.729,1.412\n0,63,64,7.118,1.377\n0,63,66,8.326,1.313\n0,63,72,4.503,1.679\n0,63,78,7.434,1.352\n0,63,81,7.778,1.316\n0,64,64,4.313,1.418\n1,64,64,4.926,1.448\n0,64,65,8.258,1.335\n0,64,66,4.456,1.369\n0,64,78,5.492,1.422\n0,64,81,5.824,1.381\n0,64,82,6.794,1.346\n0,65,66,7.243,1.323\n0,65,78,8.447,1.298\n0,65,81,5.223,1.313\n0,65,82,5.622,1.297\n0,66,66,3.874,1.368\n0,66,78,6.385,1.360\n0,66,81,3.960,1.375\n0,67,67,6.085,1.280\n0,71,75,2.852,1.423\n0,72,73,2.628,2.035\n0,76,76,4.286,1.357\n0,76,78,6.824,1.345\n0,78,78,5.573,1.374\n0,78,79,8.890,1.287\n0,78,81,5.046,1.381\n0,79,79,6.408,1.269\n0,79,81,4.305,1.356\n0,80,81,8.237,1.335\n');this.a=a;};U1(283,1,{},jlb.FB);_.Ib=function GB(a,b){return Zkb.R3(this.b[a][b]);};_.Jb=function HB(){return this.b.length;};Ykb.nZ=w3(283);jlb.IB=function IB(a,b,c,d){return ilb.iA(1,b,0,c,d,new jlb.MB(a));};jlb.JB=function JB(a,b){return Zkb.Q3(a.b[b-1][2]);};jlb.KB=function KB(a,b,c,d){var e,f,g,h,i,j,k;k=c>d?1:-1;j=c>d?d:c;i=c>d?c:d;f=jlb.IB(a,j,a.a.length,true);e=jlb.IB(a,j,a.a.length,false);if(f==-1||e==-1)return Zkb.Q3(a.b[c-1][1])-Zkb.Q3(a.b[d-1][1]);h=ilb.iA(2,i,f,e+1,true,new jlb.MB(a));g=ilb.iA(2,i,f,e+1,false,new jlb.MB(a));if(h==-1||g==-1)return Zkb.Q3(a.b[c-1][1])-Zkb.Q3(a.b[d-1][1]);if(b==0&&Zkb.R3(a.a[h][0])==0)return k*Zkb.Q3(a.a[h][3]);else if(b==1&&Zkb.R3(a.a[g][0])==1)return k*Zkb.Q3(a.a[g][3]);return Zkb.Q3(a.b[c-1][1])-Zkb.Q3(a.b[d-1][1]);};jlb.LB=function LB(){this.b=ilb.Cz('99\nint,float,float\n1,0.000,0.000\n2,-0.135,0.000\n3,-0.095,0.000\n4,-0.200,0.000\n5,-0.023,0.000\n6,-0.243,0.000\n7,-0.687,0.000\n8,-0.253,0.000\n9,-0.306,0.000\n10,-0.244,0.000\n11,-0.317,0.000\n12,-0.304,0.000\n13,-0.238,0.000\n14,-0.208,0.000\n15,-0.236,0.000\n16,-0.475,0.000\n17,-0.191,0.000\n18,-0.118,0.000\n19,0.094,0.000\n20,-0.019,0.000\n21,0.157,0.000\n22,-0.095,0.000\n23,0.193,0.000\n24,0.257,0.000\n25,0.012,0.000\n26,-0.142,0.000\n27,0.094,0.000\n28,0.058,0.000\n29,0.207,0.000\n30,-0.166,0.000\n31,0.161,0.000\n32,-0.732,0.500\n33,0.257,0.000\n34,-0.491,0.000\n35,-0.456,0.500\n36,-0.031,0.000\n37,-0.127,0.000\n38,-0.437,0.000\n39,-0.104,0.000\n40,-0.264,0.000\n41,0.052,0.000\n42,-0.757,0.000\n43,-0.326,0.000\n44,-0.237,0.000\n45,-0.260,0.000\n46,-0.429,0.000\n47,-0.418,0.000\n48,-0.525,0.000\n49,-0.283,0.000\n50,0.284,0.000\n51,-1.046,0.000\n52,-0.546,0.000\n53,-0.048,0.000\n54,-0.424,0.000\n55,-0.476,0.000\n56,-0.438,0.000\n57,-0.105,0.000\n58,-0.488,0.000\n59,-0.337,0.000\n60,-0.635,0.000\n61,-0.265,0.000\n62,-0.125,0.250\n63,-0.180,0.000\n64,-0.181,0.000\n65,-0.475,0.000\n66,-0.467,0.000\n67,-0.099,0.000\n68,-0.135,0.000\n69,-0.099,0.000\n70,-0.269,0.000\n71,-0.071,0.000\n72,-0.580,0.500\n73,-0.200,0.000\n74,-0.301,0.000\n75,-0.255,0.000\n76,-0.568,0.250\n77,-0.282,0.000\n78,-0.168,0.000\n79,-0.471,0.000\n80,-0.144,0.000\n81,-0.514,0.000\n82,-0.099,0.000\n83,0.000,0.000\n84,0.000,0.000\n85,0.000,0.000\n86,0.000,0.000\n87,2.000,0.000\n88,3.000,0.000\n89,-1.000,0.000\n90,-1.000,0.000\n91,-1.000,0.000\n92,1.000,0.000\n93,1.000,0.000\n94,1.000,0.000\n95,2.000,0.000\n96,2.000,0.000\n97,1.000,0.000\n98,2.000,0.000\n99,2.000,0.000\n');this.a=ilb.Cz('498\nint,int,int,float\n0,1,1,0.0000\n0,1,2,-0.1382\n0,1,3,-0.0610\n0,1,4,-0.2000\n0,1,5,0.0000\n0,1,6,-0.2800\n0,1,8,-0.2700\n0,1,9,-0.2460\n0,1,10,-0.3001\n0,1,11,-0.3400\n0,1,12,-0.2900\n0,1,13,-0.2300\n0,1,14,-0.1900\n0,1,15,-0.2300\n0,1,17,-0.1935\n0,1,18,-0.1052\n0,1,19,0.0805\n0,1,20,0.0000\n0,1,22,-0.0950\n0,1,25,0.0000\n0,1,26,-0.1669\n0,1,34,-0.5030\n0,1,35,-0.4274\n0,1,37,-0.1435\n0,1,39,-0.2556\n0,1,40,-0.3691\n0,1,41,0.1060\n0,1,43,-0.3557\n0,1,45,-0.2402\n0,1,46,-0.3332\n0,1,54,-0.3461\n0,1,55,-0.4895\n0,1,56,-0.3276\n0,1,57,-0.1050\n0,1,58,-0.4880\n0,1,61,-0.2657\n0,1,62,-0.2000\n0,1,63,-0.1800\n0,1,64,-0.1810\n0,1,67,-0.0990\n0,1,68,-0.2560\n0,1,72,-0.5500\n0,1,73,-0.0877\n0,1,75,-0.2550\n0,1,78,-0.1680\n0,1,80,-0.1440\n0,1,81,-0.5140\n0,2,2,0.0000\n1,2,2,0.0000\n1,2,3,-0.0144\n0,2,4,-0.0650\n1,2,4,-0.0650\n0,2,5,0.1500\n0,2,6,-0.0767\n1,2,9,-0.1710\n0,2,10,-0.1090\n0,2,11,-0.1495\n0,2,12,-0.1400\n0,2,13,-0.1100\n0,2,14,-0.0900\n0,2,15,-0.1010\n0,2,17,-0.0560\n0,2,18,0.0170\n0,2,19,0.2290\n0,2,20,0.1160\n0,2,22,0.0400\n0,2,25,0.1470\n0,2,30,-0.0310\n0,2,34,-0.3560\n0,2,35,-0.3500\n1,2,37,0.0284\n1,2,39,0.0310\n0,2,40,-0.1000\n0,2,41,0.2500\n0,2,43,-0.1910\n0,2,45,-0.2044\n0,2,46,-0.2940\n0,2,55,-0.3410\n0,2,56,-0.3030\n0,2,62,-0.0500\n1,2,63,-0.0450\n1,2,64,-0.0460\n1,2,67,0.0360\n0,2,72,-0.4500\n1,2,81,-0.3790\n1,3,3,0.0000\n1,3,4,-0.1050\n0,3,5,0.0600\n0,3,6,-0.1500\n0,3,7,-0.5700\n0,3,9,-0.4500\n1,3,9,-0.2110\n0,3,10,-0.0600\n0,3,11,-0.2220\n0,3,12,-0.2090\n0,3,15,-0.1410\n0,3,16,-0.3800\n0,3,17,-0.0960\n0,3,18,-0.0230\n0,3,20,0.0530\n0,3,22,0.0000\n0,3,25,0.1070\n1,3,30,-0.0710\n0,3,35,-0.3610\n1,3,37,0.0862\n1,3,39,-0.0090\n0,3,40,-0.0500\n0,3,41,0.1470\n0,3,43,-0.2363\n0,3,45,-0.1650\n0,3,48,-0.4300\n0,3,51,-0.9500\n0,3,53,-0.0134\n0,3,54,-0.4000\n1,3,54,-0.3290\n0,3,55,-0.3810\n0,3,56,-0.3430\n1,3,57,-0.0100\n1,3,58,-0.3930\n0,3,62,-0.0300\n1,3,63,-0.0850\n1,3,64,-0.0860\n0,3,67,-0.0040\n0,3,74,-0.3190\n0,3,75,-0.2474\n1,3,78,-0.0730\n1,3,80,-0.0490\n0,4,5,0.1770\n0,4,6,-0.0430\n0,4,7,-0.4870\n0,4,9,-0.3000\n1,4,9,-0.1060\n0,4,10,-0.0440\n0,4,15,-0.0360\n0,4,20,0.1810\n0,4,22,0.1050\n0,4,30,0.0340\n1,4,37,0.0730\n0,4,40,-0.0640\n0,4,42,-0.5571\n0,4,43,-0.1260\n1,4,63,0.0200\n1,4,64,0.0190\n0,5,19,0.2000\n0,5,20,0.0000\n0,5,22,-0.1000\n0,5,30,-0.1500\n0,5,37,-0.1500\n0,5,41,0.2203\n0,5,57,-0.1500\n0,5,63,-0.1500\n0,5,64,-0.1500\n0,5,78,-0.1500\n0,5,80,-0.1500\n0,6,6,0.0000\n0,6,8,-0.1000\n0,6,9,-0.0630\n0,6,10,0.0355\n0,6,15,0.0070\n0,6,17,0.0520\n0,6,18,0.1837\n0,6,19,0.2974\n0,6,20,0.2579\n0,6,21,0.4000\n0,6,22,0.1480\n0,6,24,0.5000\n0,6,25,0.2712\n0,6,26,0.1010\n0,6,29,0.4500\n0,6,30,0.0770\n0,6,33,0.5000\n0,6,37,0.0825\n0,6,39,0.1390\n0,6,40,-0.0210\n0,6,41,0.2950\n0,6,43,-0.0830\n0,6,45,-0.0090\n0,6,54,-0.1810\n0,6,55,-0.2330\n0,6,57,0.1380\n0,6,58,-0.2450\n0,6,63,0.0630\n0,6,64,0.0620\n0,7,17,0.5000\n0,7,46,0.1618\n0,7,74,0.5000\n0,8,8,0.0000\n0,8,9,-0.0530\n0,8,10,0.0090\n0,8,12,-0.0510\n0,8,15,0.0170\n0,8,17,0.0620\n0,8,19,0.3470\n0,8,20,0.2096\n0,8,22,0.1580\n0,8,23,0.3600\n0,8,25,0.2679\n0,8,26,0.1110\n0,8,34,-0.2380\n0,8,39,0.1490\n0,8,40,-0.0110\n0,8,43,-0.0730\n0,8,45,-0.0070\n0,8,46,-0.1760\n0,8,55,-0.2230\n0,8,56,-0.1850\n0,9,9,0.0000\n0,9,10,0.0620\n0,9,12,0.0020\n0,9,15,0.0700\n0,9,18,0.1880\n0,9,19,0.4000\n0,9,20,0.2870\n0,9,25,0.3180\n0,9,27,0.4000\n0,9,34,-0.1850\n0,9,35,-0.1500\n1,9,37,0.1790\n1,9,39,0.2020\n0,9,40,0.0420\n0,9,41,0.3580\n0,9,45,0.0460\n0,9,53,0.3179\n0,9,54,-0.1180\n0,9,55,-0.1700\n0,9,56,-0.1320\n1,9,57,0.2010\n0,9,62,0.1810\n1,9,63,0.1260\n1,9,64,0.1250\n0,9,67,0.2070\n1,9,78,0.1380\n1,9,81,-0.2080\n0,10,10,0.0000\n0,10,13,0.0060\n0,10,14,0.0360\n0,10,15,0.0080\n0,10,17,0.0530\n0,10,20,0.2250\n0,10,22,0.1490\n0,10,25,0.2560\n0,10,26,0.1020\n0,10,28,0.3700\n0,10,34,-0.2470\n0,10,35,-0.2120\n0,10,37,0.1170\n0,10,39,0.1400\n0,10,40,-0.0200\n0,10,41,0.2960\n0,10,45,-0.0160\n0,10,63,0.0640\n0,10,64,0.0630\n0,11,20,0.2980\n0,11,22,0.2317\n0,11,25,0.3290\n0,11,26,0.1750\n0,11,37,0.1900\n0,11,40,0.0530\n0,12,15,0.0680\n0,12,18,0.1860\n0,12,19,0.3701\n0,12,20,0.2900\n0,12,22,0.2273\n0,12,25,0.3160\n0,12,26,0.2112\n0,12,37,0.1770\n0,12,40,0.0400\n0,12,57,0.1990\n0,12,63,0.1240\n0,12,64,0.1230\n0,13,20,0.2190\n0,13,22,0.1430\n0,13,37,0.1110\n0,13,64,0.0570\n0,14,20,0.1890\n0,14,37,0.0810\n0,15,15,0.0000\n0,15,18,0.1180\n0,15,19,0.3300\n0,15,20,0.2170\n0,15,22,0.1410\n0,15,25,0.2480\n0,15,26,0.0940\n0,15,30,0.0700\n0,15,37,0.1015\n0,15,40,-0.0280\n0,15,43,-0.0900\n0,15,57,0.1310\n0,15,63,0.0560\n0,15,64,0.0550\n0,15,71,0.1800\n0,16,16,0.0000\n0,17,17,0.0000\n0,17,20,0.1720\n0,17,22,0.0960\n0,17,37,0.0640\n0,17,43,-0.1350\n0,18,18,0.0000\n0,18,20,0.0990\n0,18,22,0.0230\n0,18,32,-0.6500\n0,18,37,-0.0090\n0,18,39,0.0140\n0,18,43,-0.1380\n0,18,48,-0.5895\n0,18,55,-0.3580\n0,18,58,-0.3700\n0,18,62,0.2099\n0,18,63,-0.0620\n0,18,64,-0.0630\n0,18,80,-0.0260\n0,19,19,0.0000\n0,19,20,-0.1130\n0,19,37,-0.2210\n0,19,40,-0.3580\n0,19,63,-0.2740\n0,19,75,-0.3490\n0,20,20,0.0000\n0,20,22,-0.0760\n0,20,25,0.0310\n0,20,26,-0.1230\n0,20,30,-0.1380\n0,20,34,-0.4720\n0,20,37,-0.1080\n0,20,40,-0.2450\n0,20,41,0.0710\n0,20,43,-0.3070\n0,20,45,-0.2410\n0,22,22,0.0000\n0,22,30,-0.0710\n0,22,34,-0.3960\n0,22,37,-0.0320\n0,22,40,-0.1690\n0,22,41,0.1470\n0,22,43,-0.2310\n0,22,45,-0.1650\n0,23,39,-0.2700\n0,23,62,-0.4000\n0,23,67,-0.2920\n0,23,68,-0.3600\n0,25,25,0.0000\n0,25,32,-0.7000\n0,25,37,-0.1390\n0,25,39,-0.1160\n0,25,40,-0.2760\n0,25,43,-0.3380\n0,25,57,-0.1170\n0,25,63,-0.1920\n0,25,71,-0.0362\n0,25,72,-0.6773\n0,26,26,0.0000\n0,26,34,-0.3490\n0,26,37,0.0150\n0,26,40,-0.1220\n0,26,71,0.0960\n0,28,40,-0.4000\n0,28,43,-0.4200\n0,28,48,-0.4000\n0,30,30,0.0000\n0,30,40,-0.0980\n1,30,67,0.0670\n0,31,70,-0.4300\n0,32,41,0.6500\n0,32,45,0.5200\n0,32,67,0.6330\n0,32,68,0.7500\n0,32,69,0.7500\n0,32,73,0.3500\n0,32,77,0.4500\n0,32,82,0.6330\n0,34,36,0.4500\n0,34,37,0.3640\n0,34,43,0.1650\n0,35,37,0.3290\n0,35,63,0.2760\n0,36,54,-0.4000\n0,36,55,-0.4500\n0,36,56,-0.4500\n0,36,58,-0.4570\n4,36,58,-0.4500\n0,36,81,-0.4500\n0,37,37,0.0000\n1,37,37,0.0000\n0,37,38,-0.3100\n0,37,39,0.0230\n1,37,39,0.0230\n0,37,40,-0.1000\n0,37,41,0.1790\n0,37,43,-0.1990\n0,37,45,-0.1330\n0,37,46,-0.3020\n0,37,55,-0.3490\n0,37,56,-0.3110\n1,37,57,0.0220\n0,37,58,-0.3610\n1,37,58,-0.3610\n4,37,58,-0.3500\n0,37,61,-0.1380\n0,37,62,0.0020\n0,37,63,0.0000\n1,37,63,-0.0530\n0,37,64,0.0000\n1,37,64,-0.0540\n1,37,67,0.0280\n0,37,69,-0.0895\n0,37,78,-0.0410\n0,37,81,-0.3870\n1,37,81,-0.3870\n0,38,38,0.0000\n0,38,63,0.2570\n0,38,64,0.2560\n0,38,69,0.3380\n0,38,78,0.2690\n1,39,39,0.0000\n0,39,40,-0.1600\n0,39,45,-0.1560\n0,39,63,-0.1516\n1,39,63,-0.0760\n0,39,64,-0.0770\n1,39,64,-0.0770\n0,39,65,-0.4180\n0,39,78,-0.0640\n0,40,40,0.0000\n0,40,45,0.0040\n0,40,46,-0.1650\n0,40,54,-0.1600\n0,40,63,0.0840\n0,40,64,0.0830\n0,40,78,0.0960\n0,41,41,0.0000\n0,41,55,-0.5280\n0,41,62,-0.1770\n0,41,72,-0.5000\n0,41,80,-0.1960\n0,42,61,0.4920\n0,43,43,0.0000\n0,43,45,0.0660\n0,43,64,0.1450\n0,44,63,0.0400\n0,44,65,-0.2207\n0,44,78,0.0690\n0,44,80,0.0930\n0,45,63,0.0800\n0,45,64,0.0790\n0,45,78,0.0920\n0,47,53,0.3700\n0,49,50,0.5673\n0,51,52,0.5000\n0,55,57,0.3544\n0,55,62,0.3510\n0,55,64,0.2950\n0,55,80,0.3320\n0,56,57,0.4000\n0,56,63,0.2580\n0,56,80,0.2700\n4,57,58,-0.4000\n1,57,63,-0.0750\n1,57,64,-0.0760\n0,58,63,0.3080\n0,58,64,0.3070\n0,59,63,0.1400\n0,59,65,-0.1209\n0,59,78,0.1690\n0,59,80,0.1930\n0,59,82,0.2380\n0,60,61,0.3700\n0,62,63,-0.0550\n0,62,64,-0.0560\n0,63,63,0.0000\n1,63,63,0.0000\n0,63,64,0.0000\n0,63,66,-0.3381\n0,63,72,-0.4000\n0,63,78,0.0120\n0,63,81,-0.3340\n0,64,64,0.0000\n0,64,65,-0.2888\n0,64,66,-0.2272\n0,64,78,0.0130\n0,64,81,-0.3330\n0,64,82,0.0820\n0,65,66,0.0000\n0,65,78,0.3070\n0,65,81,-0.0390\n0,65,82,0.3760\n0,66,66,0.0000\n0,66,78,0.2990\n0,66,81,-0.0470\n0,71,75,-0.0958\n0,72,73,0.4500\n0,76,76,0.0000\n0,76,78,0.4000\n0,78,78,0.0000\n1,78,78,0.0000\n0,78,79,-0.3030\n0,78,81,-0.3500\n0,79,81,-0.0430\n0,80,81,-0.4000\n');};U1(281,1,{},jlb.LB);Ykb.pZ=w3(281);jlb.MB=function MB(a){this.a=a;};U1(151,1,{},jlb.MB);_.Ib=function NB(a,b){return Zkb.R3(this.a.a[a][b]);};_.Jb=function OB(){return this.a.a.length;};Ykb.oZ=w3(151);jlb.PB=function PB(a,b){return Zkb.Q3(a.a[b][2]);};jlb.QB=function QB(a){return a.a.length;};jlb.RB=function RB(a,b){return Zkb.Q3(a.a[b][1]);};jlb.SB=function SB(){this.a=ilb.Cz('18\nint,float,float\n1,0.33,2.20\n3,1.34,0.97\n6,0.77,2.50\n7,0.73,3.07\n8,0.72,3.50\n9,0.74,4.12\n11,1.54,1.01\n12,1.30,1.23\n14,1.15,1.74\n15,1.09,2.06\n16,1.03,2.44\n17,1.01,2.83\n19,1.96,0.91\n20,1.74,1.04\n29,1.38,1.75\n30,1.31,1.66\n35,1.15,2.74\n53,1.33,2.21\n');};U1(288,1,{},jlb.SB);_.Ib=function TB(a,b){return Zkb.R3(this.a[a][b]);};_.Jb=function UB(){return jlb.QB(this);};Ykb.qZ=w3(288);jlb.VB=function VB(){this.a=ilb.Dz('99\nint,int,int,int,int\n1,1,1,1,0\n2,2,2,1,0\n3,3,3,1,0\n4,4,4,1,0\n5,5,5,5,0\n6,6,6,6,0\n7,7,7,6,0\n8,8,8,8,0\n9,9,9,8,0\n10,10,10,8,0\n11,11,11,11,0\n12,12,12,12,0\n13,13,13,13,0\n14,14,14,14,0\n15,15,15,15,0\n16,16,16,15,0\n17,17,17,15,0\n18,18,18,15,0\n19,19,19,19,0\n20,20,1,1,0\n21,21,21,5,0\n22,22,22,1,0\n23,23,23,5,0\n24,24,24,5,0\n25,25,25,25,0\n26,26,26,25,0\n27,27,28,5,0\n28,28,28,5,0\n29,29,29,5,0\n30,30,2,1,0\n31,31,31,31,0\n32,32,7,6,0\n33,33,21,5,0\n34,34,8,8,0\n35,35,6,6,0\n36,36,36,5,0\n37,37,2,1,0\n38,38,9,8,0\n39,39,10,8,0\n40,40,10,8,0\n41,41,3,1,0\n42,42,42,8,0\n43,43,10,8,0\n44,44,16,15,0\n45,45,10,8,0\n46,46,9,8,0\n47,47,42,8,0\n48,48,9,8,0\n49,49,6,6,0\n50,50,21,5,0\n51,51,7,6,0\n52,52,21,5,0\n53,53,42,8,0\n54,54,9,8,0\n55,55,10,8,0\n56,56,10,8,0\n57,57,2,1,0\n58,58,10,8,0\n59,59,6,6,0\n60,60,4,1,0\n61,61,42,8,0\n62,62,10,8,0\n63,63,2,1,0\n64,64,2,1,0\n65,65,9,8,0\n66,66,9,8,0\n67,67,9,8,0\n68,68,8,8,0\n69,69,9,8,0\n70,70,70,70,70\n71,71,5,5,0\n72,72,16,15,0\n73,73,18,15,0\n74,74,17,15,0\n75,75,26,25,0\n76,76,9,8,0\n77,77,12,12,0\n78,78,2,1,0\n79,79,9,8,0\n80,80,2,1,0\n81,81,10,8,0\n82,82,9,8,0\n83,0,0,0,0\n84,0,0,0,0\n85,0,0,0,0\n86,0,0,0,0\n87,87,87,87,87\n88,88,88,88,88\n89,89,89,89,89\n90,90,90,90,90\n91,91,91,91,91\n92,92,92,92,92\n93,93,93,93,93\n94,94,94,94,94\n95,95,95,95,95\n96,96,96,96,96\n97,97,97,97,97\n98,98,98,98,98\n99,99,99,99,99\n');};U1(290,1,{},jlb.VB);Ykb.rZ=w3(290);jlb.WB=function WB(a,b,c,d,e){var f,g,h,i;f=ilb.Wz(b.C[c]);g=ilb.Wz(b.C[d]);h=ilb.Wz(b.C[e]);f>h&&(f=(i=Zkb.t4(h),Zkb.t4(h=f),i).a);return ilb.kA(oW(aW(Ykb.AX,1),gmb,6,15,[1,0,2]),oW(aW(Ykb.AX,1),gmb,6,15,[g,f,h]),a);};jlb.XB=function XB(a,b,c,d,e){var f,g,h,i;f=ilb.Wz(b.C[c]);g=ilb.Wz(b.C[e]);h=f>g?4:3;i=jlb.WB(a,b,c,d,e);return i>=0?Zkb.Q3(a.a[i][h]):0;};jlb.YB=function YB(){this.a=ilb.Cz('30\nint,int,int,float,float\n0,1,0,0.15,0.15\n0,1,1,0.10,0.30\n0,1,2,0.05,0.35\n0,1,3,0.05,0.35\n0,1,4,0.05,0.35\n1,1,1,0.30,0.30\n1,1,2,0.30,0.50\n1,1,3,0.30,0.50\n1,1,4,0.30,0.50\n2,1,2,0.50,0.50\n2,1,3,0.50,0.50\n2,1,4,0.50,0.50\n3,1,3,0.50,0.50\n3,1,4,0.50,0.50\n4,1,4,0.50,0.50\n0,2,0,0.00,0.00\n0,2,1,0.00,0.15\n0,2,2,0.00,0.15\n0,2,3,0.00,0.15\n0,2,4,0.00,0.15\n1,2,1,0.30,0.30\n1,2,2,0.25,0.25\n1,2,3,0.25,0.25\n1,2,4,0.25,0.25\n2,2,2,0.25,0.25\n2,2,3,0.25,0.25\n2,2,4,0.25,0.25\n3,2,3,0.25,0.25\n3,2,4,0.25,0.25\n4,2,4,0.25,0.25\n');};U1(289,1,{},jlb.YB);_.Ib=function ZB(a,b){return Zkb.R3(this.a[a][b]);};_.Jb=function $B(){return this.a.length;};Ykb.sZ=w3(289);jlb._B=function _B(a,b,c){return Zkb.Q3(a.a[b][c]);};jlb.aC=function aC(){this.a=ilb.Cz('25\nint,int,float,float,float\n0,0,1.26,0.025,0.025\n0,1,1.66,0.30,0.36\n0,2,1.84,0.38,0.58\n0,3,1.98,0.49,0.65\n0,4,2.03,0.51,0.80\n0,5,2.03,0.25,0.81\n0,30,1.85,0.15,0.53\n0,40,1.84,0.61,0.61\n0,50,1.78,0.97,0.62\n1,1,1.91,0.68,0.68\n1,2,2.28,0.74,0.92\n1,3,2.35,0.85,1.02\n1,4,2.33,0.68,1.12\n1,5,2.50,0.97,1.22\n1,30,2.08,1.14,0.97\n1,40,2.34,1.17,1.08\n2,2,2.41,1.18,1.18\n2,3,2.52,1.02,1.28\n2,4,2.61,1.28,1.40\n2,5,2.60,0.84,1.24\n3,3,2.58,1.41,1.35\n3,4,2.66,0.86,1.48\n3,5,2.75,1.14,1.55\n4,4,2.85,1.62,1.62\n4,5,2.76,1.25,1.51\n');};U1(291,1,{},jlb.aC);_.Ib=function bC(a,b){return Zkb.R3(this.a[a][b]);};_.Jb=function cC(){return this.a.length;};Ykb.tZ=w3(291);jlb.dC=function dC(a,b,c,d,e,f){var g,h,i,j,k,l;g=b.a[c];k=oW(aW(Ykb.AX,1),gmb,6,15,[b.a[d],b.a[e],b.a[f]]);for(h=0;h<4;h++){l=gW(Ykb.AX,gmb,6,3,15,1);for(j=0;j<3;j++)l[j]=a.a.g.a[k[j]-1][h+1];alb.jgb(l,alb.Pgb(X1(dlb.ucb.prototype.kc,dlb.ucb,[])));i=ilb.kA(oW(aW(Ykb.AX,1),gmb,6,15,[1,0,2,3]),oW(aW(Ykb.AX,1),gmb,6,15,[g,l[0],l[1],l[2]]),a);if(i>=0)return Zkb.Q3(a.b[i][4]);}return 0;};jlb.eC=function eC(a,b){this.b=ilb.Cz(b);this.a=a;};U1(282,1,{},jlb.eC);_.Ib=function fC(a,b){return Zkb.R3(this.b[a][b]);};_.Jb=function gC(){return this.b.length;};Ykb.uZ=w3(282);jlb.hC=function hC(a,b,c,d,e){var f,g,h,i,j;f=b.a[c];g=b.a[d];h=b.a[e];i=klb.DC(a.a,b,c,d,e);f>h&&(f=(j=Zkb.t4(h),Zkb.t4(h=f),j).a);return ilb.kA(oW(aW(Ykb.AX,1),gmb,6,15,[2,1,3,0]),oW(aW(Ykb.AX,1),gmb,6,15,[g,f,h,i]),a);};jlb.iC=function iC(a,b,c,d,e){var f,g,h,i,j,k;f=b.a[c];g=b.a[e];i=klb.QC(a.a,b,c,d);j=klb.QC(a.a,b,d,e);k=jlb.hC(a,b,c,d,e);h=f>g||f==g&&i<j?1:0;if(k>=0)return Zkb.Q3(a.b[k][4+h]);return jlb.XB(a.a.i,b,c,d,e);};jlb.jC=function jC(a){this.b=ilb.Cz('282\nint,int,int,int,float,float\n0,1,1,1,0.206,0.206\n0,1,1,2,0.136,0.197\n0,1,1,3,0.211,0.092\n0,1,1,5,0.227,0.070\n0,1,1,6,0.173,0.417\n0,1,1,8,0.136,0.282\n0,1,1,10,0.187,0.338\n0,1,1,11,0.209,0.633\n0,1,1,12,0.176,0.386\n0,1,1,15,0.139,0.217\n0,1,1,34,0.236,0.436\n0,1,1,37,0.152,0.260\n0,1,1,39,0.144,0.595\n0,1,1,41,0.122,0.051\n0,1,1,56,0.262,0.451\n0,1,1,68,0.186,0.125\n0,2,1,2,0.282,0.282\n0,2,1,3,0.206,0.022\n0,2,1,5,0.234,0.088\n0,2,1,6,0.183,0.387\n0,2,1,8,0.214,0.363\n0,3,1,5,0.157,0.115\n0,3,1,6,-0.036,0.456\n0,3,1,10,0.038,0.195\n0,5,1,5,0.115,0.115\n0,5,1,6,0.013,0.436\n0,5,1,8,0.027,0.358\n0,5,1,9,0.040,0.418\n0,5,1,10,0.043,0.261\n0,5,1,11,0.003,0.452\n0,5,1,12,-0.018,0.380\n0,5,1,15,0.018,0.255\n0,5,1,18,0.121,0.218\n0,5,1,20,0.069,0.327\n0,5,1,22,0.055,0.267\n0,5,1,34,-0.003,0.342\n0,5,1,37,0.074,0.287\n0,5,1,39,0.092,0.607\n0,5,1,40,0.023,0.335\n0,5,1,41,0.093,0.118\n0,5,1,54,0.016,0.343\n0,5,1,55,0.030,0.397\n0,5,1,56,0.031,0.384\n0,5,1,68,0.041,0.216\n0,6,1,6,0.320,0.320\n0,6,1,37,0.310,0.160\n0,11,1,11,0.586,0.586\n0,12,1,12,0.508,0.508\n0,1,2,1,0.250,0.250\n0,1,2,2,0.203,0.207\n2,1,2,2,0.222,0.269\n2,1,2,3,0.244,0.292\n0,1,2,5,0.215,0.128\n2,1,2,37,0.246,0.260\n1,2,2,2,0.250,0.219\n2,2,2,3,0.155,0.112\n0,2,2,5,0.207,0.157\n1,2,2,5,0.267,0.159\n0,2,2,6,0.118,0.576\n2,2,2,37,0.143,0.172\n0,2,2,40,0.289,0.390\n0,2,2,41,0.191,-0.047\n1,3,2,5,0.264,0.156\n0,5,2,5,0.140,0.140\n0,5,2,6,0.213,0.502\n2,5,2,37,0.153,0.288\n0,5,2,40,0.070,0.463\n0,5,2,41,0.191,0.005\n0,1,3,1,0.358,0.358\n2,1,3,2,0.246,0.409\n2,1,3,3,0.303,0.145\n0,1,3,5,0.321,0.183\n0,1,3,6,0.338,0.732\n0,1,3,7,0.154,0.856\n0,1,3,10,0.223,0.732\n2,1,3,37,0.217,0.207\n1,2,3,5,0.407,0.159\n1,2,3,6,0.429,0.473\n1,2,3,7,0.214,0.794\n1,2,3,9,0.227,0.610\n1,2,3,10,0.298,0.600\n1,3,3,5,0.251,0.133\n1,3,3,6,0.066,0.668\n1,3,3,7,-0.093,0.866\n0,5,3,5,0.126,0.126\n0,5,3,6,0.174,0.734\n0,5,3,7,0.032,0.805\n0,5,3,9,0.037,0.669\n0,5,3,10,0.169,0.619\n0,5,3,40,0.087,0.685\n0,5,3,54,0.098,0.210\n0,6,3,7,0.494,0.578\n4,6,3,20,1.179,0.752\n2,6,3,37,0.350,0.175\n0,7,3,10,0.771,0.353\n0,7,3,20,0.865,-0.181\n2,7,3,37,0.707,0.007\n0,9,3,40,0.680,0.260\n0,10,3,10,1.050,1.050\n4,20,3,20,0.536,0.536\n0,40,3,40,0.482,0.482\n0,1,6,1,0.309,0.309\n0,1,6,2,0.157,0.375\n0,1,6,3,-0.153,0.252\n0,1,6,21,0.256,0.143\n0,1,6,37,0.163,0.375\n0,2,6,3,-0.228,0.052\n0,2,6,29,0.259,0.163\n4,3,6,20,0.456,0.379\n0,3,6,24,0.215,0.064\n0,3,6,37,-0.225,-0.320\n0,8,6,21,0.304,0.055\n0,10,6,21,0.419,0.158\n0,18,6,33,0.309,0.120\n4,20,6,20,0.739,0.739\n0,29,6,37,0.130,0.241\n0,31,6,31,0.227,0.227\n0,1,8,1,0.312,0.312\n0,1,8,6,0.212,0.354\n0,1,8,23,0.309,0.135\n0,6,8,23,0.418,0.020\n4,20,8,20,0.653,0.653\n0,20,8,23,0.128,0.122\n0,23,8,23,0.190,0.190\n0,1,9,3,0.326,0.580\n0,3,9,27,0.464,0.222\n0,1,10,1,0.063,0.063\n0,1,10,3,-0.021,0.340\n0,1,10,6,-0.024,0.374\n0,1,10,28,0.155,-0.051\n0,3,10,3,-0.219,-0.219\n0,3,10,6,0.497,0.513\n0,3,10,28,0.137,0.066\n0,28,10,28,0.081,0.081\n0,1,15,1,0.125,0.125\n0,1,15,15,0.012,0.238\n0,1,15,37,0.048,0.229\n0,1,15,71,0.080,-0.012\n0,15,15,71,0.172,-0.068\n0,37,15,71,0.187,-0.027\n0,71,15,71,0.045,0.045\n0,1,18,1,0.023,0.023\n0,1,18,6,0.003,0.213\n0,1,18,32,-0.091,0.390\n0,1,18,43,-0.008,0.607\n0,6,18,6,0.088,0.088\n0,6,18,32,0.123,0.369\n0,32,18,32,0.404,0.404\n0,32,18,43,0.384,0.281\n0,43,18,43,0.428,0.428\n0,1,20,5,0.290,0.098\n0,1,20,20,0.179,0.004\n0,3,20,5,-0.049,0.171\n4,3,20,20,0.607,0.437\n0,5,20,5,0.182,0.182\n0,5,20,6,0.051,0.312\n0,5,20,8,0.072,0.226\n0,5,20,12,0.014,0.597\n0,5,20,20,0.101,0.079\n0,5,20,30,0.108,0.123\n4,6,20,20,0.823,0.396\n4,8,20,20,0.701,0.369\n0,12,20,20,0.310,0.000\n4,20,20,20,0.283,0.283\n4,20,20,30,0.340,0.529\n0,1,22,5,0.067,0.174\n0,1,22,22,0.199,0.039\n0,5,22,5,0.254,0.254\n0,5,22,22,0.181,0.108\n5,22,22,22,0.000,0.000\n0,5,26,5,-0.121,-0.121\n0,5,30,20,0.251,0.007\n0,5,30,30,0.267,0.054\n4,20,30,30,0.413,0.705\n0,1,34,1,0.202,0.202\n0,1,34,36,0.160,-0.009\n0,36,34,36,0.087,0.087\n0,1,37,37,0.485,0.311\n1,2,37,37,0.321,0.235\n1,3,37,37,0.179,0.217\n0,5,37,37,0.279,0.250\n0,5,37,38,0.267,0.389\n0,5,37,63,0.216,0.434\n0,5,37,64,0.167,0.364\n0,5,37,69,0.273,0.391\n0,6,37,37,0.830,0.339\n0,15,37,37,0.650,0.259\n0,37,37,37,-0.411,-0.411\n0,37,37,38,-0.424,-0.466\n0,37,37,40,0.429,0.901\n0,37,37,63,-0.173,-0.215\n0,37,37,64,-0.229,-0.229\n0,37,37,69,-0.244,-0.555\n0,38,37,38,-0.516,-0.516\n0,37,38,37,-0.342,-0.342\n0,37,38,38,-0.164,-1.130\n0,1,39,63,0.313,0.500\n0,23,39,63,-0.131,0.422\n0,23,39,65,-0.122,0.281\n0,63,39,63,0.469,0.469\n0,63,39,65,0.741,0.506\n0,65,39,65,0.706,0.706\n0,1,40,28,0.238,0.091\n0,1,40,37,0.153,0.590\n0,2,40,28,0.342,0.156\n0,3,40,28,0.228,0.104\n0,28,40,28,0.094,0.094\n0,28,40,37,0.186,0.423\n0,1,41,32,0.503,0.943\n0,2,41,32,0.594,0.969\n0,5,41,32,0.276,0.852\n0,32,41,32,0.652,0.652\n0,18,43,23,0.377,0.057\n0,23,43,23,0.082,0.082\n0,63,44,63,0.591,0.591\n0,63,44,65,0.857,0.978\n0,50,49,50,0.072,0.072\n0,1,54,3,0.192,-0.051\n0,1,54,36,0.240,0.079\n0,3,54,36,0.005,0.127\n0,36,54,36,0.148,0.148\n0,1,55,36,0.189,0.033\n0,1,55,57,0.166,0.211\n0,36,55,36,0.106,0.106\n0,36,55,57,0.093,0.080\n0,1,56,36,0.211,-0.040\n0,1,56,57,0.026,0.386\n0,36,56,36,0.101,0.101\n0,36,56,57,0.108,0.068\n0,5,57,55,0.043,0.420\n0,55,57,55,0.125,0.125\n0,56,57,56,0.431,0.431\n0,58,57,58,0.732,0.732\n0,63,59,63,0.497,0.497\n0,63,59,65,0.723,0.874\n0,5,63,39,0.009,0.654\n0,5,63,44,-0.015,0.446\n0,5,63,59,0.067,0.588\n0,5,63,64,0.055,0.370\n0,5,63,66,0.110,0.464\n0,37,63,39,0.178,0.523\n0,37,63,64,-0.045,0.497\n0,39,63,64,0.422,0.409\n0,39,63,66,0.436,0.525\n0,44,63,64,0.581,0.426\n0,44,63,66,0.542,0.365\n0,59,63,64,0.852,0.332\n0,59,63,66,0.775,0.300\n0,5,64,63,0.086,0.345\n0,5,64,64,0.085,0.369\n0,5,64,65,0.051,0.436\n0,5,64,66,0.113,0.452\n0,37,64,63,0.059,0.299\n0,37,64,64,0.277,0.377\n0,63,64,64,0.206,0.030\n0,63,64,66,0.171,0.078\n0,64,64,65,0.079,0.403\n0,65,64,66,0.406,0.066\n0,39,65,64,0.528,0.644\n0,39,65,66,0.397,0.258\n0,44,65,64,0.816,0.543\n0,59,65,64,1.177,0.594\n0,63,66,64,0.213,-0.173\n0,63,66,66,0.234,0.077\n0,64,66,65,-0.149,0.383\n0,65,66,66,0.199,0.101\n0,1,68,1,0.217,0.217\n0,1,68,23,0.285,0.050\n0,1,68,32,-0.047,0.503\n0,23,68,23,0.145,0.145\n0,23,68,32,-0.182,0.504\n0,32,69,37,1.018,0.418\n0,37,69,37,-0.169,-0.169\n0,31,70,31,0.210,0.210\n0,5,78,78,0.279,0.250\n0,5,78,81,0.083,0.250\n0,78,78,81,-0.398,0.314\n0,5,80,81,-0.101,0.691\n0,81,80,81,0.732,0.732\n0,36,81,78,0.021,0.368\n0,36,81,80,0.018,0.422\n0,78,81,80,0.366,0.419\n');this.a=a;};U1(284,1,{},jlb.jC);_.Ib=function kC(a,b){return Zkb.R3(this.b[a][b]);};_.Jb=function lC(){return this.b.length;};Ykb.vZ=w3(284);jlb.mC=function mC(a,b,c,d,e,f){var g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G,H,I,J,K,L;k=b.a[c];l=b.a[d];m=b.a[e];n=b.a[f];J=klb.TC(a.a,b,c,d,e,f);K=J>10?J/10|0:J;L=J>10?J-K*10:0;B=-1;C=0;A=0;D=0;v=K;H=5;while(C<H&&(B==-1||H==4)||C==4&&K==5&&L>0){if(H==5&&C==4){H=4;C=0;v=L;}if(C==1){A=1;D=3;}else if(C==2){A=3;D=1;}else {A=C;D=C;}r=a.a.g.a[k-1][$wnd.Math.min(A+1,4)];s=l;t=m;u=a.a.g.a[n-1][$wnd.Math.min(D+1,4)];if(s>t){t=(G=Zkb.t4(s),Zkb.t4(s=t),G).a;u=(F=Zkb.t4(r),Zkb.t4(r=u),F).a;}else s==t&&r>u&&(u=(F=Zkb.t4(r),Zkb.t4(r=u),F).a);B=ilb.kA(oW(aW(Ykb.AX,1),gmb,6,15,[2,3,1,4,0]),oW(aW(Ykb.AX,1),gmb,6,15,[s,t,r,u,v]),a);if(B!=-1&&H==4)break;++C;}if(B>=0)return new jlb.sC(a,B);q=clb.tn(b,d,e);h=oW(aW(Ykb.yX,1),emb,6,15,[0,0]);i=oW(aW(Ykb.yX,1),emb,6,15,[0,0]);j=oW(aW(Ykb.yX,1),emb,6,15,[0,0]);o=oW(aW(Ykb.AX,1),gmb,6,15,[b.C[d],b.C[e]]);g=(jlb.oB(a.a.b,l)-1)*(jlb.oB(a.a.b,m)-1);for(w=0;w<2;w++){switch(o[w]){case 6:h[w]=2;i[w]=2.12;break;case 7:h[w]=2;i[w]=1.5;break;case 8:h[w]=2;i[w]=0.2;j[w]=2;break;case 14:h[w]=1.25;i[w]=1.22;break;case 15:h[w]=1.25;i[w]=2.4;break;case 16:h[w]=1.25;i[w]=0.49;j[w]=8;}}if(jlb.qB(a.a.b,l)||jlb.qB(a.a.b,m))return new jlb.rC(0,0);if(jlb.nB(a.a.b,l)&&jlb.nB(a.a.b,m)&&q<b.g&&clb.sr(b.p,q)){p=jlb.uB(a.a.b,l)==3&&jlb.uB(a.a.b,m)==4||jlb.uB(a.a.b,l)==4&&jlb.uB(a.a.b,m)==3?3:6;I=jlb.sB(a.a.b,l)==0&&jlb.sB(a.a.b,m)==0?0.5:0.3;return new jlb.rC(p*I*$wnd.Math.sqrt(h[0]*h[1]),0);}if(clb.Hk(b,q)==2){I=jlb.rB(a.a.b,l)==2&&jlb.rB(a.a.b,m)==2?1:0.4;return new jlb.rC(6*I*$wnd.Math.sqrt(h[0]*h[1]),0);}if(jlb.oB(a.a.b,l)==4&&jlb.oB(a.a.b,m)==4)return new jlb.rC(0,$wnd.Math.sqrt(i[0]*i[1])/g);if(jlb.oB(a.a.b,l)==4&&jlb.oB(a.a.b,m)!=4){return jlb.oB(a.a.b,m)==3&&(jlb.uB(a.a.b,m)==4||jlb.uB(a.a.b,m)==34||jlb.rB(a.a.b,m)>0)||jlb.oB(a.a.b,m)==2&&(jlb.uB(a.a.b,m)==3||jlb.rB(a.a.b,m)>0)?new jlb.qC():new jlb.rC(0,$wnd.Math.sqrt(i[0]*i[1])/g);}if(jlb.oB(a.a.b,m)==4&&jlb.oB(a.a.b,l)!=4){return jlb.oB(a.a.b,l)==3&&(jlb.uB(a.a.b,l)==4||jlb.uB(a.a.b,l)==34||jlb.rB(a.a.b,l)>0)||jlb.oB(a.a.b,l)==2&&(jlb.uB(a.a.b,l)==3||jlb.rB(a.a.b,l)>0)?new jlb.qC():new jlb.rC(0,$wnd.Math.sqrt(i[0]*i[1])/g);}if(clb.Hk(b,q)==1&&jlb.rB(a.a.b,l)>0&&jlb.rB(a.a.b,m)>0||jlb.rB(a.a.b,l)>0&&jlb.sB(a.a.b,m)>0||jlb.sB(a.a.b,l)>0&&jlb.rB(a.a.b,m)>0){if(jlb.sB(a.a.b,l)>0&&jlb.sB(a.a.b,m)>0)return new jlb.qC();if(jlb.sB(a.a.b,l)>0&&jlb.rB(a.a.b,m)>0){I=0;jlb.rB(a.a.b,l)==1?I=0.5:ilb.Wz(o[0])==2&&ilb.Wz(o[1])==2?I=0.3:(ilb.Wz(o[0])!=2||ilb.Wz(o[1])!=2)&&(I=0.15);return new jlb.rC(6*I*$wnd.Math.sqrt(h[0]*h[1]),0);}if(jlb.sB(a.a.b,m)>0&&jlb.rB(a.a.b,l)>0){I=0;jlb.rB(a.a.b,m)==1?I=0.5:ilb.Wz(o[0])==2&&ilb.Wz(o[1])==2?I=0.3:(ilb.Wz(o[0])!=2||ilb.Wz(o[1])!=2)&&(I=0.15);return new jlb.rC(6*I*$wnd.Math.sqrt(h[0]*h[1]),0);}if((jlb.rB(a.a.b,l)==1||jlb.rB(a.a.b,m)==1)&&(o[0]!=6||o[1]!=6))return new jlb.rC(2.4000000000000004*$wnd.Math.sqrt(h[0]*h[1]),0);return new jlb.rC(0.8999999999999999*$wnd.Math.sqrt(h[0]*h[1]),0);}if((o[0]==8||o[0]==16)&&(o[1]==8||o[1]==16))return new jlb.rC(-$wnd.Math.sqrt(j[0]*j[1]),0);return new jlb.rC(0,$wnd.Math.sqrt(i[0]*i[1])/g);};jlb.nC=function nC(a,b){this.b=ilb.Cz(b);this.a=a;};U1(285,1,{},jlb.nC);_.Ib=function oC(a,b){return Zkb.R3(this.b[a][b]);};_.Jb=function pC(){return this.b.length;};Ykb.xZ=w3(285);jlb.qC=function qC(){this.a=0;this.b=0;this.c=0;};jlb.rC=function rC(a,b){this.a=0;this.b=a;this.c=b;};jlb.sC=function sC(a,b){this.a=Zkb.Q3(a.b[b][5]);this.b=Zkb.Q3(a.b[b][6]);this.c=Zkb.Q3(a.b[b][7]);};U1(44,1,{},jlb.qC,jlb.rC,jlb.sC);_.lb=function tC(){return this.a+','+this.b+','+this.c;};_.a=0;_.b=0;_.c=0;Ykb.wZ=w3(44);jlb.uC=function uC(a,b){return Zkb.Q3(a.a[ilb.iA(0,b,0,a.a.length,true,a)][1]);};jlb.vC=function vC(a,b){return a.a[ilb.iA(0,b,0,a.a.length,true,a)][5].a;};jlb.wC=function wC(a,b){return Zkb.Q3(a.a[ilb.iA(0,b,0,a.a.length,true,a)][4]);};jlb.xC=function xC(a){return a.a.length;};jlb.yC=function yC(a,b){return Zkb.Q3(a.a[ilb.iA(0,b,0,a.a.length,true,a)][2]);};jlb.zC=function zC(a,b){var c;c=ilb.iA(0,b,0,a.a.length,true,a);return Zkb.Q3(a.a[c][3])*$wnd.Math.pow(Zkb.Q3(a.a[c][1]),0.25);};jlb.AC=function AC(){this.a=ilb.Cz("95\nint,float,float,float,float,char\n1,1.050,2.490,3.890,1.282,'-'\n2,1.350,2.490,3.890,1.282,'-'\n3,1.100,2.490,3.890,1.282,'-'\n4,1.300,2.490,3.890,1.282,'-'\n5,0.250,0.800,4.200,1.209,'-'\n6,0.700,3.150,3.890,1.282,'A'\n7,0.650,3.150,3.890,1.282,'A'\n8,1.150,2.820,3.890,1.282,'A'\n9,0.900,2.820,3.890,1.282,'A'\n10,1.000,2.820,3.890,1.282,'A'\n11,0.350,3.480,3.890,1.282,'A'\n12,2.300,5.100,3.320,1.345,'A'\n13,3.400,6.000,3.190,1.359,'A'\n14,5.500,6.950,3.080,1.404,'A'\n15,3.000,4.800,3.320,1.345,'A'\n16,3.900,4.800,3.320,1.345,'A'\n17,2.700,4.800,3.320,1.345,'-'\n18,2.100,4.800,3.320,1.345,'-'\n19,4.500,4.200,3.320,1.345,'-'\n20,1.050,2.490,3.890,1.282,'-'\n21,0.150,0.800,4.200,1.209,'D'\n22,1.100,2.490,3.890,1.282,'-'\n23,0.150,0.800,4.200,1.209,'D'\n24,0.150,0.800,4.200,1.209,'D'\n25,1.600,4.500,3.320,1.345,'-'\n26,3.600,4.500,3.320,1.345,'A'\n27,0.150,0.800,4.200,1.209,'D'\n28,0.150,0.800,4.200,1.209,'D'\n29,0.150,0.800,4.200,1.209,'D'\n30,1.350,2.490,3.890,1.282,'-'\n31,0.150,0.800,4.200,1.209,'D'\n32,0.750,3.150,3.890,1.282,'A'\n33,0.150,0.800,4.200,1.209,'D'\n34,1.000,2.820,3.890,1.282,'-'\n35,1.500,3.150,3.890,1.282,'A'\n36,0.150,0.800,4.200,1.209,'D'\n37,1.350,2.490,3.890,1.282,'-'\n38,0.850,2.820,3.890,1.282,'A'\n39,1.100,2.820,3.890,1.282,'-'\n40,1.000,2.820,3.890,1.282,'A'\n41,1.100,2.490,3.890,1.282,'-'\n42,1.000,2.820,3.890,1.282,'A'\n43,1.000,2.820,3.890,1.282,'A'\n44,3.000,4.800,3.320,1.345,'A'\n45,1.150,2.820,3.890,1.282,'-'\n46,1.300,2.820,3.890,1.282,'-'\n47,1.000,2.820,3.890,1.282,'A'\n48,1.200,2.820,3.890,1.282,'A'\n49,1.000,3.150,3.890,1.282,'-'\n50,0.150,0.800,4.200,1.209,'D'\n51,0.400,3.150,3.890,1.282,'-'\n52,0.150,0.800,4.200,1.209,'D'\n53,1.000,2.820,3.890,1.282,'-'\n54,1.300,2.820,3.890,1.282,'-'\n55,0.800,2.820,3.890,1.282,'-'\n56,0.800,2.820,3.890,1.282,'-'\n57,1.000,2.490,3.890,1.282,'-'\n58,0.800,2.820,3.890,1.282,'-'\n59,0.650,3.150,3.890,1.282,'A'\n60,1.800,2.490,3.890,1.282,'A'\n61,0.800,2.820,3.890,1.282,'A'\n62,1.300,2.820,3.890,1.282,'A'\n63,1.350,2.490,3.890,1.282,'-'\n64,1.350,2.490,3.890,1.282,'-'\n65,1.000,2.820,3.890,1.282,'A'\n66,0.750,2.820,3.890,1.282,'A'\n67,0.950,2.820,3.890,1.282,'A'\n68,0.900,2.820,3.890,1.282,'A'\n69,0.950,2.820,3.890,1.282,'A'\n70,0.870,3.150,3.890,1.282,'A'\n71,0.150,0.800,4.200,1.209,'D'\n72,4.000,4.800,3.320,1.345,'A'\n73,3.000,4.800,3.320,1.345,'-'\n74,3.000,4.800,3.320,1.345,'-'\n75,4.000,4.500,3.320,1.345,'A'\n76,1.200,2.820,3.890,1.282,'A'\n77,1.500,5.100,3.320,1.345,'A'\n78,1.350,2.490,3.890,1.282,'-'\n79,1.000,2.820,3.890,1.282,'A'\n80,1.000,2.490,3.890,1.282,'-'\n81,0.800,2.820,3.890,1.282,'-'\n82,0.950,2.820,3.890,1.282,'A'\n87,0.450,6.000,4.000,1.400,'-'\n88,0.550,6.000,4.000,1.400,'-'\n89,1.400,3.480,3.890,1.282,'A'\n90,4.500,5.100,3.320,1.345,'A'\n91,6.000,6.000,3.190,1.359,'A'\n92,0.150,2.000,4.000,1.300,'-'\n93,0.400,3.500,4.000,1.300,'-'\n94,1.000,5.000,4.000,1.300,'-'\n95,0.430,6.000,4.000,1.400,'-'\n96,0.900,5.000,4.000,1.400,'-'\n97,0.350,6.000,4.000,1.400,'-'\n98,0.400,6.000,4.000,1.400,'-'\n99,0.350,3.500,4.000,1.300,'-'\n");};U1(286,1,{},jlb.AC);_.Ib=function BC(a,b){return Zkb.R3(this.a[a][b]);};_.Jb=function CC(){return jlb.xC(this);};Ykb.yZ=w3(286);klb.DC=function DC(a,b,c,d,e){var f,g,h,i,j,k,l;f=b.a[c];g=b.a[e];j=klb.QC(a,b,c,d);l=klb.QC(a,b,d,e);i=f<=g?j:l;k=f<g?l:j;h=klb.EC(a,b,c,d,e);switch(h){case 1:return i>0||i==k?1:2;case 2:return 3;case 3:return 5;case 4:return 4;case 5:return i>0||i==k?6:7;case 6:return 8;case 7:return i>0||i==k?9:10;case 8:return 11;}return 0;};klb.EC=function EC(a,b,c,d,e){var f,g;f=klb.QC(a,b,c,d)+klb.QC(a,b,d,e);g=f;klb.FC(b,c,d,e,3)?g+=f>0?4:3:klb.FC(b,c,d,e,4)&&(g+=f>0?6:4);return g;};klb.FC=function FC(a,b,c,d,e){var f,g,h,i,j,k,l,m;m=(clb.Gt(a,7),a.p);j=new dlb.Ncb();dlb.Mcb(j,Zkb.t4(b));dlb.Mcb(j,Zkb.t4(c));dlb.Mcb(j,Zkb.t4(d));if(clb.tn(a,b,c)>=0&&clb.tn(a,c,d)>=0)for(k=0;k<m.i.a.length;k++)if(dlb.Bi(m.j,k).length==e){l=new dlb.Ncb();for(g=dlb.Bi(m.i,k),h=0,i=g.length;h<i;++h){f=g[h];dlb.Mcb(l,Zkb.t4(f));}if(dlb.Th(l,j))return true;}return false;};klb.GC=function GC(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z,$,ab,bb,cb,db,eb,fb,gb,hb,ib,jb,kb,lb,mb,nb,ob,pb,qb,rb,sb,tb,ub,vb,wb,xb,yb,zb,Ab,Bb,Cb,Db,Eb;if(b<a.f&&clb.rr(a.p,b)){if(klb.NC(a,b,5)){p=new dlb.Ri(a.q);s=new dlb.Ri(a.q);o=false;D=false;F=false;if(a.C[b]==6||a.C[b]==7){for(A=0;A<a.e[b];A++){zb=a.i[b][A];if(!klb.NC(a,zb,5))continue;klb.LC(a,b,zb)&&(a.C[zb]==8||a.C[zb]==16||a.C[zb]==7&&a.e[zb]+clb.Kn(a,zb)==3&&!klb.MC(a,zb))&&dlb.wi(p,Zkb.t4(zb));for(hb=0;hb<a.e[zb];hb++){Ab=a.i[zb][hb];if(Ab==b)continue;if(!klb.NC(a,Ab,5))continue;klb.LC(a,b,Ab)&&(a.C[Ab]==8||a.C[Ab]==16||a.C[Ab]==7&&a.e[Ab]+clb.Kn(a,Ab)==3&&!klb.MC(a,Ab))&&dlb.wi(s,Zkb.t4(Ab));}}for(n=new dlb.Obb(p);n.a<n.c.a.length;){m=dlb.Nbb(n).a;if(a.C[m]==8||a.C[m]==16){D=true;break;}}for(r=new dlb.Obb(s);r.a<r.c.a.length;){q=dlb.Nbb(r).a;if(a.C[q]==8||a.C[q]==16){F=true;break;}}for(w=0;w<p.a.length;w++)for(gb=w;gb<s.a.length;gb++)if(klb.LC(a,(alb.Dgb(w,p.a.length),p.a[w]).a,(alb.Dgb(gb,s.a.length),s.a[gb]).a)){o=true;break;}}switch(a.C[b]){case 6:if(s.a.length==0){nb=0;jb=0;lb=0;mb=0;for(w=0;w<a.e[b];w++){zb=a.i[b][w];if(a.C[zb]==7&&a.e[zb]+clb.Kn(a,zb)==3){++nb;a.s[zb]>0&&!klb.MC(a,zb)&&++jb;klb.NC(a,zb,5)&&++lb;klb.NC(a,zb,6)&&++mb;}}if((nb==2&&lb>0||nb==3&&lb==2)&&jb>0&&mb==0)return 80;}if(!(p.a.length==0^s.a.length==0)){Eb=true;Db=true;for(w=0;w<a.e[b];w++){zb=a.i[b][w];(a.C[zb]!=6||!klb.JC(a,zb))&&(Eb=false);klb.LC(a,b,zb)&&!(zb<a.f&&clb.rr(a.p,zb))&&(Db=false);}if(p.a.length==0&&s.a.length==0&&!Eb&&Db)return 78;if(p.a.length!=0&&p.a.length!=0&&(!o||!D&&!F))return 78;}if(p.a.length!=0&&(s.a.length==0||D))return 63;if(s.a.length!=0&&(p.a.length==0||F))return 64;break;case 7:if(klb.MC(a,b))return 82;if(p.a.length==0&&s.a.length==0){if(a.e[b]+clb.Kn(a,b)==3)return 39;return 76;}if(a.e[b]+clb.Kn(a,b)==3)if(p.a.length==0^s.a.length==0)return 81;if(p.a.length!=0&&(s.a.length==0||D))return 65;if(s.a.length!=0&&(p.a.length==0||F))return 66;if(p.a.length!=0&&s.a.length!=0)return 79;break;case 8:return 59;case 16:return 44;}}if(klb.NC(a,b,6)){switch(a.C[b]){case 6:return 37;case 7:if(klb.MC(a,b))return 69;if(a.e[b]+clb.Kn(a,b)==3)return 58;return 38;}}}switch(a.C[b]){case 3:if(a.j[b]==0)return 92;break;case 6:if(a.e[b]+clb.Kn(a,b)==4){if((!!a.p&&b<a.f?clb.gr(a.p,b):0)==3)return 22;if((!!a.p&&b<a.f?clb.gr(a.p,b):0)==4)return 20;return 1;}if(a.e[b]+clb.Kn(a,b)==3){ob=0;pb=0;rb=0;vb=0;u=0;for(A=0;A<a.e[b];A++){zb=a.i[b][A];clb.Hk(a,clb.tn(a,b,zb))==2&&(u=a.C[zb]);if(a.e[zb]+clb.Kn(a,zb)==1){a.C[zb]==8&&++rb;a.C[zb]==16&&++vb;}else a.C[zb]==7&&(a.e[zb]+clb.Kn(a,zb)==3?++pb:a.e[zb]+clb.Kn(a,zb)==2&&clb.Hk(a,clb.tn(a,b,zb))==2&&++ob);}if(pb>=2&&ob==0&&u==7){return 57;}if(rb==2||vb==2){return 41;}if((!!a.p&&b<a.f?clb.gr(a.p,b):0)==4&&u==6){return 30;}if(u==7||u==8||u==15||u==16){return 3;}return 2;}if(a.e[b]+clb.Kn(a,b)==2){return 4;}if(a.e[b]+clb.Kn(a,b)==1){return 60;}break;case 7:xb=0;db=false;for(B=0;B<a.e[b];B++){zb=a.i[b][B];a.C[zb]==8&&a.e[zb]+clb.Kn(a,zb)==1&&++xb;if(clb.Pn(a,b)+clb.Kn(a,b)>=3&&(a.C[zb]==15||a.C[zb]==16)){ub=0;for(gb=0;gb<a.e[zb];gb++){Ab=a.i[zb][gb];a.C[Ab]==8&&a.e[Ab]+clb.Kn(a,Ab)==1&&++ub;}db||(db=ub>=2);}}if(a.e[b]+clb.Kn(a,b)==4){if(klb.MC(a,b))return 68;return 34;}if(a.e[b]+clb.Kn(a,b)==3){if(clb.Pn(a,b)+clb.Kn(a,b)>=4){v=false;for(w=0;w<a.e[b];w++){zb=a.i[b][w];if(clb.Hk(a,clb.tn(a,b,zb))==2){v=a.C[zb]==7||a.C[zb]==6;if(a.C[zb]==6){for(gb=0;v&&gb<a.e[zb];gb++){Ab=a.i[zb][gb];if(Ab==b)continue;v=!(a.C[Ab]==7&&a.e[Ab]+clb.Kn(a,Ab)==3);}}}}if(xb==1)return 67;if(xb>=2)return 45;if(v)return 54;}if(clb.Pn(a,b)+clb.Kn(a,b)>=3){N=false;M=false;O=false;P=false;U=false;T=false;c=0;d=0;e=0;f=0;h=0;k=0;for(w=0;w<a.e[b];w++){zb=a.i[b][w];if(a.C[zb]==6){U=true;zb<a.f&&clb.rr(a.p,zb)&&(!!a.p&&zb<a.f?clb.gr(a.p,zb):0)==6&&(T=true);e=0;f=0;h=0;k=0;jb=0;C=0;for(gb=0;gb<a.e[zb];gb++){Ab=a.i[zb][gb];t=clb.tn(a,zb,Ab);clb.Hk(a,t)==2&&(a.C[Ab]==8||a.C[Ab]==16)&&(N=true);(clb.Hk(a,t)==2||t<a.g&&clb.sr(a.p,t)&&(a.C[Ab]==6||a.C[Ab]==7&&klb.KC(a,Ab)==1))&&(c=a.C[Ab]);clb.Hk(a,t)==3&&(d=a.C[Ab]);if(a.C[Ab]==7&&a.e[Ab]+clb.Kn(a,Ab)==3){a.s[Ab]==1&&++jb;klb.NC(a,zb,6)&&++C;j=0;for(ib=0;ib<a.e[Ab];ib++){Bb=a.i[Ab][ib];a.C[Bb]==8&&++j;}j<2&&++f;}a.C[Ab]==7&&a.e[Ab]+clb.Kn(a,Ab)==2&&(clb.Hk(a,t)==2||t<a.g&&clb.sr(a.p,t))&&++e;if(Ab<a.f&&clb.rr(a.p,Ab)){a.C[Ab]==8&&++h;a.C[Ab]==16&&++k;}}if(c==7){f==2&&e==0&&jb>0&&C==0&&a.e[zb]+clb.Kn(a,zb)<4&&(M=true);f==3&&(O=true);}}else if(a.C[zb]==7){g=0;i=0;l=0;for(gb=0;gb<a.e[zb];gb++){Ab=a.i[zb][gb];t=clb.tn(a,zb,Ab);if(clb.Hk(a,t)==2){if(a.C[Ab]==6){for(ib=0;ib<a.e[Ab];ib++){Bb=a.i[Ab][ib];if(Bb==b)continue;a.C[Bb]==7?++g:a.C[Bb]==8?++i:a.C[Bb]==16&&++l;}g==0&&i==0&&l==0&&!T&&(P=true);}a.C[Ab]==7&&!T&&(P=true);}}}}if(U){d==7&&(db=true);if(M)return 55;if(O)return 56;if(!N&&!db&&(h==0&&k==0&&T||c==6||c==7||c==15||d==6))return 40;}if(!db&&(N||P))return 10;}}if(a.e[b]+clb.Kn(a,b)==2){if(clb.Pn(a,b)+clb.Kn(a,b)==4){K=false;for(w=0;!K&&w<a.e[b];w++){zb=a.i[b][w];K=clb.Hk(a,clb.tn(a,b,zb))==3;}if(K)return 61;return 53;}if(clb.Pn(a,b)+clb.Kn(a,b)==3){W=false;J=false;for(w=0;w<a.e[b];w++){zb=a.i[b][w];if(clb.Hk(a,clb.tn(a,b,zb))==2){W=a.C[zb]==8&&xb==1;J=a.C[zb]==6||a.C[zb]==7;}}if(W&&!J)return 46;if(J)return 9;}if(clb.Pn(a,b)+clb.Kn(a,b)>=2){R=false;for(w=0;w<a.e[b];w++){zb=a.i[b][w];if(a.C[zb]==16){yb=0;for(gb=0;gb<a.e[zb];gb++){Ab=a.i[zb][gb];a.C[Ab]==8&&a.e[Ab]+clb.Kn(a,Ab)==1&&++yb;}R=yb==1;}}if(R)return 48;if(!db)return 62;}}if(db)return 43;if(a.e[b]+clb.Kn(a,b)==1){S=false;L=false;for(w=0;!S&&!L&&w<a.e[b];w++){zb=a.i[b][w];S=clb.Hk(a,clb.tn(a,b,zb))==3;if(a.C[zb]==7&&a.e[zb]+clb.Kn(a,zb)==2){for(gb=0;!L&&gb<a.e[zb];gb++){Ab=a.i[zb][gb];L=a.C[Ab]==7&&a.e[Ab]+clb.Kn(a,Ab)==2||a.C[Ab]==6&&a.e[Ab]+clb.Kn(a,Ab)==3;}}}if(S)return 42;if(L)return 47;}return 8;case 8:if(a.e[b]+clb.Kn(a,b)==3)return 49;if(a.e[b]+clb.Kn(a,b)==2){if(clb.Pn(a,b)+clb.Kn(a,b)==3)return 51;kb=0;for(w=0;w<a.e[b];w++){zb=a.i[b][w];a.C[zb]==1&&++kb;}if(kb+clb.Kn(a,b)==2)return 70;return 6;}if(a.j[b]<=1){qb=0;tb=0;wb=0;$=a.e[b]-a.j[b]+clb.Kn(a,b)>0;H=false;G=false;Z=false;X=false;ab=false;Q=false;V=false;fb=false;cb=false;eb=false;bb=false;for(w=0;w<a.e[b];w++){if($)break;if(H)break;if(G)break;if(Z)break;if(X)break;if(ab)break;if(Q)break;if(V)break;if(fb)break;if(cb)break;if(eb)break;if(bb)break;zb=a.i[b][w];if(a.C[zb]==6||a.C[zb]==7||a.C[zb]==16){for(gb=0;gb<a.e[zb];gb++){Ab=a.i[zb][gb];a.C[Ab]==7&&a.e[Ab]+clb.Kn(a,Ab)==2&&++qb;a.C[Ab]==8&&a.e[Ab]+clb.Kn(a,Ab)==1&&++tb;a.C[Ab]==16&&a.e[Ab]+clb.Kn(a,Ab)==1&&++wb;}}$=a.C[zb]==1;if(a.C[zb]==6){H=tb==2;G=clb.Hk(a,clb.tn(a,b,zb))==2;Z=clb.Hk(a,clb.tn(a,b,zb))==1&&tb==1;}if(a.C[zb]==7){X=clb.Hk(a,clb.tn(a,b,zb))==2;if(clb.Hk(a,clb.tn(a,b,zb))==1&&tb==1){ab=a.e[zb]+clb.Kn(a,zb)==2||clb.Pn(a,zb)+clb.Kn(a,zb)==3;Q=clb.Pn(a,zb)+clb.Kn(a,zb)==4;}V=tb>=2;}if(a.C[zb]==16){fb=wb==1;cb=clb.Hk(a,clb.tn(a,b,zb))==1||clb.Hk(a,clb.tn(a,b,zb))==2&&tb+qb>1;eb=clb.Hk(a,clb.tn(a,b,zb))==2&&tb+qb==1;}bb=a.C[zb]==15||a.C[zb]==17;}if(Z||ab||$)return 35;if(H||V||Q||fb||cb||bb)return 32;if(G||X||eb)return 7;}break;case 9:if(a.j[b]==1)return 11;if(a.j[b]==0)return 89;break;case 11:if(a.j[b]==0)return 93;break;case 12:if(a.j[b]==0)return 99;break;case 14:return 19;case 15:if(a.e[b]+clb.Kn(a,b)==4)return 25;if(a.e[b]+clb.Kn(a,b)==3)return 26;if(a.e[b]+clb.Kn(a,b)==2)return 75;break;case 16:if(a.e[b]+clb.Kn(a,b)==3||a.e[b]+clb.Kn(a,b)==4){sb=0;wb=0;I=false;for(w=0;w<a.e[b];w++){zb=a.i[b][w];a.C[zb]==6&&clb.Hk(a,clb.tn(a,b,zb))==2&&(I=true);(a.j[zb]==1&&a.C[zb]==8||a.e[zb]+clb.Kn(a,zb)==2&&a.C[zb]==7)&&++sb;a.j[zb]==1&&a.C[zb]==16&&++wb;}if(a.e[b]+clb.Kn(a,b)==3&&sb==2&&I||a.e[b]+clb.Kn(a,b)==4)return 18;if(sb>0&&wb>0||sb==2&&!I)return 73;return 17;}if(a.e[b]+clb.Kn(a,b)==2){Y=false;for(w=0;w<a.e[b];w++){zb=a.i[b][w];a.C[zb]==8&&clb.Hk(a,clb.tn(a,b,zb))==2&&(Y=true);}if(Y)return 74;return 15;}if(a.e[b]+clb.Kn(a,b)==1){Cb=0;I=false;for(w=0;w<a.e[b];w++){zb=a.i[b][w];for(gb=0;gb<a.e[zb];gb++){Ab=a.i[zb][gb];a.C[Ab]==16&&a.e[Ab]+clb.Kn(a,Ab)==1&&++Cb;}a.C[zb]==6&&clb.Hk(a,clb.tn(a,b,zb))==2&&(I=true);}if(I&&Cb!=2)return 16;return 72;}break;case 17:if(a.j[b]==4){rb=0;for(w=0;w<a.e[b];w++){zb=a.i[b][w];a.C[zb]==8&&++rb;}if(rb==4)return 77;}if(a.j[b]==1)return 12;if(a.j[b]==0)return 90;break;case 19:if(a.j[b]==0)return 94;break;case 20:if(a.j[b]==0)return 96;break;case 26:if(a.j[b]==0){if(a.s[b]==2)return 87;if(a.s[b]==3)return 88;}break;case 29:if(a.j[b]==0){if(a.s[b]==1)return 97;if(a.s[b]==2)return 98;}break;case 30:if(a.j[b]==0)return 95;break;case 35:if(a.j[b]==1)return 13;if(a.j[b]==0)return 91;break;case 53:if(a.j[b]==1)return 14;}return 0;};klb.HC=function HC(a,b){var c,d,e,f,g,h,i,j,k,l,m;for(d=0;d<a.e[b];d++){k=a.i[b][d];switch(a.C[k]){case 6:return 5;case 7:switch(klb.GC(a,k)){case 8:case 39:case 62:case 67:case 68:return 23;case 34:case 54:case 55:case 56:case 58:case 81:return 36;case 9:return 27;default:return 28;}case 8:switch(klb.GC(a,k)){case 49:return 50;case 51:return 52;case 70:return 31;case 6:e=false;f=false;g=false;h=false;for(i=0;i<a.e[k];i++){l=a.i[k][i];if(a.C[l]==6){for(j=0;j<a.e[l];j++){m=a.i[l][j];if(m==k)continue;c=clb.tn(a,l,m);(a.C[m]==6||a.C[m]==7)&&(clb.Hk(a,c)==2||c<a.g&&clb.sr(a.p,c))&&(e=true);a.C[m]==8&&clb.Hk(a,c)==2&&(f=true);}}a.C[l]==15&&(g=true);a.C[l]==16&&(h=true);}if(f||g)return 24;if(e)return 29;if(h)return 33;default:return 21;}case 14:return 5;case 16:case 15:return 71;}}return 0;};klb.IC=function IC(a,b){if(a.a[b]>-1)return a.a[b];return a.C[b]==1?klb.HC(a,b):klb.GC(a,b);};klb.JC=function JC(a,b){var c,d;if((a.u[b]&bob)!=0){d=(clb.Gt(a,7),a.p);for(c=0;c<d.i.a.length;c++)if(dlb.Bi(d.j,c).length==6&&clb.tr(d,c,b))return true;}return false;};klb.KC=function KC(a,b){var c,d,e;e=(clb.Gt(a,7),a.p);d=0;for(c=0;c<e.i.a.length;c++)clb.fr(e,c,b)>=0&&++d;return d;};klb.LC=function LC(a,b,c){var d,e;if((a.u[b]&bob)==0||(a.u[c]&bob)==0)return false;e=(clb.Gt(a,7),a.p);for(d=0;d<e.i.a.length;d++)if(dlb.Bi(e.j,d).length==5&&clb.tr(e,d,b)&&clb.tr(e,d,c))return true;return false;};klb.MC=function MC(a,b){var c,d;if(a.C[b]==7&&a.e[b]+clb.Kn(a,b)>=3){for(c=0;c<a.e[b];c++){d=a.i[b][c];if(a.C[d]==8&&a.e[d]+clb.Kn(a,d)==1)return true;}}return false;};klb.NC=function NC(a,b,c){var d,e;if(b<a.f&&clb.rr(a.p,b)){e=(clb.Gt(a,7),a.p);for(d=0;d<e.i.a.length;d++){if(dlb.Bi(e.j,d).length!=c||!clb.tr(e,d,b))continue;if(a.b[d]==0)return true;}}return false;};klb.OC=function OC(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r;r=(clb.Gt(a,7),a.p);if(!r.d[b])return 1;if(dlb.Bi(r.j,b).length==6){for(d=dlb.Bi(r.i,b),e=0,f=d.length;e<f;++e){c=d[e];if(clb.Pn(a,c)+clb.Kn(a,c)!=a.e[c]+clb.Kn(a,c)+1)return 1;}for(i=dlb.Bi(r.j,b),j=0,k=i.length;j<k;++j){h=i[j];l=oW(aW(Ykb.AX,1),gmb,6,15,[-1,-1]);if(clb.Hk(a,h)==1){for(n=0;n<=1;n++){g=a.D[n][h];for(m=0;m<a.e[g];m++){o=a.i[g][m];if(!clb.tr(r,b,o)&&clb.Hk(a,clb.tn(a,g,o))==2){l[n]=o;break;}}}if(l[0]>-1&&l[1]>-1){for(q=0;q<r.i.a.length;q++){if(clb.tr(r,q,l[0])&&clb.tr(r,q,l[1])&&a.b[q]==2)return 2;if(clb.tr(r,q,l[0])&&clb.tr(r,q,l[1])&&a.b[q]!=0)return 1;}}}}}if(dlb.Bi(r.j,b).length==5){p=1;for(d=dlb.Bi(r.i,b),e=0,f=d.length;e<f;++e){c=d[e];if(clb.Pn(a,c)+clb.Kn(a,c)==a.e[c]+clb.Kn(a,c)&&p>0){--p;continue;}if(clb.Pn(a,c)+clb.Kn(a,c)!=a.e[c]+clb.Kn(a,c)+1){return 1;}}}return 0;};klb.PC=function PC(a,b,c){return klb.QC(a,b,b.D[0][c],b.D[1][c]);};klb.QC=function QC(a,b,c,d){var e,f,g,h,i,j,k,l,m,n;e=b.a[c];f=b.a[d];k=clb.tn(b,c,d);l=true;n=(clb.Gt(b,7),b.p);for(m=0;m<n.i.a.length&&l;m++){for(h=dlb.Bi(n.j,m),i=0,j=h.length;i<j;++i){g=h[i];if(g==k&&b.b[m]==0){l=false;break;}}}return clb.Hk(b,k)==1&&l&&(jlb.nB(a.b,e)&&jlb.nB(a.b,f)||jlb.tB(a.b,e)&&jlb.tB(a.b,f))?1:0;};klb.RC=function RC(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r;h=klb.SC(b);g=gW(Ykb.yX,emb,6,h.length,15,1);for(d=0;d<h.length;d++){q=b.a[d];n=h[d];r=jlb.JB(a.e,q);c=jlb.oB(a.b,q);o=0;p=0;if($wnd.Math.abs(r)<jqb)for(j=0;j<b.e[d];j++){l=b.i[d][j];h[l]<0&&(n+=h[l]/(2*b.e[l]));}if(q==62)for(k=0;k<b.e[d];k++){l=b.i[d][k];h[l]>0&&(n-=h[l]/2);}for(i=0;i<b.e[d];i++){l=b.i[d][i];e=clb.tn(b,d,l);m=b.a[l];f=klb.QC(a,b,b.D[0][e],b.D[1][e]);p+=jlb.KB(a.e,f,q,m);o+=h[l];}g[d]=(1-c*r)*n+r*o+p;}return g;};klb.SC=function SC(a){var b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C;g=gW(Ykb.yX,emb,6,a.q,15,1);D:for(f=0;f<g.length;f++){C=a.a[f];g[f]=0;switch(C){case 32:case 72:for(j=0;j<a.e[f];j++){r=a.i[f][j];u=a.a[r];p=0;q=0;for(l=0;l<a.e[r];l++){s=a.i[r][l];a.C[s]==7&&a.e[s]+clb.Kn(a,s)==2&&!(s<a.f&&clb.rr(a.p,s))&&++p;(a.C[s]==8||a.C[s]==16)&&a.e[s]+clb.Kn(a,s)==1&&++q;}a.C[r]==16&&q==2&&p==1&&(p=0);if(a.C[r]==6&&q>0){g[f]=q==1?-1:-(q-1)/q;continue D;}if(u==45&&q==3){g[f]=-0.3333333333333333;continue D;}if(u==25&&q>0){g[f]=q==1?0:-(q-1)/q;continue D;}if(u==18&&q>0){g[f]=p+q==2?0:-(p+q-2)/q;continue D;}if(u==73&&q>0){g[f]=q==1?0:-(q-1)/q;continue D;}if(u==77&&q>0){g[f]=-1/q;continue D;}}break;case 76:A=0;B=(clb.Gt(a,7),a.p);for(w=0;w<B.i.a.length;w++)if(clb.tr(B,w,f)){A=w;break;}if(A<B.i.a.length){o=0;for(c=dlb.Bi(B.i,A),d=0,e=c.length;d<e;++d){b=c[d];b>-1&&a.a[b]==76&&++o;}if(o>0){g[f]=-1/o;continue D;}}break;case 55:case 56:case 81:g[f]=a.s[f];n=1;v=0;h=gW(Ykb.Z0,Amb,6,a.q,16,1);h[f]=true;while(n>v){v=n;for(k=0;k<a.q;k++){if(!h[k])continue;for(l=0;l<a.e[k];l++){r=a.i[k][l];u=a.a[r];if(u!=57&&u!=80)continue;for(m=0;m<a.e[r];m++){s=a.i[r][m];t=a.a[s];if(t!=55&&t!=56&&t!=81)continue;if(h[s])continue;h[s]=true;g[f]+=a.s[s];++n;}}}}g[f]/=n;continue D;case 61:for(i=0;i<a.e[f];i++){r=a.i[f][i];if(a.a[r]==42){g[f]=1;continue D;}}continue D;case 34:case 49:case 51:case 54:case 58:case 92:case 93:case 94:case 97:g[f]=1;continue D;case 87:case 95:case 96:case 98:case 99:g[f]=2;continue D;case 88:g[f]=3;continue D;case 35:case 62:case 89:case 90:case 91:g[f]=-1;continue D;}g[f]=0;}return g;};klb.TC=function TC(a,b,c,d,e,f){var g,h,i,j,k,l;j=clb.tn(b,d,e);g=klb.QC(a,b,c,d);h=klb.QC(a,b,d,e);i=klb.QC(a,b,e,f);l=h;h==0&&clb.Hk(b,j)==1&&(g==1||i==1)&&(l=2);k=klb.UC(b,c,d,e,f);if(k==4&&clb.tn(b,c,e)==-1&&clb.tn(b,d,f)==-1)return 40+l;if(k==5&&(b.a[c]==1||b.a[d]==1||b.a[e]==1||b.a[f]==1))return 50+l;return l;};klb.UC=function UC(a,b,c,d,e){var f,g,h,i,j,k,l,m;if(clb.tn(a,b,c)==-1||clb.tn(a,c,d)==-1||clb.tn(a,d,e)==-1)return 0;if(clb.tn(a,e,b)>=0)return 4;l=(clb.Gt(a,7),a.p);m=new dlb.Ncb();dlb.Mcb(m,Zkb.t4(b));dlb.Mcb(m,Zkb.t4(c));dlb.Mcb(m,Zkb.t4(d));dlb.Mcb(m,Zkb.t4(e));for(j=0;j<l.i.a.length;j++)if(dlb.Bi(l.j,j).length==5){k=new dlb.Ncb();for(g=dlb.Bi(l.i,j),h=0,i=g.length;h<i;++h){f=g[h];dlb.Mcb(k,Zkb.t4(f));}if(dlb.Th(k,m))return 5;}return 0;};U1(314,1,{});Ykb.zZ=w3(314);llb.VC=function VC(a){};llb.WC=function WC(a){var b,c,d;b=0;c=0;for(d=0;d<a.g.a.length+a.f.a.length;d++){b+=clb.vk(d<a.g.a.length?dlb.Bi(a.g,d):dlb.Bi(a.f,d-a.g.a.length))*(d<a.g.a.length?dlb.Bi(a.g,d):dlb.Bi(a.f,d-a.g.a.length)).r;c+=(d<a.g.a.length?dlb.Bi(a.g,d):dlb.Bi(a.f,d-a.g.a.length)).r;}if(c!=0)return c/b;return 1;};llb.XC=function XC(b,c){var d,e,f,g;llb.VC(this);e=new nlb.UE(b);try{g=new Alb.w2();Zkb.y5(g.a,'$RXN\n');Zkb.y5(g.a,c!=null?c:'');Zkb.y5(g.a,'\n\n');Alb.v2(g,Fqb+nlb.bF(b,true,27));Zkb.y5(g.a,Klb);Alb.v2(g,'  '+e.g.a.length+'  '+e.f.a.length+Klb);f=llb.WC(e);for(d=0;d<e.g.a.length+e.f.a.length;d++){Zkb.y5(g.a,'$MOL\n');clb.mq(new clb.pq(d<e.g.a.length?dlb.Bi(e.g,d):dlb.Bi(e.f,d-e.g.a.length),f,null),g);}this.a=g.a;}catch(a){a=b1(a);if(mX(a,15)){Zkb.O5();}else throw c1(a);}};U1(226,1,{},llb.XC);_.a=null;Ykb.AZ=w3(226);llb.YC=function YC(a){var b,c;b=new nlb.TE();c=new Alb.q2(new Alb.u2(a));llb.ZC(b,c);return b;};llb.ZC=function ZC(a,b){var c,d;d=Alb.p2(b);c=false;if(d==null||!Zkb.c5(alb.Pgb(d).substr(0,4),'$RXN')){throw c1(new Zkb.rz("'$RXN' tag not found"));}Zkb.c5(d,'$RXN V3000')?c=llb._C(a,b,false):c=llb.$C(a,b,false);return c;};llb.$C=function $C(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o;j=Zkb.q5(Alb.p2(b));alb.Pgb(j).length!=0&&(a.e=j);Alb.p2(b);d=Alb.p2(b);if(!c&&Zkb.c5(alb.Pgb(d).substr(0,13),Fqb)){e=(alb.Kgb(13,alb.Pgb(d).length+1),alb.Pgb(d).substr(13));if(nlb.aF(e,a))return true;}o=Alb.p2(b);n=Zkb.P3(Zkb.q5((alb.Jgb(0,3,alb.Pgb(o).length),alb.Pgb(o).substr(0,3))),oob,Qlb);l=Zkb.P3(Zkb.q5((alb.Jgb(3,6,alb.Pgb(o).length),alb.Pgb(o).substr(3,3))),oob,Qlb);h=new clb.Nq();for(g=0;g<n;g++){o=Alb.p2(b);if(o==null||!Zkb.c5(alb.Pgb(o).substr(0,4),'$MOL')){throw c1(new Zkb.rz(Gqb));}m=new clb.Yt();i=new Zkb.A5();do{o=Alb.p2(b);i.a+=''+o;i.a+=Klb;}while(o!=null&&!Zkb.c5(alb.Pgb(o).substr(0,6),pob));if(o==null){throw c1(new Zkb.rz(Hqb));}clb.Jq(h,m,new Alb.q2(new Alb.u2(i.a)));dlb.wi(a.g,m);a.d=-1;}for(f=0;f<l;f++){o=Alb.p2(b);if(o==null||!Zkb.c5(alb.Pgb(o).substr(0,4),'$MOL')){throw c1(new Zkb.rz(Gqb));}k=new clb.Yt();i=new Zkb.A5();do{o=Alb.p2(b);i.a+=''+o;i.a+=Klb;}while(o!=null&&!Zkb.c5(alb.Pgb(o).substr(0,6),pob));if(o==null){throw c1(new Zkb.rz(Hqb));}clb.Jq(h,k,new Alb.q2(new Alb.u2(i.a)));dlb.wi(a.f,k);a.d=-1;}return true;};llb._C=function _C(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o;j=Zkb.q5(Alb.p2(b));alb.Pgb(j).length!=0&&(a.e=j);Alb.p2(b);d=Alb.p2(b);if(!c&&Zkb.c5(alb.Pgb(d).substr(0,13),Fqb)){e=(alb.Kgb(13,alb.Pgb(d).length+1),alb.Pgb(d).substr(13));if(nlb.aF(e,a))return true;}o=Alb.p2(b);g=new clb.Nq();if(o!=null&&Zkb.c5(alb.Pgb(o).substr(0,13),'M  V30 COUNTS')){n=Zkb.q5((alb.Kgb(13,alb.Pgb(o).length+1),alb.Pgb(o).substr(13)));k=Zkb.n5(n,' ');m=Zkb.P3(k[0],oob,Qlb);l=Zkb.P3(k[1],oob,Qlb);if(m>0){o=Alb.p2(b);if(Zkb.c5('M  V30 BEGIN REACTANT',o)){for(f=0;f<m;f++){h=new clb.Yt();i=new Zkb.A5();i.a+=Iqb;do{o=Alb.p2(b);i.a+=''+o;i.a+=Klb;}while(o!=null&&!Zkb.c5(alb.Pgb(o).substr(0,15),Jqb));clb.Jq(g,h,new Alb.q2(new Alb.u2(i.a)));dlb.wi(a.g,h);a.d=-1;}}o=Alb.p2(b);}if(l>0){o=Alb.p2(b);if(Zkb.c5('M  V30 BEGIN PRODUCT',o)){for(f=0;f<l;f++){h=new clb.Yt();i=new Zkb.A5();i.a+=Iqb;do{o=Alb.p2(b);i.a+=''+o;i.a+=Klb;}while(o!=null&&!Zkb.c5(alb.Pgb(o).substr(0,15),Jqb));clb.Jq(g,h,new Alb.q2(new Alb.u2(i.a)));dlb.wi(a.f,h);a.d=-1;}o=Alb.p2(b);}}return true;}return false;};llb.aD=function aD(a){};llb.bD=function bD(a){var b,c,d;b=0;c=0;for(d=0;d<a.g.a.length+a.f.a.length;d++){b+=clb.vk(d<a.g.a.length?dlb.Bi(a.g,d):dlb.Bi(a.f,d-a.g.a.length))*(d<a.g.a.length?dlb.Bi(a.g,d):dlb.Bi(a.f,d-a.g.a.length)).r;c+=(d<a.g.a.length?dlb.Bi(a.g,d):dlb.Bi(a.f,d-a.g.a.length)).r;}if(c!=0)return c/b;return 1;};llb.cD=function cD(b,c){var d,e,f,g,h,i;llb.aD(this);g=new nlb.UE(b);try{i=new Alb.w2();Zkb.y5(i.a,'$RXN V3000\n');Zkb.y5(i.a,c!=null?c:'');Zkb.y5(i.a,'\n\n');Alb.v2(i,Fqb+nlb.bF(b,true,11));Zkb.y5(i.a,Klb);f=g.g.a.length;e=g.f.a.length;Zkb.y5(i.a,(alb.Jgb(f,f+e,alb.Pgb(sob+f+' '+e+Klb).length),alb.Pgb(sob+f+' '+e+Klb).substr(f,f+e-f)));h=llb.bD(g);if(f>0){Zkb.y5(i.a,'M  V30 BEGIN REACTANT\n');for(d=0;d<g.g.a.length;d++){Alb.v2(i,clb.Xq(dlb.Bi(g.g,d),h));}Zkb.y5(i.a,'M  V30 END REACTANT\n');}if(e>0){Zkb.y5(i.a,'M  V30 BEGIN PRODUCT\n');for(d=0;d<g.f.a.length;d++){Alb.v2(i,clb.Xq(dlb.Bi(g.f,d),h));}Zkb.y5(i.a,'M  V30 END PRODUCT\n');}Zkb.y5(i.a,mob);this.a=i.a;}catch(a){a=b1(a);if(mX(a,15)){Zkb.O5();}else throw c1(a);}};U1(227,1,{},llb.cD);_.a=null;Ykb.BZ=w3(227);llb.eD=function eD(){llb.eD=W1;llb.dD=oW(aW(Ykb.l_,1),Xlb,2,6,['Idorsia No','Actelion No','ID','IDNUMBER','COMPOUND_ID','NAME','COMPND']);};llb.fD=function fD(b){var c,d,e,f,g,h,i,j,k;if(!b.g)return false;Zkb.B2(b.f,0);Zkb.B2(b.a,0);b.e=null;k=false;d=-1;e=null;b.b=b.c==null?null:gW(Ykb.l_,Xlb,2,b.c.length,6,1);b.d=-1;do{try{j=Alb.p2(b.g);if(j==null){Zkb.B2(b.f,0);return false;}}catch(a){a=b1(a);if(mX(a,73)){Zkb.B2(b.f,0);return false;}else throw c1(a);}if(k){Zkb.G5(b.a,j);Zkb.C5(b.a,10);}else {if(Zkb.c5(alb.Pgb(j).substr(0,1),'>')){k=true;Zkb.G5(b.f,pob);Zkb.C5(b.f,10);Zkb.G5(b.a,j);Zkb.C5(b.a,10);}else {Zkb.G5(b.f,j);Zkb.C5(b.f,10);Zkb.c5(alb.Pgb(j).substr(0,6),pob)&&(k=true);continue;}}if(b.c!=null){if(alb.Pgb(j).length==0){d=-1;}else if(d==-1){e=llb.hD(j);if(e!=null){d=-1;for(c=0;c<b.c.length;c++){if(Zkb.c5(e,b.c[c])){d=c;break;}}if(b.d==-1){for(g=llb.dD,h=0,i=g.length;h<i;++h){f=g[h];if(Zkb.c5(e,f)){b.d=d;break;}}}}}else {b.b[d]==null?b.b[d]=j:b.b[d]=Zkb._4(Zkb._4(b.b[d],Klb),j);}}}while(!Zkb.c5(alb.Pgb(j).substr(0,4),qob));return true;};llb.gD=function gD(b,c){var d,e,f,g;g=0;e=new clb.Ju();while(g<c){try{f=Alb.p2(b.g);}catch(a){a=b1(a);if(mX(a,73)){break;}else throw c1(a);}if(f==null){break;}Zkb.c5(alb.Pgb(f).substr(0,4),qob)&&++g;if(Zkb.c5(alb.Pgb(f).substr(0,1),'>')){d=llb.hD(f);d!=null&&clb.Iu(e,d);}}b.c=dlb.Pi(e.b,gW(Ykb.l_,Xlb,2,0,6,1));};llb.hD=function hD(a){var b,c,d,e;if(alb.Pgb(a).length==0||(alb.Kgb(0,alb.Pgb(a).length),alb.Pgb(a).charCodeAt(0)!=62))return null;d=1;e=0;b=0;while(d<alb.Pgb(a).length){alb.Kgb(d,alb.Pgb(a).length);if(alb.Pgb(a).charCodeAt(d)==60){if(e!=0)return null;e=d;}else {alb.Kgb(d,alb.Pgb(a).length);if(alb.Pgb(a).charCodeAt(d)==62){if(b!=0)return null;b=d;}}++d;}if(e!=0&&e<b)return alb.Jgb(e+1,b,alb.Pgb(a).length),alb.Pgb(a).substr(e+1,b-(e+1));d=alb.Pgb(a).indexOf('DT',1);if(d==-1)return null;c=d+2;while(alb.Pgb(a).length>c&&d3((alb.Kgb(c,alb.Pgb(a).length),alb.Pgb(a).charCodeAt(c))))++c;return c==d+2?null:(alb.Jgb(d,c,alb.Pgb(a).length),alb.Pgb(a).substr(d,c-d));};llb.iD=function iD(a,b){if(a.b==null)return null;return a.b[b];};llb.jD=function jD(a){a.c==null&&llb.gD(a,10240);return a.c;};llb.kD=function kD(a,b){a.c==null&&llb.gD(a,b);return a.c;};llb.lD=function lD(a){var b;if(a.e)return a.e;a.e=clb.tq(new clb.Nq(),(b=a.f.a,b));!!a.e&&(a.e.P==null||alb.Pgb(a.e.P).length==0)&&clb.rm(a.e,a.d!=-1&&a.b!=null?a.b[a.d]:a.e?a.e.P:null);return a.e;};llb.mD=function mD(a,b){llb.eD();this.c=b;this.g=new Alb.q2(a);this.f=new Zkb.K5();this.a=new Zkb.K5();};U1(230,314,{},llb.mD);_.d=0;Ykb.CZ=w3(230);mlb.qD=function qD(){mlb.qD=W1;mlb.nD=oW(aW(Ykb.BX,1),Anb,6,14,[524290,524292,589826,589827,589828,589829,589832,589833,589837,589838,598019,598020,598024,606211,688130,688131,688132,688137,688142,696324,819202,819203,819204,819205,819214,827396,1048580,1114114,1114115,1114116,1114120,1212420,1220611,1343492,1343496,1638402,1638403,17367042,17367043,17367044,17367045,17367048,17367049,17367053,17367054,17375236,17465346,17465348,17465353,17473540,1208483842,1208483848,1208483912,1208549378,1208549379,1208549380,1208549384,1208549388,1208549442,1208549443,1208549444,1208549448,1208557571,1208565763,1208565827,1409875970,1409875971,1409875972,1409875976,1409876034,1409876035,1409876036,1409876040,1409884163,1409974274,1409974280,1409974338,1678245892,1678311426,1678311427,1678311428,1678311432,1678311490,1678311491,1678311492,1678311496,1678409730,1678409731,1678409732,1678409794,1678540802,1678540808,1678540810,1678540866,2282291202,2282291203,2282291266,2282291267,2282389506,2282389507,2282389570,2282389571,2282389572,2282520578,2282520579,2282520642,2282520643,2282537027,2483617794,2483617795,2483617858,2483617859,2483617860,2483617864,2483716098,2483716099,2483716162,2483716163,2484150275,2484248579,2752675842,3356033026,3356139523,3557359618,3557457922,3557588994,34510798914,34510798915,34510798916,34510798920,34510807107,34510815299,34712125506,34712125507,34712125508,34712125512,34712223810,34712223811,34712223812,34712223816,34980560962,34980560963,34980659266,34980659267,34980659268,35568287746,35568287747,35568287748,35568287752,35568287756,35568287810,35568287811,35568287812,35568287816,35568287820,35568386050,35568386051,35568386052,35568386114,35568386120,35568517122,35568517123,35568517124,35568517128,35568517186,35568517187,35568517188,35568517192,35568812034,35568812035,35568812098,35568812099,35568910338,35568910339,35568910403,35569336322,35569434626,35585064962,35585064963,35585064964,35585064968,35585065026,35585065027,35585065028,35585065032,35769614338,35769614340,35769614402,35769712642,35770138626,35770236930,35786391554,35786391555,2475109646403,Kqb,Lqb,2475109711938,2475109711939,2475109720067,2475109720131,2475109728259,2475109728323,Mqb,Nqb,2887426572354,2887426572355,Oqb,Pqb,2887627898946,Qqb,2887627997250,Rqb,Sqb,3437182386242,3437182386243,Tqb,3437383712771,3437383712834,Uqb,Vqb,Wqb,Xqb,4674132967490,4674132967491,4674132975619,Yqb,4674334294082,4674334294083,4674334302211,4674334302275,Zqb,4674334392386,$qb,4674602729538,4674602827842,_qb,4674602958914,arb,brb,5086449827906,5086449827907,5086449827912,crb,5086651154498,5086651162627,drb,erb,5086651252802,5086651252808,5086651260931,frb,5086919589954,grb,5086919688258,5086919819330,5636205641794,hrb,5636406968386,irb,5636407066690,5636675403842,jrb,5636675502146,{l:589890,m:73760,h:4},{l:589891,m:73760,h:4},{l:598083,m:73760,h:4},{l:688194,m:73760,h:4},{l:688195,m:73760,h:4},{l:696387,m:73760,h:4},{l:819266,m:73760,h:4},{l:65602,m:73764,h:4},{l:65603,m:73764,h:4},{l:589890,m:172064,h:4},{l:589891,m:172064,h:4},{l:598083,m:172064,h:4},{l:688194,m:172064,h:4},{l:688195,m:172064,h:4},{l:696387,m:172064,h:4},{l:819266,m:172064,h:4},{l:65602,m:172068,h:4},{l:65603,m:172068,h:4},{l:589890,m:172112,h:4},{l:589891,m:172112,h:4},{l:688194,m:172112,h:4},{l:819266,m:172112,h:4},{l:65602,m:172116,h:4},{l:65608,m:172116,h:4},{l:163906,m:172116,h:4},{l:589890,m:303136,h:4},{l:688194,m:303136,h:4},{l:819266,m:303136,h:4},{l:65602,m:303140,h:4},{l:589890,m:303184,h:4},{l:688194,m:303184,h:4},{l:819266,m:303184,h:4},{l:65602,m:303188,h:4},{l:65602,m:303252,h:4},krb,lrb,{l:589890,m:590112,h:4},{l:589891,m:590112,h:4},mrb,nrb,{l:589890,m:590160,h:4},{l:589891,m:590160,h:4},orb,{l:688194,m:590160,h:4},prb,qrb,{l:589890,m:590224,h:4},{l:589891,m:590224,h:4},{l:688131,m:590224,h:4},{l:688194,m:590224,h:4},rrb,srb,{l:589890,m:590368,h:4},trb,{l:688194,m:590368,h:4},{l:696323,m:590368,h:4},urb,vrb,{l:819266,m:590368,h:4},wrb,xrb,{l:589890,m:590416,h:4},{l:589891,m:590416,h:4},{l:589896,m:590416,h:4},yrb,{l:688136,m:590416,h:4},{l:688194,m:590416,h:4},{l:696323,m:590416,h:4},zrb,{l:819266,m:590416,h:4},{l:688130,m:590480,h:4},{l:688194,m:590480,h:4},{l:65602,m:598052,h:4},{l:65603,m:598052,h:4},{l:65602,m:598100,h:4},{l:65603,m:598100,h:4},{l:73795,m:598100,h:4},{l:163906,m:598100,h:4},{l:163907,m:598100,h:4},{l:65602,m:598164,h:4},{l:163906,m:598164,h:4},Arb,Brb,{l:589890,m:598304,h:4},{l:589891,m:598304,h:4},Crb,{l:688194,m:598304,h:4},Drb,{l:1114178,m:598304,h:4},Erb,{l:1212424,m:598304,h:4},{l:1212482,m:598304,h:4},Frb,Grb,{l:589890,m:688416,h:4},Hrb,{l:589890,m:688464,h:4},{l:589890,m:688528,h:4},Irb,Jrb,{l:688130,m:688784,h:4},{l:65602,m:696356,h:4},{l:65602,m:696404,h:4},{l:163906,m:696404,h:4},{l:589826,m:696608,h:4},{l:1114178,m:696608,h:4},{l:1212418,m:696608,h:4},{l:589826,m:696612,h:4},{l:524355,m:590112,h:288},{l:589825,m:590112,h:288},Krb,{l:589890,m:590112,h:288},{l:598019,m:590112,h:288},{l:598083,m:590112,h:288},Lrb,{l:589890,m:590112,h:336},{l:598019,m:590112,h:336},{l:598083,m:590112,h:336},Mrb,{l:589890,m:688416,h:336},Nrb,{l:589890,m:688464,h:336},Orb,Prb,{l:589827,m:590112,h:400},{l:589890,m:590112,h:400},{l:589891,m:590112,h:400},Qrb,Rrb,Srb,Trb,{l:589890,m:819488,h:400},Urb,Vrb,Wrb,Xrb,{l:589827,m:819488,h:544},Yrb,Zrb,$rb,{l:688199,m:688464,h:592},_rb,asb,bsb,{l:688202,m:819600,h:592},csb,{l:589896,m:1212704,h:592},dsb,esb,{l:688200,m:1212752,h:592},fsb,{l:688135,m:688464,h:656},{l:688135,m:819536,h:656},{l:589891,m:65936,h:8228},gsb,{l:589890,m:590112,h:8480},{l:598019,m:590112,h:8480},hsb,{l:589890,m:688416,h:8480},isb,{l:589890,m:688464,h:8480},jsb,ksb,lsb,msb,{l:589896,m:1213008,h:8480},nsb,{l:688200,m:1213008,h:8480},{l:688135,m:1343824,h:8480},osb,{l:589890,m:590112,h:8484},psb,{l:589890,m:590160,h:8484},{l:1212424,m:590416,h:8484},{l:1212488,m:590416,h:8484},qsb,{l:688194,m:598304,h:8484},{l:589826,m:590112,h:8528},{l:589890,m:590112,h:8528}]);mlb.oD=oW(aW(Ykb.zX,1),cob,6,15,[0.6966999769210815,0,0.4885999858379364,-0.47269999980926514,-0.07490000128746033,rsb,0.273499995470047,0.5699999928474426,0.7009999752044678,0.9534000158309937,-3.6435000896453857,-2.150899887084961,0.4975000023841858,-2.19950008392334,-0.2809000015258789,-0.8259999752044678,-0.1784999966621399,-1.620300054550171,-1.0959999561309814,-0.3619999885559082,0.13950000703334808,-0.29750001430511475,-1.2907999753952026,1.0161999464035034,ssb,-2.5383999347686768,tsb,0.4291999936103821,-0.5824000239372253,-0.1834000051021576,0.1306000053882599,-0.5015000104904175,rsb,-0.5257999897003174,0.4244000017642975,-0.16099999845027924,-0.2777999937534332,0.5110999941825867,-0.435699999332428,-0.10409999638795853,0.3424000144004822,-0.061500001698732376,0.6035000085830688,0.7226999998092651,0.43459999561309814,-1.6821000576019287,-0.3310000002384186,-0.49799999594688416,usb,-0.3650999963283539,0.45969998836517334,0.3384000062942505,0.6632999777793884,0.4544000029563904,0.15970000624656677,0.633899986743927,0.35040000081062317,0.04490000009536743,0.34200000762939453,0.26109999418258667,0.40459999442100525,0.5218999981880188,-1.065000057220459,-1.2314000129699707,-1.802299976348877,-0.36320000886917114,-0.4108000099658966,0.30570000410079956,-0.14560000598430634,-0.27129998803138733,-0.5192999839782715,0.45260000228881836,0.5539000034332275,0.8374000191688538,-0.7070000171661377,-0.48809999227523804,-0.4099999964237213,0,0.14790000021457672,0.3447999954223633,0.42980000376701355,0.5579000115394592,-0.1264999955892563,-0.042500000447034836,0.07670000195503235,0.6635000109672546,-0.38119998574256897,-0.8367999792098999,1.0286999940872192,-0.10209999978542328,0.3587000072002411,-0.5945000052452087,0.16920000314712524,-0.121799997985363,0.32829999923706055,0.22390000522136688,0.20430000126361847,0.05900000035762787,-0.48350000381469727,0.6165000200271606,-0.4011000096797943,0.5577999949455261,-0.21639999747276306,-0.017500000074505806,0.29809999465942383,0.10999999940395355,0.27149999141693115,-0.2994999885559082,-0.46700000762939453,0.1565999984741211,0.046799998730421066,-0.13210000097751617,1.3686000108718872,0,-0.4115999937057495,1.0185999870300293,-0.3935000002384186,0.5223000049591064,0.3684999942779541,0.25769999623298645,1.5192999839782715,0.2705000042915344,0.3790999948978424,0.012000000104308128,-0.33970001339912415,0.14830000698566437,0.2766000032424927,0.35929998755455017,0.7714999914169312,0.3149999976158142,-1.618499994277954,0.18889999389648438,-0.2651999890804291,-0.09650000184774399,0.420199990272522,0.18709999322891235,-0.3684000074863434,-0.07779999822378159,0.8942999839782715,0.3693999946117401,0.28790000081062317,0.4489000141620636,-0.26010000705718994,0.4771000146865845,0.1923000067472458,0.43810001015663147,0.16949999332427979,0.45249998569488525,0.3352000117301941,0.1582999974489212,0.4036000072956085,-0.04800000041723251,0.5023000240325928,-0.26489999890327454,0.76910001039505,-0.35519999265670776,1.0300999879837036,-0.11410000175237656,-0.5932000279426575,0.17489999532699585,0.13130000233650208,-0.18039999902248383,0.399399995803833,0.22910000383853912,0.31690001487731934,0.35989999771118164,-0.0038999998942017555,-0.2955999970436096,0.4408999979496002,-0.16089999675750732,0.3774999976158142,-0.13459999859333038,0.2838999927043915,0.5128999948501587,0.1265999972820282,0.4293999969959259,0.28060001134872437,0.49070000648498535,vsb,0.219200000166893,0.15649999678134918,0.6934999823570251,0.3617999851703644,0.6735000014305115,0.5777999758720398,-0.5636000037193298,0.5569000244140625,0.30379998683929443,-0.32760000228881836,-0.6991999745368958,0.010300000198185444,-0.4659000039100647,wsb,tsb,0.18410000205039978,0.707099974155426,0.12269999831914902,0.7949000000953674,-0.6592000126838684,-1.3148000240325928,-0.4066999852657318,-0.1316000074148178,-0.4925000071525574,-0.09290000051259995,-0.4352000057697296,-0.2206999957561493,-0.9959999918937683,-0.723800003528595,-0.5468999743461609,-1.2939000129699707,-0.01360000018030405,0.065700002014637,0.7189000248908997,0.05700000002980232,0.661899983882904,-0.6381000280380249,-0.8072999715805054,0.23549999296665192,0.30480000376701355,-0.019899999722838402,-0.07519999891519547,0.44609999656677246,0.1559000015258789,1.1167999505996704,-1.8039000034332275,0.23649999499320984,-0.22059999406337738,0.4480000138282776,-1.1339999437332153,-0.5652999877929688,-0.40529999136924744,-0.13609999418258667,0.2198999971151352,0.053599998354911804,-0.020999999716877937,0.6984999775886536,0.9642999768257141,-0.41519999504089355,-1.0369000434875488,-0.18299999833106995,0.5882999897003174,-0.29179999232292175,-0.5293999910354614,-0.6541000008583069,0.9473000168800354,-0.19059999287128448,-0.8483999967575073,-0.3456999957561493,0.9541000127792358,1.4230999946594238,-0.7924000024795532,xsb,0.07999999821186066,-0.2596000134944916,0.8381999731063843,-0.4415999948978424,-0.37040001153945923,-0.7487000226974487,-0.10790000110864639,-0.29919999837875366,-0.3276999890804291,0.025100000202655792,-0.9187999963760376,0.10939999669790268,0.8230999708175659,-3.233299970626831,0.03500000014901161,wsb,ysb,0.2791000008583069,0.3206000030040741,0.5662000179290771,-0.3783999979496002,0.4032000005245209,-1.794800043106079,-0.15539999306201935,0.3785000145435333,0.05339999869465828,-0.16529999673366547,-0.09870000183582306,-0.10050000250339508,-0.6460999846458435,0.8034999966621399,-0.24050000309944153,-0.12380000203847885,-0.35760000348091125,0.09610000252723694,-0.6401000022888184,0.2029000073671341,0.23589999973773956,0.4950999915599823,0.19210000336170197,-0.37450000643730164,0.34630000591278076,0.289900004863739,-0.15330000221729279,-0.4169999957084656,0.37700000405311584,0.6998000144958496,0.593999981880188,0.5911999940872192,-0.5570999979972839,0.023800000548362732,-0.2475000023841858,0.030700000002980232,-0.38749998807907104,-0.7437000274658203,0.5144000053405762,0.00570000009611249,0.765500009059906,0.1720000058412552,-2.5624001026153564,-0.30660000443458557,0.36469998955726624,0.17270000278949738,-0.03290000185370445,-0.18930000066757202,0.07020000368356705,-1.2453999519348145,0.14959999918937683,ssb,0.4146000146865845,-0.2667999863624573,-0.11060000211000443,0.03620000183582306,-0.3188999891281128,-0.7278000116348267,-0.08940000087022781,-0.22769999504089355,-0.2393999993801117,1.011199951171875,-0.2962000072002411,0.7775999903678894,0.2944999933242798,-0.22339999675750732,0.27639999985694885,0.8011000156402588,-0.17440000176429749,0.15809999406337738,-1.7552000284194946,-0.384799987077713,0.5993000268936157,0.5267999768257141,-0.04170000180602074,0.4733000099658966,-0.3400999903678894,-0.14499999582767487,0.7088000178337097,-0.13179999589920044,0.04259999841451645,-0.5027999877929688,0.3831999897956848,-0.011800000444054604,-0.4357999861240387,0.3749000132083893,-0.12030000239610672,-0.5648000240325928,-0.1972000002861023,-0.8769000172615051,-0.3675000071525574,-0.2003999948501587,-0.6069999933242798,-0.18569999933242798,0.3467999994754791,-0.36239999532699585,0.5357999801635742,-0.3700999915599823,0.13359999656677246,0.9545000195503235,0.11389999836683273,-0.16990000009536743,tsb,0.2890999913215637,0.2612999975681305,-0.03440000116825104,-1.9498000144958496,-2.024899959564209,-0.6004999876022339,-0.6258000135421753,-1.2348999977111816,0.328000009059906,-0.54339998960495,-0.7712000012397766,-0.9057000279426575,-0.16680000722408295,-0.9904999732971191,-0.03720000013709068,-1.1638000011444092,0.12620000541210175,-0.5248000025749207,-0.15379999577999115,-0.36820000410079956,0.3249000012874603,0.06499999761581421,0.051100000739097595,-0.46070000529289246,0.22310000658035278,0.28220000863075256,0.1396999955177307,-0.49380001425743103,0.39480000734329224,-0.4074999988079071,-0.6410999894142151,-0.009100000374019146,-0.13330000638961792,-0.5192000269889832,-0.16609999537467957,tsb,-0.07069999724626541,0.4805999994277954,0.38280001282691956,0.22290000319480896,0.6159999966621399,0.33709999918937683,0.188400000333786,0.13809999823570251,usb,0.2833000123500824,-0.1225999966263771,-3.9189000129699707,-0.459199994802475,-0.3434999883174896,-0.6654000282287598,-0.5055999755859375,-0.863099992275238,0.15360000729560852,-0.6427000164985657,-0.08839999884366989,-0.0471000000834465,0.11060000211000443,0.382099986076355,-0.23919999599456787,-0.4050999879837036,0.08910000324249268,-0.6972000002861023,-0.4699000120162964,0.09220000356435776,0.08060000091791153,-0.6773999929428101,-0.062199998646974564,-0.9300000071525574,0.13369999825954437]);};mlb.rD=function rD(b){var c,d,e,f,g;d=0;clb.Eo(b);clb.Gt(b,7);for(c=0;c<b.f;c++){try{g=clb.xe(b,c,6241);f=(e=slb.UT(mlb.pD,Zkb.I4(g)),e<0?-1:e);f!=-1&&(d+=mlb.oD[f]);}catch(a){a=b1(a);if(!mX(a,15))throw c1(a);}}return d;};mlb.sD=function sD(b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q;f=new mlb.ID();dlb.wi(f.a,new mlb.FD('cLogP Values are estimated applying an atom-type based increment system.',2));dlb.wi(f.a,new mlb.FD(zsb,2));dlb.wi(f.a,new mlb.FD(Asb,2));if(b){clb.Eo(b);clb.Gt(b,7);i=0;e=new dlb.seb();j=new Dlb.q8('#0.000');for(c=0;c<b.f;c++){try{d=clb.xe(b,c,6241);q=dlb.Iab(e,new Zkb.y4(d));!q?dlb.keb(e,new Zkb.y4(d),new Zkb.h4(1)):dlb.keb(e,new Zkb.y4(d),new Zkb.h4(q.a+1));}catch(a){a=b1(a);if(mX(a,15)){++i;}else throw c1(a);}}i!=0&&dlb.wi(f.a,new mlb.FD('Warning: '+i+' atom type(s) could not be determined.',2));for(p=(h=new dlb.Ceb(new dlb.Heb(new dlb.Wab(e).a).b),new dlb.cbb(h));dlb.H9(p.a.a);){o=(g=dlb.Aeb(p.a),g.hc());l=slb.UT(mlb.pD,o);(l<0?-1:l)!=-1?mlb.HD(f,(n=o,dlb.F8(dlb.feb(e,n))+' * '+Dlb.p8(j,mlb.oD[(k=slb.UT(mlb.pD,o),k<0?-1:k)])+' AtomType: 0x'+Zkb.G4(o.a)),2):mlb.HD(f,'Warning: For atom type 0x'+Zkb.G4(o.a)+' ('+(m=o,dlb.F8(dlb.feb(e,m)))+' times found) is no increment available.',2);}}return f;};mlb.tD=function tD(){mlb.qD();var a,b,c,d;if(!mlb.pD){if(!mlb.pD){mlb.pD=new slb.WT();for(b=mlb.nD,c=0,d=b.length;c<d;++c){a=Zkb.I4(b[c]);slb.RT(mlb.pD,a);}}}};U1(165,1,{},mlb.tD);Ykb.DZ=w3(165);mlb.uD=function uD(a,b,c,d,e){var f,g,h,i,j,k;f=1/(1+$wnd.Math.exp(a-5));k=1-1/(1+$wnd.Math.exp(b+5));j=1/(1+$wnd.Math.exp(0.012*c-6));g=1-1/(1+$wnd.Math.exp(d));h=(0.5+f/2)*(0.5+k/2)*(0.5+j/2)*(0.5+g/2);for(i=0;e!=null&&i<e.length;i++){e[i]==2?h*=0.8:e[i]==3&&(h*=0.6);}return h;};mlb.yD=function yD(a,b){var c,d,e,f,g,h,i,j,k;c=new mlb.ID();if(!mlb.xD){dlb.wi(c.a,new mlb.FD(Bsb,2));return -999;}dlb.wi(c.a,new mlb.FD('Found sub-structure fragments and their contributions:',2));dlb.wi(c.a,new mlb.FD('(yellow atoms carry at least one more substituent)',2));j=0;i=0;f=0;k=new clb.ks();e=new clb.Yt();for(g=0;g<mlb.wD.a.a.length;g++){clb.ep(new clb.mp(false),e,mlb.BD(mlb.wD,g));clb.ds(k,b);clb.bs(k,e);if(clb.Rr(k,1,k.c)>0){h=mlb.CD(mlb.wD,g);if(h<-1)j+=h;else {i+=h;++f;}mlb.HD(c,mlb.BD(mlb.wD,g),1);dlb.wi(c.a,new mlb.FD(''+h,3));}}if(f==0)return -1;d=j+i/$wnd.Math.sqrt(f);d=d+0.0625*(f-40);a.a=c;return d;};mlb.zD=function zD(a){var b,c,d,e,f,g;if(!mlb.xD)return Bsb;f=0;d=0;g=new clb.ks();c=new clb.Yt();for(e=0;e<mlb.wD.a.a.length;e++){clb.ep(new clb.mp(false),c,mlb.BD(mlb.wD,e));clb.ds(g,a);clb.bs(g,c);if(clb.Rr(g,1,g.c)>0){f+=mlb.CD(mlb.wD,e);++d;}}b=d==0?-1:f/$wnd.Math.sqrt(d);return b+'\t'+d+'\t'+a.f;};mlb.AD=function AD(){if(!mlb.xD){try{mlb.wD=new mlb.DD(mlb.vD);mlb.xD=true;}catch(a){a=b1(a);if(mX(a,15)){Zkb.O5();}else throw c1(a);}}};U1(219,1,{},mlb.AD);mlb.vD='sNy@LDeVjj@XTKU|TH\t5.89\nKA|P@QvRRJjjj@LFaLJnyC@\t5.86\nHiFH@H{IIEUJjj@FGPfES]rA@\t5.82\nJoB@@BUJssoPvxPTA@@@FFpaUpriv\x7FDsP\t5.61\nHeTH@@RV[TYZ`@@AaUMpssHP`\t5.19\nHmtH@@RVYWeVhH@@FCESCJ|rDx\t5.18\nj`qA@@IIULsj\x7FiuoUP@`@@@CAUF\\DkQkN}qFB@\t5.1\nsOx@@eJymUT@pLVOLJp\t4.95\nj`a`@@@YIEEDthdg^jjj`@@@XV`cAJLxKQkN}rD`\t4.89\nHk]@@@yJeWmZ{Sjj`@`@XSBEPrngqLx\t4.83\nHkmL`LfDD@cIIBhhd]MZ`X@@FEXwKoDdp\t4.7\nHefD@Hz\\ddUTuUUP@pFDpj[ayD`\t4.7\nHaF@@@Ri_ijjj@FAPaUsL[`\t4.63\nHeV@@@RUYTYj`@@AatIS\\L|PL@\t4.6\nHif@@@RiUzzjjh@XMBXUMqND\t4.55\nHcuHA@E`dYrRQVYRUUUT@LEaLJfzUt\t4.49\nHcLD@@QIeVuWVj`@@A`q\\LkoDq`\t4.49\nsGY@LDeVj`FABuxhP\t4.38\nHcLL@@RlbbTLRRzuT@@@LFkae]xfD\t4.37\nHcNL`LaA@HrRPjIKKju@`@@pkFzUxeZ\t4.36\nHid@p@kFkAkDfUfn`BH@FF@p|qLx\t4.35\nJoBD@@IS\\rjzv[uP@@@@@X[EMprng[|a@\t4.33\nHg|H@@RYfUWd}nh@@@@@X[ATwCJz]|`@\t4.33\nHeT@p@kNkIkDfY[XXBH`@XXGSsLhP\t4.33\nJoBD@@IKLrjzv[mP@@@@@XKS\\Lkiv\x7FDa@\t4.3\nHmtHpIBlzlVlRYeeXXBHX@FFAr|sJD\t4.28\nHie@@@yJeWkjjj`A`tIaTwDxP\t4.28\nHeU@@@yJeWZzjjj@FCPfES\\PY@\t4.18\nHidH@@RYm^Fjjh@X\\BES\\ODc@\t4.14\nHeV@@@RV[TYz`@@AaUMpsqDH\t4.14\nsNplJyDJHtQddeeUPCBqXwdX\t4.1\nHg|@`@bDfUueZX{`@h@@@FB`fETkiwrN@\t4.05\nJoB`@@]ddRRJTRU][uUU@A@@XKBXUKiv\x7FDXP\t4.04\nJoBD@DIU\\vjzv[uPTEDP@XGFTwCJz]orB@\t4.04\nHg|H@@RYfUWd}nhJBbH@XFFES\\LkiwrH@\t4.04\nHg}@@@yJeWe^nNzjhHB@AaLHUCNg_DqP\t4.04\nHk^@@MRjY]\\]TzhJBH@FDieMpri|Pm@\t4.04\nHcn@@@Re]eRi]jj@B@AaLIa\\LkoDB`\t4.04\nHmt@`@dDfUuZZ@Bj@A`rXUCODyP\t3.99\nHeT@@DjUghP`h`@X]BESCODs`\t3.99\nsNuhLxj@cIHUEi`FDwDF\t3.99\nHmuL@FFnWIIEEJQfjYi`A`cCqLH\t3.98\nj`q`@@@IJsLjoiuoUT@@@@@CBtDXYpTeZMYwnP@\t3.94\nHklHpEbPRPrPrRRqIYHYj`@j@A`UMp|SS@\t3.94\nHo~@@HrRQVKJIJwjjj@@@FApfES\\ng[|`P\t3.94\nHkn@@@rQQEJIKSjj`@@A`lIaTLki|PF@\t3.94\nHeVH@DAImeQej@@@FETwCODS@\t3.94\nsNx@IddbmUPCBqXwdX\t3.89\nHmtD@@QIeyVUZh@@@XTwCJ|SB@\t3.87\nHeW@@@zTjU_kjjjh@X]BXULODzP\t3.83\nHcLD@H[IIDcLdnuT`@@CAlKae^Hf`\t3.83\nHg}@`AlHaIe]YVfNx@Jjh`AaHIaUJz_Dzp\t3.82\nHg~H@CyJieU~SvzhF`b@AaNESCJ{_DPp\t3.82\nHmtL@@Pdf{eYUj`@@A`qMproDS@\t3.79\nsNy@BDivjj@XFZodP\t3.79\nsGY@LDeZj`FAbMy@\t3.79\nsGX@@eLuT@pHVOEJ\t3.79\nHeT@`@dDfUuih@J`@XTfEP|Si@\t3.78\nJoB@@BUJssoPvxPTA@@@FApfEWCJg[|cP\t3.76\nHmuD`LVD@HrRRqIXYV`@`@XUS\\J|c@\t3.75\nHg}L`FM]n@cIIDhTheSCMUUSSP@pzDpjG^PX\t3.74\nsGYhMEPDYIBei@XS\\PH\t3.7\nj`q@A@@RGiAIe]fuzLlz@Bh@H@@XRQ`eNJtZwHR@\t3.69\nj`q@@@DjUggUhJw``hBB@@A`ZBBTxJRcV]{bLZ@\t3.69\nHg~@@@rRIIEQIUqwUUP@P@LEaLJiWSobMp\t3.69\nHk^@@@Ri_YVftzjh@H@FDpaTLki|SF@\t3.69\nHg~@@MRjY]_GUNjB`b`@XRfTwCJgqBl\t3.69\nHkn@@@rRJGJIKSjj`@@A`lIaTLki|a`\t3.69\nHmvH@DAIn[VUZh@@@XLc\\LkqLh\t3.69\nHaFH@NAIYUnZjh@XEaTwLaN@\t3.69\nqCaHK@Hg`dsPFDGME`\t3.69\nKAz@@ArUJmUT@XMBXUMrN@\t3.68\nsJY@LDeZhAahcqC@\t3.68\nHklD`HXxcIIDcLeevjd@H@FGXWCJgrD@\t3.66\nHmtH`NBHRYWVih@Jh@FG@fETkrA@\t3.66\nHiFH@BAJ]ejjh@XMFTwCrD@\t3.66\nKA|P@XBRlmUT@XMBES]r@@\t3.66\nsGT@ATiVj`FAbqxaP\t3.66\nHk]D@DHIRYge\\ftvj`PH@FE\\Jz_Dp`\t3.62\nHid@p@kFkAkDfUfn`BH@FA@cCqLx\t3.62\nsNx@@eRmUPCBqXwdX\t3.62\nsGY@DDfuj`FBMxe`\t3.6\nsGX`JBdruT@pHbwDZ\t3.59\nHknH@JCIDdhhd]Nj`h@@FDqc\\Lki|a@\t3.56\nHmv@pBBlFlVlRYfyZXHJH@FF@J|pnd\t3.56\nHeUL@DpFEIeYzyjfZ@FBIgDzP\t3.56\nJoCB@E|NRRJJIIGKYoU@uAD@AaNESRnf\x7FDFp\t3.55\nHo~D@Hy|ddUTtRVNzjj@B@AalIaTwRnorC@\t3.55\nJoB`P@vDPdrnlktqw@AUUQ@AaHIaUJz_Dyp\t3.55\nHkmL`LZDh@cIHULhdmMZZjj@F@xwCJz_H@\t3.55\nHmvDPLa@BNbLddlTVeUhH@@FAXwCqIT\t3.55\nHknH@JCIDdhhd]Nj`h@@F@qc\\LkoDPp\t3.55\nHcLH@@rJJIPiKkUP@@@p{FxYW^He@\t3.55\nKAzY@XtIPAFRPjYZZ@LDqnHG@\t3.55\nKAxH@@bSKKUT@XXUMqLx\t3.55\nsJQdEbOBAD^u@LINYX`\t3.55\nJgC@PG@DISLroutgmt@P@D@@XBALLki|Sk@\t3.54\nHk^L`FWS`HrRQJEJZfFZjjfZ@FCPfEV|`P\t3.52\nJoc@PG@DISLrj}]Mz}@D@PP@A`HDprnwqC\\\t3.51\nHcNHpBtJpZqZqIf[eZXHJI@Aa`BoLKi@\t3.51\nHcMDPLvD@HzHrRRqQ[RjtDA@@pKFx^IN`\t3.48\nsOt@@tiWMjj`FEbqoDF\t3.48\nHaE@@@YJe~fjjh@XUBXU\\c`\t3.47\nHk]D`FuS`HrRQJEIJfFZjjfZ@FCPfEP|Sm@\t3.47\nHmMH`FeXBLddRJRinFjjih@XUFEW\\QI@\t3.47\nHeV@pBBlzlflRYgea``b@Aa`]OLpa@\t3.44\nHid@`@bDfUvf`@h@FE@fEWDxP\t3.44\nsNy@BDiujj@XFZobQ@\t3.43\nsGY@LDeVj`FAbMxa`\t3.43\nKAxD@@c\\dvlts@FAIa\\\t3.42\njdyA`@@HbdsrnlkbexKT@E@A@@CBVJLxHug^xaTP\t3.4\njdyA@@IIULsZny`ncU@C@D@@@pMQgAJtZsoAcrA@\t3.4\nj`aAb@HLyzHrRQJFYIHf]USAAD@@pE``iJt[wHV@\t3.4\nj`qa@@D@R[fYU_Sk^Zh@@@@@FFdLxJRmFl{wHX@\t3.4\nj`qa@@C\\RjYU_~QmVj`ZBJ`@FBlDhpTeZl{bD^@\t3.4\nj`qA@@@ISKMjoiuoUT@@@@@C@tDLxJRmFl{wHT@\t3.4\nj`q@@@DjUggUhJw``hBB@@AaZBLDipTeFl{wHZ@\t3.4\njhiA@@@ILrsZkf|xKUP@@@@@LCXYpTeZMYw`|``\t3.4\njhi@`@@HRYyWVUEKpVh@J@@@@XRqQgAFl{wDJB\t3.4\nHg]L`LfDD@cIIBhhd]ikTC@P@LFqnW[yD`\t3.4\nJoCD@A|eTrj\x7Fr^wU@tDT@AaNESCJ{_DQp\t3.4\nHg}@@@yJeWe^nNzjhHB@A`lHUCJz]|c@\t3.4\nHcLDpITJsjsZqIfVYXXBHZ@A`P\\n|SA@\t3.4\nHknL`LaA@HrRPjIKY]VhDB@A`vMtj_Hh\t3.4\nHmv@@@RYvUeZj@@@F@pfMproD@`\t3.4\nHeV@@@RiU~njjj`AatIaTp|Si@\t3.4\nHef@@@rRJJIuUU@C@XSBinGdR\t3.4\nj`q@`@HRRjyeU\x7FSk^j`A@@@@FFhTYpRmFl{wHD@\t3.4\nsFt@ATiTvjhA`Xl^HT\t3.4\nHiFD@J@dfWZjj`A`HPfTwCrB@\t3.38\nsNq`@fdvkSHCCKGdh\t3.37\nHcnD`FWXBLddRaRuLLuUUKP@pjDpjxgB\t3.37\nHevH`Ff@cIIDbmS\\MUUM@C@hpjxb\\\t3.37\nHeTD@@QImeQej@@@FETwCODS@\t3.37\nHklL@H[lddRaaRtzjX@@@XMaCJ{qNL\t3.35\nHcNHpBtJpZqZqIfUeZXHJI@A`PDJ|sNd\t3.33\nJoBfPCZio@QddbTJRVuLLuUULsP@X]BXUCoDzp\t3.33\nHk]D`FeS`HrRQHiIZfxZjjfZ@FCQaUt|QM@\t3.33\nHg}D`FeS`HrRQHiIZTwCUUTsT@LFcBkixbV\t3.33\nsOt@@tjWkjj`FEbqoHp\t3.32\nJgC@PG@DISLroutgmt@P@D@@XRALLkiwrN@\t3.31\nJoc@PG@DISLrj}]Mz}@D@PP@AaHDprnv\x7FHL\t3.31\nHeV@@@RYyTYj`@@A`LIeMpsr@@\t3.31\nHeVH@NAIYWVyjjj@FEXULOLaI@\t3.31\nHifH@NAIYW[fjj`A`VES\\rDD\t3.31\nHieH@FxDigwJiej@FFXU\\qND\t3.31\nQO`BNZ`XL|`\t3.31\nsOt@@tjWkjj`FAbMxlp\t3.31\nsJX@@dsU@LMEnHD\t3.3\nHaD@@DjUZzjj`A`pPaUwDq`\t3.28\nHeVD`Ia@BLdabRwBl@D@CBbingd@\t3.26\nHmtD`NTHaIe]Vf`@jP@XTBXU\\PY@\t3.24\nHeTH@@RYe\\YZB@@AaVEWCqFd\t3.24\nHefD@JADeUeZjj@FCXS\\L|b@\t3.24\nKA|H@TBIJjmUPA`VDw\\RJ@\t3.24\nHo|L`H[gbLddRafRvNzjXHB@AavDLz[|aP\t3.24\nHg\\L`H[kbLddRaaRvgUS@A@@p{BFUv~Qp\t3.24\nsGX`JDdjmT@pVOEJ\t3.23\nsJXhMD@bOV`FDwHP\t3.23\njhi``@G\\DeTsJn~iqoUPMPTT@@pu`eFRUhuoAyAp\t3.22\nHkmDPLvD@HzHrRRqQ[JUV``J@AaVMp{qIL\t3.22\nHk^DBIAIeIgeYQe]Zjjjh@XBUMpki|SI@\t3.22\nHcnDBAAAeIVUexYUjjjj@F@xUMtkoD`P\t3.22\nHevHBFAiRYVVfxZjjj@F@pfEWCODA`\t3.22\nHcML@FFnwIIEEDZJuSMS@CCLX^HT`\t3.22\nHcLD@@QIeVuWVjjj`AaqUprn|SF@\t3.22\nHiV@B@BTjYnnXZjjh@X]BXUMwD@P\t3.22\nHmuL@DpFEIeY~nZifh@XXfSqNT\t3.22\nHeTD@@QImeQejjj@FCES\\L|QL@\t3.22\nHmtD@@QIeyVUZjjh@XMS\\LkqLH\t3.22\nHaE@@@yJe~fjjh@XUBES\\SN@\t3.22\nsJX@@eKU@LLH^IX\t3.22\nKA|P@DBSNuUT@X\\DHUMwHp\t3.2\nsNy@LDeVjj@XLKFod`\t3.2\nHeTD@@qI[eQej@@@FCYS\\L|RD@\t3.19\nHid@@DjU^nBBH@FEPaTwLsa@\t3.19\nHidH`NBHRYWZZ@B`@XTBXU\\`P\t3.18\nsGQ`@jdjmR@pfxhP\t3.18\nHid@`@dDfUvf`@h@FAIaUqND\t3.18\nHmuH@DHDf{eYUj`@@A`vMproDP`\t3.17\nHeVD@NADfVuFVh@@@XESCOHH\t3.17\nHaE@@@YJe~fjjh@XEBEWDs`\t3.14\nJoBb@BDByEEEMDdbSV{UTC@P@FGYpr]oqBt\t3.13\nHg}D@DHERYfywIcmjjA@`@XM`siwqBx\t3.13\nHcOLAHePPheNR[e]VyjZfd@XYWCqEt\t3.13\nHie@@@GIHddZzjjh@XMBXU]qFD\t3.13\nsGXhMD@cIHXmPCBGbE@\t3.13\nsOx@@eRimUT@pLQoEf\t3.13\nHevH`Ld@aJY[RZnjjid@XXDIsBxP\t3.13\nsOx@@drm\\@@@prkyab\t3.1\nHiVH`LD@cIEDhRZnjjfPAa`PgLJn@\t3.09\nHg}L`LGSl@cIEDhddXWTuUUTmH@phHPkx`r\t3.08\nHaF@@@RiUkjjj@FEPfEWD[`\t3.08\nHk^L`LWS@HRfVuxnijjjei@FAABGqBD\t3.07\nsNq`@fdskUHCBGbu@\t3.07\nHk]D`LES@HrQQJIKDfkjjjfY@FEABDOLz]@\t3.07\nHg}D`LES@HrQQJIKFDu]UUTsR@LJBDH^Ytv\t3.07\nHmMH`LEPBDieeRZnjjjY@FAABEsNFP\t3.07\nsOx@@drm\\@@@pqky`l\t3.07\nsJX@@eKU@LMEnHD\t3.07\nJoBaPFBivxABTrsjvWTuUUSLr@FCABDM|Rm@\t3.04\nHk]L`LE]L@aJYYwbzfjjjVd@XTDHQ|Ra@\t3.04\nHk]D`LF]@HRfV_xfkjjjYi@FEABDOLkc@\t3.04\nHcmD`LF]@HRfV_rZnjjifPAaPPaCsJyP\t3.04\nHeuH`LFPBDiegIjzjjfPA`PPa\\rnD\t3.04\nHaF@@@RiUkjjj@FCPfEW\\a`\t3.04\nsNt@A\\dbJjj@XFKGbk@\t3.04\nj`qa@@I@RYeU{TRg^jBBJjH@FE`XIQgAJtZso\\a@\t3.03\njdyP@@G^rRQRiQHjIBdFMT@ETuD@CCRLDhqVc^CD\t3.03\nj`q`@@@ITrjwoHsoUAP@@@@C@rLDhJRmFl{wH\\@\t3.03\nj`q@`@H\\RjyY]_Sk^j`ZBbH@FAhDhpTeZMYwnPp\t3.03\nj`qA@@HIU\\rj\x7FiuoUPUAQD@CBtLDhs`eZMYwnPd\t3.03\nj`aP`D@VdXDyIHiTimMAJj`BIj@@XRQ`eFBT{p\t3.03\nHcL@HHbDbLbMbLddjbRtkUP@P@LAaL[ag^PP\t3.03\nHg}L`FM]n@cIIDhTheSCMUUSSP@pZDpjGbZX\t3.03\nHg\\HpEbPRPrPrRRqIYICMT@ET@CBj[aOb[X\t3.03\nJoBb@CCWYIHhiSDdpv}TsP@P@FEKiv\x7FLpa@\t3.03\nHg~L`FWS`HrRQJEJ[TpsUUTsT@LJaLJnHM`\t3.03\nJoCD@B`eLjsj|ioUUAAD@AalXS\\Lz]orD@\t3.03\nHkoDPFF]N`aPcIIEJeeNFjfjU@FEIaUOHT\t3.03\nHk^L`FWS`HrRQJEJZfFZjjfZ@FEPfEWDGP\t3.03\nHk^@@@rQQIFIJftpHH@@@F@ieLLkoDHp\t3.03\nHo~H@EAIYeV^dvhHJJ@A`iTwCNg[|RD@\t3.03\nHknDB@dpgIIEJeMaVj@Hd@FGIaTpkrM@\t3.03\nHg}D@DHERYfywIcmjjA@`@XTLz]|sBx\t3.03\nHc^`@@pjYJYenkae]@bJhh@XDLkoHx\t3.03\nHmvHB@dIrRQRiPUj`B@@X\\fESBoHd\t3.03\nHae@PDp@bOAIfXj[fjj`AaPES]rH@\t3.03\nHcLH`ABPRYW[ZZ@BZ`@XLfETkrM@\t3.03\nHmtH`ABHRYWUih@Jh@FC@fET|Se@\t3.03\nHeV@B@B\\ddTjPsU@@@CCdpj[iy@`\t3.03\nHkl@@LddTjTRFZh@J`@X\\fESKoHL\t3.03\nHcN`@@pjYJYenk`Hbj@A`Prn|c`\t3.03\nHcL@@LddTjTPsU@AP@LNSBiewdR\t3.03\nHeTH@@Rf{TYj`@@A`qTwCODa@\t3.03\nHif@@@RiUzzjjh@X]BXUMwHD\t3.03\nsJPXHlPDQ}T@phbq@\t3.03\nHcnL`Le]@HrQQJEJEuMUURt`C@`aMxaT\t3.02\nHifD@FADfyWaZ@@@FAEWCrD@\t3.02\nHeT@@DjU_k``b`@X]BES]ODpP\t3.01\nsOx@@eR}]UT@plVMyF\t3.01\nsGP`ITjnjPFBqxh`\t3.01\nHie@@@{IHddZzjjh@XMBXUCrF@\t3\nHif@@@RYfVF@b@@XTUMp|`@\t3\nHmv@pIbPRPrPrRRqIPUj`B@@XESBoHd\t2.95\nHg^B@FACmInY]XYZZjid@XXw[sDjp\t2.92\nHknL@FACR[fWTYZZjiPAac]oLRe@\t2.92\nHmvH@JAIUYVUZjjh@X\\fDwCODaP\t2.92\nHmvD@FALbfbbQFVfji@FFMr|qJD\t2.92\nHeVH@JCHeEDcpluUH@prfgfPW@\t2.92\nHcND@JCTefWWaYjje@FFTr|rBd\t2.92\nHet@@DjYUX^dHbH`A`rDwCODr`\t2.92\nHeVH@IAJYW~F``H@FEIaMwDjP\t2.92\nHaF@@@RfYkjYj@FF@S\\sJx\t2.92\nsJPdE`DSpRYZ`FBAxi`\t2.92\nsOt`DPtfWMZi`GfVH\t2.92\nsJXhMD@bOV`FDOI`\t2.92\nHmvH@DAIVYdUZ@b@@XLc\\LkrH@\t2.91\nsNx@AddQeUPCBqXwdX\t2.91\nHaF@@@RfUi`HH@FAIeMqBx\t2.9\nsGX@@eLuT@phbqyJ\t2.89\nsNt@@|dbJjj@XVKF|c@\t2.88\nHaF@`N@HRYWih@H@FEIaUwH@\t2.88\nHid@@DjU^nBBH@FCPaTw\\SA@\t2.88\nqCh@BIWLAaEqS@\t2.84\nsGX@HeTuT@pLVOIP\t2.84\nHie@@@{IHddZzjjh@XUBXU\\Qa@\t2.83\nJoCbPCRzg@QddbQRRtuMpuUULuP@XMFEWSsDmp\t2.82\nHcLL`NWPbDfUuZf`@jX@FE@fEWDGP\t2.82\nHcNH@DAIgfYgVhBH@A`r\\LkoHp\t2.82\nKAxX@QSYIIiZih@pSBxd\\\t2.82\nsNq`IVeUuTpCAX|TX\t2.82\nsGQ@@drmT@pROEj\t2.82\nsOx@@eR}]UT@plQkyL\t2.82\nHidH`ABHRYWZZ@B`@XTBXU\\Sa@\t2.81\nHeTH`ABHRYWVf`@j@AaPIaUqNd\t2.81\nHif@@@Rge^Eh@@@XTUMp|RD@\t2.81\nsGX`BDdwMR@pbxcP\t2.81\nqCx@AYIf`OLE`\t2.81\nHaDH`NBHRYWih@H@FE@fEWHx\t2.81\nj`qAB@H^bDjn[U_UXsjh@@@`@AaheF\\EIVcN}rD@\t2.8\nHk]D`LFD@HrRPjJIEatujB`H@FEYWBoLgS@\t2.8\nHknHpEdJsjsZsHhheEEVF@bFh@FEArz_DpP\t2.8\nJoB@P@QBSJ{MkSV|@EP@@@FF`fETkiv\x7FHx\t2.8\nHcld@dsmBPzIZYyIfVuXUvjjYj@FBToDsP\t2.8\nHcmD`LFD@HrRPjIKLJzmPPD@C@lxYyeKh\t2.8\nHg^H`MDHaIe]UZf`@jj`@XRBXURiwrN@\t2.8\nHkmL@FFnOIIEEDlqvjYjf@FAXSCqIT\t2.8\nHg^H@AAJY[Ue[jhHJ@@XJaTwRng_H`\t2.8\nHeVD`La@BLdaTRPrm@@@CBlinGbAH\t2.8\nHcNH@DAInYWWVjB@@AarTwRn|SA@\t2.8\nHklH@@RYeg_SZjB@@A`NTwBngqDd\t2.8\nHmv@@@Rf~UeZj@@@FDaFDwCJ|a@\t2.8\nHeUH@DpDf^UFVjjh@X\\aTwCOHp\t2.8\nHeT@`@bDfUuih@J`@XLBXUCqNd\t2.8\nHeVH@DAImeQej@@@FCIS\\L|c@\t2.8\nHifD@AADfyWaZjj@FAES]sDpP\t2.8\nHaF@`FBHRYVkh@`@FF@e\\sFx\t2.8\nHaF@@@Rie[jjj@FEPfMwDJ`\t2.8\nsGYiKE`D[lddju@LH^R`\t2.8\nsNx@AdbbMUPCBqXwbC@\t2.8\nsJP`@TfVhAaEqX`\t2.79\nsFx@@eJfuU@LCEcqB`\t2.77\nHeWH`LJQ@HrQQEJYULtt@LLABxcR\t2.76\nHieH`LHPBLdTQRrjYi`Aa`HWD[`\t2.76\nsOy@FDiguie`FFqoDf\t2.76\nQMIDBKpRVAaGFP\t2.76\nHaE@@@yJeVnjjh@XUBXU\\Qn@\t2.75\nsGP`@dfUj`FBuyB\t2.74\nHo~LpBNwBlflvlRYfVVVVBBhfP@XTASm|PU@\t2.73\nHknDpBtpkAkEkDfYnVZXHJI`@XD@j_DJP\t2.73\nHeVH@FAIfUqfhH@@FCAAUp|sFd\t2.73\nHidH@@RUe^Ejjh@XMaTwCqHP\t2.73\nsKT@Adi\\Vj@XYX|d@\t2.73\nsKQ@@eKcRpCAX|TP\t2.72\nsFx@@eJfuU@LKEc^P@\t2.72\nHmth`LKed@cIEDUMLjfYf`Aa`HWDyP\t2.71\nHeWH`LKi@HrQQESYULsL@LLABxgB\t2.71\nHaG@`LK`BLdTQVUSLp@ppDKbMp\t2.71\nHaEH@FxDig|jfV`AafEWDS`\t2.71\nHmtH`ABPRYW[ih@Ih@FEIaUOHT\t2.71\nHif@@@rRIIFnjjj@FCPfEW\\Qa@\t2.71\nHeeH@DhDeUeZjj@FGIaMpsrH@\t2.71\nKAzP@IPIJjmUPAaRXS]qHh\t2.71\nsOtHLPDYHhckSM@LLD^Q`\t2.71\nsFtHLPDISNmLpCCAGdh\t2.71\nsKX@@dmcUPC@qX|`@\t2.71\nsJXhMD@cIHUhAaMq@`\t2.7\nHaFH@JAIYUnX@@@XEaMwH`\t2.69\nJoc@@@YHhhheDbNsYoP@PPD@@XJS\\Lkiv\x7FH@\t2.67\nHg^@pCbPRPrPrRRqIPjCMT@ET@CCjXYW[yA`\t2.67\nHo}D@HggrRQUSQIX{jjh@H@FBpfES\\iorM@\t2.67\nHkl@pHdDdLdLddlRTJFZh@J`@XMSCJgrM@\t2.67\nHmtH@@rQQJEJUjh@@@X\\aMproDb`\t2.67\nHmtH@@RY^UeVj@@@FGHS\\LkrL@\t2.67\nHedL@JZ\\ddTZUTuH@pILKnPH\t2.67\nHiDL@Hilddtjjfh@XYa]qHD\t2.67\nHaF@@@Ri_ijjf@FEPfEWHx\t2.67\nKA|@@Qddbljj`CAhSBinQp\t2.67\nHeTH@@RYe\\YjB@@AapXU\\L|RF@\t2.67\nHeULAHdDJISdfyW[fijT@XYWCrI@\t2.64\nHg|@@DjYU_~V]`@@B`@FDiaTwCN|P{@\t2.64\nsJX@@eMU@LBIcrH\t2.62\nJob@@BULj~jprmnDQE@@@@XJfDwCiv\x7FHh\t2.61\nHcMH@LDDeYWWajjjj@FDaBES]J|cP\t2.61\nHeU@@@yJeWZzjjj@FGPfESSrA@\t2.61\nHeT@@DjU^k``b`@X]BES\\ODrP\t2.61\nsOp@DjWkjj`FEbM_DL\t2.61\nHk\\d@dsmBPzIZY{HhheLdVE]jjfZh@XIR|SC@\t2.6\nHeV@pBBlzlflRYgea``b@A`PYt|Pa@\t2.6\nHeT@p@kNkIkDfY[XXBH`@XDF]ODhP\t2.6\nHmtD@@EJYUgehHJ@@X\\fTwBoDJP\t2.6\nsGX@@eMuT@pHfODj\t2.6\nHkLN@HiiWSrRSQHqRjZfX@XMFDrf\t2.59\nHmwLAHePPheNR[e][fijY@FFUp|aP\t2.58\nHeVH@LAI[eQej@@@FCIS\\L|RL@\t2.57\nsOtHBpDIRocRs@LDIsJl\t2.55\nJoB@H@RCrBSJzroSG\\@E@A@@F@iaUJz_Hx\t2.55\nsNq`@jdvsUPCCKWbK@\t2.55\nHedJ@@RaeImmfji`AaRYSSrB@\t2.54\nsGX@@eRuT@ptVxcP\t2.54\njhi@`@JLRjYeu]TzpZijjjj`@XFQ`gARUhugAyCp\t2.53\njhiA@@HIU\\rjkz}XMT@PA@@@LKPIQgARUhuoAyAp\t2.53\nJoBR@RXI`h]DmJ}dTTTTvQSSiuUTsUP@XEW[_H\\\t2.53\nj`qa@@J@Re]YyTeG^jjj`@`@FAhHpQgIZMYwnPD\t2.53\nj`q@`@@^RYWUe^cKN`@j@B@@FB`HpRbmFm{bNB@\t2.53\nj`qA@@HIU\\rj\x7FiuoUPA@@@@C@tBTYpRmFl{wHR@\t2.53\njhi@`@@HR[YfUWMypVf`@@@@@XJxJRmFl{p^HQ`\t2.53\njdya@@J@RVVyeU{A}Eiz@@@@@A`hTeZMYw`qyB@\t2.53\nj`q@`@@HR[fYU_Sk^Zh@@@@@FFlLxJRmFl{wHH@\t2.53\nj`qA@@@IJsLjoiuoLt@@@@@CASNBdkQkN}qDD@\t2.53\njhqa@@C@RYegV^tyjhHJJ@@XFqQgARUjsoAyA@\t2.53\nHg|d@dpSAPzIZU{Hhhhilbtz]UULuP@prnwdV\t2.53\nHg}DPLFD@HnHrRPjJIGLNfmPTAP@LFrnE[xdz\t2.53\nJoCd@DC_YIHhhdd\\mf}USUUT@FBxULLkiorK@\t2.53\nJoB`@@[ddTRRVJWKNuUUUUP@XZfES\\Lj]|RG@\t2.53\nJoC@A@ANRRIGIQIMuoUUL@D@AalIaTrz]orA@\t2.53\nj`q`@@@IJsLjoiuo\\t@@@@@CASNBdkQkN}rB@\t2.53\nHk]DPLFD@HNHrRPjIKYaWUjB@h@FEYpr_DiP\t2.53\nJoBB@EMddbbbQRrv[uSUUUP@XZfEprng[|a`\t2.53\nJoCFAF``{JSJroJng[UUUUT@FBeS\\Lj]oqLt\t2.53\nHk\\d@dpSAPzIZUyIfYoVgSjjifh@XYW[rC@\t2.53\nHg}@@@wIHhddlUrsmUUUUP@pULJfxYT~IE`\t2.53\nHo~@B@B\\ddTQJbRmzjj`@@A`\\IaTwKiv\x7FHD\t2.53\nHg|`@@pmrQQIPiYTrzAAUUD@LARfxYT~QX\t2.53\nHo|L@@RlbbTVbbQmvjhJ@@AaITLkiv\x7FDs`\t2.53\nHg^L`LaC@HrRPzIKJRju@AT@C@\\InF]OdV\t2.53\nHk\\`@@pmrQQIPiZfWPHJjb@FGIS\\LkrC@\t2.53\nHk]@@@wIHhddl^V]jjjjh@XRfES\\LkqHL\t2.53\nHg~H@DCHhhdeBepg[UU@A@@pdjxYWSodX\t2.53\nHkn@B@B\\dbarbRtzjh@@@XKBXUCJz_DA`\t2.53\nJoBD@@IS\\rjzv[uP@@@@@XKEMprng_DQp\t2.53\nHknL`LaC@HrRPzIKJUVh@J@AavDwCI|cP\t2.53\nHcl`@@pmrQQIPiTrzAAUQ@CCdinFUyF`\t2.53\nHg|H@JRjVWWd}njZjjh@XZfDwCJz]|b@\t2.53\nHg|H@@RYfUWd}nh@@@@@XKATwCJz_DBp\t2.53\nHcm@@@uJfUWyYvjjjj@FDiaTwCJ|RM@\t2.53\nHo~D@IADfUYUgWZjBB`@FDdwBng[|c@\t2.53\nHkmL@FFnOIIEEDRaVjYjV@FEXpsoHH\t2.53\nHeTL`HS@aLddlRPru@@@CC`SJ[ayD`\t2.53\nHcl@@DjYU_egZjjjh@XZBXUMprn|b@\t2.53\nHmvD`La@BLddNbReUj@@@FCXS\\L|aP\t2.53\nHcML@FFnwIIEEDZJuSMS@CCFF^Ia@\t2.53\nHcML@DpFEIeY}kfjYi`AaRYJ{rN@\t2.53\nHcLH@@RVYUYujBB@@X\\ULLkoLaN@\t2.53\nHmvD@EADfVUyUjjj`A`qTwCODqP\t2.53\nHmuL@DpFEIeY~nZifh@XXfKqNd\t2.53\nHeVH@BAJ]eQfjjj@FGQeMpsrD@\t2.53\nHeTH@@RYe\\YjB@@AapPUMp|SI@\t2.53\nHeV@@@RiUvnjjj`AatIaTw\\PY@\t2.53\nHifH@LAIVUxZjj`AatHUMp|`@\t2.53\nHie@@@qJYYhP`h@A`REP|Qn@\t2.53\nHieD@DHNRY[Rijih@XIc\\qBD\t2.53\nHaE@@@qJUwBZZh@XEBEWD[`\t2.53\nHaED@DHNRY[Jfjf@FDYsDI`\t2.53\nKAxX@@gILkmUHA`fEqJX\t2.53\nsOx@@eJm]UT@p\\VM_H@\t2.53\nsJX@@eSU@LDmqP`\t2.53\nsFq@@eLzts@LEkqH`\t2.52\nsJY@DDfvhAaEqX`\t2.52\nqCqPZHAD]XCB[d@\t2.52\nHidH@@RUe^Eh@@@XTUMp|RD@\t2.52\nHeTHPABHfHRYeUn`HJ@AaPXWSqJD\t2.51\nsOx@@eR}]UT@pLQoEf\t2.51\nHknHpBtJpZqZqIfUeffBBbX@FE@Pj_DrP\t2.5\nHifH@DAIVUxVjj`AarXUMp|b@\t2.49\nHifLAHABbTyInU[fijPA`e]rA@\t2.49\nHaFLAHABbTyInUnZfd@XIW\\a`\t2.49\nsFt@AdigUjhAaekrD\t2.46\nqCp@AIZ`LINXK@\t2.46\nHmv@pBBlFlVlRYfyZXHJH@FA@LkqBx\t2.45\nHif@`FBHRYVzz@H`@XDBTwLsa@\t2.45\nsOt@AdigkB@@FFU_Eb\t2.45\nHmtHPABHfHRYeW[hBBh@FEAa]ODiP\t2.45\nJoBbHFSB@DBDYIHUEDdekgZuAHTB@F@xwBng_H\\\t2.44\nHcN@@@rRHiQIKmUP@@@pfDpnFUwdT\t2.44\nsGYDJQDJHR[jf@XXQ\\e@\t2.44\nsGQLKHaQFbLddmU@LCEkrD\t2.44\nsJY@BDfZhAaaEqX`\t2.44\nsJP`@dfvhA`l^Q@\t2.43\nHg^HpBLJrZsZqIfYYye``jI`@XTASm|Se@\t2.41\nqCp@AIZ`LDmqB@\t2.41\nHaF@@@RVU[j@@@FEQaTwDC`\t2.41\nHaD@`@bDfUzZ@B@AaPIaUrN@\t2.41\nHedJ@HiagIIMEYUML@LBcFgdD\t2.39\nHid@@DjU^nBBH@FCPaTp|SN@\t2.39\nJoB`HBvDQLPdsJormuo@PUTi@AaHXWCNf\x7FHh\t2.37\nHo~D@M@\\dTRRbNTyZBBbj@A`ZYS\\Lkiv\x7FHH\t2.37\nHcN@@@rQQHqIKmUP@@@pTHSBxYW^QP\t2.37\nHo~B@D@UMInUeWzV`BJj@AaQUmorD@\t2.37\nHknL@D@UR[eY_iZ@Hj@A`QUi|QI@\t2.37\nHknL@D@]R[e[_iZ@Hj@A`QTi|QN@\t2.37\nHeTH@@RYe\\Yjjj`A`HIaUpsqHX\t2.37\nHmvD@D@TfyV~eh@b@AaaToLSi@\t2.37\nHmvD@DBTfyW^Eh@J@AaaToLQn@\t2.37\nHeU@@@qJYYzDHJH@FEHULODzP\t2.37\nHie@@@qJYWk``b@AaRES]qLD\t2.37\nHaE@@@qJYVnBB@@XDaUwDq`\t2.37\nsNx@@eLmUPCBbKGbk@\t2.37\nsNt`DPtfuZi@XYX|e@\t2.37\nsNt`DQTfuZZ@XQ|Rp\t2.37\nsKT@@Ti\\YZ@XR\\rq@\t2.37\nQMPBcdGcH\t2.37\nHmtD@@QIme\\YZ`@`@XTeMp|SE@\t2.36\nHiFD@FADf]Yjj`A`QUp|c@\t2.36\nKA|H@TBIJkMUPA`VDw\\b@\t2.36\nsGU@DPdvmT@prqyJ\t2.36\nsJY@LDeVdAaEqP`\t2.36\nHeTD@@YIfUqfhH@@FC@U\\L|rLX\t2.36\nHid@@DjU^nBBH@FCPfEP|Qn@\t2.35\nsJT@@TkVhA`enJD\t2.34\nHcML@FFnwIIEEDZJuSMS@C@lXYyA@\t2.33\nHmuL@DpFEIeY~nZifh@XDfRoHx\t2.33\nHaG@@@rdigjXHB@A`fMqDx\t2.33\nsO|@AjeL}XP@@pV_Db\t2.33\nJoCbPCRzg@QddbQRRtuMpuUULuP@X]FEWR\x7FDRp\t2.32\nsNq`@fdskUHCAX|e@\t2.32\nsJX@@eSU@LMEnP`\t2.32\nHmuH@DHDf{eYUj`@@AavDwCJ|a@\t2.3\nsGR@@mTf]jPFFBoEb\t2.3\nsGX@@eLuT@pHbwDZ\t2.3\nqCr@PIKLAy`l\t2.3\nsJX@@eMU@LLL^JH\t2.3\nHg\\B@@z]RVUeWXV@Hjh@FEXRg_H`\t2.29\nHcLL@@yTee[]aX@bh@FAXT{qHX\t2.29\nHeTD@@EIYWVy`@h@FFXT|rJX\t2.29\nsJ\\@@bdjt`LLD^JX\t2.29\nHg^DpBtpkAkEkDfYnVvfBBbZ@A`PBi|Pk@\t2.28\nHklDpEtJpZpzqIfYfVf@bah@FA@NgqNd\t2.28\nsGX@@eLuT@pLVoDB\t2.28\nHo~DpBNpkIkMkDfYeeYe``jIX@FE@Tz\x7FDyP\t2.28\nHeTD@@EJYU^f```@FCIc\\L|Pj@\t2.28\nsKR@AEdi\\Vf@^KD\t2.28\nsJU@DPdvu@LDmrD\t2.28\nHid@@DjUfaBB`@FCPfEP|Qn@\t2.28\nsJY@DDfvhAyeb\t2.28\nsKR@AEdi\\Vf@XS\\a@\t2.27\nqCp@AJZ`LEEqC@\t2.27\nHidL@@pTifvnjjj@FEPaTwLsa@\t2.26\nHaDD@@YJYZnjjh@XEFEWLQn@\t2.26\nsOx@@drm\\@@@pJM_DL\t2.25\nHaDD@@qJYnnjjh@XEBDwLrn@\t2.23\nsGX@AddQjhA`Xl^R`\t2.23\nHidH@@Rfuvz`@`@XXfUsBXP\t2.22\nHkmL`LNDD@cIIBhdmeuZ`PH@FCXwRi|b`\t2.22\nHeVH`IDHaIe]jZ@BX@FE@fEWHd\t2.22\nHmt@@DjU^ZxHHj@A`LIaTpsrE@\t2.22\nHeT@@DjU^k``b`@XCBXULL|c`\t2.22\nHieH@DDDfyWaZ@@@FAES]rD@\t2.22\nsOx@@eRimUT@plVMyF\t2.22\nHiDJ@@PnEInvZjX@XDaTOHp\t2.22\nHcNL`IaM@HrRFIKI\\Jp@T`@phj[ix`J\t2.22\nsNyA@qNRRJuU@LGEcV\t2.22\nsGP@DjVj`FAbMxa`\t2.22\nHcLL@@zTeeY]aX@bh@FAXR{qHD\t2.22\nHeTD@@yIYVvE`BH@FFXT|rFD\t2.22\nHeV@@@Rig\\YjB@@A`rEWCODq`\t2.22\nHeT@P@bIbDfYU[hBB`@XTFEt|Ra@\t2.21\nHeWH@DJPRY[TYZ`@@AaRTwCrB@\t2.21\nHmtD@@QIge\\YZ`@`@XUeMp|aP\t2.21\nsO|@AbeLmXD@@prkyB\t2.21\nsGX`LBdjlt@pexh`\t2.21\nqCr@PISRAaErX\t2.21\nqCqRZHAFzNlAxa`\t2.21\nsJY`hEiNyIej@^P`\t2.21\nHaEH@DxDeeVyjj`A`VES\\RN@\t2.21\nsGQ@HeUuT@ptuxdP\t2.21\nj`qAB@A@bDfUvVuhqwh@Jh@@@AahBLDisQkN}rB`\t2.19\njhiP`@DD@iIf[eW\\cK^Zj`XHh@AaK`iZMYw`|Q``\t2.19\nj`qP`@FBisIIEED[DdpSoUSMP@P@CAfMFl{wLDEH\t2.19\nj`aa`@H\\m{IIEUMDeBYuUU@DP@C@tDXIQgIJM[p\t2.19\nj`qA@@@ISKMjoiuoUT@@@@@CCTDLxJRmFl{bJ^@\t2.19\nj`aA@@OYIHhbeHhyVj``jJ@@XJQ`eFRUhwnP\\\t2.19\nHo\x7FD`Hu~fpcIIEULeDk^jjjZX@XSBXUMpwrC@\t2.19\nHg]LPLfDD@bxcIIBhhd]ikTC@P@LFqnW[yD`\t2.19\nHg_L`L[hR`BLdaTrbRQvmMUUP@pGFFUt{y@@\t2.19\nJoBP@@XVyHhdhTleSKhDEUUD@FDiS\\Lj]|ap\t2.19\nHg~@pNbPRPrPrRRqQISSiwU@@@@@LBZ]obJX\t2.19\nHg~@pJbPRPrPrRRqISICIwU@@@@@LB[SobBh\t2.19\nJoBDP@aDILkmrmM[p@U@@@@XZBXU\\ng[|`P\t2.19\nHk^DB@TpgIIEECTfGijjjih@XSBXUMpsrM@\t2.19\nJoB`PCFDPdrmvnuvg@DUUQ@A`hIe\\Lkm|ap\t2.19\nHg~DB@TpgIIEECThp}MUUUMP@pfDpj[agdV\t2.19\nHo\x7F@@JE|ddTnRbRmzjj`@@AalIaTpkiwrN@\t2.19\nJoBb@BDByEEEMDdbSV{UTC@P@FC\\Lg[|sBt\t2.19\nJoC@@@YIDdThdlUG]US@AP@FFpfESRnf\x7FHx\t2.19\nHknLPLaA@HNHrRPjIKY]VhDB@A`vMtj_Hh\t2.19\nHo|D`JyxcIIEFeDecnjZ`@`@XBfEJz[|a`\t2.19\nHg}H@HP\\ddRJTrUL]uUR@D@CBXpje]N~P`\t2.19\nHg|LA@kTfnRfYgW[iN`jBbP@XTPsi|Q[@\t2.19\nHg}HADH@zIRYeYwIcnjfB@`@X]prng_Hp\t2.19\nHg~@`IBHRYWVUicn@B`@@@XRBXUKiwrN@\t2.19\nHo|H@GrRQQEJQN[j``jH@FBiaTpkiorI@\t2.19\nHcNL`EaLBDrRRqIYCKT@E@@pDDrfxUyF`\t2.19\nJoCD@A|eTrj\x7Fr^wU@tDT@A`nESCJ{[|a@\t2.19\nHk]@`FLHaIe[mZ{S`BJjH@XRBYWCJ{rC@\t2.19\nHg}@`FLHaIe[m^ntx@bjh`AaHIe\\LkoHl\t2.19\nHo}L@EN]_IIEYEEBSnjjfZX@XMBXRgrA@\t2.19\nHk~@@JrRQQIFHUgYNjjjjh@XGBXUMprnf\t2.19\nHo}L@C^moIIEFeEEC^jZjYh@XLfDwCqC\\\t2.19\nHk]@@@YJUueRkSjj`@`@XKBXUCJz_DA`\t2.19\nHmNHB@TIrRQQPuazZjjj`AaLIaTwCOHT\t2.19\nHg]L@ItUoIIEXhiciuUSML@LFaLJ]yE@\t2.19\nHg}@@@UJfUW\x7FegZ`hHj@A`jXUMpsi|bp\t2.19\nHkm@@@kIHbdhdmNjj@@@FBpfDprngrJ@\t2.19\nHmvL`EaLBDrRRqIXYZ`@`@X\\BYS\\OHT\t2.19\nHko@@@q\\dTRbqThP`hj`@XBaTpsi|c`\t2.19\nHk]@@@UJfUW~V]jB`b`@XRfES\\L{rC@\t2.19\nHcND@M@\\dTRRbOKPPTP@LASJ[ae^HV`\t2.19\nHk^@@@Ri_YVftzjh@H@FBpfEPrngrF@\t2.19\nHcm@@@UJfUWyYvhJBH@FDiaTwCN|aP\t2.19\nHigDPLXXP@b`cIHUDnEZfd@XIe\\PN@\t2.19\nHev@B@B\\ddTTKCtuUUT@LAaLJfx^QH\t2.19\nHg\\H@@RYegUvvj```@FDyS\\Jz]|QI@\t2.19\nHknH@FAIfUWaVhHHh@FFaFES\\Lz_HT\t2.19\nHg\\H@NrRQRqZIRmTDAT@CCdpf{SyE`\t2.19\nHcLL@@RlbbTLRRzuUUT@LNinFUwbXP\t2.19\nHkmL@FFnOIIEEDlqvjYjf@FAXpsqBT\t2.19\nHcM@@@gIEDdTiS@PUT@C@TrfxUwdD\t2.19\nHcNH@McIIEXdmJuT@D@CCdpfxYyF`\t2.19\nHcND@E@TfUvzf`@jh@FD`fEWCN|aP\t2.19\nHklH@NrRQRqZJUj``J@AarXS]i|aP\t2.19\nHcO@@@rTie_ZnBBJh@F@hUMpkoHp\t2.19\nHcOH@DKPRYYUYujAB@@XLeMpsrE@\t2.19\nHmtH`ABHRYWUih@Jh@FC@fEW\\RU@\t2.19\nHeW@`FFZBLddTjWCUST`C@dpjyD`\t2.19\nHmtL@@Pdf{eYUjjj`AaqTwCJ|QL@\t2.19\nHmvD@AADfyW^Ejjj`AaQTwSsDqP\t2.19\nHcw@@Hx\\ddRLTeUSU@CBXSBxYWP\t2.19\nHmtD@@EIe]nf`@j`@XBBXU\\J|bP\t2.19\nKAxPPUD`dadataddeRjj`CBFyA@\t2.19\nHeVD@AADfyWxVjjh@XDUMwLSI@\t2.19\nHeVH@BAIUeQfjjj@F@`fTwCOH`\t2.19\nHeT@`@qDfUuih@J`@XLBXUCqNd\t2.19\nHeU@@@yJeWzzjjj@FGPfESCqNd\t2.19\nHmwH@DIPRYYWeVhD@@FEISCOHx\t2.19\nHmvH@DAIe[VUZh@@@X]eMproHP\t2.19\nHie@`FF`cIIEJnFjfd@XDfEWHx\t2.19\nHeVH@FAIfUqfhH@@FGAFEWCqFd\t2.19\nHeTD@@qI[eQejjj@FGXUMpsqHP\t2.19\nHmTL@Fy\\ddUfRjijPAaTIaCrI@\t2.19\nHiT`@@pjRfUj[a@`h`A`gCqDX\t2.19\nHid`@@pjRfUjXBB`@XIp|QF@\t2.19\nHaDH@@RYm[jjj@FC@aTw\\RL@\t2.19\nHaEH@LXDeYVzje`A`REW\\PH@\t2.19\nHieH@BxDivWajjV@FAYSCqHP\t2.19\nHiF@@HrRQVJjj`AatIaTw\\`P\t2.19\nHidH@HRjuVFjjh@XMBYSCqBx\t2.19\nHiDD@F{IIEYjjZ@FAPfErA@\t2.19\nHieD@FFnRjYfFjYh@^EaLH\t2.19\nHaED@DHNRY[Jfjf@GaIaL\t2.19\nKAxH@MvRRJrjf@LBaLKd\\\t2.19\nsGPdE`DSpRYVj@XXF|d@\t2.19\nsNq@JeTuUPCBkFod`\t2.19\nqCbHHAD|DeZ@pPwI@\t2.19\nsFxHB@aJUqiZ@XHSbU@\t2.19\nQMPARVAaWDP\t2.19\nsJX@@eSU@LEEqX`\t2.19\nsOq@@eLm]UT@ptMyef\t2.18\nsOpHADILkW@@@LBEcqU`\t2.18\nqC`P@HRfhCAC\\TP\t2.18\nsFx@@eRfuU@LCD[rX\t2.17\nj`q@`@HRRjyeU\x7FSk^j`B@@@@FFhTYpRmFl{wDDd\t2.17\nqCh@CIKTA`hnHX\t2.16\nsOt@AdiWqZZ`FAbMyF\t2.15\nsGX`LDdsmT@pVOIP\t2.15\nsJX`LDdru@LInP`\t2.15\nHieL@DpFEIeYkfjY`A`bYrN@\t2.15\nsGP`@dfui`FFVOIP\t2.15\nHeVD`La@BLddlRPrm@@@C@j[axfR\t2.15\nsNu@DpdjkUPC@hu|Tp\t2.14\nsGX@@eJuT@pLVODJ\t2.14\nHid@@DjU^nBBH@FGPfEWCrF@\t2.14\nHeT@pHdDdLdLddlRPsU@@@CCJ[nHL`\t2.14\nHkld`LKmePBLdTQTRbrjYffh@XDBD_Ht\t2.13\nHcLB@HZ]rRQJJqCMUUUP@pELJfxUyF`\t2.13\nHcOD`LKiT@cIEDUDeeTsMM@C@`Pmy@`\t2.13\nHmtL@HZ\\ddRblFZjjj@FGIaTwKrA@\t2.13\nHeWH`LKa@HrQQEIYULsT@LBABgdL\t2.13\nHaGDAHK`RISdfyVyjZPAaE\\Pf@\t2.13\nKA|@@@eRkUU@FCPfES\\c`\t2.13\nsGX@AddQjhA`Xm^P`\t2.13\nsJQhHl@bOV`FBq@\t2.13\nHif@@@RfU~F``@@XLfDwCq@h\t2.13\nQMPARZAaWDP\t2.13\nsJX@@eOU@LMEnHD\t2.13\nHieH@DxDee]nZjj@FAXUMqHD\t2.12\nsNxDLHaqBRjuU@LFHcWrX\t2.12\nsNz@@mVdssTpCCAWbs@\t2.12\nqCsAPKR]rSM@^Q@\t2.12\nsGQ@@drmJ@pRwDZ\t2.12\nqCp@AJZ`LHnXS@\t2.12\nHcnLbLe]@HwldTRaRa]SUUTmH@ppHSbEP\t2.11\nHk^LbLWS@HOdiem^KjZjjiZPAa`PgDHP\t2.11\nHcNL@ICNrQQSRjTMUUUP@pfDJfxUwdX\t2.11\nHmvD@ACdiewjZjjj`A`LXUMtkrD@\t2.11\nHif@@@RUe^Fh@@@X]BES\\OH@\t2.11\nqCh@BISLAyhl\t2.11\nHo~LpBtwBlFlVlrJJJZISUi``hfd@FA@JgqBl\t2.1\nHg\\LpEvpkAkCkDfYfYVf@bai@A`PCi|Si@\t2.1\nHg\\h@De]CHeDeMDcimU@PP@LFcFE[yA@\t2.1\nHcL`@@rirQQSRiUpPQU@@pkFx]xdj\t2.1\nHcLh@DxYCHdeEDcJmPDD@CBhqawdH\t2.1\nHeT`@@rirQQSRupPQP@LBqnGdR\t2.1\nsGY@BDeVj`FAbux`P\t2.1\nsNq@@dr{UPCCHwbs@\t2.1\nHaDH@@Rfu[j@@@FFIe\\pfx\t2.1\nQM`AIXFE\\Q@\t2.1\nsJQ@@dju@LEcqQ@\t2.1\nHcLD@@QIeVuWVj`@@AaqMprn|c@\t2.09\nHeTD@@EIe]jZ@Bh@FG@fEWCrI@\t2.09\nHeVH@DAImeQej@@@FCYS\\L|a@\t2.09\nsNx`LDdskUPCAX|UX\t2.09\nHg}LbFM]n@c^rRQJEJITpsUUTtt@LFaLJayA`\t2.09\nHk^LbFWS`HwlddRaRfiafjjif`AaTIaUrA@\t2.09\nQMPBchGfR\t2.09\nsGYALMJRmUPCBbHwdp\t2.08\nRF`EFCqH\t2.08\nHig@@@rdifznBBH@FFXw\\`P\t2.07\nHaG@@@rdifzxHH@AafMwHH\t2.07\nsJT@@TeZhAaaEqX`\t2.07\nHeTH`ABPRYWZf`@f@A`RXU\\bP\t2.07\nqCq@XIIf`LInQ@\t2.07\nHmtD@@QIn[VUZh@@@X\\fTwCOHT\t2.06\nHifH@DAInUxV`@@A`aUpd[a@\t2.06\nsJX`LDdru@LH^S@\t2.06\nHaF@`NBHRYWih@H@FE@fEWHx\t2.06\nHeL`@@JfRiUfnXVfjjjh@XMBYpr\t2.06\nHeU@@@{IHddUWUUUP@pZDpjGbMH\t2.06\nHeTH@@RfV\\YhH`@AaRDpsqJx\t2.05\nsJU@E`djt`LHnJD\t2.05\nsJPH@DISUPCCCGbb@\t2.05\nHifH@DAInUxV`@@Aaa\\OLRf@\t2.04\nHcLL@@PTfye]]ZhH@@F@yS\\LkoHP\t2.04\nHieH@FDDfUfnjjj@FGAATwCqDp\t2.04\nsKXHB@aJWFe`FBDxe`\t2.04\nHmvD@E@TfUvzZ@Bj@AapHU\\L|SE@\t2.03\nHaD@@DjWZXHB@AaTXS]rD@\t2.03\nsJX@@eMU@LMEnHD\t2.03\nHaDH@@RVU[f@@@FBXWBbfx\t2.03\nQMhHchFD|h\t2.02\nHg^``NeSlHaIe][Zf`@ii`@XRBXU]JgrK@\t2.02\nHkl``NeSBHRYWVvf`@ii@AaHIaUtj_Ht\t2.02\nHmw@`NePbDfUujZ@Bf@AapIaUt|aP\t2.02\nHeU@`NdHaIe]ZZ@Bd@FG@fEWSrA@\t2.02\nHidH@@RYm^Fh@@@XMaTwCq@`\t2.02\nsOpHADILkW@@@LJEc^Q`\t2.02\nsOx@@eJqh@P@pLQoHp\t2.01\nHg|@@LdbRbtJUB]aAP@@@CCXSBhYWSod\\\t2.01\nsGY@DDfUj`FDWMcP\t2.01\njdy``@J@BdlsOJkbezKMUPTBH@C@QJLUjsh|q@w`\t1.99\njhiP`@DD@iIf[eW\\cK^Zj`XHh@A`kGARtZsoAy@`\t1.99\njhi``@F@PdwLsvoIW`mMUPPB@@pEQgMFlxOLHex\t1.99\nj`qa@@J@RVYgm\\Tg^YjjB@P@F@bTXkQk^yb@g@\t1.99\nHg]HpBOPkAkEkLbbbfbT[SAAQM@@phAT{xaR\t1.99\nHg}D`LFD@HrRPjJIYLNvmPTDP@LFrnFUyfgX\t1.99\nHg~L`LaC@HrRPqQYI]NvmTBDP@LFXUt{yE@\t1.99\nj`a`P@D@ejrSKZrkbTu@DUT@@pXbcCN}rA@\t1.99\nHg~@@@rQQQUQIUqwSMP@P@LA@fzUv~YeF\t1.99\nHkmH@JXLdRRbbQtzjB`@@XCF\\Lki|a@\t1.99\nHclD@@kIEEKDeeKmUP@P@LNcNFUwbHP\t1.99\nHkmL@FFnOIIEEEBqvjYjf@FAXpsqBT\t1.99\nHknD@EADfVU}eVjjjh@X\\UMpsoDpp\t1.99\nHcLH`ABHRYWYzZ@Bj`@X\\BXURoD{P\t1.99\nHcLH@@rIQQQHkkTE@@@pxj[iW^YBB\t1.99\nHg^L@DB]RY[VWEVh@bh@FEISG_DIP\t1.99\nHg^L@DBSRY[VwEVh@bh@FEIS[_DHP\t1.99\nHcND@EADfVU~UZjjj@FCES\\L|SM@\t1.99\nHmtH`ABHRYWYih@Jh@FC@fET|Se@\t1.99\nHmLD@@qJY{WJeZj@B@A`rMproDb`\t1.99\nHmM@@@qJWYWBeVf@B@AaVMpssHQP\t1.99\nHkmH@DhDfUnYTvj@b@@X\\fCJz_Hh\t1.99\nHcML@DpFEIeY~kfjYj`A`RYJ|Sm@\t1.99\nHeTH`ABHRYWZf`@j@A`pIaUODxP\t1.99\nHmvH@AAJYUgehHJ@@XBfES]J|`P\t1.99\nHmvD@JADeUeYUjjj`AavDwCJ|b@\t1.99\nHmtH@@RYeUEZ```@F@aaTwBoDbP\t1.99\nHcND@DBTfVulUZ`BH@FAIS[sBEP\t1.99\nHcND@DATfVutYZ`@h@FAIS[sBxP\t1.99\nHeULBDpFGNRYV^nZif`AaB\\Si@\t1.99\nHeVH@FAIe]ZZjjj@FG@fEWCqHd\t1.99\nHmtH@@RVYWeVhH@@FCTwCJ|rDH\t1.99\nHeVD@J@TiWUJjjjh@XMBXS]rI@\t1.99\nHmtD@@QIee^UZjjh@XLULLkqLx\t1.99\nHifH@FAIe]ijjj`A`pIaUwD`P\t1.99\nHifD@J@TiWTjjjj@FCPfDw\\`P\t1.99\nHeTD@@QIemQejjj@FETwCODp`\t1.99\nHaFH@FAIe^fjjh@XTBXU\\RN@\t1.99\nHidD@@QInUxVjj`AaQTwCqDp\t1.99\nHaFH@FAIe^fjjh@XMBXU]r@@\t1.99\nHifH@NAJ[W[jjj`A`tXULOHP\t1.99\nHifH@NAIYW[fjj`AaVESCqHP\t1.99\nHiFH@LAIYVjjh@XBBXUMp|b@\t1.99\nHaF@@@Ri][jjj@FCPaTw\\c@\t1.99\nKA|P@TBTkuUT@XUFDw\\a@\t1.99\nKA|@@@eSKUU@FCPfDw\\b`\t1.99\nsNqdEbOBABUVmU@LMJ~P`\t1.99\nsOy@FDfUkjj`FEBqoEF\t1.99\nsNx@AdbbMUPCAbXu|b@\t1.99\nsNy@LDeVjj@XTXu|TP\t1.99\nsNq`IVeUuTpCCXod`\t1.99\nsGY@DDfyj`FBVxcP\t1.99\nHeUH@DDDf[WxVjjh@XDUMwDrP\t1.99\nKA|@`XDQtPdkOUU@FCABDw\\b`\t1.99\nHieH@DDDf[WaZjj@FAES]qLD\t1.99\nsKTHLPDIRxtl@p`xh`\t1.99\nqC`P@HRfhCBCfbp\t1.98\nsJU@DPdvu@OLlP\t1.98\nHieH`B[`BDiWWBiYj@FFA@|QJ@\t1.97\nHeTL@@pTifwkjjjh@X]BESCODs`\t1.97\nHidD@@[IEDiZzjjh@XMFESCqDx\t1.97\nsJP`@dfvdAaEqX`\t1.97\nsGY@DDfuj`FBQxmP\t1.96\nsGX@AddQjhAahcqZ`\t1.96\nsJQ@@dsU@LDCsQX\t1.96\nqCh@CIKTA``nJX\t1.95\nHiDB@@SaR[Ufjf@FAIeCrB@\t1.95\nJoc@HCADRDILkZvm]Jv|@QP@D@AaHIeSiv\x7FHX\t1.94\nsFt@AdigUjXA`d^KT\t1.94\nsFt@@Ti_FVhAaIsKT\t1.94\nHg~@@@RiU~Ukcnjj`@`@X[BXUMJz]|c`\t1.94\nHcND@IADfyW[aZ@Bh@FCES\\n|a@\t1.94\nHeTD@@QIgeQej@@@FEYS\\OHd\t1.94\nHklL@@kldTtTRQEZBHb`@XTcCN|`p\t1.94\nHmtD@@iJ[eWihHH`@XDaCODYP\t1.94\nHidH@@Rfuvz`@`@XXeMsLHP\t1.94\nHeUD@NdBRYgeajjj`A`HPeMpsqLH\t1.93\nsGX@@eSUT@pLVOIP\t1.93\nHg}LbLGSl@b~rQQJIIFEuMUUUKR@LBBDKbCH\t1.92\nJoBaQFBivxAE|eLlzmeuMUUTsL`AaPPaCqJt\t1.92\nHk]LbLE]L@`~RfV]xnijjjei@FAABEqJD\t1.92\nj`aA@@GYIHhbeHfiVj``jJ@@XJQ`eFBdkQnP|\t1.92\nsNqLKIARFdLddjjj@XP|c@\t1.92\nsJP@DiVhAaaCqK@\t1.92\nqCb@AIj`LHNZK@\t1.92\nsGQhHl@cIIBmPCBGdh\t1.91\nsJP`@dfvdA`enP`\t1.91\nsJU@DPdvt`OLlP\t1.9\nHmuD`LVD@HrRRqIXYV`@`@XES\\ODqP\t1.9\nHmtD@@yIYe^UZ``@@XBaTwCJ|b@\t1.9\nHieH@LDDeYWajjj@FGABES]rA@\t1.9\nHeUH@LDDeYWxZjjh@X\\DHUMwHd\t1.9\nqCp@AJZ`LINXK@\t1.9\nHk]H`AdpbDfUmUiev@Bfd`AaPIe[qND\t1.88\nHaED@dpFChdi[dfUjzjjPA`bUqLx\t1.88\nsGY@LDeUj`FFQoEL\t1.88\nsJ\\@@bdks@OEb\t1.88\nHk^@@@rQQIFIJftpHH@@@FDieLLki|``\t1.88\nHieDPLZD@HhHrREQKaVii@FAYWCr@@\t1.88\nHcLD@@QIn[WeVj@B@AarYS\\L|cP\t1.88\nHaDH@@RVU[fjj@FEXUMwDa@\t1.88\nsNx@AddTMUPCBqXwdX\t1.88\nsGX`LDdwMT@pQoH`\t1.88\nHaDH@@Rfu[j@@@FFIS\\sBx\t1.88\nsJX@@eSU@LINYX`\t1.88\nsGY`hEiNyIgZhAaCrT\t1.87\nHid@@DjU^nBBH@FGPaTwCrL@\t1.87\nQMB@HRZAyd`\t1.87\nHcND@MADfVU~UZ``H@FCESCN|c`\t1.86\nHidD@@EIe]ih@J@A`pIaTOHx\t1.86\nKA|PD@pSddbljj`CAhSBknPp\t1.86\nsNxA@IrRQVjhAaXlWrT\t1.86\nsNqhHl@cIICej`FBMyF\t1.86\nHeTD@@iJ[e^f```@FAHPsqFx\t1.86\nsGX@@eLuT@pHfoDb\t1.85\nHmtD@@gIELeDVz`@j@A`RYr|Pa@\t1.85\nsJQ@IGuPCAQ\\VH\t1.85\nsOt@AdieuZf`FBQxjp\t1.84\nHidH@@Rfufz`@`@XXf]sBXP\t1.84\nsJX@IGuPCCKGd`\t1.84\nqCr@XISTAaEqS@\t1.83\nsJP`@TfVhA`d^S@\t1.83\nHidH@@RYm^Fh@@@XLDES]qLD\t1.83\nHcLL@@kdinYTUhHbH@FEHpsoHT\t1.83\nqCb@AIZ`LDmqB@\t1.82\nsJY@LDeZhAa`mqP`\t1.82\nsJXHLHaIVj@XXQ\\VH\t1.81\nHid@`@qDfUvf`@h@FE@fEWDxP\t1.8\nHeTD@@EIe]jZ@Bh@FC@aUp|SI@\t1.8\nJoBD@@IKLrjzv[mP@@@@@XZeMprng[|b@\t1.8\nHidD@@QInUxV`@@AaB\\hj[a@\t1.8\nsNq`IVeUuTpCAQ|VH\t1.8\nHidL@@pTifvnjjj@FCPaTp|SN@\t1.8\nsJQ@@dsU@LMEnHD\t1.8\nqCp@BOTAyhl\t1.8\nHmu@pBXJpZqZqIf[oi`bH`@XX@ksBZP\t1.79\nHcND@DBdeVyU]Zj@@@FGHU\\LksHsP\t1.79\nHmvH@LAIUYVUZX@@@XLc\\LkqHH\t1.79\nHaF@B@B\\ddRK]UUP@pZDrf{dD\t1.79\nsOxA@IRi^njj@XNKFod@\t1.79\nsFx@@eJfuU@LCL[qA@\t1.79\nsGU@E`djmL@pROEJ\t1.79\nHo~DPJHPbDbDf{VyVwjZj@@@FBaBUpkiwqF\\\t1.79\nHkmL`LVDL@cIIKDedaeZ@Bd@FETwBoDsP\t1.79\nHmuL@ATBYIf[oijjjh@XRDIe\\LkqBX\t1.79\nHmvD@EADfVuqej@B@AaUMpkrB@\t1.79\nsGQ`@ZdrmT@prMyL\t1.79\nHaD@`@bDfYVz@`@AaPXS]rJ@\t1.78\nsJX@@eKU@LEEsCD\t1.78\nsFx@@eJf`@@LCEkrD\t1.77\nqCp@AJZ`LDEqS@\t1.77\nsJT@@TeZhAahmq@`\t1.77\njhiQ`@FBisvRRJJJKEYBLxMTsAPI@@LIDXJRmV\\D\t1.76\njhiQ@@DT@drsJsNku`mUAQED@@ptcCIJtZsoAyB`\t1.76\nj`q``@ERuddbRRbnRXk`jjjYjj@AaJBLDxHug\\ax\t1.76\nj`qP@@@BRfUWyWdg^hHH`@@@FA`HpRcNBtZsnHex\t1.76\njhya@@J@RfV]YwIQUoAjTH@@H@@XJYrRmFl{p^PP\t1.76\nj`a`@@@YIEChhhdW^jjhJ@@@XV`cAJBdkQkN}rC@\t1.76\nj`ia@@D@RYYYU\\cMNmyjh@@@@@FDd\\EIVcV]qFO@\t1.76\nj`q`@@@YIEDdcDef\\]zjjhHB@@XN`cAJLyIVcV]x\t1.76\njhiQ`@DD@hJSLwJnyFV|uU@pPp@C@VNBehuo\\PQp\t1.76\njhi@`@H^RjyV}}EjsjjjB@j@@XF`cANBdkQkAyA`\t1.76\nj`qP@@@\\RiUwYVgG^jjf`@`@FFhHpRcMFl{wDBd\t1.76\nj`qa@@D@RYfv]TgK^ZjhHH`@FBbTxJRmFm{bLN@\t1.76\nj`q@`@@TRfYW{TRg^hJB@@@@FFdXIpRmFl{wHL@\t1.76\njdy``@G\\DeTsJn~j\\[uTCTEEP@C@vBTYIVcV|FH\t1.76\nj`qP@@@LRe]UYTeG^@Bj`@@@FAhHpQgAZMYwnPd\t1.76\nj`qP@@@\\RiUwYVgG^jjj`@`@FFhHpRcMFl{wDBd\t1.76\nj`aq@@DV\\CHheEDcddkSTE@UP@C@rBTYpTeFl{p\t1.76\nj`q@`@HNRju^uu`cVjjh@J`@FFhHqQ`iJt[wHD@\t1.76\njhi@`@@HR[fuvUdkpVj@B@@@@XZQagARMYw`|aP\t1.76\njhi@`@@HRYyWVUEKpVh@Ijh`@XJqQgAFl{p^PT\t1.76\nj`qQ`@DXArRSLm\x7FJlD{sUSL@D@@pihug^ycEA@\t1.76\nj`aA`@HLyddbTLrRbMzjfBB`@AaKAARUhug\\ax\t1.76\nJoBfPCRio@QddbQRRtuMpuUULuP@X]FEWS_DQp\t1.76\nj`qA`@@HddwJzroAN|t@E@@@@LAHISQkN}qCN@\t1.76\nj`q@`@@HR[YWYTTg^Z`@`@@@FBdTYpVcV]{dL@\t1.76\nj`aQ@@DZ@dwLjsrkMTDEE@@LMHhs`iJMYwnPp\t1.76\nJoB`@@CddRRJTRU][uUU@A@@X[BXU\\ng[|Qa@\t1.76\nHg^BpLaCl@chcPcIIKEEeiJkPPDh@LJqnE^Qh\t1.76\njhq``@I@BeLljrrIUADQUT@@pT`eF\\tZso\\`D\t1.76\nj`aa@@C@RYegU{Ufj``b`@FFlTYpTeZl{wHH@\t1.76\nJoC@A@ANRQQIUQIDuoUUL@D@AalIeMrz]oq@D\t1.76\nHo}L`L^DL@cIIChdliiUZ`@j`@XSaMpsiwrG@\t1.76\nJoB`@DgddbbRRQpgmuPUAE@@XJfES\\J{_Dep\t1.76\nJob@@FRRJJEIKXRv[uP@@A@@FFyS\\Lkiv\x7FHH\t1.76\nHg\x7F@PBWPbAbLbbbRfaSR]pPLUQ@CBPqae]Np\t1.76\nJoBB@D[ddfbRbJwC[uUTBA@@X[BXWCJg[|a`\t1.76\nHg]L`EnDpHSIIKDeddLmP@UP@LEALinE]OdV\t1.76\njhqQ@@DT@drlsLjXKUAQEP@@ptc@iJtZsoA@\t1.76\nJoBp@@XUMNRJJIESIUunADT@@@AaqMJz]|ap\t1.76\nj`aa@@I@RfVUYXRjBHbj`@FBdDhsfcV]{dE@\t1.76\nJgCFAD`esJSOJrhrn{[UUUUT@F@eS\\Jz_DrP\t1.76\nHg}@@IOIIEDddbI{]TEPQ@@pULJfxUv~II`\t1.76\nJoBDPD@DIWLrjzv[mP@@@@@XZeMprng[|`@\t1.76\nJoCB@BsnRRIIJJyLoCUUSMU@A`LIa\\IwrG@\t1.76\nJoB`P@vDPdrnlktqw@AUUQ@A`hIaUJz[|c`\t1.76\nJoCd@bDpAtRdsLm{euoUTpPD@Aaprng[|a`\t1.76\nHcNDpLa@BJbFbLddLTJRzmT@@@LFinFUyF`\t1.76\nHmnDBJAZgIDeDdXPjzZjjjh@XCBXS\\L|Re@\t1.76\nHk~LBAACFTeYVUxYUSZjjjj@F@xUMtkoD`P\t1.76\nHo~B`LaK\\@cIICEBeeEuZh@I`@XUprk|Rf@\t1.76\nHctNPDpfFUCpkprRQRVSSUST@LFpfzUyF`\t1.76\nJoB`@@NeRk|kuqwUUP@T@AalIaTtkiorN@\t1.76\nJoB@P@QBSLjsnNv}HP@@@@FD`U\\Lj]|sM\\\t1.76\nJoB@P@QBRsLjnmf|t@@@@@FDaS\\Lki|rK\\\t1.76\nHo~L@C`YrRSIFYIRfjjfjj@FDpfTr{[|``\t1.76\nHknL`EaLBDrRRqIYHYZ`@j@AaHIeMpkoHL\t1.76\nHklDPNGX`xcIIDcEeHRjifj@FGPfDvgrE@\t1.76\nHg^L@MAirJIJHsIUt@QUT@CAPSFxYW[yA`\t1.76\nJoBd@BNBRsLjnmf{TEAQD@FBeS\\LkiwqH\\\t1.76\nJoB`@@ReRkkZuuoUUT@D@A`\\IaTwKiv\x7FHd\t1.76\nJoBd@BNBSKLjnmf{TEAQD@FFhUMprng_H\\\t1.76\nHg^B`LaCl@cIIBidliJkT@Dp@LJ[af~Ie@\t1.76\nHg^D`La@BLddLTVRVvmTDD@@pznFUt~Hu`\t1.76\nHg~@@@rRJIJqIMqwUUP@P@LMaLIne]N~QP\t1.76\nJoC`@@QrTvnljwV|uUP@P@FDxULng[|QA@\t1.76\nHg]L`LnDD@cIIBhhd]ikTC@P@LFqnW[yD`\t1.76\nHcoL`DphWP|LddtTSeMpmUUMP@phj[ayF`\t1.76\nJoBD@DIU\\k^x{[uUTDA@@X[BXWCJz]|Qg@\t1.76\nHg~H@KAIfYU^Svz`hJH`A`XXUMprng_H`\t1.76\nJoBf@BXCBdrl\x7FJuunuSL@D@AarXng[|c`\t1.76\nHg~D@Eg\\ddRRTUsKpuUTsU@CChSBxSyE`\t1.76\nHo~H`CDHaIe]gVih@Jjj@A`hIaUJ{[|c`\t1.76\nHk\\H@HrRSIFIJftzjh@H@FBpfTprngrB@\t1.76\nHg~H@DCHhhieBdWG[UU@A@@pDjFUt{xf\\\t1.76\nJoCD@B@dsMl{eunuUPPD@AaIUpriv\x7FDsP\t1.76\nJoBf@BXCBdrl\x7FJuunuSL@D@AaRz]osDs`\t1.76\nHcLDPNEXcXcIIDcDYBUULu@CChSBY]y@`\t1.76\nHg}@@@yJe}YVfNzjj@B@A`lHUMJz]|SN@\t1.76\nJoBD@@ISLk^x{[tE@@@@@XJfEpriv\x7FD[P\t1.76\nHk^@@@rQQIFIJftzjh@H@FFaBYSCJz_HH\t1.76\nHg|@@DjYV}~T{jjjjj@FEaBXS\\LkiwrJ@\t1.76\nHknD`La@BLddJbRRTujBB@@X]S\\LkoDpp\t1.76\nHk^@@@rRIHjIHjtzjh@H@FBpaTprngrL@\t1.76\nHg\x7F@@@adjuueZX{jjh@H@FDiaUJz]|RN@\t1.76\nHclLA@iTfnrQQQQEMt{PUAB@CBbFUwdL\t1.76\nHmTNPDpfFUCpkprRQRVRZjZ@FEXSRoHx\t1.76\nHg}@@@yJeWe^nNzjhHB@AaLIaTLz_DVp\t1.76\nHcL@p@bBBAbDfYVyi``hh@FGAaMpsqEt\t1.76\nHg|H@HRjymUV}NjB`hH@X[FTwCJz]|``\t1.76\nHg~H@DAIenUTfvvj``b@A`IMprnwsDpp\t1.76\nHg~@@@Ri_VUicnjj`@`@X[BES]Jz]|c@\t1.76\nHknB`LaML@cIIKDeeAeZ@BX@FETwB_Hp\t1.76\nHg]H@DlLbbTTRNRzuAPE@@peBinFUOdV\t1.76\nHknL@MAirJIJHsJn`BJj@AaHIc\\LkoHL\t1.76\nHg]L@FFnoIIEEDl\\NuSMTl@LFqaeSyA@\t1.76\nHg]H@FlDfYU^QVhHHj@AahQaTwCNgrK@\t1.76\nHg}@@@UJfUW\x7FegZ`hHj@AaJXS\\Lz_Djp\t1.76\nHmOD`DphTOCIIMEDz[aZjjZ@FEES\\OHd\t1.76\nHg|H@HRju^uXSnjj`@`@XKBYSCJz_DJp\t1.76\nJoB@@BULjo{rsl@@@U@@FBiaTwCNwqC\\\t1.76\nHk\\LA@kTfnRfYgUndzBhJD@FEDLz_HT\t1.76\nHk]@@@yJeWmZ{Sjj`@`@XSBXUCJ{qNL\t1.76\nHk^D@Eg\\ddRRTUY^FjjfZ`A`tIa\\OHL\t1.76\nHmt@p@bBBAbDfYVvfBBb@A`pXSCODyP\t1.76\nHg|H@@RYWVUicn@BZjH@XRfETkiwq@x\t1.76\nHk\\H@@RYfUVSWZ`hJB@FFaaTwCJz_H`\t1.76\nHmL@P@BNBDigy\\jUiffi@F@`fUproHH\t1.76\nHk^H@DAIenUr[SZjB@`@X\\S\\Jz_LSI@\t1.76\nHo}@@@UIYeV^d~hHJJ@A`iTwCNg[|a@\t1.76\nHmtHPAfHVHrRQHiRDjjVh@X]BXURoHX\t1.76\nHcNL@MAirJIJHsUt@QU@@pDDqnFUyF`\t1.76\nHk^@@@Re]YTjtzjh@H@FFpfESCJz_H@\t1.76\nHo}H@DhDfUefWWZhHb`@FDi`rng[|b`\t1.76\nHk]@@@UJfUW~V]jB`b`@XBfDwCN|Rc@\t1.76\nHeNHBJBiReYVDJnfjjjh@X]BXS\\ODjP\t1.76\nHg|L@@RdfV^Urh{Zj``H@FGEpsiwqLT\t1.76\nHkn@`ECDRYWUZf`@jj@AaHIaTLz_Hx\t1.76\nHkn@`EBHRYWUZf`@jj@AaHIaTLz_Hx\t1.76\nHk\\@@DjU^ukmLHDjh`AaLHUCJz_Ds`\t1.76\nHo~B@NAK]IenWVeVijjfPA`Q\\I|Qg@\t1.76\nHcMD`LvD@HrRRqIYCJt@E@@p{J[aWP\t1.76\nHknD@IBdifW^EZB`b`@XRfDwBngrJ@\t1.76\nHcm@@@UJfUWyYvhJBH@F@iaMpsoDiP\t1.76\nHg^H@EAIYeUz]Z``b`@XRUMpsiwqHP\t1.76\nHclL@@RlbbTLRQTnmU@A@@pkae]xfD\t1.76\nHk\\L@@RdfV^uJmMjj@B@A`qCJz_Ds`\t1.76\nHk\\H@@RfYU\\]Tz@@@@@FGXWCJ{sJXp\t1.76\nHknH@DCHheEDceujB`H@F@hUMproHL\t1.76\nHknD@E@TfUvyih@Jj`@XJBXU\\LkoHL\t1.76\nHeWDbLihP@cNrREQICJt@@@LLxYy@@\t1.76\nHmt@P@bABDfUuZZ@Bj@AapIaUp|RU@\t1.76\nHmuD`LVD@HrRRqIXYV`@`@XUeMp|aP\t1.76\nHknH@FAIfYWyuhJBH@FDxU\\Lki|a`\t1.76\nHcnD@EgTjeUeexZjjYh@XMBXWCrE@\t1.76\nHo~H@FAIfYV}dv`hJJ@AanEWCJz]n\t1.76\nHcnH@DAIenuIeujh@H@FCEprn|qLX\t1.76\nHmtL@@Z\\bbRbLkh@bh@FG@fMpsrE@\t1.76\nHcNH@DCHheEDbnmPT@@C@TJfxYWdZ\t1.76\nHeWD`LihP@cIHUDdLkP@@@psNGbAH\t1.76\nHkmL@DpFEIeY}ZyjfZj@FEIbz_DzP\t1.76\nHcMH@DDDfyWWaZjjj@FGHUMtkqLt\t1.76\nHmt@`@bDfUujZ@Bj@A`HIaUtkrA@\t1.76\nHcvL@Hz]rRQQMSUUTt@LFSBimyB`\t1.76\nHknD@FADfy^Utvix@@@XTLki|QJ@\t1.76\nHcND@NALbbTtRLjuMUR@LBKawbMH\t1.76\nHg^L@NAKRY[eueVijje@FAEpgqFt\t1.76\nHcN@@@Re]eUvjh@@@XRDXWCJ{qDh\t1.76\nHid@PNbAbLddUTaJjZ`A`tXU\\OHP\t1.76\nHcNH@AAJYU^zZBBJ@A`NES]J{rD@\t1.76\nHcN@@HrRQJqIKmUP@@@pVDpjxYWP\t1.76\nHiWH`DphCpRjyj[aZjj`A`UMp|``\t1.76\nHmv@@@rRHjIJUjh@@@X]BXwCODIP\t1.76\nHcNH@IaJkU~XZjjj`AaLIeMpkoHH\t1.76\nHknH@EAJ[WUfz`@jh@F@iaTtz_HD\t1.76\nHmt@@LddTQVeZhH@@F@iaTwCOHT\t1.76\nHmuH@DDDfyW^Ejjj`A`rES]ODqP\t1.76\nHaeH`Dr@|DjybinZjj@FAES]r@@\t1.76\nHieH@DhDeVWaZjj@FCIaMp|RJ@\t1.76\nHmtH@@RYWUih@Jh@FG@fETkqND\t1.76\nHeUH@DDDfyWxVjjh@XTaTw\\SI@\t1.76\nHif@`ABHRYWZZ@B`@XLBXU]rA@\t1.76\nHid@`@bDeYWaf@@@FE@UMwLaA@\t1.76\nHeTD@@QImYQejjj@FGXUMpsrD@\t1.76\nHcNH@JAIY^UWVg`@@AaWCJ{qHH\t1.76\nHmtD@@QIevVUZjjh@X]eMproHH\t1.76\nHeVD@AADfyWxVjjh@XTUMt|QL@\t1.76\nHmt@@DjUgjDHJJ@A`LHULLkqLx\t1.76\nHmvD@D@dfueYUj`@@A`vMproHP\t1.76\nHmv@@HrRSFIJUjh@@@XSBXS\\Lj\t1.76\nHmtD@@QIn[VUZh@@@XLfMpsqJT\t1.76\nHie@@@EJe}ijjj`AaTHU]sLXP\t1.76\nHaE@@@{IHhbSUUT@LJaBinIg@\t1.76\nHif@@@rQQIFf@`h@FEIeMwDHP\t1.76\nHieH@DDDfyWaZjj@FEHUMwDpP\t1.76\nHefD@Hz\\ddTSUUUH@piLJfy@`\t1.76\nHaF@B@B\\ddRK]UUP@pZDpj[d\\\t1.76\nHeVH@DAIemQej@@@FAIPssB[`\t1.76\nHieH@JDDiWTjjjj@FCPfDw\\`P\t1.76\nHaf@@@RYfJfzjjh@X]BXUMwH@\t1.76\nHaDH`F@HRf^rjYj@FE@fTwDK`\t1.76\nHaE@@@yJUtjjjh@XUBXS\\pJx\t1.76\nsNqlHlOBqCbLddlZj@XEZodH\t1.76\nHeV@@@RUYTYy`@@AaUMpsqDp\t1.76\nHeTD@@iJ[e^f```@FEHS]OHD\t1.76\nsGPBAbJPLaYAInjhA`aNS@\t1.76\nKA|P@QrUSMUT@XTfES\\c`\t1.76\nKA|P@XBRlkUT@XTaTw\\b@\t1.76\nsNxA@IrRJFjhAaXl[qA`\t1.76\nsFuHEhOAJnMZj@XHwbF@\t1.76\nsNy@BDeVjj@XVKU|`@\t1.76\nsFq@@drfuU@LBl[qB@\t1.76\nsFq@@drfuU@LKEc^P@\t1.76\nsGPhH`DYIHUj@XKWdH\t1.76\nsFt@@TiTt@@A`i^IX\t1.76\nsFt@ADiTt@@A`c^IX\t1.76\nsJY@LDejhAahcqC@\t1.76\nsGY@DDeYj`FAVMyH\t1.76\nsGR@@cTe[f`GbM@\t1.76\nHeTD@@qI[eQej@@@FGIeMpsrH@\t1.76\nHifH@AAJ[W[j@B@A`VES\\QA@\t1.76\nQMhHRYAxb\t1.76\nsJY@BDizhA`inID\t1.76\nHeTD@@EJ[Uvz`@h@FAIgSqBh\t1.75\nHidH@@RYm^Fh@@@XMATwCq@p\t1.75\nsNp`@dfVZj@XJobq@\t1.75\nHkmHpBXpkIkMkDfYemyXHbbP@XDASoLXU@\t1.74\nHidL@@sdifzajjj@FCPaTw\\SA@\t1.74\nHaDD@@yJY^fjjh@XUFEW\\QF@\t1.74\nHaDD@@YJYZnjjh@XUFES\\QN@\t1.74\nsJQ@@dkU@LLL^JH\t1.74\nqCp@AJZ`LDmqB@\t1.74\nHeTH@@ReyTYj`@@AaTTwCsDrP\t1.74\nHaF@@@RYe[hB@@FAXS]q@h\t1.73\nHaDH@@Rfu[j@@@FFIg\\pjX\t1.73\nHg\x7FD@L[`QIeyUTYNvjZ`@@A`vEr{_HL\t1.72\nHcm@`FtHaIe[UkiV@@@`@FC@fTJ|cP\t1.72\nHcoH@DJ`RUeUVy]ZZ`@@AaRTL{qHT\t1.72\nHk^H@IAJ[VuVzUh@JZH@XTfDq|P]@\t1.72\nHk^H@IAJ[VvvzUh@JZH@XTfDq|R]@\t1.72\nHg~H@IAJ[VvUneZ@Bfh`AaRXSWqML\t1.72\nHew@@@pldTTJVTLmP@P@LBqngbDH\t1.72\nHcnH@IAJ[Vw[iV`@ib@FEIaMoDFP\t1.72\nHmN@@@rRJJYDfeZ`XB@A`U\\L|sFT\t1.72\nHev@@@rQQQHyPsPLA@@pHfx^XER\t1.72\nHmN@@@RfYWraV`XH`@XDS\\OLBU@\t1.72\nHcn@@@RifurZ]jA`b@A`U\\L|sEt\t1.72\nHaDH`NBDRYWih@H@FAIa]q@h\t1.72\nsOt@@tigujj`FEbqoDF\t1.72\nHid@P@bAbDfY]n`HH@FEAa\\OHh\t1.72\nHeVH@LAI[eQej@@@FGIeMpsrH@\t1.72\nHaDH@@RVU[jjj@FG@fES]rH@\t1.72\nHeTH@@ReyTYj`@@A`tTwCODS@\t1.72\nQM`BN`^YH\t1.72\nHmNH@NAJ[VUnFZjjj`A`LXULLkrD@\t1.71\nHevH@FAIeYZ[ajjjh@XCBXU\\L|`@\t1.71\nHeTB@@pYRf[^njjj`AatHUMt|SA@\t1.71\nHidL@@X\\dTRekjjj`A`tXU\\ODQ`\t1.71\nHeVD@IADfyWxV`@`@XDUMwDRP\t1.71\nHieD@DDNRYWbijih@XDfEWHD\t1.71\nsGPYHlPDGlddJu@LIP\t1.71\nsGXA@IRjZj@XFKWdH\t1.71\nsJY@LDeZhA`Pl^R@\t1.71\nsGU@DPdsmR@pbxmP\t1.7\nJoC@@@ITskNx{[uA@@@@@XZaUprng[|c@\t1.7\nHg~@@@RfUYwySn``@@@@XZfDwCJz]|`@\t1.7\nHcLHpEbPRPrPrRRqIYCMT@E@@pJfx^Qh\t1.7\nHmtHpEbPRPrPrRRqIXYj`@`@XES\\OHT\t1.7\nHeVD`La@BLddlRPrm@@@CBlinGdR\t1.7\nsNplJyDJHtQddeeUPCAqXu`\t1.7\nqCr@XIJrAyhl\t1.7\nqCa@CIJtA`enR@\t1.7\nHaE@@@aJyUnh@@@XUaTw\\PH@\t1.7\nJoBBPDH@QddabbRRrv[kP@@@@@XCS\\Lki|Rw@\t1.7\nsNx`BDdw[UPCCKObM@\t1.69\nJob@@FRQQIIEI\\Lk[dDaP@@@FBiaMpz]orJ@\t1.68\nHcMB@NTLgTify^ajjjj@FBpaTwCJ{rL@\t1.68\nHmv@pBBlFlVlRYeYZXHJH@FAApksLJP\t1.68\nHmuL@AdFUJYY^njjjh@XSFES\\LkrD@\t1.68\nHifD@ACLdTTqkjjj`A`tHS\\ODr`\t1.68\nHeV@@@rRHqICMT@@@LNaJ[agdX\t1.68\nHmvD@DATf^Uqej@B@A`rYS\\OHT\t1.68\nHeTH@@RfUWihHH@AarXS\\L|b`\t1.68\nHie@@@EJeWkjjj`A`tIaTwDxP\t1.68\nHaFH@NCIEDcSUUT@LJ`j[nHf@\t1.68\nHeVH@DAIemQej@@@FFIS\\HnFP\t1.68\nHaG@@@qdig|ijj`A`RXU\\Qn@\t1.68\nsNx@@eLmUPCBbXwbS@\t1.68\nsNx@@eRmUPCBqFodp\t1.68\nsGQHLHaI[ihA`aNHt\t1.68\nsJX@@dkS@LMD^HX\t1.68\nsJX@@eSU@LDcqS@\t1.68\nqCp@AJv`LHnJX\t1.68\nqCp@AJZ`LDMqQ@\t1.68\nsGX@@eJuT@pHfODj\t1.67\nHaF@@@RVU[f@@@FEXUMwDB@\t1.67\nqCb@AIj`LHnXS@\t1.67\nsGY@DDf]j`FDWMcP\t1.67\nHmuL@DpFEIeY~nZifh@XHf\\siT\t1.66\nQMPBchFD\\Y@\t1.66\nHaD@`@dDfUzZ@B@A`RXU\\c`\t1.66\nqCp@BOTAaIqK@\t1.66\nHidH`ABPRYWZZ@BP@XDfEWHx\t1.65\nqCpB@ReMPFFbwH@\t1.65\nsJP@DiZhAaaMqH`\t1.65\nRFDEYFCBNT\t1.65\nsJY@DDfvhA`l^Q@\t1.64\nQMbDBDf`XUqD\t1.64\nsGU@EPdjmT@prqxiP\t1.64\nHeVH@IAIe]ZZ@Bh@FC@fEW\\PY@\t1.64\nHif@@@rRJEKaj@@@FEES\\ODS@\t1.64\nsOpH@DILkW@@@LBcWqC@\t1.64\nqCp@AIj`LEEqC@\t1.64\nHifL@ABnReYrZjjh@XMaTwCqHP\t1.63\nHmtD@@yIYe^UZ`P@@XLeLLkqHH\t1.63\nJoCFP`s[aH]L|drml\x7FTr{@AUTp`A`RUk|SA@\t1.62\nHcnHaAdICigdfUmffWX@JjD@XXe[sLEP\t1.62\nHeUH@DhDeVYzVjjh@XLfDwSqHD\t1.62\nHeVD@DAdfygFV``@@XYSSsDxP\t1.62\nHifH@BAIfUXXHH@AaPXUMqND\t1.62\nHieH@JXDefWaXB@@FFEp|RF@\t1.62\nHaF@@@Rig[jjj@FCPfDw\\b`\t1.62\nHaE@@@qJYZfZjh@XDeMwHH\t1.62\nsF|HLZ@aJYuif@XP\\RH\t1.62\nsOt@AdiVMZj`FAQkyH\t1.62\nsGY@LDenj`FEDQoI`\t1.62\nsGX@@eJuT@phfMyD\t1.62\nqCx@AYIV`LDEqS@\t1.62\nHeVD@IADfyWxV`@`@XTUMt|a@\t1.62\nsFt@@TiTt@@AaikrH\t1.62\nqCr@HIJtA`enR@\t1.62\nsGQ`@jdvmT@pruyB\t1.62\nsOx@@eSI]UT@pLQ_Ej\t1.62\nsGY@BDfZj`FADQxmP\t1.62\nsJY@BDfZhAaaCqK@\t1.62\nsGQ@@dkMT@pVOMEP\t1.62\nsJQ@@drt`LHnKD\t1.62\nj`qP@@@\\RiUuyVgG^jjf`@`@FAhHpRcAZMYwnPd\t1.61\nJoB`@@\\eRk{JuuoUUL@D@A`\\IaTpkiv\x7FHx\t1.61\nHmvDPLa@BEbLddlRVFUh@H@FETwBoHp\t1.61\nHcLB`HQ]@HrRFIKJ\\Jp@S@@phj[my@@\t1.61\nHmuDbLVD@HslddlRVFUh@H@FETwBoHp\t1.61\nHg\\D@@QIme]XYZ`@j`@XReMpkiwrL@\t1.61\nHcL@@LdbRVbM\\DDUP@LIaLJfF]yB`\t1.61\nHeVB@FCAeJYyzzjjj@FGPUMpsqDp\t1.61\nHcLH@ErRQRiYCMT@E@@pYLinGbEh\t1.61\nHie@B@xIrRQHynjjj@FCPfES\\`P\t1.61\nHeTL`HS@BLddlRPrm@@@CAlinFP\t1.61\nHaE@B@xIrRQHmuUU@CAhSBinQp\t1.61\nHmtH@@Rfuv[j@Bh@FCXUMJ|QA@\t1.61\nHid@`@bDfUvf`@h@FC@fEP|c`\t1.61\nsNyDJQDJHR[nihA`QE^Q`\t1.61\nsNx@@dlwUPCCZobQ@\t1.61\nsNp@Di]jj@XLSFodP\t1.61\nsGXA@IRjZj@XYZ|TH\t1.61\nsGP@Divj`FABMxi`\t1.61\nsJT@@TfZhAahmq@`\t1.61\nHmtL@@JTfYwfzB@j@AapXU\\L|aP\t1.61\nHedF@@PfFTf{nZjf@FCIaTt`\t1.61\nsJX@@eSU@LECqK@\t1.61\nj`q``@D@]dTTtTRVJXKUfjA`bh@AaSdeZ}qFC@\t1.6\njhia`@D@]yIYfU}VgEFZ`XHih@A`q`iJtGbHV@\t1.6\nJoCB@@a^QIQQQHkLNfuHTAT@A`r]Jf\x7FD`P\t1.6\nJoCB@BA^QJJJIKEUrfu@pQT@AaSCJoqHt\t1.6\nJoCB@BA^QQSQQHyLNfuPLAT@AaWRnoqLD\t1.6\nHg~D@D@|bTTTRNU\\nmPLAT@CBfFUobQp\t1.6\nJoCB@B@zRsLk\x7FWJ[TCADp@FELLkoL`{@\t1.6\nHk^H@DCHhihhdVGSZhF@`@XEtkoLpS@\t1.6\nHk^H@ACHdhhhdVGSZdJ@`@XTgRi|rAt\t1.6\nHcnH@DCHeEEDcWKkTC@P@LBXYWfQv`\t1.6\nHmtHPABHVHRYeY[hBBh@FCAaUr|PY@\t1.6\nHcLHPABHVHRYeYvz@`j`@XLFEWKqIt\t1.6\nHk^H@DAIYfUzySZ`XH`@XDproLcS@\t1.6\nHg~H@DAIfye]avvjA`b@A`WRn|sCl\t1.6\nHeWDAHHPRISdfygXVijd@XIW\\Qi@\t1.6\nHigDAHK`RISdfyUnZfi@FBTOHH\t1.6\nHigDAHHPRISdfyeaZfi@FDUqFx\t1.6\nsNy@LDeUjj@XTKF|TX\t1.6\nsOt@@Ti]qej`FBeyef\t1.6\nsF|@AbeLzmU@LLm^P`\t1.6\nsGY@DDeUj`FFQoEL\t1.6\nHif@@@RUe^Gh@@@XTUMp|a@\t1.6\nHcND@DCTeUe^UZh@H@FGHS\\L{qHp\t1.6\nsOy@DDeekZj`FFu_EB\t1.6\nsJP`@dfzhA`inXH`\t1.6\nHmuH@LDDeYW^Fjjj`A`HPaTwSrE@\t1.59\nsJU@DPdru@LHnKD\t1.59\nsJY@HDizXAyeb\t1.59\nqCpPXQBRu@XXQ\\f@\t1.59\nsJQ@@dsU@LLL^JH\t1.59\nsJX@@eSU@LLl^R@\t1.59\nqCb@AIV`LDmrP\t1.59\nqCaPQ@Hck@XS\\`@\t1.59\nsGP`@dfyj`FBMxe`\t1.59\nQM`AIhFE\\Q@\t1.59\nsOx@@eLm]UT@pXbu_HP\t1.58\nHcND@LCTeme^UZh@H@FGHS\\L{qHp\t1.58\nHaDH@@Rfu[j@@@FFYS\\qBx\t1.58\nHg\x7FD`LFyt@aJYY\x7FlfkjjjYjPA`pPaC_Lkc@\t1.57\nHmN@`FBHRYVukiV@@@@@XLBYPkrI@\t1.57\nHeVL@ICARf[^njjj`A`LHUMpsrL@\t1.57\nHifD@AAldTRekjjj`AatXUMp|a@\t1.57\nHid@P@qFqDfUfn`BH@FA@fMqND\t1.57\nHiTH@@RfU|kahDB@A`QMp|QJ@\t1.57\nHieD@DDFR[fVEijX@XQwDR`\t1.57\nHaFD@NBdefZyfi`AaC\\RB@\t1.57\nsFy@HDi[FehAaKqX`\t1.57\nsJT@AdizhAa`mqP`\t1.57\nsGQ@@djmT@pvMxh`\t1.57\nsF|@AjeKxmM@LEMqJ`\t1.57\nsGT@A\\dbMU@LCEcrT\t1.57\nsJP@DizhAa`cqS@\t1.57\nHifD@D@TefUnZjf@FAXS]qHh\t1.57\nsNpP@btf{Zj@XEXodh\t1.57\nsKT@Adi\\Vf@XS\\tQ@\t1.57\nsFx@@eRfuU@LMC^IX\t1.57\nqCp@AIZ`LEEqC@\t1.57\nsGQ@@dkUT@plVMy@\t1.56\nHiDJ@@PnEInvZjX@XDfDOHh\t1.56\nHifH@DAIVUxV`@@AaQTwCqHP\t1.56\nsJQ@@eMU@LEMqH`\t1.56\nHidL@@p\\dTTqkjjj`A`tHS\\ODr`\t1.55\nHidD@@EIe]ih@J@AaPHUCqLx\t1.55\nsBP@H|UT@ppbyL\t1.55\nsGXHLHaIVjhAaaEqF`\t1.54\nHiDJ@@PfEIn{Zjh@XLfESCrN@\t1.54\nKAxH@TvRRJNjZ@LLSByG@\t1.54\nHeTL@@JTfYw[hHB`@XLFEWSrA@\t1.53\nHeVH@DAIgeQej@@@FCIeMp|bP\t1.53\nqCj@KAIV`LHnJX\t1.53\nsOy@JDiWMjj`FAbqyF\t1.53\nj`qPB@AVAHILkkJ{QakP@UUUD@CBRLDiIVcNxcg`\t1.52\nJoB`P@vD`drnlktqw@AUUQ@A`JXURngqN\\\t1.52\nHg}@`AlIAIe]YVfNx@Jjh`A`JXURngqNl\t1.52\nsNxA@IRfZjhA`xlZ~P@\t1.52\nsGY@DDf]j`FBMxe`\t1.52\nHidH@@Rfuvz`@`@XYeMsDHP\t1.52\nHifH@AAIYW[f@B@AaVESCrH@\t1.52\nHidH@@RfU~F``@@XLfDwCrJ@\t1.52\nQMJHBHvAaOH@\t1.52\nQMB@HRZAaOD`\t1.52\nsGY@DDeej`FBexlP\t1.51\nsJY@DDeVhA`h^IX\t1.51\nHidH@@Rfuvz`@`@XXfMsBhP\t1.51\nHaF@@@Rfu[j@@@FEXUMwDA@\t1.51\nHaFH@LAIYfnZjh@XDaUwDa`\t1.5\nsOy@LDeekZj`FAQkxi`\t1.5\nHaDH@@Rfu[j@@@FFIc\\pjx\t1.5\nHeTD`HP@cIHXdmpk@A@@pHj[nHD`\t1.5\nQM`BN`XUqD\t1.5\nHiV@@@Rifzyajjj`AatIaTw\\`P\t1.49\nsJXA@IRij`FFVODH\t1.49\nsGX@@eLuT@pLVODJ\t1.49\nj`iP@@@PRfUUg_EIF]zZb@@@@@FBbLEIVcV]{dD@\t1.48\nj`qaB@MBADILklmkQcoP@UP@@@CAPDXISakN}rB`\t1.48\nJocDP`rDatsvQQISJJVTr{[p@UUTL@FCIVg[|SE@\t1.48\nj`i@B@@ABTsLjotyJvgT@P@aP@@pd@cARUhunH]x\t1.48\njdy``@J@BdlsOJkbezKMUPTBH@C@QJLUYwh|qCQ`\t1.48\nj`qA@@@YHheEdXdaR]z`bB@@@@XZPQgARtZso\\aP\t1.48\nj`aaB@HB]DYIHkECDeK^jjf@H@@XZ`cAJ\\Ujso@\t1.48\njhqa`@M@IIIf]{eYgHHBjjh@A`xFBTxJRmFl{pP\t1.48\nHo~HHNnIAICIAXcIIKEEhcIvjBBJ`@XLwKiwrG@\t1.48\nj`qP@@@XRfV]{V`g^BBb`@@@FFdDhs`mFl{wHJ@\t1.48\nj`qQ@@JV@eMrsooEFmPPTUTP@LEHHs`iJtYwH^@\t1.48\nHg]DqNm]bPRPrPz]{IIKEDheIuPPLP@LLXSyE`\t1.48\nj`qa@@J@RVYgm\\Tg^YjjB@P@F@bTXhug^yb@m@\t1.48\nHcMDpnd]bPRPrPZQyYwlddlRbLkUMUT@LDj^Qp\t1.48\nHg^HHNnIAICIAXcIIKEEhcNuPPQP@LJ[ev~PX\t1.48\nJobD@@ILsJr|wif}PTEPe@AaXXUMprng[|b@\t1.48\nJoc@@@YHhhheEcrsYoPAA@B@@XJS\\Lkiv\x7FH@\t1.48\nHg\\HpMbPRPrPrRRqIPsCMT@ET@CCjXYt{yB`\t1.48\nJgB@P@AFRJJJIIFad}n`@`@`@C@PIne]ObCX\t1.48\nJoBD@@YHihdcDepv}@PP@@@FBeS\\Jz]orD@\t1.48\nJoCDPBbDPdrnwJtuo@AT@@@A`hIaUvg[|`P\t1.48\nj`a`P@A@P{rSKKOkJtuMUUL`@phS`iVxag`\t1.48\nJob@P@ABTsLjoWS^oPA@BD@@XBALLkm|Pw@\t1.48\nHg\x7FH@HyVrRQJIWIUtkUSUUT@LApjxYt~IE`\t1.48\nHko@PITpbNbLbbbTURXXBHZP@XBFTwBi|cP\t1.48\nHg\\LpINxdDdLdLddlRTJ`kU@DS@@pJfF~QH\t1.48\nJoB`@@YdbbTVLRUC[aAQ@@@@XJaTpkiv\x7FHx\t1.48\nHk~@@HrRQQIFHUgYNjjjjh@XJfEWCJz_HX\t1.48\nHg]DpBX{BlFlVlRYf{~zXHbJX@FA@JwqBX\t1.48\nHcl@P@BABLdTRafQTnuKLuH@pDDJae]yG@\t1.48\nJoBdP@sXQBSJvlkSJ\\@EMSD@FC@fUi|Sg@\t1.48\nHknHpINIAICICIIKDeMaVj@Hd@FATLkqFt\t1.48\nHknHpCjIAICICIIJeEDmNjhB@@FADJ{rI@\t1.48\nHg^HpCjIAICICIIJeEDiiuU@PP@LBHUwdV\t1.48\nHcN@HNbPRPrPVHrRRqQZSmTDD@@pInW^QH\t1.48\nHklDpMNIAICICIIKDeeAfj@BX@FATwGrA@\t1.48\nHg\\DpINIAICICIIKDeMhJuPADp@LBiaodJ\t1.48\nHk\\d@dpSAPzIZUyIfYoVgSjjifh@XEWZX\t1.48\nHg|H@@rJJIHqIMqw@PP@@@LEpj[iWSod@\t1.48\nHg~D@DClbbTTTjSB]mUL@D@C@TXYWSodX\t1.48\nHg^H@ACIEDdhlYrtDEEP@LMSBinFUt~QX\t1.48\nHk_H@HyVrRQJIWJneZjZjj@FGXU\\L{qHL\t1.48\nHo~L@M@iRYg^ufzB@jj`@XZFEWCNg[|aP\t1.48\nJoBd@EVBTwKN\x7Frg]AAQUD@FDhS\\Lki|ap\t1.48\nHg~@@@rQQQUQIUqwSMP@P@LA@fz]N~YeJ\t1.48\nJoCD@B@drsJkkYnu@@@@@AaJUprng_DYp\t1.48\nHo}L@FFnoIIEEEB\\avjYjih@X]cCJf\x7FHH\t1.48\nHedBJHSBCpzHFHfHKlddqTcUUP@pkJxY@\t1.48\nHc^@@HRjU^^dUGZjjjj@FBiaTwCJ{rH@\t1.48\nHcmH`FeXBLddRJRUMpuUUKP@pjLJnxbZ\t1.48\nHknH@ACIEDdhl^V``hh@FBiaTwCJgrM@\t1.48\nHg|@@LddTjTrPr]uP@@@@C@TpjXUOb[X\t1.48\nHg|@@LddTjRRPr]uP@@@@C@Tpjy]ObMX\t1.48\nHg}H`AfpbDfUmYZYS`@ijR@FE@fT_D{P\t1.48\nHcoH@HyVrRQJIWUtkUSUU@CAlJnF^IF`\t1.48\nHg}H@JlDinV]~T{hHJJb@FDhS\\Lki|bp\t1.48\nHg}@@@qJYWyVnNp`b@@@A`jES]Jz]|c@\t1.48\nHedDpJZHaHcHcIIKEiUUT@LNaLInGdR\t1.48\nHkmD@AvnrRQQsQKSjfje`AarXSRi|c`\t1.48\nHmvDPLa@BNbLddlTVeUhH@@FEXwBoHd\t1.48\nHg|H@@RYfUWd}mh@@@@@XRUMpriwrM@\t1.48\nHmOH@HyVrRQJIVneZjZj`A`vEWCODaP\t1.48\nHmv@pIbPRPrPrRRqIPUj`B@@XYPkqFd\t1.48\nHmu@PITHchcHhheEVF@bF@A`pYS\\OHT\t1.48\nHmtHpIbPRPrPrRRqIPUj`B@@XYSCqIT\t1.48\nHkmL@FFnOIIEEDlqvjYjf@FEXproHH\t1.48\nHiDDpJZHaHcHcIIKEjjj@FCPfDp|c`\t1.48\nHknD@AALbbTRbqWVijjd@XTWCI|Qe@\t1.48\nHo~L@AAGRYYY}UujZjjT@XTWCM|Qc@\t1.48\nHmMHADp@zIRYeuIiVjh@@@XUgCJ|b`\t1.48\nHg]L@DpFEIeY~^nZifjh@X\\fRng_Hx\t1.48\nHeuHADp@zIRYUTjFZj@@@FEHwCOHp\t1.48\nHklH@@RYWY^f`@jj@A`hIaUpki|bP\t1.48\nHcm@@@qJUvUpeuih@H@F@pa\\LkoHh\t1.48\nHcND@JCTeUe^UZjjj@F@iaMpsoDaP\t1.48\nHcLD@NwIIDcDbpuUUS@C@XSBiagdJ\t1.48\nHcMH@NVlddTZbR{UMTl@LFSBF]yC@\t1.48\nHcmH@DhDfUe]aWVjA@`@XTf]J|P]@\t1.48\nHcNH@IAIfUWEZ``b@A`lXUMprn|`@\t1.48\nHcNH`IDHaIe]mih@Ij@AapIaUJ|cP\t1.48\nHcMD@FFnrRQQQ]LMTsUP@pKIW^XSB\t1.48\nHcmH@DhDfUe]aWVjA@`@XDgRoLp]@\t1.48\nHmwH@Dp`RYyUeVjjj@FGIS\\LkrL@\t1.48\nHmvD@E@TfUvzZ@Bj@A`HIaUpsrE@\t1.48\nHmvH`IDHaIe]nf`@f`@XLBXUSrE@\t1.48\nHetH@@RYnWaFZjjZ@F@`aTwCODc@\t1.48\nHcLD@@QInYWWVjB@@A`JYS\\LkrM@\t1.48\nHmt@`@bDfUuZZ@Bj@AapIaUp|RU@\t1.48\nHiDLpB[`bDbJ|Dfunff`A`PI`|b`\t1.48\nHcND@LADf]YU]Zj@@@FGXWCJ{rJ@\t1.48\nHeV@PIBHzHRYeea`Ha@A`pYS\\OHd\t1.48\nHcND@EADfVU~UZjjj@FGES\\L{rL@\t1.48\nHmuH@DDDeYW^Ejjj`AarXUMt|RE@\t1.48\nHeVD`La@BLddlRPrm@@@C@linx`r\t1.48\nHct`@JF]rRQRzKUUSV@LFaLJfyD`\t1.48\nHcML@DpFEIeY}kfjYj`A`RXn|Si@\t1.48\nHmLD@@yIYe^neVdHB@A`SCJ|RB@\t1.48\nHmUDB@UiB\\ddUbtjji`AatIaUr`\t1.48\nHmv@@@RYvUeZj@@@FDpfDwCJ|`@\t1.48\nHeTH@NrRQHqLMUUT@LAaLJfF^Qp\t1.48\nHmv@@@RgVUeZj@@@FDaBXwCJ|``\t1.48\nHmvH@NAIYWUnZjjh@X\\fESCODaP\t1.48\nHmwH@DJPR[YWFVjjj@FCYS\\J|a@\t1.48\nHeVDB@ZPgIIEXdLuUUP@pzDpjxP\t1.48\nHmuD@DHNRY[]Jfjfj@FEXproDP`\t1.48\nHmuD@DHNRY[]Jfjfj@FALLksDp`\t1.48\nHeV@@@rRJIJmuUUT@LAaLInF^QP\t1.48\nHiEL`LZDh@cIHULeij@FFXp|PN@\t1.48\nHmvD@DCdfVyyUjB@@A`RMr|pad\t1.48\nHeUH@DpDeYUFVjjh@X\\aTwCOH`\t1.48\nHeUH@DHDfVuFVh@@@XLeMpsrB@\t1.48\nHmtH@@RYWYih@Jh@F@`fEWBoHd\t1.48\nHeT@`@bDfUuih@J`@X\\BXU\\OHd\t1.48\nHmVDB@FPgIIETijjih@X]BXULh\t1.48\nHef`@@SFyIeYfjZ`AapIeLL|c`\t1.48\nHieH@DDDeYWaZjj@FCIaTw\\RA@\t1.48\nHeUH@DDDeYWxVjjh@XLfES]qHd\t1.48\nHeU@@@EJYU^f```@FG@fES]qAd\t1.48\nHaD@P@bBbDfYvzB@@A`PDw\\SJ@\t1.48\nHieH@DDDeYWaZjj@FEXUMwLaA@\t1.48\nHeUH@DDDeYWxVjjh@XUaTw\\rDd\t1.48\nHeVH@FAIfUqfhH@@F@aFEWCOHX\t1.48\nHeVHB@XIrRQVICMUSR@LNaLKad\t1.48\nHeUH@DdDf^UFVjjh@XTUMp|qLd\t1.48\nHeUH@LDDeYWxVjjh@XLaTwSrH@\t1.48\nHeg@@JF\\ddTneUTp@pZDpj[bCH\t1.48\nHmW@@JE\\ddTnRjjfpA`tIaTwHx\t1.48\nHif@@@rRIHhjjjj@FGPaTwCrL@\t1.48\nHie@@@QIYUxVjj`AatXUMp|`@\t1.48\nHaEHADH@zIRYUJjij@FBMwDS@\t1.48\nHiFHB@DIrRQUJjjPA`tIaTwHx\t1.48\nHiD`@@SFRYUfjZ@FG@fTwCrB@\t1.48\nHif@`ABPRYWZZ@B`@XTfEW\\`P\t1.48\nHaF@`F@HRf_rjYj@FE@fEWD[`\t1.48\nHiE@@JGIIEKjji@FCPfES\\Sa@\t1.48\nHiE@@JGIIEKjjj@FCPfES\\Sa@\t1.48\nHeUD@FFnRjYeajfZ`AaF\\HfFP\t1.48\nHeV@@@RYyTYj`@@AaHPfTwCH\t1.48\nHifD@D@Tf[WaZjj@FAES]rL@\t1.48\nHaE@@@aJmUnjjh@XLfES]rH@\t1.48\nHieL@DpFEIeYkfjY`AaB\\SN@\t1.48\nHiFH@HGIIEXjji@FCPfEW\\a`\t1.48\nHeT@@DjU]k``b`@XMBESCqLd\t1.48\nHaF@@@ReU[jjj@FGPfES]r@@\t1.48\nHif@@@Ri]^Fjjh@X]BES\\OHp\t1.48\nHaEH@HSlddRmMUTp@prLKbIP\t1.48\nsNqBGIARFdKDYIIYUT@pQoHp\t1.48\nHieH@DHDeYWaZ@@@FEIS\\OH`\t1.48\nHieD@DHNRY[Rijih@XPwBSBD\t1.48\nHiEH@FzlddTZjfh@XTfDw\\`P\t1.48\nHaDH@@RVU[jjj@FCIaTw\\PH@\t1.48\nKA|Y@]BX@QddarVj`CCBinQp\t1.48\nHaE@@@yJe~fjjh@XMBXUMrN@\t1.48\nHid@@LdbRQk``R@AaTHUCqLX\t1.48\nHeT@@DjU]k``R`@XMBESSqLD\t1.48\nHaF@@@rRIHeUUS@CAhSBinQp\t1.48\nsNqBGIARFdKHYIIYUT@payF\t1.48\nHiFH@JAIUfZjh@XUaMp|RD@\t1.48\nHaFD@DAdfUjyjf`AabYWHx\t1.48\nKA|@@Uddbejj`CAhSBinQp\t1.48\nKAzP@MuYIHhzih@pILInQp\t1.48\nKAxH@UvRRJNjZ@LLSBxc\\\t1.48\nsNyiKE`D[lddjVj@XP|UX\t1.48\nsGPdE`DSpRYvj@XXF|Tp\t1.48\nsGQLLIAREdDfvj`FDgHP\t1.48\nsOpH@DISOkSK@LBEkqE`\t1.48\nsKXDD@b^BRvKU@LLL^R@\t1.48\nsOxA@IRjVnjj@XVKU|a@\t1.48\nsOq@@drm]UT@phQkxi`\t1.48\nsFxA@IRiSZj`FEbqoH@\t1.48\nsF|@@ldrfmU@LBl[r@\t1.48\nsGYHMQDIJmT`LLHnKD\t1.48\nsN|@@ldssUPCBaFodp\t1.48\nsGQhHlOAJmZhAaCqB`\t1.48\nsNy@LDeVjj@XTKF|TX\t1.48\nsGT@@deYj`FEBqoI@\t1.48\nsNx@JeTuUPCBqXodh\t1.48\nsNy@GTjfjf@XYX|c@\t1.48\nsJR@@lTfVhAa`mrD\t1.48\nsGY@DDf]j`FFQoI`\t1.48\nqCbHXRBdDfj@pdyL\t1.48\nsJ\\@ABeOL`LECqK@\t1.48\nsGX@@eMuT@phbqyJ\t1.48\nqCsCPKCevyIj`H\t1.48\nHaDD@@{IEDcSUUT@LJ`j[nHf@\t1.48\nQMhDRZAaGFP\t1.48\nHidH`ABHRYWZZ@BP@XTBXU\\c`\t1.48\nsFpH@DISNmLpC@aZ|a@\t1.48\nsGQ`@bdwMT@pROEj\t1.48\nqC`P@HRZhCBSfBp\t1.48\nqCr@XIKTA`hnHX\t1.48\nqCp@AIj`LDmqB@\t1.48\nqCp@AJZ`LEMqA@\t1.48\nJoCb@BvxTeMrkk]IwPPP@P@AaRDporC@\t1.47\nHcNB@JciwIIMEeKruUUU@CBXSBiae^Qh\t1.47\nHk_H@NtpRfumUaWZ@@@`@FAIcGqBd\t1.47\nHk_H@IWPRfunUatz@@H@@FAIcKqBL\t1.47\nHmVB@A@feIf[vjjj@FBaBXULLkrN@\t1.47\nHmwDAHHPRISdfyeVEjZjPAae]OHT\t1.47\nHmvL@JciRjyvyZjjj@F@pfESCOHT\t1.47\nHeWDAHHPRISdfyeXVijd@XIT|c`\t1.47\nHmO@@@rdigmZZUB@@@@FFYp|qIT\t1.47\nHeTB@HhYRjwUnjjj`A`tHS\\ODrP\t1.47\nHidL@HhTjmunjjj@FEPaLODs`\t1.47\nHiFL@F@nRYgZjj@F@aBXS\\OHh\t1.47\nHaE@@@sIEDceMST@LLPfxe\\\t1.47\nsNx`BJdrmUPCAbHu|f@\t1.47\nsOx@@eR}]UT@plqkyD\t1.47\nsGY@JDinj`FFbwDZ\t1.47\nsJY@DDeVhAaecrP\t1.47\nHg^L@M@iRYg^u[hHBjh@FBaaUprnwrC@\t1.47\nHidH`H@HRme^Eh@@@XTUMp|PD@\t1.47\nHid@`@bDfUvf`@h@FC@fEW\\`P\t1.47\nsFt@AdiWEihAahcrT\t1.46\nHaD@@DjUZxHH@AaTXU]qDX\t1.46\nsJ\\@@ldru@LDEqX`\t1.45\nHeTH@@rQQQHcMAP@@LFpj[axbR\t1.45\nHo}BAHLDUxeNR[e]m^Eh@JjP@X\\UMtj_Dvp\t1.44\nHkmLAHLDVISdfyW[xV`@j`@XLUMtkqML\t1.44\nJoBF@@HrS\\srzLv{PPD@@@FGISZ]orE@\t1.44\nHcLDrITJsjsZq^RYefVF@bF`@XXG[qLD\t1.44\nHkLNB@PfESSdf{n{Zjjj@FBxUMprnf\t1.44\nHclH@@rJJIPiMr{@P@@@CA`XYW^Ie@\t1.44\nHcMD@DHMR[nUyUj`@`@X]aMpsoHP\t1.44\nHeUD@BdARYgUnjjj`A`HPaTwSqLD\t1.44\nHif@PBBHzHRYgfFBB@@XTFMp|``\t1.44\nHeTL@@Z\\bbRbM]@DT@CA`SFz^PH\t1.44\nHmtL@@ZTieeqV`hH@A`rEproDi`\t1.44\nHmv@@@Ri^ueZj@@@F@pfMproHh\t1.44\nHeU@@@yJeWZzjjZ@FCPfES\\PY@\t1.44\nHeTD@NGIIDcCBUUMP@pJDpnHt`\t1.44\nHeVH@NAIYWVyjjj@FCIaTp|RI@\t1.44\nHieH@BDDfY}njjj@FGABEWCqLX\t1.44\nHmtH@@RfUWzZBBH@F@iaTwBoHd\t1.44\nHie@@@yJeWkjji`A`tIaTwDxP\t1.44\nHidD@NGIIDcHRjih@XEBXWDXP\t1.44\nHidH@@RUY^Ejjh@X\\fES\\OH`\t1.44\nHidD@F{IIEYhRjfh@XYFEqDD\t1.44\nHidD@@iJ[gxZB@@AaRDwCrJ@\t1.44\nHidH@@RfU~F``@@XMaTwCrD@\t1.44\nHaDH@NrRQHpeUS@C@hSBxeL\t1.44\nHaDD@F{IIEYBUTt@LLcBxb\\\t1.44\nsNyhMEPDYIBhmL@pfx`p\t1.44\nsOq@GddblUUL@ptqxeP\t1.44\nsFu@E`drfmU@LD[qK@\t1.44\nsKXA@IReqjhA`Xl^P@\t1.44\nsJY@DDeVhA`l^JH\t1.44\nsGX`DJdjmT@prMxi`\t1.44\nsFx@@eLzuU@LCEkq@`\t1.44\nHidH@@RYm^Fh@@@XLATwCqHp\t1.44\nHg]HpBXpkIkMkDfYemnVBHhf@AaPENwqFT\t1.43\nHknL@M@iRYg^un``Jj@AaHXU\\LkoHL\t1.43\nsGX`LDdrmT@pexlP\t1.43\nHeT@@DjU^k``b`@XCBXU\\L|a`\t1.43\nHeTD@@iJ[e^f```@FAHSCqNd\t1.43\nsFy@JDiTvjhA`Xl^R`\t1.43\nqCp@AIZ`LMEnP@\t1.42\nHaFH@JAJUtjjjh@XUBXS\\c`\t1.42\nHaDH@@RYWih@H@FFHU\\pLx\t1.42\nHcNLAHAEbTyInUvxV`@j@A`qTwRoHt\t1.41\nHiFDPJHPbDbDf{Vij`AaPPeCqFx\t1.41\nHeTH@@RYe\\YjB@@AatXU\\L|PF@\t1.41\nHidH`BBHRYeVFBB@@XDFTOD[`\t1.41\nHaDH`BBHRYg[hH@@FAAe]qBX\t1.41\nHeTH@@RYm_aZ@B@AaQTwSrL@\t1.41\nsOp@DjUMjj`FCDVMyF\t1.41\nsNx`DFdkKUPC@kE|Th\t1.41\nHif@@@RfU~F``@@XLFES]qDD\t1.4\nsGP`@TeYj`FFVOEJ\t1.4\nsNp`Jtjfjf@XYX|c@\t1.4\nsOq@@drm\\@@@prMyaf\t1.4\nHcNL@M@iRYg^vzB@j`@XBFEWCJ|cP\t1.39\nHiU@@@iJYWrnFP`H@FAESCqDx\t1.39\nKA|X@HC\\dkJuU@FEIaMwDb`\t1.39\nsJU@DPdju@LDmqP`\t1.39\nqCr@PIWTAaEqS@\t1.39\nqC`@ISTAxQE`\t1.39\nHcLHpMbPRPrPrRRqIPcMT@E@@pjfF]yB`\t1.38\nHk^D@IADf^UeFUujjjj`A`ITwBngrL@\t1.38\nHcnD@AADeYVWaeVjjjh@XCaTwRn|b@\t1.38\nHmtL@@Pdf{eYUj`@@AavDwCJ|a@\t1.38\nHmVDB@ZPgIIEXmJjjX@X]BXU\\h\t1.38\nHeTH@@RYWVf`@j@AapIaTL|c`\t1.38\nsGQ@@dsuT@pHVOEJ\t1.38\nsKX@@eKcUPCCSGbB@\t1.38\nqCb@AIj`LEEqC@\t1.38\nsFx@@eJfuU@LJIc^Q@\t1.37\nsGX@@eRuT@pLQoI`\t1.37\nHeVB@ICFEJYyzzjjj@FGPUMpsqDp\t1.36\nHeV@@@Re[TYj`@@AapES\\L|RD@\t1.36\nHifH@JAJUuJjjj`A`tIaMwHD\t1.36\nKAxD@@c\\dvluS@FBXWDS`\t1.36\nsGPa@erS\\uPCB[bM@\t1.36\nqCqPZHAD]XCqC@\t1.36\nsGP`@TfZj`FADMxe`\t1.35\nsJX@@eOU@LML^HH\t1.35\nsNx@IddbmUPCBqXodh\t1.34\nsGY@DDfyj`FBMxe`\t1.34\nQMB@HchFD\\Y@\t1.34\nsNq`@bdw[UPCCKGbk@\t1.33\nqCh@AIJtA``nJX\t1.33\nHif@@@RUe^Fh@@@XLaTwCq@`\t1.33\nHkoBAHePPcbTyInUuVyjZfe@FAUpkrM@\t1.32\nHmvD@NADfVyyUjB@@A`SCJ|Pn@\t1.32\nHeUD@DpFRUVTYZZZPA`REt|RA@\t1.32\nsOx@@eRimUT@plqkyD\t1.32\nsG]@EbDf]jPFBVyJ\t1.32\nqCh@AIJtA`inHH\t1.32\nqCh@BIWTA``nJX\t1.32\nHeTD@@QImeQej@@@FEIS\\ODrP\t1.32\nsJQhHl@bOV`FDOI`\t1.32\nHidD@@IIf][hHB@AaPXU]rA@\t1.32\nsOq@@drm\\@@@prKyaj\t1.32\nHmvD`Ia@BLdabRrxU`@h@FEES]ODAP\t1.32\nHidH@@RfU~F``@@XTfDw\\Ra@\t1.32\nqCr@XIJtAyhl\t1.32\nHknDrBtpkAkEkCyIf[effBBbX@FF@J|Pi@\t1.31\nsJ]@EbDfVhA`enP`\t1.31\nHif@@@RfU~F``@@XLBXS]qJD\t1.31\nHaD@P@bFbDfUjz@H@AaPIeMrN@\t1.31\nsJY@DDefhAaIqX`\t1.31\nHaD@@DjUZxHH@AaTHU]qLX\t1.31\nHg|L@@QdfygUQd{ZB@@@@FGISKiwrN@\t1.3\nsGX@@eSUT@ptQxmP\t1.3\nHeTD@@iIYe^e```@FAMpsqHH\t1.3\nqC`P@HRVhCBKfDp\t1.3\nsJU@DPdvu@LInID\t1.3\nqCqPZH^D]hCsAX\t1.28\nsNp`@df]Zj@XKWbK@\t1.28\nqCp@AJZ`LLHnS@\t1.28\n`Lg@^P\t1.28\nQMhDRVAaOJ@\t1.28\nHaFD@DCdfUriji`A`RXU\\a`\t1.27\nsGX`JBdruT@pHaoDl\t1.27\nsJX`LDdvu@LH^IX\t1.27\nHidH@@RfU~F``@@XEc\\OLPj@\t1.27\nsOt@AdigkB@@FAQkyL\t1.27\nsGXhMD@cIHTmPCB[fAh\t1.27\nRGDPDQ`|R@\t1.27\nqCb@AIj`LDEqS@\t1.27\nqC`@ISTA``nJX\t1.27\nHidD@@GHhdhZZ@B`@XTBTp|SN@\t1.26\nHg}H@DTDeUfUqT{ZjP`H@F@hWRng_Dc@\t1.26\nHcm@@@uJYU_rnf`Pbh@FG@aMpsqEt\t1.26\nHmtD@@iJ[eWihHH`@XTaLL|aP\t1.26\nqCr@XIKTA`enHP\t1.26\nHeTD@@iJ[g^F``H@FAHSCqJd\t1.26\nHmtD@@iJ[eWihHH`@XDaLODeP\t1.26\nqCr@HIJtAaIqK@\t1.26\nsOp@DjWkjj`FCDQkyL\t1.26\nsJX@@eMU@LLInID\t1.26\nsJXA@IczhA`hnKD\t1.26\nqC`@IVtA`anJH\t1.26\nQM`AIhFD|R@\t1.26\nsJY@DDfVhAaEqX`\t1.26\nsKPH@DIRxtl@pHfOH`\t1.25\nHaDD@@IIf]n``@@XTFES\\c`\t1.25\nHeT@pHdDdLdLddlRPsU@@@C@j[iy@`\t1.25\nsGQ@@druT@pHaoDl\t1.25\nQM`BN`XI\\d\t1.25\nQM`AIhFCOH@\t1.25\nQM`AIhGfR\t1.24\nsJY@LDefhAaEsSD\t1.23\nsJY@DDefhAyib\t1.23\nsOpHADILkW@@@LJDZ~S@\t1.22\nHaD@@DjUZxHH@A`TIa\\rfx\t1.22\nsOpHADILkW@@@LLE^[E`\t1.22\nHmvH@DAImYVUZh@@@XLS\\LkqDp\t1.22\nsOq@@drm\\@@@pQoBEf\t1.22\nqCr@HILtAaErX\t1.22\nsJXhMD@bOV`Gbq@\t1.22\nqCp@BOTA`hnS@\t1.22\nHaD@@DjUZxHH@A`THU\\sFx\t1.22\nqCr@HILtAxe`\t1.22\nHidH@@Rfufz`@`@XXfMsBxP\t1.21\nHaF@@@Ri_ijjj@FEPaTwDs`\t1.21\nsOx@@eJymUT@plVMx`p\t1.21\nqC`P@HRZhCAK\\P`\t1.21\nsJY@DDeVhAaMsQD\t1.21\nsOy@LDeekZj`FAVKxiP\t1.2\nsJXA@IRij`FAbqy@\t1.2\nqCa@AIMTA`inHH\t1.2\nHidH@@RfU~F``@@XUaMp|QJ@\t1.2\nsOr@AcTiek@`@GfQX\t1.2\nHidD@@iIYgxVB@@AaQTwCrH@\t1.2\nHaFH@NAIYUnX@@@XEaTwH`\t1.2\nsJQDBHaQBS]R@ppbyL\t1.2\nsGX@AddQjhAah[qK@\t1.2\nHmvDAHAHeNR[e]xV`@h@FAES]qIT\t1.19\nHmLD@@eIfUTfEV``R@A`U\\J|c@\t1.19\nHeTH@@Rfuunh@J@AaRYSCqBd\t1.19\nsGXA@IRijj@XFKGbE@\t1.19\nsJX@IGuPCCQ[dH\t1.19\nsOp@DjWkB@@FAfKxeP\t1.19\nRG@DXOD`\t1.19\nsJY@BDfZhAahmq@`\t1.18\nsGQ`@ldsmT@pQoI`\t1.18\nsGQ@@dsuT@pHaoDl\t1.18\nsJX@@eOU@LBIcrH\t1.18\nHmvLAHAEbTyInUwaZ@B`@XTUMr|bP\t1.18\nKAxUBPfEp^F\\WYIIbfjd@pbnPp\t1.18\nHif@@@Rge^Fh@@@X]BES\\OH@\t1.18\nHaF@B@BTjUZxHH@A`tIaUwHX\t1.18\nqCh@CISTA``nJX\t1.18\nsGU@E`dsmT@pROEj\t1.18\nsKQ@@eKcUPCCSGdP\t1.18\nqCr@PISRAxe`\t1.18\nHknL`IaM@HrRFIKISaV@Bf@A`qTwR_H@\t1.18\nHk^@@@RiU{Vntzjh@H@FBpfEPrngrN@\t1.18\nHifL@NBaReYrZjjh@XMaTwCqHP\t1.18\nHcLD@@kIEMDdcttDDT@CAdIae^Qh\t1.18\nsJY@LDejhAaaEqX`\t1.18\nsNp`@df]Zj@XKGbk@\t1.18\nqC`@ISTAaAsQX\t1.18\nJoba@FCBJzUSsZoSCiwUUTuMP@XTaR]|Rn@\t1.17\nHeTLB@QdyInYqehH@@FETwCH\t1.17\nHaF@`FBHRYVkh@`@FE@fUwHX\t1.17\nHifH@NAJ[VXZ@H@A`RXw\\Pa@\t1.17\nHaE@@@qJYVnBB@@XTfEW\\a`\t1.17\nsFtHLPDISNmLpCCAWdH\t1.17\nj`qaB@GBAHILkmroQegP@SUUD@CBRLDiIVcVyCp\t1.17\nJoCDPCbD`drnwJtuo@AMUQ@AaJXURng_H\\\t1.17\nHkoD`LDxP@cIIBhdmeuZ`PH@FGXwCJgrJ@\t1.17\nHg]L`LnDD@cIIBhhd]ikTC@P@LF[iW[yF@\t1.17\nHmvDRLa@BJbL{IIBidiUZ`@@AaUMpsrE@\t1.17\nHg^L@DAaRUf^uNvjj@@@FBiaTprngqHl\t1.17\nJoBD@@ILvnroC[m@A@@@@XRUMrz]orL@\t1.17\nHo\x7FH@DVpRYYU]YujBBJ`@XJaTwCIv\x7FHT\t1.17\nHo}D@ElDRYYU]YujBBJ`@XRUMpr]orE@\t1.17\nHcOD`LWXP@cIIKDedLkP@R@C@j[axfZ\t1.17\nHcND@FATfYev]jB``@FDaFEWCJ|Qm@\t1.17\nHcLD@NGIIDcDYBUULu@CChSBY]y@`\t1.17\nHeTHPBBlzlRYgea``b@AaPXWCrI@\t1.17\nHmtH@ArRQHiRDjjVh@X]BXURoHX\t1.17\nHeVH@IAIfu~Fh@H@FCAATw\\SI@\t1.17\nHidH`ABHRYWZZ@B`@XLBXUCrN@\t1.17\nHeV@@@RYyTYj`@@A`HIeMpsrH@\t1.17\nHeTD@@qIUeQej@@@FCIS\\L|b@\t1.17\nHid@@LddUTaJjZ`A`tXU\\OHP\t1.17\nHaFH@BAIf]n``@@XDFTwDK`\t1.17\nsNx@HeTuUPC@kU|a@\t1.17\nsKP@DjTZj@XDQGdp\t1.17\nsGX@@eSUT@pJqoI@\t1.17\nQO@HyjA`erP\t1.17\nHeTD@@QIemQej@@@FATwCqBd\t1.17\nQM`AIdGfR\t1.17\nRG@DXLJy@\t1.17\nj`qA@@@YHihhhdd]Nmzj@B@@@@XZ`s`iJtZso\\``\t1.16\nj`qa@@F@RYV{m^gKN`BJ@B@@FB`HqSbmFm{dI@\t1.16\nJgB@P@AFRJJJIIFad}n`@`@`@CBPIne]N~PH\t1.16\nHg]DrBX{BlFlVlodfYn\x7FnfBHbf@Aa`BoDI`\t1.16\nJoBD@@YEEEEDdbmf}P@P@@@FFqS\\Lkiv\x7FH@\t1.16\nJoBP@@XUYHhhceDdwVxEAP@@@FCEWBn|p{\\\t1.16\nHg^HpBLJrZsZqIfVYYe``jI`@XT@sm|SE@\t1.16\nHg|@@LdbbRLrSB]aDP@@@CATJfFUt{yF@\t1.16\nJoCD@C@drm|kuqw@DP@P@A`hIe]Jz[|a`\t1.16\nHg\x7F@@@qdigvU|kSZj`@h@FDiaTLkm|a`\t1.16\nHkmD@ELDrJIQIIF]Z``b@AaqTwCI|aP\t1.16\nHeWD`LjXP@cIHUDdLkP@@@pSFy`\\H\t1.16\nHmtD`NTHaIe]Vf`@jP@XLBXUCrI@\t1.16\nHeVD`La@BLddlRPrm@@@CCLj^XwB\t1.16\nHcLD@@QIeeUgVhHH@AaqTwCN|aP\t1.16\nHeTH`BBHRYeUa``b@A`PYP|Si@\t1.16\nHmvH@DAIge\\YZ`@`@XLfTwCrE@\t1.16\nHeVD@DBTeYWxV`@`@XLaTwSrH@\t1.16\nHeUD@LdDRY[TYZjj`A`UMp|Pi@\t1.16\nHidH`BBHRYgVzB@`@XDFUwDHP\t1.16\nHeTH@@RV[TYZ`@@A`qTwCODa@\t1.16\nHid@@LddRL[jjj`AatIaUp|a`\t1.16\nHeVD@FADfygFV``@@XEWCODQ`\t1.16\nHeVH@IAJ[WVz`@h@FCIaTp|bP\t1.16\nHiT@@DjUfa[``hH@X]BXULOHx\t1.16\nHieD@LDDR[e^Ejjh@XDUMwDPP\t1.16\nHidH@@RYm^Fh@@@XLDESCqLx\t1.16\nHieH@DXDfyWaZ@@@FAEWCrD@\t1.16\nHaDH@HRjw[jjj@FCPfTw\\``\t1.16\nHaF@@@RiUkjjj@FEPaTwDs`\t1.16\nHaD@@DjWzZjj`A`pPaUwDq`\t1.16\nKAxH@@bRjsUT@XUaTw\\b@\t1.16\nsOq@@drm]UT@pXVM_I@\t1.16\nqChPK@HRUhCAA\\Tp\t1.16\nsJYiCE`D[h}Z@^P`\t1.16\nsJX`LDdvu@LEcrH\t1.16\nsGX@@dk]T@pvMyD\t1.16\nsJPa@erS[T@|VH\t1.16\nHaDD@@IIf]n``@@XDFEwDi`\t1.15\nHidD@@IIf][hHB@AafUwL@a@\t1.15\nHiDHPHApiprRQVRjj`A`rXS\\H\t1.15\nsJ\\@@ldru@LLEnP`\t1.14\nsJQ@@dsU@LLEnJD\t1.14\nQMPARVAaGFP\t1.14\nqCb@AIZpLDMrP\t1.13\nHaD@P@bNbDfUZZ@B@AaPHS]rL@\t1.13\nHaD@@DjUZxHH@AadIgBJfx\t1.13\nqCp@AIj`LMEnP@\t1.13\nKA|P@HBS[KUT@XDUMwDS@\t1.12\nsKP@Di\\Zj@XDQ[dH\t1.12\nHidH@@Rfy^F`H@@XDU\\ODQ`\t1.11\nsNu@EPdrsUPCCKWbK@\t1.11\nHaDH@@RYe[hB@@FAXS]q@h\t1.11\nHaDH@@RVU[f@@@FFTw\\rLH\t1.11\nsGP@Divj`FFBoMLP\t1.1\nsKT@Adi\\Vf@XFKD\t1.1\nKAxD@Ae\\dmvuU@FEIaUwDa`\t1.1\nqCx@AYIf`LHNIX\t1.1\nHeTH@@rQSIPmu@AP@LBSNGfDt`\t1.09\nHidD@@EIYW[j@B@A`PXU\\rFD\t1.09\nsGX`LJdmuT@pHboEb\t1.09\nsJX@@eMU@LBHmrD\t1.09\nsJP@DkVhAaacqQ@\t1.09\nHeTD@@IIf]vzB@h@FCAaUp|bP\t1.09\nsKT@Adi\\Vf@XZH|f@\t1.09\nHid@P@kAkDfUff`@h@FA@cCqLx\t1.09\nqCx@AYIf`LDErX\t1.09\nHifH@DAIVUxV`@@AaRES]qHD\t1.09\nsJX@@eKU@LCEcr@\t1.09\nHaF@@@RYe[hB@@FEXUMwH@\t1.08\nsGX@@eNuT@phfMyD\t1.08\nHaD@P@qFqDfUjz@H@A`PIc\\Rn@\t1.07\nsKX@@eKcUPC@qX|`@\t1.07\nHif@@@Rge^Fh@@@XMATwCq@P\t1.07\nqCa@CIJtAaEqS@\t1.07\nqCb@AIV`OME`\t1.07\nHmtB@@zURVUgXV@Hh@FEXWRoH`\t1.06\nqCp@AJZ`LLEnR@\t1.06\nHidH@@Rfuvz`@`@XDfTwDHP\t1.06\nHg|@@DjYV}~T{`d@@@@FBic\\LkiwrJ@\t1.06\nHidH@@RfU~F``@@XEaMwLRa@\t1.06\nHidH@@RYWZZ@B`@XTBXU\\Sa@\t1.06\nsJP`@TeVhA`d^JX\t1.06\nHcNJ@MCNeTify^ajjjj@FBpaTwCJ{rL@\t1.05\nHmvB@EAaeJYY^njjjh@XSFES\\LkrD@\t1.05\nHk\\D@@iIYgU^GSXH@@@@XLURngqHX\t1.05\nHmLH@@RYVuiiV@@@@@XLE\\LkqDp\t1.05\nsFq@@eLzuU@LCEkrD\t1.05\nHaDH@@Rfu[j@@@FFIW\\sBX\t1.04\nsGU@E`dsmT@pQoDl\t1.04\nHaFH@NAIe^f`@`@XDfEWDC`\t1.04\nsGU@EPdrmT@pRoEb\t1.04\n`IJpCr@\t1.04\nqCp@AIZ`LHnXS@\t1.04\nQM@HzAyd`\t1.04\nsNx@@eJ}UPCBqZobA@\t1.03\nsNq`@fdvkUHCAX|Rh\t1.03\nsJX@@dkU@LMEnHD\t1.03\nqCp@AIZ`LEMqA@\t1.02\nsGPXHlPDYIHUj@XP|e@\t1.01\nsOx@@drm\\@@@pQoBEf\t1.01\nsGT`EPTfyi`GbU@\t1.01\nqCpB@RduPFFbwH@\t1.01\nHefDB@XPgIIETiUUL@LJaLJnQH\t1.01\nHidD@@iJ[gxZB@@A`RDp|Rn@\t1.01\nsNyA@qNRRJuU@LCEcqU`\t1.01\nsGU@EPdvmT@pRwDZ\t1\nsJX@@eOU@LBHmrD\t1\nHeVH@DAIYmQej@@@FETwCOD``\t1\nHeTD@@iJ[e^f```@FEHS\\OHd\t1\nsOpHADILkW@@@LBDWqZ`\t1\nHaDH@@RYWih@H@FA@aUqLx\t1\nHidH@@RYm^Eh@@@XDUMwDpP\t1\nsOpHAHILkW@@@LBl[rL\t1\nsFy@DDfTujhAaekrD\t0.99\nsKX@@eKcUPCCCGbb@\t0.99\nqCb@AIZ`LDMqQ@\t0.99\nHg|@`@bLbbbRLRS\\]pDD@@@CAPpfzUt{yE@\t0.98\nHklJ@@R]MIemYqUj@Hh@FETtz_HH\t0.98\nHeTH`ABHRYWZf`@f@AaPIaUrI@\t0.98\nHcLD@@eJ[V][j@Bj@AaRYp{qBT\t0.98\nHie@@@QInUxV`@@A`pHUMwHD\t0.98\nKA|P@HBSMkUT@XDUMwHp\t0.98\nsNx@@eLuUPCBbKWbK@\t0.98\nsNx@@eJmUPCAqXu|`@\t0.98\nqC`@IVtA`enHP\t0.98\nsNyABCJSOUU@LJHj~KD\t0.98\nsGQ`@bdwMT@prqyJ\t0.98\nJoBD@DIU\\vjzv[uP@@@@@X[EMprng[|``\t0.98\nHg|H@@RYfUWd}nh@@@@@XZATwCJz]|b@\t0.98\nHmTFB@PfETyIn{mjjj@FGXUMpkrI@\t0.97\nqCbPPABUm@XI[d@\t0.97\nKAxDD@S]wILsuUPAaPPaMqLh\t0.97\nsNx`JDdrkUPCAE|Vh\t0.97\nHaD@@DjUZxHD@AaTXU]qDX\t0.97\nHidH@@RUe^Fh@@@X\\DES\\OHP\t0.97\nHaDH@@Rfu[j@@@FAIeMqBx\t0.97\nsGX`DJdjmR@pbyib\t0.97\nHaD@P@kNkDfUZZ@B@A`PHw\\SB@\t0.96\nHiFDB@XPgIIETjji@FEPfEWHx\t0.96\nJoCF@F``iLkJ|jz]mUUUUP@XJUMpriv\x7FHp\t0.95\nHg^D@E@TfUvujZ@Bjj@AahHU\\LkiwrL@\t0.95\nHmtD@@eIfUTUjBB@@XBDES\\L|SE@\t0.95\nHmvD@LATenUqej@B@AarYS\\J|b@\t0.95\nHeVH`NdHaIe]ZZ@Bd@FC@fEW\\`P\t0.95\nHif@@@rRJEKajjj@FGPaTwCrL@\t0.95\nHmtD@@QImYVUZX@@@XTwCJ|qLH\t0.95\nHeTH@@RfUWihHH@AaVES]sDFP\t0.95\nHifH@AAIe]ih@J@A`pIaTOHx\t0.95\nHidD@@iIYgxVB@@A`QTw\\RA@\t0.95\nHaFD@DCdeeVyjj`A`VES\\b@\t0.95\nsOp@DiUkjj`FCDVMyF\t0.95\nsJPhH`DYIBm@LEcr@\t0.95\nHeTH@@rQSIPmu@AP@LJSFx^HT`\t0.95\nHeT@pHdDdLdLddlRPsU@@@CCJF^Hw@\t0.95\nKA|PD@pSddbljj`CAhSBinQp\t0.95\nHaDH@@RYe[hB@@FAAaMqJx\t0.95\nsJY@LDeZhAaaMqH`\t0.95\nHcNH@DAIevUWVj`@@AarUprn|SB@\t0.95\nsGP@DiUiPFADVxcP\t0.95\nsJT@@TizhAaaMqH`\t0.95\nqCr@HIJtAyhl\t0.95\nsOx@@drm\\@@@pJq_DJ\t0.94\nsGQ@@dsUT@ppQyij\t0.94\nsGU@DPdwMT@pVODj\t0.94\nqCp@AIZ`LInXQ@\t0.94\nJoB@@BUJssoPvxPTA@@@FFpaTLkiv\x7FDs`\t0.93\nHidHPBBlzlRYgfFBB@@XDF\\ODI`\t0.93\nHmvH@AAIYWYnX@J`@XMaTtkrH@\t0.93\nHidL@@IdfYoa`b@@FE@UMwHD\t0.93\nsFt@ATiTvjhA`qEcP\t0.93\nsNy@DDeeZj@XGFod`\t0.93\nsOx@@drm\\@@@prMyaf\t0.93\nsGP`@dfuj`FBVxcP\t0.93\nHaDH@@Rfu[j@@@FAXUMqDx\t0.93\nsGY@LDeVj`FABqxiP\t0.92\nHcND`La@BLddJfRtjmP@P@LFqnF]yE@\t0.92\nsGU@EPdrmT@pRwDZ\t0.92\nsGQ@@djmT@pruxhP\t0.92\nqCp@AJZ`LInXQ@\t0.92\nqC`@IRtAaAsQX\t0.92\nqCbPXABRt`^XQ@\t0.91\nqC`HBHTPduPFFDWI`\t0.91\nHid@@DjU^nBBH@FCPaUp|SF@\t0.91\nQMPARZAaGFP\t0.91\n`IH`CB@\t0.91\nQM`BN`XQqd\t0.91\nKAzH@IP\\dvjuT`FFIe\\Pf@\t0.9\nsNqaIV~RjzjXAaIqX`\t0.9\nsGY@DDeUj`FBQyij\t0.9\nsJY@DDeVhAaEsSD\t0.9\nsJY@LDejhAa`cqS@\t0.89\nHidH@@Rfuvz`@`@XEaTwDPP\t0.89\nsJQ@@eMU@LEEqX`\t0.89\nsJQ@@dsU@LLHnKD\t0.89\nsJQ@@dju@LH^ZK@\t0.89\nHiDJB@PfENR[nvjj@FEXULOHx\t0.88\nHidH@@RfU~F``@@XDfDwLka@\t0.88\nHaD@`@dDfYVz@`@A`VDw\\b`\t0.88\nKA|H@TBILlmUPAafEwDi`\t0.88\nsNp`@dfUZf@XHobu@\t0.88\nqCp@AIj`LLEnR@\t0.88\nHeV@@@rRHqICMT@@@LFbfxYxbX\t0.88\nHmvH@LAI[YVUZh@@@X\\aMproDc@\t0.88\nsKXHB@aJWFe`FFDwH`\t0.87\nHidD@@iIYgxVB@@A`QMp|RJ@\t0.87\nsOpHADILkW@@@LBEWqX`\t0.87\nHmtD@@UIUe\\YZ`@`@XMeMpkqHP\t0.87\nsJX@@eKU@LLL^JH\t0.87\nsJQ@@dsU@LLH^IX\t0.87\nHkLNCHiiWS[ex~rRSQHqRjZfX@XYFD\t0.86\nHmn@@HRjuYX^gejjjj`A`lIaTwCJ`\t0.86\nHedJA@RaeNgdfvvZjf@FFYS\\``\t0.86\nHefDB@XPgIIETiUUL@LJaLJ^QP\t0.86\nHif@@@Rge^Fh@@@XLDES]qDD\t0.86\nsGPBIHJPtaXcIIKUPCBWdH\t0.86\nsNq@GddbmUHC@qX|e@\t0.86\nsGY@LDefj`FABqxiP\t0.86\nsNx@HeTuUPCCKGbk@\t0.86\nsNp`@dfvZj@XGFodP\t0.86\nsGX@HeTuT@prqxiP\t0.86\nsJPH@DILuPCAQ\\pq@\t0.86\nsJY@BDfZhAaaMqH`\t0.86\nsNp`@dfUZj@XHwbs@\t0.86\nsJQ@@dmU@LLEnJD\t0.86\nsJX@@dkU@LCEcr@\t0.85\nsJXhMD@cIHUhAyab\t0.85\nsJT@@TizhA`h^XK@\t0.84\nqCh@BIWLAaMqQ@\t0.84\nqCj@KAIf`LHnS@\t0.84\nHmN@@@RfUWrnf`Pb`@X\\BDwCOHT\t0.84\nsOq@@drm\\@@@pHQoEf\t0.84\nsGQ`@jdjmT@pVOEJ\t0.83\nsGQLKIARFdLddmU@LH^R`\t0.83\nsJXhMD@cIHUhAaCqC@\t0.83\nHaF@@@Rfu[j@@@FEAaTwDS`\t0.83\nsJQ@@dmU@LLl^HP\t0.82\nsJU@DPdvu@LH^IX\t0.82\nsJY@DDfvhAaCqK@\t0.82\nsJP`@TeVdAyhl\t0.82\nHcLJ@@PUuInUgzV`BJ@AaQTJ{rD@\t0.81\nsOxA@IRi^lH@@XVHu|f@\t0.81\nsOpHADILkW@@@LBCWqK@\t0.81\nsNp`@deVZj@X[U|TH\t0.81\nsNp`@deYZj@X[F|TX\t0.81\nsJX@@eKU@LML^HH\t0.81\nHaDH@@RYVih@H@FE@fTwHx\t0.81\nsFx@@eLzuU@LBIkqH`\t0.81\nsJQ@@dlu@LDmqP`\t0.81\nqCr@XIKTA``nJX\t0.81\nsJQ@@djs@LDmqP`\t0.81\nqCr@HIJtAaEqS@\t0.81\nHmTJ@@IaUIf[njjj@FBaBXUMpkrI@\t0.8\nHedJ@@IaeIf[zjj`AaHPfESCOHx\t0.8\nsGXhMD@cIHXmPCs@t\t0.8\nHeV@@@Re[TYj`@@AatIS\\L|PB@\t0.8\nqCb@AIf`ODl\t0.8\nHedJAHiaenglddtUeTtp@pRLyA@\t0.79\nsJY@DDeVhA`inID\t0.79\nsJX@@dku@LInID\t0.79\nsFp@DjTvjhAaQD[rX\t0.79\nsGP`@deYj`FBqxiP\t0.79\nHiF@@@RifZjj@FGPfES]rA@\t0.79\nqCa@CIJtAyhl\t0.79\nsFp`@dfTujXA`l^R`\t0.78\nsNp`@dfyZj@XEXodh\t0.78\nsGP`@dfyj`FFVOIP\t0.78\n`IHPCr@\t0.78\nsG\\@@ldsmT@pHVOIP\t0.78\nHaDH@@RVU[j@@@FAAaUsH[`\t0.78\nQMhDRVAxr\t0.78\nHeTHPBBlzlRYgea``b@A`PYp|Pi@\t0.77\nHmtD@@QIee^UZ``@@XLULLkrN@\t0.77\nsGQa@bnR[fj@XP|Vh\t0.77\nQO@HyjAaGFP\t0.77\nsGX@@eNuT@pLqoDD\t0.77\nsNq`@fdvkUPCCKObM@\t0.77\nsOx@@drm\\@@@phVMyF\t0.77\nsJX`DBdjt`LHnJX\t0.77\nKAxD@@c\\dvluS@FFIg\\``\t0.76\nHaDD@@IIf]n``@@XYeMs@K`\t0.76\nsOp@DjWkB@@FBaxUjp\t0.76\nHaDH@@RVU[j@@@FCAaTw\\b@\t0.76\nsJX`DBdvt`ODl\t0.75\nHidH@@RVUvy`@`@XUaTp|b@\t0.75\nqCp@AJZ`LLInQ@\t0.75\nsOp`Hdjekjj`FBqxjp\t0.75\nqCb@AIVPLHnJX\t0.75\nHeTB@@sirQQSRtMUUT@LNaB[agbYP\t0.74\nsGQ`@jdvmT@pQoDl\t0.74\nsNx`DJdjsUPC@hu|Tp\t0.74\nsOq@@drm\\@@@pHU_Eb\t0.74\nHidD@@QInUxV`@@A`QTw\\QA@\t0.74\nHaDH@@Rfu[j@@@FEXUMwHP\t0.74\nsOq@@drm\\@@@pRoBLV\t0.74\nHaD@@DjUZxHH@A`tIaUwHX\t0.74\nHeVH@AAIYWVy`@h@FEXULODbP\t0.73\nsNx@AddQUUPC@pu|Rp\t0.73\nsJP`@TeVhA`l^JH\t0.73\nHmt@pHdDdLdLddlRTFZh@H@FATpsrE@\t0.73\nsJT@@deVhAa`mqP`\t0.73\nsOq@@drm\\@@@pROBMV\t0.73\nqCr@XIKTA`aNIX\t0.73\nHidHPBBlzlRYgfFBB@@XTFEp|a`\t0.72\nHiDJA@PnENGdf{Yji`A`aUrL@\t0.72\nHeUH@DdDfyWxV`@`@XDUMwDRP\t0.72\nsJY@LDeZhA`QEnP`\t0.72\nsNqa@jnR[YjhA`m^Hl\t0.72\nsJY@LDeZhAaaEqX`\t0.72\nsOp@DjWkB@@FFbOMjp\t0.72\nqC`@ISTAaEsBX\t0.72\nsKP`Adi\\Zj@^ZH`\t0.71\nHidH@@RYWZZ@B`@XLBXU]rA@\t0.71\nsJQ`@bdvu@LDcrX\t0.71\nQM`BN`XL|`\t0.71\nqCb@AIZ`LDEqS@\t0.71\nKA|X@TB\\dvjuT`FFIe\\Pf@\t0.7\nsGY@DDeej`FBfxcP\t0.7\nsGXA@IRiZj@XVKF|`@\t0.7\nsJQhHl@cIHUhAaCr@\t0.7\nsJP`@TfZhAaacqQ@\t0.69\nHk\\H@@RfYU\\]Tz@@@@@F@xUMproDtp\t0.69\nHidD@@QInUxZ`@@AaQTwCs@a@\t0.69\nsOx@@eJ~MKT@ppeydV\t0.69\nsJY@DDfvhA`enP`\t0.69\nsGQ`@jdvmT@pRoEb\t0.69\nsGY@LDeZj`FFDWDZ\t0.69\nHaF@@@RVU[j@@@FEXUMwDB@\t0.69\nsGP`@df]j`FDwDZ\t0.69\nsOq@@drm\\@@@phVKyJ\t0.67\nHev@@@RfUWJzZABH@FC@aMt|`P\t0.67\nsJQ@@dju@LInZH`\t0.67\n`L@OH\t0.67\nqCp@AIZPLMEnP@\t0.66\nsJQ@@dsU@LDmsBD\t0.66\nsJP`@TizhA`h^IX\t0.66\nHaDH@@RYWih@H@FE@fEWHx\t0.66\nHaD@@DjUZxHH@AaTIaUqFx\t0.66\nqC`HBHTPduHFBByL\t0.65\nsJPXHlPDQzt@pfyB\t0.65\nsJU@DPdvu@LHnKD\t0.65\nqCbPXABRt`XR\\PP\t0.65\nHidH@@RfU~F``@@XTfMp|Pj@\t0.65\nsJP@DiVhA``nZX`\t0.65\nqCb@AIVPOME`\t0.65\nsJQ@@dkU@LEMsAD\t0.64\nsGP`@dfUj`FDoEb\t0.64\nsGY@DDfUj`FBVxcP\t0.64\nsGY@DDfuj`FDoLlP\t0.64\nsGX`BJdruT@pHboEb\t0.63\nHidDB@QNR[e^Eh@@@XDS\\OHh\t0.63\nsNu@DpdvkUPCCKGbk@\t0.63\nsJT@AdiZhA``^ZK@\t0.63\nsGQa@jnR[Vj@XKWdH\t0.63\nsGP`@dfuj`FBMxe`\t0.63\nsGP`@df]j`FBqyJ\t0.62\nHeTH@@RfU\x7FahHB@AaRXS]qJd\t0.62\nHaDH@@Rfu[j@@@FAYS]qDH\t0.62\nRG@DTLHyP\t0.62\nsGQ@@druT@pHbwDZ\t0.62\nsJPXHlPDQzt@pVH\t0.62\nHid@P@bNbDfYYa`H`@FEAc\\OHh\t0.61\nsOq@@drm\\@@@pqky`l\t0.61\nqCaPQ@HRmhCB[d@\t0.61\nQM@HvAyd`\t0.61\nHifH@AAIYW[f@B@A`VES\\RA@\t0.6\nsFx@@eJxtm@LDIsHt\t0.6\nsOq@@drm\\@@@pJM_DL\t0.6\nHmtB`HSBCprRSFIJUZh@@@XMaMpsrE@\t0.59\nHeTDPAdHc`aIe]jZ@BT@FE@fEWHx\t0.59\nHeV@@@rRJEK\\MP@P@LJJfz^Hf@\t0.59\nHif@@@Rfuvz`@`@XUaTp|PD@\t0.59\nqCcPQXPd]hCAK\\`@\t0.59\nsGU@DPdwMT@pVoDb\t0.59\nsGY@DDfuj`FFVOIP\t0.59\nsJP@DizhAa`mqP`\t0.58\nsGP`ATeUfPFBVxhP\t0.58\nqCp@AJZ`LDIqK@\t0.58\nHaDH@@RYVih@H@FFIS\\pLx\t0.57\nQMPARVA`cr`\t0.57\nHidH@@Rge^Fh@@@XTUMp|RD@\t0.57\nsOq@@drm\\@@@ppSylZ\t0.56\nHmvH@DAIUYVUZh@@@X\\aMproDc@\t0.56\nQMPARZAyd`\t0.56\nHmvH@FCHhhhdYVhJ@@AaHQaUproHX\t0.55\nHiF@@@ReUZjj@F@pfES\\OH@\t0.55\nHid@@LdbRQk``b@AaTHUCqLX\t0.55\nsNxA@IrRQVjhA`Xl^Jl\t0.55\nHiV@@@RfU|kahDB@A`pHS\\OHh\t0.54\nsFx@@eJf`@@LCL[rH\t0.54\nsFx@@eJf`@@LMM^ID\t0.54\nHaDH@@Rfu[j@@@FAIaUqFx\t0.54\nHaDH@@RYWih@H@FAIaUq@x\t0.54\nHifH@JAIYgxVB@@A`QMp|RJ@\t0.53\nsGYALMJRmUPC@aF|Tp\t0.53\nqCp@AIj`LDEqS@\t0.53\nsN|@@ldskUPCBaXwdX\t0.53\nHid@@DjU^nBBH@FGPfES]rA@\t0.53\nHaF@@@RVU[j@@@FCQaTw\\`@\t0.53\nsGQ@@druT@pHboEb\t0.52\nHidH@@Rge^Fh@@@XDUMwLaA@\t0.52\nsJP@DjYdA`inID\t0.51\nHifH@DAInUxV`@@A`QTw\\QA@\t0.51\nsGU@E`drmT@pbylZ\t0.51\nsOq@@drm\\@@@pJqoDF\t0.51\nKAxD@Ae\\dmvuT`FAIaUqHX\t0.5\nsGP`@dfuj`FBUxlP\t0.5\nqC`P@HRfhCAB\\Rp\t0.5\nsOpH@DILkW@@@LBl[qA`\t0.5\nqC`@ISTA`anJH\t0.5\nsGY@DDfUj`FBqxeP\t0.49\nHiDB@@IaRYfzjj@F@aBXULOHx\t0.49\nKAxD@@S\\dsOUU@FGABXS]rJ@\t0.49\nsJP@DiYXAaaEqX`\t0.49\nsJQ@@dru@LHnKD\t0.49\nqCa@CIJtAaMqQ@\t0.49\nHidD`HP@cIHXdnEX@@@XDUMwD@P\t0.49\nHaDH@@RYe[hB@@FEAaMwHh\t0.48\nsJU@E`dru@LHnKD\t0.48\nsGP`@df]j`FDOEj\t0.48\nKAxD@@c\\dvluS@FBIwDp`\t0.47\nsGX@@dkUT@pJqoDH\t0.47\nqCa@CIKTA``nJX\t0.47\nsNu@DPdwKUPCCXwbS@\t0.46\nHif@@@RUe^Fh@@@X\\BES\\OH`\t0.46\nsGP`ATeejPFDWMLP\t0.46\nRFD@QFCBnP\t0.46\nsOq@@drm\\@@@phVMyF\t0.46\nQM@HzAaWDP\t0.45\nQMBBHRYAaGFP\t0.44\nsOq@@drm\\@@@prqyaV\t0.44\nsGQ@@djmT@pVoMDP\t0.44\nqCaBAKdfZ@|f@\t0.44\nRFD@QFCqH\t0.44\nsJY@DDfVhAaCqK@\t0.43\nQMPARVAyd`\t0.43\nqC`@Qz`LDIqK@\t0.43\nHmv@B@B\\ddUbReZj@@@F@pfMproHH\t0.42\nsNy@LDeYjj@XDQGbk@\t0.42\nHaD@@DjUZxHD@AaTHU]qLX\t0.42\nHaDH@@RVU[j@@@FEXUMwDB@\t0.42\nqCr@XIKTAaAsQX\t0.42\nqCb@AIZ`LHnXS@\t0.42\nqCb@AIZ`LHNZK@\t0.42\nsOx@@eLmXD@@pJu_HP\t0.41\nsGY@DDfUj`FBUxlP\t0.41\nsGY@LDeVj`FADQxmP\t0.41\nsGT`EaTf]jPFDWEb\t0.41\nHaDH@@RVU[j@@@FEAaTwDc`\t0.41\nsOp@DjWkB@@FBbx\\Zp\t0.41\nsJP`@dfVhAaMrD\t0.41\nqC`@ISJA`aNIX\t0.41\nRG@DTOD`\t0.41\nsOp@DjWkB@@FAbMxlp\t0.41\nHidH@@RUe^Eh@@@XLaTwCrH@\t0.4\nsOq@@drm\\@@@pJq_DJ\t0.4\nQMhDRVAaWI@\t0.4\nsJPa@erS[T@pfyB\t0.4\nHeTH@@RUYTYZ`@@A`vTwCODa@\t0.4\nHidH@@Rfufz`@`@XDfMwDHP\t0.39\nHiD@@LddUdjjh@XMBXS]rA@\t0.39\nsJQ@@dkU@LLEnJD\t0.39\nsJP`@dfvhAyeb\t0.39\nsGY@DDeej`FDOMMP\t0.38\nqCa@AIMTAaIsAX\t0.38\nHaDD@@IIf]n``@@XEeMwD@`\t0.37\nsOp@DjWkB@@FEbM_I`\t0.37\nRF@QP|R@\t0.37\nsJY@DDefhA`l^R@\t0.36\nqCb@AIj`LINXK@\t0.36\nQMHAIhFD\\Y@\t0.36\n`Ib`hFD\t0.35\nHg|@@DjU_eZx{BAH@@@FBpaUtkiwqLX\t0.35\nsNp`@df^Zj@XKGbk@\t0.35\nHaDH@@RVU[j@@@FAXUMs@c`\t0.35\nQMHAIXGcH\t0.35\nqCaBC[dej@p`xh`\t0.34\nsJY@DDfVhA`enP`\t0.34\nKAxP`PCaSaddbljj`CBdpf{dT\t0.34\nHid@@DjU^nBBH@FCPfEW\\Qa@\t0.34\nHaDH@@RVU[f@@@FAXUMqHx\t0.34\nqCpB@SGj@pTWDL\t0.34\nHk\\@@DjU^ukmLHH@@@A`lHU\\Lki|c@\t0.34\nqCb@AJZ`OME`\t0.34\n`IlQpFD\t0.33\nHg|@@LdbRbtJUB]aAP@@@CAXPjFUt{xf\\\t0.33\nsFp@DiTt@@AaaCsKT\t0.33\nRFDDQFCBNT\t0.33\nsJP@DizhA`Pl^R@\t0.31\nsJP`@dfvhAaCqK@\t0.31\nqCb@AIj`LDIqK@\t0.31\nHidD@@iJ[gxZB@@A`QMp|QJ@\t0.3\nKA|P@HBRjsUT@XTaTw\\RL@\t0.3\nHeVD`Ia@BLdabRwBl@D@C@binx`R\t0.3\nsGP`@dfUj`FDOEj\t0.3\nsFp@DiTt@@A`QC^IX\t0.3\nsJPYHlPDGh}Z@^S@\t0.29\nqCp@AI^`ODl\t0.29\nsFp@DiTt@@A`anFHt\t0.29\nQM`AIXGfR\t0.29\nQOHBNZ`^L`\t0.28\nHidD@@QInUxV`@@AaQTwCrD@\t0.28\nsKX@@eKcRpCAB\\rq@\t0.28\nKAxD@@S\\dsOUU@FCABDw\\SJ@\t0.28\nsJP@DiZhAaaCqK@\t0.28\nQMPARVAaOD`\t0.27\nQM@H~AaWI@\t0.27\nsJQ@@dlu@LEcqQ@\t0.26\nsJP`AdizhAyhb\t0.26\nHid@@DjU^nBBH@FCPfES\\Sa@\t0.25\nHeTD@@QIemQej@@@FETwCOHH\t0.25\nqCr@HILtAaMrH\t0.25\nHid@@LdbRQk``b@AaTHUMqLD\t0.24\nsNq`AjdmsUPC@kF|TX\t0.24\nsGQ`AjdmmT@pruxhP\t0.24\nsGU@E`drmT@pRwDZ\t0.24\nsFp@DiTt@@A`a^FKD\t0.24\nQMHAIhGfR\t0.24\nsJY@DDeVhA`enJD\t0.23\nQMHBN`XUrP\t0.23\nqCa@CISTAyhl\t0.22\nQM@HvAaGFP\t0.22\nsJX@IGuPCAK\\TH\t0.21\nqC`HBHtPdmPFBFxh`\t0.21\nsGX`DJdjmR@pRwEB\t0.2\nqCj@KAIf`ODl\t0.2\nHaDH@@Rfu[j@@@FFXU\\qFx\t0.19\nHaF@@@RYWih@H@FE@fEWHx\t0.19\nsJQ@@eOU@LECqK@\t0.19\nqCr@HIJtAaMqQ@\t0.19\nRF@Q`|R@\t0.19\nsOq@@drm\\@@@pjqky@\t0.18\nQMDa^RVAyP\t0.18\nqC`@IRtA`aNIX\t0.18\nRFPDTNJlNT\t0.18\nRFPDTOJ@\t0.18\nQM`AIhFBOJ@\t0.17\nHidH@@RYm^Fh@@@X\\DES\\OHp\t0.17\nsJY@DDefhAaMqP`\t0.17\nsOx@@drm\\@@@pjqky@\t0.17\nqCcPQXAD]XCB[d@\t0.15\nQMFI@bM`XSr@\t0.14\nsFp@DiTt@@AaaEsXt\t0.13\nRFPDXLJy@\t0.11\nRFQAtXOJ@\t0.09\nRFPDXLHyP\t0.09\nqCb@AIV`LInJH\t0.08\n`H@^P\t0.08\nQMDARZAyd`\t0.05\n`I@`Cr@\t0.05\nsJXA@IczhAahmrD\t0.03\nsJP`@deVhAaMqP`\t0.03\nsJP`@TizhAaCsQX\t0.01\nsFp@DiTt@@A`QEnHt\t-0.02\nQMHBN`^L`\t-0.02\nqCa@CIKTAaAsQX\t-0.03\nQM`AIhFD\\Y@\t-0.04\nsGQ`@ZdruT@pHaoDl\t-0.05\nRG@DXLHyP\t-0.05\nsFp@DiTvjhAaacsQT\t-0.06\nRGAALXLJy@\t-0.06\nsJU@E`dru@OLlP\t-0.08\nHo|H@NrRQRqZZR]j``bh@FDiaMvg[|bP\t-0.09\nRFPDXOD`\t-0.09\nsOp@DjWkB@@FBexUbp\t-0.1\nqCb@AJZ`LHnJX\t-0.1\n`J@OH\t-0.1\nsJQ@@eKU@LECqK@\t-0.11\nsJX`BDdvu@LHnKD\t-0.11\nHk\\@@DjU^ukmLHH@@@AaLHU\\LkoDpp\t-0.11\nsFp@DiTvjhAaQEcrT\t-0.11\nsJP@DjZhAaaEqX`\t-0.11\nsJP`@dfVhAxlP\t-0.11\nqCb@AIZ`LINXK@\t-0.13\nsJPXHlQxQ{T@prq@\t-0.14\nsJP`@TeZhAaaCqK@\t-0.14\nsNq`@VdsMUPCBbHobu@\t-0.14\nQMDARZAaWDP\t-0.15\nHidB@@saRf]ZZjjh@XUEMp|qLH\t-0.15\nQMHAIXFD|h\t-0.15\nsGT@@Tivj`FADqxeP\t-0.16\nsJP@DjVhAahmrD\t-0.16\nqCa@CIKTA`anJH\t-0.16\nsFp@DiTt@@AaQEcrT\t-0.16\nsJP`@TfZhA`QD^S@\t-0.18\nsJPLIDJHtQGuPCCQ[dH\t-0.18\nsFp@DiTt@@A`QE^KD\t-0.18\nsJX@@eMU@LML^HH\t-0.19\nKA|@D@DyIHjjjh@pZDpj[d\\\t-0.19\nqCr@XIJtAaEqS@\t-0.19\nHaDH@@Rfu[j@@@FEIaTwHx\t-0.2\nqCp@AIZ`LDEqS@\t-0.2\nsOx@@drm\\@@@pJqoDF\t-0.2\nRF@Q`pce@\t-0.2\nHcl@@DjYU_egX@@@@@XRfES\\LkrM@\t-0.21\nsGP`@dfyj`FBVxcP\t-0.21\nqCa@AIJtAxi`\t-0.21\nsJX@@dmU@LLl^HP\t-0.22\nQMBBHRZAaGFP\t-0.22\nsGP@LdbKU@LCEcrT\t-0.23\nHaDH@@RVU[f@@@FEXUMwH`\t-0.23\nsNxA@IrRQVjhAaXl[rL\t-0.24\nQM@HvAaOD`\t-0.24\nsOp@DjWkB@@FAakxe`\t-0.24\nsGP@DiVj`FADUxlP\t-0.25\nqCb@AJZ`LInJH\t-0.25\nHaF@@@Rfu[jjj@FGAFES]rD@\t-0.27\nsNyA@qNRRJuU@LKEc^Q`\t-0.27\nKAx@@YIDTjjh@pxHSBknPp\t-0.28\nsFx@@eJf`@@LCEcrT\t-0.28\nqC`@ISTAa`mrP\t-0.28\nHaDH@@RYWih@H@FF@U\\qLx\t-0.28\nqCa@CIKTAaaMrH\t-0.28\nqCb@AIV`LHnJX\t-0.28\nHaF@@@RYWih@H@FAIaUq@x\t-0.29\nsJQ`@ldru@OEb\t-0.3\nsOx@@eJyh@P@pLVOHp\t-0.32\nHaD@@DjWzXHB@AaTIaUrN@\t-0.32\nKA|@@@eSMUU@FCPaTw\\c@\t-0.32\nsJP`@TeZhA`inXH`\t-0.32\nHmt@pHdDdLdLddlRVFZh@H@FATwCrE@\t-0.33\nHg\\@@LddTQRdTwUAAT@@pULJfFUt~QX\t-0.33\nHiF@B@B\\ddURjjh@X]BXUMwHD\t-0.33\nsJP@DiVhAa`mqP`\t-0.33\nQMABHXaIhFBOJ@\t-0.33\nsJP`@TfZhAaaCqK@\t-0.33\nsGP@Dj}j`FFVOEJ\t-0.34\nsJX`BDdvu@OLlP\t-0.34\nHeT@pHdDdLdLddlRPsU@@@C@j[ayD`\t-0.34\nHedHXFbPRPrPzPFPfPrRRqRUUU@CBByC@\t-0.34\nqCpB@ReMPFBfx``\t-0.34\nsFp@DiTt@@A`aNEXt\t-0.34\nHaDH@@RVU[f@@@FFXw\\rBh\t-0.35\nHmtJ@@siWIEDeDZFjjj`AatEWCJ|QF@\t-0.35\nqCa@AIMTAaMsBH\t-0.35\nsJX@@eKU@LLHnKD\t-0.35\nsGP`ATf^j`FADMxe`\t-0.36\nqCp@AIj`LDIqK@\t-0.36\nsGP`ATfVj`FADUxlP\t-0.37\nqCpPXABRu@XJKbF@\t-0.37\nRFB@QADXOD`\t-0.37\nHk\\@@DjU^ukmLHH@@@A`LHUCJ{sLxp\t-0.37\nsJQ@@dju@LDmqP`\t-0.37\nRFTPDQP|`\t-0.37\nQM@HzAaGFP\t-0.37\nQMHAIdFE\\Q@\t-0.38\nsJX`DBdvu@LH^IX\t-0.38\nqCb@AIZ`LEMqA@\t-0.38\nsNp`@dfUZj@XHobu@\t-0.38\nQM``eIhFCOH@\t-0.38\nQMFI@bMP^P\t-0.38\nHaD@@DjUZxHD@AaTIaUqFx\t-0.39\nsNp@LdbJjj@XVKF|PX\t-0.39\nsJP@DjvhA`enJD\t-0.39\nHaD@@DjUZxHH@A`tHUMwHp\t-0.39\nQMHAIhFBWI@\t-0.39\nsJPhHaxIRuPCAX|`@\t-0.4\nsJPXHlQxQ{T@|rq@\t-0.4\nqCa@AILtAxe`\t-0.4\nRGPQFCBNT\t-0.41\nsJPH@DIRuPCCBKbq@\t-0.42\nsJQ`@bdvu@LH^IX\t-0.42\nsGX`BDdwMT@pfydZ\t-0.42\nsGP`@TfZj`FADQxmP\t-0.42\nQMJHBHvAxb\t-0.42\nsFp@DiTt@@AxqEcP\t-0.42\nsGP@DjUj`FFbwDZ\t-0.43\nHmvD`La@BLddlRVFUh@H@FETwBoHp\t-0.43\nsGQ@@dkMT@pvMxh`\t-0.43\nQM``fN`XL|`\t-0.43\nQMHAIhFD|R@\t-0.43\nQMDARVAaOJ@\t-0.43\nHif@@@RUe^Fh@@@XLBES]qHD\t-0.44\nsGP@Djfj`FAVMyH\t-0.44\nqC`@Qv`LDmrP\t-0.44\nqCaPQ@Hck@^HX\t-0.44\nqCa@AILtAaErX\t-0.44\nQMDARVAqUaqd\t-0.44\nQMDARVAxr\t-0.44\nHid@@DjUfaBB`@FCPaTw\\SA@\t-0.45\nqCb@AJZ`LINIX\t-0.45\nHif@@@Rge^Fh@@@X\\DES\\OHP\t-0.46\nHiD@@LdbJTjjh@XBDIaTw\\`P\t-0.46\nsJP`@dfvhA`enP`\t-0.46\nqCaPQCpcm@XQ\\Pp\t-0.47\n`IjqpFD\t-0.47\nsJQ@@dmU@LLL^JH\t-0.47\nHaD@@DjWzXHB@A`THU\\SN@\t-0.47\nKA|H@XGIJsuUPA`pPaMwHh\t-0.48\nsKP`@Ti\\Zj@XR\\Rp\t-0.48\nHeTJ@@qaeJYyzzjjj@FGPUMpsqDp\t-0.49\nsNq`AVeMmUPC@sU|RH\t-0.49\nsGX`DJdrmT@pRoEb\t-0.5\nsGQ@@drmT@pRwDZ\t-0.5\nsGQ`AjdmuT@pHboEb\t-0.5\nHaDH@@RVU[f@@@FAYS]qHH\t-0.5\nqC`@Qv`LHnJX\t-0.5\nqCb@AIZ`LDIqK@\t-0.5\nsGP@LdbMU@LCEcqB`\t-0.51\nsGP@LdbMU@LCEkq@`\t-0.51\nHmvD`La@BLddJfReUj@@@FAMpssLiP\t-0.52\nsJPH@DISuPC@bK\\a@\t-0.53\nHiD@@Dj}Yjf`A`rXU\\OH`\t-0.53\nsGY@DDeYj`FFVOEJ\t-0.53\nsJP@DjVhA`hnKD\t-0.53\nqCr@XIKTA`anJH\t-0.53\nHaD@@DjWjXHB@A`TIS\\SN@\t-0.54\nsJPhHaxISuPCAX|PP\t-0.54\nsOq@@drm\\@@@pHVOEV\t-0.54\nsGP@LdbMU@LJHl^R`\t-0.54\nsJXHL@aIVj@XZK\\PH\t-0.55\nsNx`LFdjmUPCAbHu|f@\t-0.55\nqChPK@HRYhCBCbV@\t-0.55\nsKP@Di\\Vj@XXP|Rp\t-0.55\nqC`@IVtA`aNIX\t-0.55\nsGQhHl@cIHTmPCBGbE@\t-0.55\nsNp@LdbJjj@XLQXwdX\t-0.55\nqCb@AIj`LMEnP@\t-0.55\nHeT@@LddTjPsU@@@CCdpj[ayD`\t-0.55\nsJQhHl@cIHUhAx`P\t-0.55\nsJP@DjZhAahmq@`\t-0.55\nsJXHD@aIYj@XP\\tq@\t-0.56\nsGQ@@djuT@pHVOEJ\t-0.56\nHaD@@DjUZxHH@A`TES\\qLx\t-0.57\nsGY@DDeUj`FFVOEJ\t-0.57\nqCp@AIZ`LLHnS@\t-0.57\nqCb@AIZ`LEEqC@\t-0.57\nQMHAIhFE\\Q@\t-0.57\nsJP`@TizhAaicrH\t-0.58\nHidB@@kaReYrZjjh@XMaTwCqHP\t-0.58\nqC`@IRtA`anJH\t-0.58\nqC`@IVtA``nJX\t-0.58\nRGAALXOD`\t-0.58\nqC`P@HRfhCCBKdp\t-0.59\nsNp@LddUjj@XVKE|e@\t-0.59\nsOq@@drm\\@@@prkyab\t-0.59\nsJQ@@eOU@LEMqH`\t-0.59\nHaDL@@kldRTIMUUP@pKJ[nYBD\t-0.59\nqC`@ISTA`enHP\t-0.59\nsJP`@dfvhAaEqX`\t-0.59\nqC`@Qz`LLHnS@\t-0.59\nsNp@DiWjj@XLQFodp\t-0.6\nqCa@CIKTAaaErX\t-0.6\nsNp`@dfUZj@XKGbk@\t-0.6\nqC`@IVtA`hnHX\t-0.61\nsJP@DjZhAa`cqS@\t-0.61\nsJY@LDejhAa`mqP`\t-0.61\nqCcPQX^D]hCAK\\`@\t-0.61\nsOp@DjWkB@@FEbq_IP\t-0.62\nsGP`@dfyj`FBQxmP\t-0.62\nsOq`AVeJnMUT@pvMyhf\t-0.62\nHef@B@B\\ddURUUUP@pFDpj[ayD`\t-0.62\nHcLF`HSFgP|LdfrbTHjuUUT@LNpjzUwb@H\t-0.63\nHaf@@@RiUkfzjjh@XUBDw\\SJ@\t-0.63\nHeTD@@QIgeQej@@@FATwCqLd\t-0.63\nsNp`@dfWZj@X[U|a@\t-0.63\nQM`AIhFBWI@\t-0.63\nqCb@AIV`LINIX\t-0.64\nHaF@B@BTeeVz`@@A`tXUMwH@\t-0.64\nsF|@AbeJf`@@OMEP\t-0.64\nHmtJ@@pYUJYmVnjjjh@XCBTwCJ|SB@\t-0.64\nQMHAIdGfR\t-0.64\nHiFL@BANR[gfjf@FFIa\\Ra@\t-0.65\nqC`XBHTQhaIj`LLEnR@\t-0.65\nHeTD@@QIemQej@@@FAUpsqBX\t-0.66\nHeTB@@XYRfV~njjj`AatYS\\L|QB@\t-0.66\nHmL@@DjYeVdU@@`@@FGXULLkrN@\t-0.67\nHifDAHAHeNR[e^Eh@@@XHP|rfx\t-0.67\nsGP`@dfuj`FFqoH`\t-0.67\nsJQhHlOAJmj@XP|Pp\t-0.67\nsJQ@@dju@LLl^R@\t-0.67\nHmtJ@@siWIEEMDZFjjj`A`LHU\\LkqLX\t-0.67\nsGQ`@ZdruT@pHbOEj\t-0.68\nsJX@@dkU@LBHmrD\t-0.68\nHidH@@RYm^Eh@@@XTUMp|c@\t-0.68\nsGX`BDdwMT@pRwDZ\t-0.68\nHaDL@@sdigZZjj`A`TYW\\qBX\t-0.69\nqCb@AJZPLINIX\t-0.69\nqC`HBHtPdlpFBFxh`\t-0.69\nsJY@DDejhA`l^HP\t-0.69\nsGQhHlOAJoZhA`c^HX\t-0.69\nHmtJ@@siUJYn~ajjjh@XSBXS\\LkrJ@\t-0.7\nsGPYHlQxGdjmj`FDwIP\t-0.7\nqCbPHABSS@^HX\t-0.7\nHifDAHAHeNR[e^Eh@@@XHU\\qnD\t-0.71\nHid@`@BDiyWaj@@@FC@UMp|RD@\t-0.71\nHid@@DjUfaBB`@FGPfESCrN@\t-0.71\nqCh@CIKTA`anJH\t-0.71\nHidD@@QInUxV`@@AaRDwCrJ@\t-0.71\nqC`P@HRVhCAB\\Rp\t-0.72\nsGY@DDfUjPFBVxcP\t-0.72\nHidB@@qarQQZFnjjj@FCQaMp|QJ@\t-0.72\nHif@@@RYm^Fh@@@X]FES\\OH@\t-0.72\nHidH@@RUe^Eh@@@XTaTw\\RA@\t-0.72\nHidD@@QInUxV`@@A`QMp|QJ@\t-0.72\nsGP`@dfuj`FFVOIP\t-0.72\n`ImAHFD\t-0.72\nHeTL`HS@BLddlRPrm@@@CBlinGdR\t-0.74\nqCb@AJZ`LEErX\t-0.74\nsJQ@@dju@LDcqS@\t-0.74\n`Ld`^P\t-0.74\nRFTQXQ`|R@\t-0.75\nQMhHRZAaGFP\t-0.75\nHaDH@@RYe[hB@@FF@S\\sJx\t-0.75\nsJQ@@eOU@LDmqP`\t-0.75\nsGP`ATeUjPFBVxhP\t-0.75\nHet@@DjYUX^d@@@@AarXS\\L|b`\t-0.76\nHeV@B@B\\dbLRPsU@@@C@XSJ[agd@\t-0.76\nsJP`@TizhA`l^JH\t-0.76\nqC`@Qz`LEEqC@\t-0.76\nsNqDHGBnFRRJuU@LBlWrT\t-0.77\nsJQ@@dlu@LLl^R@\t-0.78\nKA|X@DBLdvluS@FBHWDs`\t-0.78\nqCbPP^BRu@XI[d@\t-0.78\nHid@@DjU^nBAH@FGPfES]rA@\t-0.78\nsOpHAbILkW@@@LJEc^Q`\t-0.78\nqCa@CIKTA`aNIX\t-0.78\nQMDARZA`cr`\t-0.79\nHeVH@IAIe]ZZ@Bh@FG@fEWSrA@\t-0.79\nHidH@@Rge^Fh@@@XLaTwCrH@\t-0.79\nKAxP@Uddbcjf`C@dpfyG@\t-0.79\nRFD@QECBNT\t-0.79\nHeTB@@XYrQQJHuuUUT@LNcB[agbIP\t-0.79\nqCcPQXAD]XCqC@\t-0.79\nsGP`@dfUj`FDwDZ\t-0.79\nHeV@@@rRJEK\\MP@P@LFSBinyD`\t-0.8\nHaDL@@sdigzZjj`A`TXw\\qBh\t-0.81\nsGX@@djuT@phbqyJ\t-0.81\nsGP@Djfj`FAbqyJ\t-0.81\nHaD@@DjYvxH`@A`RDw\\SJ@\t-0.81\nHeTB@@pYRf[vnjjj`AatIc\\L|Pj@\t-0.82\nHidB@@saRf]ZZjjh@XMFTwCqDH\t-0.82\nqCr@PIKLAaAqK@\t-0.82\nKAx@@YIDTfjh@pZDpj{dL\t-0.82\nqCb@AIf`LHnS@\t-0.82\nHeTJ@@qaeJYyzzjjj@F@qaTwCOHP\t-0.83\nHetD@@QIemRhYZ`@`@XDwCOHH\t-0.83\nsJP@DkVhAahmq@`\t-0.83\nsNp`@dfvZj@XXu|Rp\t-0.83\nqCc@AYIf`ODl\t-0.83\nQMBBHRZA`erP\t-0.83\nHklF@@pUt|dTTRbQjZjjjh@XKBESCJz_Hx\t-0.84\nsJPXHlQxQ{T@pRwHP\t-0.84\nHaDH@@RVU[j@@@FEQaTwDC`\t-0.85\nsFp@DjfJjhAaicqJ`\t-0.85\nQMhHchGcH\t-0.85\nKA|X@QS\\eUkUU@FGPfES\\\t-0.85\nsGPXHlQxIU[U@LEcrT\t-0.85\n`IhapFD\t-0.85\nQMFI@bM`^H`\t-0.85\nHmtJ@@pYUJYmVnjjjh@XSBYS\\LkrB@\t-0.86\nHidD@@QInUxV`@@A`RDp|Rn@\t-0.86\nHiDH@@RUUVjj@FGIaTwCrH@\t-0.86\nHaF@@@RYe[hB@@FAXUMq@x\t-0.86\nHeTH@@RUYTYY`@@AarYS\\L|b@\t-0.86\nsOp`@tieujj`FAfkxdP\t-0.86\nsGQ@HeUuT@pLVOIP\t-0.86\nsJQ@@dmU@LBIcrH\t-0.86\nsJY@BDeVhA`d^JX\t-0.86\nHaDH@@RVU[f@@@FFYS\\rBx\t-0.86\nsNp`@dfuZj@XEXwdX\t-0.87\nQM@HzA`sr@\t-0.87\nHaDH@@RVU[j@@@FAAc]sHJ`\t-0.88\nsGX`LJdmuT@phfMyD\t-0.88\nsGX@@eJuT@pHbwDZ\t-0.88\nj`i@`@@HRYYUg\\eIF]yjB@@B@@F@fBdkQkNx`g`\t-0.89\nHet@@DjfehZfjjj`AarES\\L|c@\t-0.89\nHeTD@@EIYWVy`@h@FEXUMOH`\t-0.89\nsGPhHaxISuU@LMc^HH\t-0.89\nsJXHD@aIYj@XXX|d@\t-0.89\nsJP`@deVhAqIXPVOI@\t-0.89\nsJP`@deVhA`l^R@\t-0.89\nqCb@AJZ`LEMrH\t-0.89\nsFp`ATiWFjhAal[qQ@\t-0.9\nsGQ@@dsmT@prqyJ\t-0.9\nQMA@HPaIXFD\\Y@\t-0.9\nsNphHaxIRkUT@pNM_H@\t-0.9\nsOx@@drm]UT@p\\VM_H@\t-0.9\nHiFD@BADf{Ujj`A`rXUMwHD\t-0.91\nqCb@AIY`LEEqC@\t-0.91\nsJQHH@aJuj@XI[bA@\t-0.91\nHmtH@HrRQVIJUjh@@@X\\fDwCOHT\t-0.92\nsJQhHlOBOZ`FBVyB\t-0.92\nsJQ@IGuPCCQ[dH\t-0.92\nqC`P@HRVhCAQ\\Pp\t-0.92\nHidB@@qarQQZFnjjj@FEPS\\OLSJ@\t-0.92\nsJP@DjZhAa`mqP`\t-0.92\nHcND@BADf{YU]Zj@@@F@iaUproHt\t-0.93\nHaDD@@yIe^f`@`@XHe\\HLK`\t-0.93\nsGP@LdbMU@LBHcqZ`\t-0.93\nQM@HzA`erP\t-0.93\nsOx@@drm\\@@@ppUylV\t-0.95\nsJX@@dkU@LLEnJD\t-0.95\nHaDH@@Rfu[j@@@FEIaUwHX\t-0.96\nsJY@BDizhAaicrH\t-0.96\nQMpRRWhuAyP\t-0.96\nQMACD\\QIhFBOJ@\t-0.96\nsJX`LDdvu@OLlP\t-0.96\nsFp`ATiWFjhA`m^ZH`\t-0.96\nsGP`@dfui`FBqxeP\t-0.97\nKAxYDPf@DYvRRUIZj@LLJfyG@\t-0.98\nsOpHAVILkW@@@LJEc^Q`\t-0.98\nsFx@@eJfuU@LJHl^R`\t-0.98\nqCa@CIKLA`anJH\t-0.98\nsJP`@TizhAahmrD\t-0.98\nsKQ@@eKcUPCAX|TP\t-0.98\nJoBD@@IS\\rjzv[uP@@@@@XKS\\Lkiv\x7FDa@\t-0.98\nsNy@DDf]Zj@XYZ|QX\t-0.99\nRFTPxQP|`\t-0.99\nqCp@AI^PODl\t-0.99\nHcLF@@siWTify^ajjjj@FBpaTwCJ{rL@\t-0.99\nqCpB@SGj@ptVy@\t-0.99\nHaD@@DjUZxHH@AaTHS]qLh\t-1\nKAx@@IVjmUPAapPfES\\c`\t-1\nqC`@IWtAaEqS@\t-1\nHaD@`@BDimVz`@@A`pXUMwHP\t-1\nsJPhHaxIVmPCAX|`@\t-1\nsOx@@drm\\@@@prqyaV\t-1.01\nqCa@AIJtAaMrP\t-1.01\nsJPLIHJPtaGuPCrD\t-1.01\nsNy`BDtfuZi@XYX|e@\t-1.02\nRF`dS]ECr@\t-1.02\nHaD@@DjUZxHD@A`tIaUwHX\t-1.02\nqCb@AIj`LLEnR@\t-1.02\nsOp@DjWkB@@FAfMxdp\t-1.03\nqCr@XIKTAahmr@\t-1.03\nKAxY@PfAxIUjmUPA`QTw\\`@\t-1.03\nsJP@DkVhAa`mqP`\t-1.03\nRFTQxQ`pkd@\t-1.03\nsNp`@deUZj@X[F|TX\t-1.04\nqC`@IStAxe`\t-1.04\nsOq`AVeJnMUT@pNM_ED\t-1.04\nsJQhHl@bOV`FDwHP\t-1.04\nHmvLAHAEbT{Hihdh^Eh@I@AaaTODzP\t-1.05\nHmL@@DjYUVGi@@@`@FGIaUpsrE@\t-1.05\nHev@@@RfUWJzZABH@FE@aMwDFP\t-1.05\nHiF@@@rRHiJjj`AatIaTw\\`P\t-1.05\nHaD@@DjUZzjj`AapPaTw\\c@\t-1.05\nHaFH@DAIYUnZjh@XEaTwDc`\t-1.05\nHaFH@NAIe^f`@`@XTfEW\\`@\t-1.05\nHiFD@BADf{Yjj`A`rYS\\OHH\t-1.05\nsJPXhlQx[ct^u@LH`\t-1.05\nsFp`@TivJjhAahmrT\t-1.05\nsGQHL@aJYihA``nHt\t-1.05\nsJU@DPdru@LDcrX\t-1.05\nsJQ@@dju@LEMqH`\t-1.05\nQMABlZqIhFBOJ@\t-1.05\nRFHEFCqH\t-1.05\nHaDH@@RVU[j@@@FAAeMsHK`\t-1.05\nKA|X@DBLdvluS@FFIa\\c`\t-1.05\nqCbPXQBRt`XP\\TP\t-1.05\nqC`@ISTA`aNIX\t-1.05\nJoBD@@ILrkNx{[mA@@@@@XJU\\Lkiv\x7FHp\t-1.06\nHeTD@@QImeQej@@@FCIeMp|bP\t-1.06\nHeTD@@QIemQej@@@FEES\\OHd\t-1.06\nHidH@@RYm^Eh@@@XUaTw\\`P\t-1.06\nsJT@@TizhA`QL^Q@\t-1.06\nQMBCpRZAaOD`\t-1.06\nRGPQECr`\t-1.06\nqCbHXRBdDfj@|Tp\t-1.06\nHaDL@@[die|jjj`AaTYS]qDH\t-1.06\nqCr@XIJtAaMqQ@\t-1.06\nQMFIOBM`XSr@\t-1.06\njhi@`@@^Rfuue]Yrsj@B`@h@@XJQ`eFJtZp^PD\t-1.07\nJoBD@@ISZzrk][t@E@@@@XRfESKiwqA\\\t-1.07\nHiDNPhSB[aCpkpsb{nGlddqdZih@P\t-1.07\nHiDD`HPOAJUfjjh@XMaTwCr@@\t-1.07\nsOp@DjWkB@@FAbqxjp\t-1.07\nQM@HvAaWDP\t-1.07\nsJXA@IRej`FAbqy@\t-1.07\nsGP`@dfuj`FBQxmP\t-1.07\nHmuD`IVD@HrRFIKKaV@BP@XDUMwDAP\t-1.08\nsKP@H~Jj`FBqxh`\t-1.08\nsGX`DJdjmT@pRoMLP\t-1.08\nsKQ@@eKcUPCB[fbH\t-1.09\nsJY@LDefhA`enJD\t-1.09\nsGP`@dfuj`FBqxeP\t-1.09\nsJXHB@aIVj@XZH|Pp\t-1.1\nHeTD@@QInYQehB@@FEISCOHx\t-1.1\nHaE@@@yIe^f`@`@XXfEs@k`\t-1.1\nHid@@LdbbQxXF@@A`RTw\\sBD\t-1.1\nQMhXNiRZAxr\t-1.1\nsJP`@dfvhAaMqH`\t-1.1\nKAx@@IRzmUPAapPaTw\\c@\t-1.11\nsNx`BDdw[UPCCXobU@\t-1.11\nsFp`@dfTujhA`m^P`\t-1.11\nsJQ`@bdvu@LHnKD\t-1.11\nsJQ@@dkU@LMEnHD\t-1.11\nsJQ@@eKU@LEMqH`\t-1.11\nsGXA@IRiZj@XFHwbF@\t-1.11\n`Ic@hFD\t-1.13\nHmtJ@@XYUJYY^njjjh@XSFES\\LkrD@\t-1.13\nsGP`@dfUjPFDwDZ\t-1.13\nsJQHL@aJVf@XHKba@\t-1.14\nQMB@HRZAaGFP\t-1.14\n`Ig`hFD\t-1.14\nHif@@@RYWZZ@BP@XTfEW\\PA@\t-1.14\nsNp`@teUZi@XYX|Th\t-1.14\nsGQ`@jdvmR@pbxlP\t-1.14\nsGPP@cTfyi`FBU@\t-1.14\nHidB@@kaReYrZjjh@XUaTp|rDx\t-1.14\nqC`@IRtAaaErX\t-1.15\nsNx@@eLuUPCAqXu|`@\t-1.15\nsGP`@df]j`FBMyL\t-1.15\nHcMB@hdDWXeNf]yInU^xV`@f@A`aCqJX\t-1.16\nHeTH@@ReyTYj`@@A`tYS\\ODRP\t-1.16\nHaE@@@aJyUnh@@@XLFES]rH@\t-1.16\nHidD@@yJ[VXZ@H@A`RXp|Pn@\t-1.16\nHaDD@@YIeZn`B@@XXf]s@i`\t-1.16\nKA|@@AddQRjj`CAhSBinQp\t-1.16\nsNp@DkUZj@XLKFod`\t-1.16\nsGQ@@eJuR@ptuxdP\t-1.16\nsGY@JDiVj`FAbuyB\t-1.16\nsJQ@@dmU@LBEcrP\t-1.16\nsFy@LDigVfXAydZ\t-1.16\nQMJAhHzAxr\t-1.16\nsGQ@@eNuT@pLqoH`\t-1.16\nsGPXhlQx[crUVuPCrT\t-1.16\nHaDH@@Rfu[j@@@FFXw\\qBh\t-1.16\nJoBbPCCk`DISJj{nTLuUUSSP@XZDIaTwBi|bp\t-1.17\nHk]H`FGPBDieU]rafjjjZ`A`hPfES\\J|`p\t-1.17\nHmMH`FEPBLdTRRQrafjjih@XBDIaTp|c`\t-1.17\nHcmH`FGPBDieU_JFZjjih@XRDIaTwCrE@\t-1.17\nHeuH`FzPBDiewrnFjjf`AapPfTw\\``\t-1.17\nHiUH`JXPBDiU_B[jjih@XLDXUMrD@\t-1.17\nsFp@DiTujhA`Pm^JD\t-1.17\nsGP@DiUj`FEDVOIP\t-1.17\nsGQ`@jdsmT@pfxcP\t-1.17\nsGQ`@bdwML@|Rh\t-1.17\nsGX`LDdwMT@|rM@\t-1.17\nqC`@IVtAaaMrH\t-1.18\nHidD@@QInUxV`@@AaRES]rA@\t-1.18\nHeTD@@eIYe^E`HD@FAEWCqHX\t-1.18\nqCb@AIj`LLHnS@\t-1.18\nHidH@@RVY^E`H@@XDU\\ODa`\t-1.18\nQM@HvA`erP\t-1.18\nsNqDHG@nFRQFUU@LBmWq@`\t-1.18\nqCqAPJRnRYhCrX\t-1.18\nsNp@DkUZj@XLQXwdX\t-1.19\nqCp@AIZPLDEqS@\t-1.19\nsGQLKHaQFbLddmU@LCEcrT\t-1.19\nKAxH@@bSZkUT@XTfES\\c`\t-1.19\nsJP`@dfvdAaMqH`\t-1.19\nRGPp]SFCr`\t-1.2\nHmLH@@RYUUiiV@@@@@X\\BEproHp\t-1.21\nHiV@@@RfU|kahDB@AaPHS]qJD\t-1.21\nqCbPXQBRu@XHSbV@\t-1.21\nHcN@@@rRJIIGRmPTA@@pELJfxYyF`\t-1.21\nHeTD@@eIYWVy`@d@FAXUMqHD\t-1.21\nQMB`HIchFCOH@\t-1.21\nHaDH@@RVU[f@@@FAXU]qHX\t-1.21\nQM@H~Axr\t-1.21\nQMHAIhFCOH@\t-1.21\nQM@HvA`cr`\t-1.22\nqCr@XIKTAaaMrH\t-1.22\nHg|H@@RYfUWd}nh@@@@@XJUMprng_DB@\t-1.22\nHg^J@DCiV|bbtTVaTzuUUUP@pULJnE]N~Pp\t-1.23\nHcNB@DCiUIgf^gVjjj`AarXU\\J|Qm@\t-1.23\nHidD@@QInUxV`@@AabEwLia@\t-1.23\nHaDH@@RYVih@H@FFAW\\qLX\t-1.23\nsOpHAHILkW@@@LBlWrT\t-1.23\nsGT@ATivj`FEDqoH`\t-1.23\nqCaPQCpRmhCB[d@\t-1.23\nsOp@DjWkB@@FFbwLZp\t-1.24\nHiDD@@QImUZjh@XLfES]rA@\t-1.24\nQMJH|HvAxb\t-1.24\nsJP`@dfVhAaCrX\t-1.24\nHklNaHSBySCpsb{IILUDhYujjjj@FCTpki|bP\t-1.25\nHcMB@hDDWXeNF]yInUnzV`BF@AaaUOHx\t-1.25\nHg^L@BAAR[eVuNvji@@@FDiaUJz]|a`\t-1.25\nHmtD@@eJ[WUnh@J`@XTfES\\PU@\t-1.25\nHmtD@@QIn[VUZh@@@X\\fMproHh\t-1.25\nHidD@@QInUxV`@@A`RDw\\Ra@\t-1.25\nsNp`@tfUZi@XI[bM@\t-1.25\nQOHBNZ`XUrP\t-1.25\nsNp`@dfWZj@X[F|c@\t-1.25\nsNpXhlQx[cvRRXmU@LI^Q`\t-1.25\nsOx@@drm\\@@@pHVOEV\t-1.25\nHeVDAHAHeNR[e_aZ@B@A`QTw\\bP\t-1.25\nsJX@@dmU@LCEcr@\t-1.26\nqCbPPABUm@XQ\\Pp\t-1.26\nsJP@DiVhAaaEqX`\t-1.26\nsGX`DJdjmT@prqxiP\t-1.27\nsJP@H~j@XZK\\a@\t-1.27\nHeV@B@BTiVuFZh@@@XCBES\\L|`@\t-1.28\nHidH@@Rge^Fh@@@XTaTw\\RA@\t-1.28\nsNx`LDdvkUPCCXwbS@\t-1.28\nRGDQxQ`|R@\t-1.28\nHaF@@@Rfu[j@@@FCAaTw\\a@\t-1.28\nsJP@H~j@XJKbq@\t-1.28\nHmN@@@rRJIKEaxZjjj`AaLIaMproHh\t-1.29\nKA|I@Dw@DIJwUTpAaTIa]r@@\t-1.29\nsFx@@eLzuU@LJHm^P`\t-1.29\nqCr@PIKTA`anJH\t-1.29\nsJQ@@dru@LDmrD\t-1.29\nsNq`@jdvsTpCB[bS@\t-1.3\nRGAALXLHyP\t-1.3\nHaD@@DjWZXHB@A`TXw\\QB@\t-1.3\nsNp`@dfUZj@XXu|f@\t-1.31\nHeTD@@QImeQej@@@FCIS\\L|c@\t-1.31\nsJQ@@eOT`LML^Q@\t-1.32\nHidD@@QInUxV`@@A`REp|Rf@\t-1.32\nsJPYHlQxGh}j@XQ\\f@\t-1.32\nqCb@AIZPLMEnP@\t-1.32\nsOp@DjWkB@@FEbqoHp\t-1.32\nj`aAb@FBdAprRQUJYQIN}UUM@@@@peAFBTtZsnP|\t-1.33\nHg^DIItxdDdLdKbId~rRRqISQBmT@Pt@CCJZ~PH\t-1.33\njhip@@@P\\eKLjo}HvkM@@@EP@@pTRcARUjw`|ap\t-1.33\nHo}DHL^D@HVPvPNPrRRqQJQN[V``jH@FAXporI@\t-1.33\nHo}DHLzD@HNPnP^PrRRqQ[JRUV``Jh@FAXwCrI@\t-1.33\nj`qa@@H@RVYUg^Qg^f``@@@@FF`TXJRmFl{wHD@\t-1.33\nj`aP`@N^`sIIEYdhdmYuUMP@P@CBRLDxIVcVyCp\t-1.33\nHaD@D@|HBDBLBBBJ|FBNBLddqfTuSP@pJDqnHW@\t-1.33\njdi@H@@HMYw`qR[fYf[iZZ@hafX@A`QEoQxbV`\t-1.33\nj`aa`@APYsIIEYdeDd{uUML@@@C@RLDtZso\\aH\t-1.33\nJgRF@EM^RRJJHjkNHRd]gZijjfj`@pyLKae^PX\t-1.33\nJoB@QGTG]ddRtJbReL]a@T@D@@XKBYSRiv\x7FHx\t-1.33\nJoBBQBzG`DiSJkvoS[tDDUTP@XZfES\\Lg[|`@\t-1.33\nj`a``@APYddbltrbR]zjfj@@@AaiFB\\EKQkN|\t-1.33\nJoBe@BX@j[yEEDeEeJw[[USSUT@F@xU]Iv\x7FHt\t-1.33\nHknDqItxdDdLdId~rRRqISPUj`BF@AaeLoHD\t-1.33\nHg]HpMLhdDdLdLddjbRrTkUP@T`@pinF]yE`\t-1.33\nJcBB@E[ddbTQJqbxazQfjZjZj@CAdpfx^IB`\t-1.33\nJcBB@EMddbbbJsbDiGYvjZjjj@CCdpnFUyF`\t-1.33\nHo}BbFvDqpBL{IIJeDedeuZjjjh@XRU\\Lj]n\t-1.33\nJoC@QDAxAJTsMjnmf}T@@@@@FFeS\\Lkiv\x7FH@\t-1.33\nHg|@b@|@eJYUg_eNzB@@@@A`jXS\\Lki|PK@\t-1.33\nHkmHpMLhdDdLdLddjbRreZj@B`@XTwCN|`p\t-1.33\nHg|DbEtO@IRfUWmzSn``bjH@XJfES\\Lg_H@\t-1.33\nKA|PPPrPFPAPGPFRRJrjf@NBQ@q@I@y@yD@\t-1.33\nJoBb@EFNyIHiTlhepv}USUMT@FGPfDtwrG@\t-1.33\nHklHHCbPRPrPvHrRRqISPUj`BI@A`ULn|`P\t-1.33\nHg\\L`HS@\\LddRtRRIwUTE@@@pffxYWSodX\t-1.33\nJoC`@@PJUrnljwV{@AP@@@FBxULJz]orH@\t-1.33\nHklDpMNIAICICIIKDeMAVj@HX@FATrgrA@\t-1.33\nHcL@HHdDdLdMqLddlRTHsU@AP@LJiiW^PH\t-1.33\nJoBd@AonRRJUKJICMoU@ASP`AarXUMp|bp\t-1.33\nHcL@HHdDdLdMbLddlRTHsU@AP@LJiiW^PH\t-1.33\nHklDpJZIAICICIIKLhdmNjZ@@@FACJ{rC@\t-1.33\nHg\\D`HlGCIIEUEDeiuU@PP@LISBhYWSyE`\t-1.33\nHo\x7FD@Nux[IIEYdeDk^jfjeh@XBfEtg[|`P\t-1.33\nHg\\HpJbPRPrPrRRsQIYKmTp@T@CBnFUOdV\t-1.33\nHeT@H@\\HbDbLbLddlRPsU@@@CChSJ[ayD`\t-1.33\nHo~DANW^g^rRQRqJJJSj``Xh@FEIaV\x7FDXp\t-1.33\nHmt@HHdDdLdEbLddlRVFZh@H@FFTr|Sa@\t-1.33\nJoB`@@Ndrnlktqvtlp@T@A`hIaUJz[|c`\t-1.33\nHmt@HHdDdLdIqLddlRTEZh@`@FATtkrA@\t-1.33\nHo~DB@XPgIIETihdk^jjX@@@XKBXUKivx\t-1.33\nHklD`HPGCIHdbhdmNjj@@@FDxULLki|`@\t-1.33\nHo|F@@RUm|bfbbTRlGV``Xf@AabJ\x7FLkm@\t-1.33\nHo~D@NalddUfRbRmzjZ`@@AaJXWBng_H\\\t-1.33\nHcL@PH\\JqLddT\\RR{UT@@@LISBkae]yD@\t-1.33\nHe\\H@JrRQJHxq\\P}HsUMUUP@pYLInGbQH\t-1.33\nHmtFaHSBEP|LxnrRSFJJUZjjh@XYSCqNd\t-1.33\nHklHhCBPJPZPFPVPRYf{\x7Fi`bHj@AaA|cP\t-1.33\nHg^HB@xIrRQRpqIG]UU@@@C@xSBine]Np\t-1.33\nHmTLpHZP\\J\\A\\LddUbtjjj`AarXU\\J|bP\t-1.33\nHiDLpJXT`L`B`LddTZjfd@\\XbAb@RArN@\t-1.33\nJoBF@@IrSJzljUV{UUP@P@FDxULng[|`P\t-1.33\nHedLHJ[h|DbLbBbLddTcuTuP@piLHYyG@\t-1.33\nHmtLbHS@|@gIIEXdiVj`@@AapDwCJ|QL@\t-1.33\nHmtBaHSBCpsb{IILXdiUj`@@A`S\\L|aP\t-1.33\nHmTBHJXUbPRPrPxJrRRsIJjZi@FD]rI@\t-1.33\nHcLL`HS@\\LddQbRr{UPP@@LNinFUwbI`\t-1.33\nHcLHpMbPRPrPrRRqIPcMT@D`@pJfe^PH\t-1.33\nHmTBHJXUbPRPrPytrRRsIJjZi@FD]rI@\t-1.33\nHg\\L@HSLddRtRRIwUTE@@@pffxYWSodX\t-1.33\nHeT@p@BJBFBLdTTRHsPT@@CC`SBxYxeL\t-1.33\nHklH`HAprRQUQQKSjj@`@A`JXUCNgrE@\t-1.33\nHg^L@NakrRQVZJIZ]UMUS@CCdpagSyB`\t-1.33\nsOpNAxPHPQ``aE|FDYIIcjuS@LCEgqF`\t-1.33\nHcLHbMCpBTieV_ehHJH@FBiaTwCJ{r@@\t-1.33\nJoBB@@Ndrnlktqvtlp@T@AaJXURnf\x7FHx\t-1.33\nHmtHPHApIprRHjIJUjh@@@XBBXwCJ|``\t-1.33\nHcvJ`FaLWPBLddjRbRuUU@C@\\JfFUwd\\\t-1.33\nHk^@B@BTjU^ukmLHH@@@A`lHU\\Lki|c@\t-1.33\nHk^D@D@\\bbbbRQImMj`XB@AaU\\ngrI@\t-1.33\nHg\\L@NN|ddTlVVdkUA@S@@pyLInV~PH\t-1.33\nHmTDHJVIAICi@YCIICELZijd@XPwDJP\t-1.33\nHmv@pIbPRPrPrRRqIPUj`B@@XESRoHD\t-1.33\nHiD@XHdDdLdJdNdAdLddltjjh@XPWHX\t-1.33\nHmv@pEbPRPrPrRRqIXYj`@`@XES\\OHT\t-1.33\nHmt@P@\\HbLddqbReZj@@@FGPc\\LkqLH\t-1.33\nHk^D@D@\\bbbbRQImMj`XB@A`WKi|Ri@\t-1.33\nHmv@pIbPRPrPrRRqIPUj`B@@XESCOHT\t-1.33\nHmv@pIbPRPrPrRRqIPUj`B@@XEProHX\t-1.33\nHk^H@IOIIEJeLaWSj`BFH@XLfESCrM@\t-1.33\nHcLH`HAprRQUQIKmUP@@@pELJne]y@`\t-1.33\nHg]L@NvFOIIEYhddnuTuTt@LJSBF~QH\t-1.33\nHcN@bACpBTieU{ihHHh@FDiaTwRn|`@\t-1.33\nHmt@P@\\HqLddqbReZj@@@F@qaMproHP\t-1.33\nHo|H@KrRQRiQHpYj`@jX@FCIaKk|Rf@\t-1.33\nHedHHNbPRPrPYprRRiQUUU@C@bhYyC@\t-1.33\nHg~D@DAdfygUQd{ZB@@@@FCUrz]|QF@\t-1.33\nHmtBbHSB@HKlddNbReUj@@@FAMpsrE@\t-1.33\nHmVBcNaLHOCNKngIILTiFjjh@XUSCJ`\t-1.33\nHmtB`HSBCprRSFIJUZh@@@XTwCJ|SB@\t-1.33\nHet@b@|@gIEEDcSCMAPD@C@Tpj[agd@\t-1.33\nHiDDHJZHaHcH`oCIIKLjij@FEPf\\OHH\t-1.33\nHctBPHZUApGprRQVYSUTtt@LJSB{^PH\t-1.33\nHid@p@bH\\DbDfyWaj@@@FG@aTwCrH@\t-1.33\nHmLB@HSerRQHiJfFZjjj`A`vESBoHd\t-1.33\nHklD@NOIIEKEeiVjB@d@FGIaMr{rA@\t-1.33\nHcLL@HSLddQbRr{UPP@@LNinFUwbI`\t-1.33\nHo|F@@Q]mtfyfYZSZBHXX@FFIk|siL\t-1.33\nHo|F@@SSmtfyVV{iZ@HfX@FFH[|pjd\t-1.33\nHk\\@@DjU^ukmNeZ@B@AaLHUCJz_Ds`\t-1.33\nHklH@ErRQRqJJ]j`Hb@AarXSKi|PY@\t-1.33\nHklH@IrRQRiPhUj`BJ@AarXUMI|P]@\t-1.33\nHmTBHJXUbPRPrPzlrRRsIJjZi@Gb]H\t-1.33\nHgnD@NalddUfbreUMUT@LASBe]N~PH\t-1.33\nHaL@@DjYtkBqjynjjjj@FCABDw\\SJ@\t-1.33\nHklD@NwIIEKEeiVjB@h@FGIaMrgrA@\t-1.33\nHknBAHAEvISdfyW[xV`@f`@XDUMwHL\t-1.33\nHkL@bLhLyJgnYzjjj`AaXPfES\\Lki`\t-1.33\nHeTL`HS@|LdbLRPsU@@@CA`inF^Hf@\t-1.33\nHeTDbHPO@IrRHqICMT@@@LFrfxYx`H\t-1.33\nHid@p@qH|DqDfyWaj@@@FG@aTwCrH@\t-1.33\nHcM@@@wIHhdd]JuAPD@C@Tpj[agdZ\t-1.33\nHko@@@`Tke]e[f@Bj`@XCaTtki|b@\t-1.33\nHeTDPHP@bYCIHXdmpk@A@@pHj[nP@\t-1.33\nHiDLHJXXdDdLdNBlddlrjfh@XQwHD\t-1.33\nHctDPJEYCYCIIEFiiUMMP@pILInQH\t-1.33\nHmTLRHS@BN\\L{IIJdiEjjh@XLULLj\t-1.33\nHkND@NalddUfRbjijj@F@ia]Jz_HD\t-1.33\nHiDLHJXXdDdLdN]Lddlrjfh@XQwHD\t-1.33\nHeT@P@bH\\Df^UFZh@@@X\\BTwCODc@\t-1.33\nHklD@@qJYVu}NjhH@@FDiS\\Lki|b@\t-1.33\nHkLB@NFUrRQRqSFjifh@XMBXVgrE@\t-1.33\nHmtB@HRUrRQHiJfjjjh@XMaTtkqND\t-1.33\nHiDLpJXXbDbLbLddlrjfd@XYBYrN@\t-1.33\nHmt@`NqLddTlVeZhH@@FCIaMr|PY@\t-1.33\nHmt@`EqLddTjVFZh@H@FCIaTr|Sa@\t-1.33\nHmVLB@ZUB\\ddUfTjji`AatIaUr|a`\t-1.33\nHmVB`FaLT@cIIJiDUjjd@XUaMp|bP\t-1.33\nHiFDHNihBDdLdBdLddTgjeh@XQwHD\t-1.33\nHiDDpJzHaHcHcIIJeJjf@FAPfErA@\t-1.33\nHmv@`JVYrRQRiHYj`@`@XLfDtkrN@\t-1.33\nHefDpFFXdDdLdLddjfeUTp@prfgdD\t-1.33\nHmT@bLhLyJgnVjjj@FBaBXU\\LkrF@\t-1.33\nHedLpJFXdDdLdLddlReUTp@pSiyA@\t-1.33\nHk\\D@@iIYgU^GSXH@@@@XLSRngqHh\t-1.33\nHctB`HZUGprRQVYSUTtt@LJSB{^PH\t-1.33\nHmTH`HAprRIIPjjje@FDiaTwCJ|`@\t-1.33\nHcLD@NwIIEKEeJuPPD@CCdpfx]yB`\t-1.33\nKAxXPTwQxIDYDEDIUMUSPAabXWD[`\t-1.33\nHedLPH[`\\J|LddUbuUUP@pYLJagd\\\t-1.33\nHmTLPHeP\\JBDjeUjjjT@XLfDwCrJ@\t-1.33\nHcM@@@wIHhdd]JuAPD@CBTpj[agP\t-1.33\nHcLH@NrRQRqYRmTDA@@pyLInW^PH\t-1.33\nHkLFb@RfgRhByIgeYfjjY`A`VDi`\t-1.33\nHctB`HY]AprRQVYJUTwL@LLSByF`\t-1.33\nHid@P@BJBDie_ahH@@FCAaMp|QJ@\t-1.33\nHeT@`@|LdbLRPsU@@@CC`bfxYxbX\t-1.33\nHmtD`AdOAJYUgedHF@@XLfDwKq@d\t-1.33\nHeTD`HDGCIIEXituTuP@piLKiy@`\t-1.33\nHiDLHJXXdDdLdNkLddlrjfh@^Ip`\t-1.33\nHcvL@NamrRQVYQUTuR@LFSBxUyD`\t-1.33\nHcvB@JFUwIIEJhiUULp@pZDpjgdZ\t-1.33\nHeTH`HAprRSPiCMT@@@LNpj[agdP\t-1.33\nHmtH`HApRi[WeZhH@@F@xUMproH@\t-1.33\nHetL@HR\\ddRJULLuUUT@LBpj[b\\H\t-1.33\nHefDpFjXdDdLdLddltUTuH@p`^Qp\t-1.33\nHedDjAeICI@iBiAiB^rRQR^UUS@B\t-1.33\nHcND@JADfUyU]Zj@@@FGEWCJ{rL@\t-1.33\nHmTH`HAprRQIIVjji@F@iaMproHh\t-1.33\nHmVH`DTGCIIEHizjjd@XMaTwSrA@\t-1.33\nHiDLPHS@BB\\LdaTRVjh@XES\\OD@`\t-1.33\nHedLPHZP\\A|LddUfUUMH@pILKnPH\t-1.33\nHmw@@@`Tke]Vy`@j@A`vESRoD`P\t-1.33\nHiFHb@E``IrRQUJjjPA`tIaTwHx\t-1.33\nHedJb@RfDj@nRYyyjjX@XYaSrF@\t-1.33\nHcuB@NFFW\\ddUfReULs@CCDpnQh\t-1.33\nHmv@@JrRQRiHYj`@`@XLfDtkrN@\t-1.33\nHmtD@@qJY{VUjh@@@X\\eMproDc@\t-1.33\nHctL@NF\\ddTlVuUSM@CAhSBW^Pp\t-1.33\nHmtD@@yJUe^Uj``@@XCATwCJ|a@\t-1.33\nHiDDpJzIAICICIIJeJjf@FDErA@\t-1.33\nHcLB@@RUR[fVQuhHF@@XHb|JnGP\t-1.33\nHcLB@@Q]R[e[neh@a`@XHf|HjzP\t-1.33\nHcLB@@Q]R[e]nEh@I`@XHf|Hj[`\t-1.33\nKAxA`@xPD\\DYIHjjjh@pZDpj[d\\\t-1.33\nHidD`HRgCIIEYLJjjh@XUaMp|a@\t-1.33\nHiFDpFhXdDdLdLddlrjfd@XPwHx\t-1.33\nHmVL@JFUrRQRjJjjY@FCPfET|c`\t-1.33\nHmvD@LADfueYUj`@@A`vMproDP`\t-1.33\nHmTH`DAprRQRKrjjf@FCXUMr|bP\t-1.33\nHmNH@BAIfUmaeX@@@@A`pXproHx\t-1.33\nHmVD@Aa\\ddUbajjjPAarXUMp|bP\t-1.33\nKAxX`Ia@tQDYIIcJjh@phHinxfD\t-1.33\nsGQBK@aPF`C@IUMT`NLdCHAPNR@\t-1.33\nsGQLJhCPA`Djfj`GFRAd@hDI^R@\t-1.33\nHcL@@LddTjTPsU@AP@LJSBW^YSR\t-1.33\nHmvD@DClbbbRJIfjVj@FEYSCOHT\t-1.33\nKAxX`Pf@xTxYIHkJjh@pHj[nHf@\t-1.33\nHmLH@@RYVuiiV@@@@@XLe\\Lkq@p\t-1.33\nHmtH@ErRQRiXYj`@`@X\\fTwBoHH\t-1.33\nHiDDPNDGA`cIIEUJje@FEPfEWHX\t-1.33\nHiDLPJxP\\FBLddUTjjT@XEBXWHX\t-1.33\nHiDL`HS@\\LddQTjih@XTUMp|QL@\t-1.33\nKAxY`DwQDIDYDYIIUJjX@prDsd\\\t-1.33\nHiDDPHXGBoCIIETjjj@FEIa\\OHh\t-1.33\nHmtB@HPYrRQHzZfjjfh@XEaToHX\t-1.33\nHiDDPFxGBoCIIEYjjZ@FEPfDOHh\t-1.33\nHid@b@|@eJYWxZB@@AarXUMp|`@\t-1.33\nHeTH`LCDRVyTYi`@@A`pQS\\OHd\t-1.33\nHeU@@@eJYW~F``H@FCIaTw\\PI@\t-1.33\nHmtD@@eIfUTUZBA@@XMaUpkrF@\t-1.33\nHaD@P@bFbDfUjz@H@AaPIc]rJ@\t-1.33\nsGXCJJAPF`C@CdjfjpGFRAd@h@\t-1.33\nHmUL@NFFWIIEYdjjYd@XXfErI@\t-1.33\nKAxQ`TdQdPTPeTuUU@FEIaMwHh\t-1.33\nHeV@@IrRQRiCMT@@@LJSBinIp`\t-1.33\nHmTL`HYP\\LddUfRjinPAabXWHd\t-1.33\nHctB@HY]rRQVYJUTwL@LLSByF`\t-1.33\nHmTB@NFUrRQRqRjif@FAPfEqAT\t-1.33\nHid@`@|DiyWaj@@@FCPUMp|PD@\t-1.33\nHiDD`HPGCIHdcJjj@FCXUMp|`@\t-1.33\nHmtD@@QIee^UZ``@@XLU\\LkrF@\t-1.33\nHidD`@RJAInUxZ`@@A`pHULOHx\t-1.33\nHeTD@@IJUmQfj@@@FCQS\\L|QB@\t-1.33\nHmvH@AAIYWYnh@J`@X\\FESRoH`\t-1.33\nHidH`H@HRme^Eh@@@XLaTwCr@@\t-1.33\nHiFL`FaL@HrRRjQZj`A`VEp|a`\t-1.33\nHidH`HAprRQVKajij@FEIa\\OHX\t-1.33\nHedD`HDGCIIEXiUTr@LJSBz^PH\t-1.33\nKAxX`Pw@xUxYIHkJjX@pILJnQp\t-1.33\nHmVL@NaerRQVYJjfi@FEIa\\OHd\t-1.33\nHmVD@NalddUfTjij`A`rXWRoHD\t-1.33\nsNqBbJBRBdMHCcNRRUUU@LEWrD\t-1.33\nHedH`DAprRQRKuUU@CAlJfz^PH\t-1.33\nHmVB@NaiWIIEYeJjZX@XDfEwHT\t-1.33\nHiD@bLhLyJgmjjh@X\\DIa\\ODi`\t-1.33\nHiD@bLhLyJgyjjh@XBDHUMp|c@\t-1.33\nHmtL@@SDfUmYUj`@@A`S\\L|Re@\t-1.33\nHiDDPNDGA`cIIEUJke@FFIa\\a`\t-1.33\nHiDH`HAprRIIFjjPA`rYS\\OD@`\t-1.33\nHedD`HdGCIIEXmUSR@LJSB[nPH\t-1.33\nHiDL`HXP\\LddUfjjX@XDfEwDXP\t-1.33\nHiDL`HxP\\LddUTjih@XDfEWDxP\t-1.33\nHcvD@AalddUffeUMU@C@TpnFUt\t-1.33\nHeTH@@RUYTYj`@@A`HQeMpsrD@\t-1.33\nHmTJ@H[iWIIEYeJjZX@XXfErE@\t-1.33\nHid@`@\\Die_ahD@@FGIaTwCr@@\t-1.33\nHidH`DBHR[e^FX@@@XDATOD[`\t-1.33\nHiDLpJXXdDdLdLddlrjfd@^Qp\t-1.33\nHiDBb@RnJ`Kdf]Yji`A`fCrB@\t-1.33\nHig@@@idiUWajjj@FDaBXUMp`\t-1.33\nKAxHPTtRBRFRGNfRRVZjZ@OHx\t-1.33\nHeTL@@SDf^UFVh@@@XES\\ODrP\t-1.33\nHiDH`HAprRQURjf`AaRXWCrJ@\t-1.33\nHedL@NF\\ddTlUUSH@pJDpnHp`\t-1.33\nKAx@`@xQDYIIcJjh@pjDinxfD\t-1.33\nKAxH`MpNEAFRRJrje@LBaLKdT\t-1.33\nKAxH`TpND^FRRJNjZ@LBSB{dP\t-1.33\nHaDH`@b`RVU[j@@@FEXUMwDB@\t-1.33\nKAxI`UtRBRFRFRRUJji@LHKdL\t-1.33\nHaDH`HAprRQVMuUU@CBdpf{dT\t-1.33\nHiUH@HPDiUWBxZVeh@XIp|Rf@\t-1.33\nHiFH`DDGAJiijjh@XLfES]rA@\t-1.33\nHiDH`HAprRQVJjiPAaRXWCrF@\t-1.33\nKAxHPTtRBRFRGUfRRVZjZ@OHx\t-1.33\nKAx@`PD\\DYIHjjjh@pZDpj[d\\\t-1.33\nHefD@Nb\\ddUTuUUH@pYLJf{dB\t-1.33\nKA|I@YBAxYICDjjh@phBinxdH\t-1.33\nHefL@NairRQVYUTt`C@dpny@`\t-1.33\nHiD@`F\\LddUTjjh@X]BXU\\OHX\t-1.33\nHiE@`HZoCIIEUJij@FAIgCqBh\t-1.33\nKAx@`AxPDYIIcFjh@pjDinxfD\t-1.33\nsNpbJyDJHtP_CIIKJi`FFbwDV\t-1.33\nHiFH@HGIIEKjjj@FCIaUp|a`\t-1.33\nHiDD`NDGCIIEUJkf@FFIa\\`P\t-1.33\nHidD@@EIYW[f@B@AaTXUMrA@\t-1.33\nHidH@@RYm^Fh@@@X\\FES\\OH`\t-1.33\nHefL@L@YRUeVjjh@XRDHUMpr\t-1.33\nHid@@DjUfaBB`@FCPfMp|Pj@\t-1.33\nHidD@@EIYW[j@B@A`pQaTwHD\t-1.33\nHmTL@HY\\ddUfRjinPAabXWHd\t-1.33\nHedD@F{IIEYeUST@LJSBF^Q@\t-1.33\nHedB@HXYrRQVZUTs@CCDpnQH\t-1.33\nsNpB@DQppPPaJYjj`FEDU_Eb\t-1.33\nKA|A@TCaddbjjj`CAhSB[nQP\t-1.33\nKAzA@QsAFRRJrjf@LJaLInQp\t-1.33\nKAxY@Pf@DYIIUEjh@pKB[nQP\t-1.33\nHiFH`APGAJiijjh@XUaTw\\`P\t-1.33\nKAxI@QpNFRRJjjj@LJSBinQp\t-1.33\nHiFD@Jx\\ddT\\jjX@XUBXP|b`\t-1.33\nHiFH@AcIIEXjjj@FCIaUp|a`\t-1.33\nsNxBB@bRBdMHYIIUUT@ppkyB\t-1.33\nHaF@B@BTjWzXHB@AaTIaUrN@\t-1.33\nsJXLHhCPA`H~j@\\YHFPB`\\d@\t-1.33\nHiDH`HApRjUZjj@FCIaMp|b`\t-1.33\nKAxI@QpNFRRJjjf@LBSB[bUp\t-1.33\nKAxI@QpNFRRJjjf@LBSBkbMp\t-1.33\nKAxI@P`NBUNuTt@XUaTw\\PD@\t-1.33\nKAzQ@Qs@xYIHkJjX@pJDpnQp\t-1.33\nHedB@H[irRQVYUTt`CCDpnPH\t-1.33\nKA|P@QvRRJjjj@LFSBinyD@\t-1.33\nKAxX@AaYHhdZjh@pjDinyA@\t-1.33\nHaF@@@Rfu[j@@@FC@fES\\c`\t-1.33\nHidH@@RYm^Eh@@@XUaTp|c`\t-1.33\nHaDH@@RVU[j@@@FCAFTw\\``\t-1.33\nHiDD@J{IIETjjj@FAPfEqFD\t-1.33\nHiDL@JX\\ddTZjfd@XXfErN@\t-1.33\nHaf@@@RiUkfzjjh@X]BXUMp\t-1.33\nHiED@NFFrRQVZjfPAabXWHD\t-1.33\nHiDD@NGIIEJjje@FAPfEqJX\t-1.33\nKAxQ@\\CaddbjjjPCBhSBkdL\t-1.33\nHiDL@HX\\ddUfjid@XXfErN@\t-1.33\nKAz@@QvRRJjjj@LFaLJfyG@\t-1.33\nKA|I@]C@xYIHkJjX@pqLKd\\\t-1.33\nHaF@@@RnU[fjj@FCIaTw\\b@\t-1.33\nHigL@Ds`XTfUfn`BH@FF@p`\t-1.33\nHigL@Ds`XTfUfnZif@GfIg@\t-1.33\nKAxQ@PCaddblji`C@dpnyC@\t-1.33\nHaDD@@yIe^f`@`@XDBUwDp`\t-1.33\nHaDH@@RYWifjj@FEIaTwHx\t-1.33\nHaDH@@RVU[f@@@FEQeMwHH\t-1.33\nKAz@@ArTjmUT@X\\DIaUwHX\t-1.33\nKAxH@UvRRJjjj@LBaLKbMp\t-1.33\nHiDL@HSDjeVjj`A`QTw\\`P\t-1.33\nHiDD@H[IIEYjj[@FFIa\\`P\t-1.33\nKA|A@PC`eTsUU@FEIaTwHx\t-1.33\nKAxA@@xYIHjjkh@pILInQp\t-1.33\nsNtDHpxTHrRQVjTA`Uc^Q`\t-1.33\nKAxH@QvRRJjjj@LJSBknPp\t-1.33\nKA|P@]FRRJjjj@LJSBknPp\t-1.33\nHaD@@DjUZxHD@A`tHUMwHp\t-1.33\nsJPJaPRPTai@r@zSGuPCrP\t-1.33\nKA|X@XB\\drzuU@FFXw\\Pj@\t-1.33\nsNxLGIARFdLddjjj@XQ|Qh\t-1.33\nKAxP@@djkUU@FG@fES]rH@\t-1.33\nKAxH@ArRjmUT@XLBXU]qHX\t-1.33\nHaF@@@RYe[hB@@FA@UMqLx\t-1.33\nHiDH@@RYuVjj@FCIaTw\\`P\t-1.33\nsOpIAVBTfUk`@@FEVM_H@\t-1.33\nHiDB@@QnRY^vjZ@FBDOHp\t-1.33\nsNpY@jsPGdf^Zj@XKGbk@\t-1.33\nsNpDADQpRYzjhAaPcWqS@\t-1.33\nsNpD@xTJrRQVjhAaXl[rL\t-1.33\nsJQBBGBQBbMDQ}T@ptVyB\t-1.33\nsGPL@DQppPeKUT@pHQoEL\t-1.33\nsFqlAcJATEhDiTvjhAyhj\t-1.33\nsNpD@xPHrRQVjhAaXl[rL\t-1.33\nKAxA@@xYIHjjkl@pqLKd\\\t-1.33\nsNyLGYHJPtaddeeUHCqU`\t-1.33\nsNpdE`tRHRkzjhA`XZ~HX\t-1.33\nsNpyhlZqVGkszOvj`FBV@\t-1.33\nsNqhHlGCIHcJj`FFM_LE`\t-1.33\nsNqhHlOCIHcJj`FAAkxe`\t-1.33\nKA|@@@djkuU@FEIaTwHx\t-1.33\nsNxHHGCIIEZj`FEVM_I@\t-1.33\nsNqhHlKCIHcJj`FFM_Dl\t-1.33\nsOpHAbILkW@@@LBEgqF`\t-1.33\nsNpH@xYIDYUT@phakxe`\t-1.33\nsJPLADQpTPdwU@LBEcrP\t-1.33\nsGXDHGByBUSUPC@kF|d@\t-1.33\nsGPDADQpRUjj@XTKF|d@\t-1.33\nsNqhHjGCIHcJi`FBsx``\t-1.33\nsJPlLQxRHTQGtpCAQ\\a@\t-1.33\nsGQhHlGCIIKUPCAF|tV@\t-1.33\nsNxHHpcIIEZjPFEbq_IP\t-1.33\nsNyHHpxYIHkUR@pJqoI@\t-1.33\nsGQdEbOBQFRRFZ`FDgDZ\t-1.33\nsGXhMDOCIHUUPCC@wfbp\t-1.33\nsOxA@IRi^lH@@XVKF|c@\t-1.33\nsNpIEPKdkejj@XFJofFH\t-1.33\nsNpIMP[dj_jj@XTQE|Vh\t-1.33\nsGXDHGBxBUSUPC@kF|d@\t-1.33\nsGXDHGBzBUSUPC@kF|d@\t-1.33\nKAzD@XPHwIMkMLpAxb\\\t-1.33\nsNqHHGCIIEZjPFAVMyF\t-1.33\nsOpHAHILkW@@@LLc^KL\t-1.33\nsNpHADIJkUT@pXbqoHp\t-1.33\nsNy@iYMyJijjPFFVOHp\t-1.33\nsGXLKIARFdLddmU@LDZ\t-1.33\nsNqhAVjAJYjj`FFfOEV\t-1.33\nsGQi@jZ@|dsmT@pfxcP\t-1.33\nsNpIEPKdkejj@X\\QXu`\t-1.33\nsNpH@xIRkUT@p\\VM_H@\t-1.33\nsGPH@xYIDZi@XVKF|`@\t-1.33\nsGPD@xTJRjZj@XFKGdh\t-1.33\nsNxHGGCIIEZjpFFVOI@\t-1.33\nsNphIPxYIDYUL@prsy@\t-1.33\nsGPhH`xYIHZj@XKGfbh\t-1.33\npnH@BTlzemUR@X\\QXu`\t-1.33\nsGXDHGBaBUSUHCCKGdh\t-1.33\nsNyHEAxIWKUT@pNM_DH\t-1.33\nsNyHEAxIR}UT@pNM_DD\t-1.33\nsFxHHOAIeMjj@XEXwd@\t-1.33\nsGPM@xRPT`Nc}U@LMcP\t-1.33\nsNtHHpxYIHkUJ@prqyF\t-1.33\nsGQ`HmddejhA`c^ZK@\t-1.33\nsNq@KddbmUPC@qX|c@\t-1.33\nsGY@iYMyJijhAaecrP\t-1.33\nsGPhAUPISMU@LML^IT\t-1.33\nsGPhHaXISuU@LMc^HH\t-1.33\nqCcRAZTDyIj`LINXK@\t-1.33\nsGPhCQbILuS@LLI^S@\t-1.33\nsJQDDH`qBS\\t@pPOI`\t-1.33\nsJPIAxBTiZhA`Xl^P@\t-1.33\nsNq`AbeLuUPC@qU|VH\t-1.33\nsJPBHxJPt`YBOj`Gd`\t-1.33\nsNphH`xIUKUT@pvkyB\t-1.33\nsGQHHGAJejhAaecqB`\t-1.33\nsJPdE`DPHRie`FDgDB\t-1.33\nsNy`LDtfuZj@X[U|RH\t-1.33\nsGQHBLQIejXAaaMqJ`\t-1.33\nsJQdEbOBQD_M@LINKD\t-1.33\nsOp`Jtjeqje`FBqxh`\t-1.33\nsGPhCQbILuS@LDIqZ`\t-1.33\nsNt@H|ddUje@XYX|c@\t-1.33\nsJYHEAxIVuPCAX|pb@\t-1.33\nsGXHHOAIejhA`Uc^P@\t-1.33\nsJPIEPKdkZhA`h^XK@\t-1.33\nsNqhHlOAJeZj`FAAk@\t-1.33\nsNx@GddbmUPCBqXodh\t-1.33\nsNpH@xIUMUT@pjqkyH\t-1.33\nsGPhH`xISuU@LMc^HH\t-1.33\nsNq`@jdrkTpCAE|f@\t-1.33\nsKRAADQJTnKT`OLE`\t-1.33\nsNx`JDdrkUPCCFodp\t-1.33\nsNy@DDeeZj@XZX|UX\t-1.33\nsGP`@TfVj`FEDVOIP\t-1.33\nsJPhH`DIVmPCAX|`@\t-1.33\nsNp`@dfUZf@X[F|c@\t-1.33\nsJPH@xISuPCCSGbB@\t-1.33\nsNp`@df^Zj@X[U|a@\t-1.33\nsGPH@xIUMT`LBl[rP\t-1.33\nsGPhHPxISuS@LDkr@\t-1.33\nqC`HAps`dmPFBbxa`\t-1.33\nqC`HBHTPduPFFBwI@\t-1.33\nsNx@GddbmUXCCKGd`\t-1.33\nqCcRQXV@zOTAaAsQX\t-1.33\nsFy@LDigVfhAaEqF`\t-1.33\nsJPLAHJPL`dwS@OI`\t-1.33\nsJPDAxPHcvhAaIsKD\t-1.33\nsGPH@xIUMT`LCEcrT\t-1.33\nsNu`LPfdvkSHCqJ`\t-1.33\nsJPXHlPjQzt@pfyB\t-1.33\nsNqP@mVdssTpCqY`\t-1.33\nsGQ@JeTuT@pLVOIP\t-1.33\nsGY@LDizj`FFQoI@\t-1.33\nsGP`Adinj`FFQoI@\t-1.33\nqCpPP^BRu@XI[bD@\t-1.33\nqCqPZH^D^hCBCfbp\t-1.33\nsGY@DDeYj`FFqoED\t-1.33\nsJQIH@`SGmPC@aX`\t-1.33\nqCpRPA@eIj`LDmr@\t-1.33\nqCpRP^@eIj`LDmr@\t-1.33\nqCcPQXJd]XCB[d@\t-1.33\nsJQ@@eKU@LML^Q@\t-1.33\nsJP@DkVhA`Pl^R@\t-1.33\nqCbPXUbRt`XHSdP\t-1.33\nsGPP@mTf]jPGbq@\t-1.33\nqC`PBHRZhCCA[d`\t-1.33\nqCpHXRBdDfj@|Tp\t-1.33\nsBP@DiVj`FBFxh`\t-1.33\nsJPXHlQiQzl@|a@\t-1.33\nsJTILPyAdiZ|Ay@\t-1.33\nsJPHIxQ}T@prqyH\t-1.33\nqC`R@HDqz`LBHl\t-1.33\nsJP@DjVhAaecrP\t-1.33\nsJT`LPdfvdAxdP\t-1.33\nsGP`ATeUnPGba@\t-1.33\nsJPYHlQiGh}V@P\t-1.33\nsJPYHlPZGh}V@P\t-1.33\nqCr@XISRA`enR@\t-1.33\nQMA@HoAIXFD\\Y@\t-1.33\nQMACp_AIhFE\\Q@\t-1.33\nqC`@ISJAaaErX\t-1.33\nQMJd|BTf`XL|`\t-1.33\nQMFIDjN`XQqd\t-1.33\nQMFajByIhGfR\t-1.33\nqCh@CIRrAxe`\t-1.33\nQMFiK@zN`^YH\t-1.33\nRFQALXOD`\t-1.33\n`IGPCr@\t-1.33\nHiT`@@rnRfUjEnBB`PA`bMqLD\t-1.33\nsGY@DDf]j`FBVxcP\t-1.34\nQMdXZWde`^T\t-1.34\nRFDDaFCr`\t-1.34\nHev@@@rRIIRus]UUUP@pFDJfxYyF@\t-1.35\nHaE@@@aJyUnX@@@XEeMwD``\t-1.35\nsOpHAbILkW@@@LJEb~R`\t-1.35\nsKX@@eKcUPC@bX|b@\t-1.35\nsGP`ATf]jPFDwDb\t-1.35\nHcND@LCTeme^UZh@H@F@iaMpsoH`\t-1.35\nHiT@@LddTQQnFjjj@FGPfESCrN@\t-1.35\nHeT@@DjU]k``b`@XMBXUMqAd\t-1.35\nsKP`@Tixjj@XZK\\a@\t-1.35\nsJX@@dmU@LBEcrP\t-1.35\nQMA@HPaIhFE\\Q@\t-1.35\nQMBBHRZA`cr`\t-1.35\nsJX`BDdvu@LInID\t-1.35\nHeTLbHS@BL{IIKDdLkP@@@pragbMp\t-1.35\nsOq@@drm\\@@@pHM_Dl\t-1.35\nHidH@@RYfVF@b@@XXAMsJxP\t-1.35\nsGP@DiVj`FADMxe`\t-1.35\nsJPhH`DYIBm@LInHD\t-1.35\nsJQhHlOAJmj@XS\\PH\t-1.36\nqCaPQCpRfhCsAX\t-1.36\nQMJH|Df`^H`\t-1.37\nHeTB@@xYRfUVfjjj`AatES\\L|QL@\t-1.38\nsGP@DkUj`FEDVOIP\t-1.39\nsFt@AdiTt@@AaIsHt\t-1.39\nqCaPQCpRfhCBKbF@\t-1.39\nHg}B@DpAV|bbbRbrK]imUMMU@CAlJnN~IN`\t-1.4\nHcnH@LAIYe_x^fjjjj@FDhUMprn|PH@\t-1.4\nHeTD@@QIVUnEjjj@FCXS\\L|RJ@\t-1.4\nHidH@@rJJIEn`HH@FA@UMqLD\t-1.4\nKAxP@@dsjuU@FEIaTwHx\t-1.4\nKAxH@@bSJkTt@XEaTwHx\t-1.4\nsOx@@drm]UT@pXbM_I`\t-1.4\nsOq`Afdlm[UT@pbyhZ\t-1.4\nsOp`@dfUMZj`FFqoHp\t-1.4\nsJPHAVIJuPC@bK\\a@\t-1.4\nsGPhLQDIK]M@LDKrP\t-1.4\nsFy@LDi_FfhA`d^JT\t-1.4\nsJQHBGAJ^i@XJKbF@\t-1.4\nsKY@LDi\\ZZ@XQ\\TH\t-1.4\nqC`PCDRVhCCB[dP\t-1.4\nsGQ`@bdwML@pbyJ\t-1.4\nqC`PCDRZhCCBKdp\t-1.4\nQMaDbKpRZAaGFP\t-1.4\nqC`@IRtAa`mrP\t-1.4\nQMbh|BTf`XSqH\t-1.4\nqCr@XIKVAxa@\t-1.4\nRFTEPQP|h\t-1.4\nRFTPbQP|`\t-1.4\nsOq@@drm\\@@@ppUylV\t-1.4\nHidH@@RUe^Fh@@@XLATwCqHP\t-1.4\nHifDAHAHeNR[e^Eh@@@XHW\\rfD\t-1.41\nHidB@@kaReYrZjjh@X]FES\\OHP\t-1.41\nHeT@@DjU_k``b`@XCBXUMp|bP\t-1.41\nsGQhHlOAJmZhA`c^P@\t-1.41\nsOq@@drm\\@@@prsy`Z\t-1.41\nQMFIKBN`^YH\t-1.41\nsNy@DDeUZj@XEXwbc@\t-1.41\nHmtJ@@siUJYn~ajjjh@XCBDwCJ|SJ@\t-1.41\nqCaPQCpRmhCqC@\t-1.41\nsGX`LDdvmT@pVODj\t-1.42\nqC`XBPTaiAIj`OI@\t-1.42\nsNqiHl@c]ddeRuPCAF|c@\t-1.43\nQMRIOBN`^YH\t-1.43\nsGQ@@djmT@prqxiP\t-1.43\nHeT@H@bBbFbAbDfYnzXHb@@XDALODzP\t-1.44\nHif@`D@HRUe^EX@@@XTATw\\`P\t-1.44\nKAxH@@bSZsUT@XTaTw\\c@\t-1.44\nsNy@aAL{IILZj`FAVMyF\t-1.44\nsGY@aALyJkjhAaecrT\t-1.44\nsNp`@dfUZf@XHwbs@\t-1.44\nsJY@aALzOj`FBVyB\t-1.44\nqC`@IVtAa`mrP\t-1.44\nQMPBchFBWI@\t-1.44\nsJP`@TeZhA`QL^Q@\t-1.45\nsJQiHlOC\\eVu@ODB\t-1.45\nsJT@@TeZhA`QEnP`\t-1.46\nqC`@IWtA`hnS@\t-1.46\n`IoQHFD\t-1.46\nHidD@@QInUxV`@@A`RES\\Sa@\t-1.46\nHet@@DjYUX^d@@@@AarXUMp|bP\t-1.46\nqCb@AIZ`LLInQ@\t-1.46\nsOpH@DILkW@@@LJlZ~P@\t-1.46\nj`iA`@@V|eLsJnmARMiu@A@DT@@LFDYqQg\\pJw`\t-1.47\nJoBAQDIg@DYvRRVJKIIRmnmA@@@@AaS]ioqAl\t-1.47\nJoBAQDIc`DYvRRVIJYKCIvm@@@P@AaULJoqML\t-1.47\nHknJcEaLtp|LyYOdj~UvFVh@I`@XES\\OH@\t-1.47\nJobB@@VeLsJntLgkt@D@Q@@FCDwJ[|p]l\t-1.47\nHmL`B@aBB\\dRabRpiUj`@P@XTwCJ|PL@\t-1.47\nHk^@@@rRJFIQDYtz`@@@@F@ie\\Lz_HT\t-1.47\nHmtBbHSBCpKlddqbReVj@@@FAMpsqLT\t-1.47\nHcNBAHAEvISdfyW[aZ@BX@FAES]rM@\t-1.47\nHknJ@D@ae\\bbbRtJifjiZh@XYc[rC@\t-1.47\nHcLBbHSBCpKdjm{U]Zj@@@FA\\LkqFt\t-1.47\nHid@p@bFbAbDfUfn`BH@FE@fLOHx\t-1.47\nHeVD`Aa@BLdabRgRl@P@C@bkix`B\t-1.47\nHid@P@bH\\Df[Waj@@@FGAaTwCrH@\t-1.47\nHcNJ@LANF\\bbTRbILuTmT@LH[bKh\t-1.47\nHmMH@LhDigm\\jUid@H@FAMpsqDT\t-1.47\nHeT@`@\\DieUzZBA@@XBfES\\L|`@\t-1.47\nHmtH@@RYeY[hBBh@FGAaTLkrN@\t-1.47\nHifDAHAHeNR[e^Eh@@@XXwCqBh\t-1.47\nHmvJ@LANFTfVVRYjiZ`AaC\\RU@\t-1.47\nHeTH@@RYe\\YjB@@AapES\\L|RL@\t-1.47\nHcLH@@RYeYVz@`j`@X\\FEProHt\t-1.47\nHaD@b@|@eJ[Unh@@@XLfES]r@@\t-1.47\nHidH`ACDRYWZZ@BP@XTBXU\\c`\t-1.47\nHiTH@@RgeXSaj@B@A`tES\\OHP\t-1.47\nHaDH`HApRnU[j@@@FCQaTw\\`@\t-1.47\nHeTD@@YIfUqehH@@FEEWCODq`\t-1.47\nHid@`@qDee]nh@H@FCAFES\\`P\t-1.47\nHid@@LddRL[jjj`A`tIa\\ODi`\t-1.47\nKA|Y@]BX@QddeRVj`C@lJfyG@\t-1.47\nHeTD@@QIemQej@@@FAESSqND\t-1.47\nHifH@AAJ[W[j@B@AaRXUMrA@\t-1.47\nHif@@@RfU~F``@@X\\BXS\\OHh\t-1.47\nHif@@@RUe^Fh@@@X\\DHUMwHD\t-1.47\nHidH@@RUe^Fh@@@X\\DHUMwHD\t-1.47\nHaD@P@dNdDfUZZ@B@AabDwHp\t-1.47\nHif@@@RYWZZ@B`@XLBXUCrN@\t-1.47\nHeVB@LANEIeeRYjiZ@FDMqJd\t-1.47\nsJQL@hCPA`DijhAqd`Y@JArP\t-1.47\nHaDH@@RVU[f@@@FEQaUwHX\t-1.47\nHaF@@@Re]J`@h@FEPfDwHx\t-1.47\nHaD@@DjWzXHB@A`TYW\\QB@\t-1.47\nHaFL@LAFRYUJfjZ@FDUqLx\t-1.47\nKAxD@@c\\dwLuS@FFIg\\b`\t-1.47\nKAxH@@rTzmST@XDfEwDb`\t-1.47\nKA|P@HBSJsTt@XTfTw\\``\t-1.47\nqC`XBHTQhAIj`NIdBBByH\t-1.47\nsOpHAxILkWUU@LGEcWr@\t-1.47\nsGQHHGCIHcUPC@kF|`@\t-1.47\nsOx@@drm]UT@pXbqoHp\t-1.47\nsGQHHGCIHcUPCCHwbF@\t-1.47\nsNqHHGCIHcJi`FFV_DJ\t-1.47\nsGPH@DIJmU@LJHl^R`\t-1.47\nsNp`Jtjejj@XVXu|b@\t-1.47\nsJPDAbGDRUj`FADqyD\t-1.47\nsGXA@IrRHuR@plVMy@\t-1.47\nsGPhCQDILmR`LDIqK@\t-1.47\nsJQDDGBQD_U@LML^Q@\t-1.47\nsNy`LDtfuZi@XKGbU@\t-1.47\nsNx@@djoUPC@kF|c@\t-1.47\nsNp`@dfvZj@XEZodH\t-1.47\nqC`HBHtPdmPFFDwH`\t-1.47\nsGQHDHaInfhAa`[rX\t-1.47\nsNq@@dssUPC@hu|f@\t-1.47\nsJPHAXIRuPC@qX|`@\t-1.47\nsGPP`cUuyInZXA@\t-1.47\nsJQ@@eMU@LLl^R@\t-1.47\nsGQ@@dsMT@prMyL\t-1.47\nsJQ@@dmU@LBHmrD\t-1.47\nQMCCDoAqDf`XH|h\t-1.47\nsGT@ATeWfpGbV@\t-1.47\nQMABHWAIhFBWI@\t-1.47\nQMBcpIchFCOH@\t-1.47\nqC`@IS^Axe`\t-1.47\nRG@aMt\\OH@\t-1.47\nQM`PfzO`^R\t-1.47\nQMFIOBMP^P\t-1.47\nQMPARUAxb\t-1.47\nHaFH@BAIf]n``@@XYe]s@I`\t-1.48\nHg|H@@RfUYwySn``@@@@XJfDwCNg_HT\t-1.48\nHet@@DjYUX^d@@@@A`rDwCODr`\t-1.48\nsGX`BDdvmT@prqyJ\t-1.48\nHifDAHAHeNR[e^Eh@@@XXUMqND\t-1.48\nRF@Qp|R@\t-1.48\nsJPXhlQx[ct^u@OH`\t-1.48\nsJPhHaxIRuPCsCD\t-1.48\nQMFIOBN`^YH\t-1.48\n`IK@Cr@\t-1.49\nHaD@@DjWjXHB@A`f]phRf@\t-1.49\nsGQ@@eNuT@ptqxeP\t-1.49\nqC`XCDVIlQIj`LLEnR@\t-1.5\nHif@@@rRJEKaj@@@FCIaTw\\`P\t-1.5\nHaDH`H@HRnU[f@@@FEXUMwH@\t-1.5\nsGP`AdeUj`FBMxh`\t-1.51\nsGQ`@jdrmR@|VH\t-1.51\nsNx`DFdkKUHCCKWba@\t-1.51\nqCh@CIKTAaaErX\t-1.51\nQMBCDRYAaGFP\t-1.51\nHiT`@@rnRfUjEnBA``AabMwHD\t-1.51\nsJY@DDfvdAaMqH`\t-1.51\nsJQ@@dkU@LCEcr@\t-1.51\nRF@QPpce@\t-1.51\nJoBA@@YviSJwZ}C[uUTDA@@XSA\\LkiwsDip\t-1.52\nJgBD@@YHhhhddZFSvz@B@B@@LFInT{y`sh\t-1.52\nHcND@BADf{YU]Zj@@@F@ie\\LkoHH\t-1.52\nHid@`@BDiyWaj@@@FGAATwCrD@\t-1.52\nHeTD@@eJ[WVz`@h@FEIaTwDFP\t-1.52\nHidH@@RYWZZ@B`@XLBXUCrN@\t-1.52\nsOx@@drm\\@@@pHM_Dl\t-1.52\nsNp`ATfUjj@XTQF|VX\t-1.52\nsKP`@Ti\\Zj@XJ[dP\t-1.52\nsJQ@@dmU@LML^HH\t-1.52\nqCcRQX^FzNtAaEr@\t-1.52\nsNx`BDdw[UPCCKWbK@\t-1.52\nHmtL@@QTfyeQehBA@A`ULL|QN@\t-1.53\nHk^H@DAInUm^GSZ@@@@@XLWRngqDh\t-1.54\nHmNh@DkaTDfVYVzUZiYj@FFHL|aP\t-1.54\nHmLD@@QIe[VfeVi@B@A`U\\J|SI@\t-1.54\nHaF@@@RYe[hB@@FEAaTwHx\t-1.54\nKAxD@@c\\dr|uS@FDYqBx\t-1.54\nsNu@EPdrkUPCCKWbK@\t-1.54\nqC`HBHc`dmPFFBwI@\t-1.54\nsGQ`@bdwMT@pvMyD\t-1.54\nsGP`@dfUjPFBuyB\t-1.54\nsJP@Dk^hAahmrD\t-1.54\nqCa@BIWTAaMqQ@\t-1.54\nQMABHcAIhFBWI@\t-1.54\nqCaPSAXRVdCqA@\t-1.54\nsJP`@dfvlAxdP\t-1.54\nqCb@AIV`LEMrH\t-1.54\nqCp@AI^`LInQ@\t-1.54\nRFBFIFDXLHyP\t-1.54\nQMBBpRZA`sr@\t-1.54\n`IC`Cr@\t-1.54\nqCq@XIIf`ODl\t-1.54\nsJP@DiVhA`QD^S@\t-1.56\nsGP`@TfUi`FDwDj\t-1.56\nqCj@KAIV`LDmrP\t-1.56\nHev`@@rfeJY{ZxYBBFH@XXfCrI@\t-1.58\nHmN`@@rfeJY{^nFP`ah`AabXOHT\t-1.58\nsGP`ATiVj`FAbuyB\t-1.58\nJoBD@@ISZzrk][t@E@@@@XJfESKiv\x7FHD\t-1.59\nHg|@@DjU^Uzx{BB@`@@FDpaTLki|SK@\t-1.59\nHeV@@@RfU\x7FahHB@A`rXUMwDBP\t-1.59\nHie@@@aJVuxV`@@AaQTwCrL@\t-1.59\nHaE@@@aJyUnX@@@XUaTw\\b@\t-1.59\nqCb@AIVPLInJH\t-1.59\nHg|H@@RYfUWd}mh@@@@@XBUMprn|P{@\t-1.59\nj`qAB@G@bDfYeU\x7Fd[Uj`@@B`@AahAJLxJRmV}rD@\t-1.6\njdyP@@@^Rfuue]f\\lyjVX@Jh@AaiFBTXkQkAcr@`\t-1.6\njhyQ@@LT@eL}klkbde^CSH@P@P@@pds`iFl{p^PP\t-1.6\njhia@@G@RYfUW~d[Uj`@@Bh@@XFA@eF\\EIVoAyBp\t-1.6\nj`q`@@@YIEBedhdnB]zh@J@@@@XZQ`eF\\tZso\\aH\t-1.6\nj`q`B@K@|DifUW~EiQj@@@J`@AakAJLxJRcN}r@@\t-1.6\nHgl@DLdBdJdFdAdIdCdKdLddTbdYeUUTt@LD{^Ph\t-1.6\nj`q`@@@YIEBedhdnB]zh@J@@@@XZQ`eF\\ehug\\ax\t-1.6\nj`q@`@@LRYfWg^Qg^jB`@@@@FE`PIQ`iJtZso\\a`\t-1.6\nj`qH@@@P]yJVYU_yFuYh@@@d@@XRIQgARUjwH^@\t-1.6\njhiP@@@NRYfUW~d[Uf`@@Bh@@XZ@RcNBdkW`|aX\t-1.6\njhi`@@@ISLwZkf|xMUP@@@@@LO@``cNBdkQkN|D\t-1.6\nj`qa@@D@RYYUg^Qg^Z``@@@@FDdTXkQkN}sAAR@\t-1.6\nHglLxJ[hBLdBdAdIdCdKdLddTbdYeTmUT@LHwdJ\t-1.6\njdyP@@@QrJJJJjIJILEYtADP@U@@CAPBTYqVoAb\t-1.6\nj`q@@@DjYVWWyjwhI@HA@@A`YFJLxJRmFm{dG@\t-1.6\njhia@@G@RYfUW~d[Uf`@@Bh@@XJIQgARUkp^Pl\t-1.6\nHg^BpLaIT@b`aiCIICEELb]kU@h@@LJx]N~QP\t-1.6\njdip@`OAbBPIHJdKRBSLwKKnpTuSMU_h@OHR@\t-1.6\nJoB@Q@^@SddbbaRRrv[uP@@@@@XVFES\\Lkivx\t-1.6\nJoB@P@NFRRJJEIKKYoU@@@@@AanTwCJz]orB@\t-1.6\nj`q@`@@^RVUvUugCVX@H@I@@F@lDhrRmFxbC`\t-1.6\nHkLLHDYP\\HbJ\\I\\LddqdQdjjjj@FGQa\\NgrE@\t-1.6\nJoB@H@^@~BULrj~mf}PA@@@@FAaaTwRng[|`P\t-1.6\nHctHXMRPrPjPZPFPfPrRQRFDuUUT@LLy]yA@\t-1.6\nJoBDH@QPIPIS\\rjzv[uP@@@@@XKS\\Lkiv\x7FHP\t-1.6\nJoB@@FRQQIQKH}moAHA@@@AajYS\\Lz]orE@\t-1.6\nj`aP@`G^AHDdERAiAIf[eWvBfjYjoP@^HyH\t-1.6\nHkn@PHApiprRQJFIGSjhJ@@A`lXS\\Lki|b`\t-1.6\nJoC@PD@xIU\\vjzv[uP@@@@@XZUMprng[|b@\t-1.6\nHg\\BPHSS@HxHrRPqQISKZtD`h@CAjXYV~Qp\t-1.6\nJoBAPDIa`DYIIUHiEEMrzuUUMT@F@xPrnvx\t-1.6\nJoBDPD@xITlvjzv[uP@@@@@XZUMprng[|`@\t-1.6\nHgmL`JULHOCIIEIRdiMUUU@CA\\JfxYT{yF`\t-1.6\nHg\\@x@dBdFdAdEdCdKdDfYn\x7FnfBHbj@AyF`\t-1.6\nHknBPLaFx@``cIHXhhTmMZe@@@FECJz_D@`\t-1.6\nHg\\JPHSAd@b`cIIBhhd]ikTB`P@LJ[ev~QP\t-1.6\nHo~L`LaC@HrRPjJIKG[VhJAH@FGYS\\noqAd\t-1.6\nHklBPHQ]@HxHrRPqIJJSV``T@A`qTpr_Hx\t-1.6\nHklDPDp@b@cIIDXdmevV``H@FGQS]JgrA@\t-1.6\nHklHPHApiprRQJFIGSjhJ@@AaNDwCJz_Hh\t-1.6\nHctLpHS`\\J\\F\\LddRLbeUUU@CClIae]yG@\t-1.6\nHg^L`LaM@HrRPjIIHjZuA@d@CAl[iV~IP`\t-1.6\nHedFIDpnFPBHBJBFBBz^rRQURRuK@CAHh\t-1.6\nHg}@@@aJVYU^Svz`@@@@A`HMprnwphJc@\t-1.6\nHkLLPDtp\\ABLddTbLLjjje@FGXUMtkrA@\t-1.6\nHmTHHDApbHipVHRjvYjjj`A`LXS\\LkrJ@\t-1.6\nHcMB@hDDWXeNF]yInUnzV`BF@AaaUwHd\t-1.6\nHg|H@@RYfUWd}nh@@@@@XJDES\\LkoDNp\t-1.6\nHg\\D@HkIIDhTeDmuTDE@@LIpfzUt{y@`\t-1.6\nHcLDPDp@b@cIIDYdmJrt@D@CAh[ag^QP\t-1.6\nHmTDpHPGBgAgCIIDcEJjjh@X]aUproHX\t-1.6\nHcL@P@|I|DifUl]hJB`@FDiaTwBn|PI@\t-1.6\nHg}@@@mIe]e^ftx@H@H@A`HHUCJwqLt\t-1.6\nHg~@@@RYfUWd}mh@@@@@XJUMprng_H@\t-1.6\nHedLhDp`BJdFdAdIdLddTgdmUP@|Pn@\t-1.6\nHg|H@@RVUvU[cm`@`@@@XCaTtki|RK@\t-1.6\nHmtDPDp@b@cIIKDeafV@B@AaUMpkrH@\t-1.6\nHmvD`La@BLddNbReUjjj@FCTwCJ|SB@\t-1.6\nHk\\H@@RfYU\\]Tz@@@@@FDxUMprn|`p\t-1.6\nHmV@PHApEprRQQMRjjj@F@iaTwRoHD\t-1.6\nHeVD`La@BLdaTRPrmUU@CAbinF^HF@\t-1.6\nHiD@H@\\HbNdAdLddqTjjh@XUBXU\\a`\t-1.6\nHmtJ@@IaUIf[oijjjh@XJDIaTwBoHd\t-1.6\nHmUH`Dr@|LdbTLTjjj`A`HES\\LkrL@\t-1.6\nHmtD`HP@cIICLeaeZ@B@AaUMpkrB@\t-1.6\nHmtD`HP@cIICDeiUZA@@A`qTproHx\t-1.6\nHmUD`LJD@HrRPqIIZjj@FCTwCJ|``\t-1.6\nHk^D@DBTfYYwimMjdDB@A`vMpkoHL\t-1.6\nHiDDpDXGBHbgCIILYJjj@FEQa\\OHX\t-1.6\nHmtD`HP@cIICDeiUZB@@A`qTproHx\t-1.6\nHmU@`HPGCIIEDTjjjh@XCaTwCJ|a@\t-1.6\nHedAQHSBkad@a``nglddNTbuRp@`\t-1.6\nHcNJ@D@ae\\bbbRtMLuUKT@LDqnQh\t-1.6\nHcL@@DjU_VnBAId@FBpfES\\LkrM@\t-1.6\nHeTL`HRPBLdabRwBl@D@CBbingd@\t-1.6\nHmLD@@qJY{WJeZj@B@A`tMproDR`\t-1.6\nHmvH@H[IIEDYNFjjj`AarXSCJ|c`\t-1.6\nsFpF@DSpPQ``~EBDf_EjXA`Pm^JD\t-1.6\nHk\\H@@RfYU\\]Tz@@@@@FBxUMprnf\t-1.6\nHmt@`@|DifUqV`hH@A`JXS\\Lkq@h\t-1.6\nHiDHPDApbHrRPqRjj`AatXUMp|a@\t-1.6\nHg_@@@jteem]YWizV[`A`S\\L|cP\t-1.6\nHiDHPHApIpRiYjjj@FG@fTwCrB@\t-1.6\nHcLH@@RYWeUuiX@@@XBfEprn|b`\t-1.6\nHiED`LJD@HrRPiIZj`A`UMp|SB@\t-1.6\nHaD@R@bNhNyIe^f`@`@XTBXU\\c`\t-1.6\nHeV@B@B\\dbaRwBuRs@CAdpj[nQH\t-1.6\nHmV@@@rRJJIjjjj@FDpfES]J|`P\t-1.6\nKAxUBPfEp^F\\WYIIbfjh@pRnyC@\t-1.6\nHeth@DkiAIeeVxYZiVh@XH`|Pi@\t-1.6\nHiE@`HPGCIIDbjjj@FCXUMp|RD@\t-1.6\nHeU@@@eJYW~F``H@FGIaTwSr@@\t-1.6\nHmtD@@QImYVUZh@@@X\\fMproHH\t-1.6\nHcM@@@uIVUux^ZV[`A`QTw\\QI@\t-1.6\nHiDNPHSB[a@XhXrRPzQZe`A`aB\t-1.6\nHeT`@@`YRnUunX@I@A`VES\\RI@\t-1.6\nKAxD`Pc\\@QPQddJTVYPCALKbAP\t-1.6\nHif@`HApRkm^Fh@@@XMaTwCq@`\t-1.6\nHeTL@HP\\ddRUQ]UUU@CBlJfgd\\\t-1.6\nKAxH`P`NENFRRJrjj@LJpj[nP`\t-1.6\nHif@B@B\\dbaRxVjV`A`rXUMwHD\t-1.6\nHmu@@@UJf]|YjB@`@X\\aTwBoHp\t-1.6\nHaD@P@bH|DeeVz`@@A`pXUMwH`\t-1.6\nHeeH@DhLbbTJcUUP@pyLinF^PP\t-1.6\nKAxY`Pf@DMH]HYIHUEjh@pbnPP\t-1.6\nHiDB`HSACprRSIEjjPAaaTwHx\t-1.6\nHeU@@@gIHhTmpu@A@@pyLJfzP\t-1.6\nHef@@@rRJJIuUU@C@XPj[agdX\t-1.6\nHmvJ@LANF\\bbTReIfjej@GbLh\t-1.6\nHeg@B@J`gIHhXhuUT@LFSFxY@\t-1.6\nKAxAPAHIHEHMH]HIMwTuPAyE@\t-1.6\nHidL@HP\\ddRNijji`AafEWD[`\t-1.6\nHeTD@@eIYWVy`@d@FFXU\\rFD\t-1.6\nKAxQ@PC`eWMUU@FG@fES]rH@\t-1.6\nHeTH@@RYyTYZ`@@A`rTwCOHp\t-1.6\nHifH@AAJ[W[j@B@AaVESCrD@\t-1.6\nHidH@@RUe^Fh@@@X]BES\\OH@\t-1.6\nHaDL@@[die\\jjj`AaTXUMqDx\t-1.6\nHiFD@LADfWYjj`A`VMp|Pj@\t-1.6\nHifH@DAIVUxU`@@A`QTw\\`P\t-1.6\nHiEH@DHDf{Yjj`A`vES\\OHP\t-1.6\nHiD@@LdbJTZjh@X]BXUMwHD\t-1.6\nHaDD@@YJ[tjjjh@XDfEwDb`\t-1.6\nHeVJ@LANFTfVVIfjeh@^Ht`\t-1.6\nKA|H@XBIMkMUPA`VTw\\QB@\t-1.6\nHaFH@FAIe^fZjh@XDfEWHx\t-1.6\nsGPL@xRHTQddajhA`Xl^R`\t-1.6\nKAzP@I`ILsUUPAaTES]r@@\t-1.6\nKA|X@DB\\dwZuT`FAIaUrF@\t-1.6\nHid@@Di[Waz@@@FEES\\OHp\t-1.6\nKAz@@@VRQPrjZ@LBSF{dT\t-1.6\nHifB@LANEIeeIfje`AxeL\t-1.6\nsNxhMDOCIHUJj`FAAkyhl\t-1.6\nHiF@@@RifZjj@F@pfES\\H\t-1.6\nsNpD@DSpRYyjhAaPcWqS@\t-1.6\nsGQDHGCNBTmUPCCHwbF@\t-1.6\nsOpH@DILkW@@@LJEc^Q`\t-1.6\nsNpD@xRHRjzjhAaYcWrH\t-1.6\nsNqhHfOAJmvjPFBqxaP\t-1.6\nsNpH@xIRkUJ@p\\VM_H@\t-1.6\nsNt@@|dTQjj@XTKF|TX\t-1.6\nsGTHHaxISuU@LMc^XQ@\t-1.6\nsNqHHGAJeZj`FAVkx`P\t-1.6\nsOq@@drm[Rt@pJqoHp\t-1.6\nsJPhH`xYICU@LEcsBH\t-1.6\nsGP`ATefj`FEDqoH`\t-1.6\nsJQHHGAJfj@XYX|`@\t-1.6\nsFx@@eJf`@@LEcsQT\t-1.6\nsJQHHGAJfj@XIGbF@\t-1.6\nsOy`LDtfUMZi`Gbu@\t-1.6\nsNxA@NRfZjhA`xlZp\t-1.6\nsJQHHGAJni@XYX|P`\t-1.6\nsJQHHGAJVj@XIGbF@\t-1.6\nqC`H@Hg`dsPFDGME`\t-1.6\nsJYHEAxIWMPCAX|`@\t-1.6\nsGQ@@dsuT@phbqyJ\t-1.6\nqCbPXXbRu@XHSbV@\t-1.6\nsJP`@dfzhA`l^XQ@\t-1.6\nsJQHDHaInZ@XHGdp\t-1.6\nsOq`@fdrikUL@|Vh\t-1.6\nsOq`@fdrikTl@|Vh\t-1.6\nsKQ@@eKcUHCAX|TP\t-1.6\nsGPP@cTfyi`GbU@\t-1.6\nqCcPQXCD]XCB[d@\t-1.6\nqC`PCDRZhCCA[d`\t-1.6\nsJP`@dfvdA`l^Q@\t-1.6\nqC`PApRVdCCQ[d@\t-1.6\nqCcRQXUfzNlAa@\t-1.6\nqCb@AIZPLLEnR@\t-1.6\nQMIDbIpRZAaGFP\t-1.6\nsJY`BEdfVhAxlP\t-1.6\nsGQ`@ZdrmJ@|Rp\t-1.6\nqCb@AIVPLEErX\t-1.6\nQMABlYAIhFD\\h\t-1.6\nsJQ@@djw@OEB\t-1.6\nRFBBYQDXLJy@\t-1.6\nRFTPeQ`|R@\t-1.6\n`II`Cr@\t-1.6\n`II@CB@\t-1.6\nHiFL@BAAR[mVji@FEIaTwHx\t-1.6\nqCaBAKdfZ@xTlMXPf@\t-1.6\nqCaBAKdfZ@pf@\t-1.6\nJoBA@@XNiSJkN}][uUTDA@@XSE\\LkiwsDIp\t-1.6\nHmLL`HS@BLddJfRiiUZ`@`@XEproHh\t-1.6\nHcLB@@RUR[fVQuhHF@@XEWCoDQP\t-1.6\nsGY@JDeUj`FFVoEB\t-1.6\nKA|H@DBIMvmUPAaRXUMrN@\t-1.6\nsGX@JeTuT@prqxiP\t-1.61\nRFTQxQP|`\t-1.61\nsJQ@@eKU@LEEqX`\t-1.61\nqC`@Qz`LMEnP@\t-1.61\nHiDD@@QIeuZjh@XUaTw\\`P\t-1.62\nHidB@@[aRfU\\jjjh@XMFESCqDx\t-1.63\nsGP`@dfuj`FFVoHP\t-1.64\nsGQ@@dkMT@prqxiP\t-1.64\nKAxH@@bSKkUT@XEaTwHx\t-1.64\nHeTD@@QInYQehB@@FATpsqDx\t-1.64\nKA|H@HGIL|mUHAabXWDi`\t-1.65\nsGQ`@ldsmT@paxmP\t-1.65\nHaD@`@bDeeVz`@@A`pXUMwH`\t-1.65\nsJP@DjZhA`Pl^R@\t-1.65\nHmtJ@@XYUJYY^njjjh@XCFEWCJ|QF@\t-1.65\nsJU@E`dru@LH^IX\t-1.65\nsJP`@TiZhA`inID\t-1.65\nHidH@@Rfufzjjh@XMFTwCqDH\t-1.66\nHaGH@Dq`RYVkffi@FFTw\\c@\t-1.66\nHaED@DpFRYVkfjY@FFIW\\c@\t-1.66\nHaDH@@RVU[f@@@FAQaUqFx\t-1.66\nKA|H@LEIRjuUPAaTIaMrN@\t-1.66\nsNx`FJeJmUPCBqXodh\t-1.66\nsNx`FDdvkUPCCHobu@\t-1.66\nsNq`@fdr{UHCAX|e@\t-1.66\nsJY@DDeUhAaMrD\t-1.66\nQMA@HmBN`XI\\d\t-1.66\n`IM`Cr@\t-1.66\nHev`@@rfeJY{ZxYBBJD@XDfLH\t-1.66\nHidH@@RVUvy`@`@XEaTwD`P\t-1.66\nsGY@LDemj`FFVOEJ\t-1.66\nsGQ@@eJuT@ptVxcP\t-1.67\nHeTH@@RYe\\YZB@@A`vEWCOHX\t-1.68\nKA|H@DBIMwMUPAaRXS]rJ@\t-1.68\nqCrAPCiJSU@XI[d`\t-1.68\nRFTQxQ`|R@\t-1.68\nsJP@DkVhA`QEnP`\t-1.69\nqCp@AIZ`LDMqQ@\t-1.69\nRF`EFCBNT\t-1.69\nHmv@B@B\\ddUbReZj@@@FDpfDwCJ`\t-1.69\nsNq@@djkUPC@kF|TX\t-1.69\nHifDAHAHeNR[e^Eh@@@XXS]qJD\t-1.7\nsOpHAbILkW@@@LJDZ~S@\t-1.7\nJoBD@@ILrkNx{[uA@@@@@XFDEWCJz]orL@\t-1.7\nHmtD@@QImYVUZh@@@X\\aMproHp\t-1.7\nsJQ`@bdvt`LHnS@\t-1.7\nHaD@@DjfZzjj`AaVES]qHP\t-1.7\nqCcPQX^D]hCBKbF@\t-1.7\nQMABPYAIhGe@\t-1.7\nsGP`@dfUjPFDoEb\t-1.71\nHmt@HHdDdLdEbLddlRVFZh@H@FATwKrA@\t-1.72\nHo}L@J[SoIIEKEELQfjjjYh@XMBXPkrG@\t-1.72\nHg]L@J[SoIIEKEELLuUUSL@LFaLHUyA`\t-1.72\nHcl@@DjYU_egX@@@@@XRfDwCJ{rJ@\t-1.72\nHedLpJFXdDdLdLddlreTtp@panQH\t-1.72\nHcLL@@STfue^UZh@H@FCDwCN|QL@\t-1.72\nHmTB`HZUAprRQVYRjff@FAIa]rE@\t-1.72\nKA|Q`MTQBQFQFRRVJjf@LBaL[d\\\t-1.72\nHefDB@FPgIIETiUUL@LFaLIiyE@\t-1.72\nHeTH`ACpRfUWidHD@A`rXS]ODB`\t-1.72\nHmtH@ErRQRiHYj`@`@XLfETkqFx\t-1.72\nHmtH@IrRQRiPUj`B@@XLfESSqAT\t-1.72\nHmtH@NrRQRqZUj``@@X\\fDwRoHD\t-1.72\nHeVD@DClbbbRILuRu@C@liayD`\t-1.72\nHedL`HZP\\LddUfUUMH@pILKnPH\t-1.72\nHeV@@@Re[TYj`@@A`HPUMpsrD@\t-1.72\nsNplJu@Z@L@eTuTpCcI@r@TCdX\t-1.72\nHiDD`HX\\SIIEYjjZ@FAIaCrN@\t-1.72\nKAxI`MtRBRFRFRRURjf@LH{dD\t-1.72\nKAxP`PCaSaddbjjjPCBdpf{dT\t-1.72\nHeTD@@yJ[VvF`BH@FEIaCOHX\t-1.72\nHaE@@@aJyUnh@@@XLDXUMrN@\t-1.72\nHefD@NalddUfeUMP@pILH^QH\t-1.72\nsNyLGYDJHtQddeeUHC@qY|e@\t-1.72\nHiDD`HXGCIIEYjj[@FFIa\\`P\t-1.72\nHiFD@Jx\\ddUTjjX@XDfEWD`P\t-1.72\nHidH@@RUe^Fh@@@X\\BES\\OH`\t-1.72\nKAxI@MpNFRRJrjf@LBaLKd\\\t-1.72\nKAxI@P`NBUKmUT@XUaTw\\`@\t-1.72\nHiFD@NalddUfjih@XDfDOHx\t-1.72\nsGPJHBJPt`YBubUSUPCBWd`\t-1.72\nHiFL@AanrRQVZjf`AabXWHD\t-1.72\nsNpBHxJPt`YCIIEZj`FBkyH\t-1.72\nKA|Q@QpNFRRJVji@LBSB[dT\t-1.72\nsNqLKHaQFbLddljf@XZK\\c@\t-1.72\nKAxI@PpNFRRJrji@LLSBxc\\\t-1.72\nsNplByDJHtQddeUUHCCQ[dh\t-1.72\nKAxQ@\\CaddbjjnPCCDpnPp\t-1.72\nHaD@@DjWjXHB@AaTIc]rJ@\t-1.72\nsGXLKHaQFbLddmT`LCEkrD\t-1.72\nHif@@@RVUv{`@`@XEaTwHD\t-1.72\nHaDH@@RYe[hB@@FA@UMqLx\t-1.72\nKAxD@@c\\dvlts@FBXWDS`\t-1.72\nKAxH@MvRRJrjf@LLSBxd\\\t-1.72\nKA|@D@DiUJuUPAatIaTw@\t-1.72\nsNpD@xTHrRQVjhAaXl[rL\t-1.72\nsGPdE`DRHrRRrt@pTOIP\t-1.72\nsJQLCHaQFbH~j@XZK\\a@\t-1.72\nsO|HEfHaIeZx@@AaAqF`\t-1.72\nKAxX@PfIUJuUPAaeMwHH\t-1.72\nsNqHFGCIIEZj`FEbqoHp\t-1.72\nsNqhHl@cIIJej`FFqoHp\t-1.72\nsOpH@bILkW@@@LJlZ~P@\t-1.72\nsNyHHpxYIHkUL@prqxjp\t-1.72\nsNyHG@xYIHkUR@prqxjp\t-1.72\nsJXBB@bRBdMHQ}T@p`yB\t-1.72\nsOpHAxILkW@@@LBl[qA`\t-1.72\nsFxIHO@RdrfuU@LBl[r@\t-1.72\nsGPhH`xYIDZj@X[F|PP\t-1.72\nsGQDHGBtBUSUPCCKGdh\t-1.72\nsGPD@xPHRjZj@XFKGdh\t-1.72\nsGQhHlOCIIJuPCCKWdH\t-1.72\nsOy@FDfUkZj`FAVMyF\t-1.72\nqC`XBlTaiAIj`LHNR@\t-1.72\nsJPIEPKdkZhA`QL^Q@\t-1.72\nsGXHJGAJijhA`Xl^R`\t-1.72\nsGQHJGAJijhA`Xl^R`\t-1.72\nsGQ`AbeLuT@ptUxlP\t-1.72\nsJPH@DIJuPC@bK\\a@\t-1.72\nsJPhLQDIKTpCA@|d@\t-1.72\nqC`D@Hd`iCRD^hCr@\t-1.72\nsJPH@xIKUPC@qX|`@\t-1.72\nsGT@A\\dbMU@LMC^IX\t-1.72\nsNqA@IRiVjhA`xlZp\t-1.72\nsGQHI[AJijhAaecrT\t-1.72\nsJPH@xITuHC@qX|`@\t-1.72\nsGP`ATeejPFBQxi`\t-1.72\nsGP`ITjfj`FFVOIP\t-1.72\nqC`DBPe@iCRBSU@P\t-1.72\nsJQIHGB]GuPCCKD\t-1.72\nsGX@HeTuR@prqyJ\t-1.72\nQMCAxhabHzAad`\t-1.72\nsGT@ATegipGdH\t-1.72\nRFTE@Q`xi@y@\t-1.72\nQMBCpchFCOH@\t-1.72\nQMHAIdFD|R@\t-1.72\nQMbDBDfp^P\t-1.72\n`IDhCr@\t-1.72\nsNq`@VdsMUPCBbKGbk@\t-1.72\nsGQ`@ZdruT@pHboEb\t-1.72\nsGQ@@dsMT@pQoDl\t-1.72\nsNq`AVdlmUPCAbXu|b@\t-1.72\nQMFIOBN`XUqD\t-1.72\nqC`HBPT`duPGbf@\t-1.72\nHeTD`HP@cIHXdmpk@A@@phj[iy@@\t-1.73\nsOx@@drm\\@@@phVKyJ\t-1.74\nsNx`DFdskUHCAK\\Qh\t-1.74\nHaDD@@yIe^f`@`@XHa\\HLk`\t-1.74\nHet@@DjYUX^d@@@@A`rXS\\ODjP\t-1.74\nsGPYHlQxGdjmj`Gbu@\t-1.74\nHifDAHAHeNR[e^Eh@@@XXUCqFx\t-1.75\nHaF@@@Rfu[i@@@FAXUMqDx\t-1.75\nsGQ`@bdwMT@pVODj\t-1.75\nHeTJ@@qaeJYyzzjjj@FCPUMt|qLD\t-1.76\nsJX`BDdvu@LDmrD\t-1.76\nHmVBaNaLHO@nz\\ddqRdZjj`AaULLkrL@\t-1.76\nHidD@@QInUxV`@@AaRESCrN@\t-1.77\nHaDH@@RYVijjj@FCPaTw\\PL@\t-1.77\nsJPhLQbIKTpCBCba@\t-1.77\nsJPhI`xIKTpCBGd@\t-1.77\nsGY@DDfUjPFFVoHP\t-1.77\nsGQ`@jdvmT@prqyJ\t-1.77\nsGP`ATf]jPFBVyB\t-1.77\nsGX@@dj}T@prqyJ\t-1.77\nqC`PBlRVhCCBKdp\t-1.77\nqCaPS@pRVdCqA@\t-1.77\nQMhDRYAaOD`\t-1.77\nsOx@@drm\\@@@pHU_Eb\t-1.77\nsOp@DjWkB@@FAfkxdP\t-1.77\nHidH`H@HRnUvy`@`@XUaTp|`@\t-1.77\nHiDD@@QIeWZjh@XUaTw\\`P\t-1.78\nRFDBIFCqH\t-1.78\nHidD`HP@cIHXdnEX@@@XTUMp|`@\t-1.78\nHaD@`@BDfUzZ@B@AaRXU]r@@\t-1.78\nHeTH@@rJJJJlLADP@LL@fye]H\t-1.79\nHidH@@rJJIEn`HH@FF@S\\sJD\t-1.79\nRFDFIFCbkBD\\h\t-1.79\nRFDFIFCBNT\t-1.79\nHmtL`HS@BLddlRVFUh@H@FCYS\\J`\t-1.8\nHeVH@DAInU~Eh@H@FAES]qDd\t-1.8\nsGP`Adifj`FFboEb\t-1.81\nqCb@AIZ`LLHnS@\t-1.81\nKA|@@@djkUU@FGABXUMrN@\t-1.82\nKA|H@XGIKZmUHA`RXU\\RF@\t-1.82\nsGQhHjOCIHTuHCB[fBH\t-1.82\nsGP@Di]j`FADQxmP\t-1.82\nHg]L`FvDp@cIIJeDednkUUUT@LApjxYT~QX\t-1.83\nHkmL`FvDp@cIIJeDeeuZjjj@FGXU\\LkrC@\t-1.83\nHcML`FvDp@cIIJeDdnkUUU@CClJnFUyF`\t-1.83\nHg}@@@mJYeU|]Tz@@@H@A`hXUMpri|bp\t-1.83\nHmL@`EhLddTQaQnFjjjh@XSBXUMpsrE@\t-1.83\nHknHBFAiRYfUnSjB`h@AahQaUprngrF@\t-1.83\nHg^B@D@agHhhdmBeSMURuT@LJqet~QX\t-1.83\nHmL`B@aBBTiWe\\JUZh@D@FEMproDA@\t-1.83\nHknBAHAIvISdfyWVxV`@i`@XDUMwHL\t-1.83\nHmwDAHePRISdfyW^Eh@I@A`QTw\\aP\t-1.83\nHid@P@bDbDfyWaj@@@FG@aTwCrH@\t-1.83\nHeT@b@|@eJYU^f```@FGIaMpsq@h\t-1.83\nHiDLbHS@BL{IIJdejj@FAES]rA@\t-1.83\nKAx@PQHIHUHMHYIHXjjh@p`nIg@\t-1.83\nHmvJ@D@aeTfYWjYjjV`A`fMrE@\t-1.83\nHmtH@@RYvUeVf@@@FGHS\\LkrL@\t-1.83\nHidH`HApRem^Fh@@@XMaTwCr@@\t-1.83\nHid@`@|Die_ahH@@FCXUMp|PD@\t-1.83\nHidD@@QInUxZ`@@AaTES]s@PP\t-1.83\nHeTH@@RYWZf`@j@A`pIaTODzP\t-1.83\nHid@@DjUfaBB`@FEQc\\OLPj@\t-1.83\nHaD@`@bDeeVz`@@A`pQaTwHx\t-1.83\nHie@@@EJ[W[j@B@AaVESCq@P\t-1.83\nHmt@@DjYnvDHbJ@AaVUtkrA@\t-1.83\nKA|A@PCaddTJjj`CAdpj[nP@\t-1.83\nsNqdHjG@nFRQFUU@LBLWqJ`\t-1.83\nKAxX@@gILjmUHAafDwHh\t-1.83\nsNpXHlpDYIBdmT@pQoDF\t-1.83\nqCbPXXbRt`\\JVBlHHSdP\t-1.83\nsNyHHpxYIECUR@prux`P\t-1.83\nsGXHHGCIHcUPC@kF|P`\t-1.83\nsOq@@drm[UT@pJqoHp\t-1.83\nsGPHADIJmU@LJHl^R`\t-1.83\nsJQDBIARBS]T@pVOI@\t-1.83\nsNxHHGAJijj`FAVkyB\t-1.83\nsOu@E`drm[SR@pU_Eb\t-1.83\nsJPdEaDSpR[f`FDGEB\t-1.83\nsGP@LdbMU@LJHm^P`\t-1.83\nsNq`@fdr{UHCBGbu@\t-1.83\nsJPhHaIIRuPCAX|`@\t-1.83\nsJPHAXIKUPC@qX|`@\t-1.83\nsJPYHlPLGh}Z@^S@\t-1.83\nsJT@@TizhAaicqA@\t-1.83\nsJQA@IRej`FAbqy@\t-1.83\nsJTHH`xQ}T@pVOED\t-1.83\nqCbPXXbRt`XHSdP\t-1.83\nsJPXhlPL[ct^m@H\t-1.83\nsJQ@@dsU@LBHcrX\t-1.83\nsKQ@@eKcUPC@qX`\t-1.83\nqCp@AIZ`LLInQ@\t-1.83\nRFB@QZDXLJy@\t-1.83\nRFBDQFDXLHyP\t-1.83\nRFaDSGCr@\t-1.83\n`InqHFD\t-1.83\n`IoApGd\t-1.83\nsGQiHl@c]ddeVhAaCrT\t-1.83\n`IO@Cr@\t-1.84\nsNx`BDdw[UPC@kF|c@\t-1.85\nHefLa@XY{pBY{IIETiUUL@LJaLJnQp\t-1.86\nsGQiHlOC\\eWmT@paxaP\t-1.86\nsNp`@dfuZj@X[F|RX\t-1.86\nsJX`LDdru@OEb\t-1.86\nsNp@LdbLjj@XTQU|VH\t-1.87\nQMFIOBM`^H`\t-1.87\nHiDH`DBHR[UYjj@FCAaTw\\`P\t-1.88\nqCb@AIVpOEL\t-1.88\nRFDGaFCBnP\t-1.88\n`IE`CB@\t-1.88\nHet@@DjYUX^d@@@@A`rXwCODJ`\t-1.88\nsJP`@dfvdAaCqK@\t-1.88\nsJP@DiZhAaaEqX`\t-1.88\nHmv@@@rRJIIFUjB`@@XBfES\\L|aP\t-1.89\nsNx`LDdr{UPCAZ|QX\t-1.89\nsJQ@@djs@LDcqS@\t-1.89\nsJX`BDdvu@LDcrX\t-1.89\nsNx`JDdrsUPCAZ|QX\t-1.9\nqCb@AIZPLDmqB@\t-1.9\n`IDPCr@\t-1.9\nHmvLAHAIbTyInUwaZ@B`@XDUMwHT\t-1.9\nsNq@JeTuTpCCKGdX\t-1.9\nsGX`BDdwMT@prqyJ\t-1.9\nqCcPQX^D]hCsAX\t-1.9\nHcLFbHSFgP|L{IIlheBJmUUU@CAbkiW^H@`\t-1.91\nqCb@AIi`LInHH\t-1.91\nQMB@HRZA`erP\t-1.91\nJgB@@FRQQIIEIixSl@@@@@@CBTpnE]N~QP\t-1.92\nJgBD@@YHhhhddZFSvzdI`R`@LFInT{y`sh\t-1.92\nHk\\L@@PtfUe]ieujP`J@AaV\\L{rC@\t-1.92\nHefHA@`IclddqRUUUP@pyLJfx^QH\t-1.92\nHmt@@DjU_ZxHDf@AaLIaTwCOHT\t-1.92\nHeT@@DjU_k``RP@XCBXUMp|bP\t-1.92\nHidD@@QInUxV`@@A`RMp|Pj@\t-1.92\nHaD@`@qDeeVz`@@A`pQaTwHx\t-1.92\nHidD@@QInUxV`@@Aaa\\OLRf@\t-1.92\nHifD@DCdfYTfZiZ@FFYS\\`P\t-1.92\nHidH@@RVUvy`@`@XUFES\\`P\t-1.92\nHiFD@LADfuYjj`AaVTwCqDH\t-1.92\nHaD@@DkeV{`@@AaVES]rH@\t-1.92\nKAx@@YIDTjjh@pxHSBinQp\t-1.92\nsJQBDHbNF\\CDIJuPCA@|Tp\t-1.92\nsNpD@xRHrRSFjhAaXl[rL\t-1.92\nsOpH@fILkW@@@LJlZ~P@\t-1.92\nsOpHMPIToVD@@LKDZ~S@\t-1.92\nsGPhH`xITmU@LMc^P@\t-1.92\nsNpP@jtfvZf@XIOdp\t-1.92\nsNpP@jtfvZf@XS\\RX\t-1.92\nsJPHAbIJuPCCA[ba@\t-1.92\nsGT`EaTeUfPGba@\t-1.92\nsJY@DDfvdA`l^Q@\t-1.92\nsJP`ADkjhA`l^JH\t-1.92\nqCaHK@H`QGe@|P`\t-1.92\nqC`PApRfdCCQ[d@\t-1.92\nQMFICBN`XQqd\t-1.92\nRFTPXQ`|R@\t-1.92\nqCa@CIJrAxh`\t-1.92\nHcL@h@dBdFdAdEdDfYn\x7Fi`bHh@GdZ\t-1.94\nHaD@`@BDeeVz`@@A`tXUMwH@\t-1.94\nKAxH@@bSJkUT@XEaTwHx\t-1.94\nsNpXHlQxIUZuT@paxjp\t-1.94\nsNx`BDdw[UPC@kE|e@\t-1.94\nsGP`Adinj`FFboHP\t-1.94\nQMBBlRZA`erP\t-1.94\nsGP@DjZj`FADQxmP\t-1.94\nsGP`@dfUj`FBqyJ\t-1.95\nQM`AIxGd`\t-1.95\nqCcRQX^FzNtAx``\t-1.95\nsGP@LdbMU@LBEcqR`\t-1.96\nsNx`BDdvsUPCAK\\UX\t-1.96\nHifDAHAHeNR[e^Eh@@@XDUMwHD\t-1.96\nqC`@ISTAaaErX\t-1.96\nHefB@LANEImfVjf`A`VDL|QF@\t-1.97\nsNx`JDdrsUPCCXwdX\t-1.97\nsJPH@xISuHCCSGbB@\t-1.97\nqCj@KAIVPOEL\t-1.97\nRFTPlQ`|R@\t-1.97\nHifDAHAHeNR[e^Eh@@@XDS\\OHh\t-1.97\nsNq`@fdr{UHCB[bM@\t-1.97\nHaFHAH@NbTeeVz`@@A`VES\\RN@\t-1.97\nQMFiOAzM`^P\t-1.97\nHeTD@@eIYe^E`HD@FFEW\\rFD\t-1.98\nqC`H@HpPdmPFBbxa`\t-1.98\nqC`PBHRVhCCBKdp\t-2\nsGQhHl@cIIJmPCAX|e@\t-2\nHaFH@FAIeZn`B@@XXe]s@q`\t-2.01\nsGX`BDdvmT@pRwDZ\t-2.01\nsJQiHl@c]GkPCrD\t-2.01\njhyQ@@LT@eLw\\jobaoNCSL@@@P@@pEpTeZMYwD^B\t-2.02\nj`a``@NPYddblrRbR]zjfjjj@AaiFB\\dkQkN}r@`\t-2.02\nHmt@hL`J`N`I`E`DjYnvDHbJ@AqVHEHGHDhBhGHD\t-2.02\nj`qQ@@G^@dsLjolcZmT@@@T@@LM@IQgARUiwnP`\t-2.02\nj`q@`@@^RYWYm^cKN`@j@B@@FF`HpRdeZM[wH\\@\t-2.02\nHo|LHJXXdDdLdNkLddlrfbRmzij`@@A`wKiv\x7FHD\t-2.02\nHgnHxCuICI@iAiCi@YBYCIIEIYGMUUUM@CBKyA`\t-2.02\nKAxQPTdAd@T@tAtAddbejj`CbdPLPBPFPNPNQ@\t-2.02\nHg]DHNff`HRPrPJPrRQR]QIG]Tm@@@C@et{yG@\t-2.02\nJoB@I@Xb^BRdlsJkkYoU@@@@@A`XQS\\Lkiv\x7FHP\t-2.02\nJoB@I@QB^BRdlsJkkYoU@@@@@A`XQS\\Lkiv\x7FHP\t-2.02\nJoB@H@AEABTrj}ktv}AA@@@@FAaaTwRng[|a@\t-2.02\nHg|@R@kH|HeIfYU^Svz`@@@@AahES\\LkiwrH@\t-2.02\nHg\\DHJZIAICICjsIIKLeDd]uST@@@LJe]N~Qp\t-2.02\nj`aaP@NPXkSlddUfbbaVcUTuMSP@LJHpRWnPl\t-2.02\nJoC@QDAxAJUKMjnmf}T@@@@@FFeS\\Lkiv\x7FDB@\t-2.02\nHgnHhFjIAICi@YBWCIICEMCIUMUU@C@et{yA@\t-2.02\nJoB@Q@^@ReSLjokYoT@H@@@A`^ES\\Lkiv\x7FH@\t-2.02\nHo\\DHJvIAICi@YCIICELXiJijij@FAL]orB@\t-2.02\nHg\\DpIVIAICICIIKEEDb]uU@p@@LFxUt{yA@\t-2.02\nHklLPHS@\\J\\LddQbbQtzjB`@@XCS\\Lki|QL@\t-2.02\nJoC@HGAbObILkkJ}L]p@T@D@@XJBXURnf\x7FHx\t-2.02\nJoB@X@^ErCrBTsJkzNj]@@@E@@F@xUMproH@\t-2.02\nJoB@P@^BTkLjnmf}T@@@@@FApeMprng[|`@\t-2.02\nHg|@P@BH\\DfYeUyO[j@@@@@FF`UMprng_H`\t-2.02\nHcm@RDpLROBIRYfUQe]jjjj`AaHES\\LkoH`\t-2.02\nHcm@RDpHbOBIRYfUQe]jjjj`AaHES\\LkoH`\t-2.02\nJoBDPD@xIU\\vjzv[uP@@@@@XZUMprng[|b@\t-2.02\nHkLJHJ[mN@aICI@iCIIEIuEJiZi`A``krC@\t-2.02\nHg|@P@SHbDjyeUyO[j@@@@@FFpUMprng_H@\t-2.02\nHg|@b@|@eJYUg_eNzB@@@@AajXS\\Lkiwr@@\t-2.02\nHg|@P@QH|DfYeUyO[Z@@@@@FF`UMprng_H`\t-2.02\nHg|@P@BH|DfYeUyO[Z@@@@@FF`UMprng_H`\t-2.02\nHg}@A@LINTjWvUz[SB@`@`@F@paTLkoDrp\t-2.02\nHg|H`HALRkfUWd}nh@@@@@XJUMprng_DB@\t-2.02\nJoCD@D@e\\sJkkYoU@@@@@AalTwCJz]orD@\t-2.02\nHklHPHipZHrRQVZIKSjj`@@AaJXSCJz_Hh\t-2.02\nHklHpJbPRPrPrRRqJYKSjj`@@A`wCJz_HH\t-2.02\nHcLDPHhG@gCIHcMDdnuU@@@C@PSNFUwbEP\t-2.02\nHg~@`HApRkfUWd}nh@@@@@X[ATwCJz]|`@\t-2.02\nHcmHbDr@|@eJnYUFUvjjjj@F@eS\\LkoDB@\t-2.02\nJoB@P@^BTsJkzNj]@@@E@@FBxUMprmor@@\t-2.02\nHg|@`@bDfYeUyO[j@@@@@FB`UMprngqHl\t-2.02\nJoBD@@IS\\rjzv[uP@@@@@XZeMprng[|b@\t-2.02\nHg|@`@BDfYeUyO[j@@@@@FF`UMprng_H`\t-2.02\nHg|@`@qDfYeUyO[j@@@@@FF`UMprng_H`\t-2.02\nHklD`HPGCIHdhdd]Nj`h@@FDeS\\Lki|`@\t-2.02\nHcNHpMJIAICICIIJhdmJuT@D@C@fxYyF`\t-2.02\nHg|H`@b`RYfUWd}nh@@@@@XJUMprng_H@\t-2.02\nHed@H@BH\\LBBBLdTTUeUUP@pdHSJ[agdD\t-2.02\nHklHpJbPRPrPrRRsQIY]jf@B@A`WCJ|`p\t-2.02\nHmTLpHS@\\J\\F\\LddRLTjjj`AaqTwCJ|c@\t-2.02\nHco@`HS@|DjyeTYWVjjjh@XBUMprn|PH@\t-2.02\nHctBHJ[m`HRPrPJPrRQR]QURuR@LDE^QH\t-2.02\nHcL@PH\\JbLddT\\RR{UT@@@LISBkae]yD@\t-2.02\nHg|H`HBDRkfUWd}mh@@@@@XJUMprng_H@\t-2.02\nHcLHpMbPRPrPrRRqIPcMT@D`@pJfF^Ph\t-2.02\nHg~@@@RYfUWd}nh@@@@@XZATwCJz]|b@\t-2.02\nHk\\@b@k@eJYeUquSh@@@@@XZFES\\Lki`\t-2.02\nHk\\@`@sDifUWGUN`@@@@A`nES\\Lki|`@\t-2.02\nHeT@pHbDbLbLddlRPsU@@@CChSJ[ayD`\t-2.02\nHk\\@`@rdifUWGUN`@@@@A`nES\\Lki|`@\t-2.02\nHctLhAgTdLdBdJdFdLddTgfUUTt`CrE@\t-2.02\nHg}@@@aJnYU^Svz`@@@@A`iTwCJz]|b@\t-2.02\nHkn@`NaprRQRjYKSjjp@@A`JXPrngrH@\t-2.02\nHcvHPDDGBWCIIEHniUUUP@pELJfy]yD`\t-2.02\nHcvHPAPGBWCIIEHniUUUP@pGBinE]yD`\t-2.02\nHcmH`Dr@|DjyeTYWVjjjh@XBUMprn|`@\t-2.02\nHg|H@@RYfUWd}mh@@@@@XRUMprngrK@\t-2.02\nHmv@PHApIpRi[WeZhH@@F@qeMproD@`\t-2.02\nHed@hH\\DdLdAdIdLddTaeUUP@prf{dD\t-2.02\nHiFDhNihBDdLdBdApLddTgjeh@XPOHx\t-2.02\nHg}@@@mIe]e^ftx@H@H@A`JXUCJ{q@l\t-2.02\nHglF@HXUN|ddUfffeUMUL@LNSBxYWdV\t-2.02\nHmtD`HPGCIHdhTiVj`@@AaqTwCJ|`@\t-2.02\nHiD@p@BH\\LBLdRbLjjh@XBBXUMp|b@\t-2.02\nHg}@@@mIe]e^ftx@H@H@A`hIaTLkm`\t-2.02\nHkmD@J[SrRQRqQXYjjje`A`tIaBoHx\t-2.02\nHknB@D@agHhhdmBjYjjVj@FAXr{rC@\t-2.02\nHknD@NalddUfbRtzjZjh@X\\fDLkoHL\t-2.02\nHmTLPDp`ZHbDjmyjjjh@XBDTwCJ|``\t-2.02\nHcvD`Naj|LddUfbUUUU@C@TpjFUwdL\t-2.02\nHmtHPHApIpRi[WeZhH@@FGYS\\Lkq@H\t-2.02\nHk^@@@RYWYVftx@H@@@F@iaTLkoD@p\t-2.02\nHedLHJ[hBDdLdBdLddTgUTmP@pb^PH\t-2.02\nHkLJ@HXUOIIEYiijjZjPAarXWCJ|cP\t-2.02\nHmTLPDeP\\ABLddTb|jjiPAaVES]rA@\t-2.02\nHcL@@LdbRbceBDEEP@LIaL[ae]yE@\t-2.02\nHmtD`HPGAJge^Uj``@@X\\UMproDA@\t-2.02\nHcND@NalddUfbR{USUT@LFSBE]yD`\t-2.02\nHedDhAeICI@iBiAiCIIEIyUUL@OHd\t-2.02\nHmT@P@\\HbDjmyjjjh@XSBYS\\LkrB@\t-2.02\nHcNH@JGIIEJeipuUMU@CChSBY]yD`\t-2.02\nHkLDbMLG@~rRQRVPrjjjX@X\\fDwRh\t-2.02\nHmT@P@|HBDjmyfjjh@XSBYS\\LkrB@\t-2.02\nHctL`HS@\\DjevZjij`A`ITwCJ{rL@\t-2.02\nHmvLAHAEbTyInUwaZ@BP@XDUMwHd\t-2.02\nHcvD@AklddUTReUUU@CChSBY]yD`\t-2.02\nsJPKAPR@TAh@p@zOj`GAb@dCHAP@\t-2.02\nHcvD@NalddUfReUMU@CCdpne]y@`\t-2.02\nHeT@`@\\LddTjPsU@@@CCdpj[ayD`\t-2.02\nHeTL@HSLddlRPsU@@@CBj[agfPf@\t-2.02\nHed@P@bH\\DfUfjjj@FD`fES\\L|b@\t-2.02\nHmvDAHAHeNR[e]xV`@h@FEES]OHT\t-2.02\nHmuH@JY\\ddTlRzZjjf@FCPfDL|a`\t-2.02\nHedDPDpFbHaJmYjjj`AatES\\L|`@\t-2.02\nHefD`Naj|LddUfUUUP@pYLJagbMp\t-2.02\nHmVH`FboCIIEUDjjjh@X\\fEproHh\t-2.02\nHeTB@@HYRYgUnjjj`A`HPaMpsqLh\t-2.02\nHclH@@RVUmVy]X@@@@A`vLLkoD``\t-2.02\nHeTL`HS@|Dj~UFVh@@@XUS\\L|PL@\t-2.02\nHmVD@AklddUTtjjj`AatIaMJ|c`\t-2.02\nHeTH`HApRee\\YjB@@AavES\\L|`@\t-2.02\nHedL`@idhLdTTNeUUP@pZLKagdL\t-2.02\nHiDBPHSB@HiprRPzQZj`Aac\\OHH\t-2.02\nHmtH@NrRQRqZUj``@@X\\fDwBoHd\t-2.02\nHmtD@@yJUe^Uj``@@XCBTwCJ|``\t-2.02\nHcl@@DjYU_egX@@@@@XJfES\\Lkh\t-2.02\nKAxQ`HCaDQSaddfLjj`CBhpf{dT\t-2.02\nKAx@PQHIHYHLxYIITjjh@ppj{dL\t-2.02\nHmTD`HPGAJeVZjfj@F@xUMproH@\t-2.02\nHedL`HS@\\DjWfjjj@FCES\\L|PL@\t-2.02\nHmTB@HXUrRQVZZjfj@FCIa\\J|bP\t-2.02\nHedL`HS@|DjWfjjj@FG@UMpsrL@\t-2.02\nHeTD@@gHeDeBwL@D`@psB{fPp`\t-2.02\nHiDD`@iJCIEDUJjj@FCQaMp|a@\t-2.02\nHedL`HS@lDjWfjjj@FCES\\L|c@\t-2.02\nHed@`@\\DjWfjjj@FDaBES\\L|c@\t-2.02\nHmTB@HZUrRQVYRjff@FAIa]rE@\t-2.02\nKAx@`@xTxYIDUJjh@pZDpf{bAP\t-2.02\nKAxH`PpNENFRRJrjj@LJSBknPp\t-2.02\nHeT@@LddTjPsUUU@C@XSBinGdR\t-2.02\nHedL@@pldTTUeUUP@pzDinF^PP\t-2.02\nKAz@dI`Xd^DRdsMUU@FE@UMwH`\t-2.02\nHmVD@NalddUfbjij`A`RXT|PU@\t-2.02\nHiFH`FboCIIETjjj@FEIa\\ODi`\t-2.02\nHeVH@JGIIEJepuUMP@pjDpfyD`\t-2.02\nHefH`D`OAJVyjjj`AavES\\L|`@\t-2.02\nHef@`HkprRQJrUSU@CAdpnF^QP\t-2.02\nHed@`@\\LddTeeUUP@pyLInF^QP\t-2.02\nHefH@NkIIETiUUT@LFaLHYyC@\t-2.02\nKAxHPTtRBRFRGAVRRVZjZ@OHx\t-2.02\nHedF@@PfFTf{nZjf@FAXUMqDd\t-2.02\nHiDD`HPKAJUfjjh@XMaTwCr@@\t-2.02\nHeTH@@RYWZf`@j@AapIaTL|c`\t-2.02\nsNpJIHJPtaZqrFRRVUU@LI^P`\t-2.02\nHefD@NalddUfeUUP@pYLJagdL\t-2.02\nKA|I@]CUxYIHkJjh@pILJnHw@\t-2.02\nsJPBHDJ@t@XBOj`GFRAd@hGI@\t-2.02\nKA|Q`MTRBRFRFRRVZjZ@LH{dL\t-2.02\nHiDD`HPGAJUfjjh@XMaTwCr@@\t-2.02\nKAzQDIdAxAJU\\uUT@XDUMwDB@\t-2.02\nKA|A@PCaddbljj`CAdpj[nQ@\t-2.02\nHiD@`H\\DjfZjj`AarXUMp|b@\t-2.02\nHiD@b@|@eJiUjjh@XRDIaTwB\t-2.02\nKAzA`TtRBRFRFRRUJjY@ODK`\t-2.02\nHaD@`@|DimVzP@@AaVES]q@P\t-2.02\nHiD@`@\\DjVZkj`AarXUMp|`@\t-2.02\nHiDD@JGIIEFjii@FAIaMrN@\t-2.02\nsJPK@ERlUYjpu`ZOj`FEDVH\t-2.02\nKAxA@@xYIHkJjX@pjDpfyG@\t-2.02\nsJPKAVRHTQh`q@zOj`FEDVH\t-2.02\nHiFH@DAIYfZjh@XMaTwCrH@\t-2.02\nsJPKA\\SDVIlPx`ZOj`FEDVH\t-2.02\nsJPK@\\SDVIlPx`ZOj`FEDVH\t-2.02\nsJPKA\\RHTQh`q@ZOj`FEDVH\t-2.02\nsNpLAbWD^HdlmUPCAbXu|b@\t-2.02\nKA|P@UvRRJjji@LBSBkbPp\t-2.02\nHiD`bJ[aArAdjeVj\x7FpAa@@\t-2.02\nKA|P@UvRRJNji@LJaLJnPp\t-2.02\nsNtDHpxTHrRQVjhA`Uc^JL\t-2.02\nKAxX`EWAHIHIMvuMHAxdL\t-2.02\nsNtLJyHJPtaddeUTpCqE`\t-2.02\nsJQBbJBRBdMHCcL_U@OHP\t-2.02\nKAz@@AVRQERjj@LFaLIn@\t-2.02\nsNyhGE`DYIITmT@pvMyF\t-2.02\nsNpIAxBTjUjj@XNKFod@\t-2.02\nsGYhKEaxYIIVj@XYX|e@\t-2.02\nsNyHHpxYIHkUR@pLVOIP\t-2.02\nsNyHGKxYIHkUT@prqxjp\t-2.02\nsNphH{xYIHkUT@prqxjp\t-2.02\nsGXDHGBaBUSUPCCKGbe@\t-2.02\nsNphHpxYIHkUT@prqxjp\t-2.02\nsNqHFGCIIEZjPFAbqyJ\t-2.02\nsOpAMJUKua@@CBqFodp\t-2.02\nsNpH@xYIHkUT@plVMyF\t-2.02\nsNpHAxISMUT@p\\VM_H@\t-2.02\nsGPD@xTHRjZj@XFKGdh\t-2.02\nsNpHHDYIHkUT@plVMyF\t-2.02\nsNyA@qNRRJuT`LCEcrT\t-2.02\nsNtA@QNRQFMU@LBmWrP\t-2.02\nsNpHAXYIDYUT@pLM_Dl\t-2.02\nsGPH@xISuU@LCL[qA@\t-2.02\nsGPHAXISuU@LCL[qA@\t-2.02\nsJPhLQbIKTpCA@|d@\t-2.02\nsNq`@fdvkSHCAX|Rh\t-2.02\nsNp`Adimjj@XYF|TX\t-2.02\nqCaHKBHg`dtpFDGEL\t-2.02\nsGQHI_AJijhAaecrT\t-2.02\nsN|ICVGHLeRmWxCr@\t-2.02\nsJPIAxBX~j@XTQX`\t-2.02\nsGP@DjZj`FEBqoI@\t-2.02\nqCcPQXND^hCBCfbp\t-2.02\nsJQ@@dkU@LBHcrX\t-2.02\nsJPXHlPDQzt@|VH\t-2.02\nqC`PBpcu@^ZK@\t-2.02\nsBQ@@eLUT@pTWI`\t-2.02\nsGY@LDemj`FFVoEB\t-2.02\nHiDL`HS@|Djmujj`A`UMp|``\t-2.05\nHeTD@@QInU~Eh@H@FEHUMwHd\t-2.05\nsNqhHlOCIILVj`FBkxlP\t-2.05\nsGPhHaxIU{U@LD[qC@\t-2.05\nsGQLKIARFdLddmU@ODZ\t-2.05\nHifDAHAHeNR[e^Eh@@@XXSCqJx\t-2.06\nHiDJ@@PfEIn{Zjd@XEaTwDS`\t-2.06\nKAxH@@bSKKTt@XXUMrN@\t-2.06\nsJY@LDejhA`QEnP`\t-2.06\nqCbPPNBUu@XI[bD@\t-2.06\nHcN@B@B\\dbRTJR{UT@@@LEaLinFUwd@\t-2.06\nKA|@D@DiUJuUPA`tIeMwHH\t-2.06\nqCcRQXAFzNlAy@\t-2.06\nQMFi@azM`^P\t-2.06\nHefB@BAAeImgfji`A`RYT|a`\t-2.07\nHiFB@BANEImVZjX@XDfTOHH\t-2.07\nsNx@AddQeUPC@pu|Rp\t-2.07\nsGX@@eOUT@pLqoDD\t-2.07\nQMBCDRZAaGFP\t-2.07\nsGX`JDdrmT@pexlP\t-2.08\nsJQ@@dmU@LLInID\t-2.08\nRF`EECqH\t-2.1\nHkmLAHdDvISdfyWVxV`@i`@XTUMt|`p\t-2.11\nHcMLAHdDvISdfyWWaZ@Bd@FEES]OHT\t-2.11\nHklD@@QIVYYQujjjj@FBxUMprngrH@\t-2.11\nHeTLbHS@|LyJoeQej@@@FATwCq@d\t-2.11\nHcL@@DjU_VnBBJh@FBpfES\\LkrM@\t-2.11\nHiFHA@`IclddqRjjh@XLfES]rA@\t-2.11\nHidL@HP\\ddRNijjj`A`VEP|Qn@\t-2.11\nHidD`HPOAJvUxV`@@AaQTwCr@@\t-2.11\nHidH`DBHR[e^FX@@@XTATw\\`P\t-2.11\nKA|PBA@SGYIIbjjh@piLJfyG@\t-2.11\nKAxQ@HDPdvkMU@FEAaTwHx\t-2.11\nsNyDJQHJPR[nihAaGqR`\t-2.11\nsJPL@xRHTQGuPCCQ[dH\t-2.11\nqCbXXQD|EDIMRA``nR@\t-2.11\nsOx@@drm\\@@@pHV_DZ\t-2.11\nsJPDADIpRVj`FADqyD\t-2.11\nsGPH@DISMU@LBEcqR`\t-2.11\nsNp`ATiujj@XYY|TH\t-2.11\nsJQHHGAJ^j@XYX|`@\t-2.11\nsGX`JDdrmT@pQoI`\t-2.11\nsGP`@deUjPFFqoI@\t-2.11\nqCaPQApcu@XH[bb@\t-2.11\nqCaPAR`RZhCAA\\f@\t-2.11\nsJPdE`DRPcyXAyB\t-2.11\nsGP`@dfUj`FBMyL\t-2.11\nqC`PApcu@XXQ\\f@\t-2.11\nqCx@AYIf`LLE`\t-2.11\n`IE`Cr@\t-2.11\nsJQ`@bdvt`ODl\t-2.11\nHaD@`@bDeeVz`@@AaPXUMqHx\t-2.11\nsOp@DjWkiV`FAbMxlp\t-2.11\nsGX@@djuT@pHVOEJ\t-2.11\nsNxA@IRiVjhA`xlZ~P@\t-2.11\nHcLF@@siWTify^ajjjj@FDpaTwBn|SI@\t-2.13\nHmtLbHS@BL{IIKDeaeZ@B@AaUMpj\t-2.14\nHeUDAHdDbTyInU~Eh@H@FAES]rI@\t-2.14\nqCcQQX^B{]GZ@|`@\t-2.14\nHaF@@@RYWih@H@FA@aUqLx\t-2.15\nsJPhEaDIMsPCBCdH\t-2.15\nRGDQxQP|R@\t-2.15\nsOx@@drm\\@@@phQkyL\t-2.15\nsOp@DjWkjj`FEDVOEV\t-2.15\nQMBCpRZAaWDP\t-2.15\nsJP`@TfVdAxe`\t-2.15\nQMHAIXFE\\d\t-2.15\nqC`@IRtA`enHP\t-2.16\nHevH@DAIemRhYZ`@`@XDwCODP`\t-2.18\nJoC`@@PzTlrj\x7FI{[P@@A@@FDeS\\Lkm|ap\t-2.19\nHk\\D`HP@cIHXheDQgSV@@@@@XMWCNgq@T\t-2.19\nHk]@A@LINTjWvUimLHB@@@A`LHUCJ{qLL\t-2.19\nHclL@@STfUmVfeVi@B`@XEgBoDkP\t-2.19\nHmt@`@\\DjYuQVhHD@A`JES\\Lkq@p\t-2.19\nHmtD`HPOAJUyVUjh@@@XMc\\Lkq@H\t-2.19\nHcnD@D@TfYg\\fWVjA@`@XEtkoHh\t-2.19\nKAxPP]D`daT`taddabjj`CAB{dX\t-2.19\nHidH`HCpRUe^Fh@@@XLaTwCr@@\t-2.19\nKAxX`Pf@DDxYIBeEjh@prf{b@P\t-2.19\nHiFD@L@TeYVjj`AapPaTp|c`\t-2.19\nHid@@DjUfaBB`@FGPfES]rA@\t-2.19\nsNqLKIARCdLddJjj@XKWdH\t-2.19\nsNqDHG@nFRQFUU@LJEj~P`\t-2.19\nsNpdIPxEprRHrjhA`Pl~Ht\t-2.19\nsNpXHlqxYIITuR@payej\t-2.19\nsNt@A\\dbJjj@XVKE|e@\t-2.19\nsNqhHlOAJkVj`FBkyB\t-2.19\nsJPDADQpRVj`FABqyH\t-2.19\nsNp`@dfvZj@XEFodp\t-2.19\nsJPhHaxIUmPCBGbF@\t-2.19\nqC`HCDvHdmPFBFxh`\t-2.19\nsJPhHQLiJuPCCA[dH\t-2.19\nsJXHHOAIZj@XYX|P`\t-2.19\nsJPYHlQxGh}j@XIX\t-2.19\nsFx@@eJf`@@LKEcP\t-2.19\nsGP`@Tizj`FAfMyD\t-2.19\nsGP`ADiVj`FBMxe`\t-2.19\nsJPhH`xQ}T@pfyhb\t-2.19\nqCaPKBHRZXCBCdp\t-2.19\nQMCALhabHzA`sr@\t-2.19\nqCaHK@HdaGe@|`@\t-2.19\nqCbPPNBTu@XI[d@\t-2.19\nsJPH@xQ}T@pTWEb\t-2.19\nRFDEaFCqH\t-2.19\n`IlaHFD\t-2.19\nsNx@@djmUPCAbKF|c@\t-2.21\nqCpPHABRk@XP\\f@\t-2.21\nsJQ@@dsU@LBHmrD\t-2.21\nsJX@@dmU@LLL^JH\t-2.21\nsJXaBDnR[Z`FDwHP\t-2.21\nsFp@DiTt@@AaacsQT\t-2.21\nHeVD`La@BLddlRPrm@@@CBj[agdX\t-2.22\nHif@@@RfU~F``@@XLfES]q@D\t-2.22\nsJX`LDdvu@LInID\t-2.22\nsJP@DiZhA`QEnP`\t-2.22\nsJP`@TfZhA`QEnP`\t-2.23\nsNp`@dfVZf@XJodH\t-2.23\n`IK`Cr@\t-2.23\n`IG`Cr@\t-2.23\nHmVD@NalddUfRjij`A`rXWCOHT\t-2.25\nsGP`@dfui`FBuxdP\t-2.26\nsFp@DiTujdA`QC^IX\t-2.26\nHed@H@\\HbDbLbLddjRUUUP@pFDpj[ayD`\t-2.27\nHmtF`HSBEP|LddqbbeVjjj@FEXULODzP\t-2.27\nHeT@pHdDdLdLddlRPsU@@@C@jxYyC@\t-2.27\nHiDHHNbPRPrPYprRRiJjj`AaaTOHX\t-2.27\nHcND@LADfuYU]Zj@@@FGYWCJ{qDH\t-2.27\nHeTHbACpBTieUzZBA@@XLfDwSq@h\t-2.27\nHeTD@@YIfUqfhH@@FG@UMpsqHp\t-2.27\nHefD@NalddUfUUMP@piLKiy@`\t-2.27\nHifH@JGIIEJnFjih@XUBXS\\c`\t-2.27\nHiFL@BAAR[eVji@FAIa]qJX\t-2.27\nsNplJyDJHtQddeeTpCCQ[dX\t-2.27\nKAxQ@PCaddblji`C@dpfyG@\t-2.27\nKAxQ@PC`eUkUU@FCIaTw\\b@\t-2.27\nsNpBIHJPt`wCIIJjj`FBMyF\t-2.27\nHid@@DjWffB@h@FEPf\\OHX\t-2.27\nKA|P@XBRvsUT@XLfES]rH@\t-2.27\nsNqLKIARFdLddjjj@XQ|a@\t-2.27\nKAxH@MvRRJrjf@LBSB{dP\t-2.27\nsGPLIHJPtaddejhAaCrT\t-2.27\nsNqHHGCIIEZj`FAVKyJ\t-2.27\nsGPD@xRHRjzj@XFKGdh\t-2.27\nsNpH@xYIHkUR@plVKyJ\t-2.27\nqC`DAhdPhcQD^hC@bK@\t-2.27\nsJQdHl@`nFRPkPCq@`\t-2.27\nsJQHHGAJzj@XYX|P`\t-2.27\nsGXHI_AJijdAaecrT\t-2.27\nsGPH@xIUMU@LBl[rP\t-2.27\nsGX@JeTuT@pJqoI@\t-2.27\nqC`PApcu@XP\\tV@\t-2.27\nsJPYHlQLGh}V@P\t-2.27\nsJQa@bnR[ZPGdp\t-2.27\nsJPYHlQVGh}V@P\t-2.27\nRFBCQQDXLJy@\t-2.27\nQMBBpchGfR\t-2.27\nRFDAaFCqH\t-2.27\nKAxP@@djkUU@FGABXUMrN@\t-2.27\nQMbDBDePXQrP\t-2.27\nsJP`@deVhAaCqS@\t-2.27\nRFD@QFCBNT\t-2.28\nsJP`@TizhA`inID\t-2.28\nsGP`@Tivj`FBfxeP\t-2.29\nsNx`BDdw[UPCCXwbS@\t-2.31\nsGP`@dfyi`FBMyD\t-2.31\nsJPD@DDHRgj`FFDwDb\t-2.31\nqCaPQCpcm@^XK@\t-2.31\nqCa@CIKTA`hnHX\t-2.31\nqCb@AIj`LDmqB@\t-2.32\nsGP`@TeYf`FBUxhP\t-2.33\nHeVLAHAIbTyInU~Eh@H@FAES]rI@\t-2.33\nsNpYHlQxGlddqZj@XR|VX\t-2.33\nHeTLbHS@BL{IIKDdLkP@@@pJfx^QH\t-2.33\nRG@D\\OJ@\t-2.33\nsGP@DiVj`FADVxcP\t-2.33\nj`q@@@DjU_VUiqw``RX@@@A`ZBBTYpVcV]{bLR@\t-2.34\nHkLLxJ[hBLdBdAdIdMdCdBbHaHaHbXjejj@Gb\\h\t-2.34\nJoBDH@QPIPIRlrjzv[uP@@@@@XKS\\Lkiv\x7FDa@\t-2.34\nJoB@H@^E^BTrj}ktv}AA@@@@FFiaMtkiv\x7FDB`\t-2.34\nHg\\BPHP{@HTHrRPqIIZSjtBDJ@CCbinF]yB`\t-2.34\nJoBF@DHNRRIGSQITuoUUT@D@AaNEPkiv\x7FD[`\t-2.34\nHctDHDXGBHbgBWCIILYDYUUUP@pzLKaW^QH\t-2.34\nHmTHHDBHapIpzHrJIQRrjjj@F@aeMproD``\t-2.34\nJoB@P@NBULrj~mf}P@`@@@FAxUMprng[|`@\t-2.34\nJoBDPDAxIU\\vjzv[mP@@@@@XKS\\Lkiv\x7FHH\t-2.34\nHk\\@b@B@eJYeUquSh@@@@@XKaTwCJz_H@\t-2.34\nJoBD@@ISJlzoJ[tD@@P@@XJfDwCNf\x7FHl\t-2.34\nHknD`La@BLddJbRvWUjB@`@XMc]JgqJD\t-2.34\nHcNBAHAIvISdfyWWaZ@Bd@FAES]rE@\t-2.34\nHedLPHFP\\JBLddRaeUTh@pKB[nHe@\t-2.34\nHefD`La@|LdabbeUUP@pxBinF^IB@\t-2.34\nHcLD`HP@cIHXhhjJk@QD@CBfxYwd@\t-2.34\nHmUH`Dr@|DjUyjjjh@XBATwCJ|QL@\t-2.34\nHcNB@D@agHhhdmCSMURu@CCLY^Qh\t-2.34\nHed@P@BH|DfUfZjj@FD`fES\\L|b@\t-2.34\nHmv@@@rRJEKKaj@BP@X\\fES]OHT\t-2.34\nHcLD@@QIe^UWVj`@@AavEprn|b`\t-2.34\nHiDHHJbPRPzPFPrRPqRjZ`AxaL\t-2.34\nHidH`HApRkm^Fh@@@XMaTwCq@`\t-2.34\nHmt@@DjU_ZxHHj@AaLIaTwCOHT\t-2.34\nsNpJIVJPtaYArFRRVUU@LINP`\t-2.34\nHiE@`HPOAJ[fjjh@XMaTwCq@P\t-2.34\nHiDD@@kIEDUJjj@FCQaMp|a@\t-2.34\nHiF@`HApRjYjjj@FCXUMp|a@\t-2.34\nHaDH`HCpRVU[j@@@FEXUMwH@\t-2.34\nHaE@@@yIe^f`@`@XTBXU\\c`\t-2.34\nKAz@@AVRQERij@LBSF{bPP\t-2.34\nKA|H@DFIS[UUPAadMwDR`\t-2.34\nsGPdH`xEprRHuT@ppuxdP\t-2.34\nsNqTHmV@`aFRPjKR`ODB\t-2.34\nsNx`BMdbaeUPCCRobV@\t-2.34\nsNqHDHaImYj`FAFMyF\t-2.34\nsJQHBLQIfi@XHSbV@\t-2.34\nQMIDbKpRYAaGJ@\t-2.34\nsJT@@Te^lAyD\t-2.34\nQMBCDRZA`cr`\t-2.34\nQMBApRYA`sr@\t-2.34\nsJPYHlQxGh}j@^IX\t-2.34\nsGP@Djyj`FFbwDZ\t-2.35\nHaE@@@yIe^f`@`@XDfEWDC`\t-2.35\nsNx`DJdrkUPCCHwbs@\t-2.38\n`IaphFD\t-2.38\n`IiApD\t-2.38\nsGPXHlQxIU[U@LInHt\t-2.4\nHet@@LddTQbMpuUUT@LAaLJfz^PH\t-2.41\nHcLH@@RfyY^Vjjjh@XKFES\\LkoHP\t-2.41\nHet@@DjYUZ^D@@@@A`rDwCODr`\t-2.41\nHidD@@QInUxV`@@A`REP|Qn@\t-2.41\nHiDB`HRnApReYjif@FBLOH@\t-2.41\nHaDH@@Rfu[j@@@FAIa]qJX\t-2.41\nHaF@@@RVU[n@@@FAXUMrN@\t-2.41\nsGQHHGAJmjhA`Uc^HP\t-2.41\nsJQDHG@nBUMT@ppVyB\t-2.41\nsJXHHOAIYj@XKGbB@\t-2.41\nqC`P@HRVhCCBKdp\t-2.41\nqCbPPND^hCCA[d`\t-2.41\nsJQ@@dls@LEcrP\t-2.41\nQMJDbDf`XQqd\t-2.41\n`Ld`\\WaB@\t-2.42\n`Ld`XP\t-2.42\nHeT@@LdbbQwCUUU@CBPaBinF^Q`\t-2.44\nsGP`ATf]jPFDWEb\t-2.44\nHclD@@QIeYWieujP`H@FEYpsoHT\t-2.45\nKAxA@AbIJjuUPAapPfES\\c`\t-2.45\nqC`PCDRVhCAA\\Tp\t-2.45\nsJX@@dku@LDmrD\t-2.45\nQMPBcXGcH\t-2.45\nsGQ`@jdvmR@pfxdP\t-2.46\nj`aA@@NYIHiXihYIFj``hj@@XRQ`gIFl{wHJ@\t-2.48\nHg\\@xHdDdLdNdIdMdKdLddlTTtrgUADQ@@|`p\t-2.48\nj`aaP@NPXkSlddUfbbaVcUTuMSP@LJHpRUnP|\t-2.48\nh`\x7FC@@B`qVRRJsSQZRjfjjh@LEHpS`iZl{p\t-2.48\nHmTLhJ[hBDdLdBdA\\LddTgRjej`A`dkrA@\t-2.48\nHcLHPHApiprRQUQIKmUP@@@pELKae]yE@\t-2.48\nHo|H@NrRQRqZZR]j``bh@FDiaMtg[|cP\t-2.48\nsNpJE@Z@LAXApBUSUU@NJdCHAPJ`M@yH\t-2.48\nHg}@@@aJVYU^Svv`@@@@AaITwCJz_Hl\t-2.48\nHiD@H@\\HbDbLbLddjRjjh@X]BXUMwHD\t-2.48\nHo^L@AaerRQVZYJRjfjj`AaJXWCIvx\t-2.48\nHmu@`HZoCIIEUDiVjZj`AarXWCJ|b`\t-2.48\nHiD@HH\\DdLdBdLddTjjjh@XES\\OH`\t-2.48\nHkND@NalddUfRdjijj@FGIa\\ngrA@\t-2.48\nHedLPHS@\\J\\LddQTeUMP@phfxYxbX\t-2.48\nHcvL@NamrRQVYQUTuT@LNSBxYwdJ\t-2.48\nHiDLPHS@\\J\\LddUdjjh@XDS\\ODS@\t-2.48\nHiDDPHXGBgCIIEYjji@FEIa\\ODi`\t-2.48\nHeTD`HPOAJ]eQfj@@@FCYS\\L|PD@\t-2.48\nHmLH@ARjZYjZVjjZh@XMaTwKrI@\t-2.48\nKAxI`UtQBQFQFRRUJji@LBaLKdL\t-2.48\nKAxX`Pw@xTxYIHkJjh@pILJnHw@\t-2.48\nHiFL`FaL@HrRRiQZj`AafEWDxP\t-2.48\nHeV@@JrRQRiCMT@@@LJSBZ^Ip`\t-2.48\nKAxX`Pw@xUPYIHkJjh@pqLKbMp\t-2.48\nHmVD@AalddUffjij`A`rXWBoHd\t-2.48\nHefL@H[aRjUVjjh@XCBXUMp|bP\t-2.48\nKA|Y@MBX@QddeRVj`CCLJnHw@\t-2.48\nHiFL@H[aRjUZjj@FGPfDwCrJ@\t-2.48\nqC`FB`d@hCP@zOTAqh`I@rAr@\t-2.48\nKA|AP\\dad`TaT`t`eTuUU@Gd\\\t-2.48\nsGQLJhCPA`DjfjPGFRAd@hGI@\t-2.48\nHiE@`HZoCIIEUJij@FEIa\\OHh\t-2.48\nHid@@DjUfaBB`@FEPfMwLJa@\t-2.48\nKAxY@PwUXYIHkJjh@pqLKbMp\t-2.48\nHiF@`DApRjZZjj@FCXUMp|a@\t-2.48\nKA|H@XCIKJuUPA`pQaTwDS`\t-2.48\nKAxH@AfRJIFjj@LJaJ[nPP\t-2.48\nsNpdHpxV`rRQVjhAaecqU`\t-2.48\nKAxX@PwYIHkJjX@pqLKd\\\t-2.48\nHaD@@DiUVyjjPA`HPfES\\\t-2.48\nsNplJyHJPtaddeeTpCBL\t-2.48\nsNphH{XYIHkUT@prqxjp\t-2.48\nsGQDHG@nFRQFj`FABuyB\t-2.48\nsNx`LFdlmUPCBbXobU@\t-2.48\nsNqHHGCIIEZjPFAVKyJ\t-2.48\nsGXLKIARFdLddmT`ODZ\t-2.48\nsGYHEAxIVuU@LMc^XQ@\t-2.48\nsJPiLQxBTiZhA`Xl^P@\t-2.48\nsGPD@xVHRjZj@XEXwd`\t-2.48\nsGXHHGAJijhA`Xl^R`\t-2.48\nsGQII[B|eTuT@prqyJ\t-2.48\nsGX`LDdwUT@ptMx``\t-2.48\nsJQhHlGBOj`FDOME`\t-2.48\nsJQLCIARFdH~j@^P`\t-2.48\nsJPD@xPHczhAaecrP\t-2.48\nsJQHHGAJnj@XI[fDH\t-2.48\nsNp@Djfjj@XUXu|d@\t-2.48\nsGX@@dkUT@phVMyH\t-2.48\nsFp@DiTt@@A`qEcP\t-2.48\nqCcPQXVD^hCsQX\t-2.48\nsJQAINczhAaeb\t-2.48\nqCcPQXZT]TCr@\t-2.48\n`IB`Cr@\t-2.48\n`IDpCr@\t-2.48\nKAxX@ASIRjuUPAaTIaMrN@\t-2.48\nqCc@AYIj`OBHl\t-2.48\nsNq@@djmUPCAbKF|c@\t-2.49\nHg~@@@RYfUWd}nh@@@@@XJUMprng_DB@\t-2.49\nsJPHADIJuPC@bK\\a@\t-2.51\nsNp`ATf^ZZ@XYY|e@\t-2.51\nQMIDbKpRZAaGFP\t-2.51\nsNq`AVeJmUPCBqXwdX\t-2.51\nsGQDHGBnBUSUPCCKGdh\t-2.52\nHeTH@@Re[TYj`@@AatIS\\L|``\t-2.53\nsJP@DjvhA`inID\t-2.53\nQMH`yIhFD|h\t-2.54\nsGP@DiVj`FEDVOIP\t-2.54\nHmtH@@RYeeZZjjj@FBpfES\\Lkr@@\t-2.55\nHmND@DCdfVUrjUZ`PH@FALLkrD@\t-2.55\nHaDH`HCpRnU[f@@@FEXUMwH@\t-2.55\nHaDH@@RVU[j@@@FCAFES\\c`\t-2.55\nsJPhLQDIKTpCBCba@\t-2.55\nsJXHHGAJZj@XYX|`@\t-2.55\n`Jg@XP\t-2.55\nKA|X@DB\\dwNuT`FFIa\\Rf@\t-2.55\nHmtD@@QIgYVUZh@@@XLS\\LkrL@\t-2.56\nHeTLbHS@BL{IIKDdLkP@@@prf{bCH\t-2.57\nHidH@@Rge^Fh@@@XMATwCrD@\t-2.57\nsGQhHbGAJ^jXAaKqA@\t-2.58\nsGX`BDdwMT@pVODj\t-2.59\nsNy`BDtfuZi@XIGbu@\t-2.59\nqCbPXXbRt`XP\\TP\t-2.6\nj`q@`@@LRYfWg^Qg^jB`@@@@FA`DhpTeZMYwnHa`\t-2.61\njhip@@@P\\eKLjo}HvkM@@@EP@@pTRcNBdkW`|aX\t-2.61\nj`q`@@@IToLjoiuoUT@@@@@C@tDLxJRmFl{wHX@\t-2.61\nJoB@P@^BULrj~mf}PA@@@@FA`UMprng[|c@\t-2.61\nHg|@b@|@eJf[U^Svz`@@@@AanES\\Lkiwr@@\t-2.61\nJoC@@@IRlrjzv[uP@@@@@XGBTwCJz]or@@\t-2.61\nHg|H`HApRkfUWd}nh@@@@@X[ATwCJz]|`@\t-2.61\nHg\\B`HSM@HrRPjIIHjZuAAD@CCj[ae[yF`\t-2.61\nHmT@XDdLdJdFdAdIdLddTaajjj`AaG\\Pe@\t-2.61\nHkmLbFvDp@cNrRRiQIY]Vjjj`A`qUproHL\t-2.61\nJoB`@@Ndrnlktqw@AP@P@A`hIaUJz[|c`\t-2.61\nHcm@A@tIvTiWYTjWP@`@@@XCBXWCJ|PM@\t-2.61\nHcMLbFvDp@cNrRRiQIKjuUUP@pXjxYWdZ\t-2.61\nHk\\@`@|DifUWGUNjjjj`A`\\IaTwCJz_H@\t-2.61\nHedDpHhG@gCgCIHcEiUUT@LNAL[agdD\t-2.61\nHcLD`HP@cIHXhdhLk@PT@CBfxUwfAT`\t-2.61\nHcLD`HP@cIHXdlipk@AT@CBfzUwf@U@\t-2.61\nHcL@@LdbRbUeBDEEP@LAcFxYW^Ha@\t-2.61\nHcL@@LdbRbceBDEEP@LAaL[iW^IP`\t-2.61\nHid@`@\\LdbaRxZ`@@AarXUMp|`@\t-2.61\nKA|P`E@NENFRQERjj@LJSB[nHE@\t-2.61\nHiDNQHSB[a@XhXKa{IICiEjV@D\t-2.61\nHmw@@@`Tke]fy`@j@A`vESRoH`\t-2.61\nHidH`HCpRkm^Eh@@@XTUMp|PL@\t-2.61\nHidD`HPOAJ^UxZ`@@AaQTwCq@P\t-2.61\nHeT@@DjYoIjjjh@XJDIaTwCH\t-2.61\nKAzQ@IdAxIUsMUPA`QTw\\`@\t-2.61\nsNxTMEV@`aFRPjKR`OLLP\t-2.61\nsGXHHGAJfjhA`Uc^P@\t-2.61\nsGQHDHaImfhAaacrT\t-2.61\nsJPDAHJPR[j`FDwEB\t-2.61\nqCbB@\\duPFBVyH\t-2.61\nQMFAjAIhFBOJ@\t-2.61\nHifDAHAHeNR[e^Eh@@@XXWCqJX\t-2.61\nsGQ@@eKuT@ptqxeP\t-2.62\nHaDH@@RVU[f@@@FFXW\\rJX\t-2.64\nKAxX@@gILjmUHA`aMqLh\t-2.64\nsJQ@@dkU@LBHmrD\t-2.66\nJoBBXBwD`dadaddebbTRtj[uTaPI@@XDpz_H\\\t-2.67\nHmtLbHS@BL{IIKEDiUZ@`@A`S]J|`P\t-2.67\nKAx@P@xQDIDYDYIITjjh@pZDpj[d\\\t-2.67\nHcLH@NrRQRqYRmTDA@@pYLInWbCh\t-2.67\nHkLF`HSNgP\\DjUYfjjYf@FFBi|`@\t-2.67\nHmVL@NaerRQVYJjfj@FCIa]J|`P\t-2.67\nHedL@@pdie]jjj@FCIS\\L|b@\t-2.67\nHedL@HZ\\ddUfUUMH@pILKnPH\t-2.67\nKAxX@AaYHhdZjh@pIJ[nIA@\t-2.67\nKA|X@QS\\eUkUU@FCIaTw\\b@\t-2.67\nsNpDHDTHrRQVjhAaXl[rL\t-2.67\nsGPDHDTHRjZj@XFKGdh\t-2.67\nsGQHHGCIHcUPCCKWbA@\t-2.67\nsNx`LDdvkUPCAY|rM@\t-2.67\nsGXHHGAJijhA`Uc^R@\t-2.67\nsGQ`AbeLuT@pRoMLP\t-2.67\nsGX`LJdmuT@pHaoDl\t-2.67\nsGXHHGAJijdAaecrT\t-2.67\nsGPHHDIUMU@LCEcrT\t-2.67\nsGP`Adinj`FBUxhP\t-2.67\nqC`PALcu@XZK\\`@\t-2.67\nsGQ@@dsmL@pruyB\t-2.67\nQMIBhF`chGcH\t-2.67\nqCp@BOTAahl\t-2.67\nRFTQVQP|`\t-2.67\nsNp`@dfUZj@X[E|e@\t-2.68\nHaDH@@RVU[j@@@FCQaTw\\`@\t-2.68\nsNpHAbIJkUT@pXbqoHp\t-2.69\nqCb@AIVPLDmrP\t-2.69\nsGQ`@jdvmR@|rq@\t-2.69\nsGQ@@djuT@phbqyJ\t-2.7\nJoC`@@PzTlrj\x7FI{[P@@A@@F@eS\\LkoDmp\t-2.72\nHeTDPDp@bHcIIKDdLrp@@@pjJ[ayD`\t-2.72\nHiDDHJZIAICi@YCIICEJij@GbDp\t-2.72\nKA|Y@UBXGaddeTZj`CCDpnHw@\t-2.72\nHid@@DjUfaBB`@FGPaTwCrL@\t-2.72\nsNyhKEaxYIITuT@prqxjp\t-2.72\nqC`XBHc`haIj`LLEnR@\t-2.72\nqCcRQXCFzNlAy@\t-2.72\nRFTEPQ`|R@\t-2.73\nsGP`ATiVj`FFbwDZ\t-2.74\nHaE@@@aJyUnX@@@XEaTwDc`\t-2.75\nsJPXHlQxQ{T@pbxlP\t-2.76\nsJX`BDdvu@LH^IX\t-2.77\nHid@`@\\LdbaRxZ`@@A`rES\\ODC@\t-2.78\nHmLD@@QIe[VfeVi@B@A`V\\J|Ri@\t-2.78\nHedJ`HSFDGAJeyjjY`A`gSq@p\t-2.78\nsJPD@DPHRnj`FFFOED\t-2.78\nsNp@Dj{Zj@XFKGbk@\t-2.78\nqCa@CISTAaEqS@\t-2.78\nHefD@NalddUfUUMP@piLKayD`\t-2.79\nHiFL@BAAR[eVji@FAIaUqFx\t-2.79\nsNpP@btf{Zj@X[E|Rh\t-2.8\nHiD@XHdDdLdFdNdAdLddjdjjh@^PP\t-2.8\nsNp@DiUjj@XLQXwdX\t-2.81\nHo|DpHhG@gCgCIHcDhhd[^jjB`@@XZBYprng[|``\t-2.83\nj`q@`@HRRjyeU\x7FSk^j`B@@@@FAhTYpTeZMYwnPH\t-2.83\nHglLXDp`BJdFdA\\IdEdLddTaLTdmUUT@LLt{yG@\t-2.83\nj`q@@@LddTjVTRPiN}U@A@@@@LMHpRcNBtZsnP|\t-2.83\nHo\\LxAgTdLdBdJdFdKdGdLddTgfTtjjffh@^PX\t-2.83\nJoB@Y@RGTCrG\\drnlktqw@AP@P@A`JXURngrN@\t-2.83\nHg^DHNihBDdLdBdLddTgTRQwUKP@@@pjUt{yG@\t-2.83\nHcvBXNiev@aICI@i@Pb\\CIIEIxiUKTh@pb^PH\t-2.83\nJoB@Q@^@ReSLjokYoT@P@@@A`^ES\\Lkiv\x7FH@\t-2.83\nHkLLpHS`\\J\\F\\LddRLbdjjjj@FGXPrngrN@\t-2.83\nHmTHXERPrPjPZPFPfPrRQRFFjjj@FB\\oHH\t-2.83\nHcvFPJaLe]CpGprRRjKRMUTt@LFSBY]yG@\t-2.83\nHmVBhNiiV@aICI@i@PcIIEIuJiZT@XQwHD\t-2.83\nHcLHpMbPRPrPrRRjIKRmU@A@@pinF]yA@\t-2.83\nHmVFPJaLFUCp{prRRiJQjjZ@FCIaMJ|b`\t-2.83\nHo~D@NalddUfRbRmzjZ`@@AaJXWKiv\x7FHD\t-2.83\nHk\\@b@a@eJYeUquSh@@@@@XKaTwCJz_H@\t-2.83\nHk\\@`LhDjU^ukmLHH@@@A`lHU\\Lki|c@\t-2.83\nHmTDHNFIAICIAgCIIJeDjjjh@XDURoHX\t-2.83\nHmTJhJ[iV@aICI@i@PcIIEIuJiZT@^PH\t-2.83\nHmVHHFjIAICICgCIIKMEJijh@XXLkrN@\t-2.83\nHedLjDp`BJdFdAdIdB{IIEIyKUT@OHx\t-2.83\nHedDpHXGBg@WCIIEXmUUT@LFSBkiy@`\t-2.83\nHmM@`HPOAJYeWaeZjjj`A`NES\\Lkr@@\t-2.83\nHeTL`HS@\\LddlRPsU@@@CBj[agfPf@\t-2.83\nHmVD`Naj|LddUfTjjj`AarXUCJ|Qn@\t-2.83\nHmVHpHxGBYAYCIIEKCJjfh@XDfDwHD\t-2.83\nHcw@`H[j|LddUbbeTuU@CAdpYW^HU@\t-2.83\nHkLL`HS@\\DjUYfjjjj@FDeS\\Lki|`@\t-2.83\nHmW@RDp`|Hq@eJkfZjjj@F@aEMprh\t-2.83\nHmWHbDphCpBTjnYjjjh@X\\EMproH`\t-2.83\nsJPKAXR@TAh@p@zOj`GAb@dCHAP@\t-2.83\nKAxX`Pw@xUxYIHkJjh@pILJnHw@\t-2.83\nHefH`FboCIIETiUUT@LFSBxYxeL\t-2.83\nHmTH`HApRjyfjjj`AaJXUMproH`\t-2.83\nHeT@@LddTjPsU@@@CAdpjZ^Ip`\t-2.83\nHaD@P@bH\\DeeVz`@@A`pXUMwH`\t-2.83\nHiD@`@\\DiVZjj`A`LIaTwCr@@\t-2.83\nHiD@`@lDiVZjj`A`LIaTwCr@@\t-2.83\nHed@`@lDjWfjjj@F@paTwCOHp\t-2.83\nHig@PBhPdDdDfyWaj@@@GfPw@\t-2.83\nsGPBIDJHtQXcIIKUPC@qZ|a@\t-2.83\nsJPKAyRHTQh`q@zOj`FEDVH\t-2.83\nHiFH@FcIIEUJjj@FEIa\\OHh\t-2.83\nKAzA@P`^BTlsUT@XDUMwDC@\t-2.83\nHed@@Djffjjj@FGXUMpsrD@\t-2.83\nsNxBLIAREdGHIMmUT@|tq@\t-2.83\nKA|A@HC`eTuUU@FEXUMwHP\t-2.83\nsOpIMP[djWkB@@FEbM_I`\t-2.83\nsNpL@xVP\\`eTuUPCCKGd`\t-2.83\nsNtIH`DBTifjj@XGFod@\t-2.83\nsNtIHaxBTifjj@XGFod@\t-2.83\nsNp`H|ddUjj@XYX|UX\t-2.83\nsNq`AbeMmUPCCJod`\t-2.83\nsJPD@xRHczhAahmrD\t-2.83\nsJPXHlQDQzl@pa@\t-2.83\nsJPYHlQDCh}U@P\t-2.83\nqCcPQXAD]TB\t-2.83\nsNqThmVO@~Fy|eWsTpCq@`\t-2.83\nsGP@Dj}j`FFfODj\t-2.86\nsJQ@@drt`LDmrD\t-2.86\nqCr@HIJlAyL\t-2.86\nsJP`@TeVdAaEqS@\t-2.86\nKAx@@IRjuUPAapPfES\\c`\t-2.87\nHeTLbHS@BL{IIKDdLkP@@@pJnF^Pp\t-2.88\nHeTLbHS@BL{IIKDdLkP@@@pJfz^PH\t-2.88\nsGPD@DDHRgZj@XDSGbU@\t-2.88\nsNpXHjpTIRkUJ@p`xlP\t-2.88\nsJQhHbBaJ^i@XP\\Rp\t-2.88\nsJPYHlPDGh}Z@XS@\t-2.88\nKAx@@YIDTjjh@pXDpj{bPp\t-2.88\nqCaPS@hRVdCqA@\t-2.91\nsJQhHlOBOZ`GfVH\t-2.91\nHk^@@@RfYU\\]Tz@@@@@FBaaTwCJ{rC@\t-2.93\nHeU@@@gIHhTmpu@A@@pYLJf{dR\t-2.93\nHiFD@DBlbbTLZjh@XTfUp|Pf@\t-2.93\nHefD@DBdfV^Zjj@FCIaTL|Qn@\t-2.93\nKA|H@HAIMwMUPA`VDw\\QJ@\t-2.93\nsGPHAbIJmU@LJHl^R`\t-2.93\nsOx@@drm]UT@pxbqk@\t-2.93\nsJQHDHaInZ@XH[dH\t-2.93\nqCcAAY]nRYhCbRp@\t-2.93\nqCcAAY]nRYhB\t-2.93\nQMBApRZA`sr@\t-2.93\nHmt@h@dBdFdAdEdDfYn~fBHb@AyD`\t-2.94\nQMFAjAIhGfR\t-2.94\nQMhDRUAyH\t-2.96\nRFDUAFCqH\t-2.96\nqCp@AI^`LHnS@\t-2.96\nHgnB@NamOIIEYeEEUSUM@CCdpnD{yB`\t-2.98\nHmtD`HHIeIUYVUjh@@@X\\BXwCOHT\t-2.98\nsGPBE@Z@LAXAJijhApT`Y@JATCd`\t-2.98\nHiDDpJFIAICICIIKLjii@FDMrN@\t-2.98\nHaDH@@RVU[f@@@FEQaTwHx\t-2.98\nHaFD@DCdfYRYje`A`fMrJ@\t-2.98\nsNpdHpxWprRQVjdAaecrT\t-2.98\nsNpXHmPxYIDYUL@pcy`l\t-2.98\nsNqHHGCIIEZj`FAVMyF\t-2.98\nsNqHHGCIIEZjPFFVOEV\t-2.98\nsJPD@xRHczhAaIsKD\t-2.98\nsJPD@xQpczhAaecrP\t-2.98\nqCc@AYIj`LINXK@\t-2.98\nqCpB@SGZ@pRwI@\t-2.98\nQMFIJrMP^P\t-2.98\nqC`@Qv`LEErX\t-2.98\nqCbPPSJRu@XHKdp\t-3\nQMJHfTf`XQrP\t-3\nRFTQLq`pce@\t-3\n`IC@Cr@\t-3\nsJQ@@dkU@LLInID\t-3.01\nsGX`LDdrmT@pfxcP\t-3.01\nHed@xDkLdBdJdFdAdIdLddTgeUUP@paNQp\t-3.02\nHg|@`@bDfYeUyO[j@@@@@FF`UMprng_H`\t-3.02\nHidD`HP@cIHXdnEX@@@XHw\\HBhP\t-3.02\nKAx@`ADPxILsUUPAapIaTw\\b@\t-3.02\nKAxQ@PC`eWMUU@FCIaTw\\PH@\t-3.02\nKA|A@PG`dsMUU@FCIaTw\\`@\t-3.02\nHaDD@HSIIDcSUUT@LBpj[d\\\t-3.02\nsNxTMEV@`aFRPjKR`LInHD\t-3.02\nsGPdIPxEprRHuT@ppVxcP\t-3.02\nsOp`Hdjekjj`FFqoHp\t-3.02\nQMFIBbN`XQqd\t-3.02\nRFTPTQ`|R@\t-3.05\nRFDGaFCqH\t-3.05\nHk\\@@DjU^ukmNeZ@B@A`LHUCJ{sLxp\t-3.06\nHeTD@@QIUeQej@@@FEYS\\ODbP\t-3.07\nHig@@@`Tke]nX@H@FAXUMqHD\t-3.07\nsOx`DFdrikTl@pVoH`\t-3.07\nsNp`AdenZj@XEZoba@\t-3.07\nqCbPPNBUt`XI[bD@\t-3.07\nqC`PApRZhCCQ[d@\t-3.07\nsJQDHGCNBT}T@pRODL\t-3.07\nRFTPLQP|`\t-3.09\nHcMLbEvDp@cNrRRqIYCJt@D`@pJfx^Qh\t-3.11\nHg^@B@B\\ddRRTjQwUUP@@@pNDpfxYWSl\t-3.11\nHo~J@Naeu|ddUfbbatzjZfi`A`RXT|bp\t-3.11\nHmtHpBbPRPrPrRRjIJUjh@@@XDwCOHT\t-3.11\nHmt@`H\\LddUbReZj@@@F@iaMproH`\t-3.11\nHkND@NalddUfRTjijj@F@ia]Jz_HD\t-3.11\nHiDHhARPrPJPjPZPrRQR^jjPAyG@\t-3.11\nHiDDPHPGBgCIIEYJjj@FEXS\\OHP\t-3.11\nHmTB@@SarJIIPijij@FADtkrL@\t-3.11\nHeV@B@B\\ddTjPsU@@@C@Tpj[ad\t-3.11\nHefD@AalddUfeUMP@piLKayD`\t-3.11\nKAxH`EpRBRBS]mSR@XQWDa`\t-3.11\nHiDL@HX\\ddUfjih@XDfDOHx\t-3.11\nsNpLHxVH\\PeTuUPCBkFod`\t-3.11\nsNyLGYHJPtaddeeTpCrL\t-3.11\nsNqhHlIIJeZj`FFM_H@\t-3.11\nsNx@@eRmUPCAqXu`\t-3.11\nQM@HvA`sr@\t-3.11\nHiDB@@SaRYUfjf@FBDwDpP\t-3.13\nHo~B@LAEwHhddhhd[]jjA`@@XCaCNg[|b`\t-3.15\nsJPIAxBTeZhA`Xl^P@\t-3.15\nsJP`AdizhA`d^R@\t-3.16\nRFBDQADXLHyP\t-3.17\nj`q`@@@YIEBedhdnB]zh@IiX`@XJQ`eF\\tZsnHex\t-3.19\nHglHHDApbHipVHrRSJJJ^UUUUP@pvLInFUt{yE@\t-3.19\nJoBD@@ILrkNx{[uA@@@@@XZAUprng[|RL@\t-3.19\nHg|@`@\\DjYmUyO[j@@@@@FFxUMprng_H@\t-3.19\nHctHPHApIprRIQQNUUUT@LEALinFUwdD\t-3.19\nHgmH`Dr@|DjV^Yjjjjh@XZATwCJz]|c@\t-3.19\nHiDHPHApqprQJHrjj`A`rES\\ODC@\t-3.19\nHmW@@@H\\dbabLjfj`A`rXwRoHh\t-3.19\nHiE@`HPOAJUfjjh@XMaTwCs@a@\t-3.19\nqCq@XIIV`OEL\t-3.19\nHiF@B@BTjeVjj`A`LIaTwB\t-3.19\nsJPHAbIJuPC@bK\\a@\t-3.21\nHg^J@Naev|ddUfbbNgUSTtp@pqLKdR\t-3.23\nHiFD@AalddUfjih@XDfDOHx\t-3.23\nKAx@@YIHkJjh@pZDpj[d\\\t-3.23\nsGPDHxVHRjZj@XEXwd`\t-3.23\nsNq@GddbmUHCCKGbe@\t-3.23\nsNpH@xYIHkU\\@prqyF\t-3.23\nqCcPAZTBSU@^XK@\t-3.23\nsOx@@drm\\@@@pHQoEf\t-3.25\nRFBDQ^DXLHyP\t-3.25\nHiDDHJZIAICi@YCIICEJij@FDMrB@\t-3.27\nsGPdCQHJPR[jf@XR|d@\t-3.27\n`IJ@Cr@\t-3.27\nHg|@@DjU_eZx{BBH@@@FBpaUtkiwqLX\t-3.31\nHo\\DxM]ICI@iAiCi@YBYCIIEIYGLjjjii@FDGrK@\t-3.35\nj`a``@NPYddblrRbR]zjfj@@@A`iFB\\ehug^y@P\t-3.35\nHo\\BxJX]bPRPrPzlNPnP^PrRRsIJJRjZjZ`AyG@\t-3.35\njhqA@@EYIHiXeDkIKUTADUT@@pTcAFJtYw`|`H\t-3.35\nHiD@g@hHdDdLdBdJhFdNdAd@zIklddUdjjh@P\t-3.35\nHkLLhJ[hBDdLdBdA\\LddTgTRjejj@FARngrA@\t-3.35\nHkLDxMMICI@iAiCi@YBYCIIEIYGJjji`AyA`\t-3.35\nHg\\LPHS@\\J\\LddQbdRiwUPU@@@pEnFUt{xbX\t-3.35\nHg|@P@bH\\DfYeUyO[j@@@@@FF`UMprng_H`\t-3.35\nHklDPHXGBgCIIEYhdmNjj@@@F@iaCJz_Di`\t-3.35\nHko@hAdtdLdBdJdFdLddTgbRtzjh@@@^Hn`\t-3.35\nHmV@XEbPRPrPzPFPfPrRRqRJjjj@FBDoHX\t-3.35\nHo|@`NqLddTlVVdeZhHBj@AaJXS\\iv\x7FHD\t-3.35\nHo|@`NqLddTlVfdgZhHHj@AaJXS]iv\x7FHd\t-3.35\nHg|H`HCpRkfUWd}mh@@@@@XJUMprng_H@\t-3.35\nHkLLPHZP\\A\\LddUbRdjjZj@FGIa\\ngrI@\t-3.35\nHkLLPHXP\\I\\LddUfRdjjZj@FGIa\\ngrF@\t-3.35\nHmVHHFjIAICICgCIIKLiJjZh@XXLkrJ@\t-3.35\nHmVHHFjIAICICgCIIKEiJjZh@XXLkrF@\t-3.35\nHcLHpJbPRPrPrRRsQIKmTp@@@pKae^Qh\t-3.35\nHmM@bHPO@IRfYUxYVjjjh@XCaTwCJ|`@\t-3.35\nHk^@@@RfYU\\]Tz@@@@@FBxUMprngr@@\t-3.35\nHkM@`HzoCIIDbiEJijj`A`JXPrngrJ@\t-3.35\nHctDPHxG@WCIIETeIUSUP@pyLJiW^Pp\t-3.35\nHg^@@JrRQRiKRCMT@ET@C@TpfgSod\\\t-3.35\nHef@HJbPRPrPYprRRiRUSU@CCNF^PP\t-3.35\nHct@PHBNBLddURTeUUU@CAXSBine]@\t-3.35\nHmTDPHXGCgCIIETiJjjh@XLfDLkrJ@\t-3.35\nHctDPHXG@WCIIEXmIUTuP@pYLJUwd\\\t-3.35\nHkLD@J{IIETdiJjjj`A`LIaBngrF@\t-3.35\nHeTD`HP@cIICLdLkP@@@pjfxYyA@\t-3.35\nHiDBPHSBCpiprRSFQjj`Aac\\ODp`\t-3.35\nHidD`HP@cIHXdnEX@@@XDULODC`\t-3.35\nHiDBbJ[aCpBTjeVjj`AaHPfES\\H\t-3.35\nHmVD@NalddUfRjij`AaRXWKqAd\t-3.35\nHmTD@H[IIETiJjjh@XLfDLkrJ@\t-3.35\nKAxYDPwUXUvRRJrjj@LBSBkbMp\t-3.35\nHiFH`D`OAJyfjjh@XMaTwCq@`\t-3.35\nsJPK@zRHTQh`q@ZOj`FEDVH\t-3.35\nsJPK@yRHTQh`q@ZOj`FEDVH\t-3.35\nsNqdIVG@nFRQFUU@LLEnXu`\t-3.35\nsNqiCVO@ReRmUPCAqXu|`@\t-3.35\nsJPJ@tRHTQh`qD_U@LJHlP\t-3.35\nsNpiH{XWlddUjj@XYX|UX\t-3.35\nsJXHHGAJfj@XYX|P`\t-3.35\nqCcPQX^D^hCBCfbp\t-3.35\nsJPXHlPYQzj@`\t-3.35\n`IoAHGd\t-3.35\nHeT@H@dBdAdIdDfYu[hHB`@^Ie@\t-3.39\n`L@LH\t-3.4\nsJXDHGCNBT}T@ptQxa`\t-3.42\nsJTHHaxIWMPCAX|P`\t-3.42\nsJPhLQHIKTpCqP`\t-3.43\nKAxX`Pw@xUxYIHkJjX@pqLKbUp\t-3.45\nsGQLKHaQFbLddmT`LMEnP`\t-3.45\nqC`DBHg`hcQBSU@XXK\\d@\t-3.45\nsGQDHGB~BUSUPCCKGdh\t-3.45\nsGPH@xYIDZj@XFKGbE@\t-3.45\nHo|D`HP@cIHXhheMAUXBHj`@XBwCNg[|PE@\t-3.48\nHo|D`HP@cIHXhdicAeXBBj`@XBwBng[|PJ@\t-3.48\nJoBBPDHG`eJsJkkYoU@@@@@A`mMprng[|`@\t-3.48\nHo|@@LdbRbblThP`hjj@AalIc]Jz]orA@\t-3.48\nHg}@@@aJVYU^Svv`@@@@A`ITwCJ{qCl\t-3.48\nHk^@@@RfYU\\]Tz@@@@@FDaaTwCJ|SS@\t-3.48\nHmTLPHS@BB\\LdaTTTVjj`A`uMproD@`\t-3.48\nHiDDhJZ@aICICi@YCIIECJiZ@GbPP\t-3.48\nHee@@@[IEDTiUUT@LAALJfF^IG@\t-3.48\nHid@`@|Die_ahH@@FCIaMp|PJ@\t-3.48\nKAx@`@DPDIRsUUPA`pPUMwDS@\t-3.48\nKAxH@ABTluUT@XDUMwDS@\t-3.48\nqC`HBHc`duPFFBwI@\t-3.48\nqC`HBHc`duPFDGME`\t-3.48\nHmvB@D@aeIfUzfZjeh@XIc\\aP\t-3.52\nQMCBHoAbDf`XH|h\t-3.52\n`IlAHFD\t-3.52\nHiDHhJbPRPrPzPFPrRRsRjZ`AyC@\t-3.55\nsNpB@xRHTQhcIIJjj`FEbqoHp\t-3.55\nKAxX`Pw@xTDYIHkJjT@pqLKdT\t-3.55\nHaD@`@\\DimVz`@@A`rXUMwH@\t-3.55\nKAxQ@HC`eTuUU@FEXUMwHP\t-3.55\nsNpmJyHJPt`~rRRrjXA@\t-3.55\nsNpH@xITkUT@p\\VM_H@\t-3.55\nsJPH@xIRuPC@qX|`@\t-3.55\nsGQHHGAJWjhAaecqB`\t-3.56\nHcND@LADfUyU]Zj@@@FGXWCJ{rJ@\t-3.57\nsGPeCQHJPoIMuS@OI@\t-3.58\nsJPdE`DRHcyXAaIrD\t-3.58\nsNp`@Ti]jj@XFZodP\t-3.58\n`IjApGd\t-3.59\nj`q`@@@YIEBedhdnB]zh@J@@@@XJQ`eF\\tZsnHex\t-3.61\nKAxLbPfDwAxUxEw]ddfLZi`CqLh\t-3.61\nsNqHHGAJkjj`FAqkxh`\t-3.61\nsNt@@\\dbLjj@XEZod`\t-3.61\nsNpP@jtfvZf@^YY`\t-3.61\nqC`PCDRVhCCBKdp\t-3.62\nKAxI@PpNFRRJrjf@LLSByG@\t-3.64\nsGQhHlGCIIKUHCAF|tV@\t-3.64\nsNq@IddbmUPC@kE|e@\t-3.64\nsNqdHl@`nFRPjKU@LEWq@`\t-3.67\nsJPhH`xQ}T@pVOED\t-3.67\nqCbPPND^hCBKfDp\t-3.67\nsJQHHGAJVj@XI[bA@\t-3.7\nHkLLzJ[hBLdBdAdIdMdCdNxhbHRHRHfJiZj`AyB`\t-3.73\nJoB@Y@QGTCqG\\drnlktqw@AP@P@A`hIaUJz[|c`\t-3.73\nJoBBPDHCaddabbRRrv[uP@@@@@XKS\\Lkiv\x7FDa@\t-3.73\nHknBPLaAd@b`cIIBhhd]MZ`T@@FCXwKi|b`\t-3.73\nJoB@P@ABTwLjnmf}T@@@@@FFaS\\Lkiv\x7FDa@\t-3.73\nHg|@`@|DjYmUyO[i@@@@@FBeS\\Lkiwq@p\t-3.73\nHgnD`Naj|LddUfbbeUUUT@LESBhYWSodL\t-3.73\nHcO@HBhPdDdEdMdLbfbRagCT@EP@OLci@\t-3.73\nHg|@`@BDfYeUyO[j@@@@@FBeS\\Lkiwq@`\t-3.73\nHglLPHNp\\JBDjefYjjjjT@XRfDwCJ{rJ@\t-3.73\nHk\\@`@SDifUWGUN`@@@@A`nES\\Lki|`@\t-3.73\nHmTLHHS@BJ\\FdNdLddJbdVjj`Aa`roHH\t-3.73\nHk\\@BLeJeWmZ{SBB@@@@XKBEWCJz_Hp\t-3.73\nHkNH`FboCIIEUEEJjjj`AaJXWCJz_Hh\t-3.73\nHo\\``HSBCpRjVYffjjjj@F@mprng_H\\\t-3.73\nHk^@@@RfYU\\]Tzjjjj@FEaBXUMprnf\t-3.73\nHef@XLBPRPZPzPFPfPR[fZjjh@^YAT\t-3.73\nHiDLPHQ`\\J\\LddUdjjh@XEa\\ODQ`\t-3.73\nHmTLHBk`dDdIdEdDf{[jffh@^I@`\t-3.73\nHkL@@LddTbdLjjjj@FDxS\\Lki|b`\t-3.73\nHeg@bHS@|@eJfYjjj`A`qTwCOH@\t-3.73\nKAxH`PpNENFRRJrjj@LBSB{bTp\t-3.73\nHeg@bHS@B@eJfYjjj`AapES\\L`\t-3.73\nsGPH@xIUMU`LLl^R`\t-3.73\nHcl@@DjYU_egX@@@@@XBaMprn|SJ@\t-3.75\nHmvD@LADf]eYUj`@@A`qMproHp\t-3.77\nHklL`HS@BLddJbRvWUjB@`@XMS]JgrA@\t-3.78\nsJPhH`xYICT`LEcsBH\t-3.78\nsJPXhlPD[ct^m@H\t-3.8\nHeVB@D@aeIfUzYjjV@FBXwHx\t-3.81\nHaFL@D@nRYgifjf@FBXwHH\t-3.81\nsGQLKIARFdLddmU@LI^P`\t-3.81\nsJPHHDQ}T@prqyH\t-3.81\nQMBcpIRZAaWDP\t-3.81\nsJQHHGBOj`FFVOI@\t-3.81\nHmvLbEaL@HslddlRVFUh@H@FATwCrE@\t-3.83\nHcLL`HS@BLddJfRtjmP@P@LJ[ag^QP\t-3.83\nHiDDpHhG@gAgCIHbeJjj@FC@fMp|``\t-3.83\nHidD`HPGCIHXdnFh@@@XTUMp|pHP\t-3.83\nHef@@@Ri^Zjjh@XCBES\\L|c@\t-3.83\nHiF@@@ReYjjj@F@pfES\\OH@\t-3.83\nqCaHKBH`PdthFDGI@\t-3.83\nQMBCDRZA`erP\t-3.85\nHeTD@@QIUeQej@@@FCYS\\L|b@\t-3.85\nqCbPPNBRu@XI[d@\t-3.86\nQMIDbHHRYAaGJ@\t-3.87\nHo|H@IrRQRiQFPUj`BJh@FDiaTtg[|aP\t-3.88\nHedHHJbPRPrPYprRRiRUUU@CCNF^PP\t-3.88\nHmVHPF`GCgCIIETiJjZh@XLfDLkrJ@\t-3.88\nHiDLhJ[hBDdLdBdA\\LddTgjeh@^PH\t-3.88\nHiDLHJ[hBDdLdBdLddTgjeh@^PH\t-3.88\nsNplJyHJPtaddeeTpCrL\t-3.88\nsNphHpxYIHkUR@prqyJ\t-3.88\nsOx`DFdrikUL@pVoH`\t-3.91\nqCbPPNBTu@XS\\PP\t-3.91\nHctDXAeICIBiAiAYCYCIIEHXYUUMP@pb^Qp\t-3.93\nqCpPP^BSU@XI[d@\t-3.93\nQMABHgAIhFBOJ@\t-3.94\nsNxaBDnR[YjhAaMqU`\t-3.96\nqC`PApRVhCAQ\\Pp\t-3.96\nsGXaBDnR[Vj@XS\\Qh\t-3.97\nsGQHHGAJijhAaecrT\t-3.97\nHaDH`HApRnU[j@@@FEXUMwDB@\t-3.98\nHkLHxMRPrPJPZPzPFPfPrRQRVQrjjjX@^PX\t-4.02\nHmTLhJ[hBDdLdBdA\\LddTgTjej`A`dkrA@\t-4.02\nKA|PtMpFdQBQFQAQEQ@MdddgjjPCA`aLJ`\t-4.02\nHmt@pHdDdLdLddjbReZj@@@FEMproHH\t-4.02\nHcl@@DjYU_egX@@@@@XBfES\\L|Q]@\t-4.02\nHmtL`HS@BLddlRVFUh@H@FETwBoHp\t-4.02\nHiDB`HSBBRRjUZjj@FATwCr@@\t-4.02\nsNxDHG@nFRQFUU@LKEj~HD\t-4.02\nsGP@DjZj`FAVMxa@\t-4.02\n`Jd`^P\t-4.02\nQMJH\\Df`XSr@\t-4.04\nHk|@@LdbbbRQKauS`@`@`@F@ySCJz_Hx\t-4.04\nsGPB@xRHTQhcIIKUPC@qX|e@\t-4.09\nJoB@P@NFRRJJEIKKYoU@@@@@A`mMprng[|SB@\t-4.11\nHcu@`HPOAJYYfjjjh@XSaTwCJ{q@P\t-4.11\nHiD@@DjfZjj`A`vES\\ODa@\t-4.11\nsGPdCQHJPR[jf@^JT\t-4.11\nqCbPPND^hCAK\\P`\t-4.12\nsGQ@HeTuT@prqyJ\t-4.12\nKAxH@PvRRJrjf@LLSByG@\t-4.14\nHet@@DjYUX^d@@@@A`rXULODzP\t-4.18\nHcLBHHQaApIpipUprRIZJJbmUUUP@pKNg^DATh\t-4.2\nsNpdHpxWprRQVjhAaecqU`\t-4.22\nsJPYhlQxKmqzOZ`D\t-4.22\nsGX`LDdsmT@pexlP\t-4.23\nRFPaMt\\H\t-4.25\nQMIH\\EpRZAxb\t-4.25\nHiFB@LANEImfZjX@XYaCqDX\t-4.26\nHmV@xNRPrPJPjPZPfPVPrRQR]Rjjj@Gb\\H\t-4.27\nHcu@XFVIAICICi@YBYCIIKEHkUSUH@|cP\t-4.27\nHgnD`Naj|LddUbRdUUUUT@LISBjUt{yG@\t-4.27\nHmU@XFVIAICICi@YBYCIIKEHjjZh@^Ph\t-4.27\nHedLpHi`\\B\\N\\LdbLVeUUP@pXDsagbDp\t-4.27\nHmU@pHTGBgA`cIIEKHjjjh@X\\fDwCOHT\t-4.27\nHef@XFbPRPrPzPFPfPrRRqRUTu@CrF@\t-4.27\nHcvD`Naj|LddUbteUUU@CCdpje]yG@\t-4.27\nHcw@`H[j|LddUbbeTuU@CCdpae]yE@\t-4.27\nHef@pHApipXHrRQRrUUU@CAdpnF^Pp\t-4.27\nHmTD`HZoCIIETiJjjh@XLfDLkrJ@\t-4.27\nHed@`@\\DjYfjjj@FDpfES\\L|`@\t-4.27\nKA|HP]SPDIHYHEHIUMURpAyG@\t-4.27\nsGPH@xIUMU@LCEcrT\t-4.27\nsJQ@IGuPCCKGd`\t-4.28\nHid@b@|@eJYWxZB@@A`rXS\\ODB`\t-4.31\nHiFB@LANEIevZjX@XI`|Pj@\t-4.32\nKA|D@XBMrSZsUL@XIg\\QB@\t-4.32\nqCbPHQBSS@XP\\f@\t-4.32\nHedL`HS@\\LddRRmUUP@phj[ayD`\t-4.33\nHk^@@@RfYU\\]Tzjjjj@FApfES\\Lki|`@\t-4.35\nqCaPQApcu@XS\\pb@\t-4.38\nsJPHHxQ}T@prqyH\t-4.38\nKAxI@P`NFRQIFjj@LBpj[bAp\t-4.4\nqCsCPKRUvyIf`NIO@\t-4.41\nqCsCPKRUvyIf`H\t-4.41\nHctDxAe@cI@iBiAiAYCYCIIEHhyUUKP@|QN@\t-4.42\nJoB@P@^BULrj~mf}PA@@@@FAaaTwRng[|`P\t-4.42\nsNpH@xISMUT@p\\VM_H@\t-4.42\nsNq`@jdssTpCqY`\t-4.42\nqC`XR@TAhBOTAqh`I@rAr@\t-4.43\nsJPB@xRHTQhbOj`FFbwHP\t-4.43\nsNqLKIARFdLddljf@^Q`\t-4.43\nQMJH\\HzAaOD`\t-4.44\nKAxPPUD`d`tataddaTjf`CqLH\t-4.45\nQMBCpchGfR\t-4.45\nQMJH\\Df`^H`\t-4.48\nHctLhJ[hBDdLdBdA\\LddTgReTmU@CCIW^PH\t-4.49\nHiDL`HS@\\DjeVjj`A`QTw\\`P\t-4.49\nqC`PApRfhCAQ\\Pp\t-4.5\nKAxH`P`NENFRRJrjj@LBpf{bIP\t-4.52\nHg|H`HApRkfUWd}nh@@@@@XJUMprng_DB@\t-4.55\nsNphH`xITkUT@pvMx`p\t-4.55\nsGQDBIARBS]TpCqR`\t-4.55\nRFDTAFCbdCd@\t-4.56\nsGQ`@jdsmR@|VH\t-4.57\nHedL`HS@\\DjUUjjj@FCES\\L|`@\t-4.58\nKAxY@Pf@xITnuUPA`QTw\\PL@\t-4.58\nKAxY@Pf@xIUJuUPAaeMwHH\t-4.58\nsGQhHlGCIHcUPCAF|pV@\t-4.58\nsNpHHxIUMUT@pjqkyH\t-4.58\nQMJDbDfPXQr`\t-4.63\nQMBApRZAaWDP\t-4.64\nsNphH`xIRkUT@pNM_H@\t-4.66\nsJPhH`xISuPCAX|PP\t-4.66\nHglLhJ[hBDdLdBdA\\LddTgTbeTmUT@LBWSodR\t-4.67\nHo\x7F@XBhPdDdMdCdKdGdDfyV^[aj@Bjh@GfQJ`\t-4.67\nh`~@@@YIHiEHYCJjjjj`@pu`cNRUhug^y@P\t-4.67\nHctDpHPGBgAgCIIDcHiUUUP@p{BxYW^Pp\t-4.67\nHmVBhNiiV@aICI@i@PcIIEIuJiZT@^Ip`\t-4.67\nHmW@`HS@|DjVYfjjh@XMS\\Lkq@H\t-4.67\nsOpH@xILkW@@@LJlZ~P@\t-4.67\nQMABHgAIhFD\\Y@\t-4.69\nsGPhH`xITmU@LD[qC@\t-4.7\nqC`PCpcu@XP\\tV@\t-4.72\nQMbH\\HzAaOD`\t-4.75\nsGPH@xITuU@LBl[qB@\t-4.75\nsGPBIHJPtaYCIIKUPCrD\t-4.76\nQMAJ@XBN`\\L`JAr@\t-4.77\nRFBDQNDXLHyP\t-4.77\nsNqhHlGAJeZj`FFM_H@\t-4.79\nsJQ`@bdjt`OEL\t-4.79\nj`aA@@NYIHiXmDiIZj``bj@@XRQ`cNZl{wHF@\t-4.83\nHed@DHADdLdBdFkNdAdIdLddTleUUP@panQ@\t-4.83\nHkLLpHS@\\J\\F\\LddRLbdjjjj@FGEprngrL@\t-4.83\nHkLDpHXGBg@WCIIEXdiJjjZ`A`JXWRngrJ@\t-4.83\nHctLpH[`\\J|A\\LddUbteUUU@CCdpje]yG@\t-4.83\nHctLpH[`\\J\\A\\LddUbteUUU@CCdpje]yG@\t-4.83\nHglLpHS@\\J\\F\\Djevfjjfjh@XBWCJz]|c@\t-4.83\nHctLpH[`\\J|A\\LddUfTeUMU@CAdpiW^QP\t-4.83\nHkLBpHSBCpipYpRjwiijjjh@XMprngrB@\t-4.83\nHctLpH[`\\JhA\\LddUbteUUU@CAdpiW^Qp\t-4.83\nHedHXFbPRPrPzPFPfPrRRqRUUU@CBFyA@\t-4.83\nHmTDpHXGBjCgCIIETiJjjh@XLfDLkrJ@\t-4.83\nHg\\@@LddTjTt`kU@DU@@peLJfWSodB\t-4.83\nHg^@@JrRQRiSRBmT@QT@C@TpfWSodB\t-4.83\nHctL`H[jlLddUbteUUU@CAdpiW^Qp\t-4.83\nHmTD`HZkCIIETiJjjh@XLfDLkrJ@\t-4.83\nKAxX`Pw@xTxYIHkJjh@pqLKfTw@\t-4.83\nqC`DBHc`hcQBSU@XXK\\d@\t-4.83\nsJPH@xITuPCCQ[bA@\t-4.85\nsJPhH`xIRuPCAX|`@\t-4.86\nHid@`@\\LdbaRxZ`@@AaQTwCs@S@\t-4.88\nHct@@LddTbaeUUU@C@\\InFUwbIP\t-4.88\nqCbPXRBRt`^JH\t-5.01\nsOpIAxBTfUk`@@FEVM_H@\t-5.03\nHaD@`@\\DimVz`@@AaVES]q@P\t-5.04\nRFEG`SFCqH\t-5.04\nsGX`LDdvmT@pfydZ\t-5.06\nHo]@`HPOAJYfYfjjjjh@XGaTwCJz]or@@\t-5.07\njhy@`@@HRUYfUWyHwgAZj@@@H@@XJpPRmFl{p^P`\t-5.08\nqC`PApcu@XZK\\`@\t-5.08\nJobD@@IKLrj}\\mf}T@@@P@A`lHprng[|`@\t-5.09\nQMCBHgAbDf`XH|h\t-5.09\nHctHxMRPrPJPZPzPFPfPrRQRVQuUUR@OHT\t-5.11\nHiFD@NalddUfjih@XDfEwHD\t-5.12\nJgB@@BULrjy\\Nk\\@D@Q@@FDyS\\Lkm|`p\t-5.16\nsJXHHGBOj`FFVOI@\t-5.21\nh`\x7F`D@PxJgaddbQbdTTjfjjj@CARLDdkQkN}rE@\t-5.24\nHkLLHHi`\\B\\N\\A\\LdbLRTTjjjj@FD`f\\Lki|``\t-5.24\nHcu@XJZIAICIBYAYCYCIIJdeIULuP@|Pn@\t-5.24\nHo^D`Naj|LddUbRdTjjjjh@XJfETkiv\x7FHx\t-5.24\nHk\\@bLhLyJeWmZ{SBB@@@@XKBEWCJz_Hp\t-5.24\nHmU@pHXGB`cgCIIETiJjjh@X\\fEProDa`\t-5.24\nHiD@P@\\J\\LddUdjjh@XLfDwCrH@\t-5.24\nKA~A@PfAxIUsMUPA`QTw\\PH@\t-5.27\nsNp`H|ddUji@XYX|e@\t-5.3\nHg|@`@\\DjYmUyO[j@@@@@FBeS\\Lkiwq@p\t-5.31\nQMBApchFCOH@\t-5.31\nsNpdHpxUprRQVjhAaecqU`\t-5.32\nRFDCaFCBnP\t-5.38\nRFTPxQ`|R@\t-5.39\n`IG@Cr@\t-5.39\nsJPYHlQDGh}V@P\t-5.4\nqCpPPND^hCAK\\P`\t-5.44\nKAxXPTwPDIHYHEHIUMURpAyG@\t-5.45\nKA|H@]CYIHkJjX@pqLKd\\\t-5.48\nsNqlHl@brCdLddlVj@^KD\t-5.49\nHctDpHXGBg@WCIIEXmIUUUP@pyLKiW^QP\t-5.55\nsKP@Di\\Zj@XTQX`\t-5.55\nHeT@pHdDdLdLddlRPsU@@@CCJZ^Ip`\t-5.6\nqCcPQXQD]TCr@\t-5.62\nQMBApchGfR\t-5.62\nHgl``HSBCpRjVYfZjjj`A`K\\LkiwrJ@\t-5.64\nHk\\@`@\\DifUWGUN`@@@@A`nES\\Lki|`@\t-5.7\nsNtHHaxISMUT@pNM_H@\t-5.73\nsJPLAHJPL`dwU@OEL\t-5.77\nHctLbH[jlJ{IIEXmIUUUP@pyLJiW^Qp\t-5.81\nHmTDbHZkBnrRQUJRjjj@FCIaCJ|b`\t-5.81\nHkNB@NamOIIEYeEJjZi`A`rXWB_HT\t-5.83\nHcvB@NaewIIEYdiUSTp@piLKmy@`\t-5.88\nsGQLKIARFdLddmT`OHP\t-5.94\nHo\\LhJ[hBDdLdBdA\\LddTgTTTjejjh@XMJz]orA@\t-5.96\nHmTDpHXGBoCgCIIETiJjjh@XLfDLkrJ@\t-6.03\nsOpHAxILkW@@@LJlZ~P@\t-6.07\nQMBApchFE\\Q@\t-6.07\nRFDCaFCqH\t-6.09\nsJQDBIARBS]R@|Tp\t-6.14\nsJPH@xQ}T@ptVyB\t-6.14\nJoB@Q@^@ReSLjokYoT@P@@@AanES]Jz]oq@D\t-6.22\nHmT``HSBCpRjyfZjj`A`uMproH`\t-6.22\nsJXA@IczhA`XlP\t-6.33\nHiD@p@\\H\\J\\LddUdjjh@XLfDwCrH@\t-6.38\nKAxXTTwPDIHYHEH]rUSUTl@P\t-6.38\nsNqmHl@brCdMvRRVKU@OHP\t-6.44\nqCcPQXND^hCpbK@\t-6.5\nHaD@b@|@eJ[Unh@@@XUaTw\\PD@\t-6.53\nqC`PApcu@XJKbF@\t-6.53\nsNpO@YRHTQh`qEbGDAh\x7Fjj@X\\QXu`\t-6.53\nsNpO@ZRHTQh`qEbGDAh\x7Fjj@X\\QXu`\t-6.53\nsNpOAYRHTQh`qEbGDBh\x7Fjj@X\\QXu`\t-6.53\nHiF@PHApiprRQVRjj`A`rXS\\OH`\t-6.53\nsNpO@\\RPTai@rEdGHAh\x7Fjj@XP@\t-6.53\nsNpO@JRPTai@rEdGHAh\x7Fjj@XP@\t-6.53\nHeg@`HS@|DjYfjjj@FCES\\L|`@\t-6.53\nsNpOAXRPTai@rEdGHBh\x7Fjj@P\t-6.53\nsNpOABRPTai@rEdGHCh\x7Fjj@P\t-6.53\nsNpyHlZqfCh\x7Fjj@X\\QXu`\t-6.53\nQMFIGBN`^YH\t-6.58\nsGPG@ZRHTQh`qEb@t_jhAaXl[r@\t-6.75\nsNpJIHJPtaYArFRRVUU@OHP\t-6.89\nHaD@`@|DimVz`@@AaVES]q@P\t-6.95\nHk\\@b@|@eJYeUquSh@@@@@XKaTwCJz_H@\t-7.06\nHg\\@XHdDdLdMdCdKdLddlRTt`kU@DU@@prfWdB\t-7.11\nsNpbJxDJPt`YAJijiPGd`\t-7.19\nsGPBAHJPLaYAInjhAxi`\t-7.19\nHefD@NalddUfUUMP@pILKnHL`\t-7.2\nsGPlH`DFPladdLVhAxa`\t-7.25\nsJPKAPRPTai@r@zOj`D\t-7.29\nqC`FBPe@iCRDyIj`OI@\t-7.34\nHctLpH[`\\J\\A\\LddUbteUUU@CAdpiW^IW@\t-7.38\nHg|@`@|DjYmUyO[j@@@@@FF`UMprng_Hp\t-7.38\nsNpOAfRHTQh`qEbGDCh\x7Fjj@X\\QXu`\t-7.53\nsNpOAYRHTQh`qEbGDAh\x7Fjj@X\\QXu`\t-7.53\nsNpOAZRHTQh`qEbGDBh\x7Fjj@X\\QXu`\t-7.53\nsNpO@zRHTQh`qEbGDAh\x7Fjj@X\\QXu`\t-7.53\nsNpO@tRPTai@rEdGHAh\x7Fjj@XP@\t-7.53\nHed@xDdLdBdJdFdAdIdLddTgeUUP@|c`\t-7.62\nHk\\@`@|DifUWGUN`@@@@A`nES\\Lki|`@\t-7.7\nHmTDpHXGBgCgCIIETiJjjh@XLfDLkrJ@\t-7.73\nHo]@HHTGBgA`cWCIIEKHjiJjjjj@FBiaMpr]orE@\t-7.79\nHgl@dDdLdBdFdNdIdEdMdCdLddTedLeUUUT@OHl\t-7.79\nHg|@b@|@eJf[U^Svz`@@@@A`iTwCJz]|PL@\t-7.99\nHkL@dDdLdBdFdNdAdIdMdCdLddTed\\jjjj@GdJ\t-8.08\nsNpOAfRPTai@rEdGHCh\x7Fjj@XP@\t-8.11\nh`~CDHPYreaSlddUbRdTeUUUUP@XJQ`eEZMYw`\t-8.37\nsNpBIHJPl`yCIICJj`Gbq@\t-8.5\nsNpO@yRHTQh`qEbGDAh\x7Fjj@X\\QXu`\t-8.52\nsNpO@xRPTai@rEdGHAh\x7Fjj@P\t-8.84\nHed@XDdLdJdFdAdIdLddTaeUUP@|Pn@\t-9.1\nHkL@H@\\H\\J\\F\\LddTlbdjjjj@FDia\\Lki|b@\t-9.37\nHkL@DLdBdJdFdAdIdMdCdLddTbd\\jjjj@Gb\\h\t-9.57\nHiD@XHdDdJdFdNdAdLddLTjjh@^Ia@\t-9.59\nHct@DDdLdJdFdAdIdEdMdLddTaaeUUU@CqBx\t-10.1\nsNpOAxRPTai@rEdGHCh\x7Fjj@P\t-10.77';mlb.xD=false;Ykb.EZ=w3(219);mlb.BD=function BD(a,b){return dlb.Bi(a.a,b).a;};mlb.CD=function CD(a,b){return dlb.Bi(a.a,b).b;};mlb.DD=function DD(a){var b,c,d,e,f;f=new Alb.q2(new Alb.u2(a));this.a=new dlb.Qi();while(true){e=Alb.p2(f);if(e==null)break;d=Zkb.g5(e,s5(9));if(d==-1)throw c1(new Zkb.rz('line without TAB'));b=(alb.Jgb(0,d,alb.Pgb(e).length),alb.Pgb(e).substr(0,d));c=Zkb.U3(alb.Pgb(Zkb.O3((alb.Kgb(d+1,alb.Pgb(e).length+1),alb.Pgb(e).substr(d+1)))));dlb.wi(this.a,new mlb.ED(b,c));}};U1(221,1,{},mlb.DD);Ykb.GZ=w3(221);mlb.ED=function ED(a,b){this.a=a;this.b=b;};U1(183,1,{183:1},mlb.ED);_.b=0;Ykb.FZ=w3(183);mlb.FD=function FD(a,b){this.a=a;this.b=b;};U1(34,1,{34:1},mlb.FD);_.b=0;Ykb.IZ=w3(34);mlb.GD=function GD(a){a.a=new dlb.Qi();};mlb.HD=function HD(a,b,c){dlb.wi(a.a,new mlb.FD(b,c));};mlb.ID=function ID(){mlb.GD(this);};U1(106,1,{},mlb.ID);Ykb.HZ=w3(106);mlb.LD=function LD(){mlb.LD=W1;mlb.JD=oW(aW(Ykb.l_,1),Xlb,2,6,['[N](-*)(-*)-*','[N](-*)=*','[N]#*','[N](-*)(=*)=* as in nitro','[N](=*)#* middle atom of azide','[N]1(-*)-*-*-1 3-membered ring','[NH](-*)-*','[NH]1-*-*-1 3-membered ring','[NH]=*','[NH2]-*','[N+](-*)(-*)(-*)-*','[N+](-*)(-*)=*','[N+](-*)#* N in isocyano','[NH+](-*)(-*)-*','[NH+](-*)=*','[NH2+](-*)-*','[NH2+]=*','[NH3+]-*','[n](:*):*','[n](:*)(:*):*','[n](-*)(:*):*','[n](=*)(:*):* as in pyridine-N-oxid','[nH](:*):*','[n+](:*)(:*):*','[n+](-*)(:*):*','[nH+](:*):*','[O](-*)-*','[O]1-*-*-1 3-membered ring','[O]=*','[OH]-*','[O-]-*','[o](:*):*','[S](-*)-*','[S]=*','[S](-*)(-*)=*','[S](-*)(-*)(=*)=*','[SH]-*','[s](:*):*','[s](=*)(:*):*','[P](-*)(-*)-*','[P](-*)=*','[P](-*)(-*)(-*)=*','[PH](-*)(-*)=*']);mlb.KD=oW(aW(Ykb.zX,1),cob,6,15,[3.240000009536743,12.359999656677246,23.790000915527344,11.680000305175781,13.600000381469727,Csb,12.029999732971191,21.940000534057617,23.850000381469727,26.020000457763672,0,Csb,4.360000133514404,4.440000057220459,13.970000267028809,16.610000610351562,25.59000015258789,27.639999389648438,12.890000343322754,4.409999847412109,4.929999828338623,8.390000343322754,15.789999961853027,4.099999904632568,3.880000114440918,14.140000343322754,9.229999542236328,12.529999732971191,17.06999969482422,20.229999542236328,23.059999465942383,13.140000343322754,25.299999237060547,32.09000015258789,19.209999084472656,8.380000114440918,38.79999923706055,28.239999771118164,21.700000762939453,13.59000015258789,34.13999938964844,9.8100004196167,23.469999313354492]);};mlb.MD=function MD(a,b){var c,d;c=mlb.QD(a);for(d=0;d<mlb.KD.length;d++)c[d]!=0&&mlb.HD(b,''+c[d]+' * '+mlb.KD[d]+'   AtomType: '+mlb.JD[d],2);};mlb.ND=function ND(a){var b,c,d;b=mlb.QD(a);d=0;for(c=0;c<mlb.KD.length;c++)d+=b[c]*mlb.KD[c];return d;};mlb.OD=function OD(a){var b;b=new mlb.ID();dlb.wi(b.a,new mlb.FD('The polar surface area prediction is based on an atom-type based',2));dlb.wi(b.a,new mlb.FD('increment system, published by P. Ertl, B. Rohde, P. Selzer',2));dlb.wi(b.a,new mlb.FD('in J. Med. Chem. 2000, 43, 3714-3717',2));dlb.wi(b.a,new mlb.FD(Asb,2));mlb.MD(a,b);return b;};mlb.PD=function PD(a,b){var c;switch(a.C[b]){case 7:if(b<a.f&&clb.rr(a.p,b)){if(a.s[b]==0){if(a.e[b]-clb.On(a,b)+clb.Kn(a,b)==0){if(clb.On(a,b)==2)return 18;else {for(c=0;c<clb.On(a,b);c++)if(!clb.mo(a,a.k[b][c]))return 20;return 19;}}else return 22;}else if(a.s[b]==1){if(a.e[b]-clb.On(a,b)+clb.Kn(a,b)==0){for(c=0;c<clb.On(a,b);c++)if(!clb.mo(a,a.k[b][c]))return clb.dk(a,a.i[b][c])<0?21:24;return 23;}else return 25;}}else {if(a.s[b]==0){switch(a.e[b]-clb.On(a,b)+clb.Kn(a,b)){case 0:switch(a.o[b]){case 0:return (!!a.p&&b<a.f?clb.gr(a.p,b):0)==3?5:0;case 1:return 1;case 2:return 2;}break;case 1:switch(a.o[b]){case 0:return (!!a.p&&b<a.f?clb.gr(a.p,b):0)==3?7:6;case 1:return 8;}break;case 2:return 9;}}else if(a.s[b]==1){switch(a.e[b]-clb.On(a,b)+clb.Kn(a,b)){case 0:switch(a.o[b]){case 0:return 10;case 1:return mlb.RD(a,b)?3:11;case 2:return a.n[b][0]==2?mlb.RD(a,b)?4:mlb.KD.length+1:12;}break;case 1:switch(a.o[b]){case 0:return 13;case 1:return 14;}break;case 2:return a.o[b]==0?15:16;case 3:return 17;}}}return mlb.KD.length+1;case 8:if(b<a.f&&clb.rr(a.p,b)){if(a.s[b]==0)return 31;}else {if(a.s[b]==0){if(a.o[b]>0)return 28;if(clb.On(a,b)==1)return 29;if((!!a.p&&b<a.f?clb.gr(a.p,b):0)==3)return 27;return 26;}else if(a.s[b]==-1){if(clb.On(a,b)==1&&clb.dk(a,a.i[b][0])>0)return 28;return 30;}}return mlb.KD.length+1;case 15:if(a.s[b]==0){if(a.e[b]-clb.On(a,b)+clb.Kn(a,b)==0){if(clb.On(a,b)==3&&a.o[b]==0)return 39;if(clb.On(a,b)==2&&a.o[b]==1)return 40;if(clb.On(a,b)==4&&a.o[b]==1)return 41;}else if(a.e[b]-clb.On(a,b)+clb.Kn(a,b)==1){if(clb.On(a,b)==3&&a.o[b]==1)return 42;}}return mlb.KD.length+1;case 16:if(a.s[b]==0){if(b<a.f&&clb.rr(a.p,b)){return clb.On(a,b)==2?37:38;}else {if(a.e[b]-clb.On(a,b)+clb.Kn(a,b)==0){if(clb.On(a,b)==2&&a.o[b]==0)return 32;if(clb.On(a,b)==1&&a.o[b]==1)return 33;if(clb.On(a,b)==3&&a.o[b]==1)return 34;if(clb.On(a,b)==4&&a.o[b]==2)return 35;}else if(a.e[b]-clb.On(a,b)+clb.Kn(a,b)==1){if(clb.On(a,b)==1)return 36;}}}return mlb.KD.length+1;}return mlb.KD.length;};mlb.QD=function QD(a){var b,c;c=gW(Ykb.AX,gmb,6,mlb.KD.length+2,15,1);clb.Gt(a,7);for(b=0;b<a.f;b++)++c[mlb.PD(a,b)];return c;};mlb.RD=function RD(a,b){var c;for(c=0;c<a.j[b];c++)if(clb.dk(a,a.i[b][c])<0)return true;return false;};mlb.UD=function UD(){mlb.UD=W1;mlb.SD=oW(aW(Ykb.BX,1),Anb,6,14,[524290,524292,524297,524301,589826,589827,589828,589829,589832,589833,589837,589838,688130,688131,688132,688137,688141,819202,819203,819204,819205,819208,819209,1114114,1114115,1114116,1114120,1212420,1343492,1343496,1638402,1638403,17367042,17367043,17367044,17367045,17367048,17367049,17367053,17367054,17465346,1074266116,1208483842,1208483844,1208549378,1208549379,1208549380,1208549384,1208549388,1409810434,1409875970,1409875971,1409875972,1409875976,1409974274,1409974280,1409974284,1678311426,1678311427,1678311428,1678311432,1678311436,1678409730,1678409731,1678409732,1678540802,1678540803,1678540804,1678540808,2282291202,2282291203,2282389506,2282389507,2282520578,2282520579,2483617794,2483617795,2483716098,2483716099,2752675842,3356033026,3557359618,3557457922,3557588994,34510798850,34510798851,34510798852,34510798856,34712125442,34712125443,34712125444,34712125448,34712223746,34712223747,34712223748,34980560898,34980560899,34980659202,35568287746,35568287747,35568287748,35568287752,35568386050,35568386051,35568386052,35568517122,35568517123,35568517124,35568517128,35568812034,35568812035,35568910338,35568910339,35568910350,35569336322,35585064962,35585064963,35585064964,35585064968,35769548802,35769614338,35769712642,35769843714,35786391554,Kqb,Lqb,Mqb,Nqb,Oqb,Pqb,Qqb,Rqb,Sqb,Tqb,Uqb,Vqb,Wqb,3437652377603,Xqb,Yqb,4674334294019,Zqb,$qb,4674602827778,_qb,arb,brb,crb,5086651154435,drb,5086651252739,erb,5086651252744,frb,5086919589896,grb,5086919819266,hrb,irb,jrb,5636675633154,{l:589826,m:73760,h:4},{l:589827,m:73760,h:4},{l:688130,m:73760,h:4},{l:819202,m:73760,h:4},{l:65538,m:73764,h:4},{l:65539,m:73764,h:4},{l:589826,m:172064,h:4},{l:589827,m:172064,h:4},{l:688130,m:172064,h:4},{l:819202,m:172064,h:4},{l:819203,m:172064,h:4},{l:65538,m:172068,h:4},{l:65539,m:172068,h:4},{l:589826,m:172112,h:4},{l:589827,m:172112,h:4},{l:688130,m:172112,h:4},{l:819202,m:172112,h:4},{l:65538,m:172116,h:4},{l:163842,m:172116,h:4},{l:589826,m:303136,h:4},{l:688130,m:303136,h:4},{l:819202,m:303136,h:4},{l:65538,m:303140,h:4},{l:589826,m:303184,h:4},{l:688130,m:303184,h:4},{l:819202,m:303184,h:4},{l:65538,m:303188,h:4},krb,lrb,mrb,nrb,orb,prb,qrb,{l:688130,m:590224,h:4},{l:819202,m:590224,h:4},rrb,srb,trb,urb,vrb,wrb,xrb,yrb,{l:688135,m:590416,h:4},zrb,{l:1212430,m:590416,h:4},{l:65538,m:598052,h:4},{l:65538,m:598100,h:4},{l:65539,m:598100,h:4},{l:163842,m:598100,h:4},{l:163843,m:598100,h:4},Arb,Brb,Crb,{l:688131,m:598304,h:4},Drb,Erb,Frb,Grb,Hrb,{l:589826,m:688672,h:4},Irb,Jrb,Krb,Lrb,{l:589827,m:590112,h:336},Mrb,Nrb,Orb,Prb,Qrb,Rrb,Srb,Trb,Urb,{l:688130,m:819536,h:400},Vrb,Wrb,Xrb,{l:589831,m:590112,h:592},Yrb,Zrb,$rb,_rb,asb,bsb,{l:819207,m:819600,h:592},csb,dsb,esb,{l:589832,m:1212816,h:592},{l:688136,m:1212816,h:592},fsb,gsb,hsb,isb,jsb,{l:589826,m:819488,h:8480},ksb,lsb,msb,nsb,{l:819208,m:1213008,h:8480},osb,psb,{l:688130,m:590160,h:8484},{l:589826,m:598304,h:8484},qsb,{l:819202,m:598304,h:8484}]);mlb.TD=oW(aW(Ykb.zX,1),cob,6,15,[-0.1899999976158142,1.2699999809265137,-0.7009999752044678,2.690999984741211,-0.22699999809265137,Pob,0.10599999874830246,-0.47600001096725464,-0.44699999690055847,-0.19099999964237213,-0.3330000042915344,0.0860000029206276,0.24699999392032623,-0.06199999898672104,0.01600000075995922,0.3869999945163727,0.23499999940395355,-0.4320000112056732,-0.902999997138977,0.38999998569488525,0.5809999704360962,4.52400016784668,-0.6349999904632568,-0.2800000011920929,0.7699999809265137,-0.05000000074505806,1.0870000123977661,0.19200000166893005,0.19599999487400055,-0.5199999809265137,0.5419999957084656,0.3630000054836273,0.7919999957084656,0.5920000076293945,0.9639999866485596,vsb,-0.6850000023841858,-0.3149999976158142,-0.4129999876022339,-0.5950000286102295,0.2199999988079071,-1.4320000410079956,-2.253999948501587,0.4399999976158142,-0.27000001072883606,-0.13300000131130219,-0.26899999380111694,0.2669999897480011,0.5720000267028809,-0.5680000185966492,0.17399999499320984,-0.1850000023841858,-0.23499999940395355,Dsb,Esb,-0.34200000762939453,-0.3479999899864197,-0.43700000643730164,-0.8040000200271606,-0.41200000047683716,-0.2150000035762787,-0.625,-0.8309999704360962,0.4970000088214874,-0.4309999942779541,-1.3309999704360962,0.5070000290870667,-0.6320000290870667,-0.5989999771118164,-0.15600000321865082,-0.3529999852180481,-0.164000004529953,-0.4410000145435333,-0.4970000088214874,-1.059999942779541,0.11500000208616257,-0.22499999403953552,-0.15399999916553497,-0.03099999949336052,-1.5740000009536743,-1.093000054359436,ysb,-0.44999998807907104,-0.5559999942779541,Esb,2.384000062942505,1.75,-1.6660000085830688,-1.065999984741211,1.3270000219345093,0.8029999732971191,-1.5049999952316284,-2.5369999408721924,Dsb,0.14900000393390656,0.5210000276565552,2.9049999713897705,-0.25200000405311584,0.8600000143051147,0.3610000014305115,0.40299999713897705,0.004999999888241291,1.1460000276565552,0.9359999895095825,-0.30000001192092896,0.20900000631809235,-0.5830000042915344,-0.024000000208616257,-0.009999999776482582,0.6110000014305115,0.4860000014305115,0.8619999885559082,-0.03500000014901161,-0.5960000157356262,1.1610000133514404,1.6469999551773071,0.843999981880188,0.125,0.1420000046491623,-0.17100000381469727,0.44200000166893005,0.08799999952316284,3.065999984741211,1.6519999504089355,Fsb,-0.017999999225139618,0.023000000044703484,0.0729999989271164,0.2540000081062317,0.5540000200271606,0.5950000286102295,-0.4059999883174896,-0.6370000243186951,-0.17399999499320984,-0.10100000351667404,-0.5429999828338623,-2.4059998989105225,-3.2920000553131104,-0.05299999937415123,-0.19300000369548798,Npb,-1.2610000371932983,-0.656000018119812,-0.7300000190734863,-0.9380000233650208,0.12800000607967377,1.1540000438690186,0.24199999868869781,-0.5289999842643738,-0.27799999713897705,-0.8019999861717224,0.9120000004768372,-1.38100004196167,0.46299999952316284,1.0740000009536743,-0.628000020980835,-0.9620000123977661,-1.8320000171661377,-1.4989999532699585,-2.115999937057495,-2.2070000171661377,-1.3170000314712524,2.500999927520752,-0.8489999771118164,xsb,-0.621999979019165,2.121999979019165,-2.2260000705718994,0.9129999876022339,-2.259000062942505,-1.25,1.3940000534057617,-1.4019999504089355,2.072999954223633,-2.9570000171661377,0.29100000858306885,-3.4760000705718994,-2.7269999980926514,-3.131999969482422,-2.119999885559082,-0.7250000238418579,-0.296999990940094,0.08299999684095383,0.34700000286102295,-1.4249999523162842,-1.659999966621399,-1.281999945640564,-1.2649999856948853,0.718999981880188,0.1379999965429306,1.3020000457763672,0.859000027179718,1.3589999675750732,0.6589999794960022,-0.9399999976158142,0.8999999761581421,0.3190000057220459,-2.571000099182129,1.1089999675750732,0.972000002861023,1.652999997138977,2.6019999980926514,0.7289999723434448,1.065999984741211,1.0670000314712524,-0.3109999895095825,0.03099999949336052,Fsb,-0.6809999942779541,-1.2580000162124634,Fpb,-3.0959999561309814,-0.2280000001192093,1.9329999685287476,0.11900000274181366,2.1080000400543213,0.11299999803304672,1.628000020980835,1.3079999685287476,3.3359999656677246,0.7540000081062317,-0.4650000035762787,-0.3970000147819519,0.07699999958276749,-0.4790000021457672,-0.15299999713897705,0.14100000262260437,2.134999990463257,0.23399999737739563,0.460999995470047,0.6700000166893005,-0.3610000014305115,-1.0390000343322754,-0.4830000102519989,0.13699999451637268,-0.7680000066757202,-0.5109999775886536,3.4240000247955322,-0.8550000190734863,-0.5849999785423279,-1.5670000314712524,3.3429999351501465,1.840000033378601,0.3889999985694885,1.121999979019165,Opb,1.3350000381469727,0.3659999966621399,-0.5569999814033508,0.4320000112056732,0.20399999618530273,0.8820000290870667,0.4659999907016754,-0.4580000042915344,0.40400001406669617,0.6570000052452087,1.1150000095367432,1.9759999513626099,1.7860000133514404,-0.035999998450279236,-1.0499999523162842,1.0449999570846558,0.04399999976158142,1.0329999923706055,-1.0800000429153442,2.5390000343322754,2.234999895095825,opb,3.121000051498413,3.931999921798706,2.75]);};mlb.VD=function VD(b){var c,d,e,f;e=-0.5299999713897705;clb.Eo(b);clb.Gt(b,7);for(c=0;c<b.f;c++){f=-1;try{f=clb.xe(b,c,2144);}catch(a){a=b1(a);if(!mX(a,15))throw c1(a);}for(d=0;d<mlb.TD.length;d++){if(o1(mlb.SD[d],f)){e+=mlb.TD[d];break;}}}return e;};mlb.WD=function WD(b){var c,d,e,f,g,h,i;e=new mlb.ID();dlb.wi(e.a,new mlb.FD('Solubility values are estimated applying an atom-type based increment system.',2));dlb.wi(e.a,new mlb.FD(zsb,2));dlb.wi(e.a,new mlb.FD(Asb,2));dlb.wi(e.a,new mlb.FD('Base value = -0.530',2));d=gW(Ykb.AX,gmb,6,mlb.TD.length,15,1);if(b){clb.Eo(b);clb.Gt(b,7);for(c=0;c<b.f;c++){i=-1;try{i=clb.xe(b,c,2144);}catch(a){a=b1(a);if(!mX(a,15))throw c1(a);}for(h=0;h<mlb.TD.length;h++){if(o1(mlb.SD[h],i)){++d[h];break;}}}}f=new Dlb.q8('#0.000');for(g=0;g<mlb.TD.length;g++)d[g]!=0&&mlb.HD(e,''+d[g]+' * '+Dlb.p8(f,mlb.TD[g])+'   AtomType: 0x'+Zkb.G4(mlb.SD[g]),2);return e;};mlb.nE=function nE(){mlb.nE=W1;mlb.XD=oW(aW(Ykb.l_,1),Xlb,2,6,['mutagenic','tumorigenic','irritant','reproductive effective']);mlb.YD=oW(aW(Ykb.l_,1),Xlb,2,6,['Mutagenicity','Tumorigenicity','Irritating effects','Reproductive effects']);};mlb.oE=function oE(a,b){var c,d,e,f;if(!mlb.hE)return 0;if(mlb.jE[b].zb(clb.Gf(new clb.ag(a)))!=-1)return 3;f=new clb.ks();c=new clb.Yt();for(e=0;e<mlb.gE[b].a.length;e++){clb.ep(new clb.mp(false),c,dlb.Bi(mlb.gE[b],e));clb.ds(f,a);clb.bs(f,c);if(clb.Rr(f,1,f.c)>0)return 3;}for(d=0;d<mlb.iE[b].a.length;d++){clb.ep(new clb.mp(false),c,dlb.Bi(mlb.iE[b],d));clb.ds(f,a);clb.bs(f,c);if(clb.Rr(f,1,f.c)>0)return 2;}return 1;};mlb.pE=function pE(a,b){var c,d,e,f,g,h,i;i=new mlb.ID();if(!mlb.hE){dlb.wi(i.a,new mlb.FD('Toxicity predictor not properly initialized.',2));return i;}g=clb.Gf(new clb.ag(a));if(mlb.jE[b].zb(g)!=-1){mlb.HD(i,'This molecule is known to be '+mlb.XD[b]+':',2);dlb.wi(i.a,new mlb.FD(g,1));return i;}h=new clb.ks();c=false;d=new clb.Yt();for(f=0;f<mlb.gE[b].a.length;f++){clb.ep(new clb.mp(false),d,dlb.Bi(mlb.gE[b],f));clb.ds(h,a);clb.bs(h,d);if(clb.Rr(h,1,h.c)>0){c||mlb.HD(i,'High-risk fragments indicating '+mlb.YD[b]+':',2);c=true;mlb.HD(i,dlb.Bi(mlb.gE[b],f),1);}}c=false;for(e=0;e<mlb.iE[b].a.length;e++){clb.ep(new clb.mp(false),d,dlb.Bi(mlb.iE[b],e));clb.ds(h,a);clb.bs(h,d);if(clb.Rr(h,1,h.c)>0){c||mlb.HD(i,'Medium-risk fragments indicating '+mlb.YD[b]+':',2);c=true;mlb.HD(i,dlb.Bi(mlb.iE[b],e),1);}}i.a.a.length==0&&mlb.HD(i,'No indication for '+mlb.YD[b]+' found.',2);return i;};mlb.qE=function qE(b){var c,d,e;e=new Alb.q2(new Alb.u2(b));d=new clb.Dt();while(true){try{c=Alb.p2(e);if(c!=null)clb.Bt(d,c);else break;}catch(a){a=b1(a);if(mX(a,73)){break;}else throw c1(a);}}return d;};mlb.rE=function rE(b){var c,d,e;e=new Alb.q2(new Alb.u2(b));c=new dlb.Qi();while(true){try{d=Alb.p2(e);if(d!=null)alb.ggb(c.a,d);else break;}catch(a){a=b1(a);if(mX(a,73)){break;}else throw c1(a);}}return c;};mlb.sE=function sE(){mlb.nE();if(!mlb.hE){try{mlb.jE=gW(Ykb.tY,Llb,77,4,0,1);mlb.gE=gW(Ykb.S_,Llb,18,4,0,1);mlb.iE=gW(Ykb.S_,Llb,18,4,0,1);mlb.gE[0]=mlb.rE(mlb.aE);mlb.gE[1]=mlb.rE(mlb.kE);mlb.gE[2]=mlb.rE(mlb.ZD);mlb.gE[3]=mlb.rE(mlb.dE);mlb.iE[0]=mlb.rE(mlb.bE);mlb.iE[1]=mlb.rE(mlb.lE);mlb.iE[2]=mlb.rE(mlb.$D);mlb.iE[3]=mlb.rE(mlb.eE);mlb.jE[0]=mlb.qE(mlb.cE);mlb.jE[1]=mlb.qE(mlb.mE);mlb.jE[2]=mlb.qE(mlb._D);mlb.jE[3]=mlb.qE(mlb.fE);mlb.hE=true;}catch(a){a=b1(a);if(mX(a,15)){Zkb.O5();}else throw c1(a);}}};U1(228,1,{},mlb.sE);mlb.ZD='eOHBNZ`pge@\ngCa@@dmHFFbwH@\ngFp@DiTujhCBbKWdH\ngJPXHlQxQ{TAaeb\ngCi`HEdfZ@pRp\nfJ@FD\ngJPHAbIJuPFADVyB\ngC`@Die@ppfyD\ngJQ@@dkU@XFKGd@\ngJP@DizhC@qX|`@\ngJQ@@dru@XI[dH\ngGQ@@eMuTA`Xl^R`\ngJQ@@eKU@XYX|d@\ngGQ@@djuTAaQEcrT\neMABHXaIhH\ngCa@@dkPFBbyL\ngGQ@@drmTAaekrD\ngJQ@@eKS@XZK\\a@\ngCh@@dmPFFDwH`\neMACD\\QIhH\ngJU@DPdju`P\ngGX`HDdwMLA@\ngGY@JDivjpH\ngCi@LDek@`\ndeTH@@RYWVf`@j@CC`pjxYyB@\ndid@p@bBbFbDfYoa`b@@LJ@fx^QP\ndeTH@@RYe]aZZj`cJ\ngFq@@drfmU@X[F|b@\ndeTH@@rJJIHdsSUL@P\ndeTL@@QdfygFV``@@pjfxYyB@\ndaDH@@RVU[f@@@LBcB[bUp\ndifD@HADfyWaZjj@H\ngGQ@@dkLtAad[rP\ngGQ@@dlltHkCXwd`\ndifH@JAJ[gxZB@@CBdJf{dB\ndidHPBBHFHRYgVzB@`@phLKayE@\ndeVD`FFPbDfUnkh@a`@`\ndiD@@LdbJTZjh@pzDpjX^Qp\neFDBcA`d\ndidL@@KdiuVDjjj@H\ndaDH@@RYe[hB@@LJpj[nP@\ndiT@@DiYXfifjjh@`\ngF|@ABeKZsU@P\ngNq`@fdvkSHf\\EcqJ`\ndiDL@@PTfU]jZP`f\ngJP`@TeZhCCKGbD@\ngNp`@dfujj@plVMx`p\ngGQ`@jdjmTA`l^JT\ngNp`@dfUZi@pVOEV\ngNq@@djkUPFEVM_I@\ngNq@@djmUPFCbqky@\ndiDD@@QIeuZfhHJpkBiny@`\ndaxD@@QIgUjj@LLpfxe\\\ndaxD@@QImeijBLlBSJ[d\\\ngNp`@deVZj@pNM_I@\ngNp`@dfvZj@pNM_H`\ndaxD@@QIeejj@LBpj[d\\\ngNq@@djmSPf\\GEcWr@\ngJPdE`DRPcyXCrD\ngGQ@@dsmLIkCKGdh\ngNq@@dsmUPFEDVOEV\ndaxH@@RYuji`bgA`SBknIC@\ngGQLJIARAdDfzj`LInJT\ngGQLLIAREdDfvj`LINP`\ndiDHhLBPRPjPzPFPR[[jjj@H\ngNq`@jdjsUPFAqkyH\ngGP`ATiVj`LMEnHt\ndaxH@@RYWjj`CC`aLInyE@\nfHc`A@\ndiF@@@rRHiJjj`CChSBiny@`\nday@@@{IEHkUU@FC@fES\\c`\ngGXDL@aABS\\uPFFAoH`\ngNxLL@aAABDfVZj@`\ngGPB@DHHpQPaIUZdB\ngGPD@DXHRfZf@ppUxlP\ngGX@@dsuTAaQEcrT\ngJY@BDeZlCBSbB@\ngGY@LDeVj`LCD[qC@\ngNx@@eRmUPFEbu_HP\ngNx`HDdvkSPfX\neMhDRZCAKd`\ngGQ`@ZdruTA`qEcP\ndiDDpLH@bOA@aIkUZjh@`\ndaDH@@RVU[f@@@LJcBinQp\ngFp`@dfTujXCAZ|a@\ngOx`FDdrikTtA@\ngJP@DkfhC@bH|f@\ngC`D@DSpRnhB\ngNq`@bdvkUPFFV_IP\ngGPP@cTfyi`ODj\ngJP`@TeZhC@qX|`@\ngCaHL@aIZPLDIrH\ngNp`@dfUZj@pvMyF\ndaxH@@RUVZj`CAdpj[nQ@\ngJQHLHaIVj@`\ngNphMQDIK[UTA@\ngJQ@@dkSBJpHbwHP\ngNqBLIAREdGHIMmUTA@\ndaxL@@RdfuVjh@pILInQp\ngGQ`@jdvmTA`l^IT\ngNp`@|dTQjj@plVMyF\ngJQ@@eOU@XZH|f@\ngGT@ATiVj`LJHm^P`\ngGT@Ade[j`LHnHt\ngCe@H`dkPGbV@\ngGUHLZHaIUjdB\ndazH@LAIV^jj@LFBDInyE@\ngJP@DiVhPVFbwDB\neMDARVCAd\ngNphBqDILsTrA@\nfHghA@\ndeTD@@EIYe^efjZ@H\ndeTD@@QIgeQej@@@LJrfF^Qp\ndcLD@@UIUe]FVX@J@aKCdrfx]yD@\ndmtD@@QImYVUZX@@Hrp{B[ae^P`\ngGP`@deUjPLEcqR`\ndeTH@@RUYTYi`@@aK@XSJ[agd@\ndmtD@@QIee^UZ``@@pXjXYWd\\\ngOp@DjWkjj`LJEc^JL\ndmtHPBBHfHRYeUXXHHh@H\ngOp@DjWkZj`LCD[qY`\ngJQHBJqIVz@`\ngCa`@ldkPD\ndmtL@@RTeYW^Eh@J@CBbinWdP\ndid@@DjU^nBBD@LFaLiaxa\\\ndeTD@@qI[eQej@@@LNSJ[agdP\ndcLD@@QInUuxV`@j@CCdJfzUyF`\ndmwD@HePQInUwaZ@B`@`\ndaE@@@YIeZn`B@@pILinHG@\ndmvL@HAFR[f^FV``H@H\ndeVD`NFPbDfUvih@I`@`\ndmvD@DATfYUQUjjj`CAlJfx^QH\ndeVD`BxPbDfYYZXHF@@`\ndmt@H@bAdIdEdDfUvjZ@Bj@C@`pjyB@\ndcNH@DAIee^eVhHB@CCbine]yB@\ndmvH@JAJUuTjjjjh@pFDpfxYyB`\ndmvH`HX@cIEDdTljjVj`B\ngJQ@@dkU@XDSGdP\ndiDB@@SaRUYVjj@LJrfx^IA@\ngGQ@@dkUTA`Xm^HD\ngGP@H\x7FUPD\ngGP@DkYj`LJEc^R@\ndaxD@@QIgUjfBJlLpfxe\\\ngGQ@@eNuLIkCKWba@\ndctH@@RgYujfjZBLX\ndiDD@@QImiZjh@piLiny@`\ngJP`@dfvdCBGbV@\ngNq`@fdrkThD\ngJT@@defhCCSGd@\ndeTL`HS@BLddlRPrm@@@FEYSCOHx\ndmLD@@QIee\\jeVhHB@CBbXYWd\\\ndet@@Dje^ifzjjj`B\ngOp@DiUMZj`LFHlWrT\ngC`H@DIMTAa`mrP\ngNq`@fdr{UHFBqyJ\ngJPXHlPDQztAxlP\ngJQ@@dmS@XZX|`@\ngJQ@@eMU@XYX|d@\ngNphBpDISkURA`QEnR`\ngGPhLQDIKUU@P\ngJP@DkVhC@bK\\a@\ngJQ@@djsBJpTwDb\ngNq@@drmUPFCDVMyF\ngGP`@TfVj`LJHl^R`\ngNq`@fdrkUHD\ngGY@LDenj`LJHl^R`\ngGPhCQbILmU@P\ngOx@@drm]UTA`plZ~R@\ngGP@DjZj`LCEkq@`\ngNq@@dkMMPb\\CD[qA`\ngJQ@@dju@XJGbV@\ngNq@@ds]UPFCDVMyF\ngNx@@eLsUP`lLb~KT\nfHdXA@\ndidH@@RUe^Ejjh@pyLJfx^Q@\ndidH@@Rf~hRjjh@`\ndmv@`EBHrJJIHin`HFpHy`\ndeVD@HADfyeFV`H@@piJ[iy@`\ngOp@DjWkB@@LBmWqP`\ndeVD@HADfyUxV`@`@piJXYyA@\ndeVD@HADfyWxV`@`@piJ[iyA@\ndmv@@@rQQJEJUjh@@@pdHPfxYWdT\ngNqhHl@cIIJeiaCP\ngNpP@jtfvZf@pfxdp\ngGP`@dfUjpLH^R`\ngNp@DkUzj@pjqkyH\ngJQHHOAJuj@prqy@\ngJQHHOBOZ`H\ngJQ@@dlu@XJGbV@\ngNq@@eJuUPFEbu_HP\ndeU@@@aJyenF`HH@H\ngGY`HEdf]j`LEkrD\ngJX@@dksBIpROI`\ndedD@@QImUVjj`C@Tpj[ad\neO`BNZ`pYy@\ndaDH@@RYe[jfj@LFBLJnyC@\ngJQ@@dsT`XDQ[dH\ndid@@DjU^nBBD@LNaLJfGd\\\ndidL@@RdeVWaZjj@LJpfx^Q@\ndaF@@@Rfu[j@@@LFABinyF@\ndedD@@QImiVji`B\ngGP@DjZj`LCL[qA@\ndiDL@@RdeVyjf`B\ndmtH@@ReY}Jjjjj@H\ndcLL@@Sdf^YV]Z```@LJqae^Qh\ngGT@@dfuj`LBEcrT\ndif@PACDJHRYgvzB@`@`\ndcMH@DTLbbbRRHjuUUT@X]aTwCoHd\ndkmD`LND@HrRPjZIE]VhBB@B\ndidHPBBHFHRYgVzB@`@pHLx^HU@\ndmvH@DCHhhhTiUjjj`CAl[ae^HU@\ndknH@DAIfYuUMjjjj@H\ndcND@DCdf^YV]Z```@LFQae]yF@\ngF|@AbeJf`@@P\ndifD@HADfyWaZ@@@LBRnGbDp\nfHapA@\nf`i@`@@VRYfYU]`eNMyh@`AB@@H\ndk\x7F@@@cLdRfbTQragSfhJ@T@H\ndmLH@@rJJIQEneX@@@@C@`xYxVTr`\ndk]H@BDLbbbbRQZ]NB@P@@B\nfoA@R@HHqH@QddebRbrPeV\\m@D@@@A@\ndaFH`JHHaIf]n``@@`\ndmv@HBBHFPfPVPRYUzih@Jh@H\ndeTHPIBPzPRYeea`Ha@CCLX^QP\ndeVHPIHHchaIf^VFBBH@LBCNGbEH\nek`PJ@@@GNimlbbRfbbebrTRLrThXTlBbrjZVjjjjjfijh@CAICBc`RQSPrqspIHjhX{dFP\ndmvL`EaL@HrRRqIXYV`@`@`\nfewAP@@LtT^QQQRUJQYSQZXpgCNCeNVfjjijjjZj@B\nfoQ`@@@YIEDeDTdqWAF]UUAAE@@XB`cENRUkaFFlx\nfde``@C@heMrklk|dYpXtDDUUTT@D\ndk^H@EAJ[UVVySh@JjH@pyBhYT~If`\nfoA@@@LdbRdVeRiJs``j@@@@LEPPRgAJtZwDR\\\nf`qA@@@YEDeeHhTjL]z@Bj@@@@`\ndcnH@EAIfV^XYv@@B@@H\ndmtL`HS@BLddlRTFUh@H@H\ndeT@H@bBbAbIbDfYu[hHB`@`\ndcLHpJBPRPrPrJPsQIKmTp@@A`WBn|bP\ngGP@Di]ja@xTQF|f@\ndcLB@@Q]R[e[neh@a`@piBj]yG@\ndeU@@@eJYW~F``H@LFCBinxbR\ndeUD@HdDR[eWaZ@B@C@diaxaR\ndeVH@DAIgeQej@@@LJSJX^It`\ndcNL@HAFR[fUqUhHH`@`\ndg^L`EaC@HrRPsIYJCJt@EL@FCTwBm|``\ndaFHpBxHa@bhcHheBSTuL@P\ndg^L@D@mRY^UueVj@Bh@H\ngOp@DjWkB@@LMc^ZI`\ndidD@@yIfVXXBH@C@`[axfT\ndaDH@@RYWih@H@LJSBknP@\ndeTD@@YIfUqehD@@LJJnF^Q`\ngFtHHPDIRnMKPFBEyD\ndcnDPJa@BBBLdabRRS\\nkSP@@A@\ngNxhMD@cIHUEj`LCcWr@\ndclL@@pTign_JWZjB@`@`\ndcnD`HI`BDfYoVnWZfX@@@`\ndidH@@RVY^Ejjh@pyLJfx^Q@\ndedB@@PiRUi]jjT@`\ndmTD@@QIeUyjZZBBh\neMFINbMP|`\ndo}H`BMPbLbbbRfebXXHHfj@B\ndo}H@DhDfUfUWWZhJB`@H\ngGT`EaTf]j`LDkqX`\ndayL@DpFyIeUjj@H\ngKP@H~Jj`LEcqQ@\ndid@@LdbLTifjj`B\ndaDD@@QInXjZjh@`\neMJDBDfPpce@\ndaEH@FxDiebjiV`CCDJnHw@\ndk^H@FAJY}e\\kSie`@`HipyLhYW^HQ`\ndaFH@LAIVUnZjh@pHj[nIB@\ndieH@DHDfvWaZjj@H\ndg~H@LCHeEEDdcJg[UPTA@A@\ndifD@HADfyWaZ@@@LLPjyc\\H\ndg^L@HAER[e[[xV`@jh@H\ndeVH@LAIVYQejjj@LNPj[agdP\ndeVH@BAIV[Qejjj@H\ndmtHPEBHzHrJJISEa`HbP@`\ngGQHLHaI[ihCCBWdH\ndmuD@HXDR[fUEV```@LBRiWfMp`\ndg}@@@mJYeU|]Tz@@@H@B\nfhy`B@N@BLdTTTRRVqirUmNh@`BBh@@pt@cARUhugAyCp\ngKP@LdabjhC@bH|f@\ndmtH`ABHRYW[ih@Jh@LNALJaWb]H\ndg|@@DjWmijXYB@jjb@H\ndmtD@@gHhhhdVEjjj`C@TpfxYWdT\ndeT@@DjU_k``RPHjpFDpj[ayD`\ndeTJ@@qaeJYyzzjjj@LIaLJfxY@\ndev`@@rfeJY{ZxYBBJD@`\ndefH@LAIVYfjj`B\nf`aQB@BFTBHrJJIJZUJLEAADuT@A@\nfHdHA@\ndidHPFBHJHRYf~FBH@@`\ngCe@H`dkPFDwH`\ndcND@DCTfVutYZ`@d@LJJfx^Hb`\ngGT`IPdfuj`LDmqF`\nda{D@Hi`QImejj@H\ndkm@`DDHaIe]YZZ@Bjh@H\ndcL@@LdbRbjeBDEEP@XCBES\\n|SI@\ndmvHPBTH`XaIfUmi``hP@pXLIagd\\\ngGYHCaDIK]M@XHSbM@\ndcND@DCdefV]]Z`b@@H\ndmtD@@QIVYdUZ@b@@`\neFPBca@\ndiDJ`HSJDOCIIJdfjj@LJSBx^Pp\nf`aqR@AF}AFJZAxYIITdhhmkNZjjfV`@pxcANJm{dF@\ndid@p@bFbAbDfUfn`BH@LLAaybYp\ndeVL@HAFR[f\\YZB@@C@diixgB\ndif@`ABHRYevz@``@phLJny@`\ndcNH`BdHaIfUyXXHHZ@B\ndo}H`FMPbLbbRfRaRkh@bfj@B\ndayH@DhDfWVjh@pKB[nHe@\ngNx`BDdvkUPFFu_Db\ndigD@Dq`yIeUifff`B\ndk^D@D@\\bbbbRQImMj`XB@C@jWSxgR\nfgA@@@DjYU_VByHu`@@@@@@H\nfoA`@@@ILkjrmFV]@AL@@@ar`\ndcLD@@SHhmEDcJmPDD@FA\\L{qLX\ndeUD@BdDR[YTYZjj`B\nfoA@b@HHAxIRlrjzkF]U@@@@@A@\ndif@@@RifvFjjh@pzDJfx^Q`\ndaD@`@bDfUZZ@B@C@`qnxbD\ndcLD`BTHaIfUVXXHHf@B\ndidH@@rJJIEn`HH@LJ@jX^Q`\nfbu@`@@NrJJJIPjFKQLDFLADUA@T@@P\ndidH`ACDRYWZZ@B`@pXDpjGd\\\ndg}@@@mIe]e^ftx@H@H@B\ndmvH`FdHaIe[zn`BI`@pXDrf{dJ\ndcNH@EAJYYeGZBHh@B\ndeTL`HRPBLdabRwBl@D@FEES]OH@\ngOp`Adigujj`LCEWrD\ndmtH@@RYeUEV`P`BJlNpjxYWdL\ndeTL`HS@BLddlRPrm@@@FETwCOHp\ndeV@@@rQQQHcMAP@@XBBXUMp|bP\ndmvD@H@de[eYVZ`@@bJ\ndaE@@@yIe^f`@`@pKBknHB@\ndcLH@@RfUW~f``b`@pEBinE]xfR\ndo|H@@rJJIQPrEn`HJjh@H\ndg^D@MADfVU}iUjB@j@B\ngGY@LDenjPLBHcqZ`\nf`qh@@@XIQfRJJKZJEJgG^ejj`@`@H\ndcnH@LAIYe_x^fjjjj@H\ndg^B`LaAl@cIIBheEeikTBPH@XUgSi|Re@\ndg^B`LaEt@cIIKEDhcIkPPLP@P\ndo}B`LfDEpBLddJbbbJNujAbA@B\ndieH`LE`BDiU_Bjij@LBAJ{bPH\ndk~@@@RfYU_JGUN`@@B@@pDB[aeSyF`\ndmtB`HSE@HrRRqIXYV`@`@pKFy^IP`\ndmtL@@jTef_^E``J@C@biexd\\\ndcl@@DjYU_egX@@@@@pxjxYW^XfL\nf`q@`@@HRYyV{TRg^Z`B@@@@H\nf`qA@@@ILk\\joSagPA@PP`@D\ndmt@H@bAdIdEdDfU^jZ@Bj@C@`pfyB@\ndcLHHBBHfPVPvPRYg^fzB@j`@`\ndcn@@@Re]eRi]jj@B@CBXPjxYW^HF@\nfbuQB@BFTBHrJJIJZUIQILDgLDDSU@@@@P\ndcMH@DhDfufU]Zjjj@H\ndmtD@@[HhhhdYUhJ@@CAlJae^Hw@\ndmtD@@qIYyVUZh@@@pYFxYWbPP\ndeT@@LdbRTm\\DDT@FGIeMpsrH@\ndmtHpEBHJPFHRYgW[hHBd@H\ndid@@DiUWajjj@LAaLJfx^P@\nfde@P@@BLEIfYfY\x7FyiWgQZ@HJ@b@@H\ndieH@JxLbTTQkfej`CAFGbPP\ndaD@P@bNbDfUzZ@B@C@`pnxbT\ndmMH@DhDfUmZZU`@@@@H\ngNqdEb@b^FQRHmU@P\nfoAab@GPQ`@QddebbTVLmFlm@@@P@A@\nfH`pA@\ndg\\B@@SSrJISISPbkT@Pt@D\ndeV@@@RiU\\Yjjj`C@XSBkagdL\ndmLD@@IJ]YVDeZj@B@B\ndmLH@@RgYVaAfj@B`@`\ndid@@DjWxjZjZ@H\ndaxD@@QIUijj@LLqnxdT\ndmtD@@QIee^UZ``@@pZfxYWdD\ngC`dE`DSpRZXCsBX\ndeV@@@RfV\\YhH`@CCdJfxYy@@\ndcMH@FxLdTReRQUTkUT@P\ndcNL@HAErJZJIECKPDE@A@\ndefD`BpPbDemgijj@H\ndo~H@DCHeEEEEBmmjBbH`@`\ndo~D@D@|bTTTTRqvvhJHb@B\ndknH@ICHhhhdUFF@bJh@H\ndeT@@LdbRbmBDED@FGPfTwSrB@\nfoAab@NPQ`@QddebbrRTeV\\mA@@@@A@\ndeVD`Aa@BLdabRgRl@P@D\nfoAPB@NJ@DYHhhheEcJqgT@PP@@@P\neMAALhbN``\ndidH@@RYWZZ@B`@pXDpjGd\\\nfde`B@N@BLdTTTRRVqeNRmiu@D@PUP@A@\ndk^L@IANRY[f~]tvjjjj@LApjXUt~It`\nf`iPB@N^@DISLro\x7FSdcZmPA@@W@@D\ndcLD@@QIVYVFV`HJ@CAfxYW^IE@\ndklD@@QIgfUiUj@`h@H\ndk\\D@@QIVZVVfSZjjjh@`\ndk\\D@@sIEDdXdj[Sjj`@`@`\ndeL`@@JfRiUfnXVfjjjh@`\ndif@PBBPFPRYgvzB@`@psJ[dD\ndmvHPBdIAYAIfUua``a`@`\ndieHPJD`bFbDfYoaiZi@H\ngJX`LDdvu@XI[dH\ndcnH@BAJ]fuaEvjh@H@H\nfHcxA@\neFAADdRLD\nfHdxA@\neMJD|Df`pYy@\ngJPhHaxIRuPFBqy@\ngJ]@EbDfVhCAH|f@';mlb.$D='fHe`A@\ngFq`@ldrfmU@XR|a@\ngCl@@ldsPFFBp\ngC`HADIKTAaaMrH\ngNxHLHaIYjj`H\ngNxHLHaIVjj`H\neFDBcAaWH@\neMDARVCBnR\ngGP`@TfYi`LI^S@\ngJQ@@dkT`XDKGd`\ngGQ@@dkUTAaXl[r@\ngJQ@@djsBJprqyH\neMHAIdLF^P\ngJQ@@dls@XKGd`\ngGP`ATiVj`LCEkrD\ngJP`AdejhC@qX|`@\ngGP`ATiVj`LCEcrT\ngJQ@@dsU@XDKGd`\neMJDbDfP`\ngC`DADZHRVhB\ngC`DAb[DRVhB\ngCa@@dkHFBbyL\ngCa@@dkPFBfyD\neMABHYAIhH\ngJPH@DIRuPFABqyH\ngCa@@dkHFBVyH\ngGQ`@jdjmTAal[rP\ngGY@LDeVj`LJHm^P`\ngJXHLHaIVj@pHbOI`\ngOx@@drm\\@@A`plZp\ngGXHLHaIUjhCBbHwdp\ngCh@@doHFDwH`\ngJY@BDeZlCAQ\\`@\nfHgdA@\ngJQ@@dsT`XDKGd`\ngOp`@dfUMZj`LMc^Q`\ndaD@@DjUZxHD@CAhSBinQp\ngOp`@dfUkZj`LMj~P`\ndeTH@@RVYWahBA@CC``j[ayD`\ndid@p@bBbFbDfYoa`b@@H\ndaDH@@RYg[ffj@LBrf{dD\ngFq@@drfmM@X[F|b@\ngGQhHj@cIHTmPFFqoH@\ngJQhHl@cIHUhCBGd@\ndaE@@@yIe^f`@`@piLJny@@\neMhDRUB\ndie@@@aJvUxZ`@@CChPj[ay@@\ndifH@DAIf_Ifjj`CBlJf{dB\ndifD@BADfyWaZ@@@LBQnGdT\ndeVD@FADfygFV``@@pjfxYyB@\ndeVD@AADfyVzV`B@@piBkayD`\ngF|@AbeJfuU@P\ndetD@@QInYvDYZjjh@`\ndedH@@RUUUfjhHRpELJfxYyD@\ngJQ@@dkU@XZX|PP\ngNp@DiWjj@p\\VM_H@\ngNq@@djmUPFEfM_DD\ngJQ@@dkT`XZK\\PH\ngJQ@@dkU@XDQGdp\neFA@HoBJD\ngJP@DjvhCCKGd`\ngGQLLIAREdDfvj`H\ndiDHhABPRPjPZPzPRZyjjj@H\ndiDB@@SaRY]fifBBX\ngNxHF@aJUzZqDxXH|Tp\ndmv@@@Rf~UeZj@@@LEBDpfxYT\ndaxD@@QIUYjj@LBrf{bPP\ngNq@AdTbMUPFEBq_IP\ngGP@DiUjaAXFKGbE@\ndaE@@@YIeZn`B@@piLiny@@\ngCa@@dsPFBV@\ngOp@DjWkfZ`LKEc^Q`\ngOp@DjWkZjPLKEc^Q`\ndaD@`@bDeeVz`@@CA`cBinQp\neMABHPaIhLDnR\ndaDH@@RVU[f@@@LJ`j[nQ`\ngC``AdeZ@pTWI`\ngFp`AdiTvjhCCQWdH\neMbDBDfp`\ndaEH@JXDiWRjjj`CBhSB[d\\\ndaFH@NAIe^f`@`@piLJny@@\ndaF@@@RYe[hB@@LJCBknPp\ndaF@`NBHRYUih@H@LJCB[nP`\ngC`@Die@ptVy@\neFA@HoBLD\ngGQ`@jdvmTAaecrT\ndaxB@@RfRYYZf`B\ngJQ@@eKS@XJKbq@\ngCaHLLQIZ`LDEqS@\ndaxD@@QIeUjj@LBpj{dL\ndaxD@@QIUUjj@LJpj[nQ@\ngNp`@df]Zj@pvMyF\ngJP`@dfzhCCA[ba@\ngGQ@@eKuTA`Uc^R@\ngCaHLHaIZ`LLHnS@\ngGPhMQDIK]U@XTQX|e@\ngNp@DiUZjDC`qEc^Q`\ngNpH@DIRoUTA`qEj~P`\ngNp`AdiWjj@pJM_I@\ngGP`@TeZj`LKEc^P@\ngGQ@@eJuTA`Xm^P`\neFJBhHp^I@\ngCah@mJAIj`H\ngCahHlOBOTAaAsQX\ngJT`H`TeVdB\ngNx@@eJmThFCbqky@\ndif@@@RUe^Fh@@@pDHPj[a@\ngNy`LDtfuZj@pNM_H`\ngNx`LFdjmUPFCDQkyL\ngOx@@drm]UTAaqEcV\ngGT@ATivj`LKEc^P@\ndiDDHJXIAICi@YAIkfjfh@`\ndcLL@@STfVyVUZ`HD@H\ndaDH@@RVU[fZj@LBJf{bQ`\ndmtD@@QIUYVUZh@@@p{B[ae^Q@\ndeTD@@QIgeQejjj@LFpj[ayD`\ndmtD@@QIgeTYZjjh@p{B[ae^QP\ngOp@DjWkZj`LCL[qI`\ngNp`@df^Zj@pvkyB\ndeT@@DjWvifjjh@pFDpjXYyG@\ndidD@@qJY~rjjZ`B\ngGQ@@dmltA`h^KT\ndcL@@DjU_ZnZjij@H\ndcL@@LdbRbjUBDEEP@XSBXUMt{rE@\ndid@@DjWZfZjj@LFcB[ayB@\ndid@p@bBbAbDfYun``H@H\ndcMB@HDDWTfyV{iZ@HX@H\ngC`dEaDPHRZTB\ndmtD`NDHcHhheDVfBAb@CB`rfWdR\ngNxhGD@cIHTefqMP\ndaFH`HX@aJYWJjeh@pHDJnQp\ndax@@DkUfjh@pZDpf{bAP\ngNp`@df^Zj@pV_DZ\ndedD@@qJ[^ZjZ`bf\ndaxD@@QImUjj@LJSBknPp\ndiD@@LdRbJZjhHBpxHpj[nH``\ndaxD@@QInejj@LBRf{dD\nfH`TA@\ngJQ`@bdjt`P\ndaD@`@bDfUjZ@B@CB`SJ{dL\ndkm@`ATHaIe[ujZ@BfhBAh\ndif@`BBHRYgfzB@`@`\ndetD@@eIYe~DYZjjh@`\ndaFH@DAIYUnZjX@pkBinyD@\ngC`HAVIMTAaaMrH\ngNq@@djuUPFCDqkyD\ngJQ@@dju@XZX|b@\ngCa@@dmHFFDwH`\ngJQ@@dsMBRppVyB\ngCahHlOBNtA`anQ@\ngGQDJH`qBSKMHdX\neMIDbKpRYB\ngNx@@eJ}UPFCDVkyB\ngJXhEbLQIZf@`\ndnD@@DiYrbYjj`CA`aLinPP\ngF}@EbDfTuiXB\ngJP`@TfZhCCQ[bA@\ngJPhLQDIKUPD\ndiDB@@RnRYufjf@LDp^PP\ndmTD@@SHheHjfjjh@pXj[agdJ\ngNpTHjpDDHrREQZTB\ngGP@LdbMU@XTQZ|a@\ndiDH@@rJJQUjj`CBlJf{dB\ngJQDDH`qBS]LHj\ngNplJqHJPtadTaeTpGdX\ngJYHLPDIStpblDEqP`\ndiFDpJXPdDdLdLbdJRjfdHI`\ngGX@@eKMTHGCKWba@\neFHBJFE@\nfHfpAa@\nfH`XA@\ngOu@DPdrykURA`l~Q@\nfHgHA@\ngCa@@dmHFBVxa@\ndmtD@@QIgYVUZh@@@p[FxYWdD\ndmtH@@RgfueZj@@@LASJ[ae^Q@\ndid@p@bFbAbDfUfn`BH@H\ndidH@@RYUZZ@B`@phLKayB@\ndmuL@DpIUIfVTfZjjX@`\ndeVD@HADfyVxV`@`@piBkiy@`\ndeVL@HAIR[e_aZ@B@CBdJngdL\ndmvL`NaL@HrRRqQZUV``@@`\ndco@`LK`BLdTTRRITntpTA@Pe@\ngGP@Djuj`LLm^JD\ngKP@Di\\Vj@pHfOH`\ngNp`@dfVZf@pQ_IP\ndaxD`Fx@aJUzjf@LJBDsnPP\ngGQ@@djuTAaQL[rH\ndaxH@@RUUjj`CC`cBinyB@\ndiDH@@RYujjj@LAALJfx^Q@\ngJX@@dku@XIGdp\ngJX`DBdju@XI[ba@\ndazH@LAIUjjj@LFBDinyF@\ngNq`@fdjkUHFBqxiP\ndaDD@@aJyUnh@@@`\ndid@@LdbbQxXF@@CAdrfx^PP\ndid@@Dj{WaZjf@LNaLJf{dB\ndaDH@@RYUifjj@LJpj[nP`\ndaDD@@YIeZn`B@@piLiny@@\ndidD@@iJ[gxZB@@CBdJnGdL\ndaFD@FADfyVyjj`CBdpj[d\\\ndewH@HP`RY[TjFZd@H@H\ndiD@@DiuejjP`GChSB[ax`T\ndmtDPNDHaXaIfVUi``X`@`\ndmt@@DjU_jxHHj@CBXPj[ae^Q`\ndmt@@DjU_ZxHDj@bg@XSBkagbLh\ndkl@@LdbRdSRjP`jJ`@pfDJfxUOdZ\ngOp@DiWMZj`LKEb~HT\ndmtH@@RYfWXXBHh@LF@fFUxe\\\ndax@@LddUeUT@XMBXS]rJ@\ngOq@@eJqmUTA`Xl~Ht\ndaD@P@qBbDfYvzB@@CB`pj[d\\\ndmuL@HDDWHihdh^eh@b@B\ndcNL@HALRYymUujh@@@`\ngNyhMDpDYIBdmTA`\\Z~P@\ngNx@@dlmUPFEbq_DJ\ndknL@CAErJIQIIF]Z``b@B\ndeVD@DCdeeY[fjjh@`\ndid@@DjUfaBB`@LNaLinGdD\ndifL@DCaRY]bijih@`\ndifH@DAIf_Ifjj`C@lJnxcB\ndcMB@HXDeTfyed]ZBA`@H\nfHcdAa@\nfHchA@\neF`BNFE@\ndeTD`HP@cIHXdepk@A@A`ULL|PB@\ndeTL`HS@BLddlRPrm@@@FAXwSqJD\ndcnH@NCHhheEBtkl@D@@@P\nfoA@R@HHqX@QddebRfR`iF\\m@@A@@A@\ndieH@BxDfYUa``P@LBCJ[b\\H\ndeTB@@pYRf[^njjj`CBXSBinFP\ndaE@@@aJyUnX@@@pkBinyD@\nfduA@@@ILsLjm{AJ\\XOhm@@@@A@@A@\nfhy`@@@ISLjm{btjw`t@@@@@@@P\ndmvH@DAIf{VUZh@@@p[J[agdJ\nfnkA`@@N[dTRTtTTlVRbUFJlFNZmKUUUUUUT@F@TXipTeZMYw`iKWbLm@\nfig@P@@NZOHhdihhiXleDbjLUXL\\uZVjjjjjij`@`\ndeTL`HS@BLddlRPrm@@@FAXwCqJd\ndet@@DjYUX^dHbH`CAdJfx^Id`\nffsA`@@LudTTTeRdVTtLIps`ySeijjjZjjj@B\nf`ia@@E@RfuUe]gEF]z`@jjhh@LAHIPTmFmsFG^@\nf`ia@@M@RfuU[UgEZ]z`@jjhh@LAHIPTeFmsFG^@\ndmLH@@RYegXYV@@@@@pXJXYWbYp\ndmtD@@QIee^UZ``@@pXfxYWdT\ndmtL@@QTfyeQehBA@C@jXYxb\\\ndcLB@@RUR[fVQuhHF@@`\ndklH@@rJIJQQNfZjji`B\ndmt@@DjU_ZxHHj@CBXSBine^PH\ndaDH@@RYWih@H@LB@j{bI`\ngNq@@dsKSPFFu_HP\ndeTL@@QdfygFV``@@piJXYyG@\ndmv@@@RfYWEZB``@LIALJfxYyB`\ndmuL@HTDYInYtYZB@`@`\ndeVH@IAJYW~F``H@LJPj[nId`\ngFuHC\\@aJYMif@`\ndifH@HAIYexV@`@C@biny@`\ndmvD@D@dfWeYUj`@@CCdpfxYyB`\nfoA``@H@PdwJ{J|EYsP@P@@@D\ndif@pDBHjHFHrJIQEn`HH@H\ndclL@@{TivY~DeZhHB`@`\ngFp`ATiTvjhCAH|Tp\nfgA`B@N@BDifYWz\\d[Uj@H@B@@LI@Hs`eZM[dI@\ngC`HAxIKTAahmr@\ndg|@`@|DjYmUyO[j@@@@@LM@j[ae]N~Q`\ndeTD@@YIfUqehH@@LFJfxYyF@\ndeTL@@jTef_xVB@`@phj[iyD@\ndeTL@@RdfVUFVjZd@pHfF^Qp\ndeT`@@biRnY\x7FaXHB@B\ndif@PJ@H`HRnY~F``@@pXBinGdP\ndk^@@@RfYU\\]Tz@@@@@LECBinFUOdZ\ndieDPJZD@HHHrRFIYnVfi@H\ndmND@DCdfVUrjUZjZi@LFrfFUyB@\ngOp@DjWkjj`LFEcWrP\ngOx@@eJqmUTA`xlZ~P@\ngOx@@eLm]UTA`xlZ~P@\ndcnH@DAIYegzUujBHH@LNInFUwdP\nday@@@aJVYjjB@h\ndedB@@PYR[UYjjX@pILZ^HU@\ndkLF@@RUttfyenZjif@LFSBiSyG@\ndmTL@@QdfUivijdHJ`\ngGY@LDeej`LBl[rP\ngGY@BDeUj`LBl[rP\ngGY@LDeUj`LBl[rP\ndkmH`NMPbLbbbTNfXXBHf`@`\ngGY@LDeUj`LLc^JX\ndmv@@@rRJIIFUjB`@@pELJfzUy@`\ngOx@@drm]KTA`Pl^Jl\ndaF@@@RYUijVj@H\ndif@@@RYWZZejh@`\nfoAa@@D@RUfV]qZlyhH@@@@CBRJ\\DkQkNxbD`\nfoAa@@D@RYYeUuVLyj@@@@@CARJLEIVcV]rG@\nfj}a@@D@rJIQQIQKQEYSkQrUj@@`@@@@@`\ndie@@@iJYWxYB@@bK@lInybTH\ndifH@NAIe]ih@I@C@dpjx`B\ndcn@@@rRIHqIER{UT@D@FDpaUprn|c@\ndig@@@aDiyWaV@@@LJPj[nPH\ndg~DPFvpbEBLbbRfbRM\\JpAESI@D\ndeVD@JADeUeFVjjh@p[B[agdP\ndmuD@LXDRYueeVjjj@H\ndmtD`BTHaIfUma``bP@`\ndaE@@@{IHdbUUUT@XMBXUMrN@\ndifH@LAIVUxVjj`CAdJfx^Q@\ndeVH@IAJYW~F``H@LFSBinyD`\ndifD@HADfyWaZ@@@LLRayaMp\ndeTD@@QIgeQej@@@LLsayeMH\ndeT@@DjUghP`h`@pYL[agfPU@\ndeVH@LAIUeQejjj@LASBinF^Q@\ndmuH@DHDfvYYUjjj`B\ngOx@@eLvmUTA`xlZ~P@\ngOx@@eRimUTAaXcWrX\nfle``@C@Pdrrj\x7FLlmQRuAAEUTP@P\ndiFH`JpHaI[kijh@`\ndeVL@BAIR[YTYZjj`B\ndg|H`ABHRYW[ficn@BjjH@`\nfoAqB@EZ\\HDPdrnvrtYYt@EURd@FD`HpR`iFmrG@\ndk_H@FdprJJISPkatzjjiZ@H\nfoAab@GPQ`@QddebRfRpiFlm@@@P@A@\ngNy@LDeVZj@pJM_EL\nf`aQ@@DT@drllsNoMTDQT@@P\ngJX@@eKU@XYX|P`\ndid@@LddRL[jjj`CChSBkayC@\ndk]H@DdDefueFUujjjj`B\ndg|@@DjU_eZx{BAH@@BJlARne]N~EFDp\ndmvD@HADfyeQehBA@C@dXYye\\h\ngBX@@eLUTAahmr@\ndmLH@@RYiYKnVjjjh@pFLinFUy@@\ndg_@`DGPbDfUueZZ@Bjj@B\ndeVH`BdHaIfUvFBBD@H\ndaFH@LAIVUnZjh@piBinyD@\ndg^H@LAJUyfUSjhBH`@`\ngGPHAbIKUU@P\ndmtH@@rIQQQWiXBH`@pjfxUyD@\ndcOD@Ds`wHheELUPmMUT`FCTwBn|bP\ndeTH@@rJJIHmtAAP@XTALL|sJx\ngOu@E`drm[SRAalWrT\ndo}H`AMPbDfUo[Vf`@jZh@H\ndg]H`AMPbDfY_[Vz@`ij@B\ndkmH`NMPbLbbRrbaih@Jf`@pxDpjg^PX\nf`q@@@BbHRDRHQHaIXkf`bJbjb@CARB\\EKQkN}rB`\ndcLL@@G\\dTRRbOKPPTP@XRfES\\LkrM@\ndklL@@Ptfym]eVj@BP@pyLinF^Qh\ndg}B@HTDf|bfbbTThfnmA@tI@D\nfoAP@@@HR[ieUuVLyjhJBH@B\nfoAab@KPQ`@QddebRfR`iF\\m@@A@@A@\ndg~H@FCIEDhcLdLg]AP@@@A@\ndmvH@DCHhhhdYUjjj`CClJfxYyB`\nfhiA`@@Hddjrm|jIW`mPAD@@@A@\ndk~@@@RfYU_JGUN`XJJH@pDB[aeSyF`\nf`i``@E@PdwJvvoAJt{sP@TuQP@P\ndcNL@FAMRUUeUujjjh@`\ndidH@@rJJIEn`HH@LBJfGbA`\nfhyA`@@BMdTTTTTTVoMJ|xKPAAPA@@F@aRTZsoAyCP\nflu@P@@BLgHhhhhhhml^ZUytV`BB`HX@@`\ndeTL`HS@|LddlRPru@@@FETwCODS@\ndk^LPLaC@HTHrRPqQYKiWUjfYj@LJXUt~QP\ndcNH@BAIUfYgVjjj`B\ndmt@@DjU^jxHHj@CChPjFUxf\\\ndg\\D@@QInUukaZ@Bj`@`\ndknJ@HAIT|bfbbTUGV``X`@`\ndidH@@Rge^Fh@@@pZDJf{dB\nf`qAA@A@bOQBSJ{\\ktYYt@EP@P@A@\ndmtD`ATHaIe]nf`@jP@pXDpjGb]H\ndcND@NADfUyU]Zj@@@H\ndcn@@@RigVRX]fBBb@CClkae]yB@\ngCa@@duPFADV@\ndidL@@cDkkWajjj@H\ndg|H@@RVYYwySn``@@@@pTHIne]N~PH\ndmtLPNePbABDfUujZ@Be@B\ndaDh@DqnAIeZfZZd@`\ndmM@PBx@c@aJYg\\jeZdHB@B\neFAAx`bLD\ndmv@@@rQQJEJUjh@@@pdHJfxYWdH\ndmLH@@rJJIQEneX@@@@CA`rnF^Hr`\nfoAa@@D@rJJJJHqYQkNZj`bB@@`\ndklH@@RUYffSYjZj`aJ\ndeTH@@rJIJFTt@EP@XLFTpsqDx\ndo|H@@rJJIQRFIn`HJjh@H\ndmvH@DAIgfVUZ`H@@pYFxYWdX\ndeTD`HP@cIHXhdLk@P@A`UMp|PI@\ndcLD@@QIeeUgVhHH@CAbinF^Hn`\ndknD@FADfye_EV``bP@pyJ[aW^II`\ndo~D@FADfye_TUZBBIhBMX\ndg^H@LAIYVUW[jiBB@Hi`\ndkmD@NLJrQSQQITUhHbI@B\ndiW@@@cDi[WBxYjeX@`\ndev@@@rRIIHus]UUUPA`JXUMpsrH@\ndifD@B@TfYun``H@LJCJx^PP\ndo~@@@RV^UviUj`@j`@`\ndaDH`BBHRYg[hH@@LJCJ[nPP\ndif@`ABHrJJIEn`HH@LJCBinPH\ngJXLBIARFdDfjhB\ndcLHPBBHzHrJJKQFLLDDU@A@\ndcLHPBCD{DrJJKQFLLDDU@A@\ndklJ`HSNL@cIIKEDdYuZBBH@H\nfhiAb@B^BBHRYe^unXHshHH@HX@@`\ndg\\L`AWPbDfUv{ZZ@Bij@B\ndcn@@@Re[mRY]jj@B@CBXSBxYW^HC@\nfde`@@@IRmrkNyFZ\\FMUPP@@P@A@\ndk_@`LI`BDigvUrmNfV@B@bj\nfoApA@EZ\\BHeDILrk|kNV]@PMTi@ar`\ndaE@@@yJeVnjjh@pZDpj{dL\ndmvH@LAIUYVUZh@@@pELInFUyD@\ndmL@@DjYUVGi@@@`@LNpjxYWdH\ngJX@@djsBIptQxa`\ndmV@@@RUgVYjf`aJ\ndeTD@@qI[eQfj@@@LNSJ[agbA@\ndazD@J@dfWjjh@pjLInx`H\ndg^D@EAdfYewiuhJBJ@B\ndidD@@QIVUxV`@@CCFx^YAT\ngJX@@eST`XZK\\a@\ndmvD@HALbfbbQFV`HH@H\ndk]H@BxLbbbRaRX]NBA@@@B\ndeu@@@gIHhikWLMUTu@D\ndid@P@bNbDfYYa`H`@LJBfx^Q`\ndmtHPIBHVHRYfUXXBHX@H\ndeUD@FxJRVYmnYjZ`B\nf`q@`@@LrQQJIQKHbL{uAPA@@@A`iANBdkUg^y@p\ndk\\@@DjWmkiadHBjh`B\ndk]H@DXDfYYwz]MjhHB@CClhYWSyC@\ndg~HpFlI@i@YCHhhihdUtz\\DQEJPA@\ndcLL@@S\\bbTrTHru@AH@XDUMODEP\ndg\\`@@SFRYueUNvjjjj@H\ndk\\@`LhDjU^ukmLHH@@@CAXPjxYWSyF@\ndk]H`AdpqDfUmUiev@Bfd`B\ngFp@DjTujhCCKWba@\ndkLD@@SHdiDbeFjff`B\ngGP`Ademj`LBl[rP\nfhyH@@@X\\EJYnUWoEEVMyj@@@b`@B\nfhyH@@@X|EJYnUWwEEVLyj@@@J`@B\ndk^H@FAJY}e\\kSie`@`Hj`\ndieH@FxLdTReJjeZ`B\ndeVD@HADfyeFV`H@@pqNgfTp`\ndeU@@@qJYejxBHh@LJJfF^Qp\ndmuH@DXDfUgjZ@Bj@B\ndmvH@ACHhhdcFz@`j@CA`Jfe^Ig@\ndmvH@AAIe]Zf`@j`@pXBkiWbI`\ndcn@@@RfumVy]d@@@@CClIae]yB@\nfoAP@@@TRfUVu~RlzP```@ABC@\ndknDpItpdDdLdLbdLRTtEZh@a`@`\nf`qa`@H@PqInYWmQJ]yhHH@@@@`\nfbuac@HjSdD`bPqHYEHXdleDeeAR|Fj@B`@f@@H\ndeTD`HP@cIHXhdLk@P@A`UMt|PA@\nfdy`b@LPP@HrRPjJJIIDf|xJu@A@A@@D\nf`qa@@M@rQSIYQIPlxZu@AUUQ@A@\ndig@@@`Tke]nX@H@LBpfGbQP\ndaF@`B@HRYg[hH@@LBpj[bAp\ndid@@Ldbbq[`bB@C@lJaxbL\ndidD`HPOAJvUxVjj`CAlJfx^P@\ndmtB`HSBCprRSFIJUZh@@@pinFUxfD\nfHbXA@\ndaFH@BAIf]n``@@pKBknHC@\nfjsQ@@DB@dsLsKjvldIUhaJgKU@p@@@D@@D\ndnD@@DiYrbYjj`CB`aLkbDp\ndmLD@@eIYfUayVjjZPB\ndaDH@@RVU[f@@@LJcB[nQP\ngFp`AdiTvjhCAF|TP\neMBBHRYCAKd`\ndieH@HPDeYWaZ@@@H\ngOu@E`dsu[UTA`TZ~S@\ngOx`DFdrikTlA`e^S@\ndaD@@DjWZXHB@CBdpf{dP\ndmL@@DjYeVdUBHhb@LNpjXYWd\\\ndiTH@@RVYV{ajjf`B\ndmN@@@RYVuiiV@@@@@pxLkae^P`\ndml@@LdfbTJifzUZjjj`B\nfHcDA@\nfHgPAa@\nfHe@Aa@\neMBBHRYCAGe@\ngC`DAbZHRVhB\nfHbxA@\ngCa@@dtpFBVy@\ngC`HADIMTAa`mrP\ngJQHDHaIjj@`\ngC`HADIKRAaaMrH\ngJP@DivhPNAbqy@\ngJQ@@dkSBJpHVOI@\neMJAhHzB\ngJPhLQxIRuPD';mlb._D='daD@@DiUVyjjPPGd\ndaD@@DjUZxHD@@\ndaD@@DjUZxHH@@\ndaD@@DjWjXHB@@\ndaD@@DjWzXHB@@\ndaD@D@BHBDBLBBBJBFBNBDiUVzjj`@\ndaD@P@bBbDfYvzB@@@\ndaD@P@bNBDfUzZ@B@@\ndaD@P@bNbDfUzZ@B@@\ndaD@P@qBdDfYvzB@@@\ndaD@P@qFdDfUjz@H@@\ndaD@`@BDeeVz`@@@\ndaD@`@bDfYVz@`@@\ndaDD@@IJVVfijh@@\ndaDD@@QIe\\jZjh@@\ndaDD@@YIeZn`B@@@\ndaDD@@YJZUnjjh@@\ndaDD@@qIYUnZjX@@\ndaDD@@qJYoJjjX@@\ndaDD@@qJZ_Fjjh@@\ndaDD@@yIe^f`@`@@\ndaDD@@yJYVfjjh@@\ndaDD@@yJYfnjjh@@\ndaDH@@RVU[f@@@@\ndaDH@@RVU[j@@@@\ndaDH@@RYVih@H@@\ndaDH@@RYWih@H@@\ndaDH@@RYe[hB@@@\ndaDH@@Rfu[j@@@@\ndaDH`L@HRf][jZj@@\ndaDL@@SDfUrijj`@\ndaE@@@IIf]njjh@@\ndaE@@@YIeZn`B@@@\ndaE@@@yIe^f`@`@@\ndaE@@@yIe^fjjh@@\ndaEH@DpDfYbYjj`@\ndaF@@@RVU[n@@@@\ndaF@@@RYVih@H@@\ndaF@@@RYWih@H@@\ndaF@@@RYe[hB@@@\ndaF@`NBHRYWih@H@@\ndaF@`NBPRYWih@H@@\ndaFD@DCdeeVyjj`@\ndaFH@BAIf]n``@@@\ndaFH@DAIYUnZjh@@\ndaFH@DAIeUnZjh@@\ndaFH@DAIfVfZjX@@\ndaFH@DAIf\\fZjh@@\ndaFH@FAIeZn`B@@@\ndaFH@NAIe^f`@`@@\ndaFH@NAJYfnjjh@@\ndae@@@yJeVn[jjj`@\ndaf@@@RiUkfzjjh@@\ndax@@Djuvjh@@\ndaxB@@QnR[VZY`cD\ndaxB@@QnR[VZY`cH\ndaxB@@QnR[VZi`@\ndaxB@@RnRUUZjP@\ndaxD@@KHhhbtu@@\ndaxD@@KHhhcUT`@\ndaxD@@QIUUjj@@\ndaxD@@QIUYjj@@\ndaxD@@QIeUjVBB`\ndaxD@@QIeUjZBB`\ndaxD@@QIeUjf@@\ndaxD@@QIeUjj@@\ndaxD@@QIeejj@@\ndaxD@@QIgijj@@\ndaxD@@QImUifALj`\ndaxD@@[HiDYUU@@\ndaxD@@iIijjj@@\ndaxD@@iJUfjj@@\ndaxD@@iJUvjj@@\ndaxD@@yIi^jj@@\ndaxDPDxHahaImZYiBL`\ndaxDPFxH`haIf^jj@@\ndaxDPFxLPlQIf^jj@@\ndaxDpBhHa@chaIffeZBDP\ndaxH@@RUUYf`QHh\ndaxH@@RV[jj`@\ndaxH@@RYUZj`@\ndaxH@@ReWii`QJh\ndaxH@@rJJHmUP@@\ndaxH`HALRkUZj`@\ndaxH`HALRkfZj`@\ndaxJ`HSFx@cIIJhmS@@\ndaxL@@SdfUvih@@\ndaxL@@SdfvVjh@@\ndax`@@PjRUnzZ`@\nday@@@[HiDYUU@@\nday@@@kIHbiUU@@\ndayL`BzDp@cIICdmU@@\ndaz@@@RfVjj`@\ndaz@PLBHzHRUgjj`@\ndaz@`JBHRV^jj`@\ndazD@DAdfUvih@@\ndazD@LCdeYzjh@@\ndazD@NADf{Vfl@@\ndazH@DAIeYjZ@@\ndazH@LAIUjjj@@\ndazH`BpJqI[Vfj@@\ndazH`LPHaInVZj@@\ndcL@@DiUUU]ZjejC@^QP\ndcL@@DjYYYiBHhh@@\ndcL@H@qBqEqMqDfYn]a``bh@@\ndcLB@@Q]R[e[neh@a`@@\ndcLB@@Q]R[e]nEh@I`@@\ndcLD@@EJY[WWZjB@@@\ndcLD@@GIEDTiMBUUUS@@\ndcLD@@IIf]z[hHBj@@\ndcLD@@QIUVUWVj`@@@\ndcLD@@QIe]UJfjjj`@\ndcLD@@QIgVUWVj`@@@\ndcLD@@QIge]FVh@I@@\ndcLD@@SHhdhTeSMUUU@@\ndcLD@@YJYYwEZB`b@@\ndcLD@@iJ[g]xZB@f@bX\ndcLD@@uIUfUeVXBB@aH\ndcLDPDtHaXaInUnzY`BI@@\ndcLH@@RYWZZYjjjh@@\ndcLH@@RYeZvz@`j`@@\ndcLH@@RYguRYijjh@@\ndcLL@@G\\dTRRbOKPPTP@@\ndcLL@@QTfVUV]Zjjj@@\ndcLL@@QTfVutYZ`@h@@\ndcLL@@QTfvUtYZ`@h@@\ndcLL`HQPBLddLRRTzmAA@@@\ndcLL`HS@BLddJfRtjmP@P@@\ndcM@@@eIi_Z[jjjj`@\ndcM@@@wIHhdd]JuAPD@@\ndcM@pItIAICICHiCDeDJuPAD@@\ndcMB@hDDWXeNF]yInUnzV`BF@@\ndcMD@DdMRUe]^EX@IP@@\ndcMD@LDMRUe]^Fjjjh@@\ndcMD@LtARem[~fl@bp@@\ndcMDBLHDSdf{YU]Zj@@@@\ndcMH@DdDfY}XfZjjj@@\ndcMLAHtDVISdfyW[aZ@BX@@\ndcNB@BAEuInVVFV`HF@@\ndcNBAHAEvISdfyW[aZ@BX@@\ndcND@AALbbTRbJzuAP@@@\ndcND@MADfVU~UZ``H@@\ndcNDaFePBFe^RfV^Qv`hF@@@\ndcNH@DAIf_UIfjjj`@\ndcNLAHAEbTyInUnzV`BF@@\ndcNL`NaL@HrRRqQ[RjtDA@@@\ndcO@@@JldbRTQU]UUUT@@\ndcO@@@xTjU]Znjjjj@@\ndcOLpHkb[PbAbEbDfYn\x7FijYjf@@\ndcl@@DjUg^aWP`hjH@@\ndcl@@DjYU_egX@@@@@@\ndclD@@QIe[UiiUjP@h@@\ndclD@@QIe[WiiUjP@h@@\ndclD@@SHheDhbJkkUUUT@@\ndclD@@aJVfnKfFjjjf@@\ndclD@@iJYW]rnF``IhBI`\ndclD@@iJYW]rnF``Jh@@\ndcm@@@UJfUWyYvhJBH@@\ndcmH@DHDfUyTjWVi`@`@@\ndcn@@@rJJJJJlJ{@A@@@@\ndcnD`EGPqDfUn^neX@aiH@@\ndcnH@AAJYYwhUvj``H@@\ndcnH@DCHhheBeSKkUUUT@@\ndctB@@PYRYU{Vjij@@\ndctD@@QIeWUZjjh@@\ndctD@@QIgUUZjjh@@\ndctD@@QImUUZjjh@@\ndctD@@QImUVZjjh@@\ndctD@@wHiDThmUUUP@@\ndctH@@RUgVVZijADn`\ndctH@@RV]UVjjj@@\ndctH@@RgUUZjjj@@\ndctH`HALRkUUVjjj@@\ndctH`HALRkUYfjjj@@\ndctL@@Pdf{e]jjj`@\ndctL@@X\\dTQfReUUU@@\ndctL@@jTiV[Vjjj`@\ndcvD@MADfuUUjjjp@\ndcvH@LAIVUUjjjh@@\ndeL@@Di[ernDYZjij@@\ndeL@@DjUYkfEijjjj@@\ndeT@@DjUghP`h`@@\ndeT@@DjWvifjih@@\ndeT@@DjWviifjh@@\ndeT@@DjYUXPbH`@@\ndeT@@Dj[[[ifjd@@\ndeT@@DjeUZZjjh@@\ndeT@@LdbRTm\\DBR@@\ndeT@@LdbRTm\\DBT@@\ndeT@@LdbRbmBDED@@\ndeT@@LdbTRoBuUM@@\ndeT@@LdbTRoBuUT`@\ndeT@@LdbbQwBuSU@@\ndeT@@LdbbQwCUUU@@\ndeT@P@bIbDee][j@B`@@\ndeT@p@bNBIbDfUuih@J`@@\ndeTD@@EJYU^f```@@\ndeTD@@IJVWZZfjj@@\ndeTD@@QIe]Rijjj@@\ndeTD@@QIgeQej@@@@\ndeTD@@QIgeQejjj@@\ndeTD@@QImeQej@@@@\ndeTD@@SHhdhUSMUUP@@\ndeTD@@eJ[WVz`@h@@\ndeTD@@iIYe^e```@@\ndeTD@@qIUeQej@@@@\ndeTD`AdHaIe]jZ@BX@@\ndeTD`DpHaImeQfZ@@@@\ndeTD`NDHaIfVVfBA`@@\ndeTH@@RUYTYY`@@aH\ndeTH@@RUYTYj`@@@\ndeTH@@RYVZfZZj`@\ndeTH@@RYVZfZij`@\ndeTH@@RYVffjjj`@\ndeTH@@RYWZfjjj`@\ndeTH@@RYe\\YZB@@@\ndeTH@@RYm_aZ@B@@\ndeTH@@RYm_ajjj`@\ndeTH@@RgYTYj`@@@\ndeTH@@rJJIHmtAAH@@\ndeTH@@rJQPiCMT@@@@\ndeTHPABHxHRYWZf`@f@@\ndeTH`DBHRZ{TYf`@@@\ndeTH`IBHrJJJJlLADP@@\ndeTHpACDKD[DRYf{i`bH@@\ndeTL@@QdfygFV``@@@\ndeTL`HS@BLddlRPrm@@@@\ndeTL`HS@|LddlRPru@@@@\ndeU@@@eIYVvG`BL@@\ndeU@@@eIYWVz`@h@@\ndeU@@@eIYWVzjjj@@\ndeU@@@eIYWV{`@l@@\ndeU@@@gHeDeBwT@E@@@\ndeU@@@qJYVjXBBh@@\ndeU@`Ld@aJVu~Fl@H@@\ndeUB@DpFFTfUgkfjYX@@\ndeUH@JXDiWUJjjjh@@\ndeV@@@RUYTYy`@@aH\ndeV@@@RVUenh@J@@\ndeV@@@rQQIHtpDCP@@\ndeV@@@rQQQHcMAP@@@\ndeV@@@rQQRItMMUR@@\ndeV@@@rRHqICMT@@@@\ndeV@PABPRPR[e[ij@H@@\ndeV@pABPJPZPRYf{i`bH@@\ndeVD@DAdfygFV``@@@\ndeVH@AAIfuneh@`@@\ndeVH@IAJYW~F``H@@\ndeVH@JAJUuRjjjj@@\ndeVH@LAIUeQfj@@@@\ndeVH@LAIVUVzjjj@@\ndeVH@NCIELeBpt@Q@@@\ndeVHAH@NbTfY_[hBB`@@\ndeVH`IHHaIfUVFBBH@@\ndeVH`NdHaIe]ZZ@BT@@\ndeVL@D@YrJJHjDsUTt@@\ndeVLAHAAbTyInUneh@`@@\ndeWH@DJPRY[TYZ`@@@\nded@@Dj_VfZZ@@\nded@@LdbQRdsSPQD@\nded@P@SHBDjuUZjj@@\ndedB@@PYRYWYjZX@@\ndedB@@PYR[UYjjX@@\ndedBpJxYCDKD[pRY]jjih@@\ndedD@@QIUUVjj`@\ndedD@@QIkWZjj`@\ndedD@@QInUvjj`@\ndedD@@aJVfjjj`@\ndedD@@eIffZjj`@\ndedD@@qJY]zjj`@\ndedH@@RUUUfihDRY@\ndedH@@RUUUfjhHR@\ndedH@@RUgVZjhHb@\ndedH@@RV]Ujjh@@\ndedH@@RYVYjjh@@\ndedH@@RZW^jkh@@\ndedH@@RZWvjjh@@\ndedH@@rJQEJUUU@@\ndedH`HALRkUUjjh@@\ndedH`HALRkVYjjh@@\ndedL@@PTfUvZfj@@\ndedL@@pdie]jjj@@\ndedL`@JdhDi[Ujjj@@\ndedL`HS@|DjUUjjj@@\ndee@@@eIUUZjj`@\ndee@@@{IHh\\iUUT@@\ndee@PJdLQlSHiDdUU]V@@\ndef@@@RiUVjiT@@\ndef@@@Ri]Vjjh@@\ndef@pLBHFHfHRUeVjjh@@\ndefB@LAAeIeUVjj`@\ndefB`HKad@aIf^Zff`@\ndefD@AADfUfZfjBBP\ndefH@LAIVYjjj`@\ndefL@L@YRUeVjjh@@\ndeg@@@FTjWUjjj@@\ndeg@@@JTeV]zjk@@\ndet@@DjYUX^d@@@@@\ndet@@DjYUX^dHbH`@\ndet@@DjYUZ^D`dJ@@\ndet@@DjyZkfyjjj`@\ndetH@@RYVvfFX@Jb@@\ndeu@`Dp@aIeURhYfh@@@@\ndev@@@Re[TjFP@@@@@\ndev@@@rQQJHtpr@@@@@@\ndev@`JADrQQQHyPsPLA@@@\ndevH@JCIEEDceCM@pD@@\ndevH`HX@aJVU|HYjA@`@@\ndg\\B@@Q]rJISQJHr[TDCD@@\ndg\\B@@SSRY[W[FVh@Ih@@\ndg\\B@@pSRf^Y]vzjB``@@\ndg\\D@@QIeUyT{Zjh@@@@\ndg\\D@@QIe]UTjZjjjh@@\ndg\\D@@QIgUYT{Zjh@@@@\ndg\\D@@QIge]hYZjjjh@@\ndg\\D@@QIgfVVSZjjjh@@\ndg\\D@@QIgfWzUZjZih@@\ndg\\D@@SHhdhTdeSMUUUT@@\ndg\\D@@SHhmHcDd]mUT@@@@\ndg\\D@@SHhmHhTmimUUTt@@\ndg\\D@@SHhmHhTmimUUUT@@\ndg\\D@@eIfU_Un`HJj`@@\ndg\\H@@RV^UveVj@Bh@@\ndg\\H@@rQIIQQHg]UPT@@@\ndg\\LPLi`bBBLbRTabRvgUK@A@@@\ndg]D@DdMRYe_[FVjZif@@\ndg]D@DtKrIIQIPiCJt@EJ@@\ndg]D`NV]CDRYWVyih@JZh@@\ndg]H@LlDeYeUuNj``c@@\ndg^D@L@teYee]nj`bH@@\ndg^DPKFPbNBLbbRrdJUM@AKM`Pl@\ndg^D`Ca@BLddLRRVTzm@aG@Pt@\ndg^H@DAIfVU^]Zjjjh@@\ndg^H@DAIf_UTfZjjjh@@\ndg^H@DCHhhhdhb]mTED@@@\ndg^`@@SAgHhihhhb]mTCD@@@\ndgl@P@BH|DfeUUVjjjh@@\ndglB@@RUrJIIIPiMUTuP@@\ndglD@@QIeWUUjjjj@@\ndglD@@QIeuUUjjjfBM`\ndglD@@QImUUUjjjj@@\ndglD@@SHhmHbeDuUUR`@\ndglD@@SHhmHdThuUMM@@\ndglD@@qJ[]UVjjjj@@\ndglDB@QNrJZQEIIMUMUPPt@\ndglDPDlH`xaImUUZZjji@@\ndgm@@@mIUUUVjjjj@@\ndgnB@DBcoHheEiDbuUUU@@\ndg|@P@bFBDfUoeZx{`BH@@@@\ndg|B@@Q[RYvUmgSmj`BJH@@\ndg|D@@SHieEDhcJg[T@@@@@@\ndg|DB@QNrJYQQJHrivuUUUT@@\ndg|D`BTHaIfUm]aNxHHD@@@\ndg|H@@RVYYwySn``@@@@@\ndg|H@@RYe[W[cn@`jjH@@\ndg|H`BBHRYg^U[cnB@`@@@@\ndg}@pBl@c@aPaJYgU|jgZdHHn@@\ndg~D`NTpbDfUvYj[[`@jYa@@\ndg~H@NAIe]YVfNx@J@@@@\ndg\x7F@PBWPbAbLbbbRfaSR]pPTMQ@@\ndiD@@DiUVjj`@\ndiD@`@BDiUVjj`@\ndiD@`@bDee^jj`@\ndiD@`@kDf]Vjj`@\ndiDD@@QIgUZjh@@\ndiDDB@QNR[UfjZ@@\ndiDDPBhLQlQIf_jZh@@\ndiDH@@RVUvjj@@\ndiDH@@RVvjZj@@\ndiDH@@RYuYjjBH`\ndiDH@@rIRHrjj`@\ndiDJ@@PnEInvZjX@@\ndiDJ`HSNDOAJoVZjX@@\ndiDL@@IdfY~jjP@\ndiDL@@kdiVZjj`@\ndiDLPBhPbFbLbbbeiZdHQ@\ndiDLPDp`bH|DfmVZj`@\ndiE@`ND@aJUUjj|@@\ndiEH@BxDeUZjj`@\ndiF@@@RUUZjj@@\ndiF@@@RVUzjj@@\ndiF@@@ReUZjj@@\ndiFD@AADfuUjj`@\ndiFD@BCdf]Zjj`@\ndiFD@FBdiUzjj`@\ndiFD@LCldTatjjh@@\ndiFJAHALXXgNRYvvjj@@\ndiG@@@HTeUWjjp@\ndiG@@@xTiUVjj`@\ndiT@@LdRbQrbYjjZ@@\ndiTH@@RVYz{ajjj`@\ndiTH@@ReUxRfjjf`@\ndiV@@@RVYz{ajjj`@\ndiV@@@RfU|kahDB@@\ndiV@`J@HRfU|kahDB@@\ndiVH@AAJUWaJZjjz@@\ndid@@DjUfaBB`@@\ndid@@DjWffB@h@@\ndid@@DjYUaBHP@@\ndid@@LdbRQk``b@@\ndid@@LdbbQxXF@@@\ndid@P@bNBDfUvf`@h@@\ndid@`@bDf[Waj@@@@\ndid@p@bBbAbDfYun``H@@\ndid@p@bBbFbDfYoa`b@@@\ndidD@@EIe]ih@J@@\ndidD@@EIfU[hBB@@\ndidD@@GHhdhZZ@B`@@\ndidD@@KIDhdZZfjh@@\ndidD@@QIe]Jfjj`@\ndidD@@QInUxV`@@@\ndidD@@iIYgxVB@@@\ndidD@@iJ[gxZB@@@\ndidD`BDHaIf_[hHB@@\ndidDpNDH`ha`cHhhcJZjiX@@\ndidH@@RUe^Fh@@@@\ndidH@@RVUvz`@`@@\ndidH@@RYVZZ@B`@@\ndidH@@RYWZZ@BP@@\ndidH@@RYm^Eh@@@@\ndidH@@RYm^Fh@@@@\ndidH@@RYm^Fjjh@@\ndidH@@RZU~Fjzh@@\ndidHPBBHFHRYgVzB@`@@\ndidHPBBHzHRYgfFBB@@@\ndidH`ACDrJIJFf`@d@@\ndidL@@HTfYun``H@@\ndidL@@IdfYoa`b@@@\ndidL@@KdfYynZej@@\ndidL@@RdfVwaZii@@\ndidL@@rldTTUkjjj`@\ndidlAHJfAAbTyInW[fiY`@\ndie@@@EIYW[n@B@@\ndie@@@EIfW[hBB@@\ndie@@@GHhhdVz@``@@\ndie@PLx@a@cHheDZyjjh@@\ndie@`BDHaIf][hHB@@\ndieD`JXaBPRYgvzejX@@\ndieH@JDDiWTjjjj@@\ndieH@LDDeYWajjj@@\ndif@@@RUe^Gh@@@@\ndif@@@RVUf{`@`@@\ndif@@@RVUv{`@`@@\ndif@@@RfU~Fjjh@@\ndif@@@RfWzXBBP@@\ndif@@@RfWzXBB`@@\ndif@@@rRJEKaj@@@@\ndif@PABHJHRYgVzB@`@@\ndif@`ABHRYWZZ@Bp@@\ndif@`BBHRYgVzB@`@@\ndif@`NBHRYeVFBC@@@\ndifD@D@TfY|fZjj@@\ndifD@J@TiWTjjjj@@\ndifDAHAHeNR[e^Eh@@@@\ndifFAHALkab\\yIgnxVij`@\ndifH@AAJYYhZjj`@\ndifH@DAIfVifjj`@\ndifH@DAInUxVjj`@\ndig@@@xTjU^njjj@@\ndkLB@@SSR[UUYjjjX@@\ndkLB`HSBCprRSEQIYjjjh@@\ndkLD@@QIeUoVjjj`@\ndkLD@@QIeWUVjjj`@\ndkLD@@QIe]Ufijj`@\ndkLD@@QIe^Uvijj`@\ndkLD@@QImUUVjjj`@\ndkLD@@qJ[]UZjzj`@\ndkLFPHSaTpBJBLddJTbNVjVj@@\ndkLH@@RUUUUfjjhHR@\ndkLH@@RVUU^jjjh@@\ndkLH@@rJIJJJrjjjh@@\ndkLH@@rJJQUIIjjjh@@\ndkLLHBi`bL|MbCbDeZuUjZjj@@\ndkLLHLi`bB|MbCbDeVUUjjjj@@\ndkLLXJXPdDdLdEdMdCdLbdLrfdjffj@@\ndkLL`@JdhDiYWUjjjj@@\ndkLL`@idhLdTTJTTjjjj@@\ndkLN@@PiWSR[kVYjjfX@@\ndkM@@@UJeUUZjjj`@\ndkMDHLve@HZPzPFPrQSJQVZfjihHR@\ndkN@@@RUUUVjjjh@@\ndkN@@@ReUUVjjjh@@\ndkND@CALbbRbJRZjjj@@\ndkNH@JAIgeUzjjj`@\ndkNL@BB]RYyVZjjjh@@\ndkO@@@Y\\dbJRRTjjjj@@\ndk\\@`@BDifUWGUN`@@@@@\ndk\\D@@QIenf^WSZjjjh@@\ndk\\D@@SHihheDQgSZjjjh@@\ndk\\H@@RYeg]itvi``D@@\ndk\\H@@RYeg]itxH@@@@@\ndk\\H@@RYm[Watv`@@@@@\ndk\\H@@RfU{WatzB@@@@@\ndk\\H@@rJJZIQDYtv`@@@@@\ndk\\H`ABHRYVvvftx@Jjb@@\ndk]@pLh@a@c`aIegmRkSZj`@P@@\ndk]H@DHDfYyWImMjhHA@@\ndk]LbLjDd@birRPqSIYntuj`PH@@\ndk^@@@RfYU\\]Tzjjjj@@\ndk^D@DBTfYYwimMjdDB@@\ndk^D@DBTfY[W[mNfhHB@@\ndk^HPNHJrXaIf^UvGS``B@@@@\ndk^LpB[a@HpHkprQPjSIILPjjZjj@@\ndkl@`@SLddTlTUgZhBH`@@\ndklB@@Q]RY[WoaZjjZ`@\ndklD@@QIeUY]Mjjjj@@\ndklD@@QIe]URijjjj@@\ndklD@@QIgfU}MjhD@@@\ndklD@@QIgge]Mjj@@@@\ndklD@@QInUvnEh@Jh@@\ndklD@@SHhdhTdjYjjjj@@\ndklD@@eJ[Vvfz`@jh@@\ndklD@@qJ[[m]Njj@@@@\ndklDB@QNR[V[WSZj`@@@\ndklDpLHHbOA@aIkVuVzZjjj@@\ndklH@@RYeZUn`HJj@@\ndklH@@RZWyWSjj`@@@\ndklH@@ReYUfSj``h@@\ndklL@@STf^UvFVh@J`@@\ndklL`AtpbDfUoVih@Ji`@@\ndklLpDppbHBMbLbdLRTtEYX@bP@@\ndkmB@hTDtxeNVS{HihhdUAehBBX@@\ndkmD@DTCRUfWtYV@`e@@\ndkmD@DdCrIJJIPxUV@bE@@\ndknB`NaLt@cIIKEEeiUZB@h@@\ndknD@LCTeYeUTzjBB@@@\ndknD`Ca@BLddLRRVgUhDHpHZ@\ndknD`LIPBDiZuYdzzjfh@@\ndknLPASBBH`HrJPjJKI]ehHB@@\ndknL`LaA@HrRPjIKY]VdDB@@\ndmL@@DjYYVgeBHhb@@\ndmL@@DjYeVdUjjjj@@\ndmLD@@QIe[VfeVj@B@@\ndmLD@@yJY~WJeZYijP@\ndmLH@@RYVuiiV@@@@@@\ndmLH@@RYVuiiVjjjh@@\ndmLH@@RYegXYVhH``@@\ndmLH@@RYiYKnUjjjh@@\ndmLH@@RYiYKnVjjjh@@\ndmLH@@RfYUxYVjifh@@\ndmLH@@RfYUxYVjjjh@@\ndmLH@@rJJIQEneX@@@@@\ndmN@@@RYVuiiVj`@`@@\ndmN@@@ReZ}IiVjjZh@@\ndmN@@@rQQJKFnFP@@H@@\ndmN@@@rQQQQVneP@`@@@\ndmN@`J@HrQQQH{JFZA`J@@\ndmN@`JADrQQQH{JFZA`J@@\ndmNH@BAIfUmiEX@@@@@\ndmN``DkaT@aIefUneVjVjP@\ndmO@@@SdfVUrjUZ`PH@@\ndmT@D@dDdLdJdFdAdIdEdLbdLadjjj`@\ndmT@D@kDdLdJdFdAdIdEdLbdLadjjj`@\ndmT@p@bBBEbDeYyzjjh@@\ndmTB@@RiRYyVZje`@\ndmTB@@SiRYyvZji`@\ndmTB`HSBCpRjuUZjj`@\ndmTB`NFU@HReUfjjY`@\ndmTD@@QIUUUjjj@@\ndmTD@@QIeUyjjj@@\ndmTD@@QIgUUjjj@@\ndmTD@@QImUUjjj@@\ndmTD@@iJU]Vjjj@@\ndmTH@@RUUUYjj`aH\ndmTH@@RUgVYjf`aD\ndmTH@@RUgVijf`aD\ndmTH@@RUgVijf`aH\ndmTH@@RVUWjjj`@\ndmTH@@RZWvjjj`@\ndmTH@@rJQEJJjje@@\ndmUH@JXDiUYjjjh@@\ndmV@@@RUUUjjj`@\ndmV@@@ReUUjjj`@\ndmV@@@RfWYjjj`@\ndmVD@DAdfUufijh@@\ndmVD@LA\\bRbdUjjj`@\ndmVL@IAARYW[Zff`@\ndmWH`DphCpRjyfZjj`@\ndmt@@LdbRdSjP`jH@@\ndmt@H@qAdIdEdDfYVfz@`j@@\ndmt@H@qAdIdEdLbbRadih@Jh@@\ndmtB@@RUR[e^[fjjZ@@\ndmtD@@IIf]yn``J`@@\ndmtD@@QIe]TjZjjh@@\ndmtD@@QIem\\YZ`@`@@\ndmtD@@QIgYVUZh@@@@\ndmtD@@QImYVUZX@@Hr@\ndmtD@@UIfuwaZ@B`@@\ndmtD@@aJye[ahBB`@@\ndmtD@@qJ[[VUjh@@@@\ndmtD@@yJUe^Uj``@@@\ndmtDPAdHc`aIe]jf`@e`@@\ndmtD`JTHaIYe_ihHHP@@\ndmtD`LTHaI[e\\Yi`@`@@\ndmtD`LxLQI[f^Ui``@@@\ndmtD`NTHaIe]Vf`@j`@@\ndmtDpDpHb@aXcHiCDeafV@B@@\ndmtH@@RUfueVZ@@BD`\ndmtH@@RVUv[j@Bh@@\ndmtH@@RYYf[ffjj@@\ndmtH@@RYeZ[hBBh@@\ndmtH@@RYeeZVfjj@@\ndmtH@@RYeeZVjjj@@\ndmtH@@RYeeZZjjj@@\ndmtH@@RYe~[ffjZ@@\ndmtH@@Rfuu[j@BXBAP\ndmtH@@rJJIHhfZZjh@@\ndmtH@@rJJIJEn`HJ`@@\ndmtH@@rJQPiXYjjjh@@\ndmtH@@rJQQHxYjjih@@\ndmtHpEBHZHfHrJIJHrn`BJP@@\ndmtL@@PdfueYUj`@@@\ndmtL@@YTf[gqehHB@@\ndmtL@@hTef^~e``b@@\ndmu@`ATIAIe[^n`BNp@@\ndmuDPHhfBHFHRYf~kjfZj@@\ndmuDPHhfCDFHRYf~kjfZj@@\ndmuH@DTDf^Uqej@B@@\ndmuH@DdDf^UaUj@H@@\ndmuLAHTDZISdfygQehHB@@\ndmv@@@RVUv[n@Bh@@\ndmv@@@RfUWzZjjj@@\ndmv@@@rQQJEJUjh@@@@\ndmvD@BADfueYUjjj`@\ndmvD@DCdf^YyUjB@@@\ndmvD@NADfVyyUjB@@@\ndmvD`La@BLddlTReUhB@@@\ndmvH@BAIVUwaj@B`@@\ndmvH@EAIeYfnZZjx@@\ndmvH@HAIffgejjjh@@\ndmvH@JAJUuTjjjjh@@\ndmvH@LAIUfVUj`H@@@\ndmvL@EAFR[f_FV``H@@\ndmvL@FAIR[ev[fjjZ@@\ndmwLPHkbYPbAbLbbbfezZfZf@@\ndndD`LH@aJZ\\hjijjj`@\ndo\\B`HRUALrRQIIIHjjjej`@\ndo\\D@@QIe]UUZfjjh@@\ndo\\D@@QIe]UVZfjjh@@\ndo\\D@@SHhdddhbfjjjj@@\ndo\\F@@Savtf^UVYjjjY`@\ndo\\J@@PYWHheDhbdfjYjj@@\ndo\\J@@QiuIe[YoZfifT@@\ndo\\L@@ptimyujjjjj`@\ndo\\L@@rTie]mVjjjj`@\ndo^@`L@HReuUUZzjjj@@\ndo^J@JAIW\\bbTRTtqZjifh@@\ndo|B@@RgrJYIQQIGSZZ@`hBL`\ndo|BHDrwBH`HzHNHrJPqQYIRUe``JX@@\ndo|D@@QIeUyemvij@`@`h\ndo|D@@QIe[e~WVjijf`@\ndo|D@@QIgfUYuvj``h@@\ndo|D@@QImYeeVvjjjj`@\ndo|D@@SHhmHbhdk]jjh@@@@\ndo|D@@qJY]YWmzjjB@@@\ndo|DpElH`hbXcHhhidbeFFBBJj`@@\ndo|H@@RV^UviUj`@j`@@\ndo|H@@RYfV{vF@bJj`@@\ndo|H`EBHRYWUnjZ@Bij`@@\ndo}@DDhJs``YBYAY@yByAyCHheEiEYBjfjjjd@@\ndo~@@@RfUYw~V``hj`@@\ndo~@@@RfUYw~Vjjjjh@@\ndo~B@GAEoHheDdhbiMjBBb`@@\ndo~BpIx[\\H``cXcHhheHe]FVBAXi`@@\ndo~D@AADfUvUwSZf`@h@@\ndo~D@LALbbTTJTLWVj`@j@@\ndo~H@DAIVYenEU`Hbj@@\ndo~L@DA]rJJKIJHhfZjjZj@@\neFA@HoBJ@\neFABHiBL@\neFABPiBL@\neFACDlRL@\neFBBHc@@\neFBBlc@@\neFHBJ@\neFHBL@\neFJBhHh@\neFJHbHh@\neF`BL@\neF`BN@\neMB@HRZ@\neMB@Hch@\neMCAD`aBHu@\neMFI@bMP@\neMHAIX@\neMHAIh@\neMLRRWhv@\neM`AId@\neM`AIh@\neM`AIx@\neM`BN`@\neMhDRV@\neOB@Hcfh@\neOHBNZ`@\neO`BNZ`@\nfHbd@@\nfHcp@@\nfHdP@@\nfHd`@@\nfHdp@@\nf`a@`@@FrJIJQQNKTXuUUTu@@@\nf`a@`@@HrJIJQJqIN|uUU@@@@@\nf`a@`D@HQvQSRIIFIIwfjjh@@@@\nf`aA@@@ILjjjj{sUUUUT@@\nf`aA@@@ILsKWRpTADUUP@@\nf`aA@@@YEEDcEEHc^ZZjZj`Pq@\nf`aA@@@YEEDdTddf\\`HJjj@@@\nf`aA@@@YEEEETddfB`Hbjj@@@\nf`aA`@@HqdTRTTbUrMYj`j@d@@\nf`i@A@@AG@cIEEEDedkSdcZ]PA@AE@@@\nf`i@a@FRAD^bDfUm[WirRkN`BJ@BH@@\nf`iA@@@ILrmtvQcAV|uUUUUT@@\nf`iA@@@YEEEEDhdYFTzwf`@``H@@@\nf`iA@@@YHhedhh]HHUhujjjZjj`@@\nf`iA@@@YHhhdXdhhHehujjjZjj`@@\nf`iPB@N^@DYHhhhdldZ\\d[Sj@H@Hx@@@\nf`iQA@B\\|@HpDISLzsnRdcN}TaAQUD@@\nf`q@B@@^BULrjkj\\[uPA@D@@@@\nf`q@`@@^RVYYywbkNXH@BA@@@\nf`qA`@@B|dsLrozkF\\t@P@D@@@\nf`qA`@@H\\drsJkrkF|u@@@P@@@\nf`qA`@@HidTRbRQbREIwfjZh@D@@\nf`qPA@AZ@DPBLdRbbbTVJgV}T@PP@@@@\nf`qPHAHV@cGIF]zDxzt~{HhmEDdThJRmMUUUST@@\nf`qPQ@INxJw`QA@cHhheHeUDqQgPPKELd@@\nf`qPaABLEh@Q@HIKIEvnrQJJJIQXj][uPAA@@@@@\nf`qPb@EZ]xDQdRTRTraTxIVj`@iib@@\nf`qa@@D@rJJJJIZHjl{sUTEDD@@@\nf`qa@@D@rJJJJJFHjl{sULEDD@@@\nf`qp@@@Hpds\\rj~gV|uP@@@@@@\nf`y@@@LdbbbbbfkEBMIuo@@@@@@@@@\nf`~@@@DiUUUUjjjjj@@\nf`~@H@@Hdhug^rJZJIQJFMUTts@@@\nf`~@P@@Ht[HhdhbeLhuUUMT@@\nf`~@P@@HuYIe]UVvijjfP@@\nf`~@`@@BrQQIIQSVUUUUU@@@\nf`~@`@@HRYuUUUjjjjh@@\nf`~@`@@HR[UUUUjjjjh@@\nf`~A@@@YEDeEDcEJjjjj`@@\nf`~Ab@@Dhb`rQJJIEJJUUUUU@@@\nf`~Ab@@TXb`RfYwf^jjjjh@@\nf`~aK@JPQaVcV]xG`KpexYIIUDeHiFjjff`@@\nf`~a`BH@QbDxyIgUUUVjjjj`@@\nf`~ab@IPQ`G`eUnoLsUUUUP@@\nfbe@B@@QBSLjojjheUAAEUUP@@\nfbeAP@@Hu[rSKJkK~lcMPPTUUP@@\nfbea`@D@XgHhhdddcDedFKUUUP@T@@@\nfbm@A@@IdIAJkfYUU|tWICfj@@@@@@@@\nfbmAB@H@SDjnYeUWsQ\\dNZh@@@@@@@@\nfbmAB@H@SDjnYeUWsQ\\dNZhJhJhhh@@\nfbmAB@H@SDjnYeUWsQ\\dNZjjjjjjh@@\nfbmA`@@HsdTRfbTbtjRejshiZjjj`@j@@@\nfbmPa@LN``@QhHrRPqPiSISIJL{r\\kU@DT@A@@@\nfbmp@@@XXeL\x7FLjsobe`iruUPP@@P@@@\nfbu@AP@QAHadPJHeDZbGQ@XaLQfHrJJJ[PrZJ[TyzMLuUULuP@@\nfbu`q@OPQbJ\\`B@aFRRVIJYJYZPTcVV`@@Je`@@\nfbua@@M@rJQEJKJJIKNBgMUUSTBA@HR`\nfby@`@@HRYuUUUUZjjjjj`@@\nfby@`@@HR[UUUUUZjjffj`HTv`\nfby@`@@HR[UUUUUZjjfjj`PT`\nfby@`@@HR[UUUUUZjjjjj`@@\nfbyAb@HHpCpRkUYeU}Zjjjjj`@@\nfbyP`@LR@aIemUUUujjjjjj@@\nfbya@@D@rJJIIIHiIIMUUUUUP@@\nfbya`@D@UkHhhdddbddduUUUUU@@@\nfb}@P@@H]gHheDheEeD\\jugQRgKUUUUUUU@@@\nfb}AA@K@qLxbSLl|}z{ARtYtTp@@QL@P@@@\nfde@@`@QAHa`QhHrJJJZIKPi\\EjpXpQAU@@P@@\nfde@`@@HrIJQQZQXiRljw`mUUUUUT@@\nfde@``ARADDb@qDXaIf]UUUYqVg^``Jh@h@@@\nfdeP`@DNA[HhhhlmMCDRbc^BuPPPuTP@@\nfdea@@H`rQQQIRIZHbmHq`tEAUETT@@\nfdi@`@@BrQQIJHyII\\UPPTUUP@@\nfdi@`@@HRYUUUUPqZjjjjj@@\nfdi@`D@HQrS\\jjrnFKUTuA@@H\\`\nfdiA@@@ILjjjjhXmUUUUT`aE@\nfdiA`@@BCdbbRTTbWTxjjjjjjh@@\nfdiA`@@HLdrjjjjabuUUUUT@@\nfdiA`@@H\\drjjjjabuUUUUT@@\nfdiP`@DVAGHdiEBeCHbkRuP@UR`@@\nfdiXpCHLDXLPHUiwhRcfRJ]]{lbfbbbbbblkMADMCT@@@\nfdi``DF@Pcdfye_UTRf``ajj@PU@\nfdia@@D@RYguUURLZjjjjj@@\nfdiaB@JDAbYEEEIkHhT`qjZjj@@@@\nfdiaPBH@QYwhRclbfbbRLTTpiM@PKLt@@@\nfdq@P@@H]yIeWUUmZjjjfh@@\nfdq@`@@HRYWUUUVijjjj@@\nfdq@`@@HR[UUUUVjjjjj@@\nfdqAa@HRTALhDYIHddiDeTjjjVjj@@\nfdq`@@@ITnjjjmUUUUU@@@\nfduA@@@ILsLjm{AJ\\XOhm@@@@A@@@@\nfdy@`@@XrQQSPzIKJXiYuUUP@UP@@\nfdyA@@@IKLjoSWAF|pDEUUQ@@@\nfdyA@`I@bBQGhbLQdTTVVfbRaYqpXHBh@b@@@\nfdyAB`M@qBXcLPVHkDRYf{}e^RCFBHbh@@@@\nfdyAP@@BUhNQQQQQQDqIdgAZYjZZj`@@\nfdyAP@@BtFNQQQQQJKGISk^Z@HH@h@@@\nfdyA`@@BudbbRTQrbRxhLZBBb`@@@@\nfdyAb@FAb@HrQQJVIKJJDihuRl@ESP@@\nfdyPPBHZ@aShRcdfyVyuwdmFZ@HZfh`@@\nfdyP`@KN@cHihdliEDcpPXm@AUMTP@@\nfdy`R@KPQcp@cIIKDeLeBdJQgKP@@QT@@@\nfdy``@A@Pdrrr\x7FZjLFKTEA@@@@@\nfdya@@D@rJJIIHiQIBTFKUUUP@P@@\nfdya@@D@rJJJIGIQIRTFKUUUP@P@@\nfgA@B@@XbSLrjyFRMjuP@@A@@@\nfgAP@B@BAHirRJIJHkLUpQkAPP@A@@@\nfha@B@@IbURjjjmUUUUT@@\nfha@P@@HiKHhmDeDTdfjjZjh@@\nfha@R@HHehBYddbRRbbSUUULuT@@\nfha@R@HHpPG`eUjjsLuUUUU@@@\nfha@`@@HrJYQZQHiQjjjZZ@@\nfha@p@@HhkQdfV^yuVijVjhDAP\nfhaAP@@HEirSJwkO[TuUTr@@\nfhaAp@@HYqV`iLkWl{mSUSSP@@\nfhaAr@HHpSQk@|DjmUUUVjjjjh@@\nfha`@@@IRlrj~uUUUUP@@\nfha`B@B@bDeUUUUYjjjjhDHP\nfhah@@@\\ExJTjjjjmUUUUT@@\nfhi@R@NJmx@QdbbbbTVadgFCPAAAD@@@\nfhi@a@AFADAbDfUmygZL]z@BhHB@@@\nfhi@a@OAADBBLbTTRbfQtyiUj@B@bX@@@\nfhi@b@HH@DYIHXhhddSiuoKP@P@P@@@\nfhi@c@BFADRb@qFQQQIIPq[LD{tDDPPD@@@\nfhiA@@@ISLwZkf|xMUP@@@@@@\nfhiA@@@YEEDhdcLeKW`m@dP@@@aR@\nfhiAP@@PIqRTmMJ{yoNCUUUUUT@@\nfhiA`@@HBdwLl|zKSoMA@@PP@@@\nfhiIP@DXxHDc^CdTRbfaTVUNZltuUUUL@@\nfhiP@@@ArJJIEJIJYgKN`HJ@B`@@\nfhiPA@B\\@DXBDif]YybTdZiBBbj`@@\nfhiPC@IF@|PBDAFRIJJJIQXz|xMT@PP@@@@\nfhiQ`BHL@`LIQrS\\roZxeN|tDD@A@@@\nfhiQaBOAQbpHb@QzP}dTabbTVeTmF]K@QBrd@@\nfhi`@@@ISLwZkf|xMUP@@@@@@\nfhia@BH@AtIRYeV]WEjwjP`@BH@PP`\nfhiqP@DXxBQoArJIQSPjKJ`mVZZjjjf@@\nfhqA@@@ILkKjj~BuUUUUP@@\nfhqA@@@YEEDhbdddsdAAUUT@@@\nfhqP`@DD@YIeYU_UQfjjjjj@@\nfhqh`@NFmxHJYHihhdkLhIUADQML@@@\nfhyA@@@YHiMEiEbdHtcN}UUUUUU@@@\nfhyA`@@BMdTTTTTTVoMJ|xKPAAPA@@@\nfhyq@@B\\DAIfV]UudeZ|FBBaZeJ@@\nfle@`@@LRfVVW]|QgAhJ@HBF@D@p\nfleA@@@ILwJkttJU`m@PUUUD@@\nfleA`@@HbdssLjoyoNBuT@@@T@@@\nfleP`@DA@eIVUue]^B]yX@J@BT@@@\nfleP`@DA@eIVUue]^B]yZjjjjV`@@\nflea@@D@RYeUmU|RgAZjjBBJ`@@\nfleac@FV|DD`RPEHYEEEMDbeierVcPQDTluD@@\nfleiR@AZlFLDXhdGaddeRRbbRtQk^BuUURmSP@@\nfli@@@LdbVRRbbjTjjjjjj@@\nfli@RBKN|DBX{`|eTjjkLmUUUSMP@@\nfli@`@@HrJIJHiIIIIjjjjjh@@\nfli@`@@HrJKRIEJKIQjjZZihDEH\nfliAb@@Dhb`ReeUU]Vjjjjjh@@\nfli`@@@IJjjjjkUUUUUT@@\nfli`@@@IJjjjjkuUUUUT@@\nflmA@@@YEEEEDeDTbrRgF}EKPLQTKTR@@\nflmAB@K@qDfYYy{uXJVcNbf@@BI`@@@@\nflu@B@@^BULsJjozCZOdu@@@@@@@@@\nflu@B@LTBUJssZktDzHTaAP@@@@@@@\nflu@`@@HrJKRJKRKEISmNCEjjjjjjh@@\nfluP@@@ArQQQQII[ERdmNmxH@@@Bh@@@\nfluh`@DXUipAYEEEELTdedrVcN|uUMSURt@@\nfluqB@AJMDFHdrmrlzmNZ\\EL@PuA@a@@@\nfly@PB@HbeGI{HiiBddddeBTZjjjjf`@@\nfly@`@@XrQQISHqIYQwjjjh@J`@@\nflyAP@@DExNQQQPkIIJYTXtuMUSU@@@\nflyPa@L^bdDQjHrIJJIIHiSQQjjBBJi`@@\nfly`P`LHEIpH`LaFPSHYEMEEDlbeIjtu@pQUP@@\nflya@@D@rJJIIIHiIIVfjjjjjh@@\nflya@@H@RV[WUUTTih@Jjj`DHH\nflyaR@IBlzJPUfQQIYSJJHjTY@AMTuL@@@\nfoA@@@LdbbQbRbDkQfjijjh@@\nfoA@@@LdfbTrbUipufjjjfhDCH\nfoA@P@@Ht[HheMEEEQJeYjjjZi@@\nfoA@R@HHqp@QddebbfRtmV\\mA@@@@@@\nfoA@`@@NrQQQIISDVeVh@@BH@@@\nfoA@`@@VRfUYu^JLz``@B@@@\nfoA@`@@\\RVUoeVBly`BH@@@@\nfoA@b@KN@DISLjohmJMP@@AP@@@\nfoAA@@@IRlrjzkF]U@@@@@@@\nfoAI@BDDXhCIUNQQQSQIHdyYsURE@P@@\nfoAP@@@NRYWVUzLMZ@B`@`@@\nfoAP@@@NRYWVUzLMZjjjjj@@\nfoAPPBHZ@aShRcdfyVywdmFZ@HZd`@@\nfoAQC@DL\\BHiDVbLbbTTJRtYqVhB@@i@@@\nfoA`P@L@IrRRllrkhugLuSMThHHP\nfoA``@D@ydTRbTLRIFFluR`PT@@@\nfoA``@L@QdTVbbbblmV\\u@A@@@@@\nfoA`b@LTX@HRe{VYSVlznZjjZ@@\nfoAa@@A@RfuueV\\lz`@jjb@@\nfoAab@KPQ`@QddebRfR`iF\\m@@A@@@@\nfoAab@NPQ`@QddebbfRtmV\\mA@@@@@@\nfoAqB@JLDPDQdTTTtlRWAV]RuT@B@@@\nfoQ@@@LdbTrdrLYs`cVZjjjjh@@\nfoQ@`@@HRYVvvQRuXsfiZjjY@@\nfoQ@`@@HrJIQJKPjReFlyjjjij`@@\nfoQ`@@@YHhhheDbKTkF]P@PPD@@@\nfoQa@@N@rQQQQJKGbiVLz`BB@D@@@\ngC`D@DPHRfh@\ngC`DADZHRVXRP\ngC`DADZHRVh@\ngC`H@DIKT@@\ngC`HADIKLIH\ngC`HADIKR@@\ngC``@dfZ@@\ngC``AdeY@@\ngC``Adej@@\ngCa@@dkH@\ngCa@@dkP@\ngCa@@dmH@\ngCa@@dmP@\ngCa@@dsP@\ngCa@@duP@\ngCaHH@bNt@@\ngCaHL@aIZ`@\ngCaHLHaIZ`@\ngCah@mJAIj`@\ngCd@Adej@@\ngCe@E`dsP@\ngCh@@dmH@\ngCh@@dmP@\ngCh@@doH@\ngCh@@doP@\ngCh@@duP@\ngChHD@aIU`@\ngChHLHaIZp@\ngCh`LDdsP@\ngCi@DDeV@@\ngCi@DDeZ@@\ngCi@LDej@@\ngFp@DiTt@@@\ngFp@DiTvjh@\ngFpHADILimSP@\ngFpL@DXHHPeJfuU@@\ngFp`@dfTujh@\ngFp`@df_Ejh@\ngFp`AdigVjh@\ngFq@@drfmU@@\ngFq@@drftm@@\ngFq@@drfuM@@\ngFq@@eLzts@@\ngFq@@eLzuU@@\ngFqHJ@aJUMjj@@\ngFt@ATiTvjh@\ngFtHE`DILikUP@\ngFx@@eJf`@@@\ngFx@@eJfuU@@\ngFy@JDiTvjh@\ngFy@LDiWFjh@\ngGP@DiVV`iJ@\ngGP@DiVj`@\ngGPBADJPtaXcHiCUP@\ngGPD@DPHReZj@@\ngGPDADFHRYjY@@\ngGPLADFHlPdrsTID\ngGPLADFHlPdruT@@\ngGPLAbGDlPdruT@@\ngGPP@cTfyi`@\ngGP`@TfYi`@\ngGP`@TfYj`@\ngGP`@dfUjP@\ngGP`@dfUj`@\ngGP`@df]jP@\ngGP`@dfuiaM@\ngGP`@dfuj`@\ngGP`@dfyj`@\ngGP`ADkjj`@\ngGP`ATeVj`@\ngGP`ATeej`@\ngGP`ATf^j`@\ngGP`ATiVj`@\ngGPhH`DYIHUi@@\ngGPhMQDIK]U@@\ngGPlEaDPHlQdTaeh@\ngGQ@@djuT@@\ngGQ@@dkUT@@\ngGQ@@dlmT@@\ngGQ@@drmT@@\ngGQ@@druT@@\ngGQ@@dsML@@\ngGQ@@dsMT@@\ngGQ@@dtuR@@\ngGQ@@eJttHh\ngGQDBHbqBSKTp@\ngGQDJH`qBSKUP@\ngGQDJLPxbSKUP@\ngGQDLHbqBRwSP@\ngGQDLHbqBRwUP@\ngGQHDHaInfh@\ngGQHJ@aJUjh@\ngGQHJHaIUjh@\ngGQLJIARFdLbdMU@@\ngGQ`@bdwMT@@\ngGQ`@jdsmR@@\ngGQdEb@bRFRRVV`@\ngGQh@ZjAJVjh@\ngGT@Ade[j`@\ngGT`EPTfyi`@\ngGX@@dj|tHd\ngGX@@dkUT@@\ngGX@@dk]L@@\ngGX@@dtuV@@\ngGX@@eNuT@@\ngGXHD@aIUVd@\ngGX`hEIWIMkU@@\ngGXhhZ@bS^Rmjf@@\ngGY@BDeVj`@\ngGY@DDeUZP@\ngGY@DDfYj`@\ngGY@HDefZaH`\ngJP@DknX@\ngJPDADFHRYj`@\ngJPDADFHR[f`@\ngJPH@DIJuP@\ngJPH@DIKUP@\ngJPH@DIRuP@\ngJPHADILth@\ngJPXHlPDQzt@@\ngJPXHlPiQzt@@\ngJP`@TeZh@\ngJP`@TfVd@\ngJP`@TfZh@\ngJP`@deVd@\ngJP`@deVh@\ngJP`@dfVh@\ngJP`@dfvd@\ngJP`@dfvh@\ngJP`Adizh@\ngJPdEaDPHRZe`@\ngJQ@@djsBJ@\ngJQ@@dkU@@\ngJQ@@dls@@\ngJQ@@dlu@@\ngJQ@@dmS@@\ngJQ@@drt`@\ngJQ@@dru@@\ngJQ@@dsT`@\ngJQ@@duU@@\ngJQ@@eKS@@\ngJQ@@eKU@@\ngJQHBHaIfj@@\ngJQHBHaInZ@@\ngJQ`@bdvu@@\ngJQhHlOAJmj@@\ngJT@@TeZh@\ngJT@@Te^l@\ngJT`E`TfVh@\ngJU@HPdkU@@\ngJX@@dkU@@\ngJX@@dkt`@\ngJX@@dku@@\ngJX@@dms@@\ngJX@@dmu@@\ngJX@@eKU@@\ngJX`LDdru@@\ngJY@BDeZh@\ngJY@BDeZl@\ngJY@BDizh@\ngJY@DDefh@\ngJY@DDfvd@\ngJY@LDeZh@\ngJYHCabIKTp@\ngJYhCE`DQzt@@\ngKP`Adi\\Zj@@\ngKX@@eKcUP@\ngK\\@ABeKcMH@\ngNpB@DSppPPaJ[Zj`@\ngNpJAbJHLaYArBS]UU@@\ngNpLADXH\\PdjmUP@\ngNpP@jtfvZf@@\ngNp`@TfYZZ@@\ngNp`@dfUZe@@\ngNp`@dfUZf@@\ngNp`@dfUZi@@\ngNp`@dfUZj@@\ngNp`@dfWZfDL@\ngNp`@dfWZj@@\ngNp`@df]Zj@@\ngNp`@df^Zf@@\ngNp`@df^Zj@@\ngNp`@dfvZj@@\ngNp`@tf]jj@@\ngNp`@|bdQjj@@\ngNp`ATf^jj@@\ngNp`ATiUjj@@\ngNp`ATiVjj@@\ngNphDqDYEHcUR@@\ngNphH`DYIHTmJ@@\ngNphJpDIRkUT@@\ngNphJqDIKMTl@@\ngNq@@dlkUP@\ngNq@@dl}MPb`\ngNq@@dr{Vpa`\ngNq@@dr}Vpa`\ngNq@@dsKSP@\ngNq@@eLuUP@\ngNq@AdTbMTpa`\ngNq`@fdskUP@\ngNq`@jdrkUP@\ngNq`@jdssTp@\ngNq`AVeJmUP@\ngNq`AbeMmUP@\ngNqhAbjAJyZj`@\ngNr`ijpiJyImfi`@\ngNt@@TeVzj@@\ngNt@@|dbJjj@@\ngNx@@djmUP@\ngNx@@dsuUP@\ngNx@@eJmTh@\ngNx@@eJmUP@\ngNx@@eRmUP@\ngNx@AddQUUP@\ngNxDHHaQBS]UU@@\ngNx`DFdskUP@\ngNx`LFdjmUP@\ngNy@BDf^jj@@\ngNy@DDfYZi@@\ngNy@FDeYjg@@\ngNyHJPDIJwTt@@\ngOp@DjWkB@@@\ngOp@DjWkjj`@\ngOpH@DILkW@@@@\ngOp`@dfUMZj`@\ngOp`@tiguif`@\ngOp`@tigujj`@\ngOp`ATeekZj`@\ngOq@@drm[ST@@\ngOq@@drm[UT@@\ngOq@@drm\\@@@@\ngOq@@drm]UT@@\ngOq@@eLnmLt@@\ngOq@@eMN]UT@@\ngOq`@ldrikUT@@\ngOqhHl@cIIBjujh@\ngOt@@tjWkjj`@\ngOt@ATiUkjj`@\ngOtLHPDXHhPeLq]UL@@\ngOx@@drm\\@@@@\ngOx@@drm]UT@@\ngOx@@eJqh@P@@\ngOx@@eJyh@P@@\ngOx@@eLmXD@@@\ngOy@DDfYKZj`@\ngOy@JDiWMjj`@\ngOyDEQDDHRYXnZZ@@\ngOyDLpDHHRY\\ujf@@\ngO|HDVHaIeZx@@@';mlb.aE='fHfXAa@\nfJ@FD\neOHBNZ`pge@\neFhHba@\ngFy@DDfXujhB\neFHBJFE@\ngFt@ATiTvjhCAbKF`\ngChHLHaIZ`H\neMhHchLJyH\neFB@JcAaGJ@\ngGPH@EIJmU@P\ngGPHAbIJmU@XTQX|e@\neMBBlRZCAKd`\neMABHXaIhH\ngJPDADXHRUj`LBHmrD\ngJQhHl@bOV`LH^S@\neMHAIdLF^P\ngCa@@dkHFBVyH\ngC`HABQz`H\ngCaDL@b^BTt`P\neMJDbDfP`\ngC`D@DXHRUdB\ngGQhHl@cIHTmPFBMy@\ngJXHD@aIUj@pHVOI@\ngGX@@eMUTA`Uc^P@\ngChDL@aABSM@XHKdp\ngOx@@drm\\@@A`plZp\ngJX`BDdru@P\neMC@thabHzB\ndaDD@@QInXjZjh@`\ndid@@LdbLTifjj`B\ndeTH@@RUYTYY`@@aKChSFxYyE@\ndaD@P@bNbDfUzZ@B@C@`pnxbT\ndeTHPBBHfHrJJIHlLDDP@P\ndaD@`@bDeeVz`@@B\ngFp`@TizJjhCCSGbU@\ndidD@@yIYVXV@H@CBhpf{dB\neFJHbHpP\ngO|@AFeVm]UTAaUcWrP\ngOy@FDiguie`LMj~ID\ndaD@`@bDfUjZ@B@CB`SJ{dL\ndifH@DAInUxV`@@CBdinGdD\ndaEH@HpDeeVz`@@B\ndeVD@AADfVuFVijh@phj[iy@`\ndifH@HAIYexZ@`@B\ndifH@JAJ[gxZB@@CBdJf{dB\ndifH@HAIYW[j@B@B\ngOx@@drm\\@@A`Qj~ID\ngOr@Ajti]qZY`H\ngF|@AbeJfuU@P\ndmN@@@rJJIQEneX@@@@B\ngJX`DBdru@XKGdP\ndid@`@qDeYWaf@@BH\\NABinGdP\ndifD@H@Tee]nh@H@H\ndeVD@LBTeegXV@HP@`\ndaF@@@RYWih@H@LJCBknP`\ndie@@@aJyV[f@B@B\ngGY@JDeUjpLDmrP\ngFt@AdigUjXCAF|Rp\neMBBHRZCAGe@\ngC`HADIKTAa`mrP\nfHcdA@\ngJX`HLdmU@P\ndaz`@@SFyIeYjf@LJAL[nQP\ngNtDLpDHHR[UjhB\ndiTH@@RgeXSaj@B@CAhJfx^P`\ndew@@@pldTTJVTLmP@P@XUaMt|`P\ndiUH@HPDiUWBxZVeh@`\ngNq`AVdlmUPFEfM_DD\ndaxL@@[deiZjh@pXHpf{dT\ngCaHLLQIZ`LLInQ@\ndedBPLinCDKpRUZvjZh@`\ngNplLPDSpPPdukUPFFE_H`\ngJPL@DSpPPdju@XXK\\TH\ndiDDpLH@bOA@aIiUZjh@`\neMIDBKpRYCqH\neMXIDf``\ngG]@DZDfuiPLEkrH\ngGY@JDf]j`LLl^R`\ngJX@@dlu@XZX|PP\ngNxHF@aJZzjPH\ndazD@LADeUffhHr`\ngGQHJLQIUjdCCBKbq@\ndaxD@@QIgUjj@LBrf{dD\ngNy@BDf]jj@phbuxbp\neMXIDfP`\ndiGL@DK`hTfV^ii`B\ndmvD@E@dfYwVzB@j@C@PpjxYT\ndmvL`BaL@HrRRjIJUVjjh@`\ndaFH@NAIeVf`@`@phLInyB@\ndiGD@JxPQIeUZfX@`\ngCi@DDej@ppfyD\ngCa@@dsPFBV@\ngCd@Adej@ppVyH\ndiFD`Li`BDenvjZ`CA`aLxP\neMC@HoABDe`pQyP\ndiDDpLH@bOA@aIkUZjh@`\nfHdpAa@\nfHa@A@\ngFy@JDigVjhCCSGbU@\ndaF@`L@HRe]pjjj@LFBDJfyG@\ngChHL@aJZ`LLHnS@\ndaFD@DCdfVRiji`CCDinQ`\ndaGH@DK`R[e[fii@LLPfyE@\ngOtHLPDYHhckSM@XXI|a@\ngNqhHl@cIICej`H\ngNphJqDIJmSLHf\ngJQ@@dju@XZK\\a@\neMABHYAIhH\ngJP`@TeVhCAQ\\VH\ngCahHlOBNtAaAqK@\ngGQDLHbqBRwUPFEDQoI`\ngJT@ADjzhCAQ\\VH\ndazL@BANR[UZj`CBdrf{dD\ngJX`LHe[U@P\ngNx`LDdssUPFFq_IP\ndaz@@@ReUjj`CC`aLJnyC@\ngNx`LFdjmUPFCDQkyL\ngChHHOAIj`H\ndeUH@JdDin]xZB@`@`\ndieH@BDDfY}n``H@LJpjX^P@\ndaE@@@yIe^f`@`@pHLKnHe@\ngOq@@dlvKUTAaeWqP`\ndid@p@bBbAbDfYun``H@H\ngOy@FDiguie`LMc^IL\ndaDh@DInAIf]nZiX@p`nIe@\ndigH`LH^@HRf_ljfYh@`\ndie@@@EJ[W[j@B@CBlJfGb@`\ndaFH@NAIe^f`@`@pILknHA@\ndieH@BDDfY}n``H@LBpj[b@H\ndeUD`JXiCDrJJJXlMKUL@P\ndaED`LJDCpRjw[fjj@LLinxfD\ndaDH@@RYUih@H@LBCB{bHp\ndaDH@@RVU[f@@@LB`j[bYp\ndmuD@FDDR[f[eV`b@@H\ndaDD@@yIe^fZVX@pSJxbD\ndcN@`LCDRUgeUvjh@@@`\ndk^@@@RYWYVftx@H@@@H\ngO|HEfHaIeZx@@B\ndeT`@@pjrQQIFTpDEP@P\ndif`@@pj[IEEEZxBH`@pPfy@`\ndid@p@bFbAbDfUfn`BH@H\ndaF@@@RYUih@H@LBCB{bHp\ndmuD@JDBRY^YEZjif@H\ndifH@AAJY}rjY[`bf\ndaE@@@yIe^f`@`@pKBknHB@\ndaxD@@QIeejZ@LLJfyG@\ngC`HAbIMLA``nS@\ngJQHH@aJmj@ppQyL\ndaxL`HS@|Dj}fjX@`\nded@@DiUWeiZCHTZ\\IBDpjXYyG@\ngGU@CPdsmJA`e^S@\ndeU@@@aJWeQfZ@@BHlNSJ[agdP\ndmu@pFTH`h`XaIf[oi`bH`@`\neMPBchLF^P\ngGU@DPdrmTAaecrT\ngN}@DZDfVZj@prqxjp\ngGUHEhOAJmZhCAF|pV@\ndmND@DBdfV]RZUZf@@@LBSagdJ\ndev@@@RfV^nFP@@@@LFPj[ayD`\ndcnH@HCHhheEbprl@@A@@P\ngFu@LPeLftu@XYF|f@\ndiT`@@rnRfUjEnBA``B\ndmLD@@IJ]YVDeZj@B@B\ndcnH@DAIYegzUujAHH@H\ndmL@@DjYUVGi@@@`@LNpjxYWdH\ndcn@`N@HRYeevz]`@@`@B\ndcn`@@rfeJY{]kadHHZR@H\ndevH`LX@aJWY\\HYiZZd@`\ngC`HADIKTAaaMrH\ngNpDADXHRV^jhB\ngJPXHlPDQztAxlP\ngNqHLHaIYzj`H\ngGQDJH`qBSKMPdX\ngNq`@jdvsTpFBsyD\ngGQHJHaIYfdRL\ndaFH@NAIe^f`@`@pXDpjx\neMaDBKpRVB\ngOx@@eJqmUTA`xlZ~P@\neFA@H`bLFE\\`\ngKP@Di\\YZ@phbq@\ngJPhIaxIVmPFDODD\ndcLL`NWPbDfUuZf`@jX@LNALJat\ngN|HEb@aIevj`H\ndaE@@@aJyUnx@@@`\ngJQ`@bdru@XS\\a@\ndayL@DhByIeuji@LBSBkdL\ngJY@DDfzhCCSGbB@\ndmVD@JADf^Uvjjh@`\ngJXdIbHaABRuJA@\ndiDDPNDHc@aIUVfjXHb`\ndefHPFDHc@aIUUiji`bJ\ndiEL@DpByIf^ZjX@`\ngNy`LETeUZZDs@\ngNx`BFdskUHFBVxcP\ndmLH@@Rge]aNFh@J`@`\ndeT@@DjU_k``b`@pFDpjXYyG@\ndmNH`Jd@aJYW_JxZA@j@CB`IaWdH\ndmM@@@[IEDhhZXU@@B@@H\nfHdxA@\neM`AIxLI@\ndeVD@DCDenUFVh@@@pZLinGdR\ndeVD@D@dfVuFVh@@@`\ndif@@@RfU~F``@@pYLJf{b@H\ngOx`FDdrikUTA@\ndeVH@IAJYW~F``H@LFSBinyD`\ndig@@@aDiyWaZ@@B@h\ndco@`LK`BLdTTRRITntpTA@Pe@\ngOx@@drm\\@@A`Pl~Ht\ndaE@`LH@aIYZfijd@`\ngOu@LPeLimMTHf\ngJP`@dfvhCCKD\ngKP@Di\\Vi@pLVOH@\ndiVH@BAIfUInFjjZ@H\ngOpH@EILkW@@@P\ngJPDADFHRYj`LBHcrX\ngJPHAbIKUPFBDyeb\ngNthLXaxYIHTuTA@\ngNxdMVLP~BRkUS@P\ngCd@AH}PFBVyH\ngCd@ADkV@pdxe`\ngGU@MPdllrA@\ngJPLADHHLPdwSBJ`\ndeVH@IAIe]ZZ@Bh@LAALJnFP\ndidD@@iJ[gxZB@@CBdJnGdL\ndaFD@FCdig|jfV`bf\ndaE@@@YIeZn`B@@piLiny@@\ndaEH`Dq`BDfUjyjfPC@`SNyE@\ndieH`Dq`BDfUfnZii@H\ndaFH@BAIf]n``@@phLJfyG@\ngFxhMD@cIHXZmTA`c^P@\ndaFH@BAIf]n``@@phLInyE@\ndifD@N@TfUvfZVZ@H\ndeTL`HS@BLddlRPrm@@@FEYS\\OHd\ndmtLPHS@BEBLddlRVFUh@H@H\neMPBchLD^T\ngJPDADFHRYfaIXXH|f@\ndkOL@Dhpg\\bbTTLVZjjj@H\ndcLL@@gTfYe]aZYjf@H\ngNp`@df]Zi@pvMyF\ndmtHPBBHfHRYeUXXHHh@LFCJxYyB`\ndaE@`LX@aIYZfjZd@`\ngGTHE`DILkU@XDKWdH\ndeWD@Li`QImenEjZi@H\ndcOH@DWPRYyWQej@BP@`\ndg}@@@mJYeU|]Tz@@@H@B\ndcND@LADf^YZUZ`HH@H\ndcnH`FDHaIe[gkev@@`@@H\neMbDBDfp|`\ndcMD@DpBRYgmUujh@@@`\ndmuh@DJaePRUeYxZ`@h@H\ndcNd@DJadMrIJIJE\\MP@U@A@\ngChHH@aJz`LDEqS@\ndeVH`BDHaIf]vzB@h@H\ndeU@@@eIYVvG`BL@H\ndcM@pEtIAICICHiCDedLuP@R@D\ndkmH@JTDeVVutvjh@@@`\ndmw@`Ds`BDf^YyUjB@@B\ngGYHMQHIJmT`XJKbq@\neFhHcA`d\nfoA@R@HHqH@QddebRbrPeV\\m@D@@@A@\nfoA@R@HHqp@QddebbrRTeV\\mA@@@@A@\nfoA@R@HHpx@QddebRfRpiFlm@@@P@A`sEFBT{bMF@\ndaE@@@yIe^f`@`@pILJnHG@\ndmuD`LVD@HrREQIXYV`@`@`\nf`i@@@LdbbbTRVHeZ][uHAD@D@@P\nf`i@@@LdbbRRlRSI\\D{qAHT@D@@XJpRgIZMYwnHPH\neMCBthabHzB\ndk\\H@@RfU}WJxZA@fXBIh\nf`iQ@@AR@drnrjmFJt{t@Du@@@@XR@cAJRM[wHN@\ndmM@@@qJY{WJeVj@B@CCdrfzUy@`\nffc@H@@\\eYtRurJJIQPpjYQYLxkR\\m@qAUUUQ@A@\nfmo@H@@B}GKYkrJJJJJIY[EQJKIbmNlGhv`BH@Rjjj``@`\ndk|@@LdbbbRQKauS`@`@`@H\ndcND`La@BLddJTrRzmT@@@XMaMpkqIt\nfc\x7F@H@@\\ddoU{rJJIQQXsIYJIQYLxhpXcftCDP@EUUUA@A@\nfewAP@@Fbt^QQJJJIRI[RKYr`mA}eMVfjjjjjjjj@B\nfheP`@BJ@GHhhdhlhiVRxHuc^ZejjjYh@LNXIsQk^yAp\ndcmH@EtDie_[JxZA@f`@`\nfhy`a@APP@HtDYICDeLeLerVc^Bl@QP@D@A@\nfoQP@@@VRfYe]Z\\d[S`@@@H@@CCaFBUhsnHyX\ndco@@@PTfyVwiWV`BJD@`\ndig@@@aDkYWaZ@@@LJPj[nI@`\nfbmA``BLbCDubNqLxfQQQQJYRqZGdeVBfZfi``bX@B\ndg|L`HS@BLddlTRbLj]kP@@@@FGXpsiwrE@\nflm`@@@ITssJjnsdk^RFHP@@@@@@@D\nf`i@`@@DRYfyU]`mNmyi`@@B@@LN\\dhug^yCP\ndk\\B@@zSrJJIQPenWV`X`h@LLFUyfLX\nedZPK@@@FAEG@dnaec`X\\bbbbbbIbRbTrbJffW@fefUUssPSDQUUUUUUTT@A@\ndmvL`NaL@HrRRqQZUV``@@`\nfa{@a@K]@DNdLdTtbRLRbLfVuAJtFMVuUUUUURsU@AaxAJLxJRcVBgIZ|QA@\nfew@c@OS@DXB@rFRJQZQYFIQFSK[bcVSghzjjjjjjefj@B\nffsA`@@VkdTRTtRabrTRhqQoARUijjijjjj@CArLTxJRcN}GIZ|`d\nfa{@P@@VkwHhdiheCEdheKQbc^BdkSUUSUUTuP@P\ndmL@@DjYeVdU@@`@@LFpjFUxc\\\ndie@@@aJyexV@`@C@binxdB\ndk^D@IAdfYYwz]MjTHB@CBjE]ObYH\nf`ih`@LRt{pAISK[NzRbmV]UUPHEP@FCHDipWnHPX\nfnki`@DTxIPOMrJIQQKYQQIIEgIJSWIVjVZ`hJJb@B\nf`iQP@DX@IQoYEEDeEeBf\\uYwfjffjj`@`\ndetB@@kirQQIRyS]UUUPAaTXPsqDX\ndieH@BDDfYun``H@LLrny`DH\nfoAP@@@XRf^uu\\Tdij`@fXACU@\ndeUH@JDDinUzZBA@@pIBZ^Ip`\ndeUH@AdDimW[j@BP@pIBknId`\ndig@@@pldTRaifij`B\ndmN@@@rRJKQEneP`@@@CCdrfFUyG@\nfb}@B@@AFQQQJQIHqZIgEV\\FNZjjjjjjj@B\nflu`P@@`T[vQQQQQQQIR|EjKdm@DQ@pP@A@\nf`ip@@@V}dbbbbRrQirQmN@@@@a@@B\nfc\x7F``@D@wdTRrbfdRQfRdrvtxLRufmjjjjjjjjjj@CCjLTYpRmFl{pXiKUoQsWodB@\ndmtL@@x\\bbbTUZViVf@H\nfoA@`@@NRYWVUzLMYiY`@hAAcasAJRTYwLHyh\nffcA`@@EjdrnsLjomF^SGKRsP@@AT@@P\nfdy@P@@^CEIe]YVvhpufef@Bf`@H\ndmtL@@QTfyeQehBA@C@jXYxb\\\ndg\\B@@SSRYYYyVvhJA`@H\ndeUD@DpFRUVTYZZZPcJ\ndeVH@IAJYW~F``H@LJPj[nId`\ndk^@@@RfYU\\]Tzjjjj@LKBDpj[ae]L\ngJQHBLQIVi@`\ndieD`Dqa@HRYVZyjfX@`\ndaDH@@RYWih@H@LLrny`HP\ndg^D@LADf^YVyUj@`j@B\ndifH`FDHaIe[kh@b@B\ngGT@Adekj`LD[rX\ndaD`@@pjRfUi`HH@LH{fHS@\ndeTh@DiiAIYmQfj@@@H\ndeVD@NBTfUuifefX@`\ngGYHL`DIMlu@XHwbF@\ndaxD@@QIeYjZ@LBpf{dT\ndcNL@D@mRY^UyUj`@`@`\ndeVh@LKadDimY[j@B`@`\ndmuD@ITDR[e]xV`@d@LBJf{bHh\ndmuH@DpDf[mYUj`@@CAj[ae^Q`\ngOp@DjWkB@@LMc^ZI`\ndcNH@DCHheEDbnmPT@@F@hUMproHt\ndmuL@DHJUIeeTYZijT@`\ndeVH@IAIfu~Eh@H@LJpj[nQH\ndmuD@DpERYyWFVjjj@H\nfgAp@@@XEdbbTTrLiI`mFBBhea`@pYSdmFmrB@\ndiW@@@pdieZfxPHJH@`\ndiW@@@rdiefa[``hH@ppf{bHH\ndev`@@pjYJYejxY@bJH@pPYxc\\\nfgA@@@LdbbbTRoIBMjp@@@@@@FDlTYpTeZmrA`\ndk|H@@RfU{WJx]N`PJjH@`\ndew@@@rdifYj^DHJ``B\nfgAP@@@BrQQJESITXJQk@PT@A@@X\\IPRmFmrB@\ndg|L@@ildTRbrJQTJtEAEL@D\nfoQH@@@XhiJYmg^YpRcVBHJiXX@H\ngOy@LDeYMjj`H\ndet@@DjYUX^d@@@@CAbinF^Hf@\ndie@@@EIe[ih@J@CBdrnGd@\ndmNH@HCHhheDVzU`@@@@LFCJXYxgJ\ndeVD@LBTeegijfjd@`\ndk^HPNHHbXaIf^UvGS``B@@@`\ndclL@@GTf[VwiWV`BJH@pHjy^Q`\ndaEH@DHDfURijZ`CAF{bI`\ndg}H`LHPBDigUm\\h{ifd@H@LAABe]N~Pp\ndaED@LhDRY[Ifjf@H\ndev@PF@HdHrQQJEEPsTlmPA@\ngJPhLQDIKTpD\ngJPhHPDIUmHFDGDl\ngJXhCL@aJyf@`\ndo~L@M@iRYg^ufzB@jj`@pLLJnFUt{\\\neMACDXaIhH\nfjs`@@@ISLjmvj~JBtjp\\iKP@@@@@D@@A@\ndmtB`HSBCprRSFIJUZh@@@pinFUxfD\nfbm@P@@BBeIfYfUWybm^mEh@b@aF`@B\ndclL@@HTfYm]aWViB@`@ppiWfUv`\nf`qAP@@LDivQQQQQRk[`mFZBX`j`@H\nfoQPB@F\\@DYHheBeLdRdeV]Th@@D@@X\\@RfcV]qBI@\nfhypB@F\\T@HrQQJEJIIXeIZ|FiPBB@`@B\ndg\x7FH@LiPRUYYWESnj@@@@@`\nfdeIb@LLDhwh`BLdTrbRJbTOARTxM@PMUUE@AaHBJRu[pX|`x\nfdeP`@E^@{HhhhhhdeBpV`vbt@Q@LD@@XLyhu`qxaW`\ngOx`FJdlm[MLAyib\ndk^D@NBdef^ukmMfi@B@B\nfb}@P@@HM{HihheDeEdbIVk^BgKP@@PT@D@A@\ndidL@@RdfVwaZii@LHKfMp`\nf`i`@@@ISLrj\x7FSdkZ\\@@@DD@@D\nfhyP@@@VrQQQQIYHrgIFtx@@@BJ@@B\ndg}H@DxDfVyVyO[Z`@@@@H\ndcl@@DjYU_egX@@@@@p[J[agaHRz\ndcl@@DjYU_egX@@@@@pYLJngaLJz\nfdyH@@@P]yJVYU_Ud[Uf`@@Bj@D@T\ndeVH@DAIgeQej@@@LJSFx^IT`\nfnsPR@FJtZw`AFRJQQEJIVYQIXYrUVuUUSLt@E@@XN@cAJ\\TXJ\\ejt\ndg}@@@aJVYU^Svv`@@@@`KCj[ae]yaGX\ndazJ`JaLK`BLddNRuR@P\ndmvh@HJfTLbbbdSZZfji@H\ndaDH@@RVU[f@@@LL`fyfUp\nfhyA`@@HBdrrkN~RdcN|uA@@AP@A@\nfdu@@@DjYee]}faRlGtP@@@@@@@@puS`eZMYw`qyC@\nflm@@@LdbbbbbVNVxhUc^bd@@H@@@@@CCUNRUhsoAbgdF@\nfjcA@@@YDhhhhdeElcqVgVcdm@@@@D@@@@P\nflm@@@DjYeeo\x7FyHQm^bd@@@B@@@@CCUNRUjsoAbgdL@\nfduA`@@TCdbbTVbfbLIPQmN}F``@@BH@@H\ndeT`@@aIRge_aV@B@B\ndif@@@RfU~F``@@pxDpj[nPH\ndmND@BA\\bbbTUZ^EjVih@pSayfTp\ngCaHLHaIYaIXHSbV@\ndcLD@@uIfYoXVfZi`CANWbUH\ndmtD@@eIfUTUjBB@@pDHJfxYxfJ\ngNy@LDeVjj@phQkxi`\ndg^F@D@nt{RUefuFVjjjj@LMSJ[ae]N~Q@\ndae@`LH@aJYTj[jZjPCC@RnHw@\nf`ipB@L\\D@HrQQPsISIDXkSoUL`@@P@A@\ndk]D@BXDR[ee]ntvf``H@H\ndk^D@M@dfYmUXUMjP`R@B\nfgA@`@@VRfU{WqS`mFhD@@h@@`\nfoQA@@@ISJkZ~J\\eYu@aA@P@A@\nfhyh@@@XIQVRJJIIZEKLyISo@TEP@P`@P\nfdeI`@LZCDDeYHhhhlhblbTM[pZjjhDBh@B\nf`iH`@LR]x@diemg]IQVkNjjhDBh@CCdBTxHwnHQh\nfHahAa@\nf`q@`@@^RYWUe^cKN`@f@B@DNVB`HpRbmFm{bNB@\ngGP@DiVV`hipJqoDH\ndeTH@@RYWVf`@j@CC`SBhYyG@\ndmu@@@QInUwaZ@BP@pxDJfz^Ph\nda{@`Dp`BDfUvjXHj`\nfoApP@DXxBQgYEDhihUCPVkMMUUTp@X\\hpRcV]qGM@\ndmM@@@{IEEEEZzU@B@@@LBHYWbTp\ndcmH@LXDee[UnWZ@@@@@`\nfoAQ@@NB@drnkJtYYt@Dp@@BGJ\nf`qQ`@DXAKrSLj}klyYsUUH@T@A@\ndclL@@YTfYetngV`hD`@pJag^Ic@\ngNx`LDdvkUHFAqkyD\ndif@@@RYWZZ@BP@piLJnx`B\nfhi`C@I@dDRFICHiCDeMhdaJ|Fj@H`@@@H\nfhia@@I@RfuuYWYqwj@BX@H@PEP\nf`qh@@@XIQfRJJKZJEJgG^ejj`@`@LADYIVcV]rG`\ngC``AdeZ@pdxe`\ndg|d@BE[CDeenUyT{Zj`PH@H\ndk^h@DX]LDf[e]xUvj`PJ@CB`riOdP\nfoAh`@BBUYpLIKW\\kleFluU@`T@A@\ndmu@@@EIYWYnX@J`@pxLJfe^Q@\ndaE@@@aJyUnX@@@pHj[nIF@\ndaDH`NCDRYWih@H@LBALkbEp\nfdyqP@DXxBUoQrJIQSQYQPtDYsSUUUML@D\ndg~H`NX@aJU{YWBNzVZ@B@B\ndaE@@@aJyUnX@@@pPjxTXw@\ndeVD@J@TinUzZBB@@`\ndcMD@JDErQSQIE]MA@e@A@\nfhipb@LBCA@@cIIBhhddmmNmyZ`@@B@@H\ngOx@@eLmXD@AaUcV\nfoQ@@@LdbbbRQrYHRkN@@`@@@@LIXIPRmFl{dN@\nfoI`@@@IRlrj|DTxjqgUP@@AP@A`jBFBdkQkNy@@\nfdu@@@DjYee]}faRlGtP@@@@@@@@pubgEZMYw`qy@P\nfmoA`@@HWdTrTTtbRLrTfVrk^CdhymUUUUUUUUU@AauFBTYrRmFl{pXyKUoQsV\ndifH@AAIfU[hBA@CB`Jf{bXH\nfoAP@@@TRfyWm^RlzP``@@@CBQJLdkQkNxaG@\ndmuD`IVD@HrRFIKKaV@BP@`\ndeVH@DAIgeQej@@@LBSF{fTL`\nfde@`@@DRYg[VU~BLxLViZjB@X@CCfBTyiwnDeXLP\nffsA`@@HjdkJvmk\\oAZMxJRm@AUUUUEP@XNISdeZMYwhirWbHU@\nfa{A`@@HzdrmkZvmrrUYtTeZuP@UUUUQT@D\nfoAQ@@KN@eLrj\x7Fbthu@@@D`@D\nfhy@b@K^@DISLsJntyIq`t@PPID@@XR@rRmF]xOHB@\nf`ia@@A@RYV{UVgEZ]z@Hf`@@@H\nf`yp@@@PudbTRbRbQqRVeNmzZ`@`@`@B\ndknD`La@BLddJTRVtuj``@@`\ndmuL@DpFEIeY~nZifh@pILe^Qp\nf`i@`@@VRYfYU]`eNMyh@`AB@@LNTyKQg^yAP\ndcnD`La@BLddLTJULnkU@A@A@\nfoQ`@@@ISLrkiJRMiu@A@DP@A@\nfoQP@@@LRfV]uZ\\djsjjfh@`@CAPHHIQfcV]r@`\nfoQPB@HH@DYHddheBe``iV]RuJ@E@@P\ndknD@FBTieenGZB`h`@`\ndieD`JXaCDRYgvzejX@pHLi`\ndcND`La@BLddJbRrzmPP@@XMS\\LkqLt\nfoAQ`@EZ@JVQQQQQIWLTZsT`tAP@D\ndcN@@@Rfye~f`Hb`@pzfxYW^HB@\ndg^D@DCdefVUUMjBHb@B\ndg^H@LAJUyfUSjhBH`@`\ndif@pDBHjHFHrJIQEn`HH@H\ndid`@@pjrQQIFf@`h@LDx^XaL\ndcN`@@pjYJYe}k`Hbj@B\ndid@p@qBqAqDfYun``H@H\ndeTL@@jTef_xVB@`@phj[iyD@\nfoAp@@@P\\eKLjorMjsP@@A@B@KBQJLxJRmNyBp\ndeT`@@pjrQQQUMpEAP@XDUCOHX\ndmLh@DkeAIYe]neZhDB@CCBF^HD@\ndk\\d@Dki@|bbTRQR[aejeZf`B\ndeu@PLX@bPaJWY\\HYiZVh@`\ngJ]@EbDfVdCqX`\ndg}@@@aJnYU^Svz`@@@@CARinFUt{yD@\ndcML@DpFEIeY{kfjYj`B\nfoAQ@@KN@eLrj~bthu@@@E@@D\nfoA`@@@ILkjrmFV]@AL@@@ar`\ndaFD@JCdefZyiZ`B\ndclD@@EJY}erevfVfiBJlFpje]xbL\nfoA@`@@VRfum[V\\Uj`@@JP@B\nfoA@@@DjU][VgKNBAJ@@@PiXZ`cAJLdkQk\\`x\ndaFH@HAIYUnh@@@phHJfxf\\\ndeV@@@rRJFICMPD@@XLfTwCrI@\ndk]@`FD@aJY}e\\kSif`@`@`\nf`qQ@@DX@drlrj~gV|uUUUUP@P\ndg}@@@aJVYU^Svv`@@@@`K@Z[ae]obDX\ndmwD@LxPQIeVvUZjZd@`\ndg\x7FH`NW[@HRfum]XYV`BFiH@pXLIewbHX\ndk^H`Lt@aJWYW\\JUiX@J`@pxD[ad~Q@\ndieH@JxLbTTQkfej`CAFGbPP\ndifH@AAJY}rjYY`bj\nfhiA`@@Hddjrm|jIW`mPAD@@@A`kEFBTZsoAyB@\nfgA`@@@ISLrotyHvk@@@@@@@XLYIVcVy`gA@\nf`q@`@@HRUfYU_Sk^Zh@@@@@LELxJRmFl{wDPp\nfoQAB@E@BDiegUteARlz`RB@H@@`\ngGX`JDdjmVA@\ndmtL@@RTeVUaUj@H@C@jXUydYH\ngJX`LDdju@P\nfjs@@@LdbbbbbbfIQxhSiFmGIP@@@@H@@@@LM\\dkQk^bgI^PB\nffkA@@@YDhhhhdeEmE^JuztPiKV`@@@@@@@@@`\nfbc@@@LdbbbbbbQQsEBMKuhir@@@@QE@D@D\nffsA`@@VkdTRTtRabrTRhqQoArUijjjjjfj@B\ndmM@@@iJYewJEYB`R@CBbinWbCH\nfb}H@@@TMYJYewyUWEAJ]yNYB`RZ`B@A@U@\ndiTH@@RfU|kahDB@C@biaxb\\\nf`iQ@@L\\@dmKZzhiJt{sUTu@D@@P\ndg\x7FH@DWPRUe[mzSmh@ajH@`\ndiW@@@rdiefa[``hH@pQnybDH\ndcm@@@sIEDeBeSKhD@@@@XYpkrdiit\ndieH`HHPBLdRbQrjYi`B\ndklF@@pUttiinwZZjjjh@`\nfbu`R@@zM[pHcHhheDeDeNdpTcPDQSTuQ@A`HFJRlxJ^Hcd\nfde@P@@BUYIfYfVwXKWgQZ@H``b@@H\nflu@P@@BBeIfYfWgvJtztV`BH@dh@@pypVcVbgdO@\ndk\\B@@HSRYfu}aWViB@h@LJKiT~QP\nf`iA@@@IKLl~krRmN|p@@@@@@D\ndmM@@@eJYYvfEP@@`@B\ndeUH@LXDeYgXZjYX@`\ndefJ`JaLFP|LddjRcUTpA`rXUMH\nfbc@@@LdbbbbbbejwMB]Hu`ir@@@@@@@@@FFnBehuoAbgOHJ@\nfdm@@@LdbbbbbfjSCBUIuoAb@@@@AP@`A@\ndo|D@@eIfUwU[hBAif@siXz\ndklD@@SHihdhYNEh@Jh@LFPjWSxgB\nfb}A@@@YDhhhhhdhb^ZMyrXyh@@@@@@@@H\nflmA@@@ILroJ}jQ`iV]EKPPA@@D@@D\ndk~H@NAJUmmRkatzVd@J@B\nfgAa@@N@Re[UUIPTcVijeif`@`\ndcNL@M@iRYg^vzB@j`@pdLJnFUt\ndmtL@@SdfVUyUjA@@B\ngFp@DiTvVhC@qX|Ph\ndif@@@rRJEKaj@@@LBSF{fEP`\nfoAp@@@P\\eKLjorMjsP@@A@B@K@QJLyIVg\\PJp\ndk]D@HDMrJJJJHiaTx@HB@@H\ndeTH`NBHRYWVf`@j@CB`SJgbDH\ngGY@DDfUj`LLc^S@\ndknJ@CCNgTieY_hZjjjx@`\nfhiAP@@XyKRTrlovmA^CUUUP@P@FAhDipTmFl{p^HPp\ndeVH@BAIemQfk@@@LFbfxYy@@\nfhyp@@@NBeSMrnjpRkF|D@@@Q@@A`kENBejsoA@\nfleq@@JBBAIYe_e]nR]z``R@Bh@PyP\ndclD@@{HhheEBtkl@D@@@XTGCJ|sFt\ngFx@@eRqUU@P\ngFx@@eSQUU@P\nfoAQ`@DX@pRSJs|kSegMTs@A@@X\\QaVcV]rG@\ndk^L@DBmRYVuvfeVj@Bh@H\ngNs@IcPdmmMHD\nfoAqb@BTYIS`RBSLnmnsakTmTuUP@P\ndaEH@DHDfYVyje`CAJ{bXp\ndieD@DHFRYf^EjiX@`\nf`q@R@HHpP@QddarbbTQtYwej`@@@@B\ndeTL@@J\\bbbRKBuKS@FBUwDq`\ndcLDPBtHbXcHhhddbppPQR@D\ndid@@DjUZnBBH@LBinGfPf@\ngOp`@tiguif`LEksHl\ndaD@P@qBbDfYvzB@@B\ndk\\H@@rIJJIQDYtz`@@@@H\nfgA@@@LdbbbTVKIBMjp@@@@@@FDlTYrRmFmr@`\ndmNH@BAJ]YVDeZj@B@B\ndk~H@LAJYWmRkatzA@@H@B\nfoQh@@@\\UYvRJJJJsITyKQk@A@PtD@D\ndcmD@DpFRYUmRi]Zijj`CAlxYW^P`\ndg}D@DpNrJJIIPiDqvuTuUT@P\nfgAP@@@\\RfYe_irQmV@@@@@@@pxQ`eZM[dI@\ndctDXJXIAICi@YAYCYCHiMEHyUMUPA@\nfjc@`@@VrJIJZIPqYIJcEF|ENVfjjjjjj`@p|cENBdkQkN}EN^HBT\ndieH@BxDfYUa``P@LBCJGbMp\ndg|H`BBHRYe^uXSnBB@@@@pxLhYT~Xvv\ndaE@@@yIeVf`@`@pHLKnHc@\nffk@`@@LrJJJJHsIIPi\\dkWhaRVmPTP@@@B@@A@\nffk@@@DjYee\x7F^uyHQmNCDmP@@@@@@@@@B\nf`q`@@@YIEBedhdnB]zh@J@@@@`\nfhy@`@@\\RYee~uYrVoAZA``@H@@pyPTmFm{fLNB\ndid@@DkYWaz@@@LF`j[ayB@\nfduP@@@^RiggmUvBdjwgAjjfABJh@B\ndcLDpITJsjsZqIfVYXXBHZ@C@`y]xfB\nfhiA@@@ILkkLktYxL@DtD@@H\\lM@Q`eEZMYwnHxD\nfleA@@@ILklrsoQdTp@SUA@@BGJ\ndaF@@@RYWih@H@LBALkbEp\nfdyQ@@@qAdTTRQTRVTYrshBA`@f@DNT\ndaF@@@RYWih@H@LBCBkbIp\nfbmP@@@IrRJJIQJIHdjmhKhu@DPQAT@@X^qS`iJtZsoAbgH\nfhya@@K@rQQQQIYHrgIFtziAhEJh@B\ndmvD@DCDeUeYUj`@@B\ndmL@@DjUgZFUBBbb@LISBinFUyD@\ndmvH`Nd@aIe]Zf`@i`@piLJex`\\\ndeTDPDpHb@cHiCDdLrp@@A@\ndmvD@JBTin_^F``J@C@dIexe\\\ndaE@@@aJmUnjjh@pYLJf{dP\nfl}A@@@IRlrjkoAENJl[tTuP@@@@T@@D\ndknL@LACRYVuvUZh@J@B\nfhyA`@@B|dsLro~pRkF\\t@P@EP@A@\ndk\\B@@z]rJJIQPqnTv`XbH@H\nflu@P@@\\e{HhheEEcDef\\TZJV`Xb@`H@@pebRkN|FJ^PD\ndaGH@LJ`rQQRyULs@D\ndcnD@B@TfYm]aWViB@`@`\ndcn`@@rawIEDhiUTkhPUCD@XDc\\oHt\nfdei`@LJLzHIZrQQQQIJJkDiYpXuUUTBAP@D\nfhypB@M^B@HRfYU[wDYUg^h@@HF``@`\ndmtL`HS@BLddlRRFUh@H@LJqne^QP\nf`qAP@@\\dYvQQQJJDiQgEZZAbBf`@H\nfj}@P@@\\]eIfVWyU^YrV`iZA``HHZ@@H\nfc\x7F@P@@H]oHidhiiDhjdeIemjpXekM[UUUUUUUUUT@F@tXIQgIJtZsoAbdmV}GM^p\nfj}@p@@BMGI\\bbbbbbbtQqxkWgIZ@Hb@dj@@H\nfdeP`@E^@{HhhhhhdeBpV`vbt@Q@LD@@XLxhu`qxcW`\nf`i`@@@ITrlnzpRkN|DA@@@@@F@lTyKQk^yaBg@\ndmtDpFTH`h`XaIf[oi`bH`@phBXYyB`\nfhiP@@@ARYe_YWYqwhBBh@H@@`\ndifH@DAIVUxU`@@C@biny@`\ndifH`Lx@cIEDcBjiYh@phLJayB@\nfoAaB@LJ@DYHhhmMDbQegULpLA@@P\nfhiQP@DX@IW`yEEDeDdbdsakMUMMUU@AaKAJRMYw`|ah\nfhiPP@DX@IWdfYVU_V\\MYjiijZhDKT\ndk\\D@@[HhhiDjbY]ZBhB`@`\ndeu@@@[IEDhcSCH@@@@FB]OBPjD\ndeVD@FADfygFV``@@pjfxYyB@\ndeT@@LdbRTm\\DDT@FCIc\\L|RJ@\ndidD@@iIYmxVfZPB\ndidD@@iIUexVZZPaF\nf`qA@@@ISZzljscoT@Dp@@B@kCRLDhpTmFl{dO@\ndk]H@NTDimYuX]N`B@@@B\nfhip@@@LCdbbTTrLvUIBt@DAEU@@FAdTYpTeFl{p^Pt\ndmuD@DTArJJJFHUZijX@`\ndaE@`LH@aJ[Unh@@@pHD[nQP\ndie@@@aJVuxZ`@@CAlJfx^HD@\ngG]@DZDfUj`LDkqX`\ndet`@@raRfVZi[``jB@H\nfhy@P@@BTGHhhhhhebfBtzwf`BH@J@@H\ndiU@@@aJVupnFZiV@H\nf`ia`@N@LyIfV]UV\\eiwf`XHjh`@`\nfhyaP@E@EIwlbbbbbRjRXhuoAZdF`Jh`@`\ndiDB`HSBCpRjuVji@H\ngGX`BJdsmLIgAZ|b@\nda{D@DJ`yIeUjZBBh\ngGT`EaTf]j`LD[qK@\ndknL`LaM@HrRRqQHjUV`HJ@B\ndcNH@DCHheEBdnmU@@@FGIeMpkqIt\ngChHLLQIZ`LDEqS@\ndmu`@@pjY\\dTTRak`Hbh@H\ndmt@@DjUiZdHJb@CAd[ae^IA@\nfdyhP@DTxIPCAcdTRbbURTRYrRfjVZjjh@LIHEKUg^CD\ndeUH@JXDeVVxVYjdHQ`\nffsA@@@YEDeMDhTihdZLUiwhyZjjjjjjj`@pbcAJ\\EIVcV\\FJ\\uy@h\nfoQP@@@\\rQQQQQKFdeVLx@B@@@@@`\nfj}P@@@LRfVVWV}qF]GIYB`B@@@@ABE@\ngGPP@cTfyj`LInYF`\ndk]D`LFD@HrRPjJIEatujB`H@LJrnE^YNf\ndg|D@@WIEEEDYcPsmAQDT`A@\ndif@@@Rfufz`@`@piLIax`\\\nflepr@M^SAFB\\\\CprRSEQIZJKZR`qZjjjfVh@LIDhpTeVBgdL@\nfjc@`@@LrJJJJHpiQKKdeZ]{IZ`h`@H@P@@`\nfhe@@@LdbbbbbbcxhQiNlD@@@@H@@@pepTeZMYp^P|\nfHbXAy@\nfoAA@@@ILkjrmFV]@AL@@@arpTAFBTUhug\\QpP\nfj}@p@@\\dYI\\bbbTTVaaRaYIUhyZAbJ@BJ@@H\ndcnH@EAIfV][iuhFAH@LJiag^Ib`\nffs`@@@YIDmeEEEDhlZL]DI\\ujjZ@HH@d@@p}AFBTuYw`qSdmP\nfhyH@@@\\EKIEEEEEMUfRU[pYBb`@B@@H\nfjsA`@@TdeJsZvoZpPsfk^CdmA@P@@@@@@D\nfbc@@@DjYU_eUfByKQ`icd@@B`@@@@@H\nfbc@@@LdbbbbbbcJwEB]Hu`ir@@@@DT`D@D\nfdyp`@FRbABS\\rornIW`mA@d@D@HBh\ndmLd@Dqe@TfUeZzUZjUj@LLrUyB@\ndmM@PBx@c@aJYg\\jeZdHB@B\ndaDHPH@HHHRme[fii@H\ndk^@@@RYeg]ntxB@`@@H\ndcmD@DHERYYUZz]Z``R@CBdHYwdL\ndigH@DJ`RYYrYjfh@`\ndigH@LHPRfU~F``@@`\ngC`HAbIMTA@\ngC`DAbZHRVhCCB[dP\ngCahHlNbNlA`a`\ngChHL@aIZ`LBHl\neMFIDRM``';mlb.bE='fHbTA@\nfH`pA@\nfHfXA@\neO`BNZ``\ngKXHL@aJWFj`LBEcrP\ngBP`Adibj`H\ngCh`LDdsPFDWI`\neMBBHRZCAKd`\neFhHcAaWH@\ngC`DADZHRVhB\neMBCDRZCAKd`\ngGP`@dfuiaMX[F|b@\ngCa@@dkHFBbyL\neFABH`bLD\neMDARZCAgd@\ngJQhHl@cIHUhCBGd@\ngJXDB@bABUmTA`Pl^R@\ngJXHD@aIYj@ppqyH\ngGX`DJdsmRA`enP`\neMhDRZCAKd`\neFDBcAaWH@\ngCh`LHe]PD\ngOx@@drm]UTAaqEcV\ngJPH@DISUPFABqyH\ngJX`DBdru@XI[dH\nfHapA@\ngC`DAb[DRVhB\ndaDD@@yIe^fZVX@psBkdH\ndidH@@RUe^Fh@@@pxHPj[nPH\ndig@@@x\\dTRQi`HF@akBdpj[dB\ndaE@@@yIe^f`@`@piLJny@@\ndaEH@HxDeeVz`@@B\ndeUL@DpFGHhdhYWMTuPA@\ngOx@@drm\\@@A`Qb~IT\ngOx@@drm\\@@A`Qc^IL\ngOx@@drm\\@@A`Pm^Hl\ndaD`@@pjRfUi`HH@LDKnHc@\ndaGH@DK`R[e[fiZ@LLQnyE@\ndmN@@@RYVuiiV@@@@@`\ngOq@@eL~mLlAal[qI`\ndid@p@bBbFbDfYoa`b@@H\neMBCDRZCAGe@\ndifH@NAIYVXZ@H@CA`cBX^Qp\ngFt@AdiWEihCAJ|TH\ngCd@ADkj@ppbyL\ngCaHLLQIZ`LDEqS@\ndetH@@RgYVDFZh@H@H\ndiTH@@RgeXSaj@B@B\ngGQ@@eJuRA`Xm^P`\ndiDB@@[aRVeZjj@H\ngGPdMQbGpRUZi@`\neFA@HoBJD\ndaxBPHQn@HhHrRPzKThA@\ngNqhHl@cIHUEj`LLZ~P@\ngGT@ATiVj`LJHl^R`\neMPBcTH\ngJY@BDfVhCAK\\a@\ngGX`JDdsmTA`l^R`\ngGY@BDf^j`LBHmqF`\ngGT`EaTf]jPLDmrD\ngGQHJLQIUjdB\ndefD@FADf]ZZjj@LJJnF^Q`\ngCi@LDeZ@pTwH`\ndaF`@@pjYJYfn@b@@pPfyG@\ngNt`E`tf]Zi@pVODj\ndiFB@BAFEInuZjd@pILJnQp\ngCiHEAxIVtAaMqA@\ngGU@DPdjmTAaekqP`\ngNt`E`tf]Zj@pJM_I`\ngNxhMV@aI[ji`LBHmrL\ngChhMDOBNtA`enP@\ngC``AdeY@pbyH\ndaDH@@RVU[f@@@LJcB[nQP\ndaE@@@aJyUnh@@@pXHpj[d\\\ndaFH@NAIe^f`@`@piLJny@@\ngFxHL@aJYujj@pHboEb\ndaF@@@RYe[hB@@LJ@j[nQ`\ndaFH@HAIYUnh@@@pXHpj[d\\\neFPBca@\ndaE@@@aJyUnX@@@`\ngCe@E`dkPFBbyL\nfH`XA@\ngGPBADZPLaYAIZjhB\ngJPDADFHRUj`H\ngCd@ADiZDE@\ngJY@DDeZhCCSGbB@\ngGX`LDdsmTA`m^P`\neMBBHRYCAKd`\ndkNF@BAIWSR[YVYjjfX@`\neF`BJFE\\`\nda{@`Dq`BLbbbKUR@P\ndaDD@@yIe^fZVX@pSBxbT\ndaD@@DjWZXHB@C@dpnxdL\ndmNH@HCHhheDVzU`@@@@H\ngFy@LDidviXB\ndmv@`LCDRUVUeZj@@@H\ngNxDLLQxbRjuU@P\ndaDH@@RYVih@H@LBrf{b@`\ndaG@`LK`BDimVz`@@B\ndeUD@DhBRY[TYZ`@@B\ndeUD@DdBRY[TYZ`@@B\ndaEH@LXDeYVzje`C@`RnxdD\neMBCDRYCAGe@\ngGPXHlQxIU[U@XR|VH\nfH`TA@\neFJHqHpP\ndaxD@@QIeyjZBBlLpnyC@\ngGP@Di^VaHxTQF|f@\ndctH@@RgUUZYfY@dRVQX\neFBBDcA@\neMBBHRYCAGe@\ngJQHBHaInZ@`\ngGUHEhOAJmZhB\ndmLH@@RgVUaIVj`@`@`\ngOx@@eR}XP@AaXl[rL\ndcnH@JAIYe[yYu`@@@@H\ndev@@@RfV^nFP@@@@LFPj[iy@`\ndmM@@@WIEDhlZxY@@@`@H\ngOx`DBdwQkUTA@\ndclD@@UIfV][iuhFAH@LJiag^Q`\ngJPDADXHRVj`H\ngJPDAbGDRUj`H\ngJQHBLQIVj@`\ngNt`Bpdf{Zj@pJqoHp\neMdDhzB\nfHehA@\nfHfpAa@\nfHchA@\ngOq@@drm[RtA`Uc^Q`\ngFx`LDdrfmU@XHwdp\neMhDRUB\neFbHbHpP\neMJDBDf`pQyP\ndcLL`NWPbDfUuZf`@jX@H\ngNx`JDdskUPFDwLZp\ngJX`DBdru@XS\\RH\ndiDDPNDHc@aIUVjjX@`\ngChHL@aIVPH\ngJXhEBOAJuj@`\neMJDbDf`pQyP\ndaFD@DAdegfyjj`B\ndmNh@DkaTDfVYVzUZiZi@H\ndaDD@@IIf]nfih@`\ndaG@@@kdiVrX@a@C@hPfyG@\ndcnL`LaA@HrRPjIKTrzmPHD@FEYtkh\neOHBNZP`\ndiVH@BAIfUInFjZi@H\ngJPDADFHRUfaIP\ngNqDLHaqBRjuU@P\ngNpDAbODRUVjhB\ngGX`BDdjmTA`m^JD\ndidHPBBHFHRYgvzB@`@`\ngJXHD@aIUZ@`\ndifH`NDIAIe]ih@J@B\ndaE@@@IIf]n``@@pHLJnHw@\ngJPDADFHRYfaIP\ndiFL@JANRY]fjf@LLJayF@\ndie@@@YJYYhP`X@CBdJnGdL\ngGTHE`DIJkSBZppUxhP\neMbDBDfp`\ndeVH@DAIgeQej@@@LJrfx^Hd`\ndcN`@@pjYJYenk`Hbj@B\ndidh@DJaAIVUxZ`@@B\ndcNL@BA]RYe]VEjVih@`\ngNxhIV@aJUji`H\ndcNL@LANRYygiUjB@`@`\ndid`@@pjrQQIFf@`h@LLKaxbL\ndmvH@NAIfUTUZBB@@p[BiaWdR\ndmuH@DpDfWeYUj`@@CAlInF^Hb`\nfH`PAa@\nfHd`Aa@\neFJHaHhP\nfoA@R@HHpx@QddebRfRpiFlm@@@P@A@\ndmLH@@rJJIQEneX@@@@CB`kaWfXt`\ndmLH@@RYVuiiV@@@@@phJxYybXh\nfgA`@@@ISLrotyHvk@@@@@@@P\ndaFH@HAIYUnh@@@pKBinXD\\\nfduH@@@X]GIEEMDdehUbbkF|FKT@@ACPP@P\nf`iH@@@TdyJYW^U|TxJsiB@jjh`@`\ndmM@@@qJY{WJeVj@B@CCdrfxYyB`\ndcmH@AdDfUvVfWX@IjH@`\ndiV@@@RfU|kahDB@CB`JfGbIp\nffsa@@G@RfYU_yUTVeFCDmZ@@@JZ@@@@H\neMJDBDe`pQyP\nflua@`IJAHFdKRCi@hRDQHQDaHaHFJLuzJX@Jfjja`@`\nfhyA`@@B|dsLsKnqVgVBt@Q@BP@A`s`mFlGbIN@\nfbmAP@@BBgJSLsLoOkEZ]ZKPAD@RU@@D\ndaE@@@yJe~fB@`@`\nfoAa@@D@RYYeUuVLyj@@@@@CBRJLxJRmFxbs`\nfdyQ@@DA@drsJkzjlYsT@@@T`@D\nfhiq@@D^BAIefUWuUcNZ`@@B`@B\ndcNL`LaI@HrREQISBjt@Q@AaVTp{q@T\ndg^L`LaM@HrRPiSISJZuPAD@D\nfgA@@@LdbbbTVKIBMjp@@@@@@D\nf`iA`@@F\\eLsJmmARmku@A@QD@@P\nfnk@P@@FbuIefYZWz^`mA|gMVfjjjjjjj@B\ndmLH@@RfY]raV`XD`@phj[axdj\nfoAA@@@ISLjoxmJMP@@AH@AaKAJLxJRk\\PYp\nfnsAH@@LDjwdu[dTTTTTiRbTVWAZMdkPSDEUUUD@D\nfoIQ@@BJ@dsJsllepQkF\\uKUUTt@D\nfoAaB@G\\ADILkkJ}FFm@AP@P@A@\ndk\\H@@RfY]\x7FJEZA`RXBAh\nf`qQ@@G^@eLrj\x7FpmJMP@@AL@@XJpRcNBdiwnPL\nfdyQ@@OA@eLrj~lbthu@@@EL`@D\nfhyi@@DTxIPLbbTTRqbRYrRoAZiYh@J@@`\nf`i@`@@DRYfyU]`mNmyi`@@B@@H\ndaF@@@RYWifef@H\ndaF@@@RYe[hB@@LB@j[bYp\nfhe@@@LdbbbbbqQXXUiJ|DB@H@@B@@`\nfnk@a@CM@DVdLbbdRQbTQdrvIrRoAKVjjjjjiYj`@p]`eF\\EKQoQSdoD@`\nfa{@c@K]@DHBGRFQRZQIFIQFSKZ`eZCFkZjjjjjiYj`@`\ndet@@DjYUX^d@@@@CAlJnF^Hc@\ndeth@DkiAIeeVxYZiZd@pQAxaT\ndcNL`LaE@HrRPzIJSju@D@AaVDwSqEt\ndk]@@@qJY{W\\jUZh@I`@`\ndmN@@@rRJKQEneP`@@@B\nfew@`@@HrJYJJZQIFYJSKJmxNRcfuUUUUUUUUP@XUQ`eF\\dkQkN|FNRu[t_HS@\ndeVH@DAIgeQej@@@LJSJX^It`\ndaFH@NAJY\x7FJifx@`\neMdHTf`|rP\ngJY`DLTefhB\ndiFH`Bp@cIECDjZj@H\ndeTB@@RirJIPqTsUUT@P\ndmtL@@slbTtTLpfjjj@H\ndmNH@BAIfUmiEX@@@@CC`qnFU@\ndg\\D@@eIVUuWaZ@Bj`@peBinWSodP\nfgA@@@DjYU_VByHu`@@@@@@H\ndclH@@rIQQJH|J{P@@@@D\ndk\x7F@@@p\\dTRbfQjVGSBBheF@H\ndk}@@@iJUmUR[atzjZ@H@C@PPje]OdP\ndk}@@@yJUmmRkatp@h@B@B\nfgAp@@@XheLvnjs`iFlDPT@@@A@\nfgAP@@@LrQQJEIITxJQk@QE@@@@P\ndcm@@@EJYYwietB@P@@H\ndif@@@RYWZZ@BP@pXDpj{dB\ndg}B@DpAV|bbbRbrK]imUMMU@FGXU]IwrM@\ndg|H`FBHRYV~Ukcn@H`@@@pdDrne]OdV\ndg|@@DjU_eZx{BAH@@BJlMaLJfe]N~Qp\ngGQhHjOAJmZhCBGfFh\ngGT`EaTf]j`LDkqX`\nfgA`@@@YHheEhTj\\EHu`@@@@@@H\nf`i@`@@VRYfYU]`eNMyh@`AB@@LFRUhso\\QS`\nffc@p@@DEkM\\bbbfbTtRrLKAF|dkTaQ@DDT@@P\nfoQPB@F\\@DYHheBeLdRdeV]Th@@D@@P\ndcoH@NWPRVUmVFUX@ah`B\nf`i@`@@VRYfYU]`eNMyh@`AB@@LF\\Uhso\\QRP\nfhy``@A@|dsLsKnqVgVBt@Q@BP@A@\nfde@P@@J]{HhhhhhdeBpV`vbt@Q@LD@@XLUjw`qxca`\ndaFL@NAFR[e[fff@H\nf`i@`@@VRYfYU]`eNMyh@`AB@@LN\\dkQg^yB`\ndk\\D@@qIY[mZ{SZZ`@P@`\ndk]L@LxDMIe]eRkSZjjjh@`\ndclD@@IIf]U[evjj@@@H\nfgA`@@@ISKJntXKQk@@@@@@@P\nfduP@@@FRe[Y]mRTDhu`q@@BJ@@H@B\ngGPdMQDGpRUYiDe@\ndeT@@DjUghP`h`@pYL[agfPU@\ndg]D@LlMrIJJIIHj]UAAD@D\nf`iA`@@BUdTTTTTRqXKSk^Z@H`@`@B\nfgAP@@@\\RfYe_irQmV@@@@@@@`\ndmw@`Dq`BDeUeYUi`@@cJ\ndiV@`J@HRfU|kahDB@CB`PfGd\\\nfgAPB@LD@DISJ\x7FJdhsakTuT@D`@P\ngGThEXQxIVsS@P\ndk^@@@RfYU\\]Tz@@@@@LECBinFUOdZ\nfgA@`@@\\RfYe_irQmVh@`@H@@`\ndiT`@@rnRfUjEnejfPB\nf`ih@@@XIQVRJJIIZEIgIJ]xB`j@@P@H\ndcn`@@xYUIYeg[ewiBHH@H\ndmtH@@RYWUih@IhBN\\NALJiWb\\H\nf`qAA@A@bOQBSJ{\\ktYYt@EP@P@A@\nfdy@P@@BtGHhhhheEcliuoM@DD@T@@P\ndeu@@@[IEDhcSCH@@@@FAEpsqDh\ndcm@@@{IEEEDcWSh@PD@@P\nfoAP`@DXAIIfU^uYrsfjjP@`@H\ndet@@DjYUX^d@@@@CBlJngfHp`\ndclh@LX]AIVYWxUuj`PH@H\ngJP`@TeVhCCSGdP\ndaxL@@RdfVVjh@ppj[bYp\ndg~@@@RYfUWd}mh@@@@@pdBinFUwbGX\ndifH@HAIfuxZ`@@B\ndmtD`NTLQIe]Vf`@jP@`\ngOqHF@aJW\\ZVXCCA[be@\ndk^@@@RfYU\\]Tz@@@@@LICBinFUxff\ndk}@@@iJUmUR[atpBJ@@@CChPiWSyE@\ndk^@@@RfYU\\]Tz@@@@@LI@j[aeSxfZ\ndeUH@JdDin_xZB@`@pqB[fUt`\ndetH@@RfUWJzZABH@LBInGbIH\nfoQAB@C@BDifYU^gIVtz`B@DH@@`\ngBQHDHaIejhB\ndaG@`D[`bDfUjZ@B@CA@sbUp\ndidHPACDZHrJIJFn`BH@H\ndknDPLa@BABLddJbTVtujAH@@`\ndayDPLZD@HhHrRESKSPAafTwDC`\ngNxHD@aIUVj`LFEcWrP\ndiEDPLZD@HhHrRESIZZ`B\ndayH@DpDf]Vjh@piBinyF@\ndeV@@@RfyWahBB@CBj[agf@a@\ndmtB`HSBCprRSFIJUZh@@@pInF^YaJ\ndif@`D@HRVU^Ejjh@`\ndmL`@@siRfUmhVxHFJH@`\ngO}@EfDfUkZZPH\ngCe@E`dmHD\ndeUL@DpFgHhdhUWMTuHA@\ndclD@@EJY}erevfVfiBJh\ndk\\H@@RYeg]ntxB@P@@H\ndk\\D@@MJ[Vuvy]h@@B@@`\nfoAaB@KN@DISLjoxmJMP@@AP@A@\ndaFH@HAIYUnh@@@phHpfxe\\\ngF|@AbeLzmS@XKWbQ@\ndcoH@DJ`RUeUVy]ZZ`@@CBdhYwbPh\ndmOH@FePRYVukaf@HZH@`\nfhiA`@@Hddjrm|jIW`mPAD@@@A@\ndmL`@@[aRfV[hYVPb``@`\ndeVD@LADfvUFVjjh@p{BinF^P`\nfhi``@L@PdssLjn[s`mU@@@@@A@\ndk|@`@BDie^urnGShD@@`@H\ndeVH@BAIemQfk@@@H\nf`qa@@O@rQQQIISGBtju@@@QX@A@\nfbc@@@LdbbbbbRJvcEBMIpTqrAD@@@@@@@D\ndcl@`@BLbTTRbOBnt@@@@A`LDwCJ{r@@\nfdu@P@@JMGIEEDhhhhgPPkR\\kUUSUUUUP@P\ngFxHH@aJUqiZ@ppMyD\nflu@P@@B\\EIfYfWgvJuztV`BHBDh@@`\nfHbhA@\ndcl@@DjYeeiGP@HH@@`\nf`i@`@@VRYfYU]`eNMyh@`AB@@LF\\ehso\\QQP\nfhy@@@LdbbbRQaREiQoA`@`@@@@@`\nfhyQ@@CA@dsLjm{Jvg^Bt@@DCA@A@\nf`q@Q@HH]x@QXHrRFIJYIZ\\Ehrp@@Dh@A@\ndet@@DjYUX^d@@@@C@binxRXL`\ndg|@P@bCbDfUnuj{[`B@B@@H\ndidHPBBHFHRYgVzB@`@pHLh^HW@\nfoAaB@GDADILroZ{AFmAA@@P@A@\nfoAaB@GLADILk_J}NFm@DP@P@A@\ndc\\@@DjYVYayYt@@H`PB\ndiDB@@SaR[eVfjBLh\nfoAP@@@NRYWVUzLMZ@B`@`@B\ngOq@@drm]SRA@\ndidh@DqaAIe[kffjPB\ndeV@@@rIQIPmw@AH@XUaMp|bP\ndeVB@LAaeJYyzzjjj@LAaBinF^Q`\ndk\\H@@RYm[Watz`@@@@H\nfoAh@@@XIQRTsNj~sdm@P@QT@@P\ndklB@@F]RYe]ynZYif`B\ndaF@@@RYVih@H@LLBnybXp\ndknD@LADf^YWeVhBB`@`\ndcNH`IDLQIe[^ih@Jj@B\ndmO@@@bTieulhUfhB@@H\nfoQh@@@\\eYvRJJJJUKTxkQk@AA@tD@D\nflmAP@@LUyNQQQQEJQJI|Eish~BtuUUUUU@A@\ndkm@@@QInUu^Eh@IdBIh\ndifH@JAJ[gxZB@@C@dJfxgB\nfoA@@@DkfYU]UcNz`@@@@@`\ndk~@@@rRJIJJEi{UNhJHb`@`\ndeT@@DjY]zXFB@@pYLinGbEH\nfoAA@@@ILkjrmFV]@AL@@@arpdAFBTUhunXxIp\ndcMH@EtLbbbRQc]@PLp@P\ndiTH@@RfU|kahDB@CCBknXcB\ndifH@DAInUxZ`@@CAhJfx^HB@\ndeVD@HCDi^UFZh@@@`\ngNx`DJdssTpFBsyD\nf`a``@M@EdbbRTQrdxj``hjh@C@rBTYpTeZl{wHX@\ndeT@@DjUghP`h`@pFDpj[iy@`\ndcl@@DjYU_egX@@@@@pyLJag^XwJ\ndmtL`HS@BLdaRbReUj@@@H\ndaxD@@QIUUjj@LJpj[nQ@\ndcl@@DjYU_egX@@@@@p{J[ag^XaJ\ndaE@@@aJmUnjjh@`\ngOr@ABtiYufjPH\nfgApB@LLx@HRevUUpPTcViYj@H@@`\ndeth@DkiAIeeVxYZiZd@pqJGdD\nfoA@P@@\\e[HhheEBcF\\UihFHIh@B\nfj}@P@@\\ceIfVW{WVYrVoAZA``@JZ@@H\nfbm@p@@BLEN\\bbbbbbbrNwEZ|zKPADPBU@@D\ndg|D@@iJYYytYvzB@@`@B\ndmMH@HxLbbbTQ[iV@@@@@`\ngNt@@\\dbLjj@pJu_I@\ndk\\H@@Rf_YWJtzYX@HBJX\ndg|@@DjU_eZx{BAH@@BJ\\EaLine]ObEX\ndg|@@DjU_eZx{BAH@@BJ\\EaLJfe]Ob]X\nf`q`@@@IKJzljsco\\@Dp@@B@j\ndevH@IAJYW\\kahDB`@`\ndif@@@RYWZZ@B`@pYLJnGd@\ndk_@@@Y\\dTRbJtiad@@Bh@B\ndk\\D`HP@cIHXheDQgSV@@@@@pZnE]ObAH\ndg\x7FL@Ds`f|bbTTtJuCimMUUS@FCTwJ]|P]@\nfoAq`@DXxBSlbbTTtJVhKQffjjjX@LATYpRmFmrC`\ndcnH@IAJ[Vu[ev`@@@@LFSBE]yC@\ndmM@@@[IEDhhZdU@B@@@LJRnF^Hr`\nf`iP`@B\\@aInVUuQRUiwfjij@H@@`\ndc\\@@DjYVYayYt@@H``B\nfgAa`@N@t[HhheDTdsdeFltC@UQ@A@\ndeTD`HP@cIHXhdLk@P@A`UMp|PI@\ndie@@@GHhhdVz@``@pKBinH@`\ndmN@`E@HRfUwrnF`PI`@`\ndk\\L@@R\\bbTTTU[mMjBhB@B\nfbmAR@HHqhH@cIIKDeMEhdlIUgIrm@DM@`D@A@\nfoAP@@@NrJJIHqIYgCV`HH@H@@`\ndcLL@@ETfYUUnZYjZ@H\ndcn@@@rIQQJH|J{p@@@@D\ndaF@@@RZW[jii@H\ndiVL@DBnRYYbZfZjj`B\nfHgPAa@\ngC`DAbZHRVhB\ngCaHLHaIZPLDErP\neMPBcXLJyH\ngCahHlHROTA@';mlb.cE='daD@@DjUZxHD@@\ndaD@@DjUZxHH@@\ndaD@@DjWzXHB@@\ndaD@P@bBbDfYvzB@@@\ndaD@P@bFbDfUjz@H@@\ndaD@P@bNbDfUzZ@B@@\ndaD@P@qFbDfUjz@H@@\ndaD@P@qNbDfUzZ@B@@\ndaD@P@qNqDfUzZ@B@@\ndaD@`@bDfUzZ@B@@\ndaD@`@qDeeVz`@@@\ndaDB`HSJCprRRsTsUU@@\ndaDD@@IIf]nZYX@@\ndaDD@@IIf]nZZh@@\ndaDD@@IIf]n``@@@\ndaDD@@IIf^fZfh@@\ndaDD@@IIfunZfd@@\ndaDD@@QIeUnZjh@@\ndaDD@@YIeZn`B@@@\ndaDD@@qJYfnjjh@@\ndaDD@@yIe^fZVX@@\ndaDD@@yIe^f`@`@@\ndaDH@@RVU[f@@@@\ndaDH@@RVU[j@@@@\ndaDH@@RYVih@H@@\ndaDH@@RYWih@H@@\ndaDH@@RYe[hB@@@\ndaDH@@Rfu[j@@@@\ndaDH`BBHRYg[jfj@@\ndaDL@@PdfyVyjZP@\ndaD``DJnBHrJIPeUMV`@\ndaE@@@IIf]n``@@@\ndaE@@@YIeZn`B@@@\ndaE@@@YJYVf@``@@\ndaE@@@YJY^f@``@@\ndaE@@@aJyUnh@@@@\ndaE@@@yIe^f`@`@@\ndaE@@@yJYfn@b@@@\ndaED@DHNRYWifif@@\ndaED@DXNRYUifej@@\ndaED@DpFRYVkfjY@@\ndaEH@DpDfYbijj`@\ndaEH`Bk`bDfUzZZY`@\ndaF@@@RVU[n@@@@\ndaF@@@RYWih@H@@\ndaF@@@RYe[hB@@@\ndaF@@@RfYk`H`@@\ndaF@@@Rfu[j@@@@\ndaF@@@rQQHtpDD@@\ndaF@`BBHRYg[hH@@@\ndaF@`FBHRYVkh@`@@\ndaF@`JBHRVU[j@@@@\ndaF@`L@HRf^rjjj@@\ndaF@`L@HRf_rjjj@@\ndaF@`N@HRYWih@H@@\ndaF@`NBHRYWih@H@@\ndaF@`NBPRYWih@H@@\ndaF@`NBlRYWih@H@@\ndaF@`NCDRYWih@H@@\ndaFD@BADfyVyjj`@\ndaFD@F@dfYvzB@@@\ndaFD@LADfVZYjj`@\ndaFH@BAIf]n``@@@\ndaFH@BAIfunZfd@@\ndaFH@DAIeUnZjh@@\ndaFH@FAIeZn`B@@@\ndaFH@HAIYUnfjh@@\ndaFH@HAIYUnh@@@@\ndaFH@HAIYUnjjh@@\ndaFH@JAIYVfiih@@\ndaFH@JAJUtjjjh@@\ndaFH@LAIYfnjZd@@\ndaFH@NAJYfnjjh@@\ndaFHPBxHa@aIeTjijX@@\ndaG@@@kdig|jVj`@\ndaG@@@rdifvxH`@@\ndaG@`Bk`bDfUzZ@B@@\ndaG@`Dq`BDfUjyijP@\ndaGD@Dp`yIeVfZiX@@\ndaGH@Dq`RYVkffi@@\ndaTD@@iJUfDifzjjj@@\ndaTH@@ReYaBinjjj`@\ndadH`DBHRZuSFzjjh@@\ndag@@@adie\\infjf@@\ndax@@Dj~fjh@@\ndax@@DkU^jh@@\ndax@@LddUeUT@@\ndaxB@@QnR[VZY`cD\ndaxB@@QnR[VZY`cH\ndaxB@@QnR[VZi`@\ndaxBPLinBHKpRUZjf`@\ndaxB`HSBCpRjuZj`@\ndaxD@@QIeejZ@@\ndaxD@@QImUifALj`\ndaxD@@QImUjj@@\ndaxD@@YIgYjf@@\ndaxD@@iIUmfjBD`\ndaxD@@iJU^jj@@\ndaxD@@yIUUfYADb`\ndaxD@@yIUUfZADb`\ndaxDPFxLPlQIf^ZjBH`\ndaxDPLHHb@aI[Vfj@@\ndaxDPLh@c`aI[njj@@\ndaxD`LhLQIUnjZ@@\ndaxH@@RUUYj`aH\ndaxH@@RUUjj`@\ndaxH@@RV]Zj`@\ndaxJ`HSBxOCIILTuT`@\ndaxL@@cdiZZjh@@\ndaxLRJ[`bBBNyIUjjV@@\ndaxL`HS@BLddJruT@@\ndaxd@DpnAdf]ffXHr@\nday@@@aJnZjj@@\nday@@@yIYwjk@@\nday@PFx@b@aJUVjj@@\nday@`Dp@aIfYjj@@\ndayD@DpFRYVZi`@\ndayD@DxFR[VZy`@\ndayD@HhNRV[ff`RDh\ndayH@DpDfUVjh@@\ndayH@DpDfYfjh@@\ndayH@DpDf]Vjh@@\ndayL@DpFyIeUjj@@\ndazD@BADf{fjh@@\ndazD@LADf]Vjh@@\ndazD@LADf^VihHJ@\ndazD@LADf^fjh@@\ndazD@NADf{Vfl@@\ndazD`B[`BDe[jjX@@\ndazL@BAFR[nZj`@\ndazL@LANRYuZj`@\ndazL`BaL@HrRPzKUP@@\nda{DAJ[`Qi{dfuVjT@@\ndcL@D@dDdJdFdAdIdEdMdLbdtbaa]UUUT@@\ndcL@X@bBbFbAbEbMbDfYn\x7Fijjjj@@\ndcL@X@bBdFdAdEdMdDfYn\x7Fi`bHh@@\ndcLB@@ImrJJJIH}KTsTp@@\ndcLB@@P]R[e[^eh@b`@@\ndcLB@@Q]R[e]nEh@I`@@\ndcLB@@RUR[fVQuhHF@@@\ndcLB@@R]rJYQIPbkT@Q@@@\ndcLB@@RiRYyVQejjjh@@\ndcLB@@SmR[YgYUjB@`@@\ndcLB@@reRf[ujzjjjh@@\ndcLB@@riRfY~Qfjjjh@@\ndcLD@@IIf]z[hHBj@@\ndcLD@@QIgVUWVj`@@@\ndcLD@@QInUvxVfjf`@\ndcLD@@cIMHhTmJuUUU@@\ndcLD@@eJ[W[[j@Bk@@\ndcLD@@iJ[g]xZB@f@bX\ndcLD@@iJ[g]xZB@i@@\ndcLD@@kIEMDdcttDDT@@\ndcLD@@uIfUe[ffZi`@\ndcLD@@uIfUk[ffZi`@\ndcLD@@uIfUk[hBBj@@\ndcLD@@uIfYoXVfZi`@\ndcLD@@uJ[WU[j@BZ@`X\ndcLDHFDH`haXcXaIf[ozYjYjP@\ndcLF@@Rag\\bbTVTILuSUT@@\ndcLF@@RiWTfV[UnZjjj@@\ndcLH@@RYeZvz@`j`@@\ndcLH`ECDRUYWQff@B`HR@\ndcLJ@@PUuInUgzV`BJ@@\ndcLJB@PUuNR[eY~eijjh@@\ndcLL@@GTf[VwiZ@Hh@@\ndcLL@@STfyWWaZ@Bh@@\ndcLL@@yTee[UaX@bh@@\ndcLL`HS@BLddJfRtjmP@P@@\ndcLLpLK`bEbMbDeeYunjjjj@@\ndcL``Dpn@HRYueUujX@@HJ@\ndcMB@DpIWTfeyYaZjeZ@@\ndcMD@DhARYVUuujP`@HJ@\ndcMD`LE]@HRV[]nEjiih@@\ndcMH@DdLbbtRTHju@DP@@\ndcMH@DpLbbbLRRzuT@@@@\ndcMH`BuPBDf[U{aj@BX@@\ndcML@DpByIf]vifjfj`@\ndcM`@@pjY\\dTTRrM\\ADUP@@\ndcN@`IBHRYWVjZ@Bj`@@\ndcND@BADf{YU]Zj@@@@\ndcND@FCTfUiffZjjj@@\ndcND@HC\\bbdTb\x7FKUUUT@@\ndcND@N@dfY{UnZejj@@\ndcNDPBePbMbDfYmoa`bAh@@\ndcND`MIPbLbbbbQcSAAPp@@\ndcNH@FAIe[mkh@bj@@\ndcNH@IAIeYUifejZ`@\ndcNH`Bp@aJY{UWZZjj`@\ndcNH`BpLQI[VUWZZ`@@@\ndcNJ@NCIWTify^ajjjj@@\ndcNL@LAERYyeiuj@b@@@\ndcNL@LAJRY{eUujh@@@@\ndcNL@LAMrJYQIPcKT@E@@@\ndcNL@M@aRYgWVzB@j`@@\ndcNL@NB]RfyUZziZjh@@\ndcO@@@rTie_ZnBBJh@@\ndcOB@DrPY]RYV]jyjfid@@\ndcOD@Ds`wHheELUPmMTra@p\ndc\\D@@iJYeUqavUhJBbD@@\ndc^H@AAJU[VaJZUijZjT@@\ndcl@@DjYU_egX@@@@@@\ndcl@@LdbbbRkRJ`@PD@@@\ndclD@@QIe[WiiUjP@h@@\ndclD@@UIfVW[iv@@B@@@\ndclD@@UIfV][iv@@B@@@\ndclD@@UIfV^XYv@@B@@@\ndclD@@aJyegzUvjBHH@@\ndclD@@iJYW]rnF``IhBI`\ndclD@@iJYW]rnF``JX@@\ndclD@@iJYW]rnF``Jh@@\ndclD@@uIfV_XYV@@@`@@\ndclD@@wHhheEbprl@@A@@@\ndclD`AtLQIe]miaf@Bjb@@\ndclH@@rQSQJH|J{P@@@@@\ndclL@@STfUmVfeVi@B`@@\ndcl`@@`nReeWZY]@``@@@\ndcl`@@i]RfYyvxU@hJhP@\ndcl`@@jURfYwVxY@hFh`@\ndcl`@@j]RfYuVxY@hJhP@\ndcl`@@seRfUeZEnBAbh`@\ndcll@DpYAmRYV]zzUZije`@\ndcm@@@UJfUWyYvhJBH@@\ndcm@@@YJYYwhUtH@@@@@\ndcm@@@iJYeyravPhJH@@\ndcm@@@qJY~Ureujh@H@@\ndcm@@@uIe[UiiV@@@`@@\ndcm@@@uJYU_rnf`Pbh@@\ndcm@@@{IDeCDdUKh@UUB@@\ndcm@@@{IDeCEDUSh@UUD@@\ndcm@`LH@cIEDUDeeKmLp@P@@\ndcmB@DpNE\\bbbTRMBtmULmP@@\ndcmD@hxEChgiWdfYYungX@@H@@@\ndcmH`LJPBLdTTJTvTJtpAE@@@\ndcmh@HqagPRVVY^E]fjVjPbH\ndcn@@@RVUmVy]x@@@@@\ndcn@@@Re]eRi]@B@@@@\ndcn@@@RfV]zE]B@@@@@\ndcn@@@RfYW\\hUhFBJ@@\ndcn@@@rIQQJH|J{p@@@@@\ndcn@@@rQQQIXyPkPLDT@@\ndcn@PABPJPRYgUVy]``@@@@\ndcn@PBBPZPrJJJIP}J{@D@@@@\ndcn@PBBPvPRYe[VFU`@@H@@\ndcn@PIBPJPRYfuvE]``@@@@\ndcn@PNBHvHrJJIQGMtk@@@P@@\ndcn@PNBPVPRYeeVF]`@@`@@\ndcnD@D@TfUe^fWX@B@@@@\ndcnDABCbgnrJJIQPll{@A@@@@\ndcnH@AAIVYWXUvjP`H@@\ndcnH@BAIfUnZQV@@@`@@\ndcnH@HAIYVu[ev`@@@@@\ndcnH@NAIYeUkiviBBH@@\ndcnHAH@NbTfYYungX@@H@@@\ndcnH`DDHaIe[gkev@@`@@@\ndcnH`NtHaIfV]XYV@@@`@@\ndcnH`NtLQIfV]XYV@@@`@@\ndcnL@LAMRYUUrhYZh@h@@\ndcnL`LaA@HrRPjIKTrzmPHD@@\ndcnh@DkaTLbbTTRK\\nmHTA@@@\ndcnh@DkatDfVYengVjVjd@@\ndco@@@JdeYUUnW^fh@@@@\ndco@@@pdif]wJeVhHB`@@\ndco@`FePbDfUmVnFX@ajH@@\ndct@D@dBdFdNdAdIdEdMdDfYkjZjj`bH\ndctB@@I]rJJJIVMRuLDE@\ndctB@@PYRYU{ViijBBP\ndctB@@PYRYU{ViijBB`\ndctB@@PnR[kfVjjj@@\ndctD@@QIeUUZijhHj@\ndctD@@QImUUZjjh@@\ndctF@@IaWTfYn~jjj`@\ndctF@@rngTen{mjjj`@\ndctH@@RUUUZjjj@@\ndctHxJBPRPrPFPfPVPvPrJPqJQUUUT@@\ndctd@BE]ADf{UYjji`@\ndctl@BE]ANR[mUfjjf@@\ndcu@HLd@a@```PcHheDYhuUMP@@\ndcuD@LTIrQPiIQTuUL@@\ndcuDPBwaBPRPrJZSQEUUMT@@\ndcvDBAAAeIeUzZjjh@@\ndcvJ@BAIWTfuiUjjj`@\ndcvJ@LBngTen{mjjj`@\ndcwLaNWXS@|Eg^rRSIIHmUUJ@@\ndc~D@JCldRTTRLHp|J{PA@@P@@\ndeL@@Di[ernDYZjij@@\ndeL@@DjYeIjGijjjj@@\ndeLD@@eJUUXSaFZjjj`@\ndeT@@DjUYk``R`@@\ndeT@@DjWvifjih@@\ndeT@@DjYUXPbDP@@\ndeT@h@bBbFbAbIbDfYokjYjh@@\ndeTB@@IaRYf{aZfj`@\ndeTB@@KiRYg]nZej`@\ndeTD@@EIYWVy`@h@@\ndeTD@@EIfUVz@`h@@\ndeTD@@EIfUvz@`h@@\ndeTD@@EJYU^f```@@\ndeTD@@QIUeQej@@@@\ndeTD@@YIfUqehD@@@\ndeTD@@eIfWVyiff@@\ndeTD@@gHhhhjpmLtp@@\ndeTD@@iIYe^e```@@\ndeTD@@yIYVvE`BH@@\ndeTDPAdH`haIf]VzB@h@@\ndeTDPBDHbXaIf]VzeiZ@@\ndeTD`AdHaIe[jz@HX@@\ndeTD`AdHaIe]jZ@BX@@\ndeTD`NDHaIfVVfBA`@@\ndeTH@@RUYTYY`@@aH\ndeTH@@RUYTYi`@@aH\ndeTH@@RYVZfZZj`@\ndeTH@@rJJIHmtA@pD]@\ndeTH`IBHrJJJJlLADP@@\ndeTHpIBHJHZHrJJJX|LDPP@@\ndeTL@@FTfYW[ffZX@@\ndeTL@@FTf[eXVjjh@@\ndeTL@@KlbbbtK\\uKU@@\ndeTL@@Qdf]eFVjfd@@\ndeTL@@QdfygFV``@@@\ndeTL@@RTfyWxV`@`@@\ndeTLB@QdyInYqehH@@@\ndeTL`BjPkDf[W[jjjh@@\ndeU@@@[IHhXlLuA@@@@\ndeU@@@aJnUqfhH@@@\ndeU@@@aJueQfj@@@@\ndeU@@@gIHhTmpu@A@@@\ndeU@PBdHchaIf^VFBBH@@\ndeU@`Dp@aIgeQej@@@@\ndeUB@DpFFTfUgkfjYX@@\ndeUD@DdBRY[TYZ`@@@\ndeUD@DhBRY[TYZ`@@@\ndeUD@DxBRY[TYZ`@@@\ndeUD@FdDR[VTYZZV`cH\ndeUD@HDIRVUunfef`RKh\ndeUDAHDIFY{HeEDcptAA@@@\ndeUD`DpY@HRYf|fZjj`@\ndeUH@AdDee][j@B`@@\ndeUH@AdLbbRaUM@AT@@\ndeUH@DDDfyVzV`B@@@\ndeUH@HpDenUFYh@@Ha@\ndeUH@JdDie_xZB@`@@\ndeUHBDxNeIgeQej@@@@\ndeUL@DpFgHhdhUWMTuH@@\ndeV@@@RVUenh@J@@\ndeV@@@RYfUa`Hb@@\ndeV@@@RYyTYj`@@@\ndeV@@@rRJEK\\MP@P@@\ndeV@PNBHFHRYeYi``x@@\ndeV@`ABHRYVvf`@j@@\ndeV@`ABHRYWVf`@j@@\ndeV@`D@HRUYTYV`@@@\ndeV@`LADReyTYk`@@@\ndeVD@DCDenUFVh@@@@\ndeVD@FADfygFV``@@@\ndeVD@I@dfYw[hHB`@@\ndeVD@IADfyWxV`@`@@\ndeVD@LB\\bTTQU]TuT`@\ndeVD@N@dfY{[fiZh@@\ndeVD@NADfyUxVfjh@@\ndeVH@AAIfuneh@`@@\ndeVH@AAJYWnf```@@\ndeVH@BAIemQfk@@@@\ndeVH@DAIgeQej@@@@\ndeVH@FAIe[jz@Hh@@\ndeVH@FAIe[zz@Hh@@\ndeVH@HAIYVVz`@h@@\ndeVH@HAJUmQfj@@@@\ndeVH@IAIeYZYiZf@@\ndeVH@IAIe]ZZ@Bl@@\ndeVH@IAJYW~F``H@@\ndeVH@NAIe]jZ@Bh@@\ndeVH@NCIELeBpt@Q@@@\ndeVHPNHHbXaIf^VFBBH@@\ndeV``Dqad@aIeYzyiji@@\ndeVh@DkadDfV[[ffZh@@\ndeW@@@kdigvriZjh@@\ndeW@PH[`bDbDfueFZjZd@@\ndeWH@DJPRY[TYZ`@@@\ndeWH@DZPR[e_aZ@B@@\nded@@DiUUjjj@@\nded@H@RnbAbIbDjUUjjj@@\ndedB@@PYR[UYifXDrj@\ndedB@@PYR[UYjjX@@\ndedD@@QIeVVjjP@\ndedD@@QImUVjj`@\ndedD@@QInUvjj`@\ndedD@@iIUmVZj`aH\ndedH@@RUUUfihDRY@\ndedH@@RUUUfjhHR@\ndedHXDBHjPZPzPFPfPRYZZjjh@@\ndedJ@@IaeIf[zjj`@\ndedJ@@rneI[nvjj`@\nded`@@iiReUvjjh@@\nded`PDqi@HDHRYuYjjX@@\ndeddABxYAAf^R[kujjT@@\ndeddABxYAAf^R[mUjjT@@\ndee@HHxHaH`XbXaImUjjj`@\ndeeD@BdDR[mUjjh@@\ndeeD@BhIRUUUjZdHJ@\ndeeL@BdDEInufji`@\ndefB@BAAeInufji`@\ndefB@BANeInvvjf`@\ndefD`FFPBDiWnjjf@@\ndefD`FFPBDi]nijf@@\ndefJ@BAFFTfy^Zjf@@\ndefL@LAIRYuUjjh@@\ndeg@@@zTiUWjjj@@\ndet@@DjYUX^d@@@@@\ndet@@DjzYKaejjj`@\ndet`@@siRfUna[``ha@@\ndet`@@siRfUnnFP`bb@@\ndet``Dki@HRYYUnFVjVi@@\ndeu@@@[IEDhcSCH@@@@@\ndeu@@@kIEEDceCLaPD@@\ndeu@`Dp@aIeURhYfh@@@@\ndeu@`LH@cIEEBeeCML@D@@\ndeu`@@rfFTigmkadHHhP@\ndev@@@RYyULFZh@H@@\ndev@@@Re[TjFP@@@@@\ndev@@@RfUWJzZABH@@\ndev@@@rQQJHtpr@@@@@@\ndev@PL@HPHRYUTjFVj@@@@\ndev`@@raeJY{ZXYB@iH@@\ndevh@DJndDfVU[af@`hP@\ndevhADIadFf^R[fUnxVijY@@\ndew@@@pldTTJVTLmP@P@@\ndg\\B@@ESrJJIIIFMsSMSM@@\ndg\\B@@Q[R[VUmgVf@HhBL`\ndg\\B@@RSR[YVwEVh@bh@@\ndg\\B@@SSRY[W[FVh@Ih@@\ndg\\B@@i]RVYUuzVBBJh@@\ndg\\B@@kcrIQQQIGBkADQT@@\ndg\\B@@x{RYeewgV`hHh@@\ndg\\D@@cIMHhThYJuT@EP@@\ndg\\D@@eIfU_Un`HJj`@@\ndg\\D`ILIAIme[\\Uf`BJ`@@\ndg\\H@@RYvYiVvfijjBL`\ndg\\HpL@HcpPHRZUYwNvjhH@@@\ndg\\J@@PUMInUeWiZ@Hj`@@\ndg\\L@@H|bbbftbkBtsMUP@@\ndg\\L@@PdfVUZYmjBBh@@\ndg\\L@@k\\dTtRRLwSPPQT`@@\ndg\\L@@yTimYvfF`BJj@@\ndg\\L`HS@BLddJrTRQvmUP@@@@\ndg\\L`NNpbDfUuijZ@Bjf@@\ndg\\``Dpi@HrJJJIRiG[UT`@@@\ndg\\dPHP{YPlmlldabbrV`suKRwP@@\ndg\\d`LF[a@BLddJbbQvfmPLA@@@\ndg]B@HxEv|bTTRRTlgM@aQ@IBt@\ndg]B@NTBNtfY}[fyjVjf`@\ndg]BbInDp`BB{IICiEDUikUUMR@@\ndg]DPCmaBHJHRYf{uzYjYj}@@\ndg]HPAuPbBbDfYw[fzB@ij@@\ndg]H`AuPbDfY_[fz@`ij@@\ndg]L@DDBmIeye]SZjjjX@@\ndg]L`FM]l@cIEEideCeTsUKT@@\ndg]L`LVDL@cIIKDedhLkP@Tp@@\ndg]L`LnDD@cIIBhhd]ikTC@P@@\ndg^@pLCDDHWDRUeYWtzjjZi@@\ndg^B@BAMoHiieDeBimU@DP@@\ndg^D`EppbDenUuaff@Bf@@\ndg^D`NEPbDfUv{jZ@Bij@@\ndg^H@DCHhhhddYimTE@P@@\ndg^L@NAarJJZJUQ]KSUMU@@\ndg^h@BzSlDf^[WUvjiif`cT\ndg_B@DhpK[RY[U{FVh@Ih@@\ndglB@@Q]RYUumZjjZ`@\ndglD@@QImUUUjjjj@@\ndglD@@uIUUUmfYfj@dRVQP\ndglFPHkivpqLqDen{nzjjjh@@\ndglLpDp`BH|MBLbdRRRQSUUUT@@\ndgl`@@`fRefUWejjj`RIH\ndgl`@@z[ReU]Ujjjj`@\ndgm@hNdHR@a@a``PaJeynzjfZj@@\ndgmBPFE]NpQHQDiUf{jjjfX@@\ndgmL@DdAuInUg]jjZj@@\ndgmL`DVCl@cIICDmihmUUS@@\ndgm`PFy]NpBHBDiUUYjjjfX@@\ndgnD@KADfuUUVjjjh@@\ndgnD`H[`BLdTRbJRUUMUT@@\ndgnDpKXpbBBJBDfzUUijjjX@@\ndgnLPFe]CDpHRUVV[jjif`@\ndgnL`Fe]@HRevV[ijif`@\ndg|@@DjU_eZx{BAH@@BJ`\ndg|@@Dke]eVx{x@H@@@@\ndg|@P@bBbDfYweVx{``H@@@@\ndg|@P@bKbDfUvUz[S`@`@`@@\ndg|A@@cJz]mJ{n{nDpjjjjj`@\ndg|A@@rae]oIEEDieFpr]UUUUP@@\ndg|A@@rfE]oIEEhYiCBJ]UUUUP@@\ndg|B@@KSRYfuVXUmjP`X`@@\ndg|D@@MIfV]UivviP`R@@\ndg|D@@MIfV]UivxH@@`@@\ndg|D@@SHhmEDhcJg[T@@@@@@\ndg|D@@WHhheEhbtg\\D@D@@@@\ndg|D@@mIe]e^ftvefef`@\ndg|D@@mIe]e^ftx@H@H@@\ndg|F@@RaW\\bbTbfbi]WMUUMU@@\ndg|H@@RVUvU[cn`@`@@@@\ndg|H@@RVYYwySn``@@@@@\ndg|H@@RYfUWd}mh@@@@@@\ndg|H@@RfYU[GUn`@@H@@@\ndg|J@@RiWHheHmDTWUsUUMUP@@\ndg|L@@HtfYnUvG[ZdJAH@@\ndg|L@@Pdf{UeRh{Zjh@H@@\ndg|L@@t|bbbbbJcBmm@tCD@@\ndg|d@Dq]@\\bbbbfJSSimUSTs@@\ndg|h@DqnAIe[UTYNvjZ`@@@\ndg}@@@OIEEEDTmWSh@PDT@@@\ndg}@@@aJVYU^Svv`@@@@`H\ndg}@@@aJVYU^Svz`@@@@@\ndg}@@@aJnYU^Svz`@@@@@\ndg}@A@LINTjWvUz[SB@`@`@@\ndg}D@DTBrJISQJHrivu@@@@@@\ndg}D@DhBRY[VuFSmj@@@@@@\ndg}D@LHNRfueWXSn`BB@@@@\ndg}DPDp{@H`HRefUWd}njjjjh@@\ndg}DPFES@H`HRenUVrnFijifX@@\ndg}H@DdDfvUmQT{Z`@@@@@\ndg}H@DlDfyVu~GSZ@@@`@@\ndg}H@DxDf^YVyO[Z`@@@@@\ndg}H@IlLdTrTraS]Jt@EMQ@@\ndg}L`JXiTIAIf]VunNzVjZj`@\ndg}L`JXiTIAIf^vunNzVjZj`@\ndg~@`K@HRfYU_GUN`@@B@@@\ndg~D@DCDenUmQd{Z`@@@@@\ndg~D@EADfufUqT{ZZP`HBL`\ndg~H@DAIge[TYNvh@@@@@\ndg~J@DBaW\\bbTbfbi]WMUUMU@@\ndg~L@B@SRYfU]Z]mjPhD`@@\ndg\x7FD@L[`QIeyUTYNvjZ`@@@\ndg\x7FH@DpprJJJJKJmJfuUUUT@@\ndiD@`@RdjeVjj`@\ndiD@x@bLBBdJdFdNdAdDeZjjj`@\ndiDB@@PaR[UVjj@@\ndiDB@@QaR[VvjY@@\ndiDBB@QaSdfumjj`@\ndiDD@@IIUZYjhHR@\ndiDD@@qJYWjjX@@\ndiDH@@RUUVZjBD`\ndiDH@@RUUZjj@@\ndiDH@@RYWZjj@@\ndiDJHDpnDAbHbaahcIIJiIZe@@\ndiDL@@HTeUUffPQJh\ndiDL@@IdfWUij`@\ndiDL@@PTfuUifPSJh\ndiDL@@idiUVjj`@\ndiDL@@idiU^jj`@\ndiDNPHSB[a@XhXrRPzQZe`@\ndiDdAB[aANd^R[gVje@@\ndiDdAB[aANd^R[mVje@@\ndiED@BDDR[mVjj@@\ndiED@BXDR[mfjj@@\ndiED`Dka@HRU[fjf@@\ndiFB@BANEInvZjX@@\ndiFD@BADf{Ujj`@\ndiFD@BADf{Yjj`@\ndiFD@BADf{ejj`@\ndiFD@D@dfWUjj`@\ndiFD@LADf]Yjj`@\ndiFD`JxPBDivzji`@\ndiFD`JxPBLbdTljjX@@\ndiFD`JxPQDivzji`@\ndiFL@DBarJIQEjj`@\ndiFL@LAJRY{fjj@@\ndiF`@@SNGHhhcFjf@@\ndiFd@DpjDNrJJHqji`@\ndiGDAFxPSiGdf]UjiP@\ndiT@@DiUTjxVjih@@\ndiTH@@ReUxRfjef`@\ndiTH@@RfUXQajiV`@\ndiTH@@RfU|kahDB@@\ndiTL@@idfV^nxVfjh@@\ndiU@@@iJYWrnFP`H@@\ndiV@@@RfU|kadHB@@\ndiVH@BAIfUInFjZi@@\ndiVH@FAIfU[fFjjj@@\ndid@@DjUZnBAH@@\ndid@@DjU^nBAHBJ`\ndid@@DjUfaBB`@@\ndid@@DjWffB@h@@\ndid@@DjYUaBHP@@\ndid@@DjYmaBH`@@\ndid@@DjY}nBHH@@\ndid@@LdbRQk``R@@\ndid@@LdbRQk``b@@\ndid@@LdbbQxXF@@@\ndid@H@bBbFbAbDfYnnifj@@\ndid@p@bBbFbDfYoa`b@@@\ndidD@@EIYW[f@B@@\ndidD@@EIe]ih@J@@\ndidD@@EIfU[ffiP@\ndidD@@EIfU[hBB@@\ndidD@@GHhhdVyifX@@\ndidD@@IIf][hHB@@\ndidD@@QInUxV`@@@\ndidD@@iIYgxVB@@@\ndidD@@yIYVXV@H@@\ndidD`BDHaIf_[hHB@@\ndidD`BxHaIf^XZVfP@\ndidD`FDHcHhdhZzZVX@@\ndidH@@RUe^Fh@@@@\ndidH@@RYm^Eh@@@@\ndidH@@RYm^Fh@@@@\ndidH@@Rfu^FfiX@@\ndidHPBBHFHRYgVzB@`@@\ndidHPBBHFHRYgvzB@`@@\ndidH`ABHrJJIEn`HH@@\ndidH`NADRYWZZ@B`@@\ndidL@@HTfYun``H@@\ndidL@@IdfYnfZfj@@\ndidL@@IdfYoaZYf@@\ndidL@@IdfYoa`b@@@\ndidL@@KdfYynZej@@\ndidL@@QdfumnZZjBL`\ndidL@@XTfUfn`BH@@\ndidL@@`TiYeLjjj@@\ndidL@@rldTTqkjjj`@\ndidh@DKaAInV[fiZ`@\ndidh@DqaAIe[kffjP@\ndidh`DJaxHcHheCBjfid@@\ndie@@@EIYW[n@B@@\ndie@@@EIfW[hBB@@\ndie@@@GHhhdVz@``@@\ndie@@@aJvUxZ`@@@\ndie@@@aJyW[j@B@@\ndie@@@iJ[gxZB@@@\ndie@@@yIYVX^@H@@\ndie@`BDHaIf_[hHB@@\ndie@`FDHcHhdhZz@H`@@\ndieD@DpFrJIJFnZii@@\ndieD@JXDR[Y^EjZd@@\ndieDAHxAzQyIYW[j@B@@\ndieD`JXaBPRYgvzejX@@\ndieD`LIN@HRZufFZid@@\ndieH@DDDfyWaZ@@@@\ndieH@DXDfyWaZ@@@@\ndieH@HHDeYWaf@@BH`\ndie`@@pjX\\dTTUk`Hb@@\ndif@@@RUe^Fh@@@@\ndif@@@RUe^Gh@@@@\ndif@@@RYVzZ@B`@@\ndif@@@RYevz@``@@\ndif@@@RYfVF@b@@@\ndif@@@RfU~F``@@@\ndif@@@RfWzXBB`@@\ndif@@@rRJEKaj@@@@\ndif@PABHJHRYgVzB@`@@\ndif@PBBHFHRYgVzB@`@@\ndif@PBBPFPRYgVzB@`@@\ndif@`ABHRYevz@``@@\ndif@`ABPRYVzZ@B`@@\ndif@`ACDRYVzZ@B`@@\ndif@`BBHRYgfzB@`@@\ndif@`D@HRUe^EX@@@@\ndif@`FBHrJIJFn`BH@@\ndif@`L@HRf_\\jjjh@@\ndif@`L@HRf_ljjjh@@\ndifD@BADfyWaZ@@@@\ndifD@BADfyWaZjj@@\ndifD@BADfzwaZjj@@\ndifD@DCdfYTfZiZ@@\ndifD@FADfW[aZjj@@\ndifD@J@TiWTjjjj@@\ndifH@AAIfuxV`@@@\ndifH@AAJ[W[j@B@@\ndifH@BAIfuxV`@@@\ndifH@DAIVUxU`@@@\ndifH@DAIVUxUjj`@\ndifH@DAInUxV`@@@\ndifH@FAIfuxV`@@@\ndifH@HAIYV[j@B@@\ndifH@JAIYekjZf`@\ndifH@JAIYgxZB@@@\ndifH@JAJ[gxZB@@@\ndifH@NAIYVXZ@H@@\ndifH@NAIe]ih@J@@\ndifH@NAJ[VXZ@H@@\ndifL@BANR[efEjjh@@\ndig@@@HTfYun``H@@\ndig@@@h\\dTRQriZj`@\ndig@@@idiggJejj@@\ndig@@@kdigwJejj@@\ndig@@@xTjU^njjj@@\ndig@`D[`bDfUff`@h@@\ndig@`Hi`bDeVWajfi@@\ndigD@DpP[HhdhZyjfd@@\ndigH@DK`R[e^Eh@@@@\ndigH@LxPRVUfz`@`@@\ndigH`BiaBPrJJIEniZf@@\ndkL@`@BDeUUUjjjj@@\ndkLB`HSBCprRSEQIYjjjh@@\ndkLD@@iIUmUVZjj`aH\ndkLF`DkaTpBLbdtVafjjji@@\ndkLH@@ReUUVjjjh@@\ndkLJ@@imMJUUUZjjj`@\ndkLLHLi`bB|MbCbDeVUUjjjj@@\ndkLL`HS@|DjUYfjjjj@@\ndkLP@@anF]OIDhhjeIjYi`RKh\ndkLd@BgSADf{UVZjjf@@\ndkLdABWSAMd~rJZYRHijjjT@@\ndkML@DdAuInUgVjij`@\ndkND@D@dfWUUZjjj@@\ndkNF@BAIWSR[YVYjjfX@@\ndkNH@DAIeuUVjjj`@\ndkNJ`EaLdp|LddrQTrZjij@@\ndkN`@@imMJUUUZjjj`@\ndk\\@@LdbbbRuZQT@B@d@@\ndk\\@`@bDfUvUimN@B@@@@\ndk\\@`@bDfYYwZ]NB@@@@@\ndk\\@`@dDfUnukmN@H@@@@\ndk\\@`@dDfUvUimN@B@@@@\ndk\\@`@dDfYYwZ]NB@@@@@\ndk\\@`@qDfYYwZ]NB@@@@@\ndk\\B@@P]RYVyznTviBBH@@\ndk\\D@@wHhhhhbfESZAhD`@@\ndk\\D`ALHaIe[UzZU`@iiH@@\ndk\\H@@RYeg]itxH@@@@@\ndk\\H@@RZYZ\\SgZifjf@@\ndk\\L@@KTfYmUXUMjP`R@@\ndk\\L@@X|bbbbTa[nEijjf`@\ndk\\L@@htie]urnF``Ij@bX\ndk\\L@@htie]urnF``JZ@aX\ndk\\L@@iTie]{rnF``Jf@@\ndk\\LPDp`BH|LbdRRaRX]Mjj@B@@\ndk\\`@@iSRfYyUnEPJBja@@\ndk\\`@@j]RfYuUnFPJAjb@@\ndk\\`@@kSrQQQSQEngPJBja@@\ndk\\`@@p]rQQJJIFiXP`jJa@@\ndk\\`@@y]RVUmUae^@HZb@@\ndk\\`@@{SRVUnUag^@Hja@@\ndk\\d@Dq]@\\bbbbfJZ]MjjZe`@\ndk\\d@DrUCdfY[uXUujijY`@\ndk\\d@DsmB\\bbbTrQXUujjUj`@\ndk\\d@LHYCdimY^X]N`BJh`@\ndk\\h@DrfAIgeU^GSZfh@@@@\ndk]@@@iJYez\\hSdJBh`@@\ndk]@@@qJYweZ[SB@`@@@@\ndk]@pAt@a@``aIeoeRkSZf`@`@@\ndk]D@DhBRY[UWatvjZ@@@@\ndk]H@ALLbbRfTJiaf@Bfh`@\ndk]H@BtDfYmUXUMjP`R@@\ndk]H@DHDfYyWImMjhHA@@\ndk]H@DTLbTTRaR[mMjj@B@@\ndk]`PLJnTpBIBDiguermNfZijP@\ndk]h@HKiTpRYmfTYtz`HIb@@\ndk]h@HKiTpRgefTYtzZiZiBD`\ndk^@@@RYV{Vntx@`@@@@\ndk^@@@RYeg]itxH@@@@@\ndk^@@@ReUVZ]TziZ@@ABZP\ndk^@@@RfYU\\]Tz@@@@@@\ndk^@@@Ri_YVftzjX@H@@\ndk^@pFBPJPFPrJJJZIGitxHB@@@@\ndk^@pIBPJPvPRYfuUaTxH@B@@@\ndk^D@BADfyVux]Mh@@@@@\ndk^D@BCTfYmUXUMjP`R@@\ndk^D@E@dfYuY[eNB@jh`@\ndk^D@IADfvYWz]MjdHB@@\ndk^D@MBdie]vrnF``Jj@@\ndk^H@DAIVUm^GSV@@@@@@\ndk^HPJHJqjqIf[u^GS`b@@@@@\ndk^HPNHJrXaIf^UvGS``B@@@@\ndk^HPNHLR\\QIf^UvGS``B@@@@\ndk^H`BPHaInUm^GSj@@@@@@\ndk^d@DkaTCrJIQQHynWVjVZZ@@\ndk^d@LzULDRZUnTYtvjiZi@@\ndk^h@DkatLbbTTTU[iujejjP@\ndk_@@@Y\\daRRRTaMNjjjj`@\ndk_@@@pdif]uriUjB@j@@\ndk_@@@pldTTtRJrmMjfjU`@\ndk_@@@x|dTTTRJkit@HBH@@\ndk_H@NWPRfumUaeZ@HZb@@\ndklB@@F]RYe]ynZYif`@\ndklB@@P]R[e[_iZ@Hj@@\ndklB@@QSrJYJIJF]ZX@b@cH\ndklB@@QmR[fUxUZBBF@@\ndklB@@RURYYV|jZfij`@\ndklB@@SSR[VUVUZZfjPcH\ndklD@@QIe]URijjjj@@\ndklD@@QIe]e]Mjz@@@@\ndklD@@QIgfU}MjhD@@@\ndklD@@[Hhdhbdjz@Hjh@@\ndklD@@eJ[Vvfz`@jh@@\ndklD@@kIEMDdbnf``bd@@\ndklD`AtIAIVUm~fh@bh@@\ndklF@@PittfzugEVjjjh@@\ndklL@@PtfyWUxV`@j`@@\ndkl`@@kaRe[vTf@HZj@ah\ndkm@`MLHcHhhdcDfz@`Z|@@\ndkmD@DHCRYvUvUZh@J@@\ndkmD@DTCRUfWtYV@`e@@\ndkmD@DdCrIJJIPxUV@bE@@\ndkmH`FVPbDfUonkh@bZ`@@\ndkmH`NVPbDfUunih@JZ`@@\ndkmL@DpAuIfYeVejjZZ@@\ndkmL@DpIOHhhdddVyjiVfBN`\ndkn@@@RYfVya`Hbj@@\ndkn@pLCDDHWDRUeYWSjjijP@\ndknD@BADfyWUxV`@j`@@\ndknD@D@tf^UeFVh@J`@@\ndknD@D@|bbtTTUgVhBH`@@\ndknD@LALbbRbaRtvjh@@@@\ndknDPAWPbFbLbbRbJfkh@bf`@@\ndknD`ItpdDfUunih@Ji`@@\ndknD`ItpdLbbRaTtih@Ji`@@\ndknD`ItpdLbbbRLt[hBBi`@@\ndknH`It@aJYWunF``JX@@\ndknL@BACR[me]]Zj@B@@\ndknL@D@SRUVYu]ZXHB@cH\ndknL@D@]R[e[_iZ@Hj@@\ndknL@FASrJJIIJT]ZBBb@@\ndknL@M@iRYg^un``Jj@@\ndkoD@DJPwHheLeCAej@BX@@\ndkoH@DHpRYYUfSZ``h@@\ndk|@`@BLdTRbtQJagShD@@`@@\ndk|D@@QIeeUrYngVjijjP@\ndk|H@@RYegYngUN@@BHH@@\ndk|H@@RfYU_JGUN`@@B@@@\ndk}@@@iJUmUR[atpBJ@@@@\ndk~@@@RYkUdUgYNjjjjh@@\ndk~@@@RfYU_JGUN`@@B@@@\ndk\x7F@@@p\\dTRbfQjVGSBBheF@@\ndmL@@DjYUVGi@@@`@@\ndmL@@DjYeVdU@@`@@@\ndmL@`@bLbbbTQ[iV@@@@@@\ndmLB@@IerJJJZEnxVijf`@\ndmLB@@RURYUVJaejVjh@@\ndmLD@@QIe[VfeVi@B@@\ndmLD@@UJYWwJxZA@j@@\ndmLH@@RYVuiiV@@@@@@\ndmLH@@RYiYKnUjjjh@@\ndmLH@@RYiYKnVjjjh@@\ndmLH@@RffeZVVjjjh@@\ndmLH@@Rge[aNFh@JP@@\ndmLH@@rJJIQEneX@@@@@\ndmLL@@yTee[VFUX@bb@@\ndmL`@@pURfV[jVDHJbD@@\ndmL`@@siRfUmhVxHFJH@@\ndmL``Dke@HRYYeXYUjfVh@@\ndmLd@Dqe@TfUeZzUZZeZ@@\ndmLh@DkeAIefUaeVjYZ`@\ndmM@@@UJYY~nFP@@H@@\ndmM@@@eJYY^fEP@@`@@\ndmM@@@iJYewJEYB`b@@\ndmM@@@qJYm^neP`@@@@\ndmM@@@{IDeCDbjU@Bjb@@\ndmM@@@{IEEEEZzU@B@@@@\ndmMB@DpNETfYYZEiZjYZ@@\ndmMH@DHDfVUzzUZ`PH@@\ndmMHAHx@zIrJJIQEneX@@@@@\ndmMh@DkaePRYYe[iUifjd@@\ndmN@@@RYVuiiV@@@@@@\ndmN@@@RfVWiaT@@H@@@\ndmN@@@RfV]iaT@@H@@@\ndmN@@@RfV^kad@@B@@@\ndmN@@@RfV_kad@@B@@@\ndmN@@@RfWUiiTB@@@@@\ndmN@@@RfYWraV`XH`@@\ndmN@@@rQQJJFfEP@@`@@\ndmN@@@rQQQQVneP@`@@@\ndmN@`BBHRYe[ZQV@@@@@@\ndmN@`BBPRYUUiiV@@@@@@\ndmN@`BBPRYe[ZQV@@@@@@\ndmN@`DBHRYVuiiV@@@@@@\ndmN@`FBPRYVukiV@@@@@@\ndmN@`NBPRYegXYV@@@@@@\ndmN@`NBPrJJIQEneX@@@@@\ndmN@pN@H`HPHrRPqIZneUhDB@@\ndmND@BA\\bbbReInFjZjd@@\ndmNH@BAIfUmiEX@@@@@\ndmNH@DAIe[VfeX@@@@@\ndmNH@FAIe[VneX@@@@@\ndmNH@NAIYe^neZdHB@@\ndmNH@NAIfV]aeX@@@@@\ndmNH@NCHhheDVzU`@@@@@\ndmNHAH@Nb\\bbbTQ[iV@@@@@@\ndmN``DkaT@aIefUneVjVjP@\ndmNd@DqiTARYVUkiUijUh@@\ndmNh@DkaTDfVYVzUZiZi@@\ndmO@@@pdif]|jUZ``H@@\ndmT@p@AHbDbLddJRRjjj`@\ndmT@p@bBBEbDeYyzjjh@@\ndmTB`HSBCpRjuUZjj`@\ndmTD@@QIeU]jjZ@@\ndmTD@@iIUmUfjjBD`\ndmTDPDpOBICIHUHiIjjh@@\ndmTD`HdDiJiUZjjf@@\ndmTH@@RUgVYjf`aD\ndmTH@@rJQHiRjZZ@@\ndmU@HLT@a@c`bPaIggYjjf@@\ndmU@pLD@a@c`cHheEKFjfh@@\ndmUL`LZiT@aI[mZjZf@@\ndmVD@D@dfWUVjjh@@\ndmVDbNp`qNeI[Ujfjj@@\ndmVL@LAERYuUZjj`@\ndmWLaNeXS@|Ie^Rju_ZjiP@\ndmlH@@RfVvaFGajjjj`@\ndmn@@@RZUYX^gejjjj`@\ndmnH@JAJUe^D[iV`@@@@@\ndmt@H@bAdIdEdDfUvjZ@Bj@@\ndmt@h@bJbNbIbEbDfV[vFZjj`@\ndmtB@@PUrJZIJGiZ@H`@@\ndmtB@@QeR[f]FV``H@@\ndmtD@@QIe]TjZjjh@@\ndmtD@@QIgYVUZh@@@@\ndmtD@@UIfuwaZ@B`@@\ndmtD@@WHhidh^Eh@J@@\ndmtD@@aJye[ahBB`@@\ndmtD@@iJ[g_ahHBP@@\ndmtDPAdH`haIf]Un``J`@@\ndmtDPBTHbXaIf^un``JP@@\ndmtDPITICiAIfVYa`Ha`@@\ndmtDPNDHaXcHhheEVfBAb@@\ndmtH@@RVUv[fZjZ@@\ndmtH@@RVUv[jZjZ@@\ndmtH@@RYWZih@Jh@@\ndmtH@@RYeY[hBBh@@\ndmtH@@RYe[[hBBh@@\ndmtH@@RYeeZVjjj@@\ndmtH@@RYeeZZjjj@@\ndmtH@@RYe~[ffjZ@@\ndmtH@@RYvUeVf@@BL`\ndmtH@@RZWv[jjjZ@@\ndmtH@@Rfuu[j@BXBA`\ndmtH@@Rfuu[j@Bd@@\ndmtH@@Rfuu[j@Bh@@\ndmtH@@rIQQQWiXBH`@@\ndmtHPNBHHHRUUeeZjii@@\ndmtH`IBHRUe]xY`@hBH`\ndmtH`JBHRYVueYi@@BHP\ndmtL@@ETfYUVyifi`@\ndmtL@@F\\bbfbQXVjjj@@\ndmtL@@QTfyW^Eh@I@@\ndmtL@@QTfyW^Eh@J@@\ndmtL@@QdfygQehHB@@\ndmtL@@SdfVyyUjB@@@\ndmtL@@yTee[VE`BJ@@\ndmu@@@GHhhhhvf@bb@@\ndmu@@@aJyyVUjh@@@@\ndmuB@DpAeTfUejyjiV`@\ndmuB@DpFFTfUgjyjfj`@\ndmuB@DpFe\\bbRaRkfjZi@@\ndmuD@ITDR[e]xV`@h@@\ndmuDAHDEFU{HeEDh^F`HJ@@\ndmuDPHhfBHFHRYf~kjfZj@@\ndmuD`LVD@HrRRqIXYV`@`@@\ndmuD`NEeCDRUf_FYiZfBH`\ndmuH@DHDf]eYUj`@@@\ndmuH@DTDf^Uqej@B@@\ndmuH@DpDfUmYUj`@@@\ndmuH`BhPbDfUmzZZZ[`@\ndmuH`BhPdDfUmzZZZ[`@\ndmuH`BhPkDfUmzZZZ[`@\ndmuH`BhPqDfUmzZZZ[`@\ndmuH`NVPbDfUujZ@Bf@@\ndmuL@DpByIf]zfZjZh@@\ndmuL`DxiTHaIevxjfjih@@\ndmv@@@RYfVXXBHh@@\ndmv@@@RYfWXXBHh@@\ndmv@@@rJQFIJUjh@@@@\ndmv@@@rRJIIFUjB`@@@\ndmv@HDBHFPfPVPRYWZih@Jh@@\ndmv@`D@HRUVUeUj@@@@\ndmv@pEBPRPrPrJPqIXYj`@`@@\ndmvD@DATf^Uqej@B@@\ndmvD@DATfvUqej@B@@\ndmvD@DCdf^YyUjB@@@\ndmvD@EADfvUqej@B@@\ndmvDPBS@BHBLddjbReUjjj@@\ndmvD`La@BLddlRVFUh@H@@\ndmvD`La@BLddlTReUhB@@@\ndmvD`NePBDig{ljfZf`@\ndmvH@DAIgfVUZ`H@@@\ndmvH@FAIe[Vn`BJ`@@\ndmvH@FCHhhhdYUhJ@@@\ndmvH@IAIeYVfZVih@@\ndmvH`NdHaIe]Zf`@i`@@\ndmvL`IaL@HrRRqIPUV`B@@@\ndmw@`Dp`BDf]eYUj`@@@\ndmwD@ByPQInvVUZjeh@@\ndmwH@Dp`RYvUeVj@@@@\ndnDH@@ReVDijiZ@@\ndnDH@@ReVDijij@@\ndnDH@@ReVDijji@@\ndnDH@@ReVDijjj@@\ndndD@@iJUhPfijjj`@\ndo\\BPHP{@HtHrRPzIKJQZjje`@\ndo\\F@@Savtf^UVYjjjY`@\ndo\\NPHQevw@DHDrRYJKJHqjfii`@\ndo]B@L\\Dv|bbtTTUTZjjjX@@\ndo]LpN_JXH`o@xaIUkUWjfjjh@@\ndo^B@NAK]ImgV^ZjjjX@@\ndo^D@D@dfWUUUjjjj`@\ndo^J`CaLKP|LddqbbTlZijfhHi@\ndo^LpGZ[BHHHhHrJZQIIHrZjji`@\ndo^LpNWSCDpHJPRV]efyjjfZBH`\ndo|D@@QIgfUYuvj``h@@\ndo|D@@QIn[WVeVj@Bj@@\ndo|J@@S[_HheDdeDYMjBBb`@@\ndo|L@@RtfUVuwSZjp@h@@\ndo|L@@RtfvYWwSZjA@h@@\ndo|L@@iTinU]_ihHHjXBCP\ndo|L@@iTinU]_ihHHjXBC`\ndo|L@@kldTtTRQrEZBHbi@@\ndo|LPDp`BH|LbdRRbRQmvjhJ@@@\ndo}D@DTIrJZQQQIVwZjAh@@@\ndo}DPAuSBHJHRYg]nVzB@ij`@@\ndo}D`ILmBHrJJIIESQa``bfh@@\ndo}H@DHLbbTbjbRmvjj`@@@\ndo}H@DpLbbbLRVTWVj`@j@@\ndo}L`LvDl@cIIBidleIUZ`@i`@@\ndo~B@BAC_HiiMhdh]mjj@H`@@\ndo~B@BAK]InVuf[fjjif`@\ndo~B@I@moHhhdddcFEjVjYh@@\ndo~B@JAC_HheBhdh]mjj@H`@@\ndo~D@DAlbbbRQbRmvjj`@@@\ndo~D`MNpqLbbbRLRa[hBAkZ@cd\ndo~J`IaLNpaLddlRTrTEVh@bf@@\ndo~J`LXUMpBLdTVafffrjjjjj`@\ndo~L@LANRYye[iujBBJ`@@\ndo\x7FD@Lk`QIgff{yVjZjjP@\ndo\x7FH@DxPRYYe}ZyiZjjh@@\neFA@lhbL@\neFAAD`bJ@\neFAADhbL@\neFABDhbL@\neFABHhbL@\neFACDlRL@\neFB@Hc@@\neFB@Jc@@\neFBBHc@@\neFBBlc@@\neFBCDc@@\neFDBb`@\neFDBc@@\neFHBL@\neFJHaHh@\neFJHbHh@\neFJhUKhh@\neFPBc@@\neF`BL@\neFbHbHp@\neM@H~@\neM@ghz@\neMA@HPaIT@\neMABD`bM`@\neMABlZqIh@\neMACD\\QIh@\neMB@Jch@\neMBBHRZ@\neMBBPRY@\neMBBlRZ@\neMDARV@\neMFI@bMP@\neMHAIX@\neMHAIh@\neMJHaHv@\neMLRRWhv@\neMPBch@\neM`BN`@\neMhDRV@\neMhHRY@\neMhHRZ@\neMhHch@\neMpBXv@\neO@Hyj@\neOBBHcfh@\neOBCDcfh@\neOHBNZ`@\neOPBcfX@\neO`BNZ`@\nfH`T@@\nfH`X@@\nfH`p@@\nfHap@@\nfHbT@@\nfHbh@@\nfHc`@@\nfHcp@@\nfHdH@@\nfHdP@@\nfHdT@@\nfHd`@@\nfHe@@@\nfHf@@@\nfHfp@@\nfHg`@@\nfHgp@@\nfHpXT@\nfHppT@\nfHpp\\@\nfHppt@\nfHrpT@\nfHtHh@\nfHt`x@\nfI@@\nf`a@`@@FrJJIJQJrLxtsUSU@@@\nf`a@`@@ZrJJJQIPfJltEPTT@@@\nf`aA@@@YEEEEETdfB`Hbjj@@@\nf`aAb@NFlBHrJIKIRJUTY@AUST@@@\nf`aAc@DXH@HaxNBLbdRRaRfvcMUP@U@@@\nf`aIB@DXHYp@aIgVUueZZf@Bf@PI@\nf`aPP@B\\@bwlbfdRLRTIgMUT@Q@@@\nf`aQB@NJdBHRYWVyncH@JZjp@@\nf`aQC@IVLBPQHXdLbdLRTvf`eUPADu@@@\nf`a`R@NBT{pHaIe]nujL`@jZf@@@\nf`a`b@KRTCDRVUvuYgJ@BZj`@@\nf`a`b@KRTCDrIQISPiJLEPACUT@@@\nf`a`r@MPQ`ag@|LddqTTRbNkMU@QC@@@\nf`aaB@NRADYEDediiDZL`@ijj@@@\nf`aaP@I@QPQlbbTabaaeNMUSUUP@@\nf`aa`@D@IqInvuURTZjZff`HUV`\nf`axB@DXIhso@BDf]e]VdijZVZZ@`dj@\nf`i@@@DjYeW_YHRg^@@`B@@@@\nf`i@@@DjYeeoyHQm^@@@@h@@@\nf`i@@@LdbbbRVQSEBd{p@DA@@@@@\nf`i@@@LdbbbTRISIBt{p@DD@@@@@\nf`i@@@LdbbbbbRkEB\\[p@@PD@@@@\nf`i@@@LdbbbbbSwEBlYp@@P@P@@@\nf`i@@@LdbbbbbT_EBl[p@@PA@@@@\nf`i@@@LdbbbbbrKEBl[p@@PA@@@@\nf`i@P@@HD[HhdihdhUSbkN|uHPTUB@@\nf`i@P@@HTYIe[VUZLeiwfi@HjhP@@\nf`i@`@@BrJJJJJIXlUiuoP@D@@@@@@\nf`i@`@@DRYfyU]`mNmyi`@@B@@@\nf`i@`@@DRYfyU]`mNmzB@@@@@@@\nf`i@`@@LRYfYuw`eV]zhJ`@@@@@\nf`i@`@@VRYfYU]`eNMyh@`AB@@@\nf`iA@@@YHhhheLUfBdYwjBb@@H@@@\nf`iH@@@RM[IEDhmBdeS`eZL@@DMTD@@\nf`iH@@@RM[IEDhmBdmS`eZL@@DMTD@@\nf`iH@@@RlyJYY{WZ\\Dhu`@@bZ``@@\nf`iH@@@Rl{IEDhmCDcS`eZl@@DUTB@@\nf`iH@@@TUkIEEEhdd\\s`eV\\APUTlL@@\nf`iH@@@XDiJYYe_jRXHs``jJYa`@@\nf`iH@@@XDkIEDhhdmcRSAF\\DEQSLL@@\nf`iH@@@\\myJYfUuZ\\d[S`@@@H`@@@\nf`iH@@@\\myJYfUuz\\d[S`@@@H`@@@\nf`iH@@@\\m{IEEEDedkSdcZ\\@@@AD@@@\nf`iI@@DJlxBSJvmjtYKQkMR@PuQ@@@\nf`iI@@HXIXBRsKkZtxkSoSUP@@@@aA@\nf`iI@@H\\EhFQJJIPiIKdeZ]z`HajTh@@\nf`iP@@@NRifyWU`eVMzjPZBbP@@\nf`iP@@@VRifyWm`eNMzjPZBbP@@\nf`iP@@@^RifyW}`eVLzjPZBJP@@\nf`iPB@LD@DYHhbhheD\\TtYwjY`@@H@@@\nf`iPBDK^@D@eJYfUuZ\\d[S`@@@H`@@@\nf`iP`@BJ@aInUUm^BUiwfjjh@F@@@\nf`iP`@BR@IIf]UUV\\UiwfiZZ@H@@@\nf`iP`@B\\@aInVUuQRUiwfjij@H@@@\nf`iP`@FB@QIf[eU~Rtzwff@@@H@@@\nf`iQ@DK^@BTifYWUirQmN@@@@b@@@\nf`i`@@@IKLlj{pRkN}p@@@@@@@\nf`i``@M@YdTTTTQaRyIQg^jBb@@P@@\nf`ih@@@LDYvRJIQPiIJcIJtX@@`ZhH@@\nf`ih@@@\\UYvRJJJJsIJgIZMX@HBJhH@@\nf`ih@@@\\eYvRJJJJUKJgEZMX@HHFhH@@\nf`ip@@@N}dbbbbRQrhJQmV@@@@J@@@\nf`ip@@@V|eLsJzmNRMip@@@DP@@@\nf`ip@@@XTeLwOvmNJt{pPQT@A@@@\nf`ip@@@XUdbbRRRaRiqVg^BBJ`@H@@\nf`ip@@@XdeLv{ZmNRUYpPQP@Q@@@\nf`ip@@@XdeLv{Z}NRUYpPQP@Q@@@\nf`ip@@@XheLwKkkNRT{pQAU@@@@@\nf`ip@@@XmdbbbTTqVXJQg^@H@@@@@@\nf`ipB@BBdBHRYeY_Y`nRlzBAJiXh@@\nf`iq@@BBdAIf]UUV\\UiwhH@@@@@@@\nf`iqB@HLEpBHeJkOrnBBd{uKSL@E@@@\nf`q@@`@QBhbtQzHRYegeudcN``@`b@@@\nf`q@A@@QGhaIe]fuzLlz@Bh@H@@@\nf`q@P@@HMyIgUe[]V]yjZ@Hh`PI@\nf`q@P@@HMyIgfU{]V]yjhDHh`@@\nf`q@P@@HTyIgUfUc^lyjZBB``PI@\nf`q@P@@HU{HhlhheEbhvkMULttr@@\nf`q@`@@LRYfWg^Qg^ZB`@@@@@\nf`q@`@@LrJIJHiQITx{t@QL@@@`J@\nf`q@`@@^rJIJEJIKTYYt@Dp@P@ar@\nf`q@`@@^rJJJJHpkTXkSPTPUT@@@\nf`q@a@JZADFbLbTTTtRROIN}TmPLA@@@\nf`qA@@@ILrj}jISoM@a@@@BEH\nf`qA@@@YDhhdmECJ\\UYfiVjZP@@\nf`qA@@@YDhhdmECJ\\UZfiVjZP@@\nf`qAB@C@bLbRbbbebpmV]TAECTP@@\nf`qAP@@De[vQQQSJJFTVcNZdJHbP@@\nf`qA`@@FmdbbdTUrRiIVjBh`jd@@\nf`qA`@@N|dsLjolcZlt@@@T@@@\nf`qAp@@HiIUgYEDhdeDUBLEIjfjjZ`@@\nf`qHB@DXIp@PdskKJzcN|uL@@@@HD`\nf`qHP@DXxHDg^rJIQSPiITyhsSUUUS@@@\nf`qH`@DLeXELbbTVRTQfcN|uMUUUP@@\nf`qH`@DXEXFdfYfWVYHufjjYZj@@\nf`qH`@DXUXAlbbbJRRfaJN|uUUSUP@@\nf`qH`@DXtX@lbbbbbQRSIF\\uUMULp@@\nf`qIB@DXIHP@aIgYfuyJ]yjZXHB@PI@\nf`qI`@DXEXBmYEEEEDldVRMYjjfVj`@@\nf`qP@@@PRkfUWvQmVj@@@J@@@\nf`qP@@@^RYWUe^cKN`@j@B@@@\nf`qP@@@^Rfuue]gKNh@J@B@@@\nf`qPA@NBAD^bDfUuYWhrsh@I`@`ACd@\nf`qPB@DX@DILwLjoiuoMUUUUT@@\nf`qP`@DBAKHheHdhbmPSoMUTa@P@@\nf`qP`@DXAqIfWnUrL]yjihHB@@@\nf`qQ@@FRAdTRTbdTLMYwfjjjjj@@\nf`qQB@G^`@HRkfUWvQmVZ@@@J@@@\nf`qQP@DX@ISoILrl{jsfcMUMMUT@@\nf`qQb@LD``P@cIICDhhlUrSoKUST@@@@\nf`q`P@L@PHrSJwJwJmhsUAAQQ@@@\nf`q`P@L@PZvQQISQIPiVg^ZhBBjH@@\nf`q``@D@EdTRdTTqVYIwfji``H@@\nf`q``@D@HdsOZvjmN|uT@@@@@@\nf`q`b@ILD@HrQQJJMQITX{uMTt@D@@@\nf`qa@@D@RYyeg^Qg^Z``@@@@@\nf`qa@@E@rQQIZYQF\\EjuA@TuQ@@@\nf`qaA@ODADRbLbbbRRaRsAV]AAD@D@@@\nf`qaP@D@hIVdfVfy{IrgFjjfjj@@\nf`qa`@L@PKHhdheEhchsoMTD@@@@@\nf`qa`@L@QqIgfUnyZTYjBBJh`@@\nf`qi`@DTxIPC^rJIQQJiILyISUKMUU@@@\nf`qi`@FRt{pDDR[mfUuVkNZjhDB`@@\nf`qp@@@Hpds\\rj~gV|uP@@@@@@\nf`qpP@DXxBQoYEDhihUDZBuYijjji`@@\nf`qpP@DXxBSoYEDhihTdjBtYijjji`@@\nf`qpa@LR}A@@`PQddaTTRRUtxuejBPha@@\nf`qq@@BBdAIf]ueV\\]zB@f@@@PE@\nf`qqa@FRUAE`AE@cIICDedeDJQgKTuMMR@@\nf`y@@@DjYeU\x7FYHRmF]x@B@D@H@@\nf`y@@@DjYegvYHQmNmx@@@BHA@@\nf`y@@@LdbbbbbfkEBMIuo@@@@@@@@@\nf`y@@@LdbbbbbfkEB]Jqo@@A@PA@@@\nf`y`@@@ISKJmmQ`cZ][p@@@@@@@@\nf`y`@@@ISKONwS`iZl{p@@@@@@@@\nf`y`@@@YHdhddhTbTeiQg^@@@@@@@@@\nf`~@`@@HR[UUUUjjjjh@@\nf`~@`@@TReWUUVjjjjh@@\nf`~@`@@XRfUv}ZjijihDFP\nf`~A@@@IJskNmSUMTtABGb@\nf`~A@@@ISjjjkSLsMTBbDbqDjP\nf`~AJ@HHpSdmV|CprRSESSSSMUUUT`@@\nf`~P@`LZ@DHBBAB`cHheDdiXduUTuT@@\nf`~PQ@FBUhu`AD@aJUYn{zjjfZ`@@\nf`~X@@@TYhwdiUUU]jjjjj@@\nf`~`J@NPQafcN|CprRRjYQQFMTuSS@@@\nf`~`b`KLLBHHDTBNA@`aIneUYYjjjZ`@@\nfbc@@@DjYeUU]VJEKQ`ybd@B@D@@B@@@\nfbc@@@DjYeUoUvRDkQoIcd@B@@@@B@@@\nfbc@@@DjYeU\x7FUVRDkQg^Sd@B@D@@B@@@\nfbc@@@DjYeeU_VZEJt_ICd@@@@`D@`@@\nfbc@@@DjYeeou~RD[W`qSd@@@B@P@`@@\nfbc@@@LdbbbTRrTroIBMks`ir@@@@Q@@H@@\nfbc@@@LdbbbTVraVSIBMkugIr@@@AP@@@@@\nfbc@@@LdbbbTVtRqSEBMjsoIr@@@@T@@H@@\nfbc@@@LdbbbbbVVrOEBlXKoIr@@D@B@@P@@\nfbc@@@LdbbbbbbQQsEBMKuhir@@@@@@@@@@\nfbc@@@LdbbbbbbQQsEBMKuhir@@@@QC@D@@\nfbc@@@LdbbbbbbcJwEB]Hu`ir@@@@@@@@@@\nfbc@@@LdbbbbbbcJwEB]Hu`ir@@@@DS@D@@\nfbc@@@LdbbbbbbcJwEB]Jq`ir@@DA@@A@@@\nfbcA@@@ILk\\l|{txhug^BgKRtBPBAQ@@@\nfbcA@@@ILsLjmwLDkqhnRGKP@@@@@@@@@\nfbcA@@@IRlrrk{pQSbgVBgM@@A@@@@@@@\nfbcP@@@JrQQJJZYIEITxKQkN|gH@@TUP@D@@@\nfbc`@@@IRlrrk{pQSbgVBgMT@A@@AP@@@\nfbc`@@@YHheDdihhTZLD[P[^Sd@@@@@@@@@@\nfbc`@@@YHheEMDXlijREhuoQSd@@@@@@@@@@\nfbeA`@@^rdrjljmkXKSUAAQT@ab@\nfbe`P@J@QjNQQJZZJJJYWrVjjAbJH@@\nfbe`a@KDtBlEVYEEDeDh]ddfR``hfzj`@@\nfbeaS@Lfl{rPPd@a@QddRTRRTTWTtFj`hFXf@@@\nfbepP@LZbAC`iLjmmnvjtuUMUTuP@@\nfbepb@BZ}IPHaIf]V_VUgHHBfjjh@@\nfbm@P@@BMGHhhhhhhm\\esRoNBt@PT@UP@@@\nfbm@P@@HD[HhdihdiddYSbk^BuHPTUMP`@@\nfbm@Q@NV\\DDPfHrJJIQPqIJFLUKT\\pPM@LQA@@@\nfbm@`@@HRYvYfUWTYrPyZh@@@H@@@@\nfbm@`@@YRYVvW[WhpThi`@ij`@b@@@\nfbm@a`FZADDbAQ@XaLQfHrJJJZIFYJK\\ehwhpQDT@QQ@@@\nfbm@a`FZADDbAQChbLQfHrJJJZIFZKP|ejpTpQDTDDQ@@@\nfbm@p@@JMxJ\\bbbbbbbRegAZb{KPADPLQ@@@\nfbm@p@@JmxJ\\bbbbbbTRacAZb{KPADDLQ@@@\nfbmAP@@BLENQQQQQQQYG[bm^]Eh@bHAJ`@@\nfbmAP@@BLGNQQQQQQQYGGbm^]Eh@bHAJ`@@\nfbmAP@@BUGNQQQQQQPeIG`mNBehIb@@b`@@\nfbmAP@@HCGNQQJIYJJKSDeEZBejjjjjjj@@\nfbmAP@@HeENQQJJJIKZIUgMNmyj@H@Bj`@@\nfbmAP@@JMxNQQQQQQQIRw`mQ\\eh@bHFB`@@\nfbmAP@@\\e{NQQQJJKFIKYgEFbehFH`HB`@@\nfbmAP@@\\e{NQQQJJKFIKYgEFbehJH`HB`@@\nfbmH@@@\\myJYfUu^zgIFtx@@@BJj@@@\nfbmH`@EVBdGlbbbbbbTRacAZb{KPADDLQ@@@\nfbmH`@JRUDBTin]UUU~Bt[pZB@@@Bh@@@\nfbmHp@J\\DhBC^SgHheEDjheEdsdeNBuRsUUUU@@@\nfbmIR@LLDiAoIr@HrJSJIHjIQY\\EIS`uUJuUUUP@@\nfbmPB@NA@DYHhhhddmcEJ\\e[Sj@H@`jj@@@\nfbmPB@NQ@DYHhhhddmbeJ\\e[Sj@H@`jj@@@\nfbmPBDK^@D@eJYfUu^zgIFtx@@@BJj@@@\nfbmPP@KA@kr\\bbbbbbTRacAZb{KPADDLQ@@@\nfbmPQ@ARMyNPQAHaIf]UyYugIJ\\FB@ijjjJ@@\nfbmPa@NVtx@PHHrQQQJIPjXiTD[r\\uK]S[@D@@@\nfbmPb@AJ|dDPdrmrljoSfgQs@DMPTBD@@@\nfbmQB@AJRBHRYVyV[WisShy`BFhJAB@@@\nfbmQB@EZBBHrJIJZIQQYHtxhr\\pACUAHA@@@\nfbmQ`@DX@sJSJmsJkyJNbEKUM@@@E@@@\nfbm`P@A@BgJSLsLoOsEZ}ZKPADABM@@@\nfbm``@A@BdsLsJk|qVoVbt@Q@PeP@@@\nfbmh@@@XIQRTsNj~rkNRtgHD@DU@@@@@\nfbmhR@DXyJroIrBPrJIQQJIYPyTDZs`sUMUUURp@@\nfbmi@@DTxIPLbbTTRqbRfSNRUxKUKM@AUP@@\nfbmiP@DTxIPC^SgHheEDjheEdsdeNBuRsUUUU@@@\nfbmiP@DTxIPMVSgHheEDbmDddsde^BuRsUUUU@@@\nfbmiP@DXXKPC^SgHhdheDYeEeSdmNBtuUUUUK@@@\nfbmiP@LF]EHIJugIEEEDdhjllRegAcUUUPHET@@@\nfbu@AP@QAHadPJHeDZbGQ@XaLQfHrJJJ[PrZJ[TyzMLuUULuP@@\nfbu@S@FZCDDPRH\\DILs\\}|r|dgLDQDuKTH@@\nfbu@`@@IRYV{eg^irNX@aj```@Py@\nfbu@`@@YRYWYeg_hrJVeffjef`@@\nfbu@b@AVADYEDeCMHiXdjLSf@Bji`@@@@\nfbu@b@AVADYEDeeMHiXdjLSf@Bji`@@@@\nfbu@b@AVADYEEDeKHiXdf\\Sf@`ji`@@@@\nfbuAP@@BtFNQQQQQJKGIISk^Z@HH@j`@@\nfbuAb`BJ\\BHxDRbHqFXcHhhmDiXhmDpPTpPQLDDP@@@\nfbuHP@DTtdCHyrJIJHqSSIQTxEKUMUUTsP@@\nfbuI`@DXtX@dyEEEEDbddUFRLyjjZjZfX@@\nfbuIp@DXyHBcV|gNQQJJIQYJGJ`gAZZjjjjj@@\nfbuPJ@CA`cANJ}dGaddfJbTQbbvejJVjjjjYf`@@\nfbuPb@GQxDDPdrnlkk]QakP@T@EMP@@@\nfbuPr@FVQSaoIAHIM\\w[KntDxMUUULuMP@@\nfbuPr@NBYhwdyAbIJsNk[NbdxLtmTuUUPHP`\nfbu`P@D`EGNQQQQQUJYJIb`iZjjjjfZ@@\nfbu`a@HLx@JpDYHheHiXddmgQBfje`@@B@@@\nfbuaP@L`pIUdifV^}}ZR|FjjjB@k`@@\nfbua`@D@uYIge]nyTTdyZ`@jh@@@@\nfbupb@IZCrpHaIe]YfWjcOA`@jjYZb@@\nfbupr@DDhJRgIrBHRYYymY_IRwiiijjjj`@@\nfby@`@@HR[UUUUUZjjfjj`PT`\nfby@`@@HR[UUUUUZjjjjj`@@\nfby@`@@YRUUUUUUjknknj`@@\nfbyA`@@LdeJl{jjkSUMLsU@haxjSKd\nfbyPH@BZ@bR`qSgHieDeDXdhhuUSUTs@@@\nfb}@@@DjYeeou~RD[Wdy@@@@`H@@@@\nfb}@@@DjYee\x7F]^RD[S`q@@@@@B`@@@\nfb}@@@LdbbbTRrJROEBMipT`@@@@DP@@@\nfb}@@@LdbbbbbRJvcCBTzHT`@A@@@P@@@\nfb}@@@LdbbbbbRVNSCBTzJ\\`@QDTB@P@@\nfb}@@@LdbbbbbRVNSCBTzJ\\`@QDTD@P@@\nfb}@@@LdbbbbbT^VgEBl[tT`@A@DTpD@@\nfb}@@@LdbbbbbT^VgEBl[tT`@A@DUPD@@\nfb}@@@LdbbbbbTqrOEBlXLT`@A@EEPB@@\nfb}@@@LdbbbbbqfvSMBlYr\\`@A@A@@@@@\nfb}@B@@RBSJwKON}NJMYr\\p@@@@P@@@@\nfb}@B@@RBSLl|{vkART{r\\p@@A@@@@@@\nfb}@B@@RBSLl}kvkART{r\\p@@A@@@@@@\nfb}@B@@RBSLsKoN{AJlxJ\\p@P@@@@@@@\nfb}@B@@RFQQISQJJZUJgEFmyNX@@@B@@@@@\nfb}@B@@RFQQQJIIQIKEgIF|ENX@@@H@@@@@\nfb}@B@@RFQQQJIIZJYEgIFmyNX@@@@H@@@@\nfb}@B@@RFQQQJJIJIIEgIVCfJX@@@B@@@@@\nfb}@B@@RFQQQJKPiIII`iJlzJX@@@@@H@@@\nfb}@B@@RFQQQJKPjJEI`iJmyNX@@@B@@@@@\nfb}@B@@XfQJJJJIIPy[bmNlENZ@@@@@@@@@\nfb}@B@@XfQJJJJJIJHgfc^\\fNZ@@@@@@@@@\nfb}@P@@HuYIeYUWUVcEF]yNViBBJ`B@@@\nfb}@P@@HuYIeYUWUVcEF]yNViBBJjjF@@\nfb}@`@@DRYfu{VuXIVg^Sei`P@@@`@@@\nfb}@`@@DrJJJZIQIIHlEksdqsA@@@@@@@@@\nfb}@`@@IRYe^um]HpTcVCEhH@@@J`@@@\nfb}@`@@LrJJJJHpiII\\dkSoIsTED@@@H@@@\nfb}@`@@LrJJJJHpiSI\\dkSoIsTED@@@H@@@\nfb}@`@@LrJJJJHpqJH|dhw`isTED@@@H@@@\nfb}@`@@LrJJJJHyISI\\dkSoIsTED@@@H@@@\nfb}@`@@LrJJJJHyJIK\\dkS`isTED@@@H@@@\nfb}@`@@LrJJJJJFHpi\\UjsoIrtCA@@@H@@@\nfb}@`@@LrJJJJJFHpi\\UjsoIs@D@@@@@@@@\nfb}@`@@LrJJJJKIIIH|Djw`isTEP@@@@@@@\nfb}@`@@QrJJJJIIQ[Rldiq`~Rt@@@@QP@@@\nfb}@`@@YRYVumUehrVkNBeijZfjjj`@@\nfb}@`@@YRYVum[ehrRkNBf@BjjjjJ`@@\nfb}@`@@YrJJQIFYIIKDyKUgQRuUTuPAT@@@\nfb}@`@@YrJJQIFYJYKDyIUgQRuUUU@AU@@@\nfb}A@@@IKLlrjk|Dip\\qSP@@PEAA@@@\nfb}A@@@ILrrkszlyHuoIs@@@@P@@@@@\nfb}A@@@ILrsvoZlEISoIrtDPD@@P@@@\nfb}A@@@ISZvmkZlxkSoQSP@@@AU@H@@\nfb}A@@@ISZvmkZlxkSoQSP@@@AU@P@@\nfb}A@@@IS\\lrr}|UjwlacP@@DAL@P@@\nfb}A@@@YDhhhhdeCenJtzpTyX@@@@@@@@@\nfb}A@@@YDhhhhdeCenJtzpTyh@@@@@@@@@\nfb}AP@@HeGNQQJJIQKIIVgIJlGrVi``@BJ`@@\nfb}A`@@^sdTTTTRRRTqXIScQBeh@`@HB@@@@\nfb}Ab@HHp@HrRRqQJKQYSRtZwhirm@@@@@@@@@\nfb}P`@FJ@yIfY^]oTcIFmyNV`hJI`B@@@\nfb}QB@I^DBHrJIKJSQQIHtYjw`is@AUTC@E@@@\nfb}Q`@EV@`rSJvlkjmFRt{r\\mR@A@@D@@@\nfb}`@@@ISLsJr{tdjqh~r@@@@AD@@@@\nfb}`@@@YHhhhhdddbj\\dxtPy@@@@`B@@@@\nfb}`@@@YHhhhhdhebZRUXt_I@@@@@``@@@\nfb}`@@@YHhhhhdhehZRUXt_Y@@@@@b@@@@\nfb}`@@@YHhhhheEDmZRTxrPy@@@@`H@@@@\nfb}`@@@YHhhhhecLej\\eXsdy@@@`@`@@@@\nfb}`B@I@qDefYe^}~RtzpTyh@@@@@@@@@\nfb}a@@A@RYVvWVuhrVg^Sf@@B@@@@@@@\nfb}a@@B@rJJIJZKQZHldKW`is@@@D@@@@@@\nfb}a@@I@RVYfU{wyKSkASe`@@@@@@@@@\nfb}a@@I@RVYfU{wyKSkASf`@@@@@@@@@\nfb}i@@DTxIPLbbTTRqbRfSNRUxJ\\mTlt@EUD@@\nfb}pB@ARlBHRYWYee}hpsk^Sf@Bjih@B@@@\nfde@@@DjYeew]daZCD@BBBH@@@@\nfde@P@@BLGHhhhhhhlcqVoNbt@QD@d@@@\nfde@P@@B\\EIfYfWgXkWkQZ@H`HR@@@\nfde@P@@B|EIfYfW^XkSkQZ@H`Ab@@@\nfde@P@@B}EIfYfW_XkSkAZ@H`AJ@@@\nfde@P@@HmEIeYVuuhqQkNZdHHfjH@@\nfde@P@@HuyIe[UWZhrRcVZd@JjjH@@\nfde@P@@J]{HhhhhhdeBpV`vbt@Q@LD@@@\nfde@P@@J]{HhhhhhdeBpV`vc@@A@T@@@@\nfde@P@@V}GHhhhhdddfpRgFBt@P@dT@@@\nfde@``ARADDb@qDXaIf]UUUYqVg^``Jh@h@@@\nfde@b@AZAHILkmmrmFBdFL@ETp@D@@@\nfdeAB`A@bBQCH`LQFHrJJJZEIII\\dkSoPQDT@T@@@\nfdeAB`E@bBQCH`LQFHrJJJZESII\\DkSoPQAP@TP@@\nfdeAC@A@bKQDXaIe]ke_hpRoA`@j``H`@@\nfdeA`@@BBdsLsJklUkuhm@DPDI@@@\nfdeA`@@DMdTTTtRRVLXKSk^ZXFBbjH@@\nfdeA`@@ZcdbbTRVTJVipRoAhHbH@J@@@\nfdeA`@@\\udTTRbVfaRYrQ`qZA`h@B@@@\nfdeH@@@\\mEJYfUuWirQmN@@@@bh@@@\nfdeH`@JZ|DBDfV]VUugEF]yjeifZj`@@\nfdeI@@DRUXFQQZJIPiIJVcVCEj@bFiR`@@\nfdeI@@DTYxBSOKKropQgAbuMT@@@@@@\nfdeI@@D\\tXBSOLkK{KRcAbuA@eTiP@@\nfdeI@@HXHHBRrr{lkQbmAcSU@D@@@@@\nfdeI@@HXIHBRsKj|kSbmAcMU@D@@@HPP\nfdeI@@JRUDBTwNjjkpVc^CPP@@@P@@@\nfdeI`@LZCDDeYHhhidhblbTM[pZjjhDBh@@\nfdeI`BLTEhDGZewIWNlkJ|DZLFMUMUUUU@aR@\nfdeP`@AN@EIfYfWgXkWkQZ@H`HR@@@\nfdeP`@E^@{HhhhhhdeBpV`vbt@Q@LD@@@\nfdeP`@E^@{HhhhhhdeBpV`vbuHSPME@@@\nfdeQ@@DXAdTTtTTRbqUXp_QZh@``A@@@\nfde``@A@BdsLsKslUiuhm@DPAI@@@\nfde`a@AZlBHYDYEDeDXhiij\\Lywh@bifjJ@@\nfde`b@H\\d@HRfYfWwQJMxLZjfZ``H@@\nfdea@@D@RYyVuUQRMXLVh@@@@@@@\nfdea`@D@DGHhhhieeLbrVkN|uPL@AP@@@\nfdea`@O@T{HhhhhhdeBpV`vbt@Q@LD@@@\nfdei@@JJMYpLbTTRbbQVwMBUxMAATDAB@@@\nfdei`@LZlFHIJrQQQQYQEYDhZw`uUUPHEP@@\nfdei`@LZlFHIJrQQQSIQEYDhZw`uUUPHEP@@\nfdep@@@NCdbbbbRVTqhJQm^@@@@hh@@@\nfdep@@@XMdbbTRRReRhHu`qBBbj@@`@@\nfdepA@BLBBlmVYEEEDhXXmNJd[tX@`@HH@@@\nfdepB@DXb@HrJIQIIHqIDhkPXsUAA@@@@@\nfdi@P@@Hl{HhehiheDT[sTuUSMPHD`\nfdi@S@HRMX@PkptDIUvnmZoAM@ASUT@@@\nfdiAP@@HtxJSOLkkMISTAATs@@@\nfdiPa@LR``@PHHrRPjJJKHyF\\mPLQEP@@\nfdiQ@@DT@drsMsJvbuTEDU@@@\nfdiQQ@LJ``ug@BM^FRRVIKIRIHTeh@Ijj@@@\nfdiQb@LR``P@cIIBhheedmjru@pQU@@@\nfdiQb@LR``P@cIIBhhhlcdYru@qDU@@@\nfdiY`@D\\Eiw`TbdloJskjuUT@EUP@@\nfdi`a@OJtCDMbIKJrwzsAT@QMUT@@@\nfdiqb@JLtRR`RFQQQYIPiIIgJVjVjj`@@\nfdiqc@DXipu`QBoCPQdTRbtQdrRIRZjjZjd@@\nfdm@@@LdbbRbaRRsA\\UKU`~b@@@@@@P@@@\nfdm@@@LdbbbbbfjSCBUIuoAb@@@@APA@@@\nfdq@P@@HMYIeUU{UZjjijh@@\nfdqPP@JV@bT\\bbTrTQRRSUUMUL``z@\nfdqPQ@FBUhu`AD@aJUYn{ujjjYjh@@\nfdu@@@DjYUUUU`nR\\GtP@@@@@@@@@\nfdu@@@DjYee]}daVuxLP`I@H@H@@@\nfdu@@@DjYee]}daZlGtP@@@@@@@@@\nfdu@@@DjYee]}faRlGtP@@@@@@@@@\nfdu@@@DjYee\x7F_daFtxLP@@@@@@@@@\nfdu@@@LdbbbTRerwIBMiw``@@@QT@`@@\nfdu@@@LdbbbTRerwIBMiw``@@@QTA@@@\nfdu@@@LdbbbTRrJwEBMipXp@PP@A@@@@\nfdu@@@LdbbbTVtjSEBMjpXa@RA@@P@@@\nfdu@@@LdbbbbbTUHeRlXOh`@@@@@@@@@\nfdu@@@LdbbbbbVVOEBlXOh`@A@EBA@@@\nfdu@A@@Q@XaIfV^]nXJRc^]F@@@@B@@@@\nfdu@A@@Q@XaIfV^^^XJVcN}F@@@@B@@@@\nfdu@A@@QBhcHhheDeDULpTmV|FL@@D@@@@@@\nfdu@B@@ABTsJk^wb`mJmzM@@@@DP@@@\nfdu@B@@ABTsJk^\x7Fb`mJmxM@@@@AP@@@\nfdu@B@@AFRJJJIIEYHeIFuXLZ@B@@@`@@@\nfdu@B@@AFRJJJIIQIDeIFtEtZ@@@@``@@@\nfdu@B@@AFRJJJIIQSDeIFtEtZ@@@@``@@@\nfdu@P@@HLGHheDdhidYJqk^bFKUUUUUUP@@\nfdu@`@@ARYegg[fBdhwgQZA@@hZA@@\nfdu@`@@ARYegggfBehsoQZA@@bZA@@\nfduA@@@IKJrkN{NJMipXt@A@@@P@@@\nfduA@@@IKLl{[oAJmhpXt@@E@@@@@@\nfduA@@@ILroZviFBdZpXmA@@@A@@@@\nfduA@@@YDhdhddhTf\\uXs`qh@@@@@@@@\nfduA@@@YEEDhmEhTjLehu`qZB@@@B@@@\nfduP@@@ARige[uVBeip_Qjjj`Pbh@@\nfduQ@@FRAdbbTJbRrRIQVcVCFiPHJ@H@@@\nfdu`@@@IRmjjviJBdZpX`@@@@@@@@@\nfdu`@@@IRmkZviJBdZpX`@@@@@@@@@\nfdu`@@@IRmrsziFRtZpX`@@@@@@@@@\nfdu`@@@YHheEMDXTjREhu`q@@@@@@@@@\nfdu`@@@YHheEMD\\djREhu`q@@@@@@@@@\nfdu`@@@YHheEhTddj\\EHu`q@@@@@@@@@\nfdu`@@@YHheEhTidj\\EHu`q@@@@@@@@@\nfdu`@@@YHhhhhdhbZRUXp_Q@@@@@@@@@\nfdu`@@@YHhhhhdhcjRTxp_QB@@`H@`@@\nfdu``@C@PdrmljmtYKUoAbuHAEUTT@@\nfdua@@E@RfVU]uZLEhu`qhJ@@@@@@@\nfdua`@E@QyIefUW]iqUcNCEj@@@JhD@@\nfduh@@@XUkrTs\\zsoSbcZ\\FHPQTa@E@@@\nfdy@P@@BtGHhhhheEcliuoM@DD@T@@@\nfdy@P@@HHkHheDdhcLeHpXmPPL@@@@@\nfdy@a@CVADQbLbbRrbbbQuF^C@ATC@P@@@\nfdy@c@OAAD\\BAABSJzlrsQchp@UA@p@@@\nfdyA`@@FcdTTTbbveVhsUf`jHbj`@@\nfdyAa@OAbBPUHYEEDhddYeFRMZB@B@i`@@\nfdyH@@@PL{IDhhddih]JvoM@@ADT@H@`\nfdyHQ@DDiIU`qADBBLbbTVbaTVQJF]MMMUUU@@@\nfdyIP@DXTx@cAbdsJslolyjsUSSUUTBDh\nfdyIP@DXxHDkAbdrs]k^txYsSUUUUL@@\nfdyIR@DDiHRkAbBHrJIQZJEQYDhYtttuUUT@@\nfdyP@@@HrJSQQUQIQ\\d{uTuT@EH@@\nfdyP@`ARADDbOQDXcHhhlleDeBsc`pPDpAD@HB`\nfdyPA@FN@DRBDiee\x7Ff\\R`qhJBHH@@@@\nfdyPP@LQ@bSdfUYiUmSkQZjBhJb@@@\nfdyPQ@LN``u`AF`cIICDmdiCEQg`kUUTmUP@@\nfdyP`@AR@EJ[WUe]Yqwj@Bh@J@@@\nfdyP`@NJ@aIeeU~UehLVhHD`@@DIP\nfdyPp@DX@IU`qrJJIJIIPyLxYsUSSUUT@@\nfdyPr@JLIIU`qAHILsjvskNF]RuSUUU@@@\nfdy``@F@PdwLk{JbTFKPPQP@@@@\nfdya@@D@RYyWUeQRCEj@Bh@@@@\nfdya@@D@rJJJFJIIKVCzKUT@@@@@@\nfdya`@I@UyIfUVyUEhLV``hjjH@@\nfdyaa@AZMXDPrHrJIJHqQRqTxYt@QTsTd@@\nfdyhP@AZlFHDDXdw]lrnfmxKUUTBAP@@\nfdyhR@AZlFLDXhCprRRiIQQIYFmxKUUTBAP@@\nfdypB@FR\\@HrQQHqQIIZXi[uLuAAEP@@\nfdypP@DT|@chyEDidhdeDQRlEj@@`X`@@\nfdypQ@FVcSao@dDRFQRZJZYQKF`gAjjjifZ`@@\nfdyp`@BRb@RSLzkrnsg`mRtt@E@HB`\nfdyp`@LLxABSKrjszJQgMTu@QT@@@\nfdypp@DXT@QgAbdsJslolyjsUSSUUTBDh\nfdypp@DXxBVkAbdrs]k^tDYsSUUUUL@@\nfdyppBDDDCbkAbR^]dTtRaTRbrXHsfiZjjjh@@\nfdyq`@LLxA@TfWe^UtTg^Zij`@i@@@\nfdyq`@LLxACdfWeUWTTcVZij@Jh@@@\nfdyqb@IFmcpPABT{JvnvIVcUPACTtP@@\nfdyqb@LFcA@`AFRREQQIJH{WcVVhIBhhP@@\nfd}@`@@AReYU[WhHirQmV}DLZ@`P@HBB@@\nfgA@@@DjYU_VByHu`@@@@@@@\nfgA@@@LdbbbTVKIBMjp@@@@@@@\nfgA@`@@\\RfYe_irQmVh@`@H@@@\nfgAAB@F@bDfUmUZ\\EHuh@b`@@@@\nfgAA`@@HLdrmlkQdmFluHADq@@@\nfgAA`@@HtdrmjkQdeFluH@UP`@@\nfgAH@@@RM[IEDhmBeS`eZL@@DMA@@@\nfgAH@@@XDYJYYmvdfBuXHJbYF@@\nfgAH@@@XDkIEDhhdkRSAFlDEQRc@@@\nfgAH@@@XhiJYmg]gAJMXH`jeF@@\nfgAP@@@LrQQJEIITxJQk@QE@@@@@\nfgAP@@@LrQQJJYPtdKQk@@@@@@@@\nfgAP@@@\\RfYe_irQmV@@@@@@@@\nfgAP@B@BAHirRJIJHkLUpQkAPP@A@@@\nfgAPB@LD@DISJ\x7FJdhsakTuT@E@@@\nfgAQ@@D\\@drjjkQ`iFm@AT@@@@@\nfgAQ@@F\\AdbbTJRRIPTcVjUj@H@@@\nfgA`@@@ISKJntXKQk@@@@@@@@\nfgA`@@@ISLrotyHvk@@@@@@@@\nfgA`@@@ITsZkdYHvkU@@@D@@@\nfgA`@@@YHheEMEZRDhu`@@@@@@@\nfgA`@@@YHheEhTj\\EHu`@@@@@@@\nfgA`B@N@BDifYWz\\d[Uj@H@B@@@\nfgAa@@K@RfYU_qPVeFh@@@h@@@\nfgAp@@@RMdbbTVaVipRmF@@BF``@@\nfgAp@@@XDeLzmkQ`iFlDAP@D@@@\nfgAp@@@XIdbbaRRRqPTcVZ`@@H@@@\nfgAp@@@XheLvnjs`iFlDPT@@@@@\nfgAp@@@XxeLzjkQ`iFlDAT@@@@@\nfgApB@LLx@HRevUUpPTcViYj@H@@@\nfha@P`BLxHDQSp}DAbDeUkUUZjZjjh@@\nfha@P`BLxHFISp}bAqDeUkUUZjZjjh@@\nfha@R@HHpPG`eUjjjjuUUUU@@@\nfha@s@DXHJR`ADOBgadTbRTbVQSUTuUT@@\nfhaA`@@HhdvvjjjuUUUU@@@\nfhaP`@DFAkHhdddeDTfjjijh@@\nfhaPq@BA`cAg^@DVBLddNRRRRdVjjje`@@\nfhaYA@DXHKPY@BOABSNrrzsTtuULAAKd@\nfhe@@@DjYfYuvJEXpW^@@B@I@H@@\nfhe@@@DjYfYuvJEXpW^@@B@J@H@@\nfhe@@@LdbbRbbvJYKfaJ|D@@bH@@@@@\nfhe@@@LdbbbTReryHQmN|D@@@BI@`@@\nfhe@@@LdbbbVTJrYHQeZ|D@`B`@@@@@\nfhe@@@LdbbbbbbcxhQiNlD@@@@H@@@@\nfhe@B@@ABTrnjjnJ\\Ehw`tB@@@D@@@\nfhe@B@@ABTrnkJ~J\\Ejw`tB@@@D@@@\nfhe@B@@ABTroZjnJ\\Ehw`tB@@@D@@@\nfhe@B@@ABTroZvnJ\\Ehw`tB@@@D@@@\nfhe@B@@ABTrssziJBUhw`tB@@@D@@@\nfhe@B@@AFRJIKSQJHxirQk^CPH@@@P@@@\nfhe@B@@AFRJIQZKPiDhIVc^CPH@@@P@@@\nfhe@B@@QBSLl|{[ARTYw`p@@@@@@@@\nfheA@@@IRlk\\~pQSdm^CUAAD@T@@@\nfheA`@@B|eJkjrmAEFNCxMUUUUUU@@@\nfheA`@@TdeJsZvoACNZmxMA@P@@@@@@\nfhe`@@@ILkJl{tYKRk^C@@P@@D@@@\nfhe`@@@ILrsZklxJQoNC@P@@@D@@@\nfhe`@@@YEDeDdeBeQbcZmxL@@@@@@@@@\nfhea@@D@RYYU[WirVcV|F@@@@@@@@@\nfhea@@D@rJIJIIJEJcEFu[pX@@@@@@@@\nfhea`@E@iIJUfv]nBFBL{pZB@`@@@@@\nfhep`@BLT@NQQQQQQRq\\tJQkN|uLuUTuP@@\nfhi@B`@QAHadPzHCDYEEELUDeCpUoPQA@DP@@@\nfhi@R@HHpPG`eUoLjn[s`mU@@@@@@@\nfhi@`@@ArJIKJQPiZcG^`@j`@`@@\nfhi@a@AFADAbDfUmygZL]z@BhHB@@@\nfhi@c@BFADRb@qFQQQIIPqYLD{tDDPPD@@@\nfhi@c@BFADRb@qFQQQIIPq[LD{tDDPPD@@@\nfhiAA@C@b@qBSJ{Lk}FN}@ATDA@@@\nfhiAP@@Lt[vQQQRJKYE\\d{sSUTruP@@\nfhiA`@@B|dsLro~jqgM@D@AP@@@\nfhiA`@@HBdrszroScoMSLp@T@`J@\nfhiA`@@H|dwMkZ{IUgMT@@AP@@@\nfhiA`@@LCdTRTQRbRuNN}@DS@A@B@h\nfhiE@BBTYIQoA@rY\\drkKN{hsoUTt``T@@@\nfhiHA@MFlDDPRHrJJKKQQQUgK^``HBH`@@\nfhiHP@DXyhDoARYYn]uhHuffjjji`@@\nfhiHR@DDhJQoAADILl{[NdijttuuUUP@@\nfhiH`@DXtX@lbbbbbQRRYHsfjijii`@@\nfhiH`@LTEhBDfWVUm]F|Ejf@@@@DJP\nfhiHa@LTdFB@A@`cIIBhhddmmNMYZ`hJJD@@\nfhiIB@DXHI`@aIg[ee_UoAZi`@@@@@\nfhiIP@DDhpDc^BdwJ|lzsfkMMMUUU@@@\nfhiIP@DXxHDc^CdTRbbeTVSNZltuUUUT@@\nfhiIP@DXxHDc^CdTRbfaTVUNZltuUUUL@@\nfhiI`@DXYH@`yEDeDbhdmScoMUJp@T@`J@\nfhiP@@@^Rfuue]Yrsj@B`@h@@@\nfhiPA@FV@DTBDiee~yqJ|F`hHB@@@@\nfhiPP@DB@SblbfdtQfbRHspVjff@B@@@\nfhiPR@AFIsPPRBSL{sNiFV]UUULtt@@\nfhiPR@JLIIpPRBSLzmj{NFmRuSUUT@@\nfhiP`@DZAyIgVYW^VkNZjdHBh@@\nfhiPb@OA``@QddabbRRvRkF\\m@@@E@@@\nfhiPp@DX@IQoARYeYv}YsUfjffjj`@@\nfhiQ@@DX@drlrloks`mTEATQ@@@\nfhiQ@@INAdTTTbRarrk^BtEP@@@@@\nfhiQP@DN@Qg@iLoJjnbdZsUUPAR@@@\nfhiQP@DX@IW`yEEDeDdbdsakMUMMUU@@@\nfhiQR@IV`Sa``dLbRbTQbbvXIwjjjjYf`@@\nfhiQR@JLIIW``BDfYu[UV\\MZejfjjh@@\nfhiQR@JLIIW``kDfYu[UV\\MZejfjjh@@\nfhiQR@LVXhw``BLdTVbRbbqqRVjYjjZj`@@\nfhiQR@LVXhw``QLdTVbRbbqqRVjYjjZj`@@\nfhiX@@@PHJpTiZUWYz\\MyjjbAb@DCH\nfhi`P@L@yHrTrlm{}AN}UUTDAP@@\nfhi`P@O@YivQQQRIV[SDXhsPUADu@@@\nfhi``@A@|eMkkJzsegT@E@AP@@@\nfhi`p@D@Dhw`iLrl{^lyjsUKUUUP@@\nfhia@@E@rQQQHyJIHToAhJ@h@@@@\nfhia@@F@rJJIIJZIDRoAjBBB`@@@\nfhiaB@ARADILk[OZtYxL@EM@@@@@\nfhiaB@K^@DISLjo{Bthu@@@EL@@@\nfhih@@@XIQRTsNj\x7FKNRtA@AEU@@@\nfhii`@DTxIPGArJIQQJiJYgIJZiYjjj@@\nfhii`@DTxIPK^rJIQQHpsQgEZZPhBjh@@\nfhipP@DXx@w`yEDhihUEePVkMMUSUS@@@\nfhipP@DXxBW`iLlwZztDZsSUUUTp@@\nfhipR@BTYIW``qDfY][UV\\MZejfjjh@@\nfhipS@IZCpSo@bBAA`cHhheHeTiFJlFBAXiVH@@\nfhipS@IZCpSo@bBAA`cHhheHeTiFJlFBAXjVH@@\nfhipb@AZL{pLQIe]e]ncEZ`@iZfb@@\nfhipp@DXH@Rc^BdsJsmzsfkMUMMUU@@@\nfhiq@@DZBCHheEDeDceNmyj@@`B@@@\nfhiqB@IF]hDadTTTbfLVWE^CMUTmRt@@\nfhiqP@DXH@RoArJJIJIIEIgCVZjZZjj@@\nfhiqP@DXxBQoArJIQSPjKJ`mVZZjjjf@@\nfhiqP@DXxBVoARYYnuuhHuffjjji`@@\nfhiq`@DXX@SdfUgyVj\\lyjiZjjh@@\nfhq@`@@AJDaHRDRHrHPVB`Hbjj`@@\nfhq@`@@JRVUeZZYq`@jjj@@@\nfhq@p@@HdkQlbbTLTTvRHqjZfZj`@@\nfhq@p@@LdkUlbbbbVRLrxIijjif`P]@\nfhqA``BZLBHyxRbEAFQQQIIRUILEAADuU@@@\nfhqH`@L\\MXBLbbTTJbbLTYjh@bj@@@\nfhqP@@@XRe]UUUpQijjjj`@@\nfhqQ@@DT@drlsLjXKUAQEP@@@\nfhqQa@EVEHpHc`QdTRVTaTrUFP@RtuP@@\nfhqXB@J\\dZpPAFRIJIJJqIBeUSMMUpHJ`\nfhuA@@@IRlrjwPQSbgFC[u@@@@@@@@@\nfhy@@@LdbbbTRrNYHVoA@@```@@@@\nfhy@B@@XbRsLrj\x7FIZ}XM@@@A@@@@\nfhy@`@@TrQQRJKSE[deV|F`jH@@`@@\nfhy@`@@\\RYee~uYrVoAZA``@H@@@\nfhyA@`A@bBQGh`LPdsNjjjsdeV]A@U@E@@@@\nfhyA@`F@bMQCh`LQdTTTTQbVSN\\U[tDPAAE@@@\nfhyA@`G@bEQEh`LPdsKOKrrQoN}A@qSUE@@@\nfhyA`@@BMdTTTTTTVoEZ|xL@A@P@@@@\nfhyA`@@BMdTTTTTTVoMJ|xKPAAPA@@@\nfhyA`@@B|dsLsKnqVgVBt@Q@BP@@@\nfhyA`@@DtdsMksjpRc^CA@@P@@@@@\nfhyA`@@Hldrlk[oQbcN|uHPQUP`@@\nfhyH@@@RM[IEDhmBdeJ\\DkQ`@@ajhH@@\nfhyH@@@RlyJYY{W^gAJMX@@HfjB@@\nfhyH@@@Rl{IEDhmCDcJ\\DkU`@@bjhD@@\nfhyH@@@XEkIEDhheYdjRXKpP`jJ@@P@@\nfhyH@@@XxkIEDeDehTjBYspP`Xj@@`@@\nfhyHB@FR|DDPdrmkZkSdeV]@@@@E@@@@\nfhyI@@DTeXBSOJwJxeZmxKT@QUJL@@\nfhyI@@H\\EhFQJJIPiIQ\\dkS`tADMSIP@@\nfhyI@@LDmxFRJIHqQJKTXYuoTuPDPtP@@\nfhyI`@LJMxD`yHhhhUEedRfcN}UUTBAT@@@\nfhyP@@@VRe]VYWISUoAjjjP`J@@@\nfhyP`@BZ@aInUe{W`mF|Ejjj`@X@@\nfhy`@@@ISLjm{btjw`t@@@@@@@@\nfhya@@O@RYVyY\x7FiqQkN`@@@B`@@@\nfhyh@@@\\eYvRJJJJUKKTxkQk@AA@uPP@@\nfhyh@@@\\e[vRJJJJUIITxkQk@AA@uPP@@\nfhyh`@LJMxHIYHhhhUEedRfcN}UUTBAT@@@\nfhyi@@HXIipDefWVuj\\TYwijh@@H@DHH\nfhyp@@@XheLwKjjsde^BDPUPP@@@@\nfhyp@@@^CdbbbbRRqUNRmip@@@PT@@@\nfhyq@@DTTAIgeUUTTmF|Ej@Bh@@@@\nfkAA`@@TTeJwsLDDXkVcUUUUUP@@\nfle@P@@HlgHhdeECDhl[^\\EjjifffP@@\nfle@`@@IrJJIERJEJYgOA`HJh@J@@@\nfleA@@@YEEMDleHiJJQoM@PUUUD@@\nfleA`@@HhdskLl{~cNBuT@@DR@@@\nfleA`@@QSdTTTRRTqfdcZ\\t@@AEL@@@\nfleHP@DTuDC@irJIJHqZIJJgOQZijjjYh@@\nfleH`@G^BdELdTtRRJbbQyHLZBBJ@``@@\nfleIP@DXxHDgQSdTRbffbTNUNV|tuUUUTp@@\nfleIb@LB\\fBK@BLddJbbRTVVuypUj@@HB`@@\nfleP@@@DrRJPqQPiIYtPijjh@@@@@@\nflePR@MA`cA@^FRRXqQJJMJJMjsU@QCUQ@@@\nflePq@JLIIShiAVVdLbbbrRfTbJYpwjVjZjjj@@\nflePr@FVQSaoIAHIM\\w[KoPS`uUUTsTt@@\nfleQP@EQ@RsoYEEEleDhiXRcNMUUULuT@@\nfleQa@AVQ``@bGadTbRTRRLrUgQRuUAP@@@@@\nfleQp@DXArVcQSdTTRbbtRjSAN|uUUMUUP@@\nfle`Q@LPQxH@bpQddebbTVVdleF\\m@@ABt@@@\nfle``@G@edbbTRbbNv`mV}PPE@QT@@@\nfle``@O@bdsJl{zpmV\\tD@@EL@@@\nflea@@E@RfVYUV\\tWIjh@`B`@@@\nflea`@I@U{HhhddihddQZbehHJJjh`@@\nflehPBDX}EHAJCFT}dTTRTRRJRsNFluTtuUKP@@\nflep@@@XleLl{rkMA^RDEEAAP@@@\nflepR@F\\EhtT`qDeYeumUEIwiiZijjjABD@\nflep`@IJR@bSLj~rnlExKTmS@AT@aJ@\nflepr@DDhJRgQRBHRYYym[teK^fffjjjh@@\nflepr@M^SAFB\\\\CprRSEQIZJKZR`qZjjjfVh@@\nfleqQ@BTYIShiAVVdLbbbVRfTbJYpwjVjZjjj@@\nfli@`@@HRYUoV]YjZfZjhFBPiT@\nfliAP`BJt{p@bG``HpDYEHdeCEeEluUTuMT@@\nflm@@@DjYee]{YhTkA|d@@@@@`@@@\nflm@@@DjYee]\x7FYhTkA}D@@@@@H@@@\nflm@@@DjYeeo\x7FyHQm^bd@@@B@@@@@\nflm@@@DjYee\x7F[yHQmNBd@@@@@`@@@\nflm@@@DjYee\x7F]yHQmNCD@@@@@H@@@\nflm@@@DjYee\x7F^yHQmNCD@@@@@H@@@\nflm@@@DjYee\x7F_yHQmNCD@@@@@H@@@\nflm@@@LdbbbTRRJrYHVkAbd@@B@@@@@@\nflm@@@LdbbbTRfvQyHQm^CD@@@BbhA@@\nflm@@@LdbbbTRrJRxhQmNBd@@@@@`@@@\nflm@@@LdbbbTRrVQyHQm^bd@@@@`@@@@\nflm@@@LdbbbTRraQxhQmNbd@@@@H@@@@\nflm@@@LdbbbTRvRQyHQmNbd@@@@H@@@@\nflm@@@LdbbbTVRcRXhQmNbd@@@B@@@@@\nflm@@@LdbbbbbT^VxhUc^CD@@H@bhA@@\nflm@@@LdbbbbbT^VxhUc^CD@@H@bhB@@\nflm@@@LdbbbbbVNVxhUc^bd@@H@@@@@@\nflm@@@LdbbbbbqeRYhUcNbd@@H@@@@@@\nflm@@@LdbbbbbqvRYhUcNbd@@H@@@@@@\nflm@B@@AFRJJJIISKHdiHvoQSP@P@PA@@@@\nflm@B@@QFQQQQQIJGKLdjqoQS@@@@@@@@@@\nflm@`@@QRYfYUgydeNLGrV`@@@BH@@@\nflmA@@@ILkZvmkQdeV]EL@@@@@@@@@\nflmA@@@ILroZrnQ`iFmEKPP@@PD@@@\nflmA@@@ILroZvjQ`iFlFKPP@@@T@@@\nflmA@@@ILroZvlQ`iFlFKPP@@@T@@@\nflmA@@@ILroZvnQ`iFlFKPP@@@T@@@\nflmA@@@ILrrknjsdcV]EL@@@@@@@@@\nflmA@@@ILrsssoQdmFmEKPP@@PD@@@\nflmA@@@ILrszmkQdeV]EKPQ@@@D@@@\nflmA@@@YEDeMDhmBeSbcV]EL@@@@@@@@@\nflmA@@@YEEDeieEBdQ`iF]EKPP@D@D@@@\nflmA@@@YEEDhihcBdqTcV]EL@@@@@@@@@\nflmA@@@YEEDhmBeLdpTeV]EKPQ@@@D@@@\nflmA@@@YEEDhmBeLdpTeV]EL@@@@@@@@@\nflmA@@@YEELeDdeBepQgV}EMP@@@@@@@@\nflmPB@JQAbIKJr|jlsfk^RFMUUTDCED@@\nflmQb@LA`bp@cIICMDeMDUARd[S`qVjZjZfi`@@\nflm`@@@ILkZvmkQdeV]EL@@@@@@@@@\nflm`@@@YHhhhhdddkSdgFbEH@@DDTHD@@\nflm`@@@YHhhhhdhb]RRkFCzH@@@@@P@@@\nflm`@@@YHhhhhdhbmRRkFCyH@@@@A@@@@\nflm`@@@YHhhhhdhecRRkFcyH@@@@D@@@@\nflm`@@@YHhhhhdhecRRkFcyH@A@ALPD@@\nflm`@@@YHhhhhdhecRRkFcyH@PAHE@P@@\nflm`@@@YHhhhhdhecRRkFcyH@PAPD`P@@\nflm`@@@YHhhhheED[RRgFbEH@@@D@@@@@\nflm``@J@SdbbbbLTtQqJRl[pXtC@@@AP@@@\nflm``@K@PdrlkZk]FJLxLTmRDDUUQP@@\nflma@@@`rJIJZIQPiZgEZmxLX@@@BI`H@@\nflma@@E@RfVU^_VcAZLzJZB`@H@@@@@\nflmaA@KQ@DPdLdtTRbtJfRyIVkNbfifZiZej@@\nflma`@E@PGHheEDdhlbj\\TxwhiZ`@@`j`P@@\nflmp@@@VbeJvsOviJBUYtT`@AEP@A@@@\nflmq@@DVbAIee^WmZ\\djshiZ`PJ`@b@@@\nflu@B@@YbULsJjozCZOdu@@@@@@@@@\nflu@P@@BBgHhhhhhehlVJtztV`BH@dh@@@\nflu@P@@BLGHhhhhhhlcnJuytV`BH`Dh@@@\nflu@P@@B|gHheIhcEDiRLu[pVfjjjjZ`@@\nflu@P@@HL{HheEhhdhh~BlGtVijjijj`@@\nflu@P@@\\\\eIfVWyWv\\ehLV`hHB@h@@@\nflu@P@@\\uyIfVWnuv\\dZJV`XJ@`H@@@\nflu@`@@IRYfUV}~QmNCEh@@@@H@@@\nfluAA@A@bDqFQQIYRZJIGTYYpXp@UPTAD@@@\nfluAA`A@bBQCHatQFHSDYEEEMBdeEerRm^CADQPPT@@@\nfluAP@@B\\ENQQQQQQKQXlUkuhm@DPDIP@@@\nfluAP@@B\\FJSLsLoJlUkudm@DPDLP@@@\nfluAP@@HdkrSKLvzjlxYtTmT`pQUP`@@\nfluA`@@FmdbfbTTRbawEZ|EM@@@TA@@@@\nfluA`@@LbdsLn}kkNRuxKPTD@AT@@@\nfluH@D@\\|DDiSLrno}SdcZ\\@@@AET@@@\nfluHP@CNbdDeZrQQQQIJJkHeKNCFjjj`PJ`@@\nfluHP@DLtdGGArJJIQRzJJY`iJbejijjYjh@@\nfluHP@DTuDC@irJIJHqZIJJgIJ}Ejfjjifh@@\nfluH`@DXYh@lbbRbTVaRRisQoAZZfd@Jh@@\nfluH`@DXlDGlbbbLTRvTtISQhiZj@`ijb@@\nfluHb@BJtFW`QFQQQIZKQFZLDZtTpPPuTuE@@@\nfluHb@LLxxLPABTnrjkmxHJQkTlu@EMP@@@\nfluI@@DRUXFQQZJIPiIIRtZpXmPDPuKE@@@\nfluI@@DTXDFQQZIQKQQH|DYtTmSU@A@@@@@\nfluI@@D\\tXBSOLkKzrthpXmPPIUKE@@@\nfluIP@DTxHFgQSdTRbRJbTVSNBe[sSMUUUTp@@\nfluIP@LF]DDeZSdbbbbRTUVQJV\\FMUUU@`U@@@\nfluI`@FNbdAMILs[[N}SagAcUUUPHEP@@\nfluPB@AJADYEDeMDeELcSfgQS@DMPT@P@@\nfluPP@B\\@bslbfbTTRTrJDkQhiZjfjX@`@@\nfluPP@DTAsUlbbTTTlTvRXHshiZjZfX@`@@\nfluPR@JLHkU`RBSL|kMjlyxLTtmUMUUU@@@\nfluP`@DIAEIeUYU}jLehufiZYfij`@@\nfluP`@DX@qIeVyeUrT]DJVjZ@@@H@@@\nfluQB@AJbBHRYVyV]VgMNBf@HZ``P`@@\nfluXP@L\\MZJPRUkIEEEDdeFdbTLxLZjjjP@j@@@\nflu``@C@PdwLl|{XmNbEKPP@@@@@@@\nflu`a@BJ|CDebYEEEheDXdlpQkQSAADtB@P@@\nflua`@A@\\EIfYfWgvJuztV`BHBDh@@@\nflua`@O@TyIfYfUYvBtFrV`BHAbH@@@\nfluab@FF|D@QdbbTVbtjfQJBUjuRsUMMTh@@\nfluhP@DTxIPCQSdTRbbUTRRSNRT{sUKMUUUP@@\nfluhP@LF]EHIJudbbbbRTUVQJV\\FMUUU@`U@@@\nfluhP@NFmEHIJudbbbbRRcRQJF\\FMUSUP@U@@@\nfluib@DTxIQhi@DYEDhheUDddsdeN|uRsUUUT@@\nfluqB@AJMDFHdrmrlzmNZ\\EL@PuA@a@@@\nfluq`@LLxAGdfWeUWnEHuhiZij@IjB@@\nflux@@@XIRRmYHhhldiUDdsdcQRA@AQ@@@@@\nflyAP@@HLxJSJkZrkzluT`DUT@@@\nflyP`@EN@cHheDdehbdiZZ``bjj@@@\nflyPa@LR``@PHHrRPjJJKHiXsejAbHj`@@\nflyQ`@D^@jrSOJzmkBdu@AUUT@@@\nflyQ`@D^@jrS[JzmkBdu@AUUT@@@\nflyQa@ANQ``@bGadTbRTRRLVegMUPTAU@@@\nflyQa@LR`cp@`PQddaTTRrrRVkKTCAEU@@@\nflyQb@LR``P@cIIBhhhlbecNVhFHbj@@@\nfly`R@IB]zH@aJYYY]gcAjhJ`fF@@@\nfly`R@JRU[p@cIDeDeEECEXijji`Z@@@@\nfly`R@LPQEH@cIICEDddeUC^VjB`hf@@@\nflyqa@AFlcA@ADOCHiDdhThmLmFZj`@jj@@@\nfl}@@@LdbbbTVtQVXhQmV]zJZPZHPPJH@@\nfl}@B@@AFRJJIIJISXxhKRoF]EM@@@@@@@@@@\nfl}A@@@ILrjvjvQ`mJLxLTmA@@@@@@@@\nfl}A@@@IRlkjmkAENRUYtTuPH@@@T@@@\nfl}A@@@IRlkvjkAENRUYtTuPP@@@T@@@\nfl}A@@@IRlkvmkAENRUYtTuPP@@@T@@@\nfl}A@@@IRlrjkoAENJl[tTt@@@@@@@@@\nfl}A@@@YHdhdmMDhcAENRt{tTt@@@@@@@@@\nfl}A@@@YHdhheDddcAENJ]ZHTt@@@@@@@@@\nfl}A@@@YHhhhddjdeAGERuYtTuUAL@@U@@@\nfl}`@@@IRlrjkoAENJl[tTuP@@@@T@@@\nfl}a@@A@rQIQJKJZEJBF\\UXshij``@@@h@@@\nfl}a@@E@ReYWm[VBJ\\ejshij``@@@h@@@\nfl}a@@M@ReYYy}VBF\\TZshij``@@@h@@@\nfl}aA@HF@DIdLdRbbRRtJR``cIFuXLZjjZjeif@@\nfoA@@@DjYeUlVeN`@`B`@@@\nfoA@C@@QAHadQdTTTqTRWAV]ADD@@@@@\nfoA@C@@QBhatQdTTRbRQsIFmA@A@P@@@\nfoA@P@@HTYIe[VWhrVfi@Hj`@@\nfoAA@@@ILkjrmFV]@AL@@@ar@\nfoAAB@A@bDfUmyVcKN`@j@@@@@\nfoAAP@@HiIRSKSrvSeNMUTuUP@@\nfoAA`@@HXdrl{ZlyYsUUP@P@@\nfoAAa@JJtBHxDYDhhmEDcpUgUKPJA@@@\nfoAHB@MFlx@QdbdRjbbcNZmUUTmU@@@\nfoAH`@D\\DXDdfVYe_ScVZ`ZBP`@@\nfoAH`BDRLx@cR{dfYeW\\cMVZhFAF@@@\nfoAHb@DXx[U`QFQQJIZJHdiHtuUTsL@@\nfoAI@@MFlxFRJQJjJJLyjuUURuT@@\nfoAP@@@NRYWVUzLMZ@B`@`@@\nfoAPB@KN@DISLjohmJMP@@AP@@@\nfoAPB`ARADDbCREiAt`dsNkmLyITDASUD@@\nfoAPR@JLIIU`RBSLzmlsagTmTuUP@@\nfoAP`@BZ@aInvYWejsfjiB@`@@\nfoAP`@CNAQJYW]YqS`jB@jj`@@\nfoAPa@LDlx@P`HRYYeUuVLyjjjjj@@\nfoAQA@BLD@HpDISOmrnJV]TuL@D@@@\nfoAX@`LTXKU`AB@aPPxHRYWUeRTMYjjjZV@@\nfoA`@@@ILkjrmFV]@AT@@@@@\nfoA`@@@IML|{wEFmUSA@R@@@\nfoA`R@EPQap@cIIKEDhliZMYZ@@@`@@\nfoA``@M@PdvkLkruYsUTa@P@@\nfoAaB@GDADILroZ{AFmAA@@P@@@\nfoAaB@GLADILk_J}NFm@DP@P@@@\nfoAaB@G\\ADILkkJ}FFm@AP@P@@@\nfoAaB@KN@DISLjoxmJMP@@AP@@@\nfoAaP@D@hIVlbbTbfbjIrgFjjfjh@@\nfoAa`@M@PQInvYWejsffiB@`@@\nfoAh`@JBUYpBILoLkleFmUU@`T@@@\nfoAp@@@P\\eKLjorMjsP@@A@B@H\nfoAp`@BZLABS]lroKUgMURDA@@@\nfoApb@HDihp@cIDhideDRLUZi``Xh@@\nfoAqB@JLtPFHdsM|klEYuKTa@P@@\nfoAq`@DXxBSlbbTTtJVhKQffjjjX@@\nfoI@@@LdbbRbaQXKbiZlx@@@`@`@@\nfoIA@@@IRlkZ|DTyKUgUSUUJs@@@\nfoIA@@@IRlkjlDTyIUgUPP@AP@@@\nfoIA@@@IRlkvlDTyIUgT@@@@@@@@\nfoIA@@@IRlrj|DTxjqgUP@@AP@@@\nfoI`@@@IRlrj|DTxjqgUP@@AP@@@\nfoQ@@@DjYUU}`nRlx@@@`@@@@\nfoQ@@@LdbbbRQrYHRkN@@`@@@@@\nfoQ@@@LdbbbTRQYHUmN@@@B@@@@\nfoQ@@@LdbbbTReyHQmN@@@@`@@@\nfoQ@B@@QBSJvjkQdeV]@@@@@@@@\nfoQ@B@@QBSLljzsdcV]@@@@@@@@\nfoQ@B@@QBSLsJ~pRkF]@@@@@@@@\nfoQ@B@@RBSLljzsdcV]@@@@@@@@\nfoQ@B@@XbSLljzsdcV]@@@@@@@@\nfoQ@`@@VRfYeUzBd[Sj@B@H`@@\nfoQA@@@ILrrkkNRMYt@@@@@@@@\nfoQA@@@YEEEEDdbrRkF\\t@D@D@@@\nfoQA`@@HldrlkZtXhugMRDDSD@@\nfoQA`@@HldrmlrtYKUgMR@QSD@@\nfoQH@@@BMYJUme]IRRmF@@HFhH@@\nfoQH@@@BMYJYYo]irRmF@@HFhH@@\nfoQH@@@RMYJUm[UIPRmF@@BFhH@@\nfoQH@@@RM[IEDhmBdj\\DkQ`@@ajB@@\nfoQH@@@Rl{IEDhmCDj\\DkU`@@bjA@@\nfoQH@@@TUkIEEEhddV\\Djs`JBjeF@@\nfoQH@@@TuYJYfU}YrQeZ@H@XhH@@\nfoQH@@@XD[IEDhiedZRXKU``jIfF@@\nfoQH@@@XDiJYYe_iI`cNBBhidX@@\nfoQH@@@XhiJYmg]YpRcVBHJiXX@@\nfoQH@@@XhiJYmg_YpRcVBHJiXX@@\nfoQH@@@XhiJYmggYrRkNBHJfhT@@\nfoQH@@@XhkIEELhddV\\Djs`bBjeF@@\nfoQH@@@XikIEEMEDUf\\ejs`bBjeF@@\nfoQI@@HTEHBRrjjjsdeV]P@TtiP@@\nfoQP@@@FRfYeUz\\e[SjdF`hd@@\nfoQP@@@NrQQJIIYFcAZMX@@@@`@@@\nfoQP@@@NrQQQQIHz`iFuX@@@@`@@@\nfoQP@@@RrQQJIJUJgAJlx@@H@@@@@\nfoQP@@@TRfY^]|TEjsiB`hjb@@\nfoQP@@@TrQQQQPqUdeZlx@`@@@@@@\nfoQP@@@VRfYe]Z\\d[S`@@@H@@@\nfoQP@@@XRf[WmZ\\djs``@@@@@@\nfoQP@@@XRf[eUz\\UXs``@@@@@@\nfoQQ@BHB@ChRdsLrolDjqgP@@@@@@@\nfoQ`@@@ILkZjmFRUYt@@@@@@@@\nfoQ`@@@IRlrj|DJlYuT@@@P@@@\nfoQ`@@@ISKON}NBeYp@@A@@@@@\nfoQ`@@@ISLro}NRMjp@@@A@@@@\nfoQ`@@@ITsJkyFJlYuPA@@P@@@\nfoQ`@@@ITs\\k{AJlYuT`tDR@@@\nfoQ`@@@YHheEMDcPTeF\\@@@A@@@@\nfoQ`A@F@bIABSJvmkSdeV]@DT@A@@@\nfoQ``@B@mdTTTTRQSEBdYsTmUSU@@@\nfoQ``@M@HdsMjoLDhugMLBDUD@@\nfoQa@@A@RYfYWvBUXsf`B@@`@@\nfoQh@@@LDZvRJIQPiYTYIVc@@DCTD@@\nfoQh@@@TejrTsLkzsdcJt@P@qPP@@\nfoQh@@@TtZvRJJJIIELEHrm@D@LTD@@\nfoQh@@@TyjvRJJJIIELEHrm@D@LTD@@\nfoQh@@@XijvRJJIQIELEHrm@D@LTD@@\nfoQp@@@XDeLvzjtyIUgAAEP@@@@\nfoQp@@@XDeLzmjtXJQkA@T@DP@@\nfoQp@@@XDeLzmktXJQkA@T@DP@@\nfoQp@@@XHeLsnjxiIUgMPP@A@@@\nfoQp@@@XdeL|oZtYIUgA@U@@P@@\nfoQp@@@XidbbfbQRSNRUYpQAT@@@@@\ngBQ@@eJuT@@\ngBX@@eLUT@@\ngBXHHHaIejh@\ngC`@Die@@\ngC`@Dkz@@\ngC`DADHHRVh@\ngC`DADZHRVXRH\ngC`DADZHRVXRP\ngC`DADZHRVh@\ngC`DADZHRVx@\ngC`DAHJPRZd@\ngC`DAHJPRZh@\ngC`DAHZPRVh@\ngC`DAVRDRZh@\ngC`DAbKDRZh@\ngC`DAbZHRVh@\ngC`DAb[DRVx@\ngC`HADIKLIH\ngC`HADIKR@@\ngC`HAbIKJ@@\ngC`HAbIKLIH\ngC`HAbIML@@\ngC`LAHJPt`duP@\ngC`LAVJluXduP@\ngC`LAbKDvHduP@\ngC``@dfZ@@\ngC``AdeY@@\ngC``AdeZ@@\ngC``Adej@@\ngC``Adij@@\ngCa@@dkH@\ngCa@@dkP@\ngCa@@dkX@\ngCa@@dmH@\ngCa@@dmP@\ngCa@@dmX@\ngCa@@duP@\ngCaHDHaIZ`@\ngCaHH@bNt@@\ngCaHL@aIZ`@\ngCaHLHaIZP@\ngCaHLHaIZ`@\ngCaHLLQIZP@\ngCaHLLQIZ`@\ngCah@mJAIj`@\ngCahHl@bNt@@\ngCahHlGBNt@@\ngCahHlHRNj@@\ngCahhlAa]ncm@@\ngCd@Adej@@\ngCdDI`BHDRZh@\ngCe@E`dmH@\ngCe@E`dsP@\ngCe@I`dlpd`\ngCh@@dmH@\ngCh@@doH@\ngCh@@doP@\ngChHD@aIU`@\ngChHLHaIZp@\ngChHLLQIZ`@\ngChHLLQIZp@\ngCh`LDdsP@\ngChhMDHbNl@@\ngCi@DDeV@@\ngCi@DDeZ@@\ngCi@DDfZ@@\ngCi@HDefDd@\ngCi@LDej@@\ngCiHEAxIVt@@\ngFp@DiTt@@@\ngFp@DiTvjh@\ngFpD@DTHReSZj`@\ngFpD@DXHReSZj`@\ngFp`@dfTujX@\ngFp`@dfTujh@\ngFp`@df_Ejh@\ngFp`ATiTvjh@\ngFp`AdiTvjh@\ngFq@@drfmM@@\ngFq@@eLqUU@@\ngFq@@eLzts@@\ngFqDDHbqBSZmUT@@\ngFqDLLRqBRwcUT@@\ngFq`AbeJfuU@@\ngFr@ACTiTt@@@\ngFr@ACTi[FZd@\ngFt@ATiTt@@@\ngFt@AdiTt@@@\ngFtHCQbILimKP@\ngFtHE`DILikUP@\ngFtHLPDISNmLp@\ngFu@E`drfmT`@\ngFx@@eJf`@@@\ngFx@@eJfuU@@\ngFx@@eRfuK@@\ngFxHJ@aJ]bjn@@\ngFxHL@aJYujj@@\ngFx`HJeJxtm@@\ngFy@DDfTujh@\ngFy@JDiTvjh@\ngFy@LDeXvjh@\ngF|@AbeJf`@@@\ngF|HLZ@aJYuif@@\ngGP@DiVj`@\ngGP@Di]jQ@`\ngGPBABRHTQXcIHUTpf`\ngGPDADVHRUZZDT@\ngGPDAbWDRUZj@@\ngGPP@cTfyi`@\ngGPPACTiVj`@\ngGPXHlQxIU[U@@\ngGP`@TfYi`@\ngGP`@df]j`@\ngGP`@dfuiaM@\ngGP`@dfuj`@\ngGP`@dfyi`@\ngGP`ADkjj`@\ngGP`ATeUfQD`\ngGP`ATeUfaE@\ngGP`ATeVj`@\ngGP`ATfVi`@\ngGP`ATiVj`@\ngGPhCQDIJuS@@\ngGPhH`DYIHUi@@\ngGPhMPDIK]U@@\ngGPhMQDIK]U@@\ngGQ@@djltHh\ngGQ@@djuT@@\ngGQ@@dlmT@@\ngGQ@@drmT@@\ngGQ@@dsMT@@\ngGQ@@dsmT@@\ngGQ@@eMUT@@\ngGQDB@jQBUkUP@\ngGQDL@aAFQRFj`@\ngGQDLHbqBRwSP@\ngGQDLHbqBRwUP@\ngGQHBHaIeiXQH\ngGQHBLQIeiXQH\ngGQHJ@aJ]jd@\ngGQHJHaIUjh@\ngGQLJIARFdLbdMU@@\ngGQXHlZHROjj@@\ngGQ`@ZdrmJ@@\ngGQ`@ZdrmT@@\ngGQ`@ZdruT@@\ngGQ`@bdvmT@@\ngGQ`@bdwMT@@\ngGQ`AjdmmR@@\ngGQ`AjdmmT@@\ngGQdEb@bRFRRVV`@\ngGQhHlLSIHTmP@\ngGR@aEQJyJ]Vh@\ngGT@ADiVj`@\ngGT@ATeVj`@\ngGT@ATeWfqE@\ngGT`E`TfUj`@\ngGT`E`TfYj`@\ngGT`HQTeVY`iZ@\ngGU@E`drmT@@\ngGU@E`dsmT@@\ngGU`E`ZdrmT@@\ngGXHD@aIUVd@\ngGXXKEb@cIIBmP@\ngGX`BDdvmT@@\ngGX`BDdwMT@@\ngGX`LDdsmT@@\ngGXhKB@aJvZX@\ngGY@DDfYj`@\ngGY@HDeVZaI@\ngGY@HDefZaH`\ngGY@HDfVj`@\ngGYDIQDJHR[Zj@@\ngGYHEAxIVkU@@\ngGYHEAxIVsU@@\ngGY`BETfuj`@\ngG\\DEj@`aBSJuP@\ngG]HHjPDIJuS@@\ngGp`AldTLRuUT@@\ngGq@@eJqFuUP@\ngJP@DjYd@\ngJPBAVJPt`YAIjj@@\ngJPDADFHRUfaH`\ngJPDADFHRUfaI@\ngJPDADFHRUj`@\ngJPDADFHR[f`@\ngJPDADQpRZj`@\ngJPDAbGDRUj`@\ngJPD`DHHGKdfzd@\ngJPH@EIRuP@\ngJPHADIJsHd`\ngJPHADIJsPd`\ngJPHADIJtpb`\ngJPHADIJuP@\ngJPHADIKSP@\ngJPHADILth@\ngJPHAVILuP@\ngJPHAVIMUP@\ngJPHAbIJuP@\ngJPHAbIKUP@\ngJPLADZPL`dmM@@\ngJPLAHJPt`duU@@\ngJPXHlPDQzt@@\ngJPXHlQBQ{T@@\ngJPXHlQxQ{T@@\ngJP`@TeVd@\ngJP`@TeVh@\ngJP`@TeZh@\ngJP`@TfVd@\ngJP`@TfZh@\ngJP`@dfVh@\ngJPdEaDPHRZe`@\ngJQ@@djsBJ@\ngJQ@@dju@@\ngJQ@@dkSBJ@\ngJQ@@dkU@@\ngJQ@@dls@@\ngJQ@@dmU@@\ngJQ@@dru@@\ngJQ@@dsT`@\ngJQ@@duU@@\ngJQ@@eKU@@\ngJQDDH`qBRmT@@\ngJQDHG@nBUMT@@\ngJQHBHaIVYDd@\ngJQHBHaIVj@@\ngJQHBHaIfe@@\ngJQHBHaInZ@@\ngJQHBLQIVj@@\ngJQHBOAJfj@@\ngJQ`@bdvt`@\ngJQhHl@bOV`@\ngJQhHlHROZ`@\ngJT@@Te^h@\ngJT`E`TfVh@\ngJU@DPdru@@\ngJU@E`dru@@\ngJU@LPdkU@@\ngJUHLT@aIjZ@@\ngJX@@dkU@@\ngJX@@eKU@@\ngJXDBLQXbS]V@@\ngJXHD@aIUZ@@\ngJX`BDdvu@@\ngJX`DBdjt`@\ngJX`DBdru@@\ngJX`LDdru@@\ngJY@BDfZl@\ngJY@DDeUh@\ngJY@DDeVh@\ngJY@DDefh@\ngJY@DDfVh@\ngJY@LDijX@\ngJYHC`DIKTp@\ngJYHCaHIKTp@\ngJYHEAxIVmP@\ngJ\\@@ldru@@\ngJ]@EbDfVh@\ngJ]HEcAxQ{T@@\ngKP`@df\\Vj@@\ngKP`Adi\\Zj@@\ngKQ@@eKEUP@\ngKQ@@eKcRp@\ngKQ@@eKcUP@\ngKQHDHaImZj`@\ngKQHH@aJoEj`@\ngKT@Adi\\Vf@@\ngKX@@eKcRp@\ngKX@@eKcUP@\ngKX@@eMEUP@\ngKXHL@aJWFe`@\ngKXHL@aJWFj`@\ngNpH@DIRkUJ@@\ngNpJAHJPtaYArFQRFUU@@\ngNpN@iRHTQh`qEbGDQ\x7FUT@@\ngNpOAYRHTQh`qEbGDAh\x7Fjj@@\ngNpP@jtfvZf@@\ngNp`@TfWZZ@@\ngNp`@dfVZf@@\ngNp`ATeVYjDT@\ngNp`ATf^Zf@@\ngNphJqDIKMTl@@\ngNphMQLISMSL@@\ngNpiJqbOdeVjf@@\ngNplJqHJPtadTaeTp@\ngNplLQDSpPPduluP@\ngNq@@djkLpRb`\ngNq@@djkLpRc@\ngNq@@djkMPb`\ngNq@@dl{UP@\ngNq@@dskUP@\ngNq@@eJmTh@\ngNqDLHaqBRjuU@@\ngNqHFHaIfYjP@\ngNqhHl@cIIBej`@\ngNqhHlOAJkVj`@\ngNqhMV@aI[jY`@\ngNt@@teUjj@@\ngNtHAePIKMuT@@\ngNtHE`DILruT@@\ngNtHE`DILzuR@@\ngNt`E`TfWZj@@\ngNt`E`TfYZj@@\ngNu@E`dl{Tpa`\ngNu@E`dskUH@\ngNu@LpdjmUP@\ngNx@@eLuUP@\ngNx@@eRmUP@\ngNxHD@aIUUj`@\ngNxHD@aIUej`@\ngNx`LDdskUH@\ngNx`LDdskUP@\ngNx`LDdssUP@\ngNxhMV@aI[ji`@\ngNyHEAxIVjuT@@\ngNy`BDtf{Zj@@\ngNy`LDtf]Zj@@\ngNyhGE`DYIITmT@@\ngN|@ADeJkUP``\ngOp@DiUkZV`@\ngOp@DjWkB@@@\ngOpHADILkW@@@@\ngOpHADILkWTu@@\ngOpHAbILkW@@@@\ngOp`@dfUMZj`@\ngOp`@dfVqZj`@\ngOp`@tiguif`@\ngOp`ATiekjj`@\ngOp`A\\dTQbjj`@\ngOphH`DYIHUVmT`@\ngOq@@drm[ST@@\ngOq@@drm[UT@@\ngOq@@drm\\@@@@\ngOq@@drm]UT@@\ngOq@@eLvmLt@@\ngOq`@VdsNkTl@@\ngOq`@fdrikTl@@\ngOq`@fdrikUL@@\ngOt@@TeVkzj`@\ngOt@@tiek@`@@\ngOt@@|daRbjj`@\ngOtHE`DILl[MT`@\ngOt`EPTfVKZj`@\ngOu@Dpdrm[Rt@@\ngOx@@drm]UT@@\ngOx@@eSRuUT@@\ngOx@AddJTUUT@@\ngOxHBHaIeZx@@@\ngOxHDHaIeZx@@@\ngOxHDIAIeZx@@@\ngOxHHHaIeZzjh@\ngOxHL@aJY}Zjh@\ngOy@DDfYKZj`@\ngOy@LDiisjj`@\ngOy@hAteIeZx@@@\ngOz@ACVeKNLuR@@';mlb.dE='fHe`A@\neO`BNZ``\ngF|HLZ@aJYuif@pPWHP\nfHgdAy@\neMBBHRZCAKd`\ngNxDLHaqBRjuU@P\neMABHXaIhH\ngCaHLHaIZ`H\ngJQ@@dls@XKGd`\ngJP`AdejhC@qX|`@\ngGP`ATiVj`LCEcrT\ngGP`ATeVj`LJEc^R@\ngGQ`@jdjmTAal[rP\ngGQhHl@cIIJmPFBMyL\neFBCPcA@\ndid@p@bBbFbDfYoa`b@@LJ@fx^QP\ndaDD@@IIf]n``@@pkBiny@@\ngChDL@aABSM@XHKdp\ndazD`N``|DjwVjh@`\nfHbTAa@\ndaxB@@InRYgZj`CBdpf{dT\ngNxLL@aAABDfVZj@`\ngGPB@DHHpQPaIUZdB\neMC@HoABDe`pccH\ngC`L@DSpPPdkPD\ngJU@LPdjr`XIGd`\ndaG@@@kdig|jVj`CAdpj[`\ndaD@@DjUZxHH@CAdpj[nQ@\ngKP`@Tixjj@ptVyB\neMhDRZCAKd`\ngJQ@@dkU@XDQGdp\ngC`D@DXHRVhCAC\\TP\ngGQ@@djmTA`Xl^R`\ngGXXKEb@cIIBmPD\neF`BNFE@\ndidHPBBHFHRYgVzB@`@`\ngCe@E`dsPFBV@\ndaFL@HABR[e[fii@H\ndaE@@@yIe^f`@`@piLJny@@\ngO|HEfHaIeZx@@B\ndcN`@@pjYJYe}k`Hbj@B\ngN|HEb@cHhhVj`H\ngNp`@deUZj@pvkxhP\ndax`@@bnRn[ff`RHj\ngJT@@deVhCCKGbD@\ndigDPLXXP@b`cIIKDnEZfd@`\neFBBDcAaWH@\ndeVL@HAIR[e_aZ@B@B\ndaDH@@RVU[f@@@LJ`j[nQ`\ndcoH@DJ`RUeUVy]ZZ`@@B\ndmO@@@pldTTJRraej@B`@`\ngNp`@dfUZf@pvMyF\neMBCDRZCAKd`\ngJPDAbGDRUj`H\neMBBHRYCAKd`\ngCe@H`dtpD\ngCi@LDek@`\neMaDBKpRVB\nfHbXAa@\nfHfpAa@\neMIDBKpRYB\ngJ\\HEb@aIej@pPWEb\ndcNL@M@aRYgWVzB@j`@`\ngNpXHmQxYIIXuTA`Uj~P`\ndeT@P@bNBDfUuih@J`@pxDpjx^QH\ndidHPABHJHRYgVzB@`@`\ndcl`@@`nReeWZY]@``@@B\ngOr@Ajti]qZY`H\ndeV@@@ReWTj@Bj@CCdrfxYyD@\ndeV@`IBHRYWVf`@j@CC`SBkiy@`\ngChHLIAIZ`LEMrH\ngNxhMVIAI[ji`H\ndeWH@DJPRY[TYZ`@@B\ngGPhCPDILuS@XXR|f@\ngGP`ATivj`LMc^JH\ngNp`ATiUjj@pLQoEf\ngJQ@@djsBJptQyL\ngNu@H`dlkUPFBqxjp\ndeV@@@RYyTYj`@@CBPaLinFP\ngCah@mJAIj`LLE`\neMFIHRM`pgd@\ndaD@P@bNbDfUzZ@B@B\ndifL@LAARYYRijjX@`\ndaxD@@QIUYjj@LJpj[nQ@\ndcN@@@rQQHqIKmUP@@A`hPfEprn|b`\ndmtH@@RYWUih@Jh@LAALJnF^Ph\ndmv@@@rRJIIFUjB`@@pyLJnF^Hr`\ngF|@AbeJfuU@P\ndiFB@LANEIn^ZjX@`\ndeTL@@Z\\bbRbM]@DT@FC@fMt|`P\ndcNL@MAirJIJHsUt@QU@A@\ndeT`@@pjrQQIFTpDEP@P\nfHd`Aa@\neFJHbHpP\nfdu@@@LdbbTRrLtSI\\TZwhaDTUUTU@A`YFBTYpRmF\\GfI^b\ndiT@@DjYVnXPbD`@pIBinYgB\nf`iA@@@YHheDdYdj\\DiwjBH`@H@@`\nf`iA@@@YHheEdXdj\\EIwjBHH@H@@`\ndmLH`I@HRfUwrnF`PJ`@phBXUxbT\ndedF@@PfFTf{nZjf@LFSBii@\nfoQPP@DLAhulbbbTRTLYpTmNZjjjZh@H\nf`i@@@DjUg^uhIVg^BBb`@H@B\nflmA@@@ILkZvmsQdeV\\EL@EUUUQT@FEdXipTeZM[tT|P@H\ndet@@DjYUX^dHbH`CAdJfF^Ig@\ngGY@JDeejpH\nfb}`@@@YEDeMDhTihjLUiwhyZjjjjjjh@LOHpRgARUhugASgb@Q@\ndclH@@rQQRJItJ{PUPB@FEDwSoLhU@\ndg|D@@OIEEHhfmPkmAU@T`A@\ndcMB@HDDWTfyV{iZ@HX@H\nfak`A@H`dDrBSJ{LjnmkQc`m{@ATDDUUPP@P\neghP@@@LdbbdRdRQbLf|VRcEdbgfPRSUUUUUUUUMUP@D\ndidD@@iJ[gxZB@@C@dkaxaL\ndeTD@@QImYQejjj@LNpj[agdH\nfdu@@@LdbTRTjTtSA\\dZwhmUUUUUU@A@\nfoQ@B@@AFRJJJIQX|UJqgT@PP@`@D\nflmA@@@ILk[J}sQdmV\\EL@EUUUQT@D\nfgA`B@N@BDifYWz\\d[Uj@H@B@@H\ngGUHEj@aIUZdB\ngGX`LDdjmLIkBWba@\nfnk@`@@MrJJZQIFYJSKYdmF|DmVjjjjjjjf@B\nfoQA@@@YHhhheEcqTkF]PAA@B@@P\ndiFD@HCDemVZj`bJ\ndcMH@LDDeYWWajjjj@LIBDJfzUyF`\neFDBcAaWH@\nfewAP@@Vkv^QQISQJFKIQJVZcEF|EIVejjjjjijj@CBJLTxJRmFl{t\\ejOdI`\ndmTJ@@PYUIeUYjjV@LBpjWdL\ndmLH@@RYVuiiV@BiH@`\ndk\\D@@OIEEHhkje]hJbB`@`\nffsA`@@VkdTRTtRabrTRhqQoARUiZjijjjj@B\ndg|@@DjYV}~T{`d@@@@H\ndeTH@@Rfuunh@I@C@lJfybCH\nfoA@P@@HuYIe[UvhrRfi@Bf`@H\ndeTD@@QIgeQej@@@LJrfx^QH\ndif@`D@HRUe^Eh@@@pXDinGbPP\ndg~@pIBPRPrPrJPqISIBiwU@@@@@P\ndmL@@DjYe^TYHI`h@H\nfb}A@@@YEEHdcLeIeb\\djsdyZjjjjjjh@LOXIQgARUjsoAbgdL`\nfc\x7FAR@CQ[OXICHhhdiDimCEDYmBrPk^SfmSUUMUUUSTt@D\ndmLH@@Re^UpiVe`@`@`\ngNp`@deYZj@pNM_I@\ndmtH`NBHRYWVih@Jh@LNALJiWdB\ngJQHBLQIVi@`\ndmtD`NTHaIe]Vf`@jP@`\ndmtD`NTHaIe]Vf`@j`@`\ndklLPDp`BH|LbdRRaRtvjh@@@`\ndeU@@@aJWeQej@@B@h\ndg|`@@pjrQQQGQIMqvAPP@@@P\ndeT`@@pjrQQQUMpEAP@P\ndaED@DXNRYUifjf@H\ndmND@DCdfVUrjUZjZi@H\ndg}@@@aJVYU^Svv`@@@@`J\ndg\\@@LdbbbTicRDQIS@Qs@\ndk\\d@DsmB\\bbbTrQXUujjUj`C@liS@\ndazH@DAImeiiBL\\Lrfxb\\\ndkNH@DAImgVVffZPsEhV\ndefH@HAIUVYfZPrKJj\ndaF`@@pjYJYfn@b@@pPfyG@\nfhi@@@LdbbQfTbdxKShF@jjh`@`\ndmt@`@bDfUuZZ@Bj@CC`SBkaxdj\ngOt`DPtfWMZi`OLlP\ndaED@DHNRY[Jfjf@H\nfluP`@DD@iIfUeeurL]DJVjhD@@H@@`\ngNy@BDeUZj@pJu_EB\ndcNDpBWPbNBIdDfYUYa``bT@H\ndmvDPIxPbBBDfYZVVBAX@CB`rfgdJ\nfoA@@@DjYW{WdkN`XH@@@Ppp\nfluA`@@HddrsJoN}NF}EKTpT@@D@@XJEKQkN|FJ^PX\nfhi@P@@HeyIefU]zgCNZfB`ah@B\ndcML`EvDp@cIIKDedLkP@R@D\ndieD@DpARYevyjiX@pRnxfD\nfhyA`@@HBdrrkN~RdcN|uA@@AP@A@\nfbmQA@AJRBH}HILk\\kOKtyit\\pACTE@a@@P\ndg^B@HAEmInUvwaZ@Bj`@`\ndg^L@DAaRUf^uNvjj@@@H\ndcNH@DAIgfYgVhBH@CBnFUwbI`\nfle`a@BAbBHeDYEEEDhXXeDqWdpPU@PL@@D\ndefL`BpYBHRVvZfjX@`\nfoAa@@F@rJJJIJINUeFZBPjHP@pDRgARtYwHJ@\ngOtHDpDILrWST`XHwbF@\ndigD@HK`QInW[fiZ`CCDX^QP\ndeWD`D[ad@cHhhhXWTuSHA@\ndg}@@@mJYeU|]Tz@@@H@CAPpj[aeSyE`\ndiU@@@aJUUpnFZ@@@LBinGbP`\nfoQP@@@XRfYV}|LEjsfjYA@h@B\nfhe@@@LdbbTbTurXkfaF|DHbhh@B@@`\ndaFD@DAdfUjyjf`CCDsnQP\ndax@@DjWzjh@pxHPj[nQ`\ndmO@@@`diWe\\JUfh@D@LFanFUyB@\nfdep@@@PHeKOLjoxH[s`sU@@@D`@D\ngGP@DiVj`LBl[qB@\nfdy@`@@QRYWYVuzL|F@Bj`@`@B\ndeTH@@RYWZf`@f@CA`SBj^PH\ndmtH@@RYWYih@IhBNh\ndg\\HpMBPRPrPrJPqIPsCMT@ET@D\ndmv@`EBHRYWYih@Jl@H\nfoApB@EZ\\BHRYWYyZLlz@BjiR@B\ndaG@@@rdifzxHH@CAB[bYp\ndev@`NBHRYUVfFX@Ja@LJCBz^H``\ndcnH`IHHaIfU]XUvBBJa@H\nfoAQB@FF\\BHRYVwUZ\\EJ@HjjQ@B\ndg]L`LfDD@cIIBhhd]ikTC@P@XMc\\nwrI@\ndaGH@DJ`rJIPdsTt`D\ngNq@@dsUUPFEDM_I`\ndklHPABHvHrJJIJQEn`HJj@B\ndeTH@@RfUWihHH@CCdpfxYyE@\nfduA@@@ILroZviFBdZpXmUUU@AT@A@\nfhya@@O@rJIJYRIKFcIF]z@BjjjJ@CCPDXhJRmFl{d@`\ndk\x7F@@@bdie^urnGSfj`@X@H\ndg|@@DjU^yZx{BAJjbBJX\ndid@@DjU^nBAHBJ\\FaLJaxc\\\ndeUD`LjD@HrREQICJt@@@XUc\\L|`@\nf`qPb@LB``@QddaTTRRVtzwej@@@@@B\nfdu@@@DjUe_[e`nRM[tYfjjjjj`@`\nfb}@@@LdtTbRLrTrUAJt{r\\}UUUTuUT@D\nflmA@@@ILkZvmsQdeV\\EMUMUUUUT@D\nfnk@`@@MrJJQJJYERKH{`iJ|dmZjjjjjjjj@C@hHXIQgARUYw`qSdmV|ah\ngJPhLQbIKTpD\nf`i@@@DjYU[wxjQg^`@@@@@@CBRLDirVkNy`Qo@\ngGUHEj@aIgZdCAA\\VH\ndcn@@@RieU~V]jjjj`CATpj[ae]yD@\ndmO@@@`diYuZZU@`@@@LJsae^PP\ndieD`JXaCDRYgvzejX@`\ndeVH@ACHhhdbwPDE@AaPXUMsNFP\ndknH@FAIfUWaVhHHh@LMBLJfxYt~Ph\ndg]H@FlDfYU^QVhHHj@B\ndknH`Bp@aJYvU}NfhH@@H\ngNqdEb@b^FQRHmU@XXU|VH\ndg|@P@bEbLbbbTRRKR]pP@P@@D\ndmtL@@QTfyeQehBB@B\neMdHTf`pQyP\ngN|@@ldssUPFEBM_I`\ndef`@@SFyIeYfjZ`B\ndidHPBCDGDRYgVzB@`@`\ndigD@HHPQInYXVijPCCDknPp\ndmvD@EADfzUQUjjj`B\ndifH`JD@cIEDd\\jfZh@`\ngOq@@dlvKUTAaeWqP`\ndaDD@@QInXjZjh@`\ndmMH@LhDeemZZUYh@H@H\ndeVH@ICHhdhUSP@U`A`RYS\\PN@\ndclL@@STfUmVfeVi@B`@pKaW^Ie@\nfheA`@@JLeLrsLsPPkR\\kUUSUUUU@A@\nflui@@DXYYHDfYewvUHrVhiZjifjjZ@CCUNBdkQg^CGdD`\nfoQa@@N@rQQQQJKGbiVLz`BB@D@@pxQ`iZM[bEN@\ndifH@BAIfuxZ`@@CB`inGbQ`\nfoAP@@@NrQQQUQIZgCVifh@J@@`\nfdy``@N@PdrwL}kjtFKTuUA@H@FDbLxHug^CqBh`\ndig@@@`Tke]nX@H@H\ngOq@AdbbLUUTA`Uc^Q`\ndk\\L@@jTie]urnF``Jf@B\nf`i`B@F@bDfUmYWiqQg^`BJB@H@B\ndeVD`NFPBDfUvih@I`@pKBj^HB@\nfde@@@LdbbTRtQRSIJuzHQEDDDD@A@\ndidHPABHZHRYVZz@H`@`\ndidH@@RfU~F``@@pYLJnGdL\ndmMH@NTDee[VFUX@ab@LBpfWbQH\ndcmH@DhDfUe]aWVjA@`@piLzUx`z\nfluQB@NNbBHRYeg[Y]dkNBfBAbB`P`@H\ndid@@Ldbbq[`bB@CBdJfGdX\ndefJ`JaLFP|LddjRcUTpA@\ndifD@DCdfVZaZjZ@LLRaxfL\ndeT@@DjU_k``b`@pzDJfz^I``\ndeWH@DJ`RYYTfZij`CCNF^He@\ndmwH@DJ`RYYYIfjZj@H\nfb}@`@@YRYUUm[ehrRkNBf@BjjjjJ`@p|CANBdkQk^CEN^PP\ndcnH@BAIf^u[evB@@@@H\ndcLB`HSFCpRj}mUujh@@@`\ndidH`HApRkm^Fh@@@`\ngJPhH`xQ}TA@\ndmL@@DjYUVgaHIBh@H\ndidD@@GIEEE\\jfZh@`\ngFp@DiTvVhC@qX|Ph\nfj}P@@@IrRJJIQJIHdqUmA]Fh@bBHJh@@p}bgARUhug^CGIP\ndknD@BADfyvUtvjh@@@pELXYWSxaT\ndeTH@@RYWVf`@j@CC`SBkiy@`\ndg|@@DjU_eZx{BAH@@BJlAaBjUt~Ec]X\nfj}a@@O@rJIJYRIKEIRcIF]z@Bjjjfb`@`\ngNy@LDegjj@plVKxaP\ndo~D@AA|dTRRbqbyZBBbj@B\ndidD@@yJ[VXZ@H@CBdpf{dB\ndmLD@@iJYW_JxZB@f@CBdIagdJ\ndaF@@@RYe[hB@@LJCBinQp\ndieH@FxDigwJiejBJlLpjyb\\H\ndg^L@LAER[eYWNvjhD@@LAPjF]N~Qp\ngNr@Ab|dTQeiDe@\ndaF@`H@HRVU[jjj@LNaLJf{d@\nfnk@`@@ErQSISISISQJUgEZ]zNZ@Bjjjjlj@B\nfb}A@@@YHiiDdYdidjBUiwdyjjjjh@J`@H\ndmLD@@eIfUTfEV``R@B\ngJQ@@dru@XS\\RH\ndeVD`NFPbDfU^ih@I`@phLIiyB@\ndmuD`BFUBHRYg^[hHBX@H\ndid@`@qDf[Wai@@@H\ndcmH@DhDfUe]aWVjA@`@pKNe^X`z\ndmvD@HADfueYUi`@@cF\ndeT@@LdbRQU\\DBT@FCPaTL|SF@\nf`q@@@DjU]YWiqw``R``@ABe@\nflmA@@@YEDeMDhTieQbmN}EKUUUUUUT@D\nfduA@@@ILkZvmmFRUYpXmMUUUUU@A@\nfoAA@@@ISZzrkNV]P@T@@@AaIFBTXkQk\\PIp\nfhi@`@@^Rfuue]Yrsj@B`@h@@`\nfdyA@@@ISZvnsKNJuP@@EUP@A@\ndo\x7FD@DgP]IefU\x7FTvhJBI@B\ndkm@@@kIHbdhdmNjj@@@LIaLIae]xeF\nf`qa`@D@EyIfYUwrLuYj`XHf@@pYrRmFmqEG@\ndk]H@FDLbbbbbey]N@H`@@B\ndeT@@DjU_k``b`@pFDpj[iy@`\ndg^L`LaC@HrRPzIKJRju@AL@FCXS\\L|bp\nfoAa@@I@RYeU{QJlyhHHjb@B\nfoA@B@@RFQQIPiQITYYt@Dp@@BGF\ndid@P@qAqDfY]n`HH@H\ndidHPFBHJHRYf~FBH@@`\nfdei`@LJLzHIZrQQQQIJJkDiYpXuUUTBAP@D\ndeTH@@RYWZf`@f@CB`SBkbCH\ndeTH@@RYWVf`@f@ckA`SBknHL`\ndmMH@HxLbbbTQ[iV@@@@@`\ndk\\@`@BDifUWGUN`@@@@CBPpj[ae^Ii`\ndeVD`LFPBDieWrjfiXHr`\ndg|L@@Z|dTRbfQuCNtEDQR@D\ndg]H@IlDfYU^QUhHHj@B\ndcLD`BtHaIfUuXXHHj@B\ndk_H@DhpRYVU}aWVjA@h@H\nf`a@@@DjU_gVipHDffXAbbItp\ndo}L@HdDuInUunxV`@ij@B\ndcvB@LANGHieEDXuTuPA@\ndkn@@@rQIJJIGSjhJ@@CATrfxYWSx`P\ndaxD@@QIeUjZBB\\Bpf{dT\ngCh`DLdlpd\\InHP\nfoAA@@@ILkjrmFV]@AL@@@ar`\ndk\\D@@WIEEEDYjF]hJHbP@`\ndmtH@@Rfuu[j@BXBAlJSBinXLj\ndklH@@Rfuuenh@Ij@`V\ndidB@@[aRfU\\jjjh@p[BinGbP`\nfhi@H@@XyIQgArQQIQJ[JV`k^jjjjjj@CCTBTxJVcN|GfDLl\nfhiA@@@ILrsZkf|xKUP@@@@@XFps`iJtZsoAyA@\nfdyA@@@YEEHeEBdekA}Ejj@@@@@B\ndmVH@NAIe^Yjjj@LNpjXYWdH\nfhqa@@C@RYegV^tyjhHJJ@@`\nfoAQ@@DJ@drrkNrMYsTDEED@FDdDYpVcV]sEIJ@\nfjc@`@@YRYVum[ezLdjs`i`@jjjjhj@B\ndeTH@@RfUWihHH@CCdpjxYyC@\nfbmA@@@YEEMHdcLeHVRt[pVjjjjjjh@H\nfbmA@@@YEEeHhmEhXmV]zNVjjjjjjh@H\ndk^L@IANRY[f~]tvjjjj@LApjXUt~It`\ndo|H@@rJJIPjHqaZZijZBAh\nfgAP@@@LrQQJJYPtdKQk@@@@@@@XBQPTeZMX\nfH`pA@\neMJH|Df`pgd@\neOB@HcfhH';mlb.eE='gFq`@ldrfmU@XR|a@\ngKXHL@aJWFj`LBHmrD\ngFyHL`DILikUPD\ngKTHLPDIRxtlA``nR@\nfHgdA@\ngNp`@dfzZj@pJMX\neFA@H`bLFE\\`\ngCh`LDdsPFDWI`\neMHAIdLF^P\ngCa@@dkHFBVyH\ngJXLL@aAABDfVhB\ngJXHD@aIUZ@`\ngJXHD@aIYj@ppqyH\neMXIDe``\ngOx@@drm\\@@A`plZp\ngOx@@drm]UTAaqEcV\nfHapA@\ndid@@DjUfaBB`@LNaLinGdD\ndidD@@IIf]xViZPCBlJfGd\\\ndidH`DBHR[e^FX@@@`\ndid@p@bBbFbDfYoa`b@@H\ndidH@@RUe^Fh@@@pxHPj[nPH\ngCd@ADkj@ppbyL\ndifD@BADfyWaZ@@@LBQnGdT\ndeV@@@RgYTYj`@@C@PaLinGdR\ndiDD@@QIn]Zjh@pYLInGdT\ngNp`@dfuZi@pJM_I`\ngC`hIaxIVtA`enP@\ngGYHKAxIVkU@XYZ|PH\ndiFL`JcaCpRm[fjf@H\nfHbTA@\ngNtDLpDHHR[UjhB\ngGYHEAxIVsU@XEXwd@\ngNq`@jdvkSPf\\Ll~P`\ndaxB`HSN@HrRPyKUPAaaTwHx\ngCaHDIAIZ`LINS@\ngJXDBIARBS]TA`h^S@\ndiE@PBDIAIAInujjh@`\ndiED@BDDR[mVjj@LFPj[ayF@\nday@`Lx@aIUVjj@LNaLJf{d@\ndmv@@@Rf~UeZj@@@LEBDpfxYT\ndmvD@E@dfYwVzB@j@C@PpjxYT\ndmvL`BaL@HrRRjIJUVjjh@`\ndmvL@EAFR[f_FV``H@LFRfxU@\neFA@HoBJD\ndiGD@JxPQIeUZfX@`\ndiFB@BAFEInuZjd@pILJnQp\ngCd@ADij@ppfyD\ndaFD@DCdfVRiji`CCDinQ`\ndaGH`LJn@HRf_rjYj@H\ngC`@Die@ptVy@\ngNq`AVeJmUPFEbq_IP\ngC`DAb[DRVhB\ngCaHLLQIZ`LDEqS@\ngJP`@dfzhCCA[ba@\ngNp`@dfuZZDu`TZ~S@\ndaxD@@QInuij@LBRf{dD\ngGPBADZPLaYAIZjhB\neMABHYAIhH\ngNqBLIAREdGHIMmUTAaCrP\ngNt`BpdfyZZDu@\ngJX@@dmu@XKGdP\ngGX`LDdsmTA`m^P`\ngNx@@eZoUHD\ngJY@HDeVhCAK\\a@\ngJXDB@bABUmTA`Pl^R@\nfHbxA@\ngGU@DPdrmRAaecrT\ndedd@DHYCdfW[ZfZBBX\ndcLL@@STfVyVUZ`HD@H\ngNp@DkVzZ@`\ndaD@`@bDfUjZ@B@CB`SJ{dL\ndcLL@@QTfVUV]Z```@LNJfFUwd\\\ndaxh@LInAIUYffBDh\ndaDh@DInAIf]nZiX@`\ndmu@`LTHaIUe\\Yj`@`@`\ndaFD@N@dfYvyjV`C@lJfyG@\ndeVDPL[`bB|DeYgFZjZh@`\ndk^@@@Ri_YVftzjX@H@LEaLJae]L\ngC`HADIMTAa`mrP\ndeT@`@bLbdTJPsU@@@D\ndcND`La@BLddJbRrzmPP@@X]S\\LkoHp\ngNphJpDIKMULA`QD^Q`\ndiDL`JXPBLbTTJjfd@`\ndaG@`LK`BDimVz`@@B\ndeU@PAdH`haIf]vzB@h@H\ndmuD@FdBRgmeeZjjV@LNaLJaWd\\\ngNp`ATeejj@pXfM_H`\ngNqhHjOAJmVj`LLZ~HX\nfH`TA@\ndaxL`HS@BLddNRuT@XXUMrN@\ngGR@ACTkVY`iZ`\ngN|@ABeJ|mPTdxJofVH\ndax`@@`fRegej`RIJ\ndayD@LXJRVUYk`aJ\ndigH`LJn@HRf_ljfYh@ppBGdH\ndaFH@BAIeZf`@`@piLiny@@\ngNuHDx@cIHTej`H\ndknH@EAJYYfQN`bJ`@LIRfxYWS@\ndifH`BDHaIe]ih@I@B\ndmOH`LJQ@HRf^yriVfZZh@`\ndmNH@HCHhheDVzU`@@@@LNCJXYWd\\\ndcnH@AAIVYWXUvjP`H@LABDkag^Ph\ndew@@@pldTTJVTLmP@P@XUaMt|`P\ndaEH@DhDfVVyje`C@dJfyG@\ngNp`@deVZf@pvkyH\ngGQ@@dluTAaQEkrD\ngNq@@djuUPFCDqkyD\ngNq`@fdskUPFFq_IP\ngJU@HPdkU`P\neMhHRVCBP\ngCi@HDfZ@`\ngCh@@dmHFFBwI@\ngGYHLQDIJuU@P\nfH`XA@\nfHbXA@\ngNpHAxITkUTAaqEcV\ngKP@Di\\YZ@phbq@\ngJQHH@aJmj@ppQyL\neMJDBDf`pQyP\ngJT@@TfVdCAK\\PH\ndiG@`Dp`BDfWejjPB\nfHcdAa@\ngCh`LDdkPFDwI@\ndcNL@M@iRYg^vzB@j`@pdLJnFUt\ndigD@Dq`EIeYkfje`CCDqnQp\ndiT`@@rnRfUjEnBA``B\ndmNH@DAIe[VfeVj@B@CAdkae^Q`\ndedHXJBPRPrPzPFPfPrJPsRUSU@D\nfHcDA@\nfHdXA@\nfHdxA@\nfHgHA@\ndeTH@@RYeYn`HJ@CC`JfxYyF@\ngGQHJ@aIUjhCBqXwd@\ndaG@@@kdiVrX@a@C@hPfyG@\ndcll@DpYAmRYV]zzUZije`B\ngNtPHPjtfvZf@`\ndeVD@HADfvUFVh@@@`\ngGT`EaTf]jPLDmrD\ndaGH@DK`R[e[fiZ@LLQnyE@\ndmvD@BADfyW^Eh@J@CBdingdJ\ngGY@LDeVj`LJEc^R@\ndcnL`LaA@HrRPjIKTrzmPHD@FEYtkh\ndaE@@@aJyUnX@@@pkBinyD@\ndie@`NDHaIe]ih@J@CA`SBknPH\ndeU@@@aJueQfj@@@LAaLinF^P@\ngN}@EbDf]Zj@pJqoHp\ndeU@@@aJueQfj@@@LAALinF^Q@\ngJT@@Te^hCCKD\ndcwD@BWPQInuVZjjX@`\ndiVH@BAIfUInFjZi@H\ndaz@pL@HPHxHRYyZj`B\ndaz@pL@HPHXHRYvZj`B\ngGYHE@DYIHUj@prqyJ\ndayH`Dr@|Djyfjh@`\ngNp`@dfuZi@pJq_IP\nfHdpAa@\ngNv@ALZtkefj@`\ndieH`Dq`BDfUfnZii@H\ndaF@PDBHzHRYWih@H@H\ndaF@`N@HRf_rjYj@LFALJnyC@\ndaFH@BAIf]n``@@phLInyE@\ngGQDB@baBSKTpD\ngJPhLPDIKTpFDGEB\ndeV@@@RiU\\Yjjj`C@XSBkagdL\ndg\\`@@SFRYueUNvjjjj@H\ndg]@@@IIUYyT{zjh@@@`\ndaxH@@RV^jj`CAhPj[nHF@\ngGX`JDdjmTA`c^JX\ndg^D@IADfvYW}MjhHB@B\ngNq@@dl{MPblLZ~JX\ndctJ`HSBtOCIILXhduSUHQS@\ndkl@@LdbRdSRjP`jJ`@pfDJfxUOdZ\ndidH@@RYeVz@``@pXLJf{dB\ndigH`LJa@HRf^|jfZX@`\ngJQhHb@cIHUhCB[bA@\ndaD@P@qBbDfYvzB@@B\ndkm@@@IIUfU}OjhH@@H\ndid`@@pjRfUjXBB`@pSaxbL\ndcND@E@dfYwYn``Jh@LACBkaW^QH\ndaF@@@RevpjjZ@LJAB[nIF@\ndmvD@BADfy]fyjjf`B\ndifD@NADfvWaZjj@LJSBx^IS@\ndcND@IADfvYXYZjjZ@H\ndcND@BADfuYU]Zj@@@LASJxYW^PP\ndeTH@@RYe\\YjB@@C@Ppj[agdP\ndmvH@FCHhhhdYVhJ@@C@PcJ[aWbEH\ndcNL@LANRYygiUjB@`@`\ndifH@HCIDhYLJejh@`\ndaED@DHFRUe[fff@LDRnIG@\nfH`PAa@\nfHdHA@\nfHchA@\neFHBJFE@\nffs@`@@HRYyVWm[W`cVCDmVjjjjh@J`@H\ndcLD@@UIUe]FVX@J@aKCdrfx]yD@\nfewI@@DXldBSLjj\x7FJzriFJMEHymUDDUUT@@P@D\ndeVD@HADfyeFV`H@@piJ[ayD`\ndet@@DjYUZ^D`dJ@CBlJngfHp`\ndaFH@LAIVUnjjh@pZDJf{d@\ndg~H@AAJYU^wiNzBBJh`B\ndet@@DjYUZ^D`dJ@CCdpjxYyC@\nf`qa@@D@RYeU{TRg^Zij`@`DJVBbTxIVcV]{bLL@\ndmLH@@Rfum[iV`@jD@`\ndclD@@WIEDhbmSCMAPEH@XTa]N|Rf@\ndclD@@UJYY\x7Fkaf`bBh@LJPfg^IW@\nfgAA@@@ISLrotyHvk@@@@@@@P\ndeUD@DhFrJIJHusUMT@XYgCqDd\ndaE@@@iJUdf@H`@pRnydHp\nflu@P@@\\u{HhheEEMGEfJdzJV`hJ``H@@pecdeZMzJ^PB\ndet@@DjYUX^dHbH`CAdJfx^Id`\nfbmAP@@BU{NQQQQQQFVKYbmNbehJbHHB`@B\ndeTB@@pYRf[^njjj`CBXSBinFP\nfc\x7FAR@AU[OXICHiEHhhhblXdicBkvkNbdmUUULuUMSUT@FD\\DYpTeZMYp\\eFo_HM@\ne`\\PM@@@AHdbjnikgolbbbbbbTtRQTNTtrSBfgefRvsPADADqUUUUA@@P\ngNpP@btf{Zi@prqyJ\nffsA@@@YEHeHlcDeidfRtXLRujnjjj`@j@@`\nfb}`@@@YEDeMDhTihjLUiwhyZjjjjjjh@H\nfjcP@@@FrQQQQII[FIJgIVt{IP@@@``@@@@`\ndknL`LaE@HrRPzIJZ]Vh@b@CAlInd~Qh\ndeUH@JdDin]xZB@`@pIBX^IT`\ndg]L`LnDT@cIIChdieNkT@QP@P\ndclH@@rQQRJJuJ{PUDD@FEDwCoLjU@\nfbmq@@DX|CHhhdhddlTdQfgV|uTTEEUA@Aa[ENBdkQkNCEOHY@\nffs@@@LdbbdRdRQbLcKRU{HTmUUUUUUUP@XNqQgARtZwhiKWb@y@\nfewAa@AMfBPSHYEHiEEEDUeheme^uYt\\ujjjifjjZZh@L@xHs`iJtZs`yKT_H]@\neghPJD@AFimk`IAJPrJQRJJJHkKQK[PiJ^ZVNQYUUUUTsUUMMSU@@P\ndedL@@PTfUUZjf@LJpjz^Pp\nfnkA`@@N[dTRTtTTlVRbUFJlFNZmKUUUUUUT@F@TXipTeZMYw`iKWbLm@\nfig@P@@NZOHhdihhiXleDbjLUXL\\uZVjjjjjij`@`\nechX@@@@LdbbbRRQbvfRdrqC@bfadRUSRvuUUUUUUUUUTp@D\ndg|L@@v|dTTbbluRitEQDR@FCTwSm|Pc@\ndeTL@@zTfY[XXBH`@pHJz^I``\nf`q@P@@Ty{HeEEDhYDIVcLDQEUB@D\nfi{@p@@Zldh|dTTbblvrbbfaiIQjmhJbHjBHJP@B\ndk]D@BXCrJJJIPkiWV`d`X@H\nfhiP`@CAAQJ[gnyodgAhHHBB@@B\ndidHPBBlFlRYgVzB@`@phLKayE@\ndmvH`NTHaIeU^f`@jP@phLKaxbR\ndeV@`ABHRYeun`HJ@C@`pixeB\ndmv@`EBHRYe][hBBl@H\nf`q@A@@QGhaIfUvuv\\lz@`h@H@@pdCAIJtZwnHhp\ndeV@`IBHRYWVf`@k@CB`SBkd\\\nfbu`c@MDTBleVYbLbbbtReTTRsAQSAADtAA@@D\nfhi`A@I@b@qFQQQIIJEKLx{tAAT@D@@P\nfns`P@H`EYvQQQQQVZEIQILDhuVm@tDMUUTP@XZiqQoASdmV|`p\nflmA@@@ILkZjmsSdeV\\ELuMUUUUT@D\ndmtD@@QImYVUZh@@@p{B[ae^P`\nf`i`B@A@bDfUmvUhpTg^`@i`@H@B\ngOx@@eJimUTA`plZ~R@\ndeVH@LAIVYqejfj@H\nfb}A@@@ISZvmk\\lxkSoQsP@UUUUEP@P\nfig@p@@HdFJ\\bbTTRRtVbarRipwlezMjXJBQj`B@@B\nfoA@P@@HeYIefU]ipsfi`hD`@H\ndcLL@@G\\dTRRbOKPPTP@XRfES\\L{rE@\nfdu@@@LdbbTRrLtSI\\TZwhaDTUUTU@A`[AJLxIVcNCGfDR|\nflmA@@@YEEDhhTmMDsdmV\\ELAAUUUQT@D\nfdu@@@LdbbTRrLtSI\\TZwhaDTUUTU@A`YFBTxIVcNCGfFR|\nfnkAb@AUZBPrJQRJJJHkFIIWmV]EIZjjjYjjZj@CCvBLxJRmFlxNRmyAH\ndid@`@qDeYWaf@@BHlJ@j[nYBB\ndid@`@qDeYWaf@@BH\\F@j[axdH\ndeTH`ICDRUe_af@B@bJ\ndmu@PNTHbPaIe]Zf`@i`@pxDpjz^Ph\ndmN@@@RfV_Jaf`RB`@phFzUxbT\ngOy@HDfUkjj`LJlZ~P@\nfhy@@@LdbbTRtjVYHRg^BHh`@b@@`\ngNy`LETeVZZDs@\ndazD@BADfUvjXHj`\nfb}A@@@ILk[Kk\\tyKSoQsUSUUUUUP@X^AAFJLEIVcV\\EODQr\ndmMH`LVPBDiiu\\XUjjij@H\nfc\x7F@R@AUFlDadTbdTTTQVLRVtJU{UgQRVjjjfZjffjj@CBNBLxJRmFlxNR}godD`\nfnk@`@@UrJIJYQKISQHrgIZ]zNZjZjjjjjj@B\ndmtD@@QImYVUZjjh@pGBinFUyB@\ndk\\L@@STfUmWiiUjP@j@C@nESxfT\nfhy@@@DjUg^UzBu[pP`hhH@`@H\nfb}a@@L`rJJQIFYJYKDyIUgQSUUUUUTuP@P\ngNqhHf@cIICejPLH^KT\nf`aab@APQp@QddafaRbR]yZij@@@B\ndid@`@dDfYUn`HD@LJpj[nPH\nfoA@B@@RFQQQIEQILyYtA@p@@BGJ\ndmvH`Dd@aIVUwaZ@B`@pxDJfy^Q@\nfj}P`@GEAKIEDheED]idaZm{IZB@hBJjB@CCrBTxJRmFmxLTyy@h\nfigp`@DZBAJSJvnrnwJtYIW`}FuP@UUS@AD@A@\nfoQ`@@@ISLk^~FBuYuAH@@P@AaHANBdkQk\\Pqp\nfc\x7F@Q@AMzlD`fPrJQRJJJHkKQK[ZJ}jshykUUUSMUTuMU@A`GAF\\EIVcV\\DmQ{yCH\nfc\x7F@Q@AMglD`fPrJQRJJJHkKQK[Pj}jshykUUUSMUTtuU@A`GAF\\EIVcV\\DmQkxcNp\ngF|LHjOC^A|DiTt@@B\nf`qPa@LV``@QzPrRPqQIIXjlYruPTDT@A@\nfluQ@@A^AdRbRrTTRbKNN}EK@AP@@@@@P\nfa{A`@@E[dTTbRLrTfVrTIrRkNSejjjjjjijh@H\nfhiP@@@\\RiU{WZisQjjh@Jj@@`\nfj}PB@AVADILkkJzrmFFmdl@EUUP@D@A@\nfbmP@@@\\RiUyU^uipsdyjj```@H@@p]AAJBdkQg^CEODXr\nfdyAp@@XyHwhiSJrwoMANCUUTDDT@AajAJ\\EKQoAcqBE@\nfbu@H@@TyjwdyrIQQQHqISYBTFKADQUUTP@P\ndg~HPItHciCHhheEJlpz\\ADMLPAaPXpwrE@\nf`q`a@IZ|BHyHYEEDhiULfBtZ@bFfd`@`\ndmLH@@Rfum[iV`@jH@piLIaxdj\nffsA@@@ILklsJwoQbk^RVl@EPT@@A@@D\nfnkA@@@ISZvjsJklyIRZe[P@UT@@@D@@P\nfdeA@@@ISJ~sJ\x7FAF\\FMA@UA@D@A@\ndetH@@rQQJHtpsPT@`AaQMpsqDh\nfdeIB@LZmzH@cIEEEEeEDnRfkF}TmULsMP@XLAQbcNxbPP\nflm@@@LddTTVbvebyjUcNBfjjjjjjj@C@LDXIQgARUhuoQSr@P\ngJU@H`dkSBI`\ndmtD@@QIee^UZ``@@phfFUxe\\\ndmtD@@QIee^UZ``@@pinFUxaT\ndmtL@@QTfyeQehBA@C@jXYxb\\\ndcLH@@RYeZvz@`j`@pxBXYW^Q`\neMhDRUB\ndmuD@HTDrJZIJGaZ@B`@piBkix`j\ndmv@`LBHRUVUeZj@@@H\ndmv@`LCDRUVUeZj@@@H\ndaDH@@RYU[fei@LJpj[nP`\ndiFB@LAFEIg[Zjh@pkBiny@`\ndknD@MADfym]eVj@B`@pELinF]yA`\ndmvD@D@dfWeYUj`@@CCdpfxYyB`\ndifD@LADfyWaZjj@LBinGbHP\ndifH@BAIVUxZjj`C@PaLinGdD\neMPBcXLIyP\ndcNH@DCHheEDbnmPT@@F@hUMproHt\ndcMH@ITDee]UnX@Jh@H\ndaG@`LK`BLdTRIUSUpPea`IWHH\ndaDh@DqnAIeZfZZd@`\ndaF@`BBHRYg[hH@@LJCBknPp\ndaEL@LhDYIe\\jZjd@pcnQ`\ndk^@@@RfYU\\]Tz@@@@@LECBinFUOdZ\ndidHPBBHzHRYgfFBB@@phL[ayA@\ngOt@AdiguZj`LBmWrD\ndk]H@HdDeVYWz]NjdHB@B\ndcnH`Jd@aJYW]rnF`PJh@H\ndcnD`HI`BDfYoVnWZfX@@@`\ndk^@PIBHDHRYWY^fWX@JZa@H\ndg~H@ACHhdieDYSSl@EMTPA@\ndg~D@DClbbbTlRUL]mUL@D@FGYSRngrK@\ndmM@PAdI@iAIf]UneXHBd`B\ndieDPLZD@HhHrREQKaVii@LBrnGd@\ngNq@@dsmUPFEbq_DJ\ndctB`HSE@HrRPzKJKUUT@P\ngCi@DDfj@pPwED\ndmvH`IDHaIfUin`HJ`@`\ndo~L@M@iRYg^ufzB@jj`@pLLJnFUt{\\\ndo~L@CB]RfyV~^F`HJj`@`\ndg\x7F@`LIPBLdTTJRrVUJtsUUM@FD`S\\Lz]`\ndaxD@@QIgUjfBJlBpj{dL\ndmt@@DjYefdHbR@CBlinWbCH\ndklH@@rQSQJYGahBBi@B\ndkNH@DAIeV}VijY`pdYZ\ngJY@HDeYdRVFBwHP\nf`i@P@@HD[HhdihdhUSbkN|uHPTUB@FALT]{bEZ@\ndaxL@@rdenjjh@pZDrf{d@\nf`qpB@MF|BHRYWUVVcG^`@jjeH@H\ndclD@@[HhheBeSKkTp@P@XEpkoLri@\ndclD@@kHheCDdUKkSP@P@P\ndaFH@FAIe^fZVh@ppj{bI`\nfdyaC@OVAHHdLRFQRFIJZZKHRoAj`BIZX`@`\nfbma@@E@rJJJJISIIH|TyL\\mSHPA@D@@P\ngFp@DiTujdCBqXwd@\ndeVH@LAI[eQejZi@H\ndk]H`FTpbDfUmYkiV@Hjd`B\nfj}qB@BVBxDadTTRbRRTVasIFCzLDEETuUD`A`kENBtZJ\\eyCp\ndid@@LdbbQxXF@@CBdrf{bDH\ndklD@@QIge]aej@BX@H\ndg\\D`EtICHhdhXhUSP@UMP@P\ndmtH@@rJJJJia`HbP@phBinxdj\ndeeL`LZDh@cIHULhmMT@XUc\\L|`@\nfbuqb@LRuA@`AFRREQJKKSISUhiVhFB@@`@B\ndmtHPBBHfPRYeUXXHHh@H\ndk^@@@rQQHjIKJtzjX@HBJX\ndg^L@FAMrJZJIKPbkPPPr@FGIS\\JgrK@\nff}`P@F@QkNQSQQIZEJIJXRdeZBBFX@b@DCT\nff}`P@F@QhnQSQQIZEJIKHRdyZBBFX@J@DCT\ngK\\@ABeKcMHFDgDl\ndmO@@@`diWe\\JUfh@D@H\ndmO@@@`ldRabRpiVZ`@P@`\ndg~DPFvpbEBLbbRfbRM\\JpAESI@D\ngC`@Dio@pfyD\neMBBHR[B\nfjc@`@@ERYYefUez\\UyvPiZZjjjjjj@CCrLTXJVcV]zJ\\ey@H\nfb}@`@@YRYVum[ehrRkNBf@BjjjjJ`@p\\AFJ\\EIQk^bgODZB\ngGU@EPdvmVAaErX\nfb}A@@@YEDeMDhTihjLUiwhyZVjjjjjh@LGHqS`iJtZs`isrDP\ndk}@@@aJVyY|hUtyjBHJ@B\ngGY@DDfvZPLLC^IX\ngNx`HLdmluHdX\ndkl@@LdbbTbsyYfjihDaV`\ngNp@DjWZeDCaXl[rL\ndet@@DjYWkafefiPCBdKagfYS@\nfhiAb@HHp@HrRRqQIYPsdcVVfiVji@B\nfoA@@@LdbRbbJvDkQfijZjT@H\ndknDpNWPdDdLdLbdLTRbdzhHF@@`\nfhq`c@IF\\BPQHXdLbdLRTvfdDjj@Hfj@@`\ndif@@@Rfy^F`H@@pYBinGd@\ndmvL@HAER[e]xV`@h@LFPj[eyD`\ndkmL@HLDUInUv~Eh@Jh@H\ndknH@LAIYyfUMj`H`@H\ndiFL@JAARY[vji@LLpfxe\\\ndiFL@BAAR[fvji@LLSJxc\\\ndeVD@JADfvYzVjZd@piLXYyG@\nflea`@F@bgHhhhdhebmIVTYhIBhjXP@`\ndeU@`Dp@aIUeQej@@@H\ndg|@@DjU_eZx{BAH@@BJ\\MaBine]N~Q`\nfhy@`@@BrJJJJIQ[DQeNmyh@`HB`@B\nfdeIb@LLDhwh`BLdTrbRJbTOARTxM@PMUUE@AaHBJRu[pX|`x\ndg}@@@yJeWe^nNzjhHB@CAXPjFUt{yF@\ndk]@@@yJeWmZ{Sjj`@`@pVDJnFUt~Q`\ndcmH@DxLbbTTRM\\nmPLA@AaSCJ{rD@\nfhyPB@ARADILkkKZtYhw`p@UR@A@@P\nfhyPB@ARADYEEDdXeLdsfc^C@PUH@D@A@\ndk]H`AdpqDfUmUiev@Bfd`B\nf`y@@@LdbbTRfNSI\\TKSoADTT@A@@XZPRcARtZso\\a`\ndg|H@@RfuvU[cn`@`@@@peBiiWSodX\ndg|H`ABHRYW[ficn@BjjH@`\ndk_H@FdprJJISPkatzjjiZ@H\ndid@p@qBqFqDfYoa`b@@H\ngGP@DiUja@xEXwbD@\ngGP@DiVV`iJpJqoDH\ndeTH@@RYWVf`@j@CC`SBhYyG@\ndmtH@@RYWUih@Jh@LNALJiWb\\H\ndcLD@@SHihheJLmUTu@D\ndg\x7F@`IVpbDfUuYZX{`@jiR@LAALJat~Qp\ndigDPLXXP@b`cIHUDnEZfd@`\ndk]@`AdHaIe[VZYS`@ijH@pxDret~Qp\nfoAaB@G\\ADILkkJ}FFm@AP@P@A@\ngOxhMDOAJmZvjhCCXobE@\ndk^D`La@|Dju^UimMjj@B@B\nfdyQR@NBYhwh`qLbRbbrRfTHiNCMKUMUU@aB`\nfluQ@@DJAdTTTTTRTQsEVbEKU@C@PD@@P\nfoA`P@D@DZrSLrkrQfgMTC@q@@P\nf`q@`@@HR[fYU_Sk^Zh@@@@@LMHYpTeZMYwnPp\ndg]LPElYLHc`cHhdliBiSP@Rtp@XLBXUKrK@\ndcNL@JAMRYYYyUjijX@`\ndcnH`LD@aJY{grevj``H@LABDxYW^Ie@\ndg~D`LePBLdTRTrbNT]uU@pD@D\nfoAab@LRMX@PeL|lmxiiuUAPLP@D\ndeVHPLX@bPaJU{\\Jjfj@LJANF^IA@\ndaFH`Dx@aIYUnZjh@`\ndeTH`N@HRVUmaX@b@B\ndknH@CAIe]eZZ@Bjl@H\ndk^@@@RfYU\\]Tz@@@@@LI@j[aWSxfR\nfhi`C@I@dDRFICHiCDeMhdaJ|Fj@H`@@@H\ndif@@@RYevz@``@pkBkay@@\ndew@@@pldTTJVTLmP@P@XEc]ODHP\ndaGH@LK`RUe[fjV@H\ndaGH@LK`RUe[jjV@LLBfxdH\ndeWH@BZPRYVtYjje`CB`SNGbQP\ndmtH`EBHRYWUih@Jh@LNALJnWbCH\ndo|H`EBHRYWUnjZ@Bjj`@`\ndcMH@AtDieV_ehHJH@H\ndk}@@@qJYVu|kitvi`PJ@B\nfgAP@@@XRf^~UqQgCVZjh@J@@`\ndk^H@LAJYeUquSh@@@@@pzfxUt~HT`\nfjcY`@LJCENPBedbbTRTQRRTqJZLxLTuUU@aDuQ@AaJAJ\\EJvR|``\nfmoYr@CA[t\\xHpSbk@|LddqTRbrfbRRRfejJRmzMjjjjhDHfjH@H\ngGPhMQHIJmT`XR\\RH\nfewh`@DRMdXHyEDhhhddmiUDenRuzp^cZ`B@HFjjhH@H\nf`qPC@MNADBBEQFQQQIQGQIgG^`HJjeH@H\nfdy@@`@Q@`bTQFHRYeWvUv\\|F@`j`@`@B\nf`qPA@MNADBBDfUuUehqwh@JjiR@B\nfdu@@@LdbbbRRltSIBTZwhmUUUUUU@A@\nfigA`@@U{dTRTtTTjTtRJeFJMxJRmKUUUUUSUP@P\nffcP@@@\\RiUyU_YVgCNKVjjBBF@B@DGVDXHIPTeZMYwhirVoHX@\ndg}@@@yJeWmZntzjh@J@CAXSBhYt{yG@\nfdea@@D@RYZymUr\\lGtVjh@@@`@B\nfoAQ@@KN@eLrj\x7Fbthu@@@D`@D\ndg}@@@cIDmEDhcJg\\l@@@@QE@\ndcn`@@rnuJYVuhUtHJIb@LBSIWbMh\nf`ipB@DX|@HRYeYU\\cMNmyjhhJHH@H\ndmvH`DH@aIVyVUZX@@@pxD[ae^Q@\ndeTD@@QInUnEh@H@LBRnGbEH\ndeT@@DjU^k``b`@pyLinF^IA@\nfoQH@@@XHYJYg]UirRkN@bJjhh@H\nfgApB@LLx@HRevUUpPTcViYj@H@@`\ngOy@DDfUkZj`LBcWrX\nfoQa@@H@RVUmUV\\djsj@Bh@@@B\ndclH`ABHRYVyzy]`BFh`B\ndcLDPND@c@aJY~vrjefj`B\ndidHPACDZHrJIJFn`BH@H\ngO|@AfeJykSTA@\ngNt`MPdfUZj@pvKyJ\ngNt`IPdfuZj@pJu_HP\ndg_@`DGPbDfUueZZ@Bjj@B\ndmWD@Hi`QImfUjjj@H\nfhiP`@C^@aImYWVVRoAZX@JiRACEaiFBLxJVkNB\ndmUL`LZDh@cIHULdeijh@p[FxYWd@\ngOp@DiYKZj`LFHlWrT\ndcLh@DxYCHdeEDcJmPDD@FEIcCoH`\ndcLL@@QTfVUV]Z```@LFJfFUxgZ\ndg^H@LAJUyfUSjhBH`@`\ndeTH`L@HReyTYi`@@CC`RfxYyD@\ngGYHL`DIMlu@XR|pq@\ngGYHL`DIMlu@XHwbF@\ndiFH`Bp@cIECDjZj@H\ndcLH`BBHRYg^fzB@j`@`\ndeTDPBdHcoAIfUvFBBD@H\ndg\x7F@PBWPbAbLbbbRfaSR]pPTMQ@F@acCNg_HH\nfoApA@BZLBHeDYEEDhiiTqUgPPUCTP@P\ndcN@PBBHFHrJJIJXmLDED`A`HXwCJ{rB@\ndig@@@pdigwJZjf@LFSJ[ayA@\ngOu@E`drm[SRAalWrT\ndkmL`LNDD@cIIBhdmeuZ`PH@LFqneSyE@\ndg_L`LfxPPBLddJbbQvfmPLA@A@\ndaxB`HRnCpRk]Zj`B\ndeV@PIBHzHRYeea`Ha@CA`rfx^QH\ndmu@PITHchcHhheEVF@bF@`Z\ngChhMDOBNtA`enP@\ndid@p@qBqAqDfYun``H@H\ndidD@@qJYWkjjj`CAhPj[nPH\ndeTL@@rTie_kjjjh@pZDJnGbMH\ndcLD@@QIeVuWVj`@@CClInFUyF`\nfoA@@@DjYUgWfiF`XJbh`@`\ndidH@@RYWZZ@B`@pXDpjGd\\\ndaD@P@qNqDfUZZ@B@CB`pf{dH\ndklL@@Ptfym]eVj@BP@pyLinF^Qh\ngOpH@DISOkSM@XDZobQ@\ndk\\H`F@HrQQJVIHjtzeX@H@LA@jFUt~P`\ndcLL`NWPBDif~{JifZZ@H\ndid`@@pjrQQQUn@hH@LDJnHp`\ndaG@@@pdifZxBH@CCJ[nPP\ndg~H@IAJ[VvuneZ@Bfh`CCdpfgSyE`\nf`qQB@FF\\BPRYVwUZgAR`BJjfD@H\ngNu@Dpdr{UPFAVMyF\ndg~D@EBldTtVRTOBntDASQ@D\ndig@@@pldTTQk`Ha@C@biny@`\nfoAh@@@XHkVRJJHyQJTxZpDPsUBBGJ\ndaF@@@Re]Jjjj@LFBDpnxeL\nfoA`@@@YHhhhdeCHvgT@D@P@@XJ@Q`iJtZsnPh\ndeT@@DjUijP`j@@pzDinF^PP\nfhy``@E@xeLsO}kSdm^CPUAEUQ@A`YAJLEKQkN|D\ndiT@@DjYVnXPbD`@pYLinGdD\ndmLH@@RfyYxYV`HJD@`\nfoA`B@N@bLbbbTNbRXJshBH`@@@H\ndcLH`L@HrQJSPiKmMP@@A@\ndaFL@LANRYUJfjf@LH[bXP\ndie@`NDHaIe]ih@I@B\ndmO@@@pldTTLRqiUj@``@pKNe^HP`\ndmM@@@iJYYtjFYBHJ@B\ndaF@`J@HRfWrjYj@LLAFxa\\\ndmOH@FePRYVukaf@HZH@`\nfdyAb@HHpCpRkVYU_]Nmyj`@@B`@B\nfj}A`@@HTdssKMzsRuYp\\mPDQTuTT@D\nfhiA`@@Hddjrm|jIW`mPAD@@@A@\nfhiQ@@JJ@djlklkIW`mUUT@D@AaiFBLxJUg^CqDC@\nfakQB@CQDBPRYW[Ue]eZLCEoX@Ijjj`@H@B\nfde@`@@JrJJJJJIIGLUXOhmR@T@A@@D\nfdya`@O@x[HhheDlTdhsdmM@pQUU@@P\ndmLD@@qJY{WJeZj@B@CAj[ae^IB@\ndg^L@HACR[e]VxV`@jX@H\nfdea`@D@dkHheEDheDUSfoVBuLDpTT`@P\ndmtL@@RTeVUaUj@H@C@jXUydYH\nf`qa@@O@rQQQIISGBtju@@@QX@A@\ndcNH@FAIfYWgZ`hH@CAPcBinF]yB`\nfnsqa@BLSFkPRBiCHhhhhhddTmeNZlGrXHbhjejXh@LABehsoE[rC@\nffsA@@@ILvuoZunsfc^BVkSUUUUUUL@D\ndcnD`I[PdDfUm^neX@biH@`\ndk^H`MdICHhheCEfGS`HaiH@prfOfXn`\nfbmqB@BNcxD`dsLrzlvqUhasAATUSUD`A@\ndid@@DjU^nBAHBJ\\FaBiaxf\\\ndmtDPNDHaYAIfVUi``X`@`\ndknH@JAIUYfUNjjjj@H\nfhipR@LBBhug@BLdTRbrRfeIrcJjjfYfP@pxBBBTE[bOA@\nfbmha@LBm{Lm@BDaBTrs\x7F]riFTyEMUULsRuL@FD`PPR``isqGK@\ndaE@@@aJyUnX@@@pKB[nIE@\ngGP@Djuj`LLm^JD\ndmtH@@rQQEJZDjjfh@`\nfhy@`@@\\RYeeo]xjQg^ZB`@@h@@`\nf`iA@@@ISZvmjsbmN}P@@ETD@D\ndclH@@RfumVy]h@Jh`CCdpfFUyF`\nflu@`@@IRfum]fUgEZ}F`@jjjhh@H\nfbm@`@@FrJJQIFIKSIDx{r\\uUUUT@E@@P\ndmtDPBTLSlSHhhmDVFBBI@CB`pnGdR\ndmvH@DAIe[VUZh@@@pyJ[ae^Q`\ndk^@PABHtHRYWYZfWX@JVb@LFALJmxbf\ndifD`JxPBDig{JifZ@H\ndmNH`NTHaIfVUazXBHX`B\neMJDBDe`pQyP\ndmOH@NFPRYegXYUhD``@`\ndaDD@@iJY\x7FJjjh@pjLInyB@\nf`q@a@ARADJbDfYV]}YsQhBBjjb@B\ndg\x7FD@NfpqJYoYWJNzjjjV`B\ndg}B@HTDf|bfbbTThfnmA@tI@D\nfluPP@DTAsUlbbTTTlTvRXHshiZjZfX@`@CCbLLDFJ^P|\nfhyQ@@CA@dsLjm{Jvg^Bt@@DCA@A@\ndmMH`NV@BDke[VFUX@ab@LBpfWbAH\ndiU@@@aJmUJnFjjj@H\ndo}D@DTNrJIQSEQJaZjZjj@H\nfoAP`@DNAsHheEEJefBMYji`@h@B\ndiF@@@rQRJVjj`CC`SBiny@`\nf`qa@@O@rJJJIIKERMjsPTEEQ@A@\nfb}A@@@YEEHdcLeLeB\\djshijjjj`@j`@H\nfoQHA@FJuXFH`HRYUYYbTT[UjZjefZ@B\ndcND@E@TfUvvf`@jh@LEALJnFUt\ndeTD`AdHaIe]jZ@BX@LJALj^PP\nfhi`b@FN|BHRYV~YYirpX@bBA`@@`\ndmtD@@qIUe\\YZ`@`@piFxUxdT\nf`a@P@@HhyIeWfUsVZj`HF@@`\ndklH@@rJJJIEQa`Hbj@C@PIne]OdT\ndeTH@@rJJIEMtAAP@XTFES\\PY@\nfdy@`@@QrJJIEIQISLx{tAAT@E@@D\ndg\\H`BBPRYg^U[hHBjh@H\ndcLH`IBPRYeWvz@`j`@`\ndaD@`@\\DimVz`@@CAdpj[nP@\ngGQDHG@nFRQFj`H\ndet@@DjYUZ^D`dJ@CAdpjz^Hp`\ndaxD@@QInejj@LLRfxa\\\ngOq@@eLvmLtA`l~Ht\ndidH`ACDRYWZZ@B`@pXDpjGd\\\ndaFH@NAIe^fiZh@`\nfoAPB@AVADILkkJ}FFm@AUUQ@A`hBLDiIVcNyC`\ndmvD@LADfvUaej@B@CAliae^P`\ndmvD@LADfWeYUj`@@CAlIne^PH\ndknL`LaM@HrRRqIYPYV`@f@B\ndeVH@BAIf_VzB@h@LJCBinHL`\nf`q@a@AZAD^bDfUmn]hrsh@JB@`@B\ndaD@P@bNbDfUZZ@B@C@`pnxbL\ndcND@NADfUyU]Zj@@@H\ndeV@@@RV[TYzP@@C@j[axaR\ndeT@@DjU_k``R`HipZDJagfXw@\ngGX@@dj|tHkAF|Rp\ndeT@@DjY]zXFB@@pYLinGbEH\ndcN@@@RVYUYwiBB@Hr`\ndif@@@rRQHqajjZ@H\ndazH@LAIYzjj@LFALJnxdL\nfbmPb@B^dDDadTTRbbRRTQXjrXy``jJjZbP@pyc`kNSgfC^b\ndazL`BaL@HrRPyKUPA`a]qJX\ndmVL`BaL@HrRPzJIZjj@H\ndcvL`BaL@HrRPyQZKUUT@P\ngNs@EjpdssTpFFU_I`\ndmtD@@QIn[VUZh@@@pyLkae^Pp\nfoA@`@@BRYfYWuVLyh@`@@@CBUF\\EIVcNyBp\ndmt@@DjYnvDHbJ@CBlkiWdB\ndg}H@ATLbbbbbJpj]mMULm@D\ndg}H@JxDefY^Zy[YjZZZ@H\ndmvH@ACHhhhdYUhJ@@CAbine^Q`\ndaF@`B@HRYg[hH@@LJCJ[nPP\ndg}B@DpAV|bbbRbrK]imUMMU@FGXU]IwrM@\ndcnL`LZ]@HrQQZYPyPkSMUU@D\nfoAQ`@EZ@JVQQQQQIWLTZsT`tAP@D\ndk\\D`HP@cIICDhl^e]V`bB`@`\ndg~D@D@dfVumQd{Z`@@@@H\ndg~D@FCldTRQTRUL]uUT@D@FBpfESKiwrI@\nfoA`b@LRL@HRf[g^|TuZjhDHh@B\ndif@@@RfU~F``@@pxDpj[nPH\nfoAqb@BTYIS`RBSLnmnsakTmTuUP@P\nfoAqP@DXH@RcNrJJIJKJUgMVZjZZj`@pybgIFl{dM@\ndaEH@DHDfYVyje`CAJ{bXp\ndieD@DHFRYf^EjiX@`\ngG]@EbDf]jPLInIT\ndmuD@FxERf_UrjYZjBJh\nfoQP@@@JRi^yWZ\\DhujjhHBh@B\ndo}B@HtDUtfyW[WaZ@BZh@LAPj[mM~QX\nf`qQA@CVHBHEDYEEDeMCLfR]zBBbfh`@`\ndmtH@@rJJIJEn`HJ`@pxBiae^Ig@\ndmvH@EAJYYtYhH``@pYBinGbRh\ndg^L@LAER[eYWNvjhD@@H\ndcND@BADfuYU]Zj@@@LNrnFUwbHP\ndazB`LaFx@cIHThmS@FBXWDC`\ndcND@EADfvUtYZ`@h@LFSJ[axbz\ndcN@pBBlFlVlRYfyVfBBb`@`\ndiFH@BAIUgjjl@pZDrfGd@\ndiFL@JANRY[vjj@H\ndcLL@@G\\bbbRfK]@PUP@P\ndo~D@E@\\bbbReRd[hBBjj@B\ngJ\\@AbeMK@XKGdP\ngJ\\@ABe[LbQpfyhb\ndaz`@@bfyJUfZYBHX\ndmM@PBx@c@aJYg\\jeZdHB@B\nfoQh@@@XdhrTsMlkSdeFluMTsUP@P\ndk}@@@YJUUURkatp@j@@@CCdqiWSyD@\nfnkA`@@X[dRdtbRLrTfVsIZMxIZmUUUUUUUT@D\nflm@@@DiUem^yIRVkNBejjjjjjj@B\nfhyA@@@YEHhheDecKQoNCU@DP@P@A@\nffs@`@@VrQSRIQSJJpqBt[pXykUUUUUUUU@A@\nfhyI@@DDlDBSJkrmmFF]xKUM@DMD@D\ndk]H@LdDie[Wz]N``@@@B\nfbmAP@@\\}GNRJJJJIEJIN`cA\\dBB@@Hb@@CBSNBdkpXyxbs`\nfakAp@@\\}EIVyHhhhhdTheETjBLEvPHH@@bbj@@B\ndk]L@LxDMIe]eRkSZjjjh@`\ndcNDPBePbNBDfYWia``aX@LFCBimy@`\nfnsHJ@CASVBLDxjsP^FRRXjIQYSQIYRuEIZmUUUU@`U@@XFpRcARUjwlm@\ngGX`DJdvsTA`a^YX`\ngNy`HLtemfjDc@\nfdy`a@BRlBHcDYEEDehXhlfB|FBBFB@`@B\ndg}D@DXIrJJIQIH|ivuTB`P@P\ndk]@PAdH`paIe[UZY]`@iiH@`\ndaxB@@QnRUeZj`CBlJf{dP\ndk]H`LiPBDigm[rivfPBJ@B\nfoQAB@C@BDifYU^gIVtz`B@DH@@`\ndmtH@@RVYWeVhH@@LNRfxYWbPP\ndknL@HALRYyyWSZj`@@B\nfoAPb@ARLxDPdrmjktXkT@EMLd@D\ndg|@@DjU_eZx{BAH@@BJlIaBjUt{yfMp\ndifL@NAJR[Y^Ejfd@`\ndk^D@JADfV[W[mMjdHB@B\ndmOH@FyPRf_eriVjjeh@pkBhYxdH\nflmA@@@ILkZvmsQdeV\\EL@EUUUQR@FC`HqS`iJtZwhiy@H\ndkn@`ECDRYWUZf`@fj@cj\ndmvH`BTHaIf]un``J`@`\nflea`@A@bgHhhhhdmL]EVMyh@`@bX@@puQgAJtZsoI@\ndcLHPBCD{DrJJKQFLLDDU@A@\ngJPdLQDHHRViPH\ndg|@@DjU_eZx{BAH@@BJ\\IaBiiWSyf]X\nfleA`@@HcdTtbLRTrVVc^BuU@@@T@@P\ndaEH@LHDimVz`@@CAD{bTp\ndeWD`LjXP@cIHUDdLkP@@A`fMs@xP\ndigH@LxPRfuVz`@`@pQBxeB\nfhiHb@LB|FB@AFRREQQII[Z][ru@@@D@@P\nfhiHb@LBdFB@AFRREQQII[Z][ru@@@D@@X\\psbm^CqAk@\ndigH@LhPRfuVz`@`@`\ndeUD@LhARfuunh@J@B\ndkoH@DgPRYYe]SZ`hH@C@TJfxUOdZ\ndkoH@DEPRYYUfSZ``h@C@TJfz]OdJ\nf`qq@@IZLAJ[WUeV\\]z`@j@@@@`\nfbmP@@@IrRJJIQJIHdjmhKhu@DPQAT@@X^qS`iJtZsoAbgH\ngOt@ATiVKjj`LFHlWrT\ndid@P@bNbDfYYa`H`@LJBfx^Q`\nfhiAP@@XyKRTrlovmA^CUUUP@P@FAhDipTmFl{p^HPp\ndcM@pItIAICICHiCDeLJuPAB@D\ndg_H@FzpRYeUyEZ``bh@H\ndmtH`EBHRYWUih@Jh@LAALJnE^QH\ndcOH@NGPrJJQVIKmUURpAapXUMJ|b@\ndg_H@AVprJQRIVYG]UUUK@D\ndeWL@DpPzTfY[ifjfX@`\ndaF@@@RYe[hB@@LJCBknPp\nfhyq@@DZ|AIe[yVvcCV|EjVffej@B\ndmuH@DTDfYUQUjjj`CClJfxYyB`\nfbuQ@@DJAdTTRRQRRbRDiNVjjjf@B@PMP\ndknD@HALbfbRadxV`@j`@`\nfoAAB@A@bLbbbRebRYrshBB`@@@LM@pQgAJtZsnPh\ngJXHD@aIUj@pHVOI@\ngOq@@dsI[UTA`Ub~R`\nfoAA@@@ILs|kiFZLuU@AT@A@\ndeTD`FdICHhdhUWPAD`A`RYS\\`P\ngOp@DjukZj`LJlZ~R@\nf`iA@@@YEEHdcLeB\\djsjjjjjjP@`\nf`iAB@K@BDifYYWyjSc^h@`HP`@CBPBLEIVcNyCp\nfdeAB@K@BLdTTTRbRsWMR\\[u@DABEP@A@\ndcoH@DGPRUe[^e]Z@HX`CBdJnwbPh\nfb}P@@@NrRJJIQJKEKB\\hvoQsTEQ@PDT@@XNQbgARUjw`qSd\ndeU@@@{IEEEKP`QP`A@\ndevH`Bp@cIEEBdUCMR@D@D\ndmMH`Ad`bDfYuVzU``JR@H\ndcm@PNDHaPaIeU]iaf@Bfb@LFCBE]yB@\nfluQA@N^bBH\\DILrsmlnrUoNCA@qMTlT@D\ndcn`@@rawIEDhiUTkhPUCD@XDc\\oHt\ndeVH@JAJ[e^f``P@LJPfz^PH\nf`iQB@C^X@HrQQJVIJYDijsoUJpACQ@A@\ndeTL@@zTif[rjjjh@`\ndeTL@@SdfUUifiZh@`\ndcLD@@QIe[]ifiZY``Z\ndaE@`BhHaIfUn`H@@ppL{bTp\ndmv@HBBHFPfPVPRYUzih@Jh@H\ndmuD`FFUBHrJIJERn`BI`@`\ndknD@D@tfUe_WViB@`HJpEL[aeSyE@\ndo~D@DA|bbRbbRqvviB`R@`f\ndid@@LdfbQ[fji`B\nfakA@@@YEDeLlhheHmXjL}DNZjefjjjij@aeJprBBLTxJVcN|FJ\\ejwdN`\nf`qI`@DXUh@oYEEEELTlfRtYjjZfi`@piSakNyCp\nfdyHP@DXUh@oQrJJJJXiYILehsUTuMTl@D\ndiDL@@RdfVejj`CCB[nIP`\ndmtHPIBHVHRYfUXXBHX@H\ndieH@JxLbTTQkfej`CAFGbPP\ndeUD@FxJRVYmnYjZ`B\nf`qa@@M@RZYU_tVeFj`hHj`@LM@pRcNBTZsnHex\nflma@@@`rJIJYRIIIFcIF\\GtX@Jjjjbh@LG@Qb`iJtZsoQR\ndcl@@LdbbRRkCtaDQTPA`JXU\\LkrM@\ndid@p@bFbAbDfUfn`BH@H\ndeTL@@PdfzuFVjfd@`\nf`qA@@@ILroljJSoMA@P@@@FBlDipVcV]{dF@\nfhi@p@@XyHpTieY[wzB]zjjhHB`@LCPIS`iJtZs`|``\ndig@@@pldTTqkiZjPB\ndaE@@@qJYfn@b@@ppj[d\\\ndigH@LhPRfuvz`@`@`\nfhiHb@LBlFB@AFRREQQII[Z][ru@@@D@@P\ndeWD`LjXP@cIHUDdLkP@@AafMwD@P\ngJT@ADiZhCCBGbV@\ndaFH`Lx@aJY_JjZX@ppD[dD\nfhiPb@KN|D@PeLrj~lKRcT@@@Tp@A@\ndifD`Na@BLddJT[ejj`B\ndaEH@DpDeYVyjj`B\ndiD`@@iarQQHijVPPJj\ndk}@@@qJYWm\\katvid@J@B\ndknL`JaLCprRRiQIKSZjjj`B\ndet@`@bDfUUiaf@Bh`CB`pagbIp\ndclH@@RYfmj[iZZjj`B\nfoQA`@@\\ldsKKnlyKUgM@pQSD@FALJL{bJB@\nfgAa`@N@t[HhheDTdsdeFltC@UQ@A@\ndmMD@DhNRYYWIiUjA@`@`\ndieD@HXDR[eVyiih@`\ndeU@@@qJYejxBHh@LJJfF^Qp\ndmuH@DXDfUgjZ@Bj@B\ndg}H@NTDefV]qT{Zi``H@H\ndcNH@DCHheEBdnmU@@@FGIeMpkqIt\nf`a``@L@PdwJrkIoMUPPT@@P\ndazD@DAdeYvjh@pKBknIB@\ndefD`BpPbDemgijj@H\ndo~D@D@|bTTTTRqvvhJHb@B\ndmvD`La@|Dj~Uaej@B@B\ndaE@@@yJeVnBB@@`\ndmwH@DHPRYe~[fjVj@H\ndazL@BANR[UZj`CBdrf{dD\nfHgPAa@\nfle@`@@^rJJJIRYqQY`hi`HbjB@@@H\ndaF@@@Ri][jjj@LNaLJfx\ndif@@@rRQHkajjj@H\ndet@P@bBBDfYVX^fBBHPCA`pfx^QH\ndmL@P@bBBLbbbRaZ^FBBbD@`\nfoQa@@A@RYfYWvBUXsf`B@@`@CCeNRUhsnHEX\nfhy``@A@|dsLro~pRkF\\t@P@EP@A@\ngJY@HDeYhRVFFOH`\nfoAAA@F@bGQBSJwroSakPAD@D@@P\nfle@P@@HBeIeUUYVsN}EjjZZjj`HxjX\ndeT@`@dDfYWFZP`@HR`\ndid@`@bDf[Wai@@@LJ@j[nI``\ndmtH`IBHRYm]xZP@h@H\nf`qPB@E^ADILkjlkQcoP@SUUDBGJ\nflua@@E@rQSISIQJEIgEFbf`@jj@@`@H\ndeu@`DhHaIeURhYiZeh@`\nfb}a@@E@RfuUe]UYqQg^Sf`@jjh@H@@pT`eARtZpT|qbNP\nfa{a`@C@hwIEMEDdbdeLeeqQkAbVmAAQUT@EE@@XFPpTeZlxJ\\}y@h\nffs``@C@heMrklkjoIF\\FIZtDDTD@@D@@P\ngFx@@eLzuU@XFHwbF@\nfdyqB@BZ|hDQdTTRRLrbbXKtXHHfjjH@H\nfnsQB@IVDBHrJIJZEQQHjIJgK^jv@HZjj`@H@B\ndcm@@@uJfUWyYvjjjj@LISBinFUxdZ\nfoAq@@DDlAInfUWUXsfjjjjh@H\ndg]D@DDKR[e]UxVjjjf@H\nfoAQB@ARlBHRYVueZLTZ@Bfib@B\ndg}H@DHLbbbQTRS\\]mTl@D@FERng_Lrf@\nf`qP`@DD@iIfUumV\\]yjei@B@@`\ndmuL@DHIWHhhdcFyjef`B\nfhi@P@@HD[Hhdihdibj\\UYjP`hf`DGL\ndiD@@Dj}Yjj`CCdpj[ayD@\nfdy@`@@FrQQRJKZDjTdjuATQQMH@D\nfhi@@@LdbbRRNbRxkpXFBb@@@Ppp\ndmt@@DjU_ZxHHZ@cgChSBjUyc\\H\nfle@@@LdbbRbVQfRyjJXFBhh@@ACE@\ndaE@@@qJYVnBB@@pHj[nHf@\ndidH`D@HRUe^Eh@@@phBkaxdL\ndmuH`LY@BDfymYUj`@@B\ndcMH`DjPBDefulUZ`BH@H\ngOt@AdiWqZY`LCDWrT\ndg}H@NLLbbbTVaSR]pPRTi@D\nfhiAB@A@bLbbRaRbbRhqwh@J`HD@@`\nfhy`@@@YIEEDdXllQbk^CTCP@@P@A`kENRUhsoAxae`\nflu`@@@ILksLjoQchaSUUP@@A@@D\nfbu`c@@drBlEVQkLbbbRbTJRTkI^SAAQAAQ@@FF`XEIVc^CGOHV@\ndcLL@@WTfZYWijjjj@H\nfle`b@LPP@HrRPjIIKQIYQhiVhHHB@@@LCXYpTeV]xLT|aP\ngNq`@fdwKUPFAQkyL\nfhiA`@@HBdrsJrziuoMP@A@H@A`JcARUjwnHLx\nfdya`@H`PEIefUewTzwfh@@`F@@H\nflep`@OQRABSKLjo{JlYsT@@@Tp@AajcARUhsoQSrG@\ndifH@DAIfU[fjV`CBlJf{dB\nfjc@`@@ERYeu[VyV\\Uiwhy`HJjjjhj@B\nfb}A@@@ILk[Kk\\tyKSoQruSUUUUUP@P\nfb}@`@@YRfum[VwYqVg^bf`@jjjjJ`@`\nfhyh@@@XisVRJIJYIPiTDkW`aAQL@A@@XRQabcV]xOHZ@\ngCi@DDfj@ppfyD\ndeT@P@qIdDeYWxY`@`Ha`\nfdeIB@BTuEpIAIfUeUeYrt_A`HJjfhd@LNXEHu`qxcW`\ndg}H`BFPdLbbRRTTmLnp@TuP`FAYiwqDT\nfbmIB@BTtepICHhhdhddhhfsed~C@PUUMUD`A@\ndk}@@@YJUUURkatp@j@@@C@dZUxTYi`\nfhyP`@LRAyIYUVuugIJly`@h@JH@B\nfhyQ@@M^@eMk\\lzpRmN}PA@QAD@A@\nfhyQ@@NVAdbfRfRRTKARUYu@DT@T@@D\nfhyP`@EAAQJ[eWUWdmF|F``bh@@@B\nf`yP@@@FRifUV|cAVTxwj`YBhjH@LITxJRmV]{bLF@\ndk\\H`D@HRUe[Watv`@jb@LA@jzUt~Q@\ndaDHPNBHPHrJIPeUMT`FE@aTwHx\ndeTHPNBHPHrJIPiEUMUR@P\ndclD`HP@cIHXdiepkjp@UD@XLU]J{r@@\ndk^D`La@BLddlRTrF]MZ@Bh`B\ndcl``Ae]BHRYWYZY]`@fhPB\ndg~@PNBHTHRYUueicn@BjZD@pdLKaWSobHp\nfdyPc@IZxHDPPH\\DYEEDiDfeDfJCFBAXjfa@B\ndaF@@@RiUkjjj@LFaBinyF@\ndg|H@@rJJIHqIMqw@PP@@@XKaTwRng_H@\ndidH@@RVe~Fjjh@pzLJfx^P@\ngJT`LPdfvhCAX|b@\ndcLH@@RVYVnffjZh@`\ndeTH@@rJJIFMsSUT@XUeLL|``\ngOt@ADiYqfjPLMB~R`\nfhia@@I@RYeU{UDkpV``bjh`@`\ndcnH@DAIfYwXUuj`PH@LFJne]y@`\ndk^D@DCTfYgUXUMj`Pb@B\ngCi@HDff@pPwH`\ndknDpItpdDdLdLbdLRTtEZh@a`@`\ndmuD@HXDR[fUEV```@LLRexS\\L`\ndk\\L@@STfUm]iiUjP@j@CBlkaOdR\ndieD@DpFRYUrijfh@pILx^QP\ndcnL@LAFRYV]Zy]Zi`@@B\ndmL@@DjYUVGi@@@`@LNpjxYWdH\ndet`@@iiRfYunFVifi@LLpayG@\ndidh@HJfAIfYxZie`B\neMbDBDfp`\ngJPXHlQLQzlA@\ngC`DADZHRVhB\ngC`DAbZHRVhB\ngCahHlNbNlA@\ngJQhHl@cIHUhCBGd@\ngKP`@Ti\\Zj@pRwI@';mlb.fE='daD@@DiYZYji`@\ndaD@@DjUZxHD@@\ndaD@@DjUZxHH@@\ndaD@@DjWjXHB@@\ndaD@@DjWzXHB@@\ndaD@@DjYvxH`@@\ndaD@@DkeVyjj`@\ndaD@P@bBbDfYvzB@@@\ndaDD@@IIf]nZZh@@\ndaDD@@IIf]n``@@@\ndaDD@@YJZUnjjh@@\ndaDD@@aJVdnjjh@@\ndaDD@@yIe^f`@`@@\ndaDH@@RVU[j@@@@\ndaDH@@RYVih@H@@\ndaDH@@RYe[hB@@@\ndaDH`BCDRYg[hH@@@\ndaDH`NBPRYWih@H@@\ndaDH`NCDRYWih@H@@\ndaE@@@YIeZn`B@@@\ndaE@@@aJyUnh@@@@\ndaED@DpFRYVkfjY@@\ndaF@@@RYe[hB@@@\ndaFD`L[`BDi]lJjf`@\ndaFH@BAIf]n``@@@\ndaFH@DAIYUnZjh@@\ndaFH@DAIeUnZjh@@\ndaFH@FAIeZn`B@@@\ndaFH@LAIVUnjjh@@\ndaFH@NAIe^fZVh@@\ndaFH@NAIe^f`@`@@\ndaFH`LP@aIe\\jZjX@@\ndax@H@SHbDbLbLddjUUT@@\ndax@P@SHqDjmZjh@@\ndaxB@@rnRV{Zj`@\ndaxD@@QIgUjj@@\ndaxD@@YIgYjf@@\ndaxD@@iJU^jj@@\ndaxD@@yIUVjj@@\ndaxHpJBPRPrPrJPiUUH@@\ndaxL@@SDfUVjh@@\ndaxL@@idiUZjh@@\ndaxL`HS@BLddNRuT@@\ndaxL`HS@BLddNbuT@@\ndax``HJn@JRgmjZp@\nday@@@yIUVjj@@\nday@@@yIUWjk@@\nday@PDh@c`aIUUZe@@\nday@`Dp@aIfYjj@@\ndayD@HPNRVUZj`@\ndayD@LHNRUUZZPcH\ndayH@DpDfYfjh@@\ndazB@BAJyImmji@@\ndazD@LADf]Vjh@@\ndazD@LADf^fjh@@\ndazD@LCdeYzjh@@\ndazD@NADf{Vfl@@\ndazH@DAIeYjZ@@\nda{D@HQ`iIYejZ@@\nda{H`Dpn@HRYeZjP@\ndcL@@LdbRbceBDEEP@@\ndcL@X@bBbFbAbEbMbDfYn\x7Fijjjj@@\ndcL@X@bBdFdAdEdMdDfYn\x7Fi`bHh@@\ndcLB@@imReUUUvjjjh@@\ndcLB@@riRfY~Qfjjjh@@\ndcLD@@IIf]^xViZjP@\ndcLD@@uIfUk[hBBj@@\ndcLDPDtHaXaInUvxY`@i@@\ndcLDPEt@b@cIDhTdiaUUUM@@\ndcLF@@Rag\\bbTVTILuSUT@@\ndcLH@@RYeUqVhHH`@@\ndcLJ@@PUuInUgzV`BJ@@\ndcLL@@STfue^UZX@HBL`\ndcLL@@STfyWWaZ@Bh@@\ndcL`@@qaRfU~ZxHDj`Hj@\ndcM@@@aJufYgZhBH@@\ndcM@PEtH`haIf]u[hHBj@@\ndcM@PEtHchcHhheETppDQT@@\ndcMD`LE]@HRV[]nEjiih@@\ndcMH`BuPBDf[U{aj@BX@@\ndcN@@@Ri]mUvjl@@@@\ndcNB@BAEuInVVFV`HF@@\ndcNBAHAEvISdfyV{iZ@HX@@\ndcNBAHAEvISdfyW[aZ@BX@@\ndcND@BADf{YU]Zj@@@@\ndcND@E@\\bbRafUM@AUP@@\ndcND@E@dfYwYn``Jh@@\ndcND@MBldTtRROSPPQP@@\ndcNH@EAJ[WU[j@Bj@@\ndcNH@FAIfYWgZ`hH@@\ndcNH`Bp@aJY{UWZZjj`@\ndcNL@FA]rJJJJJlLADU@@@\ndcNL@LB]RVV]vE`BFP@@\ndcNL@M@iRYg^vzB@j`@@\ndcNLaIQ]BHf]yInUvxY`@f@@\ndcOD@DgPGHheDhkrmUSU@@\ndcOH@NFPrQISQHrmTAA@@@\ndcOLAHHPSXeNrJZJIHlKTuUH@@\ndclD@@GIEEHhfUKmAU@P@@\ndclD@@UIfV][iuhFAH@@\ndclD@@iJYW]rnF``JX@@\ndcll@DpYAmRYV]zzUZije`@\ndcll@Dsm@iRYgeVE]ZjeZ`@\ndcm@@@YJYYwhUtH@@@@@\ndcm@@@{IDeCDdUKh@UUD@@\ndcm@@@{IDeCEDUSh@UUD@@\ndcmD@DHERYYUZz]Z``R@@\ndcmD@DpFRYV]Zy]Zi`@@@\ndcnD@D@TfYg\\fWVjYjh@@\ndcnDPN[PBABLdTRbauCtuTuSP@@\ndcnL@LAFRYV]Zy]Zi`@@@\ndcnL@LAMRYUUrhYZh@h@@\ndcnL`LaA@HrRPjIKTrzmPHD@@\ndcndADkaTMz]yIefU[iUjeji@@\ndco@@@bdigyWJWYj`@P@@\ndctB@@RURY]VvjjZ@@\ndctB@@ieReUWZjjj@@\ndctF@@rngTen{mjjj`@\ndctFPHSNePBABLddNRTbuUK@@\ndctH@@RYuUVjjj@@\ndctHxJBPRPrPFPfPVPvPrJPqJQUUUT@@\ndcu@`Dp@aIeUUZjjh@@\ndcuFPBvDsiT@`PcIICdeHmURp@@\ndcwD@HQ`iIYgmZfjh@@\ndeL@@Di[ernDYZjij@@\ndeL@@DjYeIjGijjjj@@\ndeLD@@EJUWhRfFZjjj`@\ndeT@@DjWvifjih@@\ndeT@@LdbTRoBuUM@@\ndeTD@@EIe]jZ@Bh@@\ndeTD@@QImeQej@@@@\ndeTD@@eIfu~Eh@H@@\ndeTD@@gHhhhjppDQ@@@\ndeTD`AdHaIe]jZ@BX@@\ndeTD`NDHaIfVVfBA`@@\ndeTH@@RUYTYY`@@aH\ndeTH@@RUYTYi`@@aH\ndeTH@@RV[TYjP@@@\ndeTH@@RYVZfZZj`@\ndeTH`IBHrJJJJlLADP@@\ndeTL@@PTfyVzV`B@@@\ndeTL@@QdfygFV``@@@\ndeTd@HRi@TefUzVjih@@\ndeU@@@aJWeQfj@@@@\ndeU@@@aJueQfj@@@@\ndeU@`Dp@aIgeQej@@@@\ndeUD@DdARYgxfZjf`@\ndeUH@HPDefuFVh@@@@\ndeUH@JdDin_xZB@`@@\ndeV@@@RgYTYj`@@@\ndeVD@BADf{YxVjjX@@\ndeVD@D@TfVgJfjih@@\ndeVD@DAdfygFV``@@@\ndeVD@FADfygFV``@@@\ndeVD@IADfyWxV`@`@@\ndeVDAHAHeNR[e[aZ@B@@\ndeVDAHAHeNR[e_aZ@B@@\ndeVDAHAHeNR[fTYZ@`@@\ndeVDPJJPqFqDfYokjVjX@@\ndeVDaBxPbBd^RYeei``X@@\ndeVDaNFPbNf^RYWZf`@f@@\ndeVH@IAIe]ZZ@Bh@@\ndeVH@LAIUeQfjjj@@\ndeVHpDxHbhbXcHheEJptuMH@@\ndeW@@@RTfyWxV`@`@@\ndeWH@DZPR[e_aZ@B@@\nded@@DiUUjjj@@\nded@@Dj_VfZZ@@\ndedB@@RiR[UUijhHr@\ndedB@@iiReUvjjh@@\ndedD@@QIkWZjj`@\ndedD@@QInUVfj`cH\ndedD@@QInUVjj`@\ndedD@@aJVfjjj`@\ndedH@@RUUVjjh@@\ndedHXDBHjPZPzPFPfPRYZZjjh@@\ndedHXJBPRPrPzPFPfPrJPsRUSU@@\ndedH`HALRkUUjjh@@\ndedJ@@rneI[nvjj`@\nded`@@iiReUvjjh@@\ndedd@BXYADfyvZZfBL`\ndee@@@gHeHiCuUV@@\ndeeD@BdDR[mUjjh@@\ndeeL@HdBEIVUfji`@\ndefD@LADf^]Zjj@@\ndefD`FFPBDiWnjjf@@\ndefH@DAIfWvjj`@\ndefH@DAIfuVjj`@\ndefL@IAAR[UYjjX@@\ndefL`F`Y@HRkvyjjX@@\ndefL`JHY@HrJJEJUMS@@\ndeflAHrfxDfISdfvyZfi@@\ndegD@HZPEIUUfji`@\ndet@@DjYUX^d@@@@@\ndet``Dki@HRYYUnFVjVi@@\ndet``DkiBHRYYUnFXBBa@@\ndeth@DkiAIeeVxYZiZd@@\ndeth@DxYAIeeZxYZfYh@@\ndeu@@@kIEEDceCLaPD@@\ndeu@`Dp@aIeURhYfh@@@@\ndev@@@RYyULFZh@H@@\ndev`@@rfeJY{ZxYBBJD@@\ndew@@@pldTTJVTLmP@P@@\ndg\\B@@Q[R[VUmgVf@HhBL`\ndg\\D@@eIfU_Un`HJj`@@\ndg\\H@@RYWY^ih@Jmh@@\ndg\\H@@RYvYiVvfZjjBL`\ndg\\d`LF[a@BLddJbbQvfmPLA@@@\ndg\\h@Fd{AIfUWxUZABI`Hj@\ndg\\h`LJfd@aJ[Ywkaijejh@@\ndg]B@NTBNtfY}[fyjVjf`@\ndg]D`NV]BHRYWVyih@JZh@@\ndg]HPAuPbBbDfYw[fzB@ij@@\ndg]H`AuPbDfY_[fz@`ij@@\ndg]L`LnDD@cIIBhhd]ikTC@P@@\ndg^@@@RigvuNzjk@@@@\ndg^B@BAEoHiihdhUNmT@QP@@\ndg^B@BAMoHiieDeBimU@DP@@\ndg^DPNI`BDBDfumeSmZf`@@@\ndg^D`INpbLbdTJTv`kU@DS@@@\ndg^D`La@BLddLTRRIvmTE@@@@\ndg^H@DCHhhhddYimTE@P@@\ndg^L@EACR[YWVFVh@JX@@\ndg^L`Iia@HrIQPjZIG]TtuU@@\ndg^LpDx{BHjHVHrJIQPiZLLADUL@@\ndg_@pNfpqDBCBDfUyWbjfijfPad\ndg_BAHJ`QSbT{HiheBidwMMUUR@@\ndg_L`LfxPPBLddJbbQvfmPLA@@@\ndgl@P@SHbDjmUUZjjjh@@\ndglB@@Q]RYUumZjjZ`@\ndglFPHSItpBEBLddNRRTbuUTl@@\ndglP@@anESoIDhhd\\iMSMS@dWP\ndgll@DrSAmRYV^uZiik``X\ndgmFPBnDr]L@aPcIICddeHmUUK@@\ndgmL`DVCl@cIICDmihmUUS@@\ndgnNPKaLXYTOBoCIIKHiMTuUMU@@\ndgoL`LD~gPBLdTtTjTuMSTt@@\ndg|@@DjU_eZx{BAH@@BJ`\ndg|@P@bEbLbbbTVbKR]pP@P@@@\ndg|D@@MIfV]UivviP`R@@\ndg|H@@RVUvU[cm`@`@@@@\ndg|H@@RVUvU[cn`@`@@@@\ndg|L@@t|bbbbbJcBmm@tCD@@\ndg|d@Dq]@\\bbbbfJSSimUSTs@@\ndg|laLJce]@HjUyJYn[gFNzZZYj`@\ndg}DPEtYBHXHrJIJZQGUvg@DKUB@@\ndg}H@IlLdTrTraS]Jt@EMQ@@\ndg}L@hdDNISid~R[fV]F]mh@@H@@@\ndg}L`JXiTIAIf]VunNzVjZj`@\ndg~D@D@\\bbTbTjQL]mUR@D@@\ndg~D@IB|dTrTraS]Jt@EMQ@@\ndg~D`LS`BDfUueRh{Zjh@H@@\ndg~L`EF[BHRYVyukev@HZiH@@\ndg\x7F@PBWPbAbLbbbRfaSR]pPTMQ@@\ndg\x7FH@DjprJIQEQIMqvuRp@P@@\ndiD@X@dDdLdJdNdAdLbdLtjjh@@\ndiD@`@RdjeVjj`@\ndiDB`HSB@HrRPiIZj`@\ndiDD@@QImVZjh@@\ndiDD@@QImZZjh@@\ndiDD@@QIn]Zjh@@\ndiDH@@RVUjjj@@\ndiDH@@RYWZjj@@\ndiDH@@RYuVjj@@\ndiDL@@Pdf]ijj`@\ndiDL@@RdfUUjj`@\ndiDL@@idiUVjj`@\ndiDL@@xTiUVjj`@\ndiDLB@PTyInuZZh@@\ndiE@@@aJuUjjh@@\ndiEL@HPJyIYvZjX@@\ndiEL@HhNEIgVZjX@@\ndiFD@AADfuUjj`@\ndiFD@BADf{Yjj`@\ndiFD@FADfumjjP@\ndiFD`JxPBDivzji`@\ndiFD`JxPBLbdTljjX@@\ndiFD`JxPQDivzji`@\ndiFHPF`@`PaJoUZjT@@\ndiFJAHALXXgNRYvvjj@@\ndiF`@@SNGHhhcFjf@@\ndiG@@@HTeUWjjp@\ndiGD@HQ`kHeECFij@@\ndiGD@HhPyIUVZjX@@\ndiGL@HQ`h\\bTTQZfh@@\ndiT@@DjV]nxVjihHB@\ndiTH@@ReUxRfjjf`@\ndiTH@@RgeXSaj@B@@\ndiV@@@RfU|kadHB@@\ndid@@DjYUaBHP@@\ndid@@LdbRQk``b@@\ndid@`@bDfUff`@h@@\ndidD@@EIfU[ffiP@\ndidD@@EIfU[hBB@@\ndidD@@GHhdhZZ@B`@@\ndidD`BD@aIf][hHB@@\ndidD`BDHaIf][hHB@@\ndidD`BDHaIf_[hHB@@\ndidD`BDLQIf][hHB@@\ndidH@@RUe^Fh@@@@\ndidH@@RYVZZ@B`@@\ndidH@@RYWZZ@BP@@\ndidH@@RYm^Eh@@@@\ndidHPNBHPHRYWbjfid@@\ndidL@@IdfYoa`b@@@\ndidL@@XTfUfn`BH@@\ndie@@@EIfW[hBB@@\ndie@`BDHaIf][hHB@@\ndie@`Dh@aIefkfif`@\ndieD@DpFRYVZyjfd@@\ndieD`JXaBPRYgvzejX@@\ndieD`LIN@HRZufFZid@@\ndieH`DpPBDfYeaZjj@@\ndif@@@rQQIFfZjj@@\ndif@@@rQQIFfjjj@@\ndif@`D@HRUe^EX@@@@\ndifDAHAHeNR[e^Eh@@@@\ndifDPJHPqFqLbbbekjVi`@\ndig@@@xTjU^njjj@@\ndigDaLHVx@cI{dieljjUj@@\ndigH@DK`R[e^Eh@@@@\ndkL@`@SDjUUUjjjj@@\ndkLD@@QIe[WVijj`@\ndkLFPHSAWPBIBLddNRRdVjjV@@\ndkLF`DkaTpBLbdtVafjjji@@\ndkLH@@RUUUVjnzl@@\ndkLJ@@imMJUUUZjjj`@\ndkLP@@anF]OIDhhjeIjYi`RKh\ndkLP@@bfF]OIDeDTeIiii`RKh\ndkMFPBNDpUt@bPcIICddiEjje`@\ndkNLPFi]@HLHrJQRjJJjZih@@\ndkNLpFjUBPRPrPrJPsISJjZfd@@\ndk\\@`@bDfYYwZ]NB@@@@@\ndk\\D@@wHhhhhbfESZAhD`@@\ndk\\D`ELLSHhdidhZZ]`@iYH@@\ndk\\H@@RYeg]itxH@@@@@\ndk\\``LyS@HRfUeTUtzBHba@@\ndk\\d@Dq]@\\bbbbfJZ]MjjZe`@\ndk\\d@DrUCdfY[uXUujijY`@\ndk]@@@uJYU_lkihDHj`@@\ndk]D@DxJRYY{Tjtvfh@H@@\ndk]DAHDMF]yIYeg^ESh@@H@@@\ndk]H@ALLbbRfTJiaf@Bfh`@\ndk]H@DHDfYyWImMjhHA@@\ndk^@@@RfYU\\]Tz@@@@@@\ndk^@@@Ri_YVftzjX@H@@\ndk^@PDCDNHRVf]}aWZjB@h@@\ndk^D@A@|bbRfTJiaf@Bfh`@\ndk^D@IADfvYWz]MjdHB@@\ndk^FAHALzSb\\{HhmEDdQe]Zjjjh@@\ndk^HPNHJrXaIf^UvGS``B@@@@\ndk^L@LANrJIQQEJatvjf@@@@\ndklB@@PcR[me]]Zj@B@@\ndklB@@QSrJYJIJF]ZX@b@cH\ndklB@@QmR[fUxUZBBF@@\ndklD@@QInUvnEh@Jh@@\ndklD@@eJ[Vvfz`@jh@@\ndklDpBhJqJs@cHiiCDeeviX@H@@\ndklH@@RYfVya`Hbj@@\ndklH@@rJJJQJy]ZBhB@@\ndkl`@@SFRYvUWSZjjj`@\ndkl`@@kaRe[vTf@HZj@ah\ndkm@`ATHaIe[ujZ@BfhBA`\ndkm@`MLHcHhhdcDfz@`Z|@@\ndkmB@hHD[heNJ^{HihhhTmMjf@@@@\ndkmD@DpJRY{YWSZf`@@@\ndkmDBLdDf\\bbTTJTWVj`@`@@\ndkmDpDgSBHjHVHRYYmYn`HJf@@\ndkmH`NVPbDfUunih@JZ`@@\ndknD@DATf^UuFVh@J`@@\ndknD@E@\\bbRafRih@Jj`@@\ndknD@LALbbRbaRtvjh@@@@\ndknD`J``BDjy{Utvfjjh@@\ndknL@BACR[me]]Zj@B@@\ndknL@BAMR[meYSZj@H@@\ndknL@M@iRYg^un``Jj@@\ndknLBLANSlbfbTaRtvjzjh@@\ndknh@HF]LDee]V[iiYihDbz@\ndko@@@aLdRbbRQtvjB`@HB@\ndkoH@Dp`RYuYWSZj`@@@\ndk}@@@iJUmUR[atpBJ@@@@\ndmLB@@RURYUVJaejVjh@@\ndmLD@@QIe[VfeVi@B@@\ndmLH@@RYiYKnUjjjh@@\ndmLH@@RffeZVVjjjh@@\ndmLH@@rJJIQEneX@@@@@\ndmLL@@SdfVUrjUZ`PH@@\ndmM@@@[IEDhhZFU@B@@@@\ndmM@@@aJUe^neYhDB@@\ndmMD@DdNRYYWJiUjA@`@@\ndmMD@DhNRYYWIiUjA@`@@\ndmMh@DkaePRYYe[iUifjd@@\ndmN@@@RYVuiiVj`@`@@\ndmN@pN@H`HPHrRPqIZneUhDB@@\ndmND@BA\\bbbReInFjZjd@@\ndmND@DBdfV]RZUZf@@@@\ndmND@DCdfVUrjUZ`PH@@\ndmND@DCdfVUrjUZfZj@@\ndmND@DCdfVUrjUZjZj@@\ndmNDPNYPBABLdTRbch^fjfih@@\ndmNH@NAIYe^neZdHB@@\ndmN`@@raeJY{VfFP`JX`@\ndmN``DkaT@aIefUneVjVjP@\ndmNh@HqaTDeee^FUhBBa@@\ndmOD@DiPyIee\\feVhDB@@\ndmOD@DjPyIee\\feVhDB@@\ndmOH@DK`RYYWkiUiB@`@@\ndmT@p@SHbDbLddJRRjjj`@\ndmTB@@ieReUWjjj`@\ndmTB`HSBCpRjuUZjj`@\ndmTBpHin@JspDJrQIRGJjZj@@\ndmTFPHSFFPBNBLddNRdVje`@\ndmTH@@RUUUjjj`@\ndmTJ@@IaUIf[~jjj@@\ndmTL@@xTiUUZjjh@@\ndmTLPDp`|HdLddJTTfjj`@\ndmTl@HQeBiRVY~Zfi`@\ndmU@HLT@a@c`bPaIggYjjf@@\ndmU@pLD@a@c`cHheEKFjfh@@\ndmUD@DXARYW[ZffP@\ndmUH@JXDiUYjjjh@@\ndmULAFDDIiGdf{evfYh@@\ndmUL`DzIT@cIICeMEjjX@@\ndmVB`NiiT@cIDeEKJijX@@\ndmVH@DAIYUUjjj@@\ndmVL`JFU@HReYyjjf`@\ndmWH`DphCpRjyfZjj`@\ndmtB@@QeR[f]FV``H@@\ndmtB@@QeR[f_FV``H@@\ndmtD@@UIfU|YZB@`@@\ndmtD@@WHhhhiVF@bJ@@\ndmtD@@iJ[g_ahHBP@@\ndmtD@@kIEEHeYV`j@@@\ndmtH@@RYeY[hBBh@@\ndmtH@@Rfuu[j@BXBA`\ndmtL@@SdfVyyUjB@@@\ndmtL@@YTf[gqehHB@@\ndmtL@@yTee[VE`BJ@@\ndmt`@@kaRe[vI`BFhBF`\ndmu@@@aJueXYj`@`@@\ndmu@@@aJue\\Yj`@`@@\ndmu@@@aJufVUj`H@@@\ndmu@`ITICHhhdbfz@`j@@\ndmu@`ITLSHhhdbfz@`j@@\ndmuD`LVD@HrRRqIXYV`@`@@\ndmuDaBWaBHJQ{HhheEVfBAb@@\ndmuH@HPDefUyUjB@@@\ndmuL@DTAeIf]XfZjih@@\ndmuL@DpFUIeY~nZijd@@\ndmv@@@Rf~UeZj@@@@\ndmvD@DATf^Uqej@B@@\ndmvD@E@dfYwVzB@j@@\ndmvD@EADfyW^Ejjj`@\ndmvD@NADfVyyUjB@@@\ndmvDPDePbAbDfUmjZ@Bf@@\ndmvD`EJPqDfY}VzB@j@@\ndmvD`La@BLddlTReUhB@@@\ndmvD`NePBDig{ljfZf`@\ndmvH@FCHhhhdYUhJ@@@\ndmvL@FAIR[f^EV```@@\ndmvLaFFUCDZYyIe[fn`BF`@@\ndmw@@@aDiUmYUj`@@`H\ndmw@@@aLdRbaReVj@@B@`\ndmwDAHEPRISlbfbRazV`BH@@\ndmwDAHYPRISdfygQehHB@@\ndo\\@T@dDdLdJdFdAdEdCdKdGdLbdLaffdjjjjh@@\ndo\\J@@imMJUUUUjjjjh@@\ndo\\L@@idiUUUVjjjj`@\ndo\\NPHQevw@DHDrRYJKJHqjfii`@\ndo]B@L\\Dv|bbtTTUTZjjjX@@\ndo^J`CaLKP|LddqbbTlZijfhHi@\ndo^bAHs[\\DxXeNrJYQQEIQjiji`@\ndo|D@@QIn[WVeVj@Bj@@\ndo|D@@uJYU]]zZBBJj@@\ndo|H@@RV^UviUj`@j`@@\ndo|H@@rJIKJQFRf`@jjh@@\ndo|H@@rJJIHiIIn`HJjh@@\ndo|J@@S[_HheDdeDYMjBBb`@@\ndo|L@@iTinU]_ihHHjXBC`\ndo|L`BmpbDfYU]Ya``biX@@\ndo|hHLJkL@bYAYCYCIEEMMHi|jfZjfh@@\ndo|h`LInT@aJYV}zFZZjVj`@\ndo}B`K^DxpBLddLRRVbgUhHHZ@@\ndo}DPAuSBHJHRYg]nVzB@ij`@@\ndo}DPAuSCDJHRYgunVzB@ij`@@\ndo}H@DpLbbbLRVTWVj`@j@@\ndo}`@@pjX|dTTRfb\\k`Hbjj@@\ndo~B@BAC_HiiMhdh]mjj@H`@@\ndo~B@BAK]InVuf[fjjif`@\ndo~D@DAdfuke^wZjhH@@@\ndo~J@BAFM|bfffbRavvjh@b@@\ndo~L@CB]RfyV~^F`HJj`@@\ndo~L@GBnrQSQQIGHUhHbJh@@\ndo~L@LANRYye[iujBBJ`@@\ndo~L@M@iRYg^ufzB@jj`@@\ndo\x7FBAHXpSAb\\yIgUnUmvji`@@@\ndo\x7FD@Ds`gHhhcDliIUjiijh@@\ndo\x7FD@HPpEIYunUmvji`@@@\neFA@lbrJ@\neFA@lhbL@\neFAADdRJ@\neFABHhbL@\neFABljrL@\neFACDlRL@\neFB@Jc@@\neFBBHc@@\neFBBPc@@\neFBCDc@@\neFDBb`@\neFHBJ@\neFHBL@\neFJHbHh@\neFPBc@@\neFhXNic@@\neMA@HPaIT@\neMA@JXaIh@\neMABPYAIh@\neMBBHRZ@\neMCALhabHz@\neMDARU@\neMDARZ@\neMFI@bMP@\neMFIBrMP@\neMHAIX@\neMHAIh@\neMHBN`@\neMIHdFPRZ@\neMPAR^@\neMPBch@\neM`AIx@\neMdXZWde`@\neMhDRV@\neOBBHcfh@\neOHBNZ`@\nfH@@\nfH`P@@\nfH`T@@\nfH`X@@\nfHap@@\nfHbd@@\nfHbh@@\nfHcP@@\nfHcd@@\nfHdH@@\nfHdP@@\nfHe@@@\nfHep@@\nfHf@@@\nfI@@\nf`aA@@@ILsKWRpTADUUP@@\nf`aA@@@YEEDdTddf\\`HJjj@@@\nf`aA`D@HdclbfdQTtRSoMUTp@@@@\nf`aI`@BJ]xBAIMrlvkYsUTuRt@@\nf`aPP@B\\@bwlbfdRLRTIgMUT@Q@@@\nf`aPP`M^djs`QAHa`PXHrJJJYRZr\\EADBtl@@@\nf`aPRDL^`cQ`AAnrRPjIIQUJlmPPLT@@@\nf`aP`@DJA{HdiEDXhkKRuSUTl@@\nf`aP`@LV@cHhmEDidYISTAAUP@@\nf`aQB@NJdBHRYWVyncH@JZjp@@\nf`a`C@C@dDRFICHiCDeBhlJUT@EUP@@\nf`a`P@B@TZvQQQIIRsHTfiZfZd@@\nf`a``@M@PdwMkjteMT@ES@@@\nf`aa`@D@IiIeyWUYJZh@Jj@@@\nf`aa`@M@D[IEDdhbeiqUAAQUP@@\nf`apRBNJMACo@BES{lddJVbbbfcKUURsP@@\nf`aq@@DV\\CHheEDcddkSTE@UP@@\nf`i@P@@HD[HhdihdhUSbkN|uHPTUB@@\nf`i@P@@HTYIe[VUZLeiwfi@HjhP@@\nf`i@a@FRAD^bDfUm[WirRkN`BJ@BH@@\nf`iP@@@TRfY]{WEAJ]zPhH@B@@@\nf`iQA@B\\|@HpDISLzsnRdcN}TaAQUD@@\nf`ia`@D@M{HhhhddYdJVkN|uPTDUD@@\nf`q@@@DjYU[oxjQh@@BJ`@@\nf`q@@`@QAHbtQzHrJJKKQIPlxYtDA@DP@@@\nf`q@A`@XaLQfHKDMb^qDfYn}gyJshHb@``@@\nf`q@`@@HR[YWYTTg^Z`@`@@@@\nf`qA`@@HddrsLk~gV|u@D@@@@@\nf`qHA@DBMxDQhHRYWVY~cMV`@jikHDMH\nf`qHP@DXxHDg^rJIQSPiITyhsSUUUS@@@\nf`qI`@DXUh@oYEEEELTlfRtYjjZfi`@@\nf`qI`BHDDhBOPeGIMsOljpSoMSUUUL@@\nf`qPA@B^ADVbLbbbrtRTKNF]A@PAD@@@\nf`qPHAHV@cGIF]zDxzt~{HhmEDdThJRmMUUUST@@\nf`qPP@LT@cfdfV^V]IRwfjhJBD@@\nf`qP`@DV@YIfYmYZLuyj`hFb@@@\nf`qP`@DXAqIfWnUrL]yjihHB@@@\nf`qPaABLEh@Q@HIKIEvnrQJJJIQXj][uPAA@@@@@\nf`qQA@CVHBHEDYEEDeMCLfR]zBBbfh`@@\nf`qQB@G^`@HRkfUWvQmVZ@@@J@@@\nf`qQ`@BF@abS\\oLkjL{sUUHPD@@@\nf`qQ`@BZ@crS]lrnruYsUTa@T@@@\nf`qQa@LL`bp@b`QddebRRRrxKQejZ@J`@@\nf`qQb@FBt{p@aJYUW]lTEJfZjZZ`@@\nf`qQb@LD``P@cIICDhhlUrSoKUST@@@@\nf`q`P@L@PZvQQISQIPiVg^ZhBBjH@@\nf`q`a@APX@H}HIUwOJ~JUgMRtDAP@@\nf`q`a@IN|BHDDILklnmQbmP@TuSB@@\nf`q`b@ILD@HrQQJJMQITX{uMTt@D@@@\nf`qa@@E@rQQIZYQF\\EjuA@TuQ@@@\nf`qaB@AFADYEEDeHUDV\\]z@`jfh`@@\nf`qaB@BXAHYDihiheD]F]zfh@@@@@@\nf`qa`@D@x{HhheKDeeQakMUL@EP@@\nf`qa`@L@QqIgfUnyZTYjBBJh`@@\nf`qi`@DTxIPC^rJIQQJiILyISUKMUU@@@\nf`qp@@@Hpds\\rj~gV|uP@@@@@@\nf`qpP@DXxBSoYEDhihTdjBtYijjji`@@\nf`qpa@LR}A@@`PQddaTTRRUtxuejBPha@@\nf`qqaBLDhJR`AA`bdr{IEELiiXeacoTtsMMR@@\nf`~@P@@HtYIeU]mVjjij`@@\nf`~@`@@^rIRHiIJQUUUUU@@@\nf`~@p@@HYHsdf]UUVZjjjf@@\nf`~@p@@TYhwdiUUU]jjjjj@@\nf`~@q@HHpjs`AA`cIIChlhmHmUUTl@@\nf`~A@@@ILjjjjuUUUT@@\nf`~PA@F\\@DPBDiUVYUjjjjj@@\nf`~`J@NPQafcN|CprRRjYQQFMTuSS@@@\nf`~a@@D@rJIIJHiIMSUMU@PRe@\nf`~hPBHXhsPDV]BT\\dvvjw[TuUSP@@\nfbc@@@LdbbbbbbQQsEBMKuhir@@@@@@@@@@\nfbc@@@LdbbbbbbcJwEB]Hu`ir@@@@@@@@@@\nfbca`@D@BeIfYeUuu`iJMytTyZh@P@bjB@@\nfbca`DK@iftiSJzljlxipVk^bEMA@@@DU@P@@\nfbe@@@LdbbTbsbrTWESMUSSML@dESY|`\nfbe@P@@LU[HhhhehcBdeHsPTEEUT@@@\nfbe`p@L@PkPTiLjlr{{V|uU@pQS@@@\nfbei`@LTDjpDIRYUyWYVtYjj@Bjj@@@\nfbepb@BZ}IPHaIf]V_VUgHHBfjjh@@\nfbepb@BZ}IPLQIf]V_VUgHHBfjjh@@\nfbexc@LDXXJ\\pP@HdD^BLddNfRRbRrcoKTuUKTt@@\nfbm@A@@IdHaJkfYUU|tWICfj@@@@@@@@\nfbm@P@@BSgHhhhheEl\\hHrgV|t@PDASP@@@\nfbmAB@H@SDjnYeUWsQ\\dNZh@@@@@@@@\nfbmAB@H@SDjnYeUWsQ\\dNZjjjjjjh@@\nfbmAP@@BLENQQQQQQQYG[bm^]Eh@bHAJ`@@\nfbmAP@@HeENQQJJJIKZIUgMNmyj@H@Bj`@@\nfbmA`@@ZMdRbbTVTJRRxIwdyXBBjZ@@@@@\nfbmHR@LLDhwdy@DYHieDdUDhlnBdipZ@`Zjjhh@@\nfbmIR@AZ|fBKNb@HrRPrJI[QQETEHr\\kUUUMRmP@@\nfbmIR@LLDiAoIr@HrJSJIHjIQY\\EIS`uUJuUUUP@@\nfbmP@@@FRieYgUWxYrPyjj`B@HH@@@\nfbmP@@@IrRJJIQJIHdjmhKhu@DPQAT@@@\nfbmPB@AIADILklsJktYyL\\p@UTEAA@@@\nfbmP`@DJ@{HhhhhhdhbRqUhaRuP@pPAP@@@\nfbmP`@DJAgHhhhhhdhcjqUhaRuP@pDAP@@@\nfbmPb@AJ|dDPdrmrljoSfgQs@DMPTBD@@@\nfbmQ`@DX@sJSJmsJkyJNbEKUM@@@E@@@\nfbm`B@I@bDfYYu^yV\\uYNXB@P`B@@DAP\nfbma@@I@rQSQIYQQIH|ExJ\\tAAUAPA@@@\nfbmaB@KDADILsjlmklxZr\\pPEUPPA@@@\nfbmhR@DXXJQoIrBHrJIJKJFIQYTyIS`pAEUUUPp@@\nfbmiP@DTxIPC^SgHheEDjheEdsdeNBuRsUUUU@@@\nfbmiP@LF]EHIJugIEEEDdhjllRegAcUUUPHET@@@\nfbmpC@KQRBHDDZBLbbbRaRtTRSNJtgLAAUMUjTBFh\nfbmp`@DXHBRSL|lvj}F^SGKUUH@@A@@@\nfbmp`@LFbAFQQISISJQIFRcVbej`@jjjJ@@\nfbmq@@ARLAJ[eg_fWbmFSf``Xj@`D@@\nfbmq@@DBBAIeeU{e^VgASejBBIB@H@@\nfbmq@@IJLAJ[V{WeY`mFbf`BFj@BD@@\nfbmq@@IJLAJ[V{WfU`mFSf`BFj@`D@@\nfbu@P`HHdhCaapXxZ\\LdTbdQLblRRmIsUUUUP@P@@\nfbuA@@@ILsOsJk~SGKUUP@@@@@@\nfbuAb@KIrBHrJJIJKIQGJLx[tAAUSULP@@\nfbuHa@LRlFB@A@`cIIBhhddmeIiqkKTDaQUP`@@\nfbuI`@DXtX@dyEEEEDbddUFRLyjjZjZfX@@\nfbuPP@DD@xL\\bbTRTRVReUNRLu@aQTuP@@\nfbuPb@GQxDDPdrnlkk]QakP@T@EMP@@@\nfbuPc@IFSdD`bPqHYEHXdimDheAJCFj@H`HF@@@\nfbuPr@NBYhwdyAbIJsNk[NbdxLtmTuUUPHP`\nfbuQP@DA@JR\\yEEEDhdUmMBLLyj`VBJf`@@\nfbuQP@DTAqTTyEDhhkMEDhfBCejii``X`@@\nfbuQP@DV@JR\\yEEEDhdXceBLMyj`VBbf`@@\nfbuQ`@DX@ZvQQZQQQQIH{rXyZj`A`@@@@\nfbuQa@EVEHpHc`QdTRVTaTrbRhqNX@IZZjh`@@\nfbu`Q@LJMxH@cHQdbbRbTTRfuqQrZj`f`ZJ@@@\nfbu`R@DFmzH@aIfYU^]^QmNZhJBbjh@@\nfbu`c@IQRBPQHXdLbdLRTvbbTPeAsU@DPPL@@@\nfbuaP@D@M[tTfYeUyuyFtyj`hJJj`@@\nfbuaPBH@PrQhRclbfbbtQfbRpeQRtDDS@A@@@\nfby@A@@IdHaJkUUUUVjjjjjj@@\nfby@`@@HR[UUUUUZjjffj`HTvP\nfby@`@@YRUUUUUUjknknj`@@\nfbyPH@BZ@bR`qSgHieDeDXdhhuUSUTs@@@\nfbyPq@BY`cGhi@DABLddNRRRRRTbuUUUTl@@\nfbyQ@@DX@dsLjjjjuUUUUU@@@\nfb}@@@DjYee\x7F]^RD[S`q@@@@@B`@@@\nfb}@@@LdbbbbbTqvwEBlXJ\\`@A@D@@@@@\nfb}@`@@YRYVumUWhrRkNbf@@@@@B@@@@\nfb}@`@@YRYVum[ehrRkNBf@BjjjjJ`@@\nfb}@`D@HQvQSRJIJUJYHRiZ]yNVjjjjjjj@@\nfb}AB@L`BLbbdRQfRfRqNRUYtTuUUUP@UP@@\nfb}A`@@JsdbbTTRrLrVqPVkNbfjjjj@Bj@@@\nfb}A`@@\\sdTTbRLrTrVIrRkNbejjjj@Bj@@@\nfb}P@@@NrRJJIQJKEKB\\hvoQsTEQ@PDT@@@\nfb}P@@@PRfYVVwWppQoIcfZj``@@X@@@\nfb}P@@@XrQQQJJYIKXxXHshaRuS@D@AT@@@\nfb}PB@NZADILkljlktXkS`is@ATu@`E@@@\nfb}Q@@AJ@drmvjroSbmNBgL@PttD@T@@@\nfb}Q@@EI@drmrsvoSdeV\\gL@PDPD@P@@@\nfb}Q@@IZ@eMk]jmjpVcN|gM@DMM@@T@@@\nfb}QB@I^DBHrJIKJSQQIHtYjw`is@AUTC@E@@@\nfb}``@H`YdTTTTTLQbJxkUg^bfBH@bBjH`@@\nfb}a@@H`rQSISJQIIHlxjwhaSP@UUUUEP@@\nfb}pB@ARTBHRYWYUVuhqVg^Sf@BZZP@J@@@\nfb}pB@ARTBPRYWYUVuhqVg^Sf@BZZP@J@@@\nfb}q@@DDtAIf[eUo\\cMNlENVjdJ@@A`@@\nfb}q@@IJtAJ[V{UUU`mF]yNZ@HZZ`@`@@\nfde@``ARAbDq@xd\\QIf]UUUYqVg^``Jh@h@@@\nfdeH@@@XH[IEEEeddhUSdeV\\ADUUUQP@@\nfdeIB@LLxxH@aJWYUWVpPTcViYj@JZ@@@\nfdeP@@@PReenUe|TLGtYj`@B@P@@\nfdeP@@@RRi^VV}z\\txLZjB`@@`@@\nfdeQ@@DXAdTTtTTRbqUXp_QZh@``A@@@\nfdeQ`@DT@hvQQJIPqSYIgMVCEjjif@H@@@\nfdeQ`@DTAsVQQJJJVKII`cVCEjijZ@H@@@\nfde`a@AZlBHYDYEDeDXhiij\\Lywh@bifjJ@@\nfde`b@H\\d@HRfYfWwQJMxLZjfZ``H@@\nfdeaB@OBADILk\\}vmNJLFL@PuP@D@@@\nfdehB@L\\tYp@cIEDeEEDdfKUgAcPQ@EP@`@@\nfdei`@LZlFHIJrQQQQYQEYDhZw`uUUPHEP@@\nfdi@Q@ARUh@Q`HRf^yoYlTjVfZjj@@\nfdi@`@@FrJJIJQIFPly@PUUUP@@\nfdiA`@@HedTtbJRbbV|Ejjj@``@@\nfdiHbBDBuxLPQGicvQQIYJJIHrcH@Jjjf@@@\nfdi``@D@TdrrvokFluUA@UP@@\nfdiqb@JLtRR`RFQQQYIPiIIgJVjVjj`@@\nfdiqb@LR}A@`AFRREQQKKI[UejA`bj@@@\nfdq@P@@HMYIeUU{UZjjijh@@\nfdq@P@@HM[HhddhbidhuUUSUP@@\nfdqPP@LQ@`p\\bbRTTaVRcUUUUS@@@\nfduP@@@PRfYVuU\\LxIt_Afjh@@A@@@\nfduP@@@PRfYemurLyJp_QfjB@@A`@@\nfduP@@@XrQQQJJEIKXYpU`~buS@@@E@@@\nfduQ@@DVAdTTRbLRrRYrVcVCEjejjjjh@@\nfdup@@@PheLr|jjxipSh~CMUP@@B@@@\nfdy@A`@QAHadPzHCDQbLbbbfJbRbwAV}ADD@QP@@@\nfdy@`@@HRYUm]eUZCEjh@H@@@@\nfdy@`@@HrJZJIPiSIBdFKUUUP@H@@\nfdy@`@@QRYWYnuzL|F@Bj`@`@@\nfdy@a@CVADQbLbbRrbbbQuF^C@ATC@P@@@\nfdy@b@@qAHILrrkssIF}A@AAPp@@@\nfdyA@@@IMLrroioNcU@DPA@@@@\nfdyAP@@BUhNQQQQQQDqIdgAZYjZZj`@@\nfdyA`@@DMdTTTtRRQtXKSfiB`XZ`@@\nfdyA`@@HedTtbabRrRMXLVjjfh@@@@\nfdyAa@OAbBPUHYEEDhddYeFRMZB@B@i`@@\nfdyAb@FAb@HrQQJVIKJJDihuRl@ESP@@\nfdyAb@NV\\@HrQQQPsQSHdhFMRsTC@P@@\nfdyH`@DXxHDlbbTTRbTrmNAbtuSUUU@@@\nfdyHb@LBeFB@AFRREQQIIZ[Sk^Vh@@@h@@@\nfdyP`@DR@IIf_mfYHstVjihBH`@@\nfdyP`@DZ@GHhleEEDbmKSoMURE@U@@@\nfdyP`@MNAKIEDheEDZhHvkTDQTMTP@@\nfdyPb@INHDD`dsJnnkLDkTDDUUSB@@\nfdyPb@NJCDDQdTTRatRbTXIwhBH`HF@@@\nfdyQ@@DQAdTRbbRbbuUzpVh@@bB@@@\nfdyQ`@BN@`VQSQIQPqIXs`qZjfdHB@@@\nfdyQ`@DLAHrSKjrmjZpXmUUU@A@@@\nfdyQ`@DZAxJSNlrnkKUgMURDAU@@@\nfdy``@F@PdwLkwKBUxKPPPAA@@@\nfdy```LHx@H}HAdHrFQQIYJIJFPeCVZjh@Jj@@@\nfdy`b@LHx@HrJIKIQIPrDhZsUU@AUP@@\nfdy`b@N^BBHrJJIPzJIQLDzLADPPL@@@\nfdyppBDDDCbkAbR^]dTtRaTRbrXHsfiZjjjh@@\nfdyqb@LFcA@`AFRREQQIJH{WcVVhIBhhP@@\nfgAAB@A@bDfUmmZLEHuh@J@@`@@\nfgAQ@@BT@dsJ}kQ`iFmTuP@T@@@\nfgApB@LLx@HRevUUpPTcViYj@H@@@\nfha@B@@IbURjjjmUUUUT@@\nfha@R@HHehBYddbRRbbSUUULuT@@\nfha@R@HHpPG`eUjjjjuUUUU@@@\nfha@b@HR@fYIHddhdbeUUSUU@@@\nfhaPq@BA`cAg^@DVBLddNbbbjdVjjje`@@\nfha`@@@IJjjjjuUUUUP@@\nfheA@@@YEEDhmEhbpTmFmxKPI@TAB@@@\nfhe`@@@YHhhhdeEbRdcZ|xM@@@@A@@@@\nfhi@B@@QFQQQJGQSILyxLAAU@@@@@\nfhi@B`@QAHadPzHCDYEEELUDeCpUoPQA@DP@@@\nfhi@`@@ArJIKJQPiZcG^`@j`@`@@\nfhi@`@@HR[fyYwU[pVjB@@@@@@\nfhi@`@@^RYvUm]djsfj@@@h@@@\nfhiA`@@H|dwMkZ{IUgMT@@AP@@@\nfhiAc@HHDApHxT\\DjUgf{zBuZj`bHj`@@\nfhiIP@DDhpDc^BdwJ|lzsfkMMMUUU@@@\nfhiIP@DXxHDc^CdTRbfaTVUNZltuUUUL@@\nfhiP`@DZAyIgVYW^VkNZjdHBh@@\nfhiPb@OA``@QddabbRRvRkF\\m@@@E@@@\nfhiPp@DX@IQoARYeYv}YsUfjffjj`@@\nfhiQ@@AJAdTTTTTJtPeVBtuTttt@@\nfhiQ@@INAdTTTbRarrk^BtEP@@@@@\nfhiQB@BJd@HrJJIKPjII`oA``ah@@@@\nfhiQP@DX@IW`yEEDeDdbdsakMUMMUU@@@\nfhiQR@IV`Sa``dLbRbTQbbvXIwjjjjYf`@@\nfhiQR@JLIIW``kDfYu[UV\\MZejfjjh@@\nfhiQR@LVXhw``BLdTVbRbbqqRVjYjjZj`@@\nfhiQ`@EZ@JVQQQQQIEYLTYsT`tDU@@@\nfhiQ`@HHAIvQJJQJIHqBdYsUUUUUP@@\nfhi`P@D@ExJSLrkoqFZluPLDSP@@\nfhi`Q@@pP{p@`pQddabTVrTgIJtmADEKP@@\nfhi``@B@PdwWLjn[s`mU@@@@@@@\nfhi``@N@PdrkLjn[s`mUTEAD@@@\nfhia`@D@HkHheDdhiTiF|EjBA`@@@@\nfhia`@F@ykIEDdUEDejLmzjj``b`@@\nfhiab@LRMx@PeLwN}obfkUU@aET@@@\nfhihB@NJtXHHcHhdlhhiDzLMz@BijjD@@\nfhihbBDBtYw``bGRGlbbRrTTRLhpuh@JijX`PT`\nfhipR@BTYIW``dDfY][UV\\MZejfjjh@@\nfhipS@IZCpSo@bBAA`cHhheHeTiFJlFBAXiVH@@\nfhipS@IZCpSo@bBAA`cHhheHeTiFJlFBAXjVH@@\nfhip`@DDh@VQQJIIFIJBd{sTuL@E@@@\nfhipp@DXH@Rc^BdsJsmzsfkMUMMUU@@@\nfhiqP@DXxBQoArJIQSPjKJ`mVZZjjjf@@\nfhiq`@DDTA`TfYg]m^B|EjiZjjh@@\nfhq@R@HHehBYddbRRbbSRcUUTsUR@@\nfhqAb@AV\\BHRYV}Umhr@Bjij@@@\nfhqQ@@DT@drlsLjXKUAQEP@@@\nfhqQa@EVEHpHc`QdTRVTaTrUFP@RtuP@@\nfhqQa@EVEHpHc`QdTRVTaTreFP@RtuP@@\nfhqXB@J\\dZpPAFRIJIJJqIBeUSMMUpHJ`\nfhq`P@L@PkRSJkLn}oMUPLDH@@\nfhq`R@LPQhp@cIIBhdeDTeVVhHFJP@@\nfhq`c@BN|BlEVJkLbbbfbUbbYJBBbjZ@@@\nfhqa`@J@QqIenvyepVjj`H`@@\nfhqa`@M@DYIfUoWigHBBjjh@@\nfhyA@`A@qBXglPNHdsNjjjsdeV]A@U@E@@@@\nfhyA`@@H}dTRbTTTUQFJ]xKTuUMST@@\nfhyH@@@XxkIEDeDehTjBYspP`Xj@@`@@\nfhyHB@L\\uX@QdbbRbbRRhmFmxMAD@T@H@@\nfhy``@D@TdsLrj\x7FQaoNBuP@`@P@@@\nfhyh@@@XdhvRJJJYQIWTyIQkMSULuUP@@\nfhyh@@@XhrRTsvzrmNBexHPPu@@P@@\nfhyq@@DTtAIemU[TTmF|Ej@B`@H@@\nfle@`@@HrJZQEJIJYJshiZjj@BjH@@\nfle@`@@VRfYU_uTVeFh@@@jk@@@\nfleA@@@ILr{LjnzHTmUT@@@@@@\nfleA@@@YEEMDleHiJJQoM@PUUUD@@\nfleAC@N@bERBYCHhheDlUDefRCFBAbX@H@PU@\nfleAP@@HMEJSKLjt\x7FJ|xKTCAUBq@@@\nfleA`@@HXdvmrnrncQRuS@A@@@@@\nfleA`@@QSdTTTRRTqfdcZ\\t@@AEL@@@\nfleAp@@XDkSdyHhheDeLUmRPXuUUTDAP@@\nfleH@@@XIsIEEDbeMMDjBbfVjfhBA@HPbP\nfleHP@DTuDC@irJIJHqZIJJgOQZijjjYh@@\nfleHb@LBdfB@AFRREQQIIZIZ][ru@@@EP@@@\nfleI`BHDihBEPeGYEMDhULeDdsdTmMUMP@H@@\nfleIb@LBLFBH`BLddJbbRRvVtzwej@@@J`@@\nfleIb@LB\\fBK@BLddJbbRTVVuypUj@@HB`@@\nfleIb@LB}FB@`BLddJbbRRrVtzwej@@@J`@@\nfleP@@@PReevYU]tPijjh@@@@@@\nflePB@K^AbILklrj}Qc`p@TaAE@B@h\nfleP`@DA@eIVUue]^B]yX@J@BT@@@\nfleQ@@DLAdTTTTtRbTI`~RuUATQQ@@@\nfleQ@@DR@dsK[JsioARuUTEDQ@@@\nfleQA@CQDBHUDILrl{ljsdTpDEUUJd@@\nfle``@G@edbbTRbbNv`mV}PPE@QT@@@\nfle`a@BQRBHEDYEEDeMCDdXrSoPPT@PS@@@\nflea@@E@RfVYUV\\tWIjh@`B`@@@\nfleaR@LPQYw`AFRRFJJYIQW\\dXJuPLDqT@@@\nflehPBDX}EHAJCFT}dTTRTRRJRsNFluTtuUKP@@\nflepa@LRmA@@`PQddaTTRRVLfgFlmPREETH@@\nflepb@BZSIPHaIf]V_eV\\bfB@ijjh`@@\nfleqa@EV\\JQ`QG@cHhdliBieDjLbf@BVfjh`@@\nfli@q@HHpxLPAG`cIICdddddiEjjjje`@@\nfli`@@@IJjjjjkUUTuUTBDd\nflmA@@@ILkZvmsQdeV\\EL@EUUUQT@@\nflmP@@@PRfYV{U_CAZ]DJYji@@@F@@@\nflmP@@@PRfYV{U_CAZ]DJYjj@@@F@@@\nflmP@@@PRfYen]|cIF]DJYj```@E@@@\nflmP@@@PrQQQQJZKIDcIV]DJYj``H@F@@@\nflmP@@@TRfYmUo\\eEVMzJYf`h@@J@@@\nflmP@@@XRfYYmU\x7FCAF]DJVjX@`@J@@@\nflma@@@`rJIJYRIIIFcIF\\GtX@Jjjjbh@@\nflma@@I@rJJIQZEJYI`iJlzJV`b@@@H@@@\nflmp@@@PheLr|vj~JBtzHTsUR@@@L@@@\nflmpB@ARTBHRYWYUUVcEZlzJX@Iij@B@@@\nflu@b@HiADILrljm|sfoVC@PUUULT@@\nfluA@@@IRlkjtrRdeFmUA@UUUD@@\nfluAP@@HeEJSKLrorlyiuoMPA@@UP@@@\nfluAP@@\\dZJSLlsr{lxjtTm@qEETq@@@\nfluHR@DTyKShi@DILlk|lzs`iV}@PUUUTL@@\nfluHR@IV|fANJ@DIJrsmrnpSoQSUUUTBAP@@\nfluH`@DXTDAdfYfYu_Yit_AZj`eAbb@@\nfluHb@LLxxLPABTnrjkmxHJQkTlu@EMP@@@\nfluPB@AIADYEEDdUEDhlsc`qS@PL@@@@BGH\nfluPB@AJADYEDeMDeELcSfgQS@DMPT@P@@\nfluPP@DTAsUlbbTTTlTvRXHshiZjZfZjf@@\nfluPP@DVApt\\bbTTtabbJhJs`iZfZiifi@@\nfluPQ@N^YirPA@`cIEDhh\\ihmjByHLZjZiijZ`@@\nfluP`@DX@qIeVyeUrT]DJVjZ@@@H@@@\nfluP`@NQ@EIfVVWV~Je[rV`h@`FH@@@\nfluQ@@DJAdTTTTTRTQsEVbEKU@C@PD@@@\nfluQ@@LT@eLw\\jmvJF|zMLp@@DT@@@\nfluQ@@LT@eLw\\jonJF|xMLp@@AT@@@\nfluQ@@LTAdbbffbbTRNJVbEMLp@PPD@@@\nfluQP@BBAIWhyEEEDhdbddpQgQRtpSAEUD@@\nfluQ`@DQ@KrSLrkssDYiwhmTC@qSQ@@@\nfluQ`@DTAjvQQJQJVJ[ILDYtTmUUSL@P@@@\nflu``@O@HdsNkKN{NF}ELDAUPPA@@@\nflu`a@NZlBHHDILro\\wjpQgQSUUULpA@@@\nflu`b@AQRBHRYVvuvZcARMZ@B`@jX`@@\nflu`b@LQR@HRf[eU\x7F[EEVLzf@@@JZ@@@\nflu`p@E@EJwhyEEEEDdTddqQgQRuHMAEUD@@\nflua`@@`PYIn[VuUYJlzJVj@Bj@@@@@\nfluhP@LF]EHIJudbbbbRTUVQJV\\FMUUU@`U@@@\nfluib@DXXJQhiADYEDeEeCDdeSdeN}@DUUUTL@@\nflup@@@JLeLlj||}AZ]EHP@PTUPP@@\nflup@@@PIdbTVbbbRQNBVCzLuP@P@R@@@\nflup@@@PIdbTVbbbRQfBVCzLuP@P@R@@@\nflup@@@PIdbTVbbbTRNBVbELuP@PPB@@@\nflupB@ARtBHRYV{WfVgEZbf@HZhB@P@@\nflupB@ARtBHRYWYWfVcEZbf@BZhB@P@@\nflupB@ARtBPRYWYWfVcEZbf@BZhB@P@@\nflupB@NBtBHRYeg_fUdeZbfBAbhB@P@@\nfly@R@HHpPG`eUjrjkm`mUPTEE@@@\nflyIPAHDTXBMV]BT\\jW]dTtTVRbfaSAMSUSMUH@@\nflyQP@BI@`uhyEMDeEEDkhkSUUUMLt@@\nflyQ`@D^@jrSOJzmkBdu@AUUT@@@\nflyQ`@D^@jrS[JzmkBdu@AUUT@@@\nflyaP@B@QjJTfvUfW^\\Ejj`XHX@@\nflya`@M@EGIEDdhbdeD^JhHJJjj@@@\nflyaa@KRtX@PkprQSQHiRYIS`j@`ijj`@@\nflypqBE^CAFNBdCpixRyTyIIXiEXdhX{sUST@EP@@\nflyqP@DDTA`XiRYf]vug`fjejjfh@@\nflyqP@DDTAchiRYf]wU[`fjejjih@@\nflyyB@J\\dZwhi@DYHdhdhkDhdJUUMUMUjBFd\nfoA@C@@IdHaDQddabbRRrkF]U@@@@@@@\nfoA@P@@HtYIe[UUhrRfi@Bj`@@\nfoA@`@@HR[e]e^Blyh@H@@@@\nfoA@`@@HR[fV]qZlyhH@@@@@\nfoA@`@@\\RVUoeVBly`BH@@@@\nfoAHB@L\\TX@QdbbRbRRheZMPQDUP`@@\nfoAIB@HXHK`@aJV~vUqRsjYf`@`@@\nfoAPP@DTAsUlbbTTTlTXHsfjfifh@@\nfoAP`@BZ@aInvYWejsfjiB@`@@\nfoAP`@DX@qIeVyWIRsfjZB@`@@\nfoAP`@DXAsHhhddXdbLlyjih@H@@\nfoAPa@LDlx@P`HRYYeUuVLyjjjjj@@\nfoAQPBHF@aVgPeGIMrms\x7FIFlt@PuI@@@\nfoA`P@D@DZrSLrkrQfgMTC@q@@@\nfoA``@D@edTTTbtjQNV\\uUR@D@@@\nfoA``@L@QdTVbbbblmV\\u@A@@@@@\nfoA`a@NRTBH]DYEEDhid\\pQkPD@pD@@@\nfoAh@@@TYIVRJJKIFILxJSTsUUR@@\nfoAh`@JBUYpBILoLkleFmUU@`T@@@\nfoAi@@HDhrPLbbbbjbRxJsjiejjh@@\nfoAq@@DD\\AIeUyWhpufjZ@B`@@\nfoAq@DLTtCDiS\\kN\x7FAV]PD@P@@@@\nfoAqB@JLDPDQdTTTtlRWAV]RuT@B@@@\nfoAqB@JLtPFHdsM|klEYuKTa@P@@\nfoAq`@DXxBSlbbTTtJVhKQffjjjX@@\nfoAqb@NZ]ab`ABTsoL\x7FbakUUULmP@@\nfoQ`@@@ILkZjmFRUYt@@@@@@@@\nfoQa@@N@rQQQQJKGbiVLz`BB@D@@@\ngBQ@@eLUT@@\ngC`@Die@@\ngC`HAbIMT@@\ngC`LADJPt`duP@\ngC`LAbJPt`duP@\ngC`LAbKDvHduP@\ngC``@dfZ@@\ngC``Adej@@\ngCa@@dkH@\ngCa@@dmP@\ngCa@@dsP@\ngCa@@duP@\ngCa@@eMH@\ngCaHH@bNt@@\ngCahHlHRNj@@\ngCb@AEdij@@\ngCd@ADij@@\ngCd@ADkZ@@\ngCd@Adej@@\ngCd@Adez@@\ngCdDI`BHDRZh@\ngCe@h`NdiKLIH\ngCh@@doH@\ngCh@@doP@\ngCh@AGj@@\ngChHD@aIU`@\ngChHL@aIZ`@\ngCh`DLdkP@\ngCi@DDeV@@\ngCi@DDeZ@@\ngCi@DDfZ@@\ngCi@LDej@@\ngFp@DiTt@@@\ngFp`@dfTujX@\ngFp`@dfTujh@\ngFp`ATiTvjh@\ngFq`AbeJfuU@@\ngFr@ACTi[FZd@\ngFt@ADiTt@@@\ngFt@ADi[FZd@\ngFtHE`DILikUP@\ngFu@E`drfmU@@\ngFx@@eJfuU@@\ngFx`DBdwFmU@@\ngFy@DDfTujh@\ngF|HLZ@aJYuif@@\ngGP@DiVj`@\ngGPBAHJPLaYAInih@\ngGPBAHJPtaYCHiCUP@\ngGPHAbIL}U@@\ngGPP@cTfyi`@\ngGP`@TfYj`@\ngGP`@dfUjP@\ngGP`@df]jP@\ngGP`ATeVn`@\ngGP`ATefj`@\ngGP`ATiVj`@\ngGP`Adinj`@\ngGPhMPDIK]U@@\ngGQ@@eMUT@@\ngGQDB@jQBUkUP@\ngGQDL@aAFQRFj`@\ngGQHHGCIHcUP@\ngGQLJIARFdLbdMU@@\ngGQXHlZHROjj@@\ngGQ`@ZdruT@@\ngGQ`@bdvmT@@\ngGQ`@bdwMT@@\ngGQdLZ@j^BTuSP@\ngGQhHl@cIIBmP@\ngGT@ADiVj`@\ngGT@ATeVj`@\ngGT@ATeWjp@\ngGTHE`DILluBR@\ngGTHE`DIL{U@@\ngGU@CPdrm^@@\ngGU@E`drmT@@\ngGU@E`dsmT@@\ngGXHD@aIUVd@\ngGX`DBdsMT@@\ngGX`LDdsmT@@\ngGX`hEIWIMsU@@\ngGY@DDfUjP@\ngGY@DDfYj`@\ngGY@HDfVj`@\ngGYHI`xISkTbB@\ngGp`@TizHvjj@@\ngJPB@fRHTQhbOj`@\ngJPBAbJHt`YAIjj@@\ngJPD@eRHczh@\ngJPD@fRHczh@\ngJPH@DIJuP@\ngJPH@EIRuP@\ngJPH@eQ}T@@\ngJPHADILth@\ngJPLADJPt`duU@@\ngJPLAHJPt`duU@@\ngJPXHlPDQzt@@\ngJP`@TeVh@\ngJP`@TeZh@\ngJP`@TfZh@\ngJP`@dfvd@\ngJPhLQVIKTp@\ngJPlLPDRPTaGth@\ngJQ@@djsBJ@\ngJQ@@dkU@@\ngJQ@@dlu@@\ngJQ@@dru@@\ngJQ@@dsU@@\ngJQ@@duU@@\ngJQ`@bdvu@@\ngJT@@TeZh@\ngJT@@Te^h@\ngJTHE`DILmP@\ngJT`E`TfVh@\ngJU@H`dlu@@\ngJX@@dkU@@\ngJX@@dkt`@\ngJX@@dku@@\ngJX@@dms@@\ngJXDBLQQBS]V@@\ngJXDBLQXbS]V@@\ngJX`DBdru@@\ngJY@BDeZh@\ngJY@BDfZh@\ngJY@DDefh@\ngJY@DDfVh@\ngJY@DDfvd@\ngJYHC`DIKTp@\ngKP`@Tixjj@@\ngKP`Adi\\Zj@@\ngKQ@@eKcRp@\ngKQ@@eKcUP@\ngKQ@@eOEUP@\ngKT@ADi\\Yi@@\ngKT@Adi\\Vf@@\ngKX@@eKcUP@\ngKY@HDi\\ZV@@\ngNpJAbJHLaYArBS]UU@@\ngNpP`jusyImfi`@\ngNpXHlPDYIHTmT@@\ngNp`@dfUZf@@\ngNp`@dfuZj@@\ngNp`ATf^Zf@@\ngNp`ATiUjj@@\ngNplJqHJPtadTaeTp@\ngNq@@dskUP@\ngNq@@dssUP@\ngNq@@eLuUP@\ngNq@@eM]UP@\ngNqTHmVDPhbU_MS@@\ngNq`@bdvkUP@\ngNq`AVeJmUP@\ngNqhHl@cIICej`@\ngNt@@Te[zj@@\ngNtDLpDDHRevnl@\ngNu@HPdjkUH@\ngNu@H`dlkUP@\ngNu@H`dl{UP@\ngNxHD@aIUUfaM@\ngNx`LDdskUP@\ngNx`LDdssUP@\ngNx`LFdjmUP@\ngNxhMV@aI[ji`@\ngNy@FDfWj[@@\ngNy@LDeVjj@@\ngNyhGE`DYIITmT@@\ngN|@ADeJkUP``\ngN|`HfJdlsTp@\ngOp@DjWkB@@@\ngOpH@DILkW@@@@\ngOpHADILkW@@@@\ngOp`@tigujj`@\ngOp`AdeekZZP@\ngOq@@drm[UT@@\ngOq@@drm\\@@@@\ngOq@@drm]UT@@\ngOqHL@aIYZzfd@\ngOq`@fdrikTl@@\ngOq`@fdrikUL@@\ngOq`AVeL~mUT@@\ngOqhHl@cIIBjujh@\ngOrHEcPDILl[MT`@\ngOt@AdigkB@@@\ngOtHE`DILjZuU@@\ngOtHE`DILl[MT`@\ngOt`E`tfUMZi`@\ngOx@@drm\\@@@@\ngOx@@drm]UT@@\ngOxHHHaIeZzjh@\ngOx`BDdwM[UT@@\ngOx`DFdrikTl@@\ngOx`FDdwM[UT@@\ngOy@DDfYKZj`@\ngOy@JDiWMjj`@';mlb.hE=false;mlb.kE='eOHBNZ`pge@\neFDBcA@\neFhHbayP\ngFy@DDfXujhCAF|f@\nfHcpAa@\neMPBchLDnR\neMBBHRZCAKd`\neFJHbHpXI@\ngCa@@dkHFBbyL\neMJDbDf``\neMHAIdLF^P\ngJXHD@aIUj@pHVOI@\ngGY@BDeVj`LJHm^P`\neMPBcTH\ngCd@ADkj@pTWDL\ndeTH`ABHRVUunh@J@B\ndidL@@SdfU{aZjj@H\ndiDD@@QIeuZjh@pkJ[ayA@\ngOy@HDfUk`@@H\ngJ\\@ADe\\u@XKGd`\ndeV@@@Rffeijjj`CClJfxYy@@\ndeVH`NdLQIe]ZZ@Bd@LFALJny@`\ngOx@@drm\\@@A`Qb~IT\ngF|@AbeJfuU@P\ndmN@@@rJJIQEneX@@@@B\ndifH@BAIfuxV`@@C@j[ayF@\ngOx@@drm\\@@A`PZ~IX\ndaF@@@Rfu[j@@@LJSBinHG@\ndeU@@@yJUuRh@Jh@LNaLIagd\\\ngNxLL@aAABDfVZj@`\ngGPB@DHHpQPaIUZdB\ngGY@BDf^j`LBHmqF`\ndazH@LAIUUjj@LJPj[nIF@\neMBCDRZCAKd`\ngGQHJLQIUjdB\ndefD@B@TfUvZjf@H\neFA@HoBJFD\\h\ndayD@DpNRYWZj`C@lInxbT\ngFt@AdiTvjhC@qF|Pp\ngOtHLPDYHhckSM@XXI|a@\ngNqBLIAREdGHIMmUTA@\neMXIDfP`\ngJT@ADiVhPT\ngGY@JDeVj`LJHl^R`\ngCi@DDeZ@pTwH`\ngNx@@eJmUPFCDVKyJ\ngNxDLHaqBRjuU@P\ngGP@DjVj`LKEc^P@\ngNx`LFdjmUPFCDQkyL\nfHbpAa@\ndidHPBBHFHRYgVzB@`@`\ndaD@P@bNbDfUzZ@B@B\ndaD@`@bDfUjZ@B@CB`SJ{dL\ngCe@E`dsPFBV@\ngOy@FDiguie`LMc^IL\ndaDh@DInAIf]nZiX@`\ndigH`LH^@HRf_ljfYh@ppBkbHH\ndaD@`@QDeeVz`@@B\ngCahHlHRNtA@\ngOxhMDOAJmZvjhC@xu|`@\ndaED`LJDCpRjw[fjj@LLinxfD\ndcMDPLzfBHKpRUZvYvjZjh@`\ndeT@`@bLbdTJPsU@@@D\ndcNH@DAIee^eVhHB@CCbine]yB@\ngJX`DBdru@XKGdP\ndif``DqnDHaIeYih@J@B\ngOx@@drm\\@@A`Pm^Hl\ngCa`@ldsPFBV@\ngNqhHl@cIICej`LD[rL\ngO|HLV@aJY}ZYhB\ngF}@LZDigVfXB\ndaE@@@aJyUnh@@@pXLJf{dP\ndmN@@@RYVuiiV@@@@@`\ngFx@@eJfuT`XEXwbD@\ngFt@ADiWFZdCCPwdP\ngGPhMQDIJmU@P\ngNqHLHaIYzj`H\ngNx`JBdr}UPFCDVKyJ\ndaF@`LBHRVU[j@@@H\ngGX`HJeZuTA`Uc^R@\nfHfpA@\ngOy@FDfUkZj`LBl[rL\ngGQ@@dluTA`Xm^HD\ndaz@@@Revjj`CAdpj[nHD@\ndiTD@@yJ]VaNFjjj@H\ndmLL@@iTie]|kahHBh@LJPfE^QH\ngOu@DPdrykURA`l~Q@\ndiT`@@rnRfUjEnBA``B\nfHgHA@\ndid@@DjU^nBBD@LFaLiaxa\\\neFACr`bLD\ndcl`@@`nReeWZY]@``@@B\ndid@`@bDfYUn`HD@LFCBiny@`\ndmv@`EBHrJJIHin`HFpHy`\ngOq@@eL~mLlAal[qI`\ndeUH@DpDf^UFVh@@@pYLinGdR\ndeVH@IAJYW~F``H@LFSBinyD`\ndeV`@@rfyJWUlIifjBJh\ndig@@@aDiyWaZ@@B@h\ndeWH@DJPRY[TYZ`@@B\neMBBHRZCAGe@\ngNy@FDfUZk@pRwIP\ndiFL@LANRYufjf@H\ngGU@E`dkMTAad[rP\ndayH`Dr@|Djyfjh@`\ngNtDLpDHHR[UjhB\ngJXDL@aABS[TA``nKD\nfHe`Aa@\ngJQ@@drt`XI[dH\ndid@@DjU^nBBD@LNaLJfGd\\\ndifH@FAIYU[fZj`CBlJnGdP\ngJ]@HbDfZdB\ndie@@@EJf[XZjj`CChSBiny@`\ndk^@@@RYWYVftx@H@@@H\neFA@H`bLFE\\`\ndeTH@@RYWZf`@j@CC`SBhYyG@\ngOu@JpeJymUTA@\ndcN`@@pjYJYenk`Hbj@B\ndmu@@@QIUYVUZh@@@pdDpfxYWdP\ndmvH@NAIfUTUZBB@@p[BiaWdR\ndkmH@NtDfYU_EZ``b`@`\ndkmH@JTDeVVutvjh@@@`\ndieH@DHLbbbaIjZjPB\nfHaXA@\nfHbHAa@\nfHdXA@\nfoA@R@HHpx@QddebRfRpiFlm@@@P@A@\nf`i@@@LdbbRRlRSI\\D{qAHT@D@@P\ngNq`@VdsMUPFCDQkyL\nflmA@@@YEEHdcLdddSdmV]EKUUSU@E@@D\nffsA`@@YkdTTbRLrTrVRIrRkNbejjjj@Bfh@B\ndaE@@@yIe^f`@`@pILJnHG@\nfeg@`@@SrJIJYYQQJQZqYTYzH\\uUKMUUUUUPDLiVEPPQbgARtYw`qSdmV}gr@p\ndcMH@HdDf[W[ai@Bh@H\nfc\x7F@H@@JbdoU{RYfYU_uyYubc^\\D\\vi@H@BjjjhH@H\nfb}A@@@YEDeMDhTihjLUiwhyZZjjjjjh@LKHqPTeZMYpTyxcdP\nfnk@P@@FbuIefYZWz^`mA|gMVfjjjjjjj@B\ndmLH@@rJJIQEneX@@@@CA`iae^Ig@\nfleA@@@YDddhiiDdYipTtsUUUSTABHe@\ndk|@@LdbbbRQKauS`@`@`@H\nfjc@`@@ERYYefUez\\UyvPiZZjjjjjj@CCrLTXJVcV]zJ\\ey@H\nfjc@`@@JrJIJZJJUJZJcMF|EIVfjjjjjj`@`\nffsA`@@VkdTRTtRabrTRhqQoARUijjijjjj@B\ndie@@@aJyW[f@B@CBlJfGdP\ndeT`@@`YRnUunX@I@B\ndmL@@DjYeVdU@@`@@H\nfgA`@@@YIEDeDUfJxHujjhHB`@LNPQbgIZxQbcV@\nf`ia@@E@Rfume]gEF]z`@jjhh@H\nfoQ`@@@YIEDeDTdpWEF]UUAAE@@P\ndcnH@EAJ[UU[ev`@jb@LFPje]xfB\ndcnH@MAJ[UU[ev`@jb@LFPjE]xfR\nfjc@`@@ErJIJZIPiSQJcEZ]zNVfjjjjjj`@p\\cENBdkQkNBgODQJ\nfb}A@@@ILk[Kk\\tyKSoQsUSUMUUUP@XN`cEFBdhugASgb@Q@\nfb}@@@LdbbTbrNTtWEBt{t\\sMUUUUUT@D\ndg\\L@@{\\dTrTRtKCPAET`A@\ngOtHLPDISKWSU@XDJodH\ndknH@ECHhheLcFz@`jh@H\ngJP@DknhCCSGdP\ndcLh@LKaCIELeBhwT@ET@D\ndmv@@@RfUYyZBB`@LAALInF^IR`\nfgA@@@DjYU_VByHu`@@@@@@LIXISdeZM[dD@\ndidD@@yIfVXXBH@C@`[axfT\ngCa@@dmHFBVxa@\ndaxL`HS@\\DjeZjh@`\ngNphH`xITkUTA@\ndaGH@Dp`RYeifjf@H\ndg\x7FH`LKU@HrQQSIJHyTgSA@qP@P\ndev@@@RfU\x7FJxZA@h@LFAB[iyE@\ngOqHJ@aJUcZZhB\ndaF@@@Rfu[j@@@LFALJfyG@\ndieH@NDDfUvf`@d@H\ngFx`LDdrfmU@XHwdp\ngNuhJxl@cIIJej`H\ndifD@JAdiWTjjjj@H\ngGT`DQTfuiaMXIWdp\nffcAp@@DEiNZyEEEMDihbdiVBMzIViBb@@hh@@pTQVcV]ENZ`\ndo^H@DAIeV}YZfifdLIFU`\ndg\x7FH@LiPRUYYWESnj@@@@@`\nfoAQ`@DD@irSLwN~QakMUPHE@@XLpJVcNx`g@\ndg}D@DHERYfywIcmjjA@`@p[AgSobEp\ndieD@DHNRY[Rijih@pSFybDH\ndg}D`Ad{BHRYVuUiev@BffH@pXDrmob\\H\nfoAPb@ARlxDPdrmkKtXht@EMSD@D\ndclD@@[HhheBeSKkTp@P@P\ndcNH@MAJ[WY[j@Bg@B\nf`qA@@@ISZzljscoT@Dp@@B@kARLDhsQkN}q@i@\nfbmpB@NV|@HRfYe]WnirQmN@@@@bj`@@pt@cAJLxLTy@\ndg}L@LhDWHheDbhdSG[UTtuHQu@\ndmLH@@rJJIQEneX@@@@CC`rfFUyG@\nfbmPb@FRTX@QdbdTjRtrbRps`dyjjjYh@J@@pLAAJ\\e[pXisrF@\ngJ]@EbDeVdCBKba@\ndcl@@DjYU_egX@@@@@pELJae]xc\\\ngJP@Di[xCBGdp\nffsA`@@IkdbfbTTTTRtwxkW`ecfjjBjHjJb@B\ngJYhMDPDYIBm@P\ndmM@@@iJYWWJxYB@j@CBbiiWdH\ndaD@@DjYvxH`@CCLJnXc\\\ndg^@@@rQQQIIRcmAPTT@D\ndiV@`J@HRfU|kahDB@CB`PfGd\\\ndmL``LXU@HRfvUxYV`HFH@pHDj^Ph\ngC`DADJHRZhCCBKdp\ndmtH@@RYWYih@Jh@LAALJnE^QH\ndmtH@@RYWUih@Jh@LNALJiWb\\H\ndeUD@DhFrJIJHusUMT@XDf]OHD\ndg}@@@aJVYU^Svv`@@@@`K@Z[ae]ObEX\ndmwH@DePRUe]xV`@d@H\ndcO@@@b\\dtTRJgBpDEP@P\ndaD@@DjYvxH`@C@linxbD\ngJX`BDdru@XS\\a@\ndie@@@aJyW[f@B@C@lJfxdB\ndid@`@bDfYUn`HH@LFCBiayG@\nfoAPB@NBADILkjrmFV]@AL@@@ar`\ndeUH@BxLbbbRKCA@d@D\ndk}@@@iJUmUR[atpBJ@@@CChPiWSyE@\ndeUD`LjD@HrREQICJt@@@XUc\\L|`@\ndmuD`IVD@HrRFIKKaV@BP@`\ndmtD`ATIAIe]Vf`@jP@pILJnIt`\ngGP`@deUjpLI^JX\ndmvD@LADfvUYUjjj`B\ndcND`MEPdDfUuZf`@jX@H\nfjc@`@@HRUe[Vun^Bt[pTeZ@Bjjjhj@CBqJ\\dkQkN}GI^H`d\nfnk@`@@HRYVum[VydjshiJuj`@jjjjJ`@`\nfa{@P@@HkwHdhdididihdUpVc^BdkP@UUUUTeP@P\nfjcAB@C@bLbbbRdRbLJbXJUoQRVejjfjjjh@LG@pQ`iJuYpXyKrBP\nfb}A@@@ILk[Kk\\tyKSoQruSUUUUUP@P\nfjcP@@@FrQQQQII[FIJgIVt{IP@@@``@@@@`\ndaD@@DjUZxHH@CAL[ePaUp\ndcNH`BpHaI[fuWZZ`@@B\ndcND@DCdefV]]Z`b@@H\ngJQDD@b^BRkTA@\ndg|@P@bEbLbbbTRRKR]pP@P@@D\nfoA@A@@QChaIe]YWhpuh@J@B@@LE@Q`eIJtYwH\\@\nfoA@@@DjYUgWfiF`XJbh`@`\ndeTL`HS@BLddlRPrm@@@FETwCOHp\ngOx@@eLmXD@A`Uc^Q`\ndclD@@EJY}erevfVfiBJX\ndcNH@DAIge]FVh@I@B\nfoA`@@@ILkjrmFV]@AL@@@arptcAJ\\DkQkNy@@\nf`qqa@FF}Sf`RBICHiMEMCEmPUgUUUSKT@D\ndg}@@@aJVYU^Svv`@@@@`K@Rine]obBX\ndg}@@@aJyeg_eNvB@@@@B\ndmND@LAdige\\jUifZi@H\ngKP@H~Jj`LEcqQ@\ndidD@@QIenifjj`B\ndklD@@QIVVU}MjlH@@H\nf`q@`@@HRUfYU_Sk^Zh@@@@@H\ndeVD@BADfVuFVh@@@`\ndmwH@HePRYm]xZ`@d@H\nf`qP@@@^RYWUe^cKN`@f@B@DNT\nffsA`@@VkdTRTtRabrTRhqQoARUiZjijjjj@CArLTxJRcN}GIZ|`d\ngNy`DBtf]Zi@`\ndeV@pJBPRPrPrJPqICMT@@@^DwCH\nfaw@@@LdbbbbbbeeRRwMB]Jq`y[Wh@@@@@@@@@@A@\ndmN@@@rQQJJFfEP@@`@B\ndmN@@@RfV_kad@@B@@`\ndco@@@g\\dTRbtM\\J`@AB@A@\nfdep@@@PheL}sJkxiXOhsUP@@@`@D\nfhiP@@@ARVUue]Yrsn@B`@l@@`\ndcn@@@RfV]zXU@@BD@CCdJnFUyF`\nfbmP@@@IRfV]}e]hpR`q@@BF@B`@PUP\ndeWH@DJ`RYYTfZij`B\nfb}@`@@YRYVum[ehrRkNBejfjjjjj`@`\ndk~H@NAJUmmRkatzVd@J@B\ndklD@@IIf]vVzB@jh@LICBkagSyB`\nfbuA@@@ISZ{Ll{lxgM@AMTD@@HBh\ndaF@@@RYe[hB@@LBpj[bAp\ndco@@@bdigyWJWYj`@P@pYLKawbRh\ndaGD@Bi`QInUnZZX@`\ndkmD@DpJRY{e]]Zf@B@B\ndaDH@@RZW[jii@H\ndazL`FaL@HrRRiKUPA`VEW\\a`\ndaG@@@[diWRh@I@C@hSByG@\ndigH`LJn@HRf_ljfYh@ppBGdH\ndmL@`@bLbbbTQ[iV@@@@@`\ndeVD@DCdfV[hVjfh@piJXYyF@\ndaDH@@RYe[hB@@LJCBinQp\nfoAPR@JLIIS`UbSLzmnsakTmTuUP@X\\Ab`mV]rA`\ndcmH@NDLbbbTVKCJm@dE@A@\ndg~H@FAIfU{TYNz``@@@B\ndklF@@sittieY_hZjjjh@pfBinF]ObHh\ndcLH@@RfUWnf``R`@pyBinW^Id`\ndo|H@@rQQIIZHkihHDjd@H\ndo~L`MaL@HrRPjIIKISVhHHh@H\ndg]LPElYLHc`cHhdliBiSP@Rtp@XLBXUKrK@\ndcNH`LdHaIUe[EZh@b@B\ndk|H@@RfYU_JGUN`@@B@@pxfzUt~PH\ndklH`I@HRYeuin`HJj@B\nfdyQR@FJtZwh`BLdTbbJTRlvF\\eUUULsU@AaHBLDiqQ`|aD\ndmu@pNTIAICICHiCDeafj@B@CAJ[bBh\ndkmHpNTpdDdLdLbdLRRrFZh@JP@`\ndkoL`LhXPpBLdaTRbQeUhBBP@`\nfdy`a@BRlBHcDYEEDehXhlfB|FBBFB@`@B\nfb}A@@@YEDeMDhTihjLUiwhyZZjjjjjd@H\ndco@@@rldTRTJU\\naA@@@A`Prn|qLX\nf`qA@@@IMKMjoiuoUV@@@@@D\nflm`@@@YHhhhhdhb]RRkFCzH@@@@@P@@D\ndg\\L`AWPbDfUv{ZZ@Bij@B\ndg|H`KBHRYWYWimN@B@B@@`\ndaF@@@RYVih@H@LBSJ{b@p\ndeTD@@QIVYQehB@@LBinGbQH\ndeTD`NDHaIfVVfBA`@LJCJX^QH\neMhDRZCAKd`\ndeU@@@cIMDeBwL@E@A@\ndaG@`D[`bDfUZZ@B@CA@sbEp\ndcMDPDy]BHXHRYV}jz@Hi`@`\ndmt@@DjYZVTHbh@CBdxYWfES@\ndev@@@Re[TjFP@@@@LFaFxYyA@\ngOpHADILkW@@@XHWaVK@\ndmv@HBBHFPfPVPRYUzih@Jh@H\nfhy@`@@\\RYee~uYrVoAZA``@H@@pI`uo\\YPTmNB\ndk\\L@@{\\bbbTQr[iUhF@j@CALOaTpr\nfoA@P@@\\ekHhheECEf\\TYhFHbh@B\nfoA@P@@\\d[HhheELiVRUYhFHhh@CCFMNyabk@\nfoA@P@@\\T[HhheDXef\\eihFBJh@B\nfj}@P@@\\tEIfVWnU]YrQdeZA`hB`b@@H\nfj}@P@@\\ueIfVWn]}YrQhiZA`hB@j@@H\nfj}@P@@\\MeIfVWVu}YrVhiZA`bB@j@@H\ndmL@@DjYUVGi@@@`@LFrnFUxbD\ndclH@@RfumVy]h@@@@CCdpfE]yD`\ndmMH@HxLbbbTQ[iV@@@@@`\ndeVH@HCHiEBdLuP@@A@\nfoA@b@HH@DYIHXeEhbkUgKPP@@@@P\ngJU@LPdjt`XQ\\TH\ndeUH@JDDinUzZBA@@`\ndclD@@IJ]YWaIVj`@h@H\ngNpXHlQxIUZuTAaGqF`\ndiDB`HSBCpRjuVji@H\nf`a`R@LPP{p@cIIBhddbhhruAADp@F@jLxJRm^yC@\ndk]@`FD@aJY}e\\kSif`@`@`\nfoA@B@@QBRsLjnjqgSP@@@@@P\ndmtH`IBHRUe]xY`@hBH\\F@j[exdH\nfhiAB@O@bDfYUg_QZlzdH@@J@DDL\nfhi@`@@HRYyWVUEKpVh@J@@@@pebcNBMYwnHTD\nfjm@P@@HceIge]YWVEKpVh@J@Bf@@H\ndmt@@DkYV~Gh@J@B\nfjm@h@@XDkSoQRWIEEDhdicDXZRcfjjjjjjj@CBLDDhs`iJtYw`irWdK@\nfleab@OPQD@QddabbRRvrbkF\\m@@@EL@@XJhs`iJt[r^P\\\nfbuQb@OA`aH@cIICEDdelehjqgKP@@ATp@A@\ndkld`LWSa@BLddlRVRFUh@JP@`\ndg}H`AfpbDfUmYZYS`@ijR@LJALh~Iv`\neFJHSHp^I@\ngOpH@fILkW@@@P\ngJPhI`fIKTpD\ndaE@@@aJyUnX@@@ppj{fQc@\ndmvDPLa@BNdLddlTVeUhH@@LBqagdJ\ndcnH@LCIEDUDeeKmLuUT@P\ndaFD@LADfyVyjj`C@binyB@\ndcnD@BCTfYVuiEX@@B@@`\ngC`LADJPt`duPFDGI@\neMACDXaIhH\neMACD\\QIhH\neMBBlRZCAKd`\neFJHAHhP\neM`AIdLF^P\nfHbXAa@\neMBCDRZCAGe@\ngJQdEbOBRD_M@P\ngChHHDQIj`H';mlb.lE='fHbTA@\nfH`pA@\ngFp`@dfTujXCAZ|a@\ngFx@@eJftu@XVKF|`@\neO`BNZ``\nfH`XA@\nfHdpAa@\ngNxHLHaIVjj`H\neFJHbHpP\neMABHXaIhH\ngJXHD@aIYj@ppqyH\ngCi@HDej@pRwDH\ngCi@LDeZ@pTWI`\ngCd@ADiZDE@\ngOx@@drm\\@@A`plZp\ngGX`LDdsmTA`m^P`\ngCiHLaDIMLA@\nfHapA@\ndeTH@@RY[TYjp@@B\ngCa@@dkHFBVyH\ndeTD@@eIYWVy`@h@LFpjXYyD@\ndeT@`@qDeVUFZX@@HR`\ngJQhHl@cIHUhCBGd@\ndifH@DAInUxV`@@CBdinGdD\ndeV@@@Rge[aj@B@CChPjxYy@@\ndeV@@@RgfTYj@`@CChRfxYy@@\ndeVD@AADfVuFVijh@phj[iy@`\ndeVD@ICDiieZZjjh@`\ndaGH@DK`R[e[fiZ@LLQnyE@\ngOr@Ajti]qZY`H\ngGPhIPDIU{T`XXK\\a@\ndid@`@qDeYWaf@@BH\\NABinGdP\nfHa@A@\ngNq`@jdvkSPf\\Ll~P`\ndedB`LkiCDRV{njjh@`\ndiGH@Dr`RY{fjj@H\ngJY@BDfZhC@bK\\a@\ngJY@BDfVhCAK\\a@\ngGY@JDf]j`LLl^R`\ngGY@BDfUj`LLm^P`\ngJPH@DISUPFABqyH\ngJX@@dlu@XZX|PP\ngNxHF@aJZzjPH\ndazD@LADeUffhHr`\ngGT`EaTf]jPLDmrD\ngCh`LDdsPFDWI`\ngGX`JDdsmTA`l^R`\ndmv@@@Rf~UeZj@@@LEBDpfxYT\ngOx@@drm]UTAaqEcV\ngOx@@drm\\@@A`Qc^IL\ndmvL`BaL@HrRRjIJUVjjh@`\neFA@HoBJD\ndiFB@BAFEInuZjd@pILJnQp\ndayH@DpDf]Vjh@pKBinHg@\ngNuHLzHaIUji`H\ngNt`E`tf]Zj@pJM_I`\neMJD|Df`pYy@\ngJPhLQxIRuPD\ndaDL@@KdfYvyjV`CCLJnPp\neMBBlRZCAGe@\ngOq`AVeL~mUTA`Yb~Q@\neMPBchLD^T\ndaF@@@ReYJjjj@LNaLJf{d@\ndaE@@@aJyUnX@@@`\ngCe@E`dkPFBbyL\ngCahHlGBNtA@\ngC`@Die@ptVy@\ngC`DAb[DRVhB\ngCaHLLQIZ`LDEqS@\ngGPBADZPLaYAIZjhB\neMABHYAIhH\ngJX@@dkT`XFKGd@\ngJY@DDeZhCCSGbB@\ngGT`CPdfuj`LLl^R`\ngGX`DJdsmRA`enP`\ngFq@@eMqUW@P\ndkNF@BAIWSR[YVYjjfX@`\ndeVDPL[`bB|DeYgFZjZh@`\ndeVL`LxY@HRf][JjZV`cJ\ngO|HEfHaIeZx@@B\ndaxD@@QInuij@LBRf{dD\ndaxD@@QImUijBLlBRf{bXP\ndedB@@PYR[fyijXHqpQIxe\\\nfH`TA@\ndaxL`HS@BLddNRuR@P\neFJHqHpP\ndaxL`Lk`qDenzjh@pXDpj{bPp\neFPBca@\ngG]@EjDfUj`LEcqJ`\ndedd@DpaCdfU{ZjZ@H\ndmOH`LJQ@HRf^yriVfZZh@`\ndaE@@@yIe^f`@`@piLJny@@\ndevH`LX@aJWY\\HYiZZd@`\ndaEH@DHDfURijZ`CCL[nP`\ndaFH@HAIYUnh@@@pXHpj[d\\\ngFt`CQdidviXB\ngJPXHlPDQztAxlP\ngJPDAbGDRUj`H\ngNx@@eJmThFCbqky@\neMA@HPaIXLD^T\ngGYHLQDIJuU@P\ngGP`ATf]j`LLl^R`\ngFp`AdeoEjhCCHwd`\ngOp`AdeekZZPLMB~R`\ngF|@@ZeJxru@XYF|d@\ngOy@FDiekjj`LKEc^Q`\ngOx@@eJqmUTA`xlZ~P@\ngOx@@eLvmUTA`xlZ~P@\ngOxHBHaIeZzjhB\ngKP@Di\\YZ@phbq@\ndiDB`HSB@HrRPyIZj`CCBknHp`\ngNq@@djmUPFEfM_DD\ndcLL`HS@BLddjbRtjmP@P@P\ngJPJAHR`Tai@rBSUTA@\neMCArhabHzCCI@\ngNy@BDf[Zj@pruxbp\ngJY@DDfzhCCSGbB@\ngNx`JDdskUPFDwLZp\ndmVD@JADf^Uvjjh@`\ngChHL@aIVPH\ngNy`LETeUZZDs@\ngNt`LPdfUZi@pexlp\ndiEH@DpDfYUjj`C@bkaxfL\ndidD@@EJ[W[j@B@CBdJfGdX\ndmtH@@rJIJFRf`@j`@pxDrae^Pp\ndaG@@@kdiVrX@a@B\neMhDRUB\ngOx`FDdrikUTA@\ngJXHD@aIUZ@`\ndcnL`LaA@HrRPjIKTrzmPHD@FEYtkh\ngCi@LDeZ@pTwH`\ngFq@@eNqUU@XZX|Rh\ngKP@Di\\Vi@pLVOH@\ndiVH@BAIfUInFjZi@H\ngNqhHl@cIHUEj`LLZ~P@\ndaxD@@QIe]ji@LBpf{dT\ndiFL@J@aRY]Zjj@LABDpfx^QP\ngNx@@eLmUPFEfM_DD\ngNy@LDeUji@phQkxi`\ngGX`BDdjmTA`m^JD\ndazD@FCdfUVjx@`\ngCd@AH}PFBVyH\ngChHHGBOTA@\ngC`DADZHRVhB\ndeVB`BaLd@cIIBeDwKULpA@\ngJT@@deVhCCCGbb@\ngNu@E`drkUPFFM_Dl\ngGXHJGAJijhC@qX|e@\ndidH@@RYeVz@``@pXLJf{dB\ndaEH`Dq`BDfUjyjfPC@`SNyE@\ndieH`Dq`BDfUfnZii@H\ngJPDADFHRYfaHp\ndmuL@DpFEIeY~nZifh@pILe^Qp\ndklL@@STfue]eVj@B`@pyL[ad~PP\ndifH@HAIVUxY`@@bGA`Pjx^Pp\ndid@p@bBbFbDfYoa`b@@H\ndid`@@pjRfUjXBB`@pSaxbL\ndcNH@DCHheEDbnmPT@@F@hUMproHt\ndaz`@@SFyIeYjf@LJAL[nQP\ndaG@`LK`BDimVz`@@B\ndeT`@@pjrQQIFTpDEP@P\ndid`@@pjrQQIFf@`h@LLKaxbL\ngNy@JDeUjj@phVKxiP\ndigD@DpP[HhdhZyjfd@pqLkdB\ndmuH@DpDfWeYUj`@@CAlInF^Hb`\nfH`PAa@\nfHdHA@\nfHchA@\neFHBJFE@\ndmLH@@RYVuiiV@@@@@phJxYybXh\ndid@@DjY}nBHH@LJSBh^Qp\nf`i@@@LdbbbTRVHeZ][uHAD@D@@XRhs`iJtZwLX]x\nfhyA@@@ILklrstXYw`p@TaDA@@P\nfdeA@@@ISZvmvkNJLFM@AUH@D@A@\ngOu@HpeK^MKTAaKqY`\nffsA`@@LudTTTeRdVTtLIps`ySeijjjZjjj@B\ndklF@@XUttief_kjjjjh@`\nfi{@h@@LDipTmzOHhhhhhbXdiidnBu[IV`fHbjjjh`@pmIVc^CENRmzObNU@\ndayL@DpFyIgYjf@LLPnyF@\nfb}A@@@ISZvmk\\lxkSoQsP@UUUUEP@XNQ`cARUhugASgdH`\nffs``@L@QdTVbdRQfRfRxhu`qKUjjjjj@Bh@B\nfnkA`@@HkdRTTbRLrTrVSIZMxNRmUUUU@AUP@D\nfa{A@@@YEDeMDhTihdXjLUiwhyZZjjjjjjj@B\ndaxH@@RYWjZPcKA`SBinIG@\ndet@@DjYUX^d@@@@CAlJnF^Hc@\ngF|LHjOC^A|DiTt@@B\nfnk@`@@UrJIJZIPiSQHrcEZ]zNVfjjjjjZj@CCrLTxJRmFlxJ\\myBH\nfc\x7F@P@@E{OHhdiheBeMDhUEKQbmN}GKSUUUUUTsUT@D\nfnk@@@LdbTTRbTRQNfiKak^cejjfjjjjj`@`\ndmtL@@QTfyeQehBA@C@jXYxb\\\ndklL@@PtfVV]WVhH`P@`\ndeTD@@eJ[WVz`@h@LBRfgfXP`\ndcLL@@{TimY]ah@bh@LJPaW^Id`\ndcLH@@RYeZvz@`j`@pxBXYW^Q`\nfoAPB@LD@DYHhdcEEEQagTuPDQ@@P\ndeVH@DAIgeQej@@@LJSJX^It`\ndeVH@IAJYW~F``H@LJPj[nId`\ndk^@@@RfYU\\]Tzjjjj@LKBDpj[ae]L\ndid@@DjYmaBH`@LBrnGbDp\ngJX@@dmu@XKGdP\ndg^L@D@[rJIJJIGZ[UAPD@D\ndeVh@LKadDimY[j@B`@paNHL`\neMPBcXLIyP\ndcMH@ITDee]UnX@Jh@H\ndg]D@DpCRYVuveVj@BX@H\nfgA@@@DjYU_VByHu`@@@@@@H\ndclL@@{TivY~DeZhHB`@`\ndid@@LdbRQk``b@CAhPjX^Q`\neMJH\\Df`pgd@\ndeTD@@YIfUqehH@@LFJfxYyF@\ndclH@@rQQRJJuJ{PUDB@FCES\\L|Q]@\ndif@@@RYWZZ@BP@pXDpj{dB\ndaF`@@pjYJYfn@b@@pPfyG@\ndeV@@@RYV~f`@i@B\ndeV@`BBHRYg]n``I@B\ndmNH@NCHhheDVzU`@@@@LJCJe^Hp`\ndcnD`HI`BDfYoVnWZfX@@@`\ndmND@DCdfVUrjUZjZi@LFrfFUyB@\ndeVH@HAIYWVz`@d@H\ndaG@@@rdifvxH`@C@linyA@\ndieDPLZD@HhHrREQKaVii@LBrnGd@\ndk]L@LhDeIeoYR[SZjZZdHZ`\ndmTJ`HSNd@cIICeMEjjh@`\ndaxB@@rnRV{jj`CAhSBinHG@\ndeeD@DHFR[eyiihHr`\ndaxD@@QIgUjfBJlBpj{dL\nfoQPB@F\\@DYHheBeLdRdeV]Th@@D@@P\ndk^@@@RfYU\\]Tz@@@@@LECBinFUOdZ\ndclD@@kHheCDdUKkSP@P@P\ndeV@@@RV[TYzP@@C@j[axaR\ndklHPBBPzPrJJKQEIa``bZ@bV\ngGP@DiUjaAXEXwbD@\ndmtH@@RYWUih@IhBN\\NALJiWb\\H\ndk]L@LxDMIe]eRkSZjjjh@`\ngN}@DVDfUZi@`\nfb}@`@@YRYVum[ehrRkNBf@BjjjjJ`@p\\AFJ\\EIQk^bgODZB\nffs@`@@URYVumfv^cIJmyIX@Jjjjjbh@H\nfjc@`@@ErJJQIFYJSKXgIJlyNVjjjjjjj`@pC`eF\\EIVkN|FJ\\|`T\ndg|@@DjU_eZx{BAH@@BJ\\MaBine]N~Q`\neFJHSHpP\ndiV@`J@HRfU|kahDB@CB`QnGdD\nfhy`B@J@BDifW_e\\TDkpZA`R@B@DAVF`DYpTeFl{wHA@\nfhy`B@N@BLdTTTRRVqirUmNh@`BBh@@pt@cARUhugAyCp\ngNx`DJdssTpFBsyD\nfgA`@@@ISLrotyHvk@@@@@@@P\nfdy@@@LdbbRbVbJwMAc@pU@P@@ab`\nf`q@`@@^RYWUe^cKN`@f@B@DNVB`HpRbmFm{bNB@\ngGP@DiVV`iJpJqoDH\ndeTH@@RYWVf`@j@CC`SBhYyG@\nf`qAA@A@bOQBSJ{\\ktYYt@EP@P@A@\ndif@@@RfU~F``@@pYLJf{b@H\ngJQ@@dsU`XKGbD@\ndeVD@LADfvUFVjjh@p{BinF^P`\ndmtD@@QIV[VUZh@@@pZfxYWbQ`\ndeT@`@bDfUuih@Jp@`\ndid@@DkYWaz@@@LF`j[ayB@\ngNx`LDdskUXD\nfoA@@@DkfYU]UcNz`@@@@@`\ngJX`DBdru@XS\\RH\ndeVH@DAIgeQej@@@LJrfx^Hd`\ndg~@@@RYfUWd}mh@@@@@pdBinFUwbGX\ndid@@DjYmaBH`@LJpj[nPH\ndmvD@EBdin]~F``I@CAdJfF^Ph\ndetD@@eIYe~DYZjjh@`\nfmoA`@@HWdTrTTtbRLrTfVrk^CdhymUUUUUUUUU@AauFBTYrRmFl{pXyKUoQsV\nf`qAA@A@dORBSJ{\\ktYYt@EP@P@A`IFBTUhunHxH\nfb}@`@@YRYVum[ehrRkNBf@BjjjjJ`@p\\cENBdkQk^CEOD@r\nfb}A@@@YEDeMDhTihjLUiwhyjjjjjjih@L@``cAJ\\EIQkNBgOHQ@\ndknL`LaE@HrRPzIJZ]Vh@b@CAlInd~Qh\ndeUH@JdDin]xZB@`@pIBX^IT`\ndg]L`LnDT@cIIChdieNkT@QP@P\nfgAAB@H@BDjyeUrLd[Uf`@@B@@H\nfgA@@@LdbbbTVKIBMjp@@@@@@D\ndieD`JXaCDRYgvzejX@pHLi`\ndmUL`LZDh@cIHULdeijh@p[FxYWd@\ndeV@@@RfyWahBB@CBj[agf@a@\ndcNH@DAIVYeEZ`Hb@B\ndaF@@@Rfu[j@@@LJABinIg@\ndo}D@LlMrIJJIIHiSjhHHh@H\ndid@p@qBqAqDfYun``H@H\ndcn@@@RieU~V]jB`b@C@\\JfxYWbIh\nfoA``@I@PdwJ{J|EYsP@UUD@D\ndeUH@AdDim][j@B`@pYLJfGdR\ndid@@DjUZnBAH@LFaLkayC@\nfoA@@@DjU][VgKNBAJ@@@PiXZ`cAJLdkQk\\`x\ndid@@DjYUaBHP@LFSBiayG@\nfoA@B@@QBSJzlkQegP@S@@@H\\lM@Q`eNBUhunP\\\ndif@@@RYWZZ@BP@piLJnx`B\nfoA`@@@ILkjrmFV]@AL@@@ar`\ndeUD@DXIRYvTYZjV`B\nfdyAb@HHpCpRkVYU_]Nmyj`@@B`@B\nfhiA`@@Hddjrm|jIW`mPAD@@@A@\nfhi``@L@PdrkLjn[s`mUTEAD@A@\ndeVD@LADeVUFVh@@@`\ngJX`LDdju@XP|Tp\ndifH@HAIfuxZ`@@B\ndif@PBBPRPR[e^Fh@@@pbNES\\H\ndcNHpJtIAICICHiCDedLuP@R@D\ndkn@hJBPRPrPvPNPrJPqIPpYj`@j@B\ndeV@@@Re]Xj@Bj@C@fxYxTIa@\ndmvHPBTIAIAInV_ij@HP@`\ndcNH@NCHeEDdYplAAT@D\ndkn@PBBPRPR[eW[aj@Bj@B\nfHbhA@\nf`q`@@@YIEBedhdnB]zh@J@@@@`\ndeVD@D@dfVuFVh@@@pXj[agdH\nfoAP@@@NRYWVUzLMZ@B`@`@B\nfde`@@@ISKN~rmFBTFH@@Pp@@@`j`\nfoQHA@FJuXFH`HRYUYYbTT[UjZjefZ@B\ndid@P@BJdDef_ahH@@LJ`fx^P@\ndeT@@DjY]zXFB@@pYLinGbEH\ndaF@@@RYWih@H@LBCB{bIP\ndcl@@DjYU_egX@@@@@pYLJngaLJz\ndknL`LaM@HrRRqIYPYV`@f@B\ndeTh@DiiAIgeQej@@@H\ndg^@@@rIRJEJFRoU@AT@D\nfoAp@@@PidbbvbRafJJuMT@ER@A@\ndk_@PBxpbEbDfYYUZ]NBBbT`B\ndcvB@FAEuIm[VZijX@`\ndknL@JABR[mfWSZZ@`@B\ngOq@@drm]SRA@\nfoA@`@@BRYfYWuVLyh@`@@@CBUF\\EIVcNyBp\ndaG@@@[diWRh@I@B\ndeT`@@pjrQQQUMpEAP@XDUCOHX\ndaDh@DqnAIeZfZZd@`\nfoAP`@DNAsHheEEJefBMYji`@h@B\nfoAQ`@DX@pRSJs|kSegMTs@A@@X\\QaVcV]rG@\ndg|@@DjU_eZx{BAH@@BJ\\MaLJfe]N~Qp\ndk\\H@@RYm[Watz`@@@@H\ndmvH@JAJ[g_ahHBP@`\ndmvH`BdIAIfUya``a`@pkBhUyC@\ngOy@HDfUkjj`LJlZ~P@\ndifD@LADeYWaZjj@H\ndif@@@RfU~F``@@pxDpj[nPH\ndmtH@@rJJIJEn`HJ`@pxBiae^Ig@\ndeVH@NAJ[VvF`BH@LBPfGfYt`\nfoQH`@LBUXCldTRabRrIRRcVjj`PJ`@LFPISfg\\``\ndmM@PBx@c@aJYg\\jeZdHB@B\ndaF@`H@HRVU[jjj@LNaLJf{d@\nfgA`B@K@BDifUW|TEiQj@@@J@@H\nflmAP@@LUyNQQQQEJQJI|Eish~BtuUUUUU@A@\nfnkA`@@U[dTRTrTrTtRJeFRUYpTmMUUUUTuT@D\ndaDH@@RYUih@H@LBCB{bHp\nfoAQ@@DZ@drsJkjlYsUPTDP@D\nfoQAB@C@BDifYU^gIVtz`B@DH@@`\nf`ip@@@F}dbbTRRRQhpVkN@@@BB@@B\ndklD@@QIe]e]MjZ@@@LApfFUt~QP\ndg|H@@rIQQJQZ}NfuUUTt@P\ndmtD`ATHaIe]nf`@jP@pXDpjGb]H\nfbmPB@NA@DYHhhhddmcEJ\\e[Sj@H@`jj@@H\ndg~H@HAIYeg_eNzB@@@@B\ndmvD`La@BLdabRbxUjjj@H\ngGQ@@djutA`c^HP\ndaD@@DjUZxHH@CBdpj[bQp\nf`qpB@DLxBHRYUvYZcKN`@hBB@@H\ndigDPLXXP@b`cIHUDnEZfd@`\ndaE@@@aJmUnjjh@`\nf`iA@@@YHhhhheEZBdxwj@BHHH@@`\nfluA`@@HRdrvmkZxiFlFKUUUP@U@@P\ndev@@@Re[TjFP@@@@LFaB[iy@`\ndif`@@pjGIEEEVxB``@ppjGdL\ndaE@`BhHaIfUn`H@@ppL{bTp\ndg~L@BAER[e[gzSmh@B@@@`\nfj}@P@@\\teIfVWn]{YrQhyZA`hBBJ@@H\nfj}@P@@\\LeIfVWVu{YrVhyZA`bBBJ@@H\ndmvH@DAIVUVUZjjh@peLJfxYWdP\ngNp`@dfzZj@pJMX\ndk\\D`HP@cIHXheDQgSV@@@@@pZnE]ObAH\ndeVD@FADfygFV``@@pjfxYyB@\nf`qa@@H@RVUuYUgG^h@J`@@@H\ndaD@`@qDfYVz@`@CB`pj[d\\\ndif@@@rRJEKaj@@@LJSJ[nHP`\ndifD`Na@BLddJT[ejj`B\nfhiQ`@DX@pRSJswJ}N^BuSMA@P@D\nfgAa`@N@t[HhheDTdsdeFltC@UQ@A@\neMBBHRYCAKd`\ngGPdMQDGpRUYiDe@\ngGPXHlQxIU[U@XR|VH\ndeU@@@qJYejxBHh@LJJfF^Qp\ndmuH@DXDfUgjZ@Bj@B\ndcNH@DCHheEBdnmU@@@FGIeMpkqIt\nfnk@`@@UrJIJZIPiSQHrcEZ]zNVfjjjjjZj@CCrLTxJRmFlxLTyyAh\neMJDBDe`pQyP\ndeTH`ICDRUe_af@B@bGB`Jf{fPd`\nf`qAB@O@qDfYUg_EjsjP`@@`AAC@\ndcLH`ICDRUe]^FX@J`Ha`\ndid@`@bDf[Wai@@@LJ@j[nI``\nfhi``@C@PdsrnljJW`mP@T@@@A@\nfiwpP@DVz@wliLsLj{[klrPeFCEKQmTtuAPHDQ@@FDj\\d{qV}GrF`\nfhiPb@OA``@QddabbRRvRkF\\m@@@E@@F@jLxJRmFxcpP\ndeVH`IDIAIe[ZZ@Bd@LBSJGb]H\ndmvH`IDIAIe[^f`@i`HF`\ndmv@`ABHRYWUih@IhBN\\FALJixgJ\ndaE@`FxLQIfVfifx@`\ndaFH`BxLQIe\\jffh@`\ndig@@@aDkYWaZ@@@LJPj[nI@`\neMBBHR[B\ndmtD@@QIn[VUZd@@@pYFxYWdT\nfhi@`@@HR[YfUWMypVf`@@@@@ptc`iJtZsoAyC@\ndk^H`MDIAIe[mZy]`BIjD@`\ndaF@@@RYWifef@H\ngOx@@drm[RtA`Uc^HL\ndidL@@QdfU\\jZff@LBpf{dB\ndcmH@HDLbTTRbOBnt@@@@A@\ndaF@@@RZW[jii@H\ndaFH@NAIe^f`@`@piLJny@@\nfHgPAa@\ngC`DAbZHRVhB\neMBBHRYCAGe@\neFJH\\HpXQr`\neMPBchLF^P\neMbDBDfp`';mlb.mE='daD@@DiYZYji`@\ndaD@@DjUZxHD@@\ndaD@@DjUZxHH@@\ndaD@@DjWjXHB@@\ndaD@@DjWzXHB@@\ndaD@@DjYvxH`@@\ndaD@P@bBbDfYvzB@@@\ndaD@P@bFbDfUjz@H@@\ndaD@P@bNBDfUzZ@B@@\ndaD@`@BDeeVz`@@@\ndaDB@@InRYgrfiZ@@\ndaDD@@IIf]n``@@@\ndaDD@@QIeZfZfh@@\ndaDD@@QIe\\jZehHj@\ndaDD@@QIe\\jZfh@@\ndaDD@@QIe\\jZihHj@\ndaDD@@YIeZn`B@@@\ndaDD@@iIeenjZd@@\ndaDD@@yIe^fZVX@@\ndaDD@@yIe^f`@`@@\ndaDH@@RVU[f@@@@\ndaDH@@RVU[j@@@@\ndaDH@@RYVih@H@@\ndaDH@@RYWih@H@@\ndaDH@@RYe[hB@@@\ndaDH`NBPRYWih@H@@\ndaDH`NBlRYWih@H@@\ndaDH`NCDRYWih@H@@\ndaDL@@SdfURijZ`@\ndaDL`HS@BLddJS\\mUP@@\ndaE@@@YIeZn`B@@@\ndaE@@@yIe^f`@`@@\ndaED@DHNRYWifif@@\ndaED@DpFRYVkfjY@@\ndaEH@DXDf[Vyje`@\ndaF@@@RYe[hB@@@\ndaF@`BBHRYg[hH@@@\ndaF@`FBHRYVkh@`@@\ndaF@`NBHRYWih@H@@\ndaFD`HI`bDfYjzif`@\ndaFD`JK`BLbbbMMTtp@@\ndaFH@DAIeUnZjh@@\ndaFH@HAIYUnfjh@@\ndaGD@Dp`yIeVfZiX@@\ndadL`HS`BLddJULwKUU@@\ndax@X@bDbLbJbFbNbLbdLeUT@@\ndax@X@bDbLbJdFdNdLbdLeUT@@\ndax@X@bDbLdJbFbNdLbdLeUT@@\ndaxB@@QnR[VZY`cH\ndaxB`HSBCpRjuZj`@\ndaxD@@IIeujj@@\ndaxD@@QImUifALj`\ndaxD@@iJU^jj@@\ndaxL@@SDfUVjh@@\ndaxL`HS@BLddNbuT@@\nday@`Dp@aIfYjj@@\ndazD@LADf]Vjh@@\ndazD@LADf^Vjh@@\ndazD@LADf^fjh@@\ndazH@DAIfujj@@\ndazH@DAImUjj@@\ndazH`LPHaInVZj@@\ndcL@@DjYn}aBHbh@@\ndcL@X@bBbFbAbEbMbDfYn\x7Fijjjj@@\ndcL@X@bDbJbAbEbMbDfn^_ijjjj@@\ndcLB@@RURYYejyjieh@@\ndcLB@@RiRYyVQejjjh@@\ndcLD@@IIf]z[hHBj@@\ndcLD@@eJ[W[[j@Bk@@\ndcLD@@iJ[g]xZB@f@bX\ndcLD@@uIfUk[hBBj@@\ndcLD@@uIfU}FV`PJ@@\ndcLDHFDH`haXcXaIf[ozYjYjP@\ndcLF@@IaWTfYn\x7Fijjjj@@\ndcLF@@Rag\\bbTVTILuSUT@@\ndcLH@@RYWUZZ@Bj`@@\ndcLH@@RYWYzZ@Bj`@@\ndcLH@@RYeZvz@`j`@@\ndcLH@@rJJIJGMtAAU@@@\ndcLJB@PUuNR[eY~eijjh@@\ndcLL@@QTfvUtYZ`@h@@\ndcLL`HS@BLddJfRtjmP@P@@\ndcM@@@WIDeBddU@AMTACP\ndcMD@DTIR[fVQuhHF@@@\ndcMH`BuPBDf[U{aj@BX@@\ndcMh@DKaePR[eoVEjVfhHF@\ndcNB`BaLtOCIILeBdnmUUU@@\ndcND@DATfyeXYZ@`h@@\ndcND@LADfU[U]Zj@@@@\ndcNH@ICHhdhdYSP@UT@@\ndcO@@@aDiUm^UZh@HB@`\ndcl@@DjYU_egX@@@@@@\ndcl@@DjYn}BXVjjjd@@\ndclD@@UIfV][iuhFAH@@\ndclD@@iJYW]rnF``IhBI`\ndclD@@iJYW]rnF``Jh@@\ndcll@Dsm@iRYgeVE]ZjeZ`@\ndcllADqe@]R]{HhdhdcWRkURmT@@\ndcm@@@YJYYwhUtH@@@@@\ndcmH@DpLbbbLRQTnmU@A@@@\ndcmH@DpLbbbLRQTnmUUUP@@\ndcnL`LaA@HrRPjIKTrzmPHD@@\ndcndADkatIjYyIefY[eujeji@@\ndcnl@DsetBeIf^UXUujjUj@@\ndct@@DiUUVjjj`@\ndctB@@I]rJJJIVMRuLDE@\ndctB@@PYRYU{ViijBBP\ndctB@@RURY]VvjjZ@@\ndctBHFxYBHRHrHkprJPqREUUMT@@\ndctF@@IaWTfYn~jjj`@\ndctF@@rngTen{mjjj`@\ndctd@DrmATf^VYjji`@\ndcuD`FWi@HrQRXiSUTttDU@\ndcvB`JFUt@aJUgfjjfX@@\ndcvD@LADf^eujjj`@\ndcvD@LADf^fYjjj`@\ndcvHPF`G@WCIIEXmIUSUPQR@\ndeL@@DjYeIjGijjjj@@\ndeT@@DjWvifjih@@\ndeT@@DjYUXPbDP@@\ndeT@p@bDbLbLbdLRPsU@@@@\ndeTB@@KiRYg]nZej`@\ndeTD@@SHheDYaMUMP@@\ndeTD@@eIff\\Ijjf@@\ndeTDB@YnRYe\\YZB@@@\ndeTD`AdHaIe[jz@HX@@\ndeTD`NDHaIfVVfBA`@@\ndeTH@@RYVZfZZj`@\ndeTH@@RYe\\YZA@@@\ndeTH@@rJJIHmtA@pD]@\ndeTH@@rJJIHmtAAH@@\ndeTL@@JTfYoXXHH`@@\ndeTL`BjPkDf[W[jjjh@@\ndeU@@@EIYe^g``p@@\ndeU@@@aJWeQfj@@@@\ndeU@PBdHchaIf^VFBBH@@\ndeU@`Dp@aIgeQej@@@@\ndeUD@HDIRVUunfef`RKh\ndeV@@@RVUenh@J@@\ndeV@@@RYeun`HJ@@\ndeV@PNBHFHRYeYi``x@@\ndeV@pBBHzHfHRYgea``b@@\ndeVD@FADfygFV``@@@\ndeVD@IADfyWxV`@`@@\ndeVH@BAIf]VzB@h@@\ndeVH@FAIfUqehH@@@\ndeVH@HAIYf^f`H`@@\ndeVH@IAJ[Vvz`@h@@\ndeVH`Ax@aIfVVfBA`@@\nded@@DiUUjjj@@\nded@@Dj_VfZZ@@\nded@X@bDbBbFbAbIbDf{nijZ@@\ndedD@@QIeVVjjP@\ndeeD@DdAR[UYjjX@@\ndefD@LADf^]Zjj@@\ndefD`FFPBDiWnjjf@@\ndefD`FFPBDi]nijf@@\ndefJ`JaLFP|LddjRcUTp@@\ndet@@DjYUX^d@@@@@\ndet@@DjYUX^dHbH`@\ndetL@@jTie]rnF``J@@\ndet``Dki@HRYYUnFVjVi@@\ndev@@@rQQJHtpr@@@@@@\ndev@PL@HPHRYUTjFVj@@@@\ndevh@DJndDfVU[af@`hP@\ndevhADIadFf^R[fUnxVijY@@\ndg\\B@@Q[R[VUmgVf@HhBL`\ndg\\B@@SSRY[W[FVh@Ih@@\ndg\\D@@eIfU_Un`HJj`@@\ndg\\H`ABHRYVwUih@Jjh@@\ndg]HPAuPbBbDfYw[fzB@ij@@\ndg^B@BAMoHiieDeBimU@DP@@\ndg^L`LxY@HrQQYJEIYUSRuUAFP\ndgl@@DiUUUZjjjh@@\ndglBA@RUSe{HihheDbtuSUAFH\ndglBPHRU@HhHrRPrIRIkUTmP@@\ndglD@@QIgV]YjfjZBJ`\ndglD@@QImUUUjjjj@@\ndglFPHkivpqLqDen{nzjjjh@@\ndgmB@LxDWTfU[{Vjjfh@@\ndgnD@KADfuUUVjjjh@@\ndgnD`H[`BLdTRbJRUUMUT@@\ndg|D@@OIEEHhfmPkmAU@T`@@\ndg|DPFDH`haIf[oWiNyjY`@@@\ndg|H@@RVUvU[cn`@`@@@@\ndg|H@@RYfUWd}mh@@@@@@\ndg|L@@ildTRbrJQTJtEAEL@@\ndg|d@Dq]@\\bbbbfJSSimUSTs@@\ndg|l@Dq]@[rJJJJXiMNfuUMSL@@\ndg}@@@aJVYU^Svv`@@@@`H\ndg}@@@mJYeU|]Tz@@@H@@\ndg}D@AlBRYgU][iVB@jjD@@\ndg}D@DpCrJJHqIYERzuT@EP@@\ndg}D`LHU@HrQQYJJEYQwSMMMR@@\ndg}H@DHDfYV]rX{Zi``H@@\ndg}HPAuPbBbDfYw[fx{``JZb@@\ndg}L`FWSl@cIEHhbeEc]MUUTsP@@\ndg}L`JXiTIAIf]VunNzVjZj`@\ndg~D@EADfufUqT{ZZP`HBL`\ndg~L@BAER[e[gzSmh@B@@@@\ndg~L@IAKR[Ye]z]MjdHB`@@\ndiD@`@RdjeVjj`@\ndiDB`HSB@HrRPiIZj`@\ndiDD@@GIEHjjjj@@\ndiDJHDpnDAbHbaahcIIJiIZe@@\ndiDL@@xTiUVjj`@\ndiDLPBhPbFbLbbbeiZdHQ@\ndiDNPHSB[a@XhXrRPzQZe`@\ndiE@@@sIDhcFZj@@\ndiF@PHApiprRQVRjj`@\ndiFD@AADfuUjj`@\ndiFD@LADf^Yjj`@\ndiFD@LADf^]jj`@\ndiFD`JxPBLbdTljjX@@\ndiFDpAk`bDbLbLbdJTjjX@@\ndiTH@@RfU|kahDB@@\ndiTL@@X\\dRRaaJzjZj@@\ndiV@@@RfU|kahDB@@\ndid@@DjUZnBAH@@\ndid@@DjUfaBB`@@\ndid@@DjYUaBHP@@\ndid@@LdbRQk``R@@\ndid@@LdbbQxXF@@@\ndidD@@IIf][hHB@@\ndidH@@RYVZZ@B`@@\ndidH@@RYVzZ@B`@@\ndidH@@RYeVz@``@@\ndidH@@RYevz@``@@\ndidH@@RYfVF@b@@@\ndidH@@RYm^Fh@@@@\ndidHHFBHJHzHFHRYgljZfh@@\ndidH`DBHR[e^FX@@@@\ndidL@@IdfYoa`b@@@\ndidL@@RdfV^fZjj@@\ndidL@@SdfVTjZfZ@@\ndidL@@pTee^fZZi@@\ndidh@DKaAInV[fiZ`@\ndie@`HxGCIIEJnFjiX@@\ndieD@DpFRYVZyjfd@@\ndieD`JXaBPRYgvzejX@@\ndieD`LIN@HRZufFZid@@\ndieH`Dq`BDfUfnZii@@\ndie`@@pjX\\dTTUk`Hb@@\ndif@@@rJJIEn`HH@@\ndif@@@rRJEKaj@@@@\ndifH@AAJ[W[j@B@@\ndifH@BAIfuxV`@@@\ndifH@JAJ[gxZB@@@\ndigH@DK`R[e^Eh@@@@\ndigL@Ds`XTfUfn`BH@@\ndkLB`HSB@HrRPiIIIZjjh@@\ndkLH@@RUUUVjjjh@@\ndkMB@LxDeTfU]mZjij@@\ndkNF@BAIWSR[YVYjjfX@@\ndk\\@`@bDfYYwZ]NB@@@@@\ndk\\B@@SSRYVuVfeVi@Bh@@\ndk\\D@@QIee}RkaZfjjh@@\ndk\\D@@wHhhhhbfESZAhD`@@\ndk\\D@@wHhhhhbfESZBhD`@@\ndk\\H@@RYWYVftx@H@@@@\ndk\\H@@RYeg]itxH@@@@@\ndk\\L@@x|bbbTTJZUuhFHF@@\ndk\\b@Dsm@iMIf^UvE]Zjeih@@\ndk\\d@Dq]@\\bbbbfJZ]MjjZe`@\ndk\\d@DsmB\\bbbTrQXUujjUj`@\ndk]D@JxCRe]YTjtzjjjj@@\ndk]D`LHY@HRf]VwJtzYifi@@\ndk]H@DpLbbbLRVJeujh@J@@\ndk]H`FVPbDfUonkmN@Hfh`@\ndk^@@@RfYU\\]Tzjjjj@@\ndk^@@@rQQRJJjaTzBjBD@@\ndk^D@IADfvYWz]MjdHB@@\ndk^d@DXYtCRYf[WaWVjfji@@\ndk^d@DkaTMRYYe]neVjZji@@\ndk^d@DkatCRYYfUngVjZji@@\ndk_D@DHPuIeeevySZ`hD`@@\ndklB@@PcR[me]]ZZ@B@@\ndklB@@PcR[me]]Zj@B@@\ndklB@@QSrJYJIJF]ZX@b@cH\ndklB@@QmR[fUxUZBBF@@\ndklD@@MJ[eZ~F`HJh@@\ndklD@@eJ[Vvfz`@jh@@\ndklH@@RYfWua`Hbe@@\ndklL`HS@BLddJbRvWUjB@`@@\ndkl`@@kaRe[vTf@HZj@ah\ndkm@@@GHhhhhdvf@bbh@@\ndkmD@DHCRYvUvUZh@J@@\ndkmD@DTCRUfWtYV@`e@@\ndkmD@DdCrIJJIPxUV@bE@@\ndkmDpDgSBHjHVHRYYmYn`HJf@@\ndkmH`NVPbDfUunih@JZ`@@\ndkn@`D@HRUUYWSVj`@@@\ndknD@LALbbRbaRtvjh@@@@\ndknH@DCHhmEEEYuj@bH@@\ndknL`IaMADRge][aj@Bf@@\ndk~@@@RfYU_JGUN`@@B@@@\ndmL@@DjYUVGi@@@`@@\ndmL@`@VDifU^FUifje@@\ndmL@`@ZDifU^FUifje@@\ndmLB@@RURYUVJaejVjh@@\ndmLD@@QIe[VfeVi@B@@\ndmLD@@QIe[VfeVj@B@@\ndmLH@@RYVuiiV@BjH@@\ndmLH@@RYe~Ifyjjjh@@\ndmLH@@RYiYKnUjjjh@@\ndmLL@@SdfVUrjUZ`PH@@\ndmLd@DpYBdfV]VzUZZjV@@\ndmLd@Dqe@TfUeZzUZZeZ@@\ndmM@@@yJUntfePBIhP@\ndmN@pN@H`HPHrRPqIZneUhDB@@\ndmND@BA\\bbbReInFjZjd@@\ndmNH@BAIfUmiEX@@@@@\ndmNH@NAIYe^neZdHB@@\ndmNh@DkaTDfVYVzUZiZi@@\ndmO@@@SdfVUrjUZ`PH@@\ndmTB`HSB@HrRPiQQZjj@@\ndmTH@@RUUUjjj`@\ndmU@pLD@a@c`cHheEKFjfh@@\ndmV@HLBHQpYpVHrIRHrJjjj@@\ndmt@H@bAdIdEdDfUvjZ@Bj@@\ndmt@X@bBbFbAbIbEbDfYojzfZj`@\ndmtD@@QIgYVUZh@@@@\ndmtH@@RYWUih@Jh@@\ndmtH@@RYe[[hBBh@@\ndmtH@@RYeeZVfjj@@\ndmtH@@RYeeZZjjj@@\ndmtH@@RYe~[ffjZ@@\ndmtH@@Rfuu[j@BXBA`\ndmtH@@rJJIHin`HJ`@@\ndmuD`LVD@HrRRqIXYV`@`@@\ndmuH`Dq`BLbbRbJkfjZi@@\ndmvD@DATf^Uqej@B@@\ndmvD`La@BLddlTReUhB@@@\ndmvHPEHJsjsHhhmDVFBBK@@\ndmvHPEHLSlSHhhmDVFBBK@@\ndmvH`ITICHhdhdZZ@Bj@@\ndmvL`BaL@HrRRjIJUVjjh@@\ndnDH@@ReVDijiZ@@\ndnDH@@ReVDijjj@@\ndo\\H@@RUUUUZjjjj@@\ndo^HpAxH`hb`aIevyffjZjhHa@\ndo|J@@S[_HheDdeDYMjBBb`@@\ndo|L@@RtfUVuwSZjp@h@@\ndo|L@@RtfvYWwSZjA@h@@\ndo|L@@iTinU]_ihHHjXBCP\ndo|L@@iTinU]_ihHHjXBC`\ndo~L@MAER[e]mnEh@Ij`@@\ndo~``LKad@aJ[V]Y[j@Bjj@@\neF@Hh@\neFAAD`bJ@\neFAADdRJ@\neFABD`bJ@\neFABHhbL@\neFACDlRL@\neFBBHc@@\neFBBlc@@\neFBCDc@@\neFHBJ@\neFPBc@@\neFbHbHp@\neFhXNic@@\neM@Hv@\neMA@JXaIh@\neMABHXaIh@\neMABHYAIh@\neMB@Jch@\neMBBHRZ@\neMBBPRY@\neMCALhabHz@\neMDARV@\neMFI@bMP@\neMFIGBMP@\neMFiDqzN`@\neMHAIX@\neMHAId@\neMHAIh@\neMIdEJHIcd@\neMJDBDeP@\neMPBch@\neM`AIx@\neMbDbDfp@\neMhDRV@\neO@Hyj@\neOB@Hcfh@\neOBBHcfh@\neOBCDcfh@\neOHBNZ`@\neOPBcfX@\neO`BNZ`@\nfH`D@@\nfH`T@@\nfH`X@@\nfH`p@@\nfHa@@@\nfHap@@\nfHbT@@\nfHcD@@\nfHcP@@\nfHcT@@\nfHcd@@\nfHdH@@\nfHdP@@\nfHdd@@\nfHdp@@\nfHep@@\nfHfX@@\nfHgP@@\nfHgd@@\nfHgh@@\nfHpXT@\nfHpp\\@\nfI@@\nfJ@@\nf`a@P@@Ht[HheDhmD\\jsTE@qP@@\nf`a@`@@FrJJIJQJrLy@PUUT@@@\nf`aA@@@ILsKWRpTADUUP@@\nf`aAb@NFlBHrJIKIRJUTY@AUST@@@\nf`aQC@IVLBPQHXdLbdLRTvf`eUPADu@@@\nf`ahB@LDxJP@aJ[V]Yf\\h@Jjj@@@\nf`ahB@LDxJP@aJ[V]ZV\\h@Jjj@@@\nf`aq@@DV\\CHheEDcddkSTE@UP@@\nf`i@P@@HD[HhdihdhUSbkN|uHPTUB@@\nf`i@P@@HTYIe[VUZLeiwfi@HjhP@@\nf`i@`@@DRYfyU]`mNmyi`@@B@@@\nf`i@`@@HrJSQQQIH|UiuoMP@P@P@@@\nf`i@`@@VRYfYU]`eNMyh@`AB@@@\nf`i@a@ARADDbDfYuUUYqVg^``Jh@@@@\nf`i@a@BBADNbLbbbRfaRcIBU[tDE@AA@@@\nf`i@a@FRAD^bDfUm[UirRkN`BJ@BH@@\nf`i@a@FRAD^bDfUm[WirRkN`BJ@BH@@\nf`iA@@@YHhhheLUfBdYwjBb@@H@@@\nf`iA`@@HldrlkZuFJMYsTaADtP@@\nf`iA`@@HmdTRTRTrQhqQkNZdHHfb@@\nf`iQA@B\\|@HpDISLzsnRdcN}TaAQUD@@\nf`ih@@@\\eYvRJJJJUKJgEZMX@HHFhH@@\nf`ip@@@XTeLwOvmNJt{pPQT@A@@@\nf`q@@@DjUgm_hJs``hB@`@@\nf`q@`@@LRYfWg^Qg^ZB`@@@@@\nf`qA`@@FmdbbdTUrRiIVjBh`jd@@\nf`qA`@@Hpdrlrj~gV|uP@@@@@@\nf`qHC@DXxHDPrHMDYEDeDUEEj\\]z@HhH@@@@\nf`qP@@@PrQJJJIIFJlYsP@P@P@`B@\nf`qPB@DX@DILwLjoiuoMUUUUT@@\nf`qP`@DBAKHheHdhbmPSoMUTa@P@@\nf`q`@@@YEEDbdhdf\\]z@`f@@@PE@\nf`q`B@B@bDfYwVUYqwhHBX@@A@T@\nf`q`B@O@dDfUuYWhrsh@I`@`ACd@\nf`q```JBTBHQDXbBAFQREQQSYJVg^jjfX@@@@\nf`q```JBTBHQDXbBAFQREQQSYJVg^jjfZjd@@\nf`q`b@LPP@HrRPjJIIKZ][ru@@@@@@@\nf`qa@@D@RYyV{TRg^Z`B@@@@@\nf`qa@@D@RYyeg^Qg^Z``@@@@@\nf`qh@@@XirVRJJZGJII`g^BHa`@@DAP\nf`qi`@DTxIPC^rJIQQJiILyISUKMUU@@@\nf`qp@@@Hpds\\rj~gV|uP@@@@@@\nf`qpa@LR}A@@`PQddaTTRRUtxuejBPha@@\nf`y@@@LdbbbbbfkEBMIuo@@@@@@@@@\nf`~`b`KLLBHHDTBNA@`aIneUYYjjjZ`@@\nfbc@@@LdbbbTRLRqWEBMjsoIs@AA@UUPT@@\nfbc@@@LdbbbbbbQQsEBMKuhir@@@@@@@@@@\nfbc@@@LdbbbbbbcJwEB]Hu`ir@@@@@@@@@@\nfbc`@@@ISLrj}{dirVgVBgLmUTrB@m@@@\nfbc`@@@YHheEMDXlijREhuoQSd@@@@@@@@@@\nfbe@P@@HM[HheDhdhmbdisTEALUT@@@\nfbe@`@@HRYWUUUUIQjjjjjj`@@\nfbe`P@N@P[vQQJJKQRzZIUfjijjZi@@\nfbm@@@DjYVWV}~ZlENXI@H@@@@@@\nfbmAP@@BLENQQQQQQQYG[bm^]Eh@bHAJ`@@\nfbmAP@@BUGNQQQQQQPeIG`mNBehIb@@b`@@\nfbmH`@EVBdGlbbbbbbTRacAZb{KPADDLQ@@@\nfbmI@@DTdhFQQIQIQHqIY`iJSejfYjB@h@@\nfbmPB@NA@DYHhhhddmcEJ\\e[Sj@H@`jj@@@\nfbmPb@AJ|dDPdrmrljoSfgQs@DMPTBD@@@\nfbmQB@AJRBHRYVyV[WisShy`BFhJAB@@@\nfbmp@@@V|eLsJzo]SdcZ\\@@@AEU@@@@\nfbu@@@LdbbRbVbrQwMQS@pU@TA@BFH\nfbu@@@LdbbRbbtRJOCIs@pUPE@@BFH\nfbu@`@@YRYWYeg_hrJX@Ij``H@Py@\nfbu@`@@YRYWYeg_hrJX@JY``H@HDj`\nfbua@@D@rJJJPjJYIK^SGKUUX@@@@@@\nfbupb@LVcA@@cIIBmDeLhThkUgKU@ASUQ@@@\nfby@`@@HR[UUUUUZjjfjj`PT`\nfby@`@@HR[UUUUUZjjjjj`@@\nfbya@@D@R[UUUUUZjjjjj`@@\nfb}@@@DjYee\x7F]^RD[S`q@@@@@B`@@@\nfb}@P@@H]gHheDheEeD\\jugQRgKUUUUUUU@@@\nfb}@`@@LrJJJJHyISI\\dkSoIsTED@@@H@@@\nfb}@`@@LrJJJJHyJIK\\dkS`isTED@@@H@@@\nfb}@`@@LrJJJJKIIIH|Djw`isTEP@@@@@@@\nfb}@`@@YRYVum[ehrRkNBf@BjjjjJ`@@\nfb}@`@@YrJJQIFYJYKDyIUgQRuUUU@AU@@@\nfb}@`D@HQvQSRJIJUJYHRiZ]yNVjjjjjjj@@\nfb}A@@@IS\\lj{j|DjsoIsP@@@@@@@@@\nfb}A@@@IS\\l~kZ|dkSoIsP@@@@@@@@@\nfb}A@@@YHihhhdeCenJtzpTyh@@@@@@@@@\nfb}P@@@RRVYfU{wyKSkASg`@@@@@@@@@\nfb}`@@@YHhhhhdhecjRUXt_I@@@@@``@@@\nfb}`B@A@dDfUmeumZLeiwdy`@@`@@@@@@\nfb}`B@A@dDfUmevUzLeipTy`@@`@@@@@@\nfb}`B@B@dLbbbRfbtVbKIBuxJ\\p@@A@@@@@@\nfb}a@@I@RVYfU{wyKSkASe`@@@@@@@@@\nfde@@P@QAHadQJHuDFb@qDXcHhhiMMEciS`eN}MUUUUUP@@\nfde@@P@QAHadQJHuDFbOQDXcHhhiMMEcCS`eNCMUUUUUP@@\nfde@P@@BLGHhhhhhhlcqVoNbt@QD@d@@@\nfde@``ARADDb@qDXaIf]UUUYqVg^``Jh@h@@@\nfde@``BRADLb@qDXcHhhheCBdeqTmN}ADT@AQ@@@\nfdeQ@@DFAdTRbRRTJbIQVg^ZiBBZhDDJP\nfde``@A@BdsLsKslUiuhm@DPAI@@@\nfde`b@H\\d@HRfYfWwQJMxLZjfZ``H@@\nfdi@P@@HM[HheDhdhkdisTE@lT`@@\nfdiA`@@HedTtbJRbbV|Ejjj@``@@\nfdiQb@LR``P@cIIBhheedmjru@pQU@@@\nfdq@`@@HR[UUUUVjjjjj@@\nfdqA`@@LdeJl{jjtuSSLtBbGbiLnP\nfdqPP@LQ@`p\\bbRTTaVRcUUUUS@@@\nfdqaQ@JDT{pPQEoCHhhihldYMRuUUMPHHP\nfdu@@@DjYee]}daZlGtP@@@@@@@@@\nfdu@@@DjYee]}faRlGtP@@@@@@@@@\nfdu@@@DjYee\x7F_daFtxLP@@@@@@@@@\nfdu@@@LdbbbbbTUHeRlXOh`@@@@@@@@@\nfdu@A`@QAHadQJHCDQbLbbbdtqTVeA\\TYuoSUUUUUT`@@\nfduAC`H`bBQCHbTQjHMD^bLbbbdttVLUNBTxHXsUUUUUU@@@\nfdu`@@@YHheEhTddj\\EHu`q@@@@@@@@@\nfdu`@@@YHhhhdeCejBd[S`q@@@@@@@@@\nfdu`@@@YHhhhhdhbZRUXp_Q@@@@@@@@@\nfdy@A`@XaLPVH[DCbQqDfYuygUgG^``JB@h@@@\nfdy@A`@XaLQfHKDUbNqDfYn\x7Ff_d`q`bHhH@@@@\nfdyAP@@BUhNQQQQQQDqIdgAZYjZZj`@@\nfdyAa@MAbBHQDIM_JztvBRUUP@UTt@@@\nfdyP`@AR@EJ[WUe]Yqwj@Bh@J@@@\nfdyhP@DTxIPCAcdTRbbURTRYrRfjVZjjh@@\nfdyi`@DTxIP@qrJIQQJiJILyISUKMUUT@@\nfdyqb@LFcA@`AFRREQQIJH{WcVVhIBhhP@@\nfgA@@@DjYU_VByHu`@@@@@@@\nfgA@@@LdbbbTVKIBMjp@@@@@@@\nfgA@P@@HEkHheHeEBRdmFluUMUU@@@\nfgA@`@@\\RfYe_irQmVh@`@H@@@\nfgAA`@@HLdrmlkQdmFluHADq@@@\nfgAH@@@XhiJYmg]gAJMXH`jeF@@\nfgAP@@@\\RfYe_irQmV@@@@@@@@\nfgAp@@@XheLvnjs`iFlDPT@@@@@\nfgApB@LLx@HRevUUpPTcViYj@H@@@\nfha@R@HHpPG`eUjjjjuUUUU@@@\nfhaH@@@\\DyJUUUWVjjjjj@@\nfhep`@BLT@NQQQQQQRq\\tJQkN|uLuUTuP@@\nfhi@B`@QAHadPzHCDYEEELUDeCpUoPQA@DP@@@\nfhi@`@@RrJJIIQFYHVoAZBA`@@@@\nfhi@c@ARAD\\B@qFQQIYRFIKTX{t@Dl@D@@@\nfhiA`@@B|dsLro~jqgM@D@AP@@@\nfhiHB@EZLDDQdTRVTTTQUFF]@A@QE@@@\nfhiHa@LTdFB@A@`cIIBhhddmmNMYZ`hJJD@@\nfhiIP@DXxHDc^CdTRbfaTVUNZltuUUUL@@\nfhiP@@@ArJJIEJIJYgKN`HJ@B`@@\nfhiPA@BAADNbLbbbrrbRaYrwhHB`BH@@@\nfhiP`@DZAyIgVYW^VkNZjdHBh@@\nfhiPb@OA``@QddabbRRvRkF\\m@@@E@@@\nfhiQA@BADBH]DYEEEeeDeBseoPPE@DP@@@\nfhiQ`@DX@pRSJswJ}N^BuSMA@P@@\nfhia@@E@rQQQHyJIHToAhJ@h@@@@\nfhia@@J@RfywVUxKpZB@f@@@Pe@\nfhipS@IZCpSo@bBAA`cHhheHeTiFJlFBAXjVH@@\nfhiq@@DZBCHheEDeDceNmyj@@`B@@@\nfhiqB@IF]hDadTTTbfLVWE^CMUTmRt@@\nfhiqP@DXxBQoArJIQSPjKJ`mVZZjjjf@@\nfhiqb@LJMAC`AFRRVIKIQKBd{rt@EMLP@@\nfhq@`@@NrQQJIJYHxRjBHbjh@@\nfhqXB@J\\dZpPAFRIJIJJqIBeUSMMUpHJ`\nfhy@C`@QAHadQJHuDFbOQFQQQRZZKFTxIS`sUUUUMP@@\nfhy@`@@HRY[fUWpPwgAZj@@@H@@@\nfhy@c@ARADDb@qBSLzjjkNJt{tDAU@D@@@\nfhyA@`A@bBQGh`LPdsNjjjsdeV]A@U@E@@@@\nfhyA`@@BMdTTTTTTVoEZ|xL@A@P@@@@\nfhyA`@@B|dsLsKnqVgVBt@Q@BP@@@\nfhyA`@@Hldrlk[oQbcN|uHPQUP`@@\nfhyH@@@XxkIEDeDehTjBYspP`Xj@@`@@\nfhyI`@LJMxD`yHhhhUEedRfcN}UUTBAT@@@\nfhyPA@B\\@DXBDif]WmRTekpZdHHjjH@@\nfhy``@A@|dsLsKnqVgVBt@Q@BP@@@\nfhyaB@K^@DISLjo{XhKRcT@@@Tt@@@\nfhyh@@@\\e[vRJJJJUIITxkQk@AA@uPP@@\nfkAA`@@TTeJwsLDDXkVcUUUUUP@@\nfle@B`@QAhbtPzHSDYEEDeCEHe\\s`XpDEATA@@@\nfle@Q`OAbdDPRHYDRbMQAhcHhhiMMEcEJ\\DjZjjjfZ`@@\nfleHb@LBdfB@AFRREQQIIZIZ][ru@@@EP@@@\nfleI@BHTDh@NaNQJJIIKQPi\\eEMA@eT@@@ar@\nfleP`@DA@eIVUue]^B]yX@J@BT@@@\nfle`@@@YIEDeDThll[tTuSPP@@@BAH\nfle``@A@Pdrrr\x7FrjcQRuAPI@@@HJ`\nfle``@D`TeMrnkZ\x7FAAcPDET@D@@@\nflehPBDX}EHAJCFT}dTTRTRRJRsNFluTtuUKP@@\nfli@@@LdbVRRbbjTjjjjjj@@\nfliA@@@IJjjjjkUUUUUT@@\nfliAq@LDhkSo@BH^FRJQSIQUQ[TuUMSU@@@\nflm@@@DjYee]\x7FYhTkA}D@@@@@H@@@\nflm@@@DjYee\x7F]yHQmNCD@@@@@H@@@\nflm@@@DjYee\x7F_yHQmNCD@@@@@H@@@\nflm@@@LdbbbTRrJRxhQmNBd@@@@@`@@@\nflm@@@LdbbbTRvRQyHQmNbd@@@@H@@@@\nflm@@@LdbbbTVRcRXhQmNbd@@@B@@@@@\nflm@@@LdbbbbbTQnEjUcA}D@@@@@H@@@\nflm@@@LdbbbbbTUVDjUcA|d@@@@@`@@@\nflm@B@@AFQQQQQIJGKLdjqoQS@@@@@@@@@@\nflm@B@@RFQQQJKPiIILEIUgQS@@@@@@@@@@\nflm@B@@XfQQQQQIJGKLdjqoQS@@@@@@@@@@\nflmA@@@ILrrknjsdcV]EL@@@@@@@@@\nflm`@@@YHhhhdeElcPTcZ}EH@@@A@@@@@\nflm`@@@YHhhhhdhecRRkFcyH@@@@D@@@@\nflmaA@KQ@DPdLdtTRbtJfRyIVkNbfifZiZej@@\nfluAP@@B\\FJSLsLoJlUkudm@DPDLP@@@\nfluAP@@HdkrSKLvzjlxYtTmT`pQUP`@@\nfluAc`OARBHIDLbIQFh`tQDHrJJJSSQXiZgAJCFZjjjjfh@@\nfluPP@DTAsUlbbTTTlTvRXHshiZjZfX@`@@\nfluP`@DX@qIeVyeUrT]DJVjZ@@@H@@@\nfluQB@DXX@HRYUnYU\\eGQBejf`@@B@@@\nflu`a@BJ|CDebYEEEheDXdlpQkQSAADtB@P@@\nfluaP@E@EKt\\bbbbbRJRRXhshiZdF`bjb@@\nflua`@O@QGHheEDdebeJ\\UXsfh@@@ih@@@\nfluib@DTxIQhi@DYEDhheUDddsdeN|uRsUUUT@@\nflux@@@XIRRmYHhhldiUDdsdcQRA@AQ@@@@@\nflyAP@@HLxJSJkZrkzluT`DUT@@@\nfl}A@@@IRlrjkoAENJl[tTuP@@@@T@@@\nfl}A@@@YEEDhih]DdpTmZlxLTmSSTuJsT@@\nfl}A@@@YHdhheDddcAENJ]ZHTt@@@@@@@@@\nfl}AA`D`bBQCHbTPFHcDYEEEIibheEPWEFl{wdsUUUUUUT@@\nfl}aA@HF@DIdLdRbbRRtJR``cIFuXLZjjZjeif@@\nfoA@`@@VRfUYu^JLz``@B@@@\nfoAAB@A@bDfUmyVcKN`@j@@@@@\nfoAA`@@HXdrkkJdiYsTtp@PBGH\nfoAP@@@NRYWVUzLMZ@B`@`@@\nfoAP@@@XReeV]qZlyfjjjj@@\nfoAPB@KN@DISLjohmJMP@@AP@@@\nfoAPQ@LF`aV`AD`cIICDTiCJLlyZjiZj@@\nfoAP`@BZ@aInvYWejsfjiB@`@@\nfoA`@@@IKLrjzkF]u@@@@@@@\nfoA`@@@ILkjrmFV]@AL@@@ar@\nfoA`@@@IML|{wEFmUSA@R@@@\nfoA``@L@QdTVbbbblmV\\u@A@@@@@\nfoA`a@AZlBHYDYEDeDXhiSagPAESLP@@\nfoAaB@G\\ADILkkJ}FFm@AP@P@@@\nfoAa`@J@PIImeeWyJsfjZb@@@@\nfoAp@@@P\\eKLjorMjsP@@A@B@H\nfoAq`@DXxBSlbbTTtJVhKQffjjjX@@\nfoIA@@@IRlkZ|DTyKUgUSUUJs@@@\nfoIA@@@IRlrj|DTxjqgUP@@AP@@@\nfoQ@b@BBADYEEDeMBdrPeV]AAP@A@@@\nfoQ@b@FRADILkZvmNRUYt@QP@D@@@\nfoQA`@@HldrmlrtYKUgMR@QSD@@\nfoQH@@@RM[IEDhmBdj\\DkQ`@@ajB@@\nfoQH@@@XhiJYmg^YpRcVBHJiXX@@\nfoQP@@@FRfYeUz\\e[S`@@@`@@@\nfoQP@@@FRfYeUz\\e[S`@`JbB@@\nfoQa@@N@rQQQQJKGbiVLz`BB@D@@@\nfoQp@@@XdeLv{ZtyIUgAAE@@P@@\nfoQp@@@XidbbfbQRSNRUYpQAT@@@@@\ngBQ@@eJuT@@\ngBX@@eLUT@@\ngC`@Die@@\ngC`@H{P@\ngC`DADJHRZd@\ngC`DADZHRVXRP\ngC`DADZHRVx@\ngC`DAHJPRZd@\ngC`HADIKLIH\ngC`HAVIMT@@\ngC`HAbIKJ@@\ngC`LADJHtPduP@\ngC`LADJPt`duP@\ngC`LAVJluXduP@\ngC``Adej@@\ngCa@@dkH@\ngCa@@dmH@\ngCa@@dmP@\ngCa@@dmX@\ngCa@@dsP@\ngCa@@duP@\ngCaA@NRVd@\ngCaHH@bNt@@\ngCah@mJAIj`@\ngCahHl@bNj@@\ngCahHlGBNt@@\ngCahHlHRNj@@\ngCahhlAa]ncm@@\ngCaihlLr\\nwQz`@\ngCd@ADij@@\ngCd@ADkZ@@\ngCdDI`BHDRZh@\ngCh@@doH@\ngCh@@duP@\ngCi@DDfZ@@\ngFp@DiTt@@@\ngFp`@dfTujh@\ngFp`@df_Ejh@\ngFp`ATiTvjh@\ngFq@@eOKUU@@\ngFq`@ldrfmT`@\ngFr@ACTi[FZd@\ngFr@ACTi_FVh@\ngFt@ATigVVh@\ngFt@AdigUjX@\ngFtHE`DILikUP@\ngFu@E`drfmU@@\ngFx@@eJf`@@@\ngFx`LDdrfmU@@\ngFy@DDfXujh@\ngFy@JDiTvjh@\ngFy@LDeXvjh@\ngFy@LDi^Jnh@\ngGP@DiVj`@\ngGPBADJHLQXaInih@\ngGPBADJHtQXcHiCUp@\ngGPBAHJPLaYAInih@\ngGPBAHJPtaYCHiCUP@\ngGP`@TfYi`@\ngGP`ATeVj`@\ngGP`ATeVn`@\ngGP`ATiVj`@\ngGQ@@dkUT@@\ngGQ@@eMUT@@\ngGQLJHaQFbLbdMT`@\ngGQXHlZHROjj@@\ngGQ`@bdwMT@@\ngGQhHl@cIIBmP@\ngGQhHlLSIHTmP@\ngGQhHlOAJmZh@\ngGT@ADiVj`@\ngGU@E`dmmT@@\ngGXHD@aIUVd@\ngGXLJHaQFbLbdMU`@\ngGX`LDdsmT@@\ngGY@HDeVZaI@\ngGY@HDefZaH`\ngGYHLaDIMtu@@\ngG]HHjPDIJuS@@\ngJP@DjYd@\ngJPBADJHtPXaIjj@@\ngJPBADJHtPYAIjj@@\ngJPDADQpRZj`@\ngJPHADIKSP@\ngJPHADILth@\ngJPHAVILuP@\ngJPLADJHLPdwS@@\ngJPXHlPDQzt@@\ngJPXHlPLQzt@@\ngJP`@TeVd@\ngJP`@TeZh@\ngJP`@TfVd@\ngJP`@deVh@\ngJP`@dfvd@\ngJPlLQDPHTPduR`@\ngJQ@@dlu@@\ngJQ@@dmU@@\ngJQ@@duU@@\ngJQ@@eKU@@\ngJQDHG@nBUMT@@\ngJQHBHaIfe@@\ngJQHBLQIfe@@\ngJQ`@bdvu@@\ngJT@ADiYhRP\ngJT`E`TfVh@\ngJX@@dkU@@\ngJX@@dms@@\ngJX@@eKU@@\ngJX`LDdru@@\ngJY@DDfvd@\ngJYHC`DIKTp@\ngKP`@df\\Vj@@\ngKQ@@eKcRp@\ngKQ@@eKcUP@\ngKX@@eKcUP@\ngK\\@ADeKbuH@\ngNpXHlPDYIHTmT@@\ngNp`@dfVZf@@\ngNp`@df]Zi@@\ngNp`@dfzZj@@\ngNp`@teUZi@@\ngNplJqDJHtQdTaeUP@\ngNpmJqDJHtP~rJPrjX@\ngNq@@dssUP@\ngNq`AVeJmUP@\ngNqhHl@cIICej`@\ngNqhHlOAJkVj`@\ngNtDLpDDHRevnl@\ngNtHE`DILruT@@\ngNx@@eRmUP@\ngNx`LDdskUH@\ngNx`LDdskUP@\ngNx`LDdssUP@\ngNx`LFdjmUP@\ngNy`LDtf]Zj@@\ngN|@ADeJkUP``\ngN}HEbpDILzuR@@\ngOp@DjWkB@@@\ngOpHADILkW@@@@\ngOpXHlPDYIHUVmU@@\ngOp`@dfUMZf`@\ngOp`@dfVqZj`@\ngOp`@tiguif`@\ngOp`AdeekZZP@\ngOphH`DYIHUVmT`@\ngOq@@drm[UT@@\ngOq@@drm\\@@@@\ngOq`@fdrikTl@@\ngOq`@fdrikUL@@\ngOqhHl@cIIBjujh@\ngOtHE`DILl[MT`@\ngOx@@drm\\@@@@\ngOx@@drm]UT@@\ngOx@@eJqh@P@@\ngOxHDHaIeZx@@@\ngOy@DDfYKZj`@\ngOz@ACVeKNLuR@@\ngO|HDVHaIeZx@@@';Ykb.JZ=w3(228);nlb.tE=function tE(a,b){dlb.wi(a.a,b);};nlb.uE=function uE(a,b,c){dlb.vi(a.a,c,b);};nlb.vE=function vE(a,b){dlb.wi(a.f,b);a.d=-1;};nlb.wE=function wE(a,b,c){dlb.vi(a.f,c,b);a.d=-1;};nlb.xE=function xE(a,b){dlb.wi(a.g,b);a.d=-1;};nlb.yE=function yE(a,b,c){dlb.vi(a.g,c,b);a.d=-1;};nlb.zE=function zE(a){alb.igb(a.g.a,0);alb.igb(a.f.a,0);alb.igb(a.a.a,0);a.b=null;a.d=-1;};nlb.AE=function AE(a){var b,c,d;for(d=new dlb.Obb(a.g);d.a<d.c.a.length;){b=dlb.Nbb(d);if(b.K)return true;}for(c=new dlb.Obb(a.f);c.a<c.c.a.length;){b=dlb.Nbb(c);if(b.K)return true;}return false;};nlb.BE=function BE(a){var b,c,d,e;c=0;b=0;for(d=0;d<a.g.a.length+a.f.a.length;d++){e=d<a.g.a.length?dlb.Bi(a.g,d):dlb.Bi(a.f,d-a.g.a.length);if(e.r!=0){c+=e.r;b+=clb.wk(e,e.q,e.r,(clb.wj(),clb.vj))*e.r;}}return c==0?(clb.wj(),clb.wj(),clb.vj):b/c;};nlb.CE=function CE(a,b){return dlb.Bi(a.a,b);};nlb.DE=function DE(a){var b,c,d;if(a.d!=-1)return a.d;a.d=0;for(c=0;c<a.g.a.length+a.f.a.length;c++){d=c<a.g.a.length?dlb.Bi(a.g,c):dlb.Bi(a.f,c-a.g.a.length);for(b=0;b<d.q;b++){a.d<$wnd.Math.abs(d.w[b])&&(a.d=$wnd.Math.abs(d.w[b]));}}return a.d;};nlb.EE=function EE(a){var b,c,d,e;c=new nlb.TE();if(a.g.a.length!=0){e=new clb.$t(dlb.Bi(a.g,0));for(b=1;b<a.g.a.length;b++)clb.Bj(e,dlb.Bi(a.g,b));dlb.wi(c.g,e);c.d=-1;}if(a.f.a.length!=0){d=new clb.$t(dlb.Bi(a.f,0));for(b=1;b<a.f.a.length;b++)clb.Bj(d,dlb.Bi(a.f,b));dlb.wi(c.f,d);c.d=-1;}return c;};nlb.FE=function FE(a,b){return b<a.g.a.length?dlb.Bi(a.g,b):dlb.Bi(a.f,b-a.g.a.length);};nlb.GE=function GE(a){return a.g.a.length+a.f.a.length;};nlb.HE=function HE(a){return a.e==null?'':a.e;};nlb.IE=function IE(a,b){return dlb.Bi(a.f,b);};nlb.JE=function JE(a,b){return dlb.Bi(a.g,b);};nlb.KE=function KE(a){var b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t;if(a.g.a.length==0||a.f.a.length==0)return null;m=nlb.DE(a);if(m==0)return null;l=gW(Ykb.AX,Dnb,7,a.f.a.length,0,2);for(f=0;f<a.f.a.length;f++){p=dlb.Bi(a.f,f);clb.Gt(p,15);l[f]=gW(Ykb.AX,gmb,6,m+1,15,1);dlb.Ybb(l[f]);for(b=0;b<p.q;b++){k=$wnd.Math.abs(p.w[b]);if(k!=0&&l[f][k]!=-1)return null;l[f][k]=b;}}g=gW(Ykb.Z0,Amb,6,m+1,16,1);for(e=0;e<a.g.a.length;e++){t=dlb.Bi(a.g,e);clb.Gt(t,15);for(r=0;r<t.q;r++){k=$wnd.Math.abs(t.w[r]);if(k!=0&&!g[k]){for(h=0;h<a.f.a.length;h++){n=l[h][k];if(n!=-1){p=dlb.Bi(a.f,h);if(t.j[r]!=p.j[n]){g[k]=true;break;}if((t.u[r]&3)!=(p.u[n]&3)){g[k]=true;break;}for(i=0;i<t.j[r];i++){c=clb.mk(t,t.i[r][i]);if(c==0){g[k]=true;}else {s=t.k[r][i];d=false;for(j=0;j<p.j[n];j++){q=clb.mk(p,p.i[n][j]);if(q==0){g[k]=true;break;}if(q==c){d=true;o=p.k[n][j];if((s<t.g&&(clb.wr(t.p,s)||t.H[s]==64))^(o<p.g&&(clb.wr(p.p,o)||p.H[o]==64))||!(s<t.g&&(clb.wr(t.p,s)||t.H[s]==64))&&(clb.Hk(t,s)!=clb.Hk(p,o)||(t.F[s]&3)!=(p.F[o]&3))){g[k]=true;g[c]=true;break;}break;}}d||(g[k]=true);}}}}}}}return g;};nlb.LE=function LE(a){var b,c,d,e;for(d=new dlb.Obb(a.g);d.a<d.c.a.length;){b=dlb.Nbb(d);if(b.q!=0)return false;}for(e=new dlb.Obb(a.f);e.a<e.c.a.length;){b=dlb.Nbb(e);if(b.q!=0)return false;}for(c=new dlb.Obb(a.a);c.a<c.c.a.length;){b=dlb.Nbb(c);if(b.q!=0)return false;}return true;};nlb.ME=function ME(a){return a.c||nlb.AE(a);};nlb.NE=function NE(a){var b,c,d,e,f,g,h,i,j,k,l;c=0;for(l=new dlb.Obb(a.g);l.a<l.c.a.length;){j=dlb.Nbb(l);clb.Gt(j,1);if(j.K){for(b=0;b<j.f;b++){if(o1(e1(j.B[b],Bmb),0))++c;else if($wnd.Math.abs(j.w[b])!=0)return false;}}else {c+=j.f;}}for(i=new dlb.Obb(a.f);i.a<i.c.a.length;){g=dlb.Nbb(i);clb.Gt(g,1);if(g.K){for(b=0;b<g.f;b++){if(o1(e1(g.B[b],Bmb),0))--c;else if($wnd.Math.abs(g.w[b])!=0)return false;}}else {c-=g.f;}}if(c!=0)return false;f=nlb.DE(a);d=gW(Ykb.Z0,Amb,6,f+1,16,1);for(k=new dlb.Obb(a.g);k.a<k.c.a.length;){j=dlb.Nbb(k);for(b=0;b<j.f;b++){if(!j.K||o1(e1(j.B[b],Bmb),0)){e=$wnd.Math.abs(j.w[b]);if(d[e])return false;d[e]=true;}}}for(h=new dlb.Obb(a.f);h.a<h.c.a.length;){g=dlb.Nbb(h);clb.Gt(g,1);for(b=0;b<g.f;b++){if(!g.K||o1(e1(g.B[b],Bmb),0)){e=$wnd.Math.abs(g.w[b]);if(e>=f||!d[e])return false;d[e]=false;}}}return true;};nlb.OE=function OE(a){var b,c,d,e;if(a.g.a.length+a.f.a.length<=1)return false;b=nlb.BE(a);e=gW(Ykb.SZ,Ulb,46,a.g.a.length+a.f.a.length,0,1);for(c=0;c<a.g.a.length+a.f.a.length;c++){e[c]=clb.Mk(c<a.g.a.length?dlb.Bi(a.g,c):dlb.Bi(a.f,c-a.g.a.length),null);if(e[c]){for(d=0;d<c;d++){if(e[d]){if(e[c].c+e[c].b>=e[d].c&&e[c].c<=e[d].c+e[d].b)return true;if(e[c].d+e[c].a>=e[d].d&&e[c].d<=e[d].d+e[d].a)return true;}}if(c!=0&&!!e[c-1]){if(e[c].c-e[c-1].c-e[c].b>5*b)return true;if(e[c].d-e[c-1].d-e[c].a>5*b)return true;}}}return false;};nlb.PE=function PE(a,b){a.b=b;};nlb.QE=function QE(a,b){var c,d,e;a.c=b;for(e=new dlb.Obb(a.g);e.a<e.c.a.length;){c=dlb.Nbb(e);clb.lm(c,b);}for(d=new dlb.Obb(a.f);d.a<d.c.a.length;){c=dlb.Nbb(d);clb.lm(c,b);}};nlb.RE=function RE(a,b){a.e=b;};nlb.SE=function SE(a){var b,c,d,e,f,g,h,i,j,k,l,m,n,o;l=nlb.DE(a);k=gW(Ykb.Z0,Amb,6,l+1,16,1);for(c=0;c<a.g.a.length;c++){o=dlb.Bi(a.g,c);for(g=0;g<o.q;g++){i=$wnd.Math.abs(o.w[g]);if(i!=0){if(k[i])throw c1(new Zkb.rz('Duplicate mapping no in reactants'));k[i]=true;}}}j=gW(Ykb.Z0,Amb,6,l+1,16,1);for(d=0;d<a.f.a.length;d++){n=dlb.Bi(a.f,d);for(g=0;g<n.q;g++){i=$wnd.Math.abs(n.w[g]);if(i!=0){if(j[i])throw c1(new Zkb.rz('Duplicate mapping no in products'));j[i]=true;}}}m=gW(Ykb.AX,gmb,6,l+1,15,1);h=0;for(e=1;e<=l;e++)k[e]&&j[e]&&(m[e]=++h);if(h!=l){for(f=0;f<a.g.a.length;f++){o=dlb.Bi(a.g,f);for(g=0;g<o.q;g++)clb.Ql(o,g,m[$wnd.Math.abs(o.w[g])],o.w[g]<0);}for(b=0;b<a.f.a.length;b++){n=dlb.Bi(a.f,b);for(g=0;g<n.q;g++)clb.Ql(n,g,m[$wnd.Math.abs(n.w[g])],n.w[g]<0);}}};nlb.TE=function TE(){this.g=new dlb.Qi();this.f=new dlb.Qi();this.a=new dlb.Qi();this.d=-1;this.c=false;};nlb.UE=function UE(a){var b,c,d,e,f,g;nlb.TE.call(this);g=!a?0:!a.g?0:a.g.a.length;f=!a?0:!a.f?0:a.f.a.length;b=!a?0:!a.a?0:a.a.a.length;for(d=0;d<g;d++)dlb.wi(this.g,new clb.$t(dlb.Bi(a.g,d)));for(e=0;e<f;e++)dlb.wi(this.f,new clb.$t(dlb.Bi(a.f,e)));for(c=0;c<b;c++)dlb.wi(this.a,new clb.$t(dlb.Bi(a.a,c)));this.b=new clb.jj(a.b);a.e!=null&&(this.e=a.e);this.c=a.c||nlb.AE(a);};nlb.VE=function VE(a,b){var c,d;nlb.TE.call(this);for(d=0;d<b;d++)dlb.wi(this.g,a[d]);for(c=b;c<a.length;c++)dlb.wi(this.f,a[c]);this.c=nlb.AE(this);};U1(59,1,fmb,nlb.TE,nlb.UE,nlb.VE);_.c=false;_.d=0;Ykb.LZ=w3(59);nlb.WE=function WE(){this.e=gW(Ykb.QZ,Ulb,50,2,0,1);this.e[0]=new plb.OF();this.e[1]=new plb.OF();};nlb.XE=function XE(b){var c,d,e,f;nlb.WE.call(this);c=0;while(c!=-1){d=alb.Pgb(b).indexOf('="',c);if(d==-1)break;e=(alb.Jgb(c+1,d,alb.Pgb(b).length),alb.Pgb(b).substr(c+1,d-(c+1)));c=alb.Pgb(b).indexOf('"',d+2);f=c==-1?(alb.Kgb(d+1,alb.Pgb(b).length+1),alb.Pgb(b).substr(d+1)):(alb.Jgb(d+1,c,alb.Pgb(b).length),alb.Pgb(b).substr(d+1,c-(d+1)));if(Zkb.c5(e,'x1'))try{this.e[0].a=a4(f);}catch(a){a=b1(a);if(!mX(a,35))throw c1(a);}else if(Zkb.c5(e,'y1'))try{this.e[0].b=a4(f);}catch(a){a=b1(a);if(!mX(a,35))throw c1(a);}else if(Zkb.c5(e,'x2'))try{this.e[1].a=a4(f);}catch(a){a=b1(a);if(!mX(a,35))throw c1(a);}else if(Zkb.c5(e,'y2'))try{this.e[1].b=a4(f);}catch(a){a=b1(a);if(!mX(a,35))throw c1(a);}}};U1(155,154,{154:1},nlb.WE,nlb.XE);_.mb=function YE(){var a;a=new nlb.WE();a.e[0].a=this.e[0].a;a.e[0].b=this.e[0].b;a.e[1].a=this.e[1].a;a.e[1].b=this.e[1].b;a.d=this.d;return a;};_.nb=function ZE(){var a;a=new Zkb.J5();Zkb.G5(a,' x1="'+this.e[0].a+'"');Zkb.G5(a,' y1="'+this.e[0].b+'"');Zkb.G5(a,' x2="'+this.e[1].a+'"');Zkb.G5(a,' y2="'+this.e[1].b+'"');return a.a;};_.ob=function $E(){return 'arrow';};Ykb.KZ=w3(155);nlb._E=function _E(a,b,c,d,e,f){var g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v;if(a==null||alb.Pgb(a).length==0){return null;}n=false;k=0;s=0;h=0;v=Zkb.g5(a,s5(33));if(v==-1){return null;}!f?f=new nlb.TE():nlb.zE(f);while(k!=-1){k>v&&(n=true);i=Zkb.h5(a,s5(32),k);!n&&(i>v||i==-1)&&(i=v);j=null;if(i==-1){j=(alb.Kgb(k,alb.Pgb(a).length+1),alb.Pgb(a).substr(k));k=-1;}else {j=(alb.Jgb(k,i,alb.Pgb(a).length),alb.Pgb(a).substr(k,i-k));k=i+1;}r=null;if(b!=null&&alb.Pgb(b).length!=0){i=Zkb.h5(b,s5(32),s);if(i==-1){r=(alb.Kgb(s,alb.Pgb(b).length+1),alb.Pgb(b).substr(s));}else {r=(alb.Jgb(s,i,alb.Pgb(b).length),alb.Pgb(b).substr(s,i-s));s=i+1;}}g=null;if(c!=null&&alb.Pgb(c).length!=0){i=Zkb.h5(c,s5(32),h);if(i==-1){g=(alb.Kgb(h,alb.Pgb(c).length+1),alb.Pgb(c).substr(h));}else {g=(alb.Jgb(h,i,alb.Pgb(c).length),alb.Pgb(c).substr(h,i-h));h=i+1;}}u=new clb.mp(true);t=j==null?null:clb.dp(u,alb.qgb((p=j,alb.lgb(),p)),g==null?null:alb.qgb((q=g,q)));r!=null&&clb.hp(u,alb.qgb((o=r,alb.lgb(),o)));n?(dlb.wi(f.f,t),f.d=-1):(dlb.wi(f.g,t),f.d=-1);}d!=null&&alb.Pgb(d).length!=0&&nlb.PE(f,new clb.kj(d));if(e!=null&&alb.Pgb(e).length!=0){u=new clb.mp(true);l=0;m=Zkb.g5(e,s5(43));while(m!=-1){nlb.tE(f,clb.bp(u,(alb.Jgb(l,m,alb.Pgb(e).length),alb.Pgb(e).substr(l,m-l))));l=m+1;m=Zkb.h5(e,s5(43),l);}nlb.tE(f,clb.bp(u,(alb.Kgb(l,alb.Pgb(e).length+1),alb.Pgb(e).substr(l))));}return f;};nlb.aF=function aF(a,b){var c,d,e,f,g,h,i,j,k;if(a==null)return null;h=a;j=null;i=null;k=null;g=null;c=Zkb.g5(a,s5(35));if(c==-1){h=a;}else {h=(alb.Jgb(0,c,alb.Pgb(a).length),alb.Pgb(a).substr(0,c));d=Zkb.h5(a,s5(35),c+1);if(d==-1){j=(alb.Kgb(c+1,alb.Pgb(a).length+1),alb.Pgb(a).substr(c+1));}else {j=(alb.Jgb(c+1,d,alb.Pgb(a).length),alb.Pgb(a).substr(c+1,d-(c+1)));e=Zkb.h5(a,s5(35),d+1);if(e==-1){i=(alb.Kgb(d+1,alb.Pgb(a).length+1),alb.Pgb(a).substr(d+1));}else {i=(alb.Jgb(d+1,e,alb.Pgb(a).length),alb.Pgb(a).substr(d+1,e-(d+1)));f=Zkb.h5(a,s5(35),e+1);if(f==-1){k=(alb.Kgb(e+1,alb.Pgb(a).length+1),alb.Pgb(a).substr(e+1));}else {k=(alb.Jgb(e+1,f,alb.Pgb(a).length),alb.Pgb(a).substr(e+1,f-(e+1)));g=(alb.Kgb(f+1,alb.Pgb(a).length+1),alb.Pgb(a).substr(f+1));}}}}return nlb._E(h,j,i,k,g,b);};nlb.bF=function bF(a,b,c){var d,e;e=nlb.cF(a,b,(c&16)==0);if(e==null){return null;}d=new Zkb.B5(e[0]);if(c!=0){d.a+='#';(c&1)!=0&&e.length>1&&e[1]!=null&&Zkb.y5(d,e[1]);}c&=-2;if(c!=0){d.a+='#';(c&2)!=0&&e.length>2&&e[2]!=null&&Zkb.y5(d,e[2]);}c&=-3;if(c!=0){d.a+='#';(c&4)!=0&&e.length>3&&e[3]!=null&&Zkb.y5(d,e[3]);}c&=-5;if(c!=0){d.a+='#';(c&8)!=0&&e.length>4&&e[4]!=null&&Zkb.y5(d,e[4]);}return d.a;};nlb.cF=function cF(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s;if(!a||a.g.a.length==0||a.f.a.length==0){return null;}k=gW(Ykb.l_,Xlb,2,a.g.a.length+a.f.a.length,6,1);o=gW(Ykb.l_,Xlb,2,a.g.a.length+a.f.a.length,6,1);f=gW(Ykb.l_,Xlb,2,a.g.a.length+a.f.a.length,6,1);for(i=0;i<a.g.a.length+a.f.a.length;i++){r=i<a.g.a.length?dlb.Bi(a.g,i):dlb.Bi(a.f,i-a.g.a.length);if(r.K&&i<a.g.a.length)for(d=0;d<r.q;d++)clb.Ul(r,d,Jnb,false);e=new clb.ag(r);k[i]=clb.Gf(e);if(k[i]==null){return null;}o[i]=clb.Ff(e);f[i]=clb.Ef(e,b);}l=new Zkb.J5();g=new Zkb.J5();p=new Zkb.J5();for(j=0;j<a.g.a.length;j++){m=j;if(c){q='';m=-1;for(n=0;n<a.g.a.length;n++){if(Zkb.Z4(q,k[n])<0){q=k[n];m=n;}}}if(j>0){l.a+=' ';p.a+=' ';g.a+=' ';}Zkb.G5(l,k[m]);Zkb.G5(p,o[m]);Zkb.G5(g,f[m]);k[m]='';}l.a+='!';p.a+=' ';g.a+=' ';for(h=a.g.a.length;h<a.g.a.length+a.f.a.length;h++){m=h;if(c){q='';m=-1;for(n=a.g.a.length;n<a.g.a.length+a.f.a.length;n++){if(Zkb.Z4(q,k[n])<0){q=k[n];m=n;}}}if(h>a.g.a.length){l.a+=' ';p.a+=' ';g.a+=' ';}Zkb.G5(l,k[m]);Zkb.G5(p,o[m]);Zkb.G5(g,f[m]);k[m]='';}s=gW(Ykb.l_,Xlb,2,5,6,1);s[0]=l.a;alb.Pgb(p.a).length>a.g.a.length+a.f.a.length-1&&(s[1]=p.a);alb.Pgb(g.a).length>a.g.a.length+a.f.a.length-1&&(s[2]=g.a);!!a.b&&(s[3]=clb.ij(a.b));a.a.a.length!=0&&(s[4]=nlb.dF(a,b));return s;};nlb.dF=function dF(a,b){var c,d,e;e=new Zkb.J5();for(d=0;d<a.a.a.length;d++){alb.Pgb(e.a).length!=0&&(e.a+='+',e);c=new clb.ag(dlb.Bi(a.a,d));Zkb.G5(e,clb.Gf(c));if(b){e.a+=' ';Zkb.G5(e,clb.Ef(c,true));}}return e.a;};nlb.eF=function eF(a,b,c,d,e){var f,g,h,i;if((b.u[c]&3)!=0&&(b.u[c]&4)==0&&o1(e1(b.B[c],Jnb),0)){h=$wnd.Math.abs(b.w[c]);if(h!=0){for(g=0;g<a.c.g.a.length;g++){f=nlb.JE(a.c,g);for(i=0;i<f.f;i++){if($wnd.Math.abs(f.w[i])==h){if(b.j[c]==d.j[e])return true;if(z1(e1(f.B[i],knb),0))return true;if((f.u[i]&rnb)>>18!=(b.u[c]&rnb)>>18)return true;return false;}}}}}return false;};nlb.fF=function fF(a,b,c,d){var e,f,g,h,i,j,k,l,m,n;m=gW(Ykb.AX,gmb,6,a.f,15,1);n=nlb.hF(a,b,m);g=false;f=false;l=new dlb.Qi();for(e=0;e<n;e++){if(clb.Zk(a,m[e])){j=clb.Vt(a,m[e],d);if(j==1||j==2){h=clb.ok(c,d[m[e]]);(h==1||h==2)&&(j==h?g=true:f=true);}i=gW(Ykb.AX,gmb,6,2,15,1);i[0]=m[e];i[1]=j;alb.ggb(l.a,i);}}if(!g||!f){for(k=new dlb.Obb(l);k.a<k.c.a.length;){j=dlb.Nbb(k);i=j[1];(i==1||i==2)&&f&&(i=i==1?2:1);clb.Tl(c,d[j[0]],i,true);}}};nlb.gF=function gF(a){var b,c,d,e,f,g,h,i,j,k,l;if(a.n!=null)return;if(a.b){d=a.j+1;a.p=gW(Ykb.AX,Llb,26,a.o.length,0,3);for(f=0;f<a.o.length;f++){a.p[f]=gW(Ykb.AX,Dnb,7,a.g[f].a.length,0,2);for(h=0;h<a.g[f].a.length;h++)a.p[f][h]=nlb.lF(a,f,dlb.Bi(a.g[f],h),d);d+=a.o[f].f;e=nlb.JE(a.c,f);for(b=0;b<e.f;b++)o1(e1(e.B[b],Bmb),0)&&--d;}}a.n=eW(Ykb.uY,[Llb,Bob],[104,25],0,[a.q,a.c.f.a.length],2);a.d=eW(Ykb.l_,[Llb,Xlb],[29,2],6,[a.q,a.c.f.a.length],2);a.e=gW(Ykb.Z0,Amb,6,a.q,16,1);l=new clb.Dt();k=new Zkb.J5();g=0;c=0;if(a.q!=0){i=gW(Ykb.AX,gmb,6,a.o.length,15,1);do{j=alb.Pgb(k.a).length;0<j?k.a=Zkb.p5(k.a,0,0):0>j&&(k.a+=Zkb.u5(gW(Ykb.xX,Anb,6,-j,15,1)));for(f=0;f<a.c.f.a.length;f++){kW(a.n[g],f,nlb.iF(a,a.g,i,f));a.d[g][f]=clb.Gf(new clb.ag(a.n[g][f]));Zkb.G5(k,a.d[g][f]);}a.e[g]=clb.Bt(l,k.a)==-1;(!a.t||!a.e[g])&&++c;++g;}while(nlb.oF(a,i)&&c<a.i);}};nlb.hF=function hF(a,b,c){var d,e,f,g,h,i;h=gW(Ykb.Z0,Amb,6,a.f,16,1);c[0]=b;i=1;h[b]=true;for(f=0;f<i;f++){for(g=0;g<clb.wn(a,c[f]);g++){e=clb.xn(a,c[f],g);if((a.F[e]&64)!=0||clb.Hk(a,e)==2||clb.no(a,e)){d=clb.vn(a,c[f],g);if(!h[d]){c[i++]=d;h[d]=true;}}}}return i;};nlb.iF=function iF(a,b,c,d){var e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z,$,ab,bb,cb,db,eb,fb,gb,hb,ib,jb,kb,lb,mb,nb,ob,pb,qb,rb,sb;B=nlb.IE(a.c,d);hb=new clb.Yt();p=0;q=0;rb=null;for(N=0;N<a.o.length;N++){C=nlb.JE(a.c,N);clb.Gt(a.o[N],1);bb=dlb.Bi(b[N],c[N]);ab=gW(Ykb.AX,gmb,6,a.o[N].f,15,1);t=gW(Ykb.Z0,Amb,6,a.o[N].f,16,1);u=gW(Ykb.Z0,Amb,6,a.o[N].g,16,1);for(S=0;S<C.f;S++){if(bb[S]!=-1){if($wnd.Math.abs(C.w[S])==0){v=bb[S];t[v]=true;for(Y=0;Y<clb.wn(a.o[N],v);Y++)u[clb.xn(a.o[N],v,Y)]=true;}else {ab[bb[S]]=$wnd.Math.abs(C.w[S]);}}}for(T=0;T<C.g;T++){l=C.D[0][T];m=C.D[1][T];if($wnd.Math.abs(C.w[l])!=0&&$wnd.Math.abs(C.w[m])!=0){h=bb[l];i=bb[m];if(h!=-1&&i!=-1){for(Y=0;Y<a.o[N].g;Y++){if(clb.zk(a.o[N],0,Y)==h&&clb.zk(a.o[N],1,Y)==i||clb.zk(a.o[N],0,Y)==i&&clb.zk(a.o[N],1,Y)==h){u[Y]=true;break;}}}}}eb=gW(Ykb.AX,gmb,6,a.o[N].f,15,1);for(U=0;U<a.o[N].f;U++){if(!t[U]){eb[U]=clb.Pj(a.o[N],hb,U,p,q);a.b&&clb.Ql(hb,eb[U],a.p[N][c[N]][U],false);if(ab[U]!=0){clb.Ql(hb,eb[U],ab[U],false);for(Y=0;Y<B.f;Y++){if($wnd.Math.abs(B.w[Y])==ab[U]){clb.Il(hb,eb[U],B.s[Y]);clb.Vl(hb,eb[U],B.u[Y]&48);if(a.f[d][Y]){gb=clb.ok(a.o[N],U);jb=e1(B.B[Y],Jnb);if(j1(jb,0)==0){clb.Tl(hb,eb[U],3,false);}else if(j1(jb,Jnb)==0){!rb&&(rb=new dlb.Qi());dlb.wi(rb,Zkb.t4(eb[U]));}else {if(gb==1||gb==2){Q=j1(jb,Gsb)==0;for(Z=0;Z<clb.wn(a.o[N],U);Z++){n=clb.vn(a.o[N],U,Z);if(t[n]){for($=0;$<clb.wn(a.o[N],U);$++){fb=clb.vn(a.o[N],U,$);!t[fb]&&fb>n&&(Q=!Q);}}}Q&&(gb=gb==1?2:1);clb.Tl(hb,eb[U],gb,false);}else {clb.Tl(hb,eb[U],0,false);}}}break;}}}}}for(V=0;V<a.o[N].g;V++)u[V]||clb.Rj(a.o[N],hb,V,p,q,eb,true);p=clb.Cl(hb,1);q=clb.Cl(hb,2);}db=gW(Ykb.AX,gmb,6,B.f,15,1);for(W=0;W<B.f;W++){ab=$wnd.Math.abs(B.w[W]);if(ab==0){db[W]=clb.Pj(B,hb,W,p,q);}else {for(Y=0;Y<hb.q;Y++){if($wnd.Math.abs(hb.w[Y])==ab){db[W]=Y;break;}}}}if(a.r){for(S=0;S<B.f;S++){clb.Rl(hb,db[S],true);clb.Yl(hb,db[S],B.J[S].a);clb.Zl(hb,db[S],B.J[S].b);}}for(D=0;D<B.g;D++){if((B.G[D]&nnb)!=0)continue;ib=clb.Qj(B,hb,D,p,q,db[B.D[0][D]],db[B.D[1][D]],false);kb=B.G[D]&31;if(kb!=0){A=false;clb.im(hb,ib,31,false);F=clb.mk(B,B.D[0][D]);G=clb.mk(B,B.D[1][D]);for(O=0;!A&&O<a.c.g.a.length;O++){C=nlb.JE(a.c,O);for(J=0;!A&&J<C.g;J++){H=C.D[0][J];I=C.D[1][J];K=$wnd.Math.abs(C.w[H]);L=$wnd.Math.abs(C.w[I]);if(K!=0&&L!=0&&(K==F&&L==G||K==G&&L==F)){A=true;sb=C.G[J]&31;if(sb!=0){bb=dlb.Bi(b[O],c[O]);mb=bb[H];nb=bb[I];ob=clb.tn(a.o[O],mb,nb);qb=clb.Kk(a.o[O],ob);pb=clb.Hk(a.o[O],ob);sb&=7;kb&=7;sb==3&&kb==6?(hb.H[ib]=pb<=1?2:4,hb.T=0):sb==6&&kb==3?(hb.H[ib]=pb==3?2:1,hb.T=0):(hb.H[ib]=qb,hb.T=0);}}}}}}clb.Gt(hb,1);r=false;for(X=0;X<B.f;X++){if($wnd.Math.abs(B.w[X])==0){gb=clb.Vt(B,X,db);clb.Tl(hb,db[X],gb,false);}else if(a.f[d][X]&&nlb.eF(a,B,X,hb,db[X])){gb=clb.Vt(B,X,db);clb.Tl(hb,db[X],gb,false);if(gb==1||gb==2){s=(B.u[X]&rnb)>>18;o=(B.u[X]&rnb)>>18!=1&&(B.u[X]&rnb)>>18!=2?-1:(B.u[X]&Snb)>>20;s==1?o+=p:s==2&&(o+=q);clb.Nl(hb,db[X],s,o);r=true;}}}if(r){p=clb.Cl(hb,1);q=clb.Cl(hb,2);}lb=gW(Ykb.Z0,Amb,6,B.q,16,1);for(R=0;R<B.f;R++)a.f[d][R]&&!lb[R]&&(B.u[R]&4)!=0&&o1(e1(B.B[R],Jnb),0)&&B.j[R]==clb.wn(hb,db[R])&&nlb.fF(B,R,hb,db);P=gW(Ykb.Z0,Amb,6,hb.q,16,1);for(M=0;M<db.length;M++)P[db[M]]=true;w=true;while(w){w=false;for(k=0;k<hb.r;k++){h=hb.D[0][k];i=hb.D[1][k];if(P[h]&&!P[i]){P[i]=true;w=true;}else if(P[i]&&!P[h]){P[h]=true;w=true;}}}for(g=0;g<hb.q;g++)clb.Wl(hb,g,!P[g]);clb.$j(hb);if(!a.b)for(j=0;j<hb.q;j++)hb.w[j]=0;clb.ce(new clb.me(hb),null,false);hb.T|=8;cb=2|(a.r?8:0);glb.yx(new glb.Rx(cb),hb);if(rb){clb.Gt(hb,15);for(f=new dlb.Obb(rb);f.a<f.c.a.length;){e=dlb.Nbb(f).a;if((hb.u[e]&Xnb)!=0){clb.Tl(hb,e,1,false);clb.Nl(hb,e,1,p++);}}}return hb;};nlb.jF=function jF(a){var b,c;b=a.q;if(a.t)for(c=0;c<a.q;c++)a.e[c]&&--b;a.i>0&&b>a.i&&(b=a.i);return b;};nlb.kF=function kF(a){var b,c,d;nlb.gF(a);d=gW(Ykb.uY,Llb,104,nlb.jF(a),0,2);b=0;for(c=0;c<a.q&&b<a.i;c++)(!a.t||!a.e[c])&&(d[b++]=a.n[c]);return d;};nlb.lF=function lF(a,b,c,d){var e,f,g,h,i;i=gW(Ykb.AX,gmb,6,a.o[b].f,15,1);for(h=0;h<i.length;h++)i[h]=-1;f=nlb.JE(a.c,b);for(e=0;e<f.f;e++)c[e]!=-1&&(i[c[e]]=$wnd.Math.abs(f.w[e]));for(g=0;g<i.length;g++)i[g]==-1&&(i[g]=d++);return i;};nlb.mF=function mF(a,b){var c,d,e,f;c=gW(Ykb.AX,gmb,6,a.j[b]-clb.zn(a,b),15,1);f=0;for(e=0;e<a.j[b];e++){d=a.i[b][e];o1(e1(a.B[d],Bmb),0)&&(c[f++]=a.C[d]);}alb.jgb(c,alb.Pgb(X1(dlb.ucb.prototype.kc,dlb.ucb,[])));return c;};nlb.nF=function nF(a,b){var c,d,e,f;f=gW(Ykb.AX,gmb,6,a.j[b]-clb.zn(a,b),15,1);e=0;for(d=0;d<a.j[b];d++){c=a.i[b][d];o1(e1(a.B[c],Bmb),0)&&(f[e++]=$wnd.Math.abs(a.w[c]));}alb.jgb(f,alb.Pgb(X1(dlb.ucb.prototype.kc,dlb.ucb,[])));return f;};nlb.oF=function oF(a,b){var c;for(c=0;c<b.length;c++){if(b[c]<a.g[c].a.length-1){++b[c];return true;}b[c]=0;}return false;};nlb.pF=function pF(a,b){var c,d,e,f,g,h,i,j,k,l;a.j=0;for(e=0;e<b.g.a.length+b.f.a.length;e++){i=nlb.FE(a.c,e);for(c=0;c<i.f;c++){z1(e1(i.B[c],Bmb),0)?i.w[c]=0:a.j<$wnd.Math.abs(i.w[c])&&(a.j=$wnd.Math.abs(i.w[c]));}}l=gW(Ykb.Z0,Amb,6,a.j+1,16,1);for(f=0;f<b.g.a.length;f++){k=dlb.Bi(b.g,f);for(c=0;c<k.f;c++){h=$wnd.Math.abs(k.w[c]);h!=0&&(l[h]=true);}}for(g=0;g<b.f.a.length;g++){j=dlb.Bi(b.f,g);for(c=0;c<j.f;c++){h=$wnd.Math.abs(j.w[c]);h!=0&&(l[h]?l[h]=false:j.w[c]=0);}}for(d=0;d<b.g.a.length;d++){k=dlb.Bi(b.g,d);for(c=0;c<k.f;c++){h=$wnd.Math.abs(k.w[c]);h!=0&&l[h]&&(k.w[c]=0);}}};nlb.qF=function qF(a,b,c){var d,e,f,g,h,i,j,k;a.o[b]=c;a.n=null;e=nlb.JE(a.c,b);clb.cs(a.s,e,a.o[b]);i=8+(a.a?0:1);if(clb.Rr(a.s,5,i)==0){a.g[b]=new dlb.Qi();a.q=0;return false;}a.g[b]=a.s.D;for(g=a.g[b].a.length-1;g>=0;g--){j=dlb.Bi(a.g[b],g);for(h=0;h<j.length;h++){if(j[h]!=-1){d=0;if(a.a&&e.s[h]==0&&clb.dk(a.o[b],j[h])!=0){k=clb.Qk(a.o[b],j[h]);d=clb.Ok(a.o[b],j[h],k);}if(a.k[b][h]>0&&a.k[b][h]>clb.Gn(a.o[b],j[h])-d){dlb.Ii(a.g[b],g);break;}}}}a.q=1;for(f=0;f<a.o.length;f++)a.q*=!a.g[f]?0:a.g[f].a.length;return true;};nlb.rF=function rF(a){var b,c,d,e,f,g,h,i,j,k,l,m,n;this.r=true;this.b=false;this.t=true;this.a=false;this.i=Qlb;this.c=a;this.o=gW(Ykb.uY,Bob,25,a.g.a.length,0,1);for(d=0;d<a.g.a.length;d++){clb.lm(dlb.Bi(a.g,d),true);clb.Gt(dlb.Bi(a.g,d),15);}for(e=0;e<a.f.a.length;e++)clb.Gt(dlb.Bi(a.f,e),15);nlb.pF(this,a);this.k=gW(Ykb.AX,Dnb,7,a.g.a.length,0,2);for(f=0;f<a.g.a.length;f++){l=dlb.Bi(a.g,f);this.k[f]=gW(Ykb.AX,gmb,6,l.f,15,1);for(g=0;g<l.f;g++){j=$wnd.Math.abs(l.w[g]);if(j!=0){for(h=0;h<a.f.a.length;h++){k=dlb.Bi(a.f,h);for(i=0;i<k.f;i++){if($wnd.Math.abs(k.w[i])==j){b=(n=clb.Qk(l,g),n+clb.Ok(l,g,n)-clb.Pn(l,g)-(m=clb.Qk(k,i),m+clb.Ok(k,i,m)-clb.Pn(k,i)));this.k[f][g]=b>0?b:0;}}}}}}this.f=gW(Ykb.Z0,Llb,11,a.f.a.length,0,2);for(c=0;c<a.f.a.length;c++){k=dlb.Bi(a.f,c);this.f[c]=gW(Ykb.Z0,Amb,6,k.f,16,1);for(g=0;g<k.f;g++){j=$wnd.Math.abs(k.w[g]);if(j!=0){for(h=0;h<a.g.a.length;h++){l=dlb.Bi(a.g,h);for(i=0;i<l.f;i++){$wnd.Math.abs(l.w[i])==j&&(slb.MT(nlb.nF(k,g),nlb.nF(l,i))!=0||slb.MT(nlb.mF(k,g),nlb.mF(l,i))!=0)&&(this.f[c][g]=true);}}}}}this.s=new clb.js();this.g=gW(Ykb.S_,Llb,18,this.o.length,0,1);};nlb.sF=function sF(a){nlb.rF.call(this,a);};U1(167,1,{},nlb.sF);_.a=false;_.b=false;_.i=0;_.j=0;_.q=0;_.r=false;_.t=false;Ykb.MZ=w3(167);nlb.tF=function tF(a,b,c){var d,e,f;clb.Gt(b,1);e=dlb.Bi(a.a,c);for(d=0;d<a.d.d.a.length;d++){f=slb.TT(a.d,d);nlb.wF(f,b,e);}clb.Zj(b);};nlb.uF=function uF(a,b){var c,d,e;a.f=b;clb.cs(a.e,a.c,a.f);if(clb.Rr(a.e,4,8)==0){a.a=null;return 0;}a.a=a.e.D;for(c=a.a.a.length-1;c>=0;c--){e=dlb.Bi(a.a,c);for(d=0;d<e.length;d++){if(e[d]!=-1){if(a.b[d]>0&&a.b[d]>clb.Gn(a.f,e[d])){dlb.Ii(a.a,c);break;}}}}return a.a.a.length;};nlb.vF=function vF(a,b){var c,d,e,f,g,h,i,j,k,l,m;clb.Gt(a,7);clb.Gt(b,7);this.c=a;this.d=new slb.WT();for(d=0;d<a.g;d++)slb.RT(this.d,new nlb.zF(a,d));for(c=0;c<b.g;c++){k=new nlb.zF(b,c);i=(h=slb.UT(this.d,k),h<0?-1:h);if(i==-1){k.i=(nlb.IF(),nlb.EF);slb.RT(this.d,k);}else {nlb.yF(slb.TT(this.d,i),k);}}for(g=this.d.d.a.length-1;g>=0;g--){k=slb.TT(this.d,g);k.i!=(nlb.IF(),nlb.HF)?slb.TT(this.d,g).i==nlb.FF&&slb.VT(this.d,g):k.i=nlb.GF;}this.b=gW(Ykb.AX,gmb,6,a.f,15,1);for(f=0;f<a.f;f++){for(j=0;j<b.f;j++){if($wnd.Math.abs(b.w[j])==$wnd.Math.abs(a.w[f])){e=(m=clb.Qk(a,f),m+clb.Ok(a,f,m)-clb.Pn(a,f)-(l=clb.Qk(b,j),l+clb.Ok(b,j,l)-clb.Pn(b,j)));this.b[f]=e>0?e:0;break;}}}this.e=new clb.js();};U1(229,1,{},nlb.vF);Ykb.PZ=w3(229);nlb.wF=function wF(a,b,c){var d,e,f,g;d=c[a.a];e=c[a.b];if(a.i==(nlb.IF(),nlb.EF)){clb.Aj(b,d,e,a.g);return true;}else {f=clb.tn(b,d,e);if(a.i==nlb.CF){clb.jm(b,f,a.g);return true;}else if(a.i==nlb.DF){g=clb.Hk(b,f)+a.f;if(g>=0&&g<=3){clb.jm(b,f,(clb.wj(),g==0?32:g==1?1:g==2?386:g==3?4:g==4?8:16));return true;}}else if(a.i==nlb.GF){b.H[f]=512;return true;}}return false;};nlb.xF=function xF(a,b){if(a.d!=b.d)return a.d<b.d?-1:1;if(a.e!=b.e)return a.e<b.e?-1:1;return 0;};nlb.yF=function yF(a,b){var c,d;if(a.c==b.c){a.i=(nlb.IF(),nlb.FF);}else if(i4(b.c)==1){a.g=b.c==1?1:b.c==2?386:b.c==4?4:b.c==16?32:64;a.i=(nlb.IF(),nlb.CF);}else {c=(a.c&16)!=0?0:(a.c&1)!=0?1:(a.c&2)!=0?2:3;d=(b.c&16)!=0?0:(b.c&1)!=0?1:(b.c&2)!=0?2:3;if(d==c)a.i=(nlb.IF(),nlb.FF);else {a.f=d-c;a.i=(nlb.IF(),nlb.DF);}}};nlb.zF=function zF(a,b){var c,d,e;this.a=a.D[0][b];this.b=a.D[1][b];d=clb.mk(a,this.a);e=clb.mk(a,this.b);if(d<e){this.d=d;this.e=e;}else {this.d=e;this.e=d;}this.c=a.G[b]&31;c=a.H[b]&127;c==32?this.c|=16:c==2?this.c|=2:c==4?this.c|=4:this.c|=1;this.i=(nlb.IF(),nlb.HF);};U1(136,1,{136:1,27:1},nlb.zF);_.qb=function AF(a){return nlb.xF(this,a);};_.ib=function BF(a){return this.d==a.d&&this.e==a.e;};_.a=0;_.b=0;_.c=0;_.d=0;_.e=0;_.f=0;_.g=0;Ykb.OZ=w3(136);nlb.IF=function IF(){nlb.IF=W1;nlb.EF=new nlb.JF('CREATE',0);nlb.DF=new nlb.JF('CHANGE_DIF',1);nlb.CF=new nlb.JF('CHANGE_ABS',2);nlb.GF=new nlb.JF('REMOVE',3);nlb.FF=new nlb.JF('NO_CHANGE',4);nlb.HF=new nlb.JF('UNKNOWN',5);};nlb.JF=function JF(a,b){_z.call(this,a,b);};nlb.KF=function KF(){nlb.IF();return oW(aW(Ykb.NZ,1),Bqb,70,0,[nlb.EF,nlb.DF,nlb.CF,nlb.GF,nlb.FF,nlb.HF]);};U1(70,52,{70:1,4:1,27:1,52:1},nlb.JF);Ykb.NZ=x3(70,nlb.KF);olb.NF=function NF(){olb.NF=W1;olb.LF=oW(aW(Ykb.l_,1),Xlb,2,6,['','r0','r','r3','r3-4','r3-5','r3-6','r3-7','r4','r4-5','r4-6','r4-7','r>3','r5','r5-6','r5-7','r>4','r6','r6-7','r>5','r7','r>6','r>7']);olb.MF=oW(aW(Ykb.BX,1),Anb,6,14,[0,lmb,gob,mmb,25769803776,60129542144,128849018880,266287972352,nmb,51539607552,120259084288,257698037760,532575944704,omb,103079215104,240518168576,515396075520,pmb,206158430208,481036337152,qmb,412316860416,rmb]);};plb.OF=function OF(){};plb.PF=function PF(a,b){this.a=a;this.b=b;};U1(50,1,{50:1},plb.OF,plb.PF);_.lb=function QF(){return 'x:'+this.a+' y:'+this.b;};_.a=0;_.b=0;Ykb.QZ=w3(50);plb.RF=function RF(a,b,c){if(a.a==a.b.length){a.b=dlb.Tbb(a.b,2*a.a);a.c=dlb.Tbb(a.c,2*a.a);}a.b[a.a]=b;a.c[a.a]=c;++a.a;};plb.SF=function SF(a){this.b=gW(Ykb.yX,emb,6,a,15,1);this.c=gW(Ykb.yX,emb,6,a,15,1);this.a=0;};U1(204,1,{302:1},plb.SF);_.a=0;Ykb.RZ=w3(204);plb.TF=function TF(a,b,c){return b>=a.c&&b<=a.c+a.b&&c>=a.d&&c<=a.d+a.a;};plb.UF=function UF(a,b){return plb.TF(a,b.c,b.d)&&plb.TF(a,b.c+b.b,b.d+b.a);};plb.VF=function VF(a,b,c,d,e){a.c=b;a.d=c;a.b=d;a.a=e;};plb.WF=function WF(a,b){var c,d,e,f;e=$wnd.Math.min(a.c,b.c);f=$wnd.Math.min(a.d,b.d);d=$wnd.Math.max(a.c+a.b,b.c+b.b)-e;c=$wnd.Math.max(a.d+a.a,b.d+b.a)-f;return new plb.YF(e,f,d,c);};plb.XF=function XF(){};plb.YF=function YF(a,b,c,d){this.c=a;this.d=b;this.b=c;this.a=d;};U1(46,1,{46:1,302:1},plb.XF,plb.YF);_.lb=function ZF(){return 'x:'+this.c+' y:'+this.d+' w:'+this.b+' h:'+this.a;};_.a=0;_.b=0;_.c=0;_.d=0;Ykb.SZ=w3(46);qlb.dG=function dG(){};qlb.eG=function eG(a,b){switch(b){default:case 0:return clb.gh(a.a,0);case 1:return clb.gh(a.a,1);case 2:return clb.gh(a.a,2);case 3:return clb.gh(a.a,3);case 4:return clb.gh(a.a,4);}};U1(301,1,{},qlb.dG);qlb.$F=2;qlb._F=0;qlb.aG=1;qlb.bG=4;qlb.cG=3;Ykb.TZ=w3(301);qlb.jG=function jG(a){this.a=new Flb.xhb(Ykb.m1(a));};U1(303,1,{},qlb.jG);_.getConformerCount=function kG(){return this.a.p;};_.getNextConformerAsMolecule=function lG(a){var b,c;b=!a?null:a.a;c=Flb.lhb(this.a,b);if(!c)return null;if(c==b)return a;return new rlb.fM(c);};_.getOCL=function mG(){return $wnd.OCL;};_.getOneConformerAsMolecule=function nG(a){var b;b=Flb.nhb(this.a,a.a);return !b?null:a;};_.getPotentialConformerCount=function oG(){return Flb.ohb(this.a);};_.Kb=function pG(a,b,c,d){return Flb.rhb(this.a,a.a,b,c,d);};_.initializeConformers=function qG(a,b){b===undefined&&(b={});var c=b.strategy;c===undefined&&(c=3);var d=b.maxTorsionSets;d===undefined&&(d=Mob);var e=b.use60degreeSteps;e===undefined&&(e=false);return this.Kb(a,c,d,e);};qlb.fG=4;qlb.gG=3;qlb.hG=1;qlb.iG=2;Ykb.UZ=w3(303);qlb.rG=function rG(){};qlb.sG=function sG(a,b,c,d,e){return mlb.uD(a,b,c,d,e);};U1(305,1,{},qlb.rG);Ykb.VZ=w3(305);qlb.vG=function vG(){qlb.vG=W1;qlb.uG=(!qlb.uH&&(qlb.uH=new qlb.xH()),qlb.uH);};qlb.wG=function wG(){qlb.vG();this.a=new mlb.AD();};U1(306,1,{},qlb.wG);_.assessDruglikeness=function xG(a){var b;return mlb.yD(this.a,(b=a.a,qlb.wH(qlb.uG),b));};_.getDetail=function yG(){return qlb.zH(this.a.a);};_.getDruglikenessString=function zG(a){return mlb.zD(a.a);};_.getOCL=function AG(){return $wnd.OCL;};qlb.tG=-999;Ykb.WZ=w3(306);qlb.HG=function HG(a,b,c){qlb.LG(b);this.a=new ilb.Pz(a.a,b,new dlb.Lcb());};qlb.LG=function LG(a){if(Zkb.c5(a,Hsb)&&!qlb.EG){ilb.Jz();ilb.Qz(Hsb,new ilb.HA('117\nint,int,int,int,float\n0,2,0,0,0.020\n1,2,1,2,0.030\n1,2,2,2,0.027\n1,2,2,3,0.026\n1,2,2,5,0.013\n1,2,2,37,0.032\n2,2,2,5,0.013\n2,2,3,5,0.012\n2,2,5,5,0.006\n2,2,5,6,0.027\n2,2,5,37,0.017\n2,2,5,40,0.012\n2,2,5,41,0.008\n0,3,0,0,0.130\n1,3,1,7,0.146\n1,3,2,7,0.138\n1,3,3,7,0.134\n1,3,5,7,0.122\n1,3,6,7,0.141\n1,3,7,10,0.129\n1,3,7,37,0.138\n2,3,5,7,0.113\n2,3,5,9,0.081\n2,3,6,7,0.127\n2,3,7,10,0.116\n3,3,5,7,0.113\n3,3,6,7,0.127\n5,3,5,7,0.103\n5,3,5,9,0.074\n5,3,5,54,0.078\n5,3,6,7,0.119\n5,3,7,10,0.102\n5,3,9,40,0.067\n6,3,7,37,0.127\n7,3,10,10,0.113\n7,3,20,20,0.151\n9,3,40,40,0.057\n0,8,0,0,0.000\n0,10,0,0,-0.020\n1,10,1,3,-0.02\n1,10,3,6,-0.033\n1,10,3,28,-0.02\n3,10,3,28,-0.030\n3,10,28,28,-0.019\n0,17,0,0,0.000\n0,26,0,0,0.000\n0,30,0,0,0.010\n5,30,20,30,0.008\n0,37,0,0,0.035\n1,37,37,37,0.040\n2,37,37,37,0.031\n3,37,37,37,0.027\n5,37,37,37,0.015\n5,37,37,38,0.046\n5,37,37,63,0.008\n5,37,37,64,0.012\n5,37,37,69,0.016\n5,37,38,38,0.084\n6,37,37,37,0.048\n15,37,37,37,0.025\n37,37,37,40,0.046\n0,39,0,0,0.020\n1,39,63,63,0.012\n23,39,63,63,-0.014\n23,39,63,65,0.021\n23,39,65,65,0.062\n0,40,0,0,-0.005\n1,40,28,37,-0.006\n2,40,28,28,-0.007\n3,40,28,28,-0.007\n28,40,28,37,0.004\n0,41,0,0,0.180\n1,41,32,32,0.178\n2,41,32,32,0.161\n5,41,32,32,0.158\n0,43,0,0,0.000\n0,45,0,0,0.150\n0,49,0,0,0.000\n50,49,50,50,0.000\n0,54,0,0,0.020\n1,54,3,36,0.016\n3,54,36,36,0.018\n0,55,0,0,0.020\n1,55,36,57,0.020\n36,55,36,57,0.020\n0,56,0,0,0.020\n1,56,36,57,0.020\n36,56,36,57,0.020\n0,57,0,0,0.080\n5,57,55,55,0.038\n56,57,56,56,0.158\n0,58,0,0,0.025\n0,63,0,0,0.050\n5,63,39,64,0.019\n5,63,39,66,0.068\n5,63,44,64,0.014\n5,63,44,66,0.055\n5,63,59,64,0.033\n5,63,59,66,0.085\n37,63,39,64,0.010\n0,64,0,0,0.040\n5,64,63,64,0.006\n5,64,63,66,0.043\n5,64,64,65,0.052\n5,64,65,66,0.094\n37,64,63,64,-0.011\n0,67,0,0,0.070\n0,69,0,0,0.070\n32,69,37,37,0.067\n0,73,0,0,0.000\n0,78,0,0,0.045\n5,78,78,81,0.046\n0,80,0,0,0.080\n5,80,81,81,0.057\n0,81,0,0,0.025\n36,81,78,80,0.016\n0,82,0,0,0.000\n','926\nint,int,int,int,int,float,float,float\n0,0,1,1,0,0.000,0.000,0.300\n5,0,1,1,0,0.200,-0.800,1.500\n0,1,1,1,1,0.103,0.681,0.332\n5,1,1,1,1,0.144,-0.547,1.126\n0,1,1,1,2,-0.295,0.438,0.584\n0,1,1,1,3,0.066,-0.156,0.143\n0,1,1,1,5,0.639,-0.630,0.264\n0,1,1,1,6,-0.688,1.757,0.477\n5,1,1,1,6,0.000,0.000,0.054\n0,1,1,1,8,-1.420,-0.092,1.101\n5,1,1,1,8,0.000,-0.158,0.323\n0,1,1,1,11,0.593,0.662,1.120\n0,1,1,1,12,-0.678,0.417,0.624\n0,1,1,1,15,-0.714,0.698,0.000\n0,1,1,1,34,-0.647,0.550,0.590\n0,2,1,1,5,0.321,-0.411,0.144\n0,3,1,1,3,0.443,0.000,-1.140\n0,3,1,1,5,-0.256,0.058,0.000\n0,3,1,1,6,-0.679,-0.029,0.000\n0,5,1,1,5,0.284,-1.386,0.314\n0,5,1,1,6,-0.654,1.072,0.279\n0,5,1,1,8,-0.744,-1.235,0.337\n0,5,1,1,10,0.000,0.000,0.427\n0,5,1,1,11,0.000,0.516,0.291\n0,5,1,1,12,0.678,-0.602,0.398\n0,5,1,1,15,1.142,-0.644,0.367\n0,5,1,1,25,0.000,0.000,0.295\n0,5,1,1,34,0.692,-0.530,0.278\n0,5,1,1,37,0.000,0.000,0.389\n0,5,1,1,39,0.000,0.000,0.278\n0,5,1,1,41,0.000,0.000,-0.141\n0,5,1,1,56,0.000,0.000,0.324\n0,5,1,1,68,0.000,0.000,0.136\n0,6,1,1,6,0.408,1.397,0.961\n5,6,1,1,6,0.313,-1.035,1.631\n0,8,1,1,8,1.055,0.834,0.000\n0,11,1,1,11,-0.387,-0.543,1.405\n0,12,1,1,12,0.000,0.000,0.893\n0,15,1,1,15,-0.177,0.000,0.049\n0,0,1,2,0,0.000,0.000,0.000\n2,0,1,2,0,0.000,0.000,0.000\n5,0,1,2,0,0.000,0.000,0.000\n0,0,1,2,2,0.000,0.000,-0.650\n5,0,1,2,2,0.000,0.000,-0.650\n0,1,1,2,1,0.419,0.296,0.282\n0,1,1,2,2,-0.494,0.274,-0.630\n0,1,1,2,5,0.075,0.000,0.358\n0,2,1,2,2,-0.293,0.115,-0.508\n0,2,1,2,5,0.301,0.104,0.507\n0,3,1,2,1,0.565,-0.554,0.234\n0,3,1,2,2,-0.577,-0.482,-0.427\n0,3,1,2,5,0.082,0.000,0.123\n0,5,1,2,1,0.000,-0.184,0.220\n0,5,1,2,2,0.501,-0.410,-0.535\n2,5,1,2,2,0.000,0.000,0.055\n2,5,1,2,3,0.000,0.000,-0.108\n0,5,1,2,5,-0.523,-0.228,0.208\n2,5,1,2,37,0.000,0.000,0.000\n0,6,1,2,1,-0.467,0.000,0.490\n0,6,1,2,2,0.425,0.168,-0.875\n0,6,1,2,5,0.000,0.136,0.396\n0,8,1,2,1,-0.504,0.371,0.557\n0,8,1,2,2,0.541,0.539,-1.009\n0,8,1,2,5,0.000,0.204,0.464\n0,0,1,3,0,0.000,0.400,0.300\n2,0,1,3,0,0.000,0.500,0.350\n5,0,1,3,0,0.000,0.000,0.000\n0,0,1,3,1,0.000,0.000,0.550\n0,0,1,3,5,0.000,0.200,0.700\n0,0,1,3,7,0.000,0.400,0.400\n0,1,1,3,1,0.103,0.177,0.545\n0,1,1,3,5,-0.072,0.316,0.674\n0,1,1,3,6,-0.117,-0.333,0.202\n0,1,1,3,7,0.825,0.139,0.325\n0,1,1,3,10,-0.927,1.112,1.388\n0,2,1,3,5,0.663,-0.167,0.426\n0,2,1,3,7,-0.758,0.112,0.563\n0,5,1,3,1,-0.073,0.085,0.531\n2,5,1,3,2,0.000,0.000,0.115\n2,5,1,3,3,0.000,0.000,0.446\n0,5,1,3,5,-0.822,0.501,1.008\n0,5,1,3,6,0.000,-0.624,0.330\n0,5,1,3,7,0.659,-1.407,0.308\n0,5,1,3,10,-0.412,0.693,0.087\n2,5,1,3,37,0.000,0.000,0.056\n0,5,1,3,43,0.000,1.027,0.360\n0,5,1,3,51,0.000,1.543,0.350\n0,5,1,3,53,0.000,0.501,0.000\n0,5,1,3,74,0.000,0.513,-0.344\n0,5,1,3,75,0.000,0.511,-0.186\n0,6,1,3,6,0.447,0.652,0.318\n0,6,1,3,7,-0.395,0.730,-0.139\n0,10,1,3,7,0.338,2.772,2.145\n0,10,1,3,10,0.548,0.000,1.795\n0,0,1,4,0,0.000,0.000,0.000\n0,0,1,6,0,0.000,0.000,0.200\n5,0,1,6,0,0.000,-0.200,0.400\n0,1,1,6,1,-0.681,0.755,0.755\n5,1,1,6,1,0.000,0.243,-0.596\n0,1,1,6,3,-0.547,0.000,0.320\n0,1,1,6,21,0.000,0.270,0.237\n0,2,1,6,21,0.102,0.460,-0.128\n0,3,1,6,21,-1.652,-1.660,0.283\n0,5,1,6,1,0.571,0.319,0.570\n0,5,1,6,2,0.000,0.000,0.306\n0,5,1,6,3,0.572,0.000,-0.304\n0,5,1,6,21,0.596,-0.276,0.346\n0,5,1,6,25,0.000,0.000,0.061\n0,5,1,6,37,0.000,0.000,0.106\n0,5,1,6,45,0.000,0.000,-0.174\n0,6,1,6,1,0.229,-0.710,0.722\n5,6,1,6,1,0.000,0.000,0.040\n0,6,1,6,21,1.488,-3.401,-0.320\n0,37,1,6,21,0.712,1.320,-0.507\n0,0,1,8,0,0.000,-0.300,0.500\n5,0,1,8,0,0.000,0.000,0.297\n0,1,1,8,1,-0.439,0.786,0.272\n5,1,1,8,1,0.115,-0.390,0.658\n0,1,1,8,6,-0.608,0.339,1.496\n0,1,1,8,23,-0.428,0.323,0.280\n0,2,1,8,23,0.594,-0.409,0.155\n0,5,1,8,1,0.393,-0.385,0.562\n0,5,1,8,6,0.598,-0.158,0.399\n0,5,1,8,23,-0.152,-0.440,0.357\n0,0,1,9,0,0.000,0.000,0.000\n5,0,1,9,0,0.000,0.000,0.000\n0,5,1,9,3,0.204,-0.335,-0.352\n0,5,1,9,53,0.000,0.000,0.097\n0,0,1,10,0,0.000,0.000,0.300\n5,0,1,10,0,0.000,0.000,0.000\n0,0,1,10,3,0.000,0.000,1.000\n0,1,1,10,3,-1.027,0.694,0.948\n0,1,1,10,6,0.159,-0.552,0.198\n0,1,1,10,28,0.552,-0.380,0.326\n0,3,1,10,3,3.100,-2.529,1.494\n0,3,1,10,28,0.079,0.280,0.402\n0,5,1,10,1,0.000,0.000,0.779\n0,5,1,10,3,-2.099,1.363,0.021\n0,5,1,10,6,-0.162,0.832,0.552\n0,5,1,10,28,-0.616,0.000,0.274\n0,0,1,15,0,0.000,0.000,0.400\n5,0,1,15,0,0.000,0.000,0.336\n0,1,1,15,1,-1.047,0.170,0.398\n0,1,1,15,15,-1.438,0.263,0.501\n0,1,1,15,71,-0.376,-0.133,0.288\n0,5,1,15,1,1.143,-0.231,0.447\n0,5,1,15,15,1.555,-0.323,0.456\n0,5,1,15,37,0.000,0.000,0.459\n0,5,1,15,71,0.229,0.203,0.440\n0,0,1,17,0,0.000,0.000,0.350\n5,0,1,17,0,0.000,0.000,0.000\n0,5,1,17,1,0.000,0.000,0.536\n0,5,1,17,7,0.000,0.000,0.212\n0,0,1,18,0,0.000,0.000,0.100\n5,0,1,18,0,0.000,0.000,0.112\n0,5,1,18,1,0.000,0.000,0.000\n0,5,1,18,6,0.000,0.000,0.099\n0,5,1,18,32,0.000,0.585,0.388\n0,5,1,18,43,0.000,-0.412,0.121\n0,5,1,18,48,0.000,0.000,0.195\n0,5,1,18,62,0.000,0.000,-0.088\n0,0,1,19,0,0.000,0.000,0.150\n5,0,1,19,0,0.000,0.000,0.179\n0,5,1,19,5,0.000,0.000,0.196\n0,5,1,19,6,0.000,0.000,0.176\n0,5,1,19,12,0.000,0.000,0.152\n0,0,1,20,0,0.000,0.000,0.350\n5,0,1,20,0,0.000,0.000,0.350\n0,5,1,20,5,0.000,0.000,0.344\n0,5,1,20,20,0.000,0.000,0.361\n0,0,1,22,0,0.000,0.000,0.236\n5,0,1,22,0,0.000,0.000,0.236\n0,0,1,25,0,0.000,0.000,0.300\n5,0,1,25,0,0.000,0.000,0.251\n0,1,1,25,1,0.000,-0.207,0.232\n0,1,1,25,32,0.000,0.288,0.218\n0,5,1,25,1,0.000,0.152,0.235\n0,5,1,25,6,0.000,0.000,0.495\n0,5,1,25,32,0.000,-0.130,0.214\n0,5,1,25,43,0.000,0.000,0.466\n0,5,1,25,72,0.000,0.000,0.243\n0,0,1,26,0,0.000,0.000,0.450\n5,0,1,26,0,0.000,0.000,0.376\n0,5,1,26,12,0.000,0.000,0.439\n0,5,1,26,71,0.000,0.000,0.472\n0,0,1,34,0,0.000,0.000,0.250\n5,0,1,34,0,0.000,0.000,0.198\n0,1,1,34,36,0.000,0.000,0.187\n0,5,1,34,1,0.000,0.000,0.247\n0,5,1,34,36,0.000,0.000,0.259\n0,0,1,37,0,0.000,0.000,0.200\n5,0,1,37,0,0.000,0.000,0.000\n0,1,1,37,37,0.000,0.449,0.000\n0,5,1,37,37,0.000,-0.420,0.391\n0,6,1,37,37,0.000,0.000,0.150\n0,0,1,39,0,0.000,0.000,0.000\n5,0,1,39,0,0.000,0.000,0.000\n0,1,1,39,63,0.000,-0.080,-0.056\n0,5,1,39,63,0.000,0.000,-0.113\n0,0,1,40,0,0.000,0.000,0.250\n5,0,1,40,0,0.000,0.000,0.297\n0,5,1,40,28,0.000,-0.097,0.203\n0,5,1,40,37,0.000,0.000,0.329\n0,0,1,41,0,0.000,0.600,0.000\n0,1,1,41,32,0.000,1.263,0.000\n0,5,1,41,32,0.000,0.000,-0.106\n0,5,1,41,72,0.000,0.632,0.000\n0,0,1,43,0,0.000,0.000,0.150\n5,0,1,43,0,0.000,0.000,0.297\n0,5,1,43,18,0.357,-0.918,0.000\n0,5,1,43,25,0.000,0.000,0.061\n0,5,1,43,28,-0.249,0.382,0.343\n0,0,1,45,0,0.000,0.000,0.100\n0,5,1,45,32,0.000,0.000,0.125\n0,0,1,46,0,0.000,0.000,-0.500\n0,5,1,46,7,0.000,0.000,-0.540\n0,0,1,54,0,0.000,0.000,0.000\n2,0,1,54,0,0.000,0.000,0.000\n5,0,1,54,0,0.000,0.000,0.000\n0,5,1,54,3,0.000,0.000,-0.315\n0,5,1,54,36,0.000,0.000,0.315\n0,0,1,55,0,0.000,0.000,0.000\n5,0,1,55,0,0.000,0.000,0.000\n0,5,1,55,36,0.000,-0.058,0.084\n0,5,1,55,57,0.000,-0.058,-0.092\n0,0,1,56,0,0.000,0.000,-0.300\n0,1,1,56,36,0.875,0.668,-0.015\n0,1,1,56,57,-0.870,0.775,-0.406\n0,5,1,56,36,-0.958,-0.629,-0.372\n0,5,1,56,57,0.952,-0.715,-0.483\n0,0,1,57,0,0.000,0.000,0.000\n5,0,1,57,0,0.000,0.000,0.000\n0,0,1,58,0,0.000,0.000,0.000\n0,0,1,62,0,0.000,0.000,0.250\n0,5,1,62,18,0.000,0.000,0.270\n0,0,1,63,0,0.000,0.000,0.000\n5,0,1,63,0,0.000,0.000,0.000\n0,0,1,64,0,0.000,0.000,0.000\n5,0,1,64,0,0.000,0.000,0.000\n0,0,1,67,0,0.000,0.000,0.000\n5,0,1,67,0,0.000,0.000,0.000\n0,0,1,68,0,0.000,0.000,0.400\n0,1,1,68,1,-0.117,0.090,0.751\n0,1,1,68,23,0.373,0.153,0.635\n0,1,1,68,32,-0.090,-0.169,0.075\n0,5,1,68,1,0.134,-0.112,0.329\n0,5,1,68,23,-0.361,-0.202,0.560\n0,5,1,68,32,0.072,0.218,0.093\n0,0,1,73,0,0.000,0.000,0.500\n0,5,1,73,32,0.000,0.000,0.509\n0,5,1,73,72,0.000,0.000,0.443\n0,0,1,75,0,0.000,0.000,0.000\n0,0,1,78,0,0.000,0.000,0.000\n0,0,1,80,0,0.000,0.000,0.000\n0,0,1,81,0,0.000,0.000,0.000\n0,0,2,2,0,0.000,12.000,0.000\n1,0,2,2,0,0.000,1.800,0.000\n5,0,2,2,0,0.000,12.000,0.000\n0,1,2,2,1,-0.403,12.000,0.000\n0,1,2,2,2,0.000,12.000,0.000\n1,1,2,2,2,-0.418,2.089,-0.310\n0,1,2,2,5,0.000,12.000,0.000\n1,1,2,2,5,0.412,2.120,0.269\n1,2,2,2,2,0.094,1.621,0.877\n0,2,2,2,5,0.000,12.000,0.000\n1,2,2,2,5,0.317,1.421,-0.870\n0,3,2,2,5,0.000,12.000,0.000\n0,5,2,2,5,0.000,12.000,0.000\n1,5,2,2,5,-0.406,1.767,0.000\n0,5,2,2,6,0.000,12.000,0.000\n0,5,2,2,37,0.000,12.000,0.000\n0,5,2,2,40,0.000,12.000,0.000\n0,5,2,2,41,0.000,12.000,0.000\n0,5,2,2,45,0.000,12.000,0.000\n0,5,2,2,62,0.000,12.000,0.000\n1,0,2,3,0,0.000,2.500,0.000\n1,1,2,3,1,0.136,1.798,0.630\n1,1,2,3,5,0.497,2.405,0.357\n1,1,2,3,6,-0.211,1.925,-0.131\n1,1,2,3,7,-0.401,2.028,-0.318\n1,1,2,3,10,-0.084,2.214,-0.610\n1,2,2,3,1,-0.325,1.553,-0.487\n1,2,2,3,5,-0.295,2.024,-0.590\n1,2,2,3,6,-0.143,1.466,0.000\n1,2,2,3,7,0.362,1.978,0.000\n1,2,2,3,9,0.296,1.514,0.481\n1,2,2,3,10,0.095,1.583,0.380\n1,5,2,3,1,0.213,1.728,-0.042\n1,5,2,3,5,-0.208,1.622,0.223\n1,5,2,3,6,0.359,1.539,0.194\n1,5,2,3,7,0.000,2.046,0.000\n1,5,2,3,9,-0.290,1.519,-0.470\n1,5,2,3,10,0.000,1.395,0.227\n1,0,2,4,0,0.000,0.000,0.000\n0,0,2,6,0,0.000,3.100,0.000\n2,0,2,6,0,0.000,3.600,0.000\n5,0,2,6,0,0.000,3.600,0.000\n0,2,2,6,1,-1.953,3.953,-1.055\n0,2,2,6,3,-1.712,2.596,-0.330\n0,2,2,6,29,-0.215,2.810,-0.456\n0,5,2,6,1,1.951,3.936,1.130\n0,5,2,6,3,1.719,2.628,0.360\n0,5,2,6,29,0.216,2.808,0.456\n1,0,2,9,0,0.000,1.800,0.000\n0,0,2,10,0,0.000,6.000,0.000\n2,0,2,10,0,0.000,6.000,0.000\n5,0,2,10,0,0.000,6.000,0.000\n0,0,2,15,0,0.000,1.423,0.000\n2,0,2,15,0,0.000,1.423,0.000\n5,0,2,15,0,0.000,1.423,0.000\n0,0,2,17,0,0.000,1.423,0.000\n0,0,2,18,0,0.000,0.000,0.000\n2,0,2,18,0,0.000,0.000,0.000\n5,0,2,18,0,0.000,0.000,0.000\n0,0,2,19,0,0.000,0.000,0.000\n0,0,2,20,0,0.000,0.000,0.000\n2,0,2,20,0,0.000,0.000,0.000\n0,0,2,22,0,0.000,0.000,0.000\n2,0,2,22,0,0.000,0.000,0.000\n5,0,2,22,0,0.000,0.000,0.000\n0,0,2,25,0,0.000,0.000,0.000\n0,0,2,30,0,0.000,12.000,0.000\n0,0,2,34,0,0.000,0.000,0.000\n2,0,2,34,0,0.000,0.000,0.000\n1,0,2,37,0,0.000,2.000,0.000\n1,1,2,37,37,0.000,2.952,-0.079\n1,2,2,37,37,0.000,1.542,0.434\n1,5,2,37,37,0.000,1.308,-0.357\n1,0,2,39,0,0.000,6.000,0.000\n0,0,2,40,0,0.000,3.700,0.000\n2,0,2,40,0,0.000,3.600,0.000\n5,0,2,40,0,0.000,3.600,0.000\n0,2,2,40,28,0.000,3.756,-0.530\n0,5,2,40,28,0.073,3.698,0.291\n0,0,2,41,0,0.000,1.200,0.000\n2,0,2,41,0,0.000,1.800,0.000\n0,2,2,41,32,0.000,1.235,0.000\n0,5,2,41,32,0.000,1.231,0.000\n0,0,2,43,0,0.000,3.600,0.000\n2,0,2,43,0,0.000,3.600,0.000\n0,0,2,45,0,0.000,2.200,0.000\n2,0,2,45,0,0.000,1.800,0.000\n0,2,2,45,32,0.000,2.212,0.000\n0,5,2,45,32,0.000,2.225,0.000\n0,0,2,46,0,0.000,1.800,0.000\n2,0,2,46,0,0.000,1.800,0.000\n0,0,2,55,0,0.000,4.800,0.000\n0,0,2,56,0,0.000,4.800,0.000\n0,0,2,62,0,0.000,8.000,0.000\n0,2,2,62,23,1.693,7.903,0.532\n0,5,2,62,23,-1.696,7.897,-0.482\n1,0,2,63,0,0.000,1.800,0.000\n1,0,2,64,0,0.000,1.800,0.000\n1,0,2,67,0,0.000,1.800,0.000\n1,0,2,81,0,0.000,4.800,0.000\n1,0,3,3,0,0.000,0.600,0.000\n4,0,3,3,0,0.000,1.800,0.000\n1,1,3,3,1,-0.486,0.714,0.000\n1,1,3,3,6,-0.081,-0.125,0.132\n1,1,3,3,7,1.053,1.327,0.000\n1,5,3,3,6,0.000,0.188,0.436\n1,5,3,3,7,0.000,0.177,-0.412\n1,6,3,3,6,0.269,0.437,0.000\n1,6,3,3,7,-0.495,0.793,-0.318\n1,7,3,3,7,-0.260,1.084,0.193\n0,0,3,6,0,0.000,5.500,0.000\n2,0,3,6,0,0.000,5.500,0.000\n4,0,3,6,0,0.000,3.600,0.000\n5,0,3,6,0,0.000,3.600,0.000\n0,1,3,6,1,-1.244,5.482,0.365\n0,1,3,6,24,-1.166,5.078,-0.545\n0,1,3,6,37,-0.677,5.854,0.521\n2,2,3,6,24,0.256,4.519,0.258\n2,3,3,6,24,1.663,4.073,0.094\n0,5,3,6,1,0.526,5.631,0.691\n0,5,3,6,2,0.159,6.586,0.216\n0,5,3,6,24,-2.285,4.737,0.468\n0,7,3,6,0,0.700,6.500,-0.400\n0,7,3,6,1,0.682,7.184,-0.935\n0,7,3,6,2,-0.168,6.572,-0.151\n0,7,3,6,24,1.662,6.152,-0.058\n0,7,3,6,37,0.635,5.890,-0.446\n2,37,3,6,24,0.000,3.892,-0.094\n0,0,3,9,0,0.000,16.000,0.000\n1,0,3,9,0,0.000,1.800,0.000\n5,0,3,9,0,0.000,12.000,0.000\n0,2,3,9,27,0.000,16.000,0.000\n0,5,3,9,1,0.687,16.152,0.894\n0,5,3,9,27,0.000,16.000,0.000\n0,40,3,9,1,-0.758,18.216,-0.188\n0,40,3,9,27,0.000,16.000,0.000\n0,0,3,10,0,0.000,6.000,0.000\n2,0,3,10,0,0.000,6.000,0.000\n4,0,3,10,0,0.000,6.000,0.000\n5,0,3,10,0,0.000,6.000,0.000\n0,1,3,10,1,0.647,6.159,0.507\n0,1,3,10,6,-1.035,8.791,1.464\n0,1,3,10,28,-0.294,5.805,1.342\n2,2,3,10,28,-0.287,7.142,0.120\n0,5,3,10,1,-0.183,6.314,1.753\n0,5,3,10,3,-0.751,5.348,0.209\n0,5,3,10,28,-0.388,5.972,0.459\n0,7,3,10,1,-0.319,6.294,-0.147\n0,7,3,10,3,0.776,-0.585,-0.145\n0,7,3,10,6,1.107,8.631,-0.452\n0,7,3,10,28,1.435,4.975,-0.454\n0,10,3,10,28,0.000,3.495,1.291\n0,0,3,15,0,0.000,1.423,0.000\n2,0,3,15,0,0.000,1.423,0.000\n4,0,3,15,0,0.000,1.423,0.000\n5,0,3,15,0,0.000,1.423,0.000\n0,0,3,17,0,0.000,1.423,0.000\n5,0,3,17,0,0.000,1.423,0.000\n0,0,3,18,0,0.000,0.000,0.000\n2,0,3,18,0,0.000,0.000,0.000\n0,0,3,20,0,0.000,0.000,-0.300\n2,0,3,20,0,0.000,0.000,0.000\n4,0,3,20,0,0.000,0.000,-0.300\n5,0,3,20,0,0.000,0.000,0.000\n0,7,3,20,0,0.000,0.400,0.400\n0,7,3,20,5,0.000,0.000,-0.131\n0,7,3,20,20,0.000,0.000,0.000\n0,20,3,20,5,0.000,0.000,0.085\n0,20,3,20,20,0.000,0.000,0.000\n0,0,3,22,0,0.000,0.000,0.000\n2,0,3,22,0,0.000,0.000,0.000\n4,0,3,22,0,0.000,0.000,0.000\n5,0,3,22,0,0.000,0.000,0.000\n0,7,3,22,0,0.000,0.400,0.400\n0,0,3,25,0,0.000,0.000,0.000\n2,0,3,25,0,0.000,0.000,0.000\n1,0,3,30,0,0.000,1.800,0.000\n4,0,3,30,0,0.000,1.800,0.000\n1,0,3,37,0,0.000,2.500,0.000\n4,0,3,37,0,0.000,1.800,0.000\n1,1,3,37,37,0.000,2.428,0.000\n1,6,3,37,37,0.000,1.743,0.000\n1,7,3,37,37,0.000,2.256,0.000\n1,43,3,37,37,-0.241,3.385,-0.838\n1,0,3,39,0,0.000,5.500,0.000\n0,0,3,40,0,0.000,3.900,0.000\n2,0,3,40,0,0.000,3.600,0.000\n5,0,3,40,0,0.000,3.600,0.000\n0,5,3,40,28,-1.477,4.362,0.902\n0,9,3,40,28,1.496,4.369,-0.417\n0,40,3,40,28,0.178,3.149,0.778\n0,0,3,41,0,0.000,1.800,0.000\n2,0,3,41,0,0.000,1.800,0.000\n0,0,3,43,0,0.000,4.500,0.000\n2,0,3,43,0,0.000,3.600,0.000\n4,0,3,43,0,0.000,3.600,0.000\n5,0,3,43,0,0.000,3.600,0.000\n0,1,3,43,18,1.712,3.309,0.233\n0,1,3,43,28,-0.414,4.168,-0.875\n0,7,3,43,18,-0.880,5.091,-0.129\n0,7,3,43,28,0.536,5.276,-0.556\n2,37,3,43,18,-0.701,4.871,1.225\n2,37,3,43,28,-0.086,5.073,0.878\n0,0,3,45,0,0.000,1.800,0.000\n2,0,3,45,0,0.000,1.800,0.000\n0,0,3,48,0,0.000,0.000,0.892\n0,0,3,51,0,0.000,13.500,0.000\n0,1,3,51,52,0.000,13.549,0.000\n0,0,3,54,0,0.000,8.000,0.000\n1,0,3,54,0,0.000,2.500,0.000\n5,0,3,54,0,0.000,12.000,0.000\n0,5,3,54,1,0.000,8.000,0.000\n0,5,3,54,36,0.000,8.000,0.000\n0,0,3,55,0,0.000,4.800,0.000\n2,0,3,55,0,0.000,4.800,0.000\n0,0,3,56,0,0.000,4.800,0.000\n2,0,3,56,0,0.000,4.800,0.000\n1,0,3,57,0,0.000,2.500,0.000\n1,0,3,58,0,0.000,4.800,0.000\n0,0,3,62,0,0.000,3.600,0.000\n2,0,3,62,0,0.000,3.600,0.000\n5,0,3,62,0,0.000,3.600,0.000\n1,0,3,63,0,0.000,2.500,0.000\n1,0,3,64,0,0.000,2.500,0.000\n0,0,3,67,0,0.000,12.000,0.000\n0,0,3,74,0,0.000,19.000,0.000\n0,1,3,74,7,0.000,19.349,0.000\n0,0,3,75,0,0.000,19.000,0.000\n0,1,3,75,71,0.000,18.751,0.000\n1,0,3,78,0,0.000,2.500,0.000\n1,0,3,80,0,0.000,2.500,0.000\n0,0,6,6,0,0.000,-2.000,0.000\n5,0,6,6,0,0.000,-2.000,0.000\n0,0,6,8,0,0.900,-1.100,-0.500\n5,0,6,8,0,0.000,0.000,0.274\n0,21,6,8,1,0.261,-0.330,-0.542\n0,21,6,8,23,1.503,-1.853,-0.476\n0,0,6,9,0,0.000,3.600,0.000\n5,0,6,9,0,0.000,3.600,0.000\n0,0,6,10,0,1.200,0.500,-1.000\n0,21,6,10,1,0.875,0.180,-0.733\n0,21,6,10,3,0.529,0.000,-1.163\n0,0,6,15,0,0.000,-4.000,0.000\n0,0,6,17,0,0.000,1.423,0.000\n5,0,6,17,0,0.000,1.423,0.000\n0,0,6,18,0,0.000,0.000,0.100\n5,0,6,18,0,0.000,0.000,0.103\n0,33,6,18,1,-0.520,-0.471,-0.267\n0,33,6,18,6,-1.623,0.204,0.438\n0,33,6,18,32,1.616,0.425,0.191\n0,0,6,19,0,0.000,0.000,0.150\n5,0,6,19,0,0.000,0.000,0.165\n0,21,6,19,1,-0.620,-0.329,0.303\n0,21,6,19,5,0.683,0.220,0.000\n0,0,6,20,0,0.000,0.000,0.400\n4,0,6,20,0,0.000,0.000,0.217\n5,0,6,20,0,0.000,0.000,0.217\n0,20,6,20,5,0.000,0.000,-0.079\n4,20,6,20,20,0.000,0.000,0.000\n0,0,6,22,0,0.000,0.000,0.217\n0,0,6,25,0,0.000,0.000,0.650\n5,0,6,25,0,0.000,0.000,0.231\n0,1,6,25,1,-1.704,-0.452,0.556\n0,1,6,25,6,0.000,0.000,0.777\n0,1,6,25,32,1.205,0.914,0.612\n0,24,6,25,6,-3.209,-7.622,1.065\n0,24,6,25,32,-5.891,-3.332,0.290\n0,0,6,26,0,0.000,0.000,0.346\n0,0,6,30,0,0.000,3.600,0.000\n2,0,6,30,0,0.000,3.600,0.000\n0,0,6,37,0,0.000,3.200,0.000\n5,0,6,37,0,0.000,3.600,0.000\n0,1,6,37,37,0.000,4.382,0.000\n0,3,6,37,37,0.000,2.576,0.000\n0,29,6,37,37,0.000,2.801,0.000\n0,0,6,39,0,0.000,0.000,0.000\n0,0,6,40,0,0.000,0.000,0.274\n0,0,6,41,0,0.000,3.600,0.000\n0,0,6,43,0,0.000,0.000,0.274\n0,0,6,45,0,0.000,6.000,0.000\n0,1,6,45,32,0.000,6.208,0.000\n0,0,6,54,0,0.000,3.600,0.000\n0,0,6,55,0,0.000,3.600,0.000\n0,0,6,57,0,0.000,3.600,0.000\n0,0,6,58,0,0.000,3.600,0.000\n0,0,6,63,0,0.000,3.600,0.000\n0,0,6,64,0,0.000,3.600,0.000\n0,0,8,8,0,0.000,0.000,0.375\n5,0,8,8,0,0.000,0.000,0.375\n0,0,8,9,0,0.000,3.600,0.000\n5,0,8,9,0,0.000,3.600,0.000\n0,0,8,10,0,0.000,0.000,0.000\n4,0,8,10,0,0.000,0.000,0.000\n0,0,8,15,0,0.000,0.000,0.424\n0,0,8,17,0,0.000,1.423,0.000\n4,0,8,17,0,0.000,1.423,0.000\n5,0,8,17,0,0.000,1.423,0.000\n0,0,8,19,0,0.000,0.000,0.225\n0,0,8,20,0,0.000,0.000,0.350\n4,0,8,20,0,0.000,0.000,0.300\n5,0,8,20,0,0.000,0.000,0.297\n0,20,8,20,5,0.000,0.120,0.472\n4,20,8,20,20,0.000,-0.097,0.200\n0,23,8,20,5,-0.101,-0.324,0.371\n0,23,8,20,20,0.107,0.253,0.151\n0,0,8,22,0,0.000,0.000,0.297\n0,0,8,25,0,0.000,0.000,0.316\n5,0,8,25,0,0.000,0.000,0.316\n0,0,8,26,0,0.000,0.000,0.474\n5,0,8,26,0,0.000,0.000,0.474\n0,0,8,34,0,0.000,0.000,0.250\n0,0,8,39,0,0.000,0.000,0.000\n0,0,8,40,0,0.000,0.000,0.375\n0,0,8,43,0,0.000,0.000,0.375\n0,0,8,45,0,0.000,3.600,0.000\n0,0,8,46,0,0.000,3.600,0.000\n0,0,8,55,0,0.000,3.600,0.000\n0,0,8,56,0,0.000,3.600,0.000\n0,0,9,9,0,0.000,12.000,0.000\n1,0,9,9,0,0.000,1.800,0.000\n5,0,9,9,0,0.000,12.000,0.000\n0,0,9,10,0,0.000,6.000,0.000\n5,0,9,10,0,0.000,6.000,0.000\n0,0,9,15,0,0.000,1.423,0.000\n0,0,9,18,0,0.000,0.000,0.000\n0,0,9,19,0,0.000,0.000,0.000\n0,0,9,20,0,0.000,0.000,0.000\n0,0,9,25,0,0.000,0.000,0.000\n0,0,9,34,0,0.000,0.000,0.000\n5,0,9,34,0,0.000,0.000,0.000\n1,0,9,37,0,0.000,1.800,0.000\n1,0,9,39,0,0.000,6.000,0.000\n0,0,9,40,0,0.000,3.600,0.000\n0,0,9,41,0,0.000,4.800,0.000\n0,0,9,45,0,0.000,1.800,0.000\n0,0,9,54,0,0.000,12.000,0.000\n0,0,9,55,0,0.000,4.800,0.000\n0,0,9,56,0,0.000,4.800,0.000\n1,0,9,57,0,0.000,1.800,0.000\n0,0,9,62,0,0.000,3.600,0.000\n1,0,9,63,0,0.000,1.800,0.000\n1,0,9,64,0,0.000,1.800,0.000\n0,0,9,67,0,0.000,12.000,0.000\n1,0,9,78,0,0.000,1.800,0.000\n1,0,9,81,0,0.000,4.800,0.000\n0,0,10,10,0,0.000,0.000,0.000\n5,0,10,10,0,0.000,0.000,0.000\n0,0,10,15,0,0.000,0.000,0.000\n0,0,10,17,0,0.000,4.743,0.000\n0,0,10,20,0,0.000,0.000,0.000\n4,0,10,20,0,0.000,0.000,0.000\n5,0,10,20,0,0.000,0.000,0.000\n0,0,10,22,0,0.000,0.000,0.000\n0,0,10,25,0,0.000,0.000,0.000\n0,0,10,26,0,0.000,0.000,0.000\n5,0,10,26,0,0.000,0.000,0.000\n0,0,10,34,0,0.000,0.000,0.000\n0,0,10,37,0,0.000,6.000,0.000\n0,0,10,39,0,0.000,0.000,0.000\n0,0,10,40,0,0.000,0.000,0.000\n5,0,10,40,0,0.000,0.000,0.000\n0,0,10,41,0,0.000,6.000,0.000\n0,0,10,45,0,0.000,6.000,0.000\n0,0,10,63,0,0.000,6.000,0.000\n0,0,10,64,0,0.000,6.000,0.000\n0,0,15,15,0,-1.400,-8.300,1.000\n5,0,15,15,0,0.000,-8.000,0.000\n0,1,15,15,1,-1.663,-8.408,1.433\n0,1,15,15,71,-1.088,-8.245,0.411\n0,0,15,18,0,0.000,0.000,0.160\n0,0,15,19,0,0.000,0.000,0.255\n5,0,15,19,0,0.000,0.000,0.255\n0,0,15,20,0,0.000,0.000,0.336\n4,0,15,20,0,0.000,0.000,0.336\n0,0,15,22,0,0.000,0.000,0.336\n0,0,15,25,0,0.000,0.000,0.358\n4,0,15,25,0,0.000,0.000,0.358\n0,0,15,26,0,0.000,0.000,0.537\n0,0,15,30,0,0.000,1.423,0.000\n4,0,15,30,0,0.000,1.423,0.000\n0,0,15,37,0,0.000,1.300,0.000\n5,0,15,37,0,0.000,1.423,0.000\n0,1,15,37,37,0.000,2.177,0.000\n0,71,15,37,37,0.000,0.505,0.333\n0,0,15,40,0,0.000,0.000,0.424\n0,0,15,43,0,0.000,0.000,0.424\n0,0,15,57,0,0.000,1.423,0.000\n0,0,15,63,0,0.000,1.423,0.000\n0,0,15,64,0,0.000,1.423,0.000\n0,0,17,20,0,0.000,0.000,0.000\n4,0,17,20,0,0.000,0.000,0.000\n5,0,17,20,0,0.000,0.000,0.000\n0,0,17,22,0,0.000,0.000,0.000\n0,0,17,37,0,0.000,1.423,0.000\n0,0,17,43,0,0.000,3.795,0.000\n0,0,18,20,0,0.000,0.000,0.112\n4,0,18,20,0,0.000,0.000,0.112\n5,0,18,20,0,0.000,0.000,0.112\n0,0,18,22,0,0.000,0.000,0.112\n0,0,18,37,0,0.000,-1.200,-0.300\n0,32,18,37,37,-0.173,-0.965,-0.610\n0,39,18,37,37,0.000,-0.760,0.227\n0,43,18,37,37,0.228,-1.741,-0.371\n0,0,18,39,0,0.000,0.000,0.500\n0,32,18,39,63,0.000,0.687,0.680\n0,37,18,39,63,0.000,-0.513,0.357\n0,0,18,43,0,0.000,0.000,0.350\n4,0,18,43,0,0.000,0.000,0.141\n5,0,18,43,0,0.000,0.000,0.141\n0,1,18,43,1,-0.914,-0.482,0.179\n0,1,18,43,3,-0.392,-2.724,0.312\n0,1,18,43,28,-1.508,-1.816,-0.175\n0,1,18,43,37,0.823,-1.220,-0.770\n0,32,18,43,1,1.588,1.499,1.410\n0,32,18,43,3,0.653,0.254,0.000\n0,32,18,43,28,0.528,0.342,0.000\n0,32,18,43,37,0.812,1.513,1.266\n0,37,18,43,1,-1.139,-0.703,1.088\n0,37,18,43,28,-2.014,-1.646,-2.068\n0,37,18,43,37,-1.519,-0.328,1.437\n0,43,18,43,28,3.011,-1.405,2.038\n0,0,18,48,0,0.000,0.000,0.400\n0,1,18,48,28,1.767,1.606,0.408\n0,32,18,48,28,-1.463,-2.548,0.310\n0,0,18,55,0,0.000,0.000,0.000\n0,0,18,58,0,0.000,0.000,0.000\n0,0,18,62,0,0.000,0.000,0.500\n0,1,18,62,1,-0.403,-0.273,0.440\n0,32,18,62,1,0.291,0.385,0.582\n0,0,18,63,0,0.000,0.000,0.000\n0,0,18,64,0,0.000,0.000,0.000\n0,0,18,80,0,0.000,0.000,0.000\n0,0,19,20,0,0.000,0.000,0.179\n4,0,19,20,0,0.000,0.000,0.179\n0,0,19,37,0,0.000,0.000,0.000\n0,0,19,40,0,0.000,0.000,0.225\n0,0,19,63,0,0.000,0.000,0.000\n0,0,19,75,0,0.000,0.000,0.000\n0,0,20,20,0,0.000,0.000,0.200\n4,0,20,20,0,0.000,0.000,0.000\n5,0,20,20,0,0.000,0.000,0.236\n0,1,20,20,5,0.067,0.081,0.347\n0,1,20,20,20,-0.063,-0.064,0.140\n0,3,20,20,5,0.000,0.000,0.083\n0,3,20,20,20,0.000,0.000,0.000\n0,5,20,20,5,0.000,0.000,0.424\n0,5,20,20,6,0.000,0.000,-0.080\n0,5,20,20,8,0.000,0.127,0.450\n0,5,20,20,12,-0.072,-0.269,0.439\n0,5,20,20,20,-0.057,0.000,0.307\n4,6,20,20,20,0.000,0.000,0.000\n4,8,20,20,20,0.000,-0.091,0.192\n0,12,20,20,20,0.077,0.202,0.183\n4,20,20,20,20,0.000,0.000,0.000\n0,0,20,22,0,0.000,0.000,0.236\n4,0,20,22,0,0.000,0.000,0.236\n0,0,20,25,0,0.000,0.000,0.251\n4,0,20,25,0,0.000,0.000,0.251\n0,0,20,26,0,0.000,0.000,0.376\n4,0,20,26,0,0.000,0.000,0.376\n5,0,20,26,0,0.000,0.000,0.376\n0,0,20,30,0,0.000,0.000,0.000\n2,0,20,30,0,0.000,0.000,0.000\n4,0,20,30,0,0.000,0.000,0.000\n0,0,20,30,30,0.000,0.000,-0.500\n0,0,20,34,0,0.000,0.000,0.198\n4,0,20,34,0,0.000,0.000,0.198\n0,0,20,37,0,0.000,0.000,0.000\n4,0,20,37,0,0.000,0.000,0.000\n0,0,20,40,0,0.000,0.000,0.297\n0,0,20,41,0,0.000,0.000,0.000\n0,0,20,43,0,0.000,0.000,0.297\n4,0,20,43,0,0.000,0.000,0.297\n0,0,20,45,0,0.000,0.000,0.000\n0,0,22,22,0,0.000,0.000,0.236\n4,0,22,22,0,0.000,0.000,0.236\n5,0,22,22,0,0.000,0.000,0.236\n0,0,22,30,0,0.000,0.000,0.000\n4,0,22,30,0,0.000,0.000,0.000\n0,0,22,34,0,0.000,0.000,0.198\n0,0,22,37,0,0.000,0.000,0.000\n0,0,22,40,0,0.000,0.000,0.297\n0,0,22,41,0,0.000,0.000,0.000\n0,0,22,43,0,0.000,0.000,0.297\n5,0,22,43,0,0.000,0.000,0.297\n0,0,22,45,0,0.000,0.000,0.000\n0,0,25,25,0,0.000,0.000,0.267\n0,0,25,37,0,0.000,0.000,0.000\n5,0,25,37,0,0.000,0.000,0.000\n0,0,25,39,0,0.000,0.000,0.000\n0,0,25,40,0,0.000,0.000,0.316\n5,0,25,40,0,0.000,0.000,0.316\n0,0,25,43,0,0.000,0.000,0.250\n0,1,25,43,1,-2.686,-1.512,0.591\n0,1,25,43,28,-3.730,-0.531,0.000\n0,32,25,43,1,2.108,1.896,0.965\n0,32,25,43,28,2.977,0.732,-0.502\n0,0,25,57,0,0.000,0.000,0.000\n0,0,25,63,0,0.000,0.000,0.000\n0,0,26,26,0,0.000,0.000,0.600\n5,0,26,26,0,0.000,0.000,0.600\n0,0,26,34,0,0.000,0.000,0.316\n5,0,26,34,0,0.000,0.000,0.316\n0,0,26,37,0,0.000,1.423,0.000\n0,0,26,40,0,0.000,0.000,0.474\n0,0,30,30,0,0.000,12.000,0.000\n1,0,30,30,0,0.000,1.800,0.000\n4,0,30,30,0,0.000,1.800,0.000\n0,0,30,40,0,0.000,3.600,0.000\n1,0,30,67,0,0.000,1.800,0.000\n0,0,34,37,0,0.000,0.000,0.000\n0,0,34,43,0,0.000,0.000,0.250\n0,0,37,37,0,0.000,7.000,0.000\n1,0,37,37,0,0.000,2.000,0.000\n4,0,37,37,0,0.000,6.000,0.000\n5,0,37,37,0,0.000,6.000,0.000\n0,1,37,37,5,0.000,7.000,0.000\n0,1,37,37,37,0.000,7.000,0.000\n0,2,37,37,5,0.000,7.000,0.000\n0,2,37,37,37,0.000,7.000,0.000\n0,3,37,37,5,0.000,7.000,0.000\n0,3,37,37,37,0.000,7.000,0.000\n0,5,37,37,5,0.000,7.000,0.000\n0,5,37,37,6,0.000,7.000,0.000\n0,5,37,37,15,0.000,7.000,0.000\n0,5,37,37,18,0.000,7.000,0.000\n0,5,37,37,37,0.000,7.000,0.000\n0,5,37,37,40,0.000,7.000,0.000\n0,5,37,37,43,0.000,7.000,0.000\n0,6,37,37,37,0.000,7.000,0.000\n0,15,37,37,37,0.000,7.000,0.000\n0,18,37,37,37,0.000,7.000,0.000\n0,37,37,37,37,0.000,7.000,0.000\n0,37,37,37,40,0.000,7.000,0.000\n0,37,37,37,43,0.000,7.000,0.000\n0,0,37,38,0,0.000,7.000,0.000\n0,0,37,39,0,0.000,3.600,0.000\n1,0,37,39,0,0.000,6.000,0.000\n0,0,37,40,0,0.000,4.000,0.000\n5,0,37,40,0,0.000,3.600,0.000\n0,37,37,40,1,0.000,4.336,0.370\n0,37,37,40,28,0.715,2.628,3.355\n0,0,37,41,0,0.000,1.800,0.000\n0,0,37,43,0,0.000,2.000,1.800\n5,0,37,43,0,0.000,3.600,0.000\n0,37,37,43,18,0.372,2.284,2.034\n0,37,37,43,28,0.000,1.694,1.508\n0,0,37,45,0,0.000,1.800,0.000\n0,0,37,46,0,0.000,1.800,0.000\n0,0,37,55,0,0.000,4.800,0.000\n0,0,37,56,0,0.000,4.800,0.000\n1,0,37,57,0,0.000,1.800,0.000\n0,0,37,58,0,0.000,6.000,0.000\n1,0,37,58,0,0.000,4.800,0.000\n0,0,37,62,0,0.000,3.600,0.000\n0,0,37,63,0,0.000,7.000,0.000\n1,0,37,63,0,0.000,1.800,0.000\n0,0,37,64,0,0.000,7.000,0.000\n1,0,37,64,0,0.000,1.800,0.000\n1,0,37,67,0,0.000,1.800,0.000\n0,0,37,69,0,0.000,7.000,0.000\n0,0,37,78,0,0.000,6.000,0.000\n0,0,37,81,0,0.000,6.000,0.000\n1,0,37,81,0,0.000,4.800,0.000\n0,0,38,38,0,0.000,7.000,0.000\n0,0,38,58,0,0.000,7.000,0.000\n0,0,38,63,0,0.000,7.000,0.000\n0,0,38,64,0,0.000,7.000,0.000\n0,0,38,69,0,0.000,6.000,0.000\n0,0,38,78,0,0.000,6.000,0.000\n0,0,39,40,0,0.000,0.000,0.000\n0,0,39,45,0,0.000,6.000,0.000\n0,0,39,63,0,0.000,4.000,0.000\n1,0,39,63,0,0.000,6.000,0.000\n5,0,39,63,0,0.000,3.600,0.000\n0,1,39,63,5,0.000,4.000,0.000\n0,1,39,63,64,0.000,4.000,0.000\n0,18,39,63,5,0.000,4.000,0.000\n0,18,39,63,64,0.000,4.000,0.000\n0,63,39,63,5,0.000,4.000,0.000\n0,63,39,63,64,0.000,4.000,0.000\n0,0,39,64,0,0.000,3.600,0.000\n1,0,39,64,0,0.000,6.000,0.000\n0,0,39,65,0,0.000,4.000,0.000\n0,0,39,78,0,0.000,3.600,0.000\n0,0,40,40,0,0.000,0.000,0.375\n0,0,40,45,0,0.000,3.600,0.000\n0,0,40,46,0,0.000,3.600,0.000\n0,0,40,54,0,0.000,3.600,0.000\n2,0,40,54,0,0.000,3.600,0.000\n0,0,40,63,0,0.000,3.600,0.000\n0,0,40,64,0,0.000,3.600,0.000\n0,0,40,78,0,0.000,3.600,0.000\n0,0,41,41,0,0.000,1.800,0.000\n0,0,41,55,0,0.000,4.800,0.000\n0,0,41,62,0,0.000,3.600,0.000\n0,0,41,80,0,0.000,1.800,0.000\n0,0,43,43,0,0.000,0.000,0.375\n0,0,43,45,0,0.000,3.600,0.000\n0,0,43,64,0,0.000,3.600,0.000\n0,0,44,57,0,0.000,7.000,0.000\n0,0,44,63,0,0.000,7.000,0.000\n0,0,44,65,0,0.000,7.000,0.000\n0,0,44,78,0,0.000,2.846,0.000\n0,0,44,80,0,0.000,2.846,0.000\n0,0,45,63,0,0.000,1.800,0.000\n0,0,45,64,0,0.000,1.800,0.000\n0,0,45,78,0,0.000,1.800,0.000\n0,0,55,57,0,0.000,10.000,0.000\n2,0,55,57,0,0.000,4.800,0.000\n5,0,55,57,0,0.000,4.800,0.000\n0,1,55,57,5,0.423,12.064,0.090\n0,1,55,57,55,-0.428,12.044,0.000\n0,36,55,57,5,-0.268,8.077,-0.806\n0,36,55,57,55,0.273,8.025,0.692\n0,0,55,62,0,0.000,3.600,0.000\n0,0,55,64,0,0.000,4.800,0.000\n0,0,55,80,0,0.000,4.800,0.000\n0,0,56,57,0,0.000,6.000,0.000\n0,1,56,57,56,0.000,6.886,-0.161\n0,36,56,57,56,0.000,4.688,0.107\n0,0,56,63,0,0.000,4.800,0.000\n0,0,56,80,0,0.000,4.800,0.000\n1,0,57,63,0,0.000,1.800,0.000\n1,0,57,64,0,0.000,1.800,0.000\n0,0,58,63,0,0.000,6.000,0.000\n0,0,58,64,0,0.000,6.000,0.000\n0,0,59,63,0,0.000,7.000,0.000\n0,0,59,65,0,0.000,7.000,0.000\n0,0,59,78,0,0.000,3.600,0.000\n0,0,59,80,0,0.000,3.600,0.000\n0,0,59,82,0,0.000,3.600,0.000\n0,0,62,63,0,0.000,3.600,0.000\n0,0,62,64,0,0.000,3.600,0.000\n1,0,63,63,0,0.000,1.800,0.000\n0,0,63,64,0,0.000,7.000,0.000\n0,5,63,64,5,0.000,7.000,0.000\n0,5,63,64,64,0.000,7.000,0.000\n0,39,63,64,5,0.000,7.000,0.000\n0,39,63,64,64,0.000,7.000,0.000\n0,0,63,66,0,0.000,7.000,0.000\n0,0,63,78,0,0.000,6.000,0.000\n0,0,63,81,0,0.000,6.000,0.000\n0,0,64,64,0,0.000,7.000,0.000\n1,0,64,64,0,0.000,1.800,0.000\n0,5,64,64,5,0.000,7.000,0.000\n0,5,64,64,63,0.000,7.000,0.000\n0,63,64,64,63,0.000,7.000,0.000\n0,0,64,65,0,0.000,7.000,0.000\n0,0,64,66,0,0.000,7.000,0.000\n0,0,64,78,0,0.000,6.000,0.000\n0,0,64,81,0,0.000,6.000,0.000\n5,0,64,81,0,0.000,6.000,0.000\n0,0,64,82,0,0.000,6.000,0.000\n0,0,65,66,0,0.000,7.000,0.000\n0,0,65,78,0,0.000,6.000,0.000\n0,0,65,81,0,0.000,6.000,0.000\n0,0,65,82,0,0.000,6.000,0.000\n0,0,66,66,0,0.000,7.000,0.000\n0,0,66,78,0,0.000,6.000,0.000\n0,0,66,81,0,0.000,6.000,0.000\n0,0,67,67,0,0.000,12.000,0.000\n5,0,67,67,0,0.000,12.000,0.000\n0,0,76,76,0,0.000,3.600,0.000\n0,0,76,78,0,0.000,3.600,0.000\n0,0,78,78,0,0.000,7.000,0.000\n0,0,78,79,0,0.000,6.000,0.000\n0,0,78,81,0,0.000,4.000,0.000\n0,0,79,79,0,0.000,6.000,0.000\n0,0,79,81,0,0.000,6.000,0.000\n0,0,80,81,0,0.000,4.000,0.000\n'));qlb.EG=true;}else if(Zkb.c5(a,Isb)&&!qlb.FG){ilb.Jz();ilb.Qz(Isb,new ilb.HA(Jsb,'926\nint,int,int,int,int,float,float,float\n0,0,1,1,0,0.000,0.000,0.300\n5,0,1,1,0,0.200,-0.800,1.500\n0,1,1,1,1,0.103,0.681,0.332\n5,1,1,1,1,0.144,-0.547,1.126\n0,1,1,1,2,-0.295,0.438,0.584\n0,1,1,1,3,0.066,-0.156,0.143\n0,1,1,1,5,0.639,-0.630,0.264\n0,1,1,1,6,-0.688,1.757,0.477\n5,1,1,1,6,0.000,0.000,0.054\n0,1,1,1,8,-1.420,-0.092,1.101\n5,1,1,1,8,0.000,-0.158,0.323\n0,1,1,1,11,0.593,0.662,1.120\n0,1,1,1,12,-0.678,0.417,0.624\n0,1,1,1,15,-0.714,0.698,0.000\n0,1,1,1,34,-0.647,0.550,0.590\n0,2,1,1,5,0.321,-0.411,0.144\n0,3,1,1,3,0.443,0.000,-1.140\n0,3,1,1,5,-0.256,0.058,0.000\n0,3,1,1,6,-0.679,-0.029,0.000\n0,5,1,1,5,0.284,-1.386,0.314\n0,5,1,1,6,-0.654,1.072,0.279\n0,5,1,1,8,-0.744,-1.235,0.337\n0,5,1,1,10,0.000,0.000,0.418\n0,5,1,1,11,0.000,0.516,0.291\n0,5,1,1,12,0.678,-0.602,0.398\n0,5,1,1,15,1.142,-0.644,0.367\n0,5,1,1,25,0.000,0.000,0.295\n0,5,1,1,34,0.692,-0.530,0.278\n0,5,1,1,37,0.000,0.000,0.389\n0,5,1,1,39,0.000,0.000,0.278\n0,5,1,1,41,0.000,0.000,-0.141\n0,5,1,1,56,0.000,0.000,0.324\n0,5,1,1,68,0.000,0.000,0.136\n0,6,1,1,6,0.408,1.397,0.961\n5,6,1,1,6,0.313,-1.035,1.631\n0,8,1,1,8,1.055,0.834,0.000\n0,11,1,1,11,-0.387,-0.543,1.405\n0,12,1,1,12,0.000,0.000,0.893\n0,15,1,1,15,-0.177,0.000,0.049\n0,0,1,2,0,0.000,0.000,0.000\n2,0,1,2,0,0.000,0.000,0.000\n5,0,1,2,0,0.000,0.000,0.000\n0,0,1,2,2,0.000,0.000,-0.650\n5,0,1,2,2,0.000,0.000,-0.650\n0,1,1,2,1,0.419,0.296,0.282\n0,1,1,2,2,-0.494,0.274,-0.630\n0,1,1,2,5,0.075,0.000,0.358\n0,2,1,2,2,-0.293,0.115,-0.508\n0,2,1,2,5,0.301,0.104,0.507\n0,3,1,2,1,0.565,-0.554,0.234\n0,3,1,2,2,-0.577,-0.482,-0.427\n0,3,1,2,5,0.082,0.000,0.123\n0,5,1,2,1,0.000,-0.184,0.220\n0,5,1,2,2,0.501,-0.410,-0.535\n2,5,1,2,2,0.000,0.000,0.055\n2,5,1,2,3,0.000,0.000,-0.108\n0,5,1,2,5,-0.523,-0.228,0.208\n2,5,1,2,37,0.000,0.000,0.000\n0,6,1,2,1,-0.467,0.000,0.490\n0,6,1,2,2,0.425,0.168,-0.875\n0,6,1,2,5,0.000,0.136,0.396\n0,8,1,2,1,-0.504,0.371,0.557\n0,8,1,2,2,0.541,0.539,-1.009\n0,8,1,2,5,0.000,0.204,0.464\n0,0,1,3,0,0.000,0.400,0.300\n2,0,1,3,0,0.000,0.500,0.350\n5,0,1,3,0,0.000,0.000,0.000\n0,0,1,3,1,0.000,0.000,0.550\n0,0,1,3,5,0.000,0.200,0.700\n0,0,1,3,7,0.000,0.400,0.400\n0,1,1,3,1,0.103,0.177,0.545\n0,1,1,3,5,-0.072,0.316,0.674\n0,1,1,3,6,-0.117,-0.333,0.202\n0,1,1,3,7,0.825,0.139,0.325\n0,1,1,3,10,-0.763,1.244,0.986\n0,2,1,3,5,0.663,-0.167,0.426\n0,2,1,3,7,-0.758,0.112,0.563\n0,5,1,3,1,-0.073,0.085,0.531\n2,5,1,3,2,0.000,0.000,0.115\n2,5,1,3,3,0.000,0.000,0.446\n0,5,1,3,5,-0.822,0.501,1.008\n0,5,1,3,6,0.000,-0.624,0.330\n0,5,1,3,7,0.659,-1.407,0.308\n0,5,1,3,10,-0.687,1.244,0.136\n2,5,1,3,37,0.000,0.000,0.056\n0,5,1,3,43,0.000,1.027,0.360\n0,5,1,3,51,0.000,1.543,0.350\n0,5,1,3,53,0.000,0.501,0.000\n0,5,1,3,74,0.000,0.513,-0.344\n0,5,1,3,75,0.000,0.511,-0.186\n0,6,1,3,6,0.447,0.652,0.318\n0,6,1,3,7,-0.395,0.730,-0.139\n0,10,1,3,7,0.530,2.905,2.756\n0,10,1,3,10,0.465,-0.241,1.850\n0,0,1,4,0,0.000,0.000,0.000\n0,0,1,6,0,0.000,0.000,0.200\n5,0,1,6,0,0.000,-0.200,0.400\n0,1,1,6,1,-0.681,0.755,0.755\n5,1,1,6,1,0.000,0.243,-0.596\n0,1,1,6,3,-0.547,0.000,0.320\n0,1,1,6,21,0.000,0.270,0.237\n0,2,1,6,21,0.102,0.460,-0.128\n0,3,1,6,21,-1.652,-1.660,0.283\n0,5,1,6,1,0.571,0.319,0.570\n0,5,1,6,2,0.000,0.000,0.306\n0,5,1,6,3,0.572,0.000,-0.304\n0,5,1,6,21,0.596,-0.276,0.346\n0,5,1,6,25,0.000,0.000,0.061\n0,5,1,6,37,0.000,0.000,0.106\n0,5,1,6,45,0.000,0.000,-0.174\n0,6,1,6,1,0.229,-0.710,0.722\n5,6,1,6,1,0.000,0.000,0.040\n0,6,1,6,21,1.488,-3.401,-0.320\n0,37,1,6,21,0.712,1.320,-0.507\n0,0,1,8,0,0.000,-0.300,0.500\n5,0,1,8,0,0.000,0.000,0.297\n0,1,1,8,1,-0.439,0.786,0.272\n5,1,1,8,1,0.115,-0.390,0.658\n0,1,1,8,6,-0.608,0.339,1.496\n0,1,1,8,23,-0.428,0.323,0.280\n0,2,1,8,23,0.594,-0.409,0.155\n0,5,1,8,1,0.393,-0.385,0.562\n0,5,1,8,6,0.598,-0.158,0.399\n0,5,1,8,23,-0.152,-0.440,0.357\n0,0,1,9,0,0.000,0.000,0.000\n5,0,1,9,0,0.000,0.000,0.000\n0,5,1,9,3,0.204,-0.335,-0.352\n0,5,1,9,53,0.000,0.000,0.097\n0,0,1,10,0,0.000,0.000,0.300\n5,0,1,10,0,0.000,0.000,0.000\n0,0,1,10,3,0.000,0.000,1.000\n0,1,1,10,3,-0.884,0.578,0.818\n0,1,1,10,6,0.000,-0.379,0.565\n0,1,1,10,28,0.750,-0.404,0.369\n0,3,1,10,3,3.219,-2.699,1.875\n0,3,1,10,28,0.207,0.461,0.324\n0,5,1,10,1,0.000,0.000,0.706\n0,5,1,10,3,-2.334,1.517,-0.065\n0,5,1,10,6,0.000,0.688,0.665\n0,5,1,10,28,-0.982,-0.207,0.166\n0,0,1,15,0,0.000,0.000,0.400\n5,0,1,15,0,0.000,0.000,0.336\n0,1,1,15,1,-1.047,0.170,0.398\n0,1,1,15,15,-1.438,0.263,0.501\n0,1,1,15,71,-0.376,-0.133,0.288\n0,5,1,15,1,1.143,-0.231,0.447\n0,5,1,15,15,1.555,-0.323,0.456\n0,5,1,15,37,0.000,0.000,0.459\n0,5,1,15,71,0.229,0.203,0.440\n0,0,1,17,0,0.000,0.000,0.350\n5,0,1,17,0,0.000,0.000,0.000\n0,5,1,17,1,0.000,0.000,0.536\n0,5,1,17,7,0.000,0.000,0.212\n0,0,1,18,0,0.000,0.000,0.100\n5,0,1,18,0,0.000,0.000,0.112\n0,5,1,18,1,0.000,0.000,0.000\n0,5,1,18,6,0.000,0.000,0.099\n0,5,1,18,32,0.000,0.585,0.388\n0,5,1,18,43,0.000,-0.412,0.121\n0,5,1,18,48,0.000,0.000,0.195\n0,5,1,18,62,0.000,0.000,-0.088\n0,0,1,19,0,0.000,0.000,0.150\n5,0,1,19,0,0.000,0.000,0.179\n0,5,1,19,5,0.000,0.000,0.196\n0,5,1,19,6,0.000,0.000,0.176\n0,5,1,19,12,0.000,0.000,0.152\n0,0,1,20,0,0.000,0.000,0.350\n5,0,1,20,0,0.000,0.000,0.350\n0,5,1,20,5,0.000,0.000,0.344\n0,5,1,20,20,0.000,0.000,0.361\n0,0,1,22,0,0.000,0.000,0.236\n5,0,1,22,0,0.000,0.000,0.236\n0,0,1,25,0,0.000,0.000,0.300\n5,0,1,25,0,0.000,0.000,0.251\n0,1,1,25,1,0.000,-0.207,0.232\n0,1,1,25,32,0.000,0.288,0.218\n0,5,1,25,1,0.000,0.152,0.235\n0,5,1,25,6,0.000,0.000,0.495\n0,5,1,25,32,0.000,-0.130,0.214\n0,5,1,25,43,0.000,0.000,0.466\n0,5,1,25,72,0.000,0.000,0.243\n0,0,1,26,0,0.000,0.000,0.450\n5,0,1,26,0,0.000,0.000,0.376\n0,5,1,26,12,0.000,0.000,0.439\n0,5,1,26,71,0.000,0.000,0.472\n0,0,1,34,0,0.000,0.000,0.250\n5,0,1,34,0,0.000,0.000,0.198\n0,1,1,34,36,0.000,0.000,0.187\n0,5,1,34,1,0.000,0.000,0.247\n0,5,1,34,36,0.000,0.000,0.259\n0,0,1,37,0,0.000,0.000,0.200\n5,0,1,37,0,0.000,0.000,0.000\n0,1,1,37,37,0.000,0.449,0.000\n0,5,1,37,37,0.000,-0.420,0.391\n0,6,1,37,37,0.000,0.000,0.150\n0,0,1,39,0,0.000,0.000,0.000\n5,0,1,39,0,0.000,0.000,0.000\n0,1,1,39,63,0.000,-0.080,-0.056\n0,5,1,39,63,0.000,0.000,-0.113\n0,0,1,40,0,0.000,0.000,0.250\n5,0,1,40,0,0.000,0.000,0.297\n0,5,1,40,28,0.000,-0.105,0.000\n0,5,1,40,37,0.000,0.000,0.468\n0,0,1,41,0,0.000,0.600,0.000\n0,1,1,41,32,0.000,1.263,0.000\n0,5,1,41,32,0.000,0.000,-0.106\n0,5,1,41,72,0.000,0.632,0.000\n0,0,1,43,0,0.000,0.000,0.150\n5,0,1,43,0,0.000,0.000,0.297\n0,5,1,43,18,0.357,-0.918,0.000\n0,5,1,43,25,0.000,0.000,0.061\n0,5,1,43,28,-0.249,0.382,0.343\n0,0,1,45,0,0.000,0.000,0.100\n0,5,1,45,32,0.000,0.000,0.125\n0,0,1,46,0,0.000,0.000,-0.500\n0,5,1,46,7,0.000,0.000,-0.540\n0,0,1,54,0,0.000,0.000,0.000\n2,0,1,54,0,0.000,0.000,0.000\n5,0,1,54,0,0.000,0.000,0.000\n0,5,1,54,3,0.000,0.000,-0.315\n0,5,1,54,36,0.000,0.000,0.315\n0,0,1,55,0,0.000,0.000,0.000\n5,0,1,55,0,0.000,0.000,0.000\n0,5,1,55,36,0.000,-0.058,0.084\n0,5,1,55,57,0.000,-0.058,-0.092\n0,0,1,56,0,0.000,0.000,-0.300\n0,1,1,56,36,0.875,0.668,-0.015\n0,1,1,56,57,-0.870,0.775,-0.406\n0,5,1,56,36,-0.958,-0.629,-0.372\n0,5,1,56,57,0.952,-0.715,-0.483\n0,0,1,57,0,0.000,0.000,0.000\n5,0,1,57,0,0.000,0.000,0.000\n0,0,1,58,0,0.000,0.000,0.000\n0,0,1,62,0,0.000,0.000,0.250\n0,5,1,62,18,0.000,0.000,0.270\n0,0,1,63,0,0.000,0.000,0.000\n5,0,1,63,0,0.000,0.000,0.000\n0,0,1,64,0,0.000,0.000,0.000\n5,0,1,64,0,0.000,0.000,0.000\n0,0,1,67,0,0.000,0.000,0.000\n5,0,1,67,0,0.000,0.000,0.000\n0,0,1,68,0,0.000,0.000,0.400\n0,1,1,68,1,-0.117,0.090,0.751\n0,1,1,68,23,0.373,0.153,0.635\n0,1,1,68,32,-0.090,-0.169,0.075\n0,5,1,68,1,0.134,-0.112,0.329\n0,5,1,68,23,-0.361,-0.202,0.560\n0,5,1,68,32,0.072,0.218,0.093\n0,0,1,73,0,0.000,0.000,0.500\n0,5,1,73,32,0.000,0.000,0.509\n0,5,1,73,72,0.000,0.000,0.443\n0,0,1,75,0,0.000,0.000,0.000\n0,0,1,78,0,0.000,0.000,0.000\n0,0,1,80,0,0.000,0.000,0.000\n0,0,1,81,0,0.000,0.000,0.000\n0,0,2,2,0,0.000,12.000,0.000\n1,0,2,2,0,0.000,1.800,0.000\n5,0,2,2,0,0.000,12.000,0.000\n0,1,2,2,1,-0.403,12.000,0.000\n0,1,2,2,2,0.000,12.000,0.000\n1,1,2,2,2,-0.418,2.089,-0.310\n0,1,2,2,5,0.000,12.000,0.000\n1,1,2,2,5,0.412,2.120,0.269\n1,2,2,2,2,0.094,1.621,0.877\n0,2,2,2,5,0.000,12.000,0.000\n1,2,2,2,5,0.317,1.421,-0.870\n0,3,2,2,5,0.000,12.000,0.000\n0,5,2,2,5,0.000,12.000,0.000\n1,5,2,2,5,-0.406,1.767,0.000\n0,5,2,2,6,0.000,12.000,0.000\n0,5,2,2,37,0.000,12.000,0.000\n0,5,2,2,40,0.000,12.000,0.000\n0,5,2,2,41,0.000,12.000,0.000\n0,5,2,2,45,0.000,12.000,0.000\n0,5,2,2,62,0.000,12.000,0.000\n1,0,2,3,0,0.000,2.500,0.000\n1,1,2,3,1,0.136,1.798,0.630\n1,1,2,3,5,0.497,2.405,0.357\n1,1,2,3,6,-0.211,1.925,-0.131\n1,1,2,3,7,-0.401,2.028,-0.318\n1,1,2,3,10,0.000,2.237,-0.610\n1,2,2,3,1,-0.325,1.553,-0.487\n1,2,2,3,5,-0.295,2.024,-0.590\n1,2,2,3,6,-0.143,1.466,0.000\n1,2,2,3,7,0.362,1.978,0.000\n1,2,2,3,9,0.296,1.514,0.481\n1,2,2,3,10,0.000,1.599,0.380\n1,5,2,3,1,0.213,1.728,-0.042\n1,5,2,3,5,-0.208,1.622,0.223\n1,5,2,3,6,0.359,1.539,0.194\n1,5,2,3,7,0.000,2.046,0.000\n1,5,2,3,9,-0.290,1.519,-0.470\n1,5,2,3,10,0.000,1.409,0.254\n1,0,2,4,0,0.000,0.000,0.000\n0,0,2,6,0,0.000,3.100,0.000\n2,0,2,6,0,0.000,3.600,0.000\n5,0,2,6,0,0.000,3.600,0.000\n0,2,2,6,1,-1.953,3.953,-1.055\n0,2,2,6,3,-1.712,2.596,-0.330\n0,2,2,6,29,-0.215,2.810,-0.456\n0,5,2,6,1,1.951,3.936,1.130\n0,5,2,6,3,1.719,2.628,0.360\n0,5,2,6,29,0.216,2.808,0.456\n1,0,2,9,0,0.000,1.800,0.000\n0,0,2,10,0,0.000,6.000,0.000\n2,0,2,10,0,0.000,6.000,0.000\n5,0,2,10,0,0.000,6.000,0.000\n0,0,2,15,0,0.000,1.423,0.000\n2,0,2,15,0,0.000,1.423,0.000\n5,0,2,15,0,0.000,1.423,0.000\n0,0,2,17,0,0.000,1.423,0.000\n0,0,2,18,0,0.000,0.000,0.000\n2,0,2,18,0,0.000,0.000,0.000\n5,0,2,18,0,0.000,0.000,0.000\n0,0,2,19,0,0.000,0.000,0.000\n0,0,2,20,0,0.000,0.000,0.000\n2,0,2,20,0,0.000,0.000,0.000\n0,0,2,22,0,0.000,0.000,0.000\n2,0,2,22,0,0.000,0.000,0.000\n5,0,2,22,0,0.000,0.000,0.000\n0,0,2,25,0,0.000,0.000,0.000\n0,0,2,30,0,0.000,12.000,0.000\n0,0,2,34,0,0.000,0.000,0.000\n2,0,2,34,0,0.000,0.000,0.000\n1,0,2,37,0,0.000,2.000,0.000\n1,1,2,37,37,0.000,2.952,-0.079\n1,2,2,37,37,0.000,1.542,0.434\n1,5,2,37,37,0.000,1.308,-0.357\n1,0,2,39,0,0.000,6.000,0.000\n0,0,2,40,0,0.000,3.700,0.000\n2,0,2,40,0,0.000,3.600,0.000\n5,0,2,40,0,0.000,3.600,0.000\n0,2,2,40,28,0.000,3.305,-0.530\n0,5,2,40,28,0.139,3.241,0.139\n0,0,2,41,0,0.000,1.200,0.000\n2,0,2,41,0,0.000,1.800,0.000\n0,2,2,41,32,0.000,1.235,0.000\n0,5,2,41,32,0.000,1.231,0.000\n0,0,2,43,0,0.000,3.600,0.000\n2,0,2,43,0,0.000,3.600,0.000\n0,0,2,45,0,0.000,2.200,0.000\n2,0,2,45,0,0.000,1.800,0.000\n0,2,2,45,32,0.000,2.212,0.000\n0,5,2,45,32,0.000,2.225,0.000\n0,0,2,46,0,0.000,1.800,0.000\n2,0,2,46,0,0.000,1.800,0.000\n0,0,2,55,0,0.000,4.800,0.000\n0,0,2,56,0,0.000,4.800,0.000\n0,0,2,62,0,0.000,8.000,0.000\n0,2,2,62,23,1.693,7.903,0.532\n0,5,2,62,23,-1.696,7.897,-0.482\n1,0,2,63,0,0.000,1.800,0.000\n1,0,2,64,0,0.000,1.800,0.000\n1,0,2,67,0,0.000,1.800,0.000\n1,0,2,81,0,0.000,4.800,0.000\n1,0,3,3,0,0.000,0.600,0.000\n4,0,3,3,0,0.000,1.800,0.000\n1,1,3,3,1,-0.486,0.714,0.000\n1,1,3,3,6,-0.081,-0.125,0.132\n1,1,3,3,7,1.053,1.327,0.000\n1,5,3,3,6,0.000,0.188,0.436\n1,5,3,3,7,0.000,0.177,-0.412\n1,6,3,3,6,0.269,0.437,0.000\n1,6,3,3,7,-0.495,0.793,-0.318\n1,7,3,3,7,-0.260,1.084,0.193\n0,0,3,6,0,0.000,5.500,0.000\n2,0,3,6,0,0.000,5.500,0.000\n4,0,3,6,0,0.000,3.600,0.000\n5,0,3,6,0,0.000,3.600,0.000\n0,1,3,6,1,-1.244,5.482,0.365\n0,1,3,6,24,-1.166,5.078,-0.545\n0,1,3,6,37,-0.677,5.854,0.521\n2,2,3,6,24,0.256,4.519,0.258\n2,3,3,6,24,1.663,4.073,0.094\n0,5,3,6,1,0.526,5.631,0.691\n0,5,3,6,2,0.159,6.586,0.216\n0,5,3,6,24,-2.285,4.737,0.468\n0,7,3,6,0,0.700,6.500,-0.400\n0,7,3,6,1,0.682,7.184,-0.935\n0,7,3,6,2,-0.168,6.572,-0.151\n0,7,3,6,24,1.662,6.152,-0.058\n0,7,3,6,37,0.635,5.890,-0.446\n2,37,3,6,24,0.000,3.892,-0.094\n0,0,3,9,0,0.000,16.000,0.000\n1,0,3,9,0,0.000,1.800,0.000\n5,0,3,9,0,0.000,12.000,0.000\n0,2,3,9,27,0.000,16.000,0.000\n0,5,3,9,1,0.687,16.152,0.894\n0,5,3,9,27,0.000,16.000,0.000\n0,40,3,9,1,-0.704,18.216,0.000\n0,40,3,9,27,0.000,16.000,0.178\n0,0,3,10,0,0.000,6.000,0.000\n2,0,3,10,0,0.000,6.000,0.000\n4,0,3,10,0,0.000,6.000,0.000\n5,0,3,10,0,0.000,6.000,0.000\n0,1,3,10,1,0.831,6.061,0.522\n0,1,3,10,6,-1.152,8.588,1.511\n0,1,3,10,28,-0.259,5.934,1.326\n2,2,3,10,28,0.000,6.561,0.294\n0,5,3,10,1,-0.195,6.304,1.722\n0,5,3,10,3,-0.705,5.383,0.234\n0,5,3,10,28,-0.417,5.981,0.511\n0,7,3,10,1,-0.491,6.218,0.000\n0,7,3,10,3,0.733,-0.543,-0.163\n0,7,3,10,6,1.234,8.372,-0.539\n0,7,3,10,28,1.168,4.857,-0.341\n0,10,3,10,28,0.000,3.706,1.254\n0,0,3,15,0,0.000,1.423,0.000\n2,0,3,15,0,0.000,1.423,0.000\n4,0,3,15,0,0.000,1.423,0.000\n5,0,3,15,0,0.000,1.423,0.000\n0,0,3,17,0,0.000,1.423,0.000\n5,0,3,17,0,0.000,1.423,0.000\n0,0,3,18,0,0.000,0.000,0.000\n2,0,3,18,0,0.000,0.000,0.000\n0,0,3,20,0,0.000,0.000,-0.300\n2,0,3,20,0,0.000,0.000,0.000\n4,0,3,20,0,0.000,0.000,-0.300\n5,0,3,20,0,0.000,0.000,0.000\n0,7,3,20,0,0.000,0.400,0.400\n0,7,3,20,5,0.000,0.000,-0.131\n0,7,3,20,20,0.000,0.000,0.000\n0,20,3,20,5,0.000,0.000,0.085\n0,20,3,20,20,0.000,0.000,0.000\n0,0,3,22,0,0.000,0.000,0.000\n2,0,3,22,0,0.000,0.000,0.000\n4,0,3,22,0,0.000,0.000,0.000\n5,0,3,22,0,0.000,0.000,0.000\n0,7,3,22,0,0.000,0.400,0.400\n0,0,3,25,0,0.000,0.000,0.000\n2,0,3,25,0,0.000,0.000,0.000\n1,0,3,30,0,0.000,1.800,0.000\n4,0,3,30,0,0.000,1.800,0.000\n1,0,3,37,0,0.000,2.500,0.000\n4,0,3,37,0,0.000,1.800,0.000\n1,1,3,37,37,0.000,2.428,0.000\n1,6,3,37,37,0.000,1.743,0.000\n1,7,3,37,37,0.000,2.256,0.000\n1,43,3,37,37,-0.241,3.385,-0.838\n1,0,3,39,0,0.000,5.500,0.000\n0,0,3,40,0,0.000,3.900,0.000\n2,0,3,40,0,0.000,3.600,0.000\n5,0,3,40,0,0.000,3.600,0.000\n0,5,3,40,28,-1.355,3.964,0.800\n0,9,3,40,28,1.045,3.785,-0.291\n0,40,3,40,28,0.508,2.985,0.809\n0,0,3,41,0,0.000,1.800,0.000\n2,0,3,41,0,0.000,1.800,0.000\n0,0,3,43,0,0.000,4.500,0.000\n2,0,3,43,0,0.000,3.600,0.000\n4,0,3,43,0,0.000,3.600,0.000\n5,0,3,43,0,0.000,3.600,0.000\n0,1,3,43,18,1.712,3.309,0.233\n0,1,3,43,28,-0.414,4.168,-0.875\n0,7,3,43,18,-0.880,5.091,-0.129\n0,7,3,43,28,0.536,5.276,-0.556\n2,37,3,43,18,-0.701,4.871,1.225\n2,37,3,43,28,-0.086,5.073,0.878\n0,0,3,45,0,0.000,1.800,0.000\n2,0,3,45,0,0.000,1.800,0.000\n0,0,3,48,0,0.000,0.000,0.892\n0,0,3,51,0,0.000,13.500,0.000\n0,1,3,51,52,0.000,13.549,0.000\n0,0,3,54,0,0.000,8.000,0.000\n1,0,3,54,0,0.000,2.500,0.000\n5,0,3,54,0,0.000,12.000,0.000\n0,5,3,54,1,0.000,8.000,0.000\n0,5,3,54,36,0.000,8.000,0.000\n0,0,3,55,0,0.000,4.800,0.000\n2,0,3,55,0,0.000,4.800,0.000\n0,0,3,56,0,0.000,4.800,0.000\n2,0,3,56,0,0.000,4.800,0.000\n1,0,3,57,0,0.000,2.500,0.000\n1,0,3,58,0,0.000,4.800,0.000\n0,0,3,62,0,0.000,3.600,0.000\n2,0,3,62,0,0.000,3.600,0.000\n5,0,3,62,0,0.000,3.600,0.000\n1,0,3,63,0,0.000,2.500,0.000\n1,0,3,64,0,0.000,2.500,0.000\n0,0,3,67,0,0.000,12.000,0.000\n0,0,3,74,0,0.000,19.000,0.000\n0,1,3,74,7,0.000,19.349,0.000\n0,0,3,75,0,0.000,19.000,0.000\n0,1,3,75,71,0.000,18.751,0.000\n1,0,3,78,0,0.000,2.500,0.000\n1,0,3,80,0,0.000,2.500,0.000\n0,0,6,6,0,0.000,-2.000,0.000\n5,0,6,6,0,0.000,-2.000,0.000\n0,0,6,8,0,0.900,-1.100,-0.500\n5,0,6,8,0,0.000,0.000,0.274\n0,21,6,8,1,0.261,-0.330,-0.542\n0,21,6,8,23,1.503,-1.853,-0.476\n0,0,6,9,0,0.000,3.600,0.000\n5,0,6,9,0,0.000,3.600,0.000\n0,0,6,10,0,1.200,0.500,-1.000\n0,21,6,10,1,0.829,0.000,-0.730\n0,21,6,10,3,0.675,-0.185,-1.053\n0,0,6,15,0,0.000,-4.000,0.000\n0,0,6,17,0,0.000,1.423,0.000\n5,0,6,17,0,0.000,1.423,0.000\n0,0,6,18,0,0.000,0.000,0.100\n5,0,6,18,0,0.000,0.000,0.103\n0,33,6,18,1,-0.520,-0.471,-0.267\n0,33,6,18,6,-1.623,0.204,0.438\n0,33,6,18,32,1.616,0.425,0.191\n0,0,6,19,0,0.000,0.000,0.150\n5,0,6,19,0,0.000,0.000,0.165\n0,21,6,19,1,-0.620,-0.329,0.303\n0,21,6,19,5,0.683,0.220,0.000\n0,0,6,20,0,0.000,0.000,0.400\n4,0,6,20,0,0.000,0.000,0.217\n5,0,6,20,0,0.000,0.000,0.217\n0,20,6,20,5,0.000,0.000,-0.079\n4,20,6,20,20,0.000,0.000,0.000\n0,0,6,22,0,0.000,0.000,0.217\n0,0,6,25,0,0.000,0.000,0.650\n5,0,6,25,0,0.000,0.000,0.231\n0,1,6,25,1,-1.704,-0.452,0.556\n0,1,6,25,6,0.000,0.000,0.777\n0,1,6,25,32,1.205,0.914,0.612\n0,24,6,25,6,-3.209,-7.622,1.065\n0,24,6,25,32,-5.891,-3.332,0.290\n0,0,6,26,0,0.000,0.000,0.346\n0,0,6,30,0,0.000,3.600,0.000\n2,0,6,30,0,0.000,3.600,0.000\n0,0,6,37,0,0.000,3.200,0.000\n5,0,6,37,0,0.000,3.600,0.000\n0,1,6,37,37,0.000,4.382,0.000\n0,3,6,37,37,0.000,2.576,0.000\n0,29,6,37,37,0.000,2.801,0.000\n0,0,6,39,0,0.000,0.000,0.000\n0,0,6,40,0,0.000,0.000,0.274\n0,0,6,41,0,0.000,3.600,0.000\n0,0,6,43,0,0.000,0.000,0.274\n0,0,6,45,0,0.000,6.000,0.000\n0,1,6,45,32,0.000,6.208,0.000\n0,0,6,54,0,0.000,3.600,0.000\n0,0,6,55,0,0.000,3.600,0.000\n0,0,6,57,0,0.000,3.600,0.000\n0,0,6,58,0,0.000,3.600,0.000\n0,0,6,63,0,0.000,3.600,0.000\n0,0,6,64,0,0.000,3.600,0.000\n0,0,8,8,0,0.000,0.000,0.375\n5,0,8,8,0,0.000,0.000,0.375\n0,0,8,9,0,0.000,3.600,0.000\n5,0,8,9,0,0.000,3.600,0.000\n0,0,8,10,0,0.000,0.000,0.000\n4,0,8,10,0,0.000,0.000,0.000\n0,0,8,15,0,0.000,0.000,0.424\n0,0,8,17,0,0.000,1.423,0.000\n4,0,8,17,0,0.000,1.423,0.000\n5,0,8,17,0,0.000,1.423,0.000\n0,0,8,19,0,0.000,0.000,0.225\n0,0,8,20,0,0.000,0.000,0.350\n4,0,8,20,0,0.000,0.000,0.300\n5,0,8,20,0,0.000,0.000,0.297\n0,20,8,20,5,0.000,0.120,0.472\n4,20,8,20,20,0.000,-0.097,0.200\n0,23,8,20,5,-0.101,-0.324,0.371\n0,23,8,20,20,0.107,0.253,0.151\n0,0,8,22,0,0.000,0.000,0.297\n0,0,8,25,0,0.000,0.000,0.316\n5,0,8,25,0,0.000,0.000,0.316\n0,0,8,26,0,0.000,0.000,0.474\n5,0,8,26,0,0.000,0.000,0.474\n0,0,8,34,0,0.000,0.000,0.250\n0,0,8,39,0,0.000,0.000,0.000\n0,0,8,40,0,0.000,0.000,0.375\n0,0,8,43,0,0.000,0.000,0.375\n0,0,8,45,0,0.000,3.600,0.000\n0,0,8,46,0,0.000,3.600,0.000\n0,0,8,55,0,0.000,3.600,0.000\n0,0,8,56,0,0.000,3.600,0.000\n0,0,9,9,0,0.000,12.000,0.000\n1,0,9,9,0,0.000,1.800,0.000\n5,0,9,9,0,0.000,12.000,0.000\n0,0,9,10,0,0.000,6.000,0.000\n5,0,9,10,0,0.000,6.000,0.000\n0,0,9,15,0,0.000,1.423,0.000\n0,0,9,18,0,0.000,0.000,0.000\n0,0,9,19,0,0.000,0.000,0.000\n0,0,9,20,0,0.000,0.000,0.000\n0,0,9,25,0,0.000,0.000,0.000\n0,0,9,34,0,0.000,0.000,0.000\n5,0,9,34,0,0.000,0.000,0.000\n1,0,9,37,0,0.000,1.800,0.000\n1,0,9,39,0,0.000,6.000,0.000\n0,0,9,40,0,0.000,3.600,0.000\n0,0,9,41,0,0.000,4.800,0.000\n0,0,9,45,0,0.000,1.800,0.000\n0,0,9,54,0,0.000,12.000,0.000\n0,0,9,55,0,0.000,4.800,0.000\n0,0,9,56,0,0.000,4.800,0.000\n1,0,9,57,0,0.000,1.800,0.000\n0,0,9,62,0,0.000,3.600,0.000\n1,0,9,63,0,0.000,1.800,0.000\n1,0,9,64,0,0.000,1.800,0.000\n0,0,9,67,0,0.000,12.000,0.000\n1,0,9,78,0,0.000,1.800,0.000\n1,0,9,81,0,0.000,4.800,0.000\n0,0,10,10,0,0.000,0.000,0.000\n5,0,10,10,0,0.000,0.000,0.000\n0,0,10,15,0,0.000,0.000,0.000\n0,0,10,17,0,0.000,4.743,0.000\n0,0,10,20,0,0.000,0.000,0.000\n4,0,10,20,0,0.000,0.000,0.000\n5,0,10,20,0,0.000,0.000,0.000\n0,0,10,22,0,0.000,0.000,0.000\n0,0,10,25,0,0.000,0.000,0.000\n0,0,10,26,0,0.000,0.000,0.000\n5,0,10,26,0,0.000,0.000,0.000\n0,0,10,34,0,0.000,0.000,0.000\n0,0,10,37,0,0.000,6.000,0.000\n0,0,10,39,0,0.000,0.000,0.000\n0,0,10,40,0,0.000,0.000,0.000\n5,0,10,40,0,0.000,0.000,0.000\n0,0,10,41,0,0.000,6.000,0.000\n0,0,10,45,0,0.000,6.000,0.000\n0,0,10,63,0,0.000,6.000,0.000\n0,0,10,64,0,0.000,6.000,0.000\n0,0,15,15,0,-1.400,-8.300,1.000\n5,0,15,15,0,0.000,-8.000,0.000\n0,1,15,15,1,-1.663,-8.408,1.433\n0,1,15,15,71,-1.088,-8.245,0.411\n0,0,15,18,0,0.000,0.000,0.160\n0,0,15,19,0,0.000,0.000,0.255\n5,0,15,19,0,0.000,0.000,0.255\n0,0,15,20,0,0.000,0.000,0.336\n4,0,15,20,0,0.000,0.000,0.336\n0,0,15,22,0,0.000,0.000,0.336\n0,0,15,25,0,0.000,0.000,0.358\n4,0,15,25,0,0.000,0.000,0.358\n0,0,15,26,0,0.000,0.000,0.537\n0,0,15,30,0,0.000,1.423,0.000\n4,0,15,30,0,0.000,1.423,0.000\n0,0,15,37,0,0.000,1.300,0.000\n5,0,15,37,0,0.000,1.423,0.000\n0,1,15,37,37,0.000,2.177,0.000\n0,71,15,37,37,0.000,0.505,0.333\n0,0,15,40,0,0.000,0.000,0.424\n0,0,15,43,0,0.000,0.000,0.424\n0,0,15,57,0,0.000,1.423,0.000\n0,0,15,63,0,0.000,1.423,0.000\n0,0,15,64,0,0.000,1.423,0.000\n0,0,17,20,0,0.000,0.000,0.000\n4,0,17,20,0,0.000,0.000,0.000\n5,0,17,20,0,0.000,0.000,0.000\n0,0,17,22,0,0.000,0.000,0.000\n0,0,17,37,0,0.000,1.423,0.000\n0,0,17,43,0,0.000,3.795,0.000\n0,0,18,20,0,0.000,0.000,0.112\n4,0,18,20,0,0.000,0.000,0.112\n5,0,18,20,0,0.000,0.000,0.112\n0,0,18,22,0,0.000,0.000,0.112\n0,0,18,37,0,0.000,-1.200,-0.300\n0,32,18,37,37,-0.173,-0.965,-0.610\n0,39,18,37,37,0.000,-0.760,0.227\n0,43,18,37,37,0.228,-1.741,-0.371\n0,0,18,39,0,0.000,0.000,0.500\n0,32,18,39,63,0.000,0.687,0.680\n0,37,18,39,63,0.000,-0.513,0.357\n0,0,18,43,0,0.000,0.000,0.350\n4,0,18,43,0,0.000,0.000,0.141\n5,0,18,43,0,0.000,0.000,0.141\n0,1,18,43,1,-0.914,-0.482,0.179\n0,1,18,43,3,-0.392,-2.724,0.312\n0,1,18,43,28,-1.508,-1.816,-0.175\n0,1,18,43,37,0.823,-1.220,-0.770\n0,32,18,43,1,1.588,1.499,1.410\n0,32,18,43,3,0.653,0.254,0.000\n0,32,18,43,28,0.528,0.342,0.000\n0,32,18,43,37,0.812,1.513,1.266\n0,37,18,43,1,-1.139,-0.703,1.088\n0,37,18,43,28,-2.014,-1.646,-2.068\n0,37,18,43,37,-1.519,-0.328,1.437\n0,43,18,43,28,3.011,-1.405,2.038\n0,0,18,48,0,0.000,0.000,0.400\n0,1,18,48,28,1.767,1.606,0.408\n0,32,18,48,28,-1.463,-2.548,0.310\n0,0,18,55,0,0.000,0.000,0.000\n0,0,18,58,0,0.000,0.000,0.000\n0,0,18,62,0,0.000,0.000,0.500\n0,1,18,62,1,-0.403,-0.273,0.440\n0,32,18,62,1,0.291,0.385,0.582\n0,0,18,63,0,0.000,0.000,0.000\n0,0,18,64,0,0.000,0.000,0.000\n0,0,18,80,0,0.000,0.000,0.000\n0,0,19,20,0,0.000,0.000,0.179\n4,0,19,20,0,0.000,0.000,0.179\n0,0,19,37,0,0.000,0.000,0.000\n0,0,19,40,0,0.000,0.000,0.225\n0,0,19,63,0,0.000,0.000,0.000\n0,0,19,75,0,0.000,0.000,0.000\n0,0,20,20,0,0.000,0.000,0.200\n4,0,20,20,0,0.000,0.000,0.000\n5,0,20,20,0,0.000,0.000,0.236\n0,1,20,20,5,0.067,0.081,0.347\n0,1,20,20,20,-0.063,-0.064,0.140\n0,3,20,20,5,0.000,0.000,0.083\n0,3,20,20,20,0.000,0.000,0.000\n0,5,20,20,5,0.000,0.000,0.424\n0,5,20,20,6,0.000,0.000,-0.080\n0,5,20,20,8,0.000,0.127,0.450\n0,5,20,20,12,-0.072,-0.269,0.439\n0,5,20,20,20,-0.057,0.000,0.307\n4,6,20,20,20,0.000,0.000,0.000\n4,8,20,20,20,0.000,-0.091,0.192\n0,12,20,20,20,0.077,0.202,0.183\n4,20,20,20,20,0.000,0.000,0.000\n0,0,20,22,0,0.000,0.000,0.236\n4,0,20,22,0,0.000,0.000,0.236\n0,0,20,25,0,0.000,0.000,0.251\n4,0,20,25,0,0.000,0.000,0.251\n0,0,20,26,0,0.000,0.000,0.376\n4,0,20,26,0,0.000,0.000,0.376\n5,0,20,26,0,0.000,0.000,0.376\n0,0,20,30,0,0.000,0.000,0.000\n2,0,20,30,0,0.000,0.000,0.000\n4,0,20,30,0,0.000,0.000,0.000\n0,0,20,30,30,0.000,0.000,-0.500\n0,0,20,34,0,0.000,0.000,0.198\n4,0,20,34,0,0.000,0.000,0.198\n0,0,20,37,0,0.000,0.000,0.000\n4,0,20,37,0,0.000,0.000,0.000\n0,0,20,40,0,0.000,0.000,0.297\n0,0,20,41,0,0.000,0.000,0.000\n0,0,20,43,0,0.000,0.000,0.297\n4,0,20,43,0,0.000,0.000,0.297\n0,0,20,45,0,0.000,0.000,0.000\n0,0,22,22,0,0.000,0.000,0.236\n4,0,22,22,0,0.000,0.000,0.236\n5,0,22,22,0,0.000,0.000,0.236\n0,0,22,30,0,0.000,0.000,0.000\n4,0,22,30,0,0.000,0.000,0.000\n0,0,22,34,0,0.000,0.000,0.198\n0,0,22,37,0,0.000,0.000,0.000\n0,0,22,40,0,0.000,0.000,0.297\n0,0,22,41,0,0.000,0.000,0.000\n0,0,22,43,0,0.000,0.000,0.297\n5,0,22,43,0,0.000,0.000,0.297\n0,0,22,45,0,0.000,0.000,0.000\n0,0,25,25,0,0.000,0.000,0.267\n0,0,25,37,0,0.000,0.000,0.000\n5,0,25,37,0,0.000,0.000,0.000\n0,0,25,39,0,0.000,0.000,0.000\n0,0,25,40,0,0.000,0.000,0.316\n5,0,25,40,0,0.000,0.000,0.316\n0,0,25,43,0,0.000,0.000,0.250\n0,1,25,43,1,-2.686,-1.512,0.591\n0,1,25,43,28,-3.730,-0.531,0.000\n0,32,25,43,1,2.108,1.896,0.965\n0,32,25,43,28,2.977,0.732,-0.502\n0,0,25,57,0,0.000,0.000,0.000\n0,0,25,63,0,0.000,0.000,0.000\n0,0,26,26,0,0.000,0.000,0.600\n5,0,26,26,0,0.000,0.000,0.600\n0,0,26,34,0,0.000,0.000,0.316\n5,0,26,34,0,0.000,0.000,0.316\n0,0,26,37,0,0.000,1.423,0.000\n0,0,26,40,0,0.000,0.000,0.474\n0,0,30,30,0,0.000,12.000,0.000\n1,0,30,30,0,0.000,1.800,0.000\n4,0,30,30,0,0.000,1.800,0.000\n0,0,30,40,0,0.000,3.600,0.000\n1,0,30,67,0,0.000,1.800,0.000\n0,0,34,37,0,0.000,0.000,0.000\n0,0,34,43,0,0.000,0.000,0.250\n0,0,37,37,0,0.000,7.000,0.000\n1,0,37,37,0,0.000,2.000,0.000\n4,0,37,37,0,0.000,6.000,0.000\n5,0,37,37,0,0.000,6.000,0.000\n0,1,37,37,5,0.000,7.000,0.000\n0,1,37,37,37,0.000,7.000,0.000\n0,2,37,37,5,0.000,7.000,0.000\n0,2,37,37,37,0.000,7.000,0.000\n0,3,37,37,5,0.000,7.000,0.000\n0,3,37,37,37,0.000,7.000,0.000\n0,5,37,37,5,0.000,7.000,0.000\n0,5,37,37,6,0.000,7.000,0.000\n0,5,37,37,15,0.000,7.000,0.000\n0,5,37,37,18,0.000,7.000,0.000\n0,5,37,37,37,0.000,7.000,0.000\n0,5,37,37,40,0.000,7.000,0.000\n0,5,37,37,43,0.000,7.000,0.000\n0,6,37,37,37,0.000,7.000,0.000\n0,15,37,37,37,0.000,7.000,0.000\n0,18,37,37,37,0.000,7.000,0.000\n0,37,37,37,37,0.000,7.000,0.000\n0,37,37,37,40,0.000,7.000,0.000\n0,37,37,37,43,0.000,7.000,0.000\n0,0,37,38,0,0.000,7.000,0.000\n0,0,37,39,0,0.000,3.600,0.000\n1,0,37,39,0,0.000,6.000,0.000\n0,0,37,40,0,0.000,4.000,0.000\n5,0,37,40,0,0.000,3.600,0.000\n0,37,37,40,1,0.000,4.095,0.382\n0,37,37,40,28,0.698,2.542,3.072\n0,0,37,41,0,0.000,1.800,0.000\n0,0,37,43,0,0.000,2.000,1.800\n5,0,37,43,0,0.000,3.600,0.000\n0,37,37,43,18,0.372,2.284,2.034\n0,37,37,43,28,0.000,1.694,1.508\n0,0,37,45,0,0.000,1.800,0.000\n0,0,37,46,0,0.000,1.800,0.000\n0,0,37,55,0,0.000,4.800,0.000\n0,0,37,56,0,0.000,4.800,0.000\n1,0,37,57,0,0.000,1.800,0.000\n0,0,37,58,0,0.000,6.000,0.000\n1,0,37,58,0,0.000,4.800,0.000\n0,0,37,62,0,0.000,3.600,0.000\n0,0,37,63,0,0.000,7.000,0.000\n1,0,37,63,0,0.000,1.800,0.000\n0,0,37,64,0,0.000,7.000,0.000\n1,0,37,64,0,0.000,1.800,0.000\n1,0,37,67,0,0.000,1.800,0.000\n0,0,37,69,0,0.000,7.000,0.000\n0,0,37,78,0,0.000,6.000,0.000\n0,0,37,81,0,0.000,6.000,0.000\n1,0,37,81,0,0.000,4.800,0.000\n0,0,38,38,0,0.000,7.000,0.000\n0,0,38,58,0,0.000,7.000,0.000\n0,0,38,63,0,0.000,7.000,0.000\n0,0,38,64,0,0.000,7.000,0.000\n0,0,38,69,0,0.000,6.000,0.000\n0,0,38,78,0,0.000,6.000,0.000\n0,0,39,40,0,0.000,0.000,0.000\n0,0,39,45,0,0.000,6.000,0.000\n0,0,39,63,0,0.000,4.000,0.000\n1,0,39,63,0,0.000,6.000,0.000\n5,0,39,63,0,0.000,3.600,0.000\n0,1,39,63,5,0.000,4.000,0.000\n0,1,39,63,64,0.000,4.000,0.000\n0,18,39,63,5,0.000,4.000,0.000\n0,18,39,63,64,0.000,4.000,0.000\n0,63,39,63,5,0.000,4.000,0.000\n0,63,39,63,64,0.000,4.000,0.000\n0,0,39,64,0,0.000,3.600,0.000\n1,0,39,64,0,0.000,6.000,0.000\n0,0,39,65,0,0.000,4.000,0.000\n0,0,39,78,0,0.000,3.600,0.000\n0,0,40,40,0,0.000,0.000,0.375\n0,0,40,45,0,0.000,3.600,0.000\n0,0,40,46,0,0.000,3.600,0.000\n0,0,40,54,0,0.000,3.600,0.000\n2,0,40,54,0,0.000,3.600,0.000\n0,0,40,63,0,0.000,3.600,0.000\n0,0,40,64,0,0.000,3.600,0.000\n0,0,40,78,0,0.000,3.600,0.000\n0,0,41,41,0,0.000,1.800,0.000\n0,0,41,55,0,0.000,4.800,0.000\n0,0,41,62,0,0.000,3.600,0.000\n0,0,41,80,0,0.000,1.800,0.000\n0,0,43,43,0,0.000,0.000,0.375\n0,0,43,45,0,0.000,3.600,0.000\n0,0,43,64,0,0.000,3.600,0.000\n0,0,44,57,0,0.000,7.000,0.000\n0,0,44,63,0,0.000,7.000,0.000\n0,0,44,65,0,0.000,7.000,0.000\n0,0,44,78,0,0.000,2.846,0.000\n0,0,44,80,0,0.000,2.846,0.000\n0,0,45,63,0,0.000,1.800,0.000\n0,0,45,64,0,0.000,1.800,0.000\n0,0,45,78,0,0.000,1.800,0.000\n0,0,55,57,0,0.000,10.000,0.000\n2,0,55,57,0,0.000,4.800,0.000\n5,0,55,57,0,0.000,4.800,0.000\n0,1,55,57,5,0.423,12.064,0.090\n0,1,55,57,55,-0.428,12.044,0.000\n0,36,55,57,5,-0.268,8.077,-0.806\n0,36,55,57,55,0.273,8.025,0.692\n0,0,55,62,0,0.000,3.600,0.000\n0,0,55,64,0,0.000,4.800,0.000\n0,0,55,80,0,0.000,4.800,0.000\n0,0,56,57,0,0.000,6.000,0.000\n0,1,56,57,56,0.000,6.886,-0.161\n0,36,56,57,56,0.000,4.688,0.107\n0,0,56,63,0,0.000,4.800,0.000\n0,0,56,80,0,0.000,4.800,0.000\n1,0,57,63,0,0.000,1.800,0.000\n1,0,57,64,0,0.000,1.800,0.000\n0,0,58,63,0,0.000,6.000,0.000\n0,0,58,64,0,0.000,6.000,0.000\n0,0,59,63,0,0.000,7.000,0.000\n0,0,59,65,0,0.000,7.000,0.000\n0,0,59,78,0,0.000,3.600,0.000\n0,0,59,80,0,0.000,3.600,0.000\n0,0,59,82,0,0.000,3.600,0.000\n0,0,62,63,0,0.000,3.600,0.000\n0,0,62,64,0,0.000,3.600,0.000\n1,0,63,63,0,0.000,1.800,0.000\n0,0,63,64,0,0.000,7.000,0.000\n0,5,63,64,5,0.000,7.000,0.000\n0,5,63,64,64,0.000,7.000,0.000\n0,39,63,64,5,0.000,7.000,0.000\n0,39,63,64,64,0.000,7.000,0.000\n0,0,63,66,0,0.000,7.000,0.000\n0,0,63,78,0,0.000,6.000,0.000\n0,0,63,81,0,0.000,6.000,0.000\n0,0,64,64,0,0.000,7.000,0.000\n1,0,64,64,0,0.000,1.800,0.000\n0,5,64,64,5,0.000,7.000,0.000\n0,5,64,64,63,0.000,7.000,0.000\n0,63,64,64,63,0.000,7.000,0.000\n0,0,64,65,0,0.000,7.000,0.000\n0,0,64,66,0,0.000,7.000,0.000\n0,0,64,78,0,0.000,6.000,0.000\n0,0,64,81,0,0.000,6.000,0.000\n5,0,64,81,0,0.000,6.000,0.000\n0,0,64,82,0,0.000,6.000,0.000\n0,0,65,66,0,0.000,7.000,0.000\n0,0,65,78,0,0.000,6.000,0.000\n0,0,65,81,0,0.000,6.000,0.000\n0,0,65,82,0,0.000,6.000,0.000\n0,0,66,66,0,0.000,7.000,0.000\n0,0,66,78,0,0.000,6.000,0.000\n0,0,66,81,0,0.000,6.000,0.000\n0,0,67,67,0,0.000,12.000,0.000\n5,0,67,67,0,0.000,12.000,0.000\n0,0,76,76,0,0.000,3.600,0.000\n0,0,76,78,0,0.000,3.600,0.000\n0,0,78,78,0,0.000,7.000,0.000\n0,0,78,79,0,0.000,6.000,0.000\n0,0,78,81,0,0.000,4.000,0.000\n0,0,79,79,0,0.000,6.000,0.000\n0,0,79,81,0,0.000,6.000,0.000\n0,0,80,81,0,0.000,4.000,0.000\n'));qlb.FG=true;}else if(Zkb.c5(a,qqb)&&!qlb.GG){ilb.Jz();ilb.Qz(qqb,new ilb.HA(Jsb,'930\nint,int,int,int,int,float,float,float\n0,0,1,1,0,0.000,0.000,0.300\n5,0,1,1,0,0.200,-0.800,1.500\n0,1,1,1,1,0.103,0.681,0.332\n5,1,1,1,1,0.144,-0.547,1.126\n0,1,1,1,2,-0.295,0.438,0.584\n0,1,1,1,3,0.066,-0.156,0.143\n0,1,1,1,5,0.639,-0.630,0.264\n0,1,1,1,6,-0.688,1.757,0.477\n5,1,1,1,6,0.000,0.000,0.054\n0,1,1,1,8,-1.420,-0.092,1.101\n5,1,1,1,8,0.000,-0.158,0.323\n0,1,1,1,11,0.593,0.662,1.120\n0,1,1,1,12,-0.678,0.417,0.624\n0,1,1,1,15,-0.714,0.698,0.000\n0,1,1,1,34,-0.647,0.550,0.590\n0,2,1,1,5,0.321,-0.411,0.144\n0,3,1,1,3,0.443,0.000,-1.140\n0,3,1,1,5,-0.256,0.058,0.000\n0,3,1,1,6,-0.679,-0.029,0.000\n0,5,1,1,5,0.284,-1.386,0.314\n0,5,1,1,6,-0.654,1.072,0.279\n0,5,1,1,8,-0.744,-1.235,0.337\n0,5,1,1,10,0.000,0.000,0.418\n0,5,1,1,11,0.000,0.516,0.291\n0,5,1,1,12,0.678,-0.602,0.398\n0,5,1,1,15,1.142,-0.644,0.367\n0,5,1,1,25,0.000,0.000,0.295\n0,5,1,1,34,0.692,-0.530,0.278\n0,5,1,1,37,0.000,0.000,0.389\n0,5,1,1,39,0.000,0.000,0.278\n0,5,1,1,41,0.000,0.000,-0.141\n0,5,1,1,56,0.000,0.000,0.324\n0,5,1,1,68,0.000,0.000,0.136\n0,6,1,1,6,0.408,1.397,0.961\n5,6,1,1,6,0.313,-1.035,1.631\n0,8,1,1,8,1.055,0.834,0.000\n0,11,1,1,11,-0.387,-0.543,1.405\n0,12,1,1,12,0.000,0.000,0.893\n0,15,1,1,15,-0.177,0.000,0.049\n0,0,1,2,0,0.000,0.000,0.000\n2,0,1,2,0,0.000,0.000,0.000\n5,0,1,2,0,0.000,0.000,0.000\n0,0,1,2,2,0.000,0.000,-0.650\n5,0,1,2,2,0.000,0.000,-0.650\n0,1,1,2,1,0.419,0.296,0.282\n0,1,1,2,2,-0.494,0.274,-0.630\n0,1,1,2,5,0.075,0.000,0.358\n0,2,1,2,2,-0.293,0.115,-0.508\n0,2,1,2,5,0.301,0.104,0.507\n0,3,1,2,1,0.565,-0.554,0.234\n0,3,1,2,2,-0.577,-0.482,-0.427\n0,3,1,2,5,0.082,0.000,0.123\n0,5,1,2,1,0.000,-0.184,0.220\n0,5,1,2,2,0.501,-0.410,-0.535\n2,5,1,2,2,0.000,0.000,0.055\n2,5,1,2,3,0.000,0.000,-0.108\n0,5,1,2,5,-0.523,-0.228,0.208\n2,5,1,2,37,0.000,0.000,0.000\n0,6,1,2,1,-0.467,0.000,0.490\n0,6,1,2,2,0.425,0.168,-0.875\n0,6,1,2,5,0.000,0.136,0.396\n0,8,1,2,1,-0.504,0.371,0.557\n0,8,1,2,2,0.541,0.539,-1.009\n0,8,1,2,5,0.000,0.204,0.464\n0,0,1,3,0,0.000,0.400,0.300\n2,0,1,3,0,0.000,0.500,0.350\n5,0,1,3,0,0.000,0.000,0.000\n0,0,1,3,1,0.000,0.000,0.550\n0,0,1,3,5,0.000,0.200,0.700\n0,0,1,3,7,0.000,0.400,0.400\n0,1,1,3,1,0.103,0.177,0.545\n0,1,1,3,5,-0.072,0.316,0.674\n0,1,1,3,6,-0.117,-0.333,0.202\n0,1,1,3,7,0.825,0.139,0.325\n0,1,1,3,10,-0.763,1.244,0.986\n0,2,1,3,5,0.663,-0.167,0.426\n0,2,1,3,7,-0.758,0.112,0.563\n0,5,1,3,1,-0.073,0.085,0.531\n2,5,1,3,2,0.000,0.000,0.115\n2,5,1,3,3,0.000,0.000,0.446\n0,5,1,3,5,-0.822,0.501,1.008\n0,5,1,3,6,0.000,-0.624,0.330\n0,5,1,3,7,0.659,-1.407,0.308\n0,5,1,3,10,-0.687,1.244,0.136\n2,5,1,3,37,0.000,0.000,0.056\n0,5,1,3,43,0.000,1.027,0.360\n0,5,1,3,51,0.000,1.543,0.350\n0,5,1,3,53,0.000,0.501,0.000\n0,5,1,3,74,0.000,0.513,-0.344\n0,5,1,3,75,0.000,0.511,-0.186\n0,6,1,3,6,0.447,0.652,0.318\n0,6,1,3,7,-0.395,0.730,-0.139\n0,10,1,3,7,0.530,2.905,2.756\n0,10,1,3,10,0.465,-0.241,1.850\n0,0,1,4,0,0.000,0.000,0.000\n0,0,1,6,0,0.000,0.000,0.200\n5,0,1,6,0,0.000,-0.200,0.400\n0,1,1,6,1,-0.681,0.755,0.755\n5,1,1,6,1,0.000,0.243,-0.596\n0,1,1,6,3,-0.547,0.000,0.320\n0,1,1,6,21,0.000,0.270,0.237\n0,2,1,6,21,0.102,0.460,-0.128\n0,3,1,6,21,-1.652,-1.660,0.283\n0,5,1,6,1,0.571,0.319,0.570\n0,5,1,6,2,0.000,0.000,0.306\n0,5,1,6,3,0.572,0.000,-0.304\n0,5,1,6,21,0.596,-0.276,0.346\n0,5,1,6,25,0.000,0.000,0.061\n0,5,1,6,37,0.000,0.000,0.106\n0,5,1,6,45,0.000,0.000,-0.174\n0,6,1,6,1,0.229,-0.710,0.722\n5,6,1,6,1,0.000,0.000,0.040\n0,6,1,6,21,1.488,-3.401,-0.320\n0,37,1,6,21,0.712,1.320,-0.507\n0,0,1,8,0,0.000,-0.300,0.500\n5,0,1,8,0,0.000,0.000,0.297\n0,1,1,8,1,-0.439,0.786,0.272\n5,1,1,8,1,0.115,-0.390,0.658\n0,1,1,8,6,-0.608,0.339,1.496\n0,1,1,8,23,-0.428,0.323,0.280\n0,2,1,8,23,0.594,-0.409,0.155\n0,5,1,8,1,0.393,-0.385,0.562\n0,5,1,8,6,0.598,-0.158,0.399\n0,5,1,8,23,-0.152,-0.440,0.357\n0,0,1,9,0,0.000,0.000,0.000\n5,0,1,9,0,0.000,0.000,0.000\n0,5,1,9,3,0.204,-0.335,-0.352\n0,5,1,9,53,0.000,0.000,0.097\n0,0,1,10,0,0.000,0.000,0.300\n5,0,1,10,0,0.000,0.000,0.000\n0,0,1,10,3,0.000,0.000,1.000\n0,1,1,10,3,-0.884,0.578,0.818\n0,1,1,10,6,0.000,-0.379,0.565\n0,1,1,10,28,0.750,-0.404,0.369\n0,3,1,10,3,3.219,-2.699,1.875\n0,3,1,10,28,0.207,0.461,0.324\n0,5,1,10,1,0.000,0.000,0.706\n0,5,1,10,3,-2.334,1.517,-0.065\n0,5,1,10,6,0.000,0.688,0.665\n0,5,1,10,28,-0.982,-0.207,0.166\n0,0,1,15,0,0.000,0.000,0.400\n5,0,1,15,0,0.000,0.000,0.336\n0,1,1,15,1,-1.047,0.170,0.398\n0,1,1,15,15,-1.438,0.263,0.501\n0,1,1,15,71,-0.376,-0.133,0.288\n0,5,1,15,1,1.143,-0.231,0.447\n0,5,1,15,15,1.555,-0.323,0.456\n0,5,1,15,37,0.000,0.000,0.459\n0,5,1,15,71,0.229,0.203,0.440\n0,0,1,17,0,0.000,0.000,0.350\n5,0,1,17,0,0.000,0.000,0.000\n0,5,1,17,1,0.000,0.000,0.536\n0,5,1,17,7,0.000,0.000,0.212\n0,0,1,18,0,0.000,0.000,0.100\n5,0,1,18,0,0.000,0.000,0.112\n0,5,1,18,1,0.000,0.000,0.000\n0,5,1,18,6,0.000,0.000,0.099\n0,5,1,18,32,0.000,0.585,0.388\n0,5,1,18,43,0.000,-0.412,0.121\n0,5,1,18,48,0.000,0.000,0.195\n0,5,1,18,62,0.000,0.000,-0.088\n0,0,1,19,0,0.000,0.000,0.150\n5,0,1,19,0,0.000,0.000,0.179\n0,5,1,19,5,0.000,0.000,0.196\n0,5,1,19,6,0.000,0.000,0.176\n0,5,1,19,12,0.000,0.000,0.152\n0,0,1,20,0,0.000,0.000,0.350\n5,0,1,20,0,0.000,0.000,0.350\n0,5,1,20,5,0.000,0.000,0.344\n0,5,1,20,20,0.000,0.000,0.361\n0,0,1,22,0,0.000,0.000,0.236\n5,0,1,22,0,0.000,0.000,0.236\n0,0,1,25,0,0.000,0.000,0.300\n5,0,1,25,0,0.000,0.000,0.251\n0,1,1,25,1,0.000,-0.207,0.232\n0,1,1,25,32,0.000,0.288,0.218\n0,5,1,25,1,0.000,0.152,0.235\n0,5,1,25,6,0.000,0.000,0.495\n0,5,1,25,32,0.000,-0.130,0.214\n0,5,1,25,43,0.000,0.000,0.466\n0,5,1,25,72,0.000,0.000,0.243\n0,0,1,26,0,0.000,0.000,0.450\n5,0,1,26,0,0.000,0.000,0.376\n0,5,1,26,12,0.000,0.000,0.439\n0,5,1,26,71,0.000,0.000,0.472\n0,0,1,34,0,0.000,0.000,0.250\n5,0,1,34,0,0.000,0.000,0.198\n0,1,1,34,36,0.000,0.000,0.187\n0,5,1,34,1,0.000,0.000,0.247\n0,5,1,34,36,0.000,0.000,0.259\n0,0,1,37,0,0.000,0.000,0.200\n5,0,1,37,0,0.000,0.000,0.000\n0,1,1,37,37,0.000,0.449,0.000\n0,5,1,37,37,0.000,-0.420,0.391\n0,6,1,37,37,0.000,0.000,0.150\n0,0,1,39,0,0.000,0.000,0.000\n5,0,1,39,0,0.000,0.000,0.000\n0,1,1,39,63,0.000,-0.080,-0.056\n0,5,1,39,63,0.000,0.000,-0.113\n0,0,1,40,0,0.000,0.000,0.250\n5,0,1,40,0,0.000,0.000,0.297\n0,5,1,40,28,0.000,-0.105,0.000\n0,5,1,40,37,0.000,0.000,0.468\n0,0,1,41,0,0.000,0.600,0.000\n0,1,1,41,32,0.000,1.263,0.000\n0,5,1,41,32,0.000,0.000,-0.106\n0,5,1,41,72,0.000,0.632,0.000\n0,0,1,43,0,0.000,0.000,0.150\n5,0,1,43,0,0.000,0.000,0.297\n0,5,1,43,18,0.357,-0.918,0.000\n0,5,1,43,25,0.000,0.000,0.061\n0,5,1,43,28,-0.249,0.382,0.343\n0,0,1,45,0,0.000,0.000,0.100\n0,5,1,45,32,0.000,0.000,0.125\n0,0,1,46,0,0.000,0.000,-0.500\n0,5,1,46,7,0.000,0.000,-0.540\n0,0,1,54,0,0.000,0.000,0.000\n2,0,1,54,0,0.000,0.000,0.000\n5,0,1,54,0,0.000,0.000,0.000\n0,5,1,54,3,0.000,0.000,-0.315\n0,5,1,54,36,0.000,0.000,0.315\n0,0,1,55,0,0.000,0.000,0.000\n5,0,1,55,0,0.000,0.000,0.000\n0,5,1,55,36,0.000,-0.058,0.084\n0,5,1,55,57,0.000,-0.058,-0.092\n0,0,1,56,0,0.000,0.000,-0.300\n0,1,1,56,36,0.875,0.668,-0.015\n0,1,1,56,57,-0.870,0.775,-0.406\n0,5,1,56,36,-0.958,-0.629,-0.372\n0,5,1,56,57,0.952,-0.715,-0.483\n0,0,1,57,0,0.000,0.000,0.000\n5,0,1,57,0,0.000,0.000,0.000\n0,0,1,58,0,0.000,0.000,0.000\n0,0,1,62,0,0.000,0.000,0.250\n0,5,1,62,18,0.000,0.000,0.270\n0,0,1,63,0,0.000,0.000,0.000\n5,0,1,63,0,0.000,0.000,0.000\n0,0,1,64,0,0.000,0.000,0.000\n5,0,1,64,0,0.000,0.000,0.000\n0,0,1,67,0,0.000,0.000,0.000\n5,0,1,67,0,0.000,0.000,0.000\n0,0,1,68,0,0.000,0.000,0.400\n0,1,1,68,1,-0.117,0.090,0.751\n0,1,1,68,23,0.373,0.153,0.635\n0,1,1,68,32,-0.090,-0.169,0.075\n0,5,1,68,1,0.134,-0.112,0.329\n0,5,1,68,23,-0.361,-0.202,0.560\n0,5,1,68,32,0.072,0.218,0.093\n0,0,1,73,0,0.000,0.000,0.500\n0,5,1,73,32,0.000,0.000,0.509\n0,5,1,73,72,0.000,0.000,0.443\n0,0,1,75,0,0.000,0.000,0.000\n0,0,1,78,0,0.000,0.000,0.000\n0,0,1,80,0,0.000,0.000,0.000\n0,0,1,81,0,0.000,0.000,0.000\n0,0,2,2,0,0.000,12.000,0.000\n1,0,2,2,0,0.000,1.800,0.000\n5,0,2,2,0,0.000,12.000,0.000\n0,1,2,2,1,-0.403,12.000,0.000\n0,1,2,2,2,0.000,12.000,0.000\n1,1,2,2,2,-0.418,2.089,-0.310\n0,1,2,2,5,0.000,12.000,0.000\n1,1,2,2,5,0.412,2.120,0.269\n1,2,2,2,2,0.094,1.621,0.877\n0,2,2,2,5,0.000,12.000,0.000\n1,2,2,2,5,0.317,1.421,-0.870\n0,3,2,2,5,0.000,12.000,0.000\n0,5,2,2,5,0.000,12.000,0.000\n1,5,2,2,5,-0.406,1.767,0.000\n0,5,2,2,6,0.000,12.000,0.000\n0,5,2,2,37,0.000,12.000,0.000\n0,5,2,2,40,0.000,12.000,0.000\n0,5,2,2,41,0.000,12.000,0.000\n0,5,2,2,45,0.000,12.000,0.000\n0,5,2,2,62,0.000,12.000,0.000\n1,0,2,3,0,0.000,2.500,0.000\n1,1,2,3,1,0.136,1.798,0.630\n1,1,2,3,5,0.497,2.405,0.357\n1,1,2,3,6,-0.211,1.925,-0.131\n1,1,2,3,7,-0.401,2.028,-0.318\n1,1,2,3,10,0.000,2.237,-0.610\n1,2,2,3,1,-0.325,1.553,-0.487\n1,2,2,3,5,-0.295,2.024,-0.590\n1,2,2,3,6,-0.143,1.466,0.000\n1,2,2,3,7,0.362,1.978,0.000\n1,2,2,3,9,0.296,1.514,0.481\n1,2,2,3,10,0.000,1.599,0.380\n1,5,2,3,1,0.213,1.728,-0.042\n1,5,2,3,5,-0.208,1.622,0.223\n1,5,2,3,6,0.359,1.539,0.194\n1,5,2,3,7,0.000,2.046,0.000\n1,5,2,3,9,-0.290,1.519,-0.470\n1,5,2,3,10,0.000,1.409,0.254\n1,0,2,4,0,0.000,0.000,0.000\n0,0,2,6,0,0.000,3.100,0.000\n2,0,2,6,0,0.000,3.600,0.000\n5,0,2,6,0,0.000,3.600,0.000\n0,2,2,6,1,-1.953,3.953,-1.055\n0,2,2,6,3,-1.712,2.596,-0.330\n0,2,2,6,29,-0.215,2.810,-0.456\n0,5,2,6,1,1.951,3.936,1.130\n0,5,2,6,3,1.719,2.628,0.360\n0,5,2,6,29,0.216,2.808,0.456\n1,0,2,9,0,0.000,1.800,0.000\n0,0,2,10,0,0.000,6.000,0.000\n2,0,2,10,0,0.000,6.000,0.000\n5,0,2,10,0,0.000,6.000,0.000\n0,0,2,15,0,0.000,1.423,0.000\n2,0,2,15,0,0.000,1.423,0.000\n5,0,2,15,0,0.000,1.423,0.000\n0,0,2,17,0,0.000,1.423,0.000\n0,0,2,18,0,0.000,0.000,0.000\n2,0,2,18,0,0.000,0.000,0.000\n5,0,2,18,0,0.000,0.000,0.000\n0,0,2,19,0,0.000,0.000,0.000\n0,0,2,20,0,0.000,0.000,0.000\n2,0,2,20,0,0.000,0.000,0.000\n0,0,2,22,0,0.000,0.000,0.000\n2,0,2,22,0,0.000,0.000,0.000\n5,0,2,22,0,0.000,0.000,0.000\n0,0,2,25,0,0.000,0.000,0.000\n0,0,2,30,0,0.000,12.000,0.000\n0,0,2,34,0,0.000,0.000,0.000\n2,0,2,34,0,0.000,0.000,0.000\n1,0,2,37,0,0.000,2.000,0.000\n1,1,2,37,37,0.000,2.952,-0.079\n1,2,2,37,37,0.000,1.542,0.434\n1,5,2,37,37,0.000,1.308,-0.357\n1,0,2,39,0,0.000,6.000,0.000\n0,0,2,40,0,0.000,3.700,0.000\n2,0,2,40,0,0.000,3.600,0.000\n5,0,2,40,0,0.000,3.600,0.000\n0,2,2,40,28,0.000,3.305,-0.530\n0,5,2,40,28,0.139,3.241,0.139\n0,0,2,41,0,0.000,1.200,0.000\n2,0,2,41,0,0.000,1.800,0.000\n0,2,2,41,32,0.000,1.235,0.000\n0,5,2,41,32,0.000,1.231,0.000\n0,0,2,43,0,0.000,3.600,0.000\n2,0,2,43,0,0.000,3.600,0.000\n0,0,2,45,0,0.000,2.200,0.000\n2,0,2,45,0,0.000,1.800,0.000\n0,2,2,45,32,0.000,2.212,0.000\n0,5,2,45,32,0.000,2.225,0.000\n0,0,2,46,0,0.000,1.800,0.000\n2,0,2,46,0,0.000,1.800,0.000\n0,0,2,55,0,0.000,4.800,0.000\n0,0,2,56,0,0.000,4.800,0.000\n0,0,2,62,0,0.000,8.000,0.000\n0,2,2,62,23,1.693,7.903,0.532\n0,5,2,62,23,-1.696,7.897,-0.482\n1,0,2,63,0,0.000,1.800,0.000\n1,0,2,64,0,0.000,1.800,0.000\n1,0,2,67,0,0.000,1.800,0.000\n1,0,2,81,0,0.000,4.800,0.000\n1,0,3,3,0,0.000,0.600,0.000\n4,0,3,3,0,0.000,1.800,0.000\n1,1,3,3,1,-0.486,0.714,0.000\n1,1,3,3,6,-0.081,-0.125,0.132\n1,1,3,3,7,1.053,1.327,0.000\n1,5,3,3,6,0.000,0.188,0.436\n1,5,3,3,7,0.000,0.177,-0.412\n1,6,3,3,6,0.269,0.437,0.000\n1,6,3,3,7,-0.495,0.793,-0.318\n1,7,3,3,7,-0.260,1.084,0.193\n0,0,3,6,0,0.000,5.500,0.000\n2,0,3,6,0,0.000,5.500,0.000\n4,0,3,6,0,0.000,3.600,0.000\n5,0,3,6,0,0.000,3.600,0.000\n0,1,3,6,1,-1.244,5.482,0.365\n0,1,3,6,24,-1.166,5.078,-0.545\n0,1,3,6,37,-0.677,5.854,0.521\n2,2,3,6,24,0.256,4.519,0.258\n2,3,3,6,24,1.663,4.073,0.094\n0,5,3,6,1,0.526,5.631,0.691\n0,5,3,6,2,0.159,6.586,0.216\n0,5,3,6,24,-2.285,4.737,0.468\n0,7,3,6,0,0.700,6.500,-0.400\n0,7,3,6,1,0.682,7.184,-0.935\n0,7,3,6,2,-0.168,6.572,-0.151\n0,7,3,6,24,1.662,6.152,-0.058\n0,7,3,6,37,0.635,5.890,-0.446\n2,37,3,6,24,0.000,3.892,-0.094\n0,0,3,9,0,0.000,16.000,0.000\n1,0,3,9,0,0.000,1.800,0.000\n5,0,3,9,0,0.000,12.000,0.000\n0,2,3,9,27,0.000,16.000,0.000\n0,5,3,9,1,0.687,16.152,0.894\n0,5,3,9,27,0.000,16.000,0.000\n0,40,3,9,1,-0.704,18.216,0.000\n0,40,3,9,27,0.000,16.000,0.178\n0,0,3,10,0,0.000,6.000,0.000\n2,0,3,10,0,0.000,6.000,0.000\n4,0,3,10,0,0.000,6.000,0.000\n5,0,3,10,0,0.000,6.000,0.000\n0,1,3,10,1,0.831,6.061,0.522\n0,1,3,10,6,-1.152,8.588,1.511\n0,1,3,10,28,-0.259,5.934,1.326\n2,2,3,10,28,0.000,6.561,0.294\n0,5,3,10,1,-0.195,6.304,1.722\n0,5,3,10,3,-0.705,5.383,0.234\n0,5,3,10,28,-0.417,5.981,0.511\n0,7,3,10,1,-0.491,6.218,0.000\n0,7,3,10,3,0.733,-0.543,-0.163\n0,7,3,10,6,1.234,8.372,-0.539\n0,7,3,10,28,1.168,4.857,-0.341\n0,10,3,10,28,0.000,3.706,1.254\n0,0,3,15,0,0.000,1.423,0.000\n2,0,3,15,0,0.000,1.423,0.000\n4,0,3,15,0,0.000,1.423,0.000\n5,0,3,15,0,0.000,1.423,0.000\n0,0,3,17,0,0.000,1.423,0.000\n5,0,3,17,0,0.000,1.423,0.000\n0,0,3,18,0,0.000,0.000,0.000\n2,0,3,18,0,0.000,0.000,0.000\n0,0,3,20,0,0.000,0.000,-0.300\n2,0,3,20,0,0.000,0.000,0.000\n4,0,3,20,0,0.000,0.000,-0.300\n5,0,3,20,0,0.000,0.000,0.000\n0,7,3,20,0,0.000,0.400,0.400\n0,7,3,20,5,0.000,0.000,-0.131\n0,7,3,20,20,0.000,0.000,0.000\n0,20,3,20,5,0.000,0.000,0.085\n0,20,3,20,20,0.000,0.000,0.000\n0,0,3,22,0,0.000,0.000,0.000\n2,0,3,22,0,0.000,0.000,0.000\n4,0,3,22,0,0.000,0.000,0.000\n5,0,3,22,0,0.000,0.000,0.000\n0,7,3,22,0,0.000,4.200,1.900\n0,0,3,25,0,0.000,0.000,0.000\n2,0,3,25,0,0.000,0.000,0.000\n1,0,3,30,0,0.000,1.800,0.000\n4,0,3,30,0,0.000,1.800,0.000\n1,0,3,37,0,0.000,2.500,0.000\n4,0,3,37,0,0.000,1.800,0.000\n1,1,3,37,37,0.000,2.428,0.000\n1,6,3,37,37,0.000,1.743,0.000\n1,7,3,37,37,0.000,2.256,0.000\n1,43,3,37,37,-0.241,3.385,-0.838\n1,0,3,39,0,0.000,5.500,0.000\n0,0,3,40,0,0.000,3.900,0.000\n2,0,3,40,0,0.000,3.600,0.000\n5,0,3,40,0,0.000,3.600,0.000\n0,5,3,40,28,-1.355,3.964,0.800\n0,9,3,40,28,1.045,3.785,-0.291\n0,40,3,40,28,0.508,2.985,0.809\n0,0,3,41,0,0.000,1.800,0.000\n2,0,3,41,0,0.000,1.800,0.000\n0,0,3,43,0,0.000,4.500,0.000\n2,0,3,43,0,0.000,3.600,0.000\n4,0,3,43,0,0.000,3.600,0.000\n5,0,3,43,0,0.000,3.600,0.000\n0,1,3,43,18,1.712,3.309,0.233\n0,1,3,43,28,-0.414,4.168,-0.875\n0,7,3,43,18,-0.880,5.091,-0.129\n0,7,3,43,28,0.536,5.276,-0.556\n2,37,3,43,18,-0.701,4.871,1.225\n2,37,3,43,28,-0.086,5.073,0.878\n0,0,3,45,0,0.000,1.800,0.000\n2,0,3,45,0,0.000,1.800,0.000\n0,0,3,48,0,0.000,0.000,0.892\n0,0,3,51,0,0.000,13.500,0.000\n0,1,3,51,52,0.000,13.549,0.000\n0,0,3,54,0,0.000,8.000,0.000\n1,0,3,54,0,0.000,2.500,0.000\n5,0,3,54,0,0.000,12.000,0.000\n0,5,3,54,1,0.000,8.000,0.000\n0,5,3,54,36,0.000,8.000,0.000\n0,0,3,55,0,0.000,4.800,0.000\n2,0,3,55,0,0.000,4.800,0.000\n0,0,3,56,0,0.000,4.800,0.000\n2,0,3,56,0,0.000,4.800,0.000\n1,0,3,57,0,0.000,2.500,0.000\n1,0,3,58,0,0.000,4.800,0.000\n0,0,3,62,0,0.000,3.600,0.000\n2,0,3,62,0,0.000,3.600,0.000\n5,0,3,62,0,0.000,3.600,0.000\n1,0,3,63,0,0.000,2.500,0.000\n1,0,3,64,0,0.000,2.500,0.000\n0,0,3,67,0,0.000,12.000,0.000\n0,0,3,74,0,0.000,19.000,0.000\n0,1,3,74,7,0.000,19.349,0.000\n0,0,3,75,0,0.000,19.000,0.000\n0,1,3,75,71,0.000,18.751,0.000\n1,0,3,78,0,0.000,2.500,0.000\n1,0,3,80,0,0.000,2.500,0.000\n0,0,6,6,0,0.000,-2.000,0.000\n5,0,6,6,0,0.000,-2.000,0.000\n0,0,6,8,0,0.900,-1.100,-0.500\n5,0,6,8,0,0.000,0.000,0.274\n0,21,6,8,1,0.261,-0.330,-0.542\n0,21,6,8,23,1.503,-1.853,-0.476\n0,0,6,9,0,0.000,3.600,0.000\n5,0,6,9,0,0.000,3.600,0.000\n0,0,6,10,0,1.200,0.500,-1.000\n0,21,6,10,1,0.829,0.000,-0.730\n0,21,6,10,3,0.675,-0.185,-1.053\n0,0,6,15,0,0.000,-4.000,0.000\n0,0,6,17,0,0.000,1.423,0.000\n5,0,6,17,0,0.000,1.423,0.000\n0,0,6,18,0,0.000,0.000,0.100\n5,0,6,18,0,0.000,0.000,0.103\n0,33,6,18,1,-0.520,-0.471,-0.267\n0,33,6,18,6,-1.623,0.204,0.438\n0,33,6,18,32,1.616,0.425,0.191\n0,0,6,19,0,0.000,0.000,0.150\n5,0,6,19,0,0.000,0.000,0.165\n0,21,6,19,1,-0.620,-0.329,0.303\n0,21,6,19,5,0.683,0.220,0.000\n0,0,6,20,0,0.000,0.000,0.400\n4,0,6,20,0,0.000,0.000,0.217\n5,0,6,20,0,0.000,0.000,0.217\n0,20,6,20,5,0.000,0.000,-0.079\n4,20,6,20,20,0.000,0.000,0.000\n0,0,6,22,0,0.000,0.000,0.217\n0,0,6,25,0,0.000,0.000,0.650\n5,0,6,25,0,0.000,0.000,0.231\n0,1,6,25,1,-1.704,-0.452,0.556\n0,1,6,25,6,0.000,0.000,0.777\n0,1,6,25,32,1.205,0.914,0.612\n0,24,6,25,6,-3.209,-7.622,1.065\n0,24,6,25,32,-5.891,-3.332,0.290\n0,0,6,26,0,0.000,0.000,0.346\n0,0,6,30,0,0.000,3.600,0.000\n2,0,6,30,0,0.000,3.600,0.000\n0,0,6,37,0,0.000,3.200,0.000\n5,0,6,37,0,0.000,3.600,0.000\n0,1,6,37,37,0.000,4.382,0.000\n0,3,6,37,37,0.000,2.576,0.000\n0,29,6,37,37,0.000,2.801,0.000\n0,0,6,39,0,0.000,0.000,0.000\n0,0,6,40,0,0.000,0.000,0.274\n0,0,6,41,0,0.000,3.600,0.000\n0,0,6,43,0,0.000,0.000,0.274\n0,0,6,45,0,0.000,6.000,0.000\n0,1,6,45,32,0.000,6.208,0.000\n0,0,6,54,0,0.000,3.600,0.000\n0,0,6,55,0,0.000,3.600,0.000\n0,0,6,57,0,0.000,3.600,0.000\n0,0,6,58,0,0.000,3.600,0.000\n0,0,6,63,0,0.000,3.600,0.000\n0,0,6,64,0,0.000,3.600,0.000\n0,0,8,8,0,0.000,0.000,0.375\n5,0,8,8,0,0.000,0.000,0.375\n0,0,8,9,0,0.000,3.600,0.000\n5,0,8,9,0,0.000,3.600,0.000\n0,0,8,10,0,0.000,0.000,0.000\n4,0,8,10,0,0.000,0.000,0.000\n0,0,8,15,0,0.000,0.000,0.424\n0,0,8,17,0,0.000,1.423,0.000\n4,0,8,17,0,0.000,1.423,0.000\n5,0,8,17,0,0.000,1.423,0.000\n0,0,8,19,0,0.000,0.000,0.225\n0,0,8,20,0,0.000,0.000,0.350\n4,0,8,20,0,0.000,0.000,0.300\n5,0,8,20,0,0.000,0.000,0.297\n0,20,8,20,5,0.000,0.120,0.472\n4,20,8,20,20,0.000,-0.097,0.200\n0,23,8,20,5,-0.101,-0.324,0.371\n0,23,8,20,20,0.107,0.253,0.151\n0,0,8,22,0,0.000,0.000,0.297\n0,0,8,25,0,0.000,0.000,0.316\n5,0,8,25,0,0.000,0.000,0.316\n0,0,8,26,0,0.000,0.000,0.474\n5,0,8,26,0,0.000,0.000,0.474\n0,0,8,34,0,0.000,0.000,0.250\n0,0,8,39,0,0.000,0.000,0.000\n0,0,8,40,0,0.000,0.000,0.375\n0,0,8,43,0,0.000,0.000,0.375\n0,0,8,45,0,0.000,3.600,0.000\n0,0,8,46,0,0.000,3.600,0.000\n0,0,8,55,0,0.000,3.600,0.000\n0,0,8,56,0,0.000,3.600,0.000\n0,0,9,9,0,0.000,12.000,0.000\n1,0,9,9,0,0.000,1.800,0.000\n5,0,9,9,0,0.000,12.000,0.000\n0,0,9,10,0,0.000,6.000,0.000\n5,0,9,10,0,0.000,6.000,0.000\n0,0,9,15,0,0.000,1.423,0.000\n0,0,9,18,0,0.000,0.000,0.000\n0,0,9,19,0,0.000,0.000,0.000\n0,0,9,20,0,0.000,0.000,0.000\n0,0,9,25,0,0.000,0.000,0.000\n0,0,9,34,0,0.000,0.000,0.000\n5,0,9,34,0,0.000,0.000,0.000\n1,0,9,37,0,0.000,1.800,0.000\n1,0,9,39,0,0.000,6.000,0.000\n0,0,9,40,0,0.000,3.600,0.000\n0,0,9,41,0,0.000,4.800,0.000\n0,0,9,45,0,0.000,1.800,0.000\n0,0,9,54,0,0.000,12.000,0.000\n0,0,9,55,0,0.000,4.800,0.000\n0,0,9,56,0,0.000,4.800,0.000\n1,0,9,57,0,0.000,1.800,0.000\n0,0,9,62,0,0.000,3.600,0.000\n1,0,9,63,0,0.000,1.800,0.000\n1,0,9,64,0,0.000,1.800,0.000\n0,0,9,67,0,0.000,12.000,0.000\n1,0,9,78,0,0.000,1.800,0.000\n1,0,9,81,0,0.000,4.800,0.000\n0,0,10,10,0,0.000,0.000,0.000\n5,0,10,10,0,0.000,0.000,0.000\n0,0,10,15,0,0.000,0.000,0.000\n0,0,10,17,0,0.000,4.743,0.000\n0,0,10,20,0,0.000,0.000,0.000\n4,0,10,20,0,0.000,0.000,0.000\n5,0,10,20,0,0.000,0.000,0.000\n0,0,10,22,0,0.000,0.000,0.000\n0,0,10,25,0,0.000,0.000,0.000\n0,0,10,26,0,0.000,0.000,0.000\n5,0,10,26,0,0.000,0.000,0.000\n0,0,10,34,0,0.000,0.000,0.000\n0,0,10,37,0,0.000,2.700,0.000\n0,0,10,39,0,0.000,0.000,0.000\n0,0,10,40,0,0.000,0.000,0.000\n5,0,10,40,0,0.000,0.000,0.000\n0,0,10,41,0,0.000,6.000,0.000\n0,0,10,45,0,0.000,6.000,0.000\n0,0,10,63,0,0.000,0.600,0.000\n0,3,10,63,44,-10.200,7.000,0.000\n0,0,10,64,0,0.000,1.200,0.000\n0,28,10,64,63,2.400,2.900,0.000\n0,0,15,15,0,-1.400,-8.300,1.000\n5,0,15,15,0,0.000,-8.000,0.000\n0,1,15,15,1,-1.663,-8.408,1.433\n0,1,15,15,71,-1.088,-8.245,0.411\n0,0,15,18,0,0.000,0.000,0.160\n0,0,15,19,0,0.000,0.000,0.255\n5,0,15,19,0,0.000,0.000,0.255\n0,0,15,20,0,0.000,0.000,0.336\n4,0,15,20,0,0.000,0.000,0.336\n0,0,15,22,0,0.000,0.000,0.336\n0,0,15,25,0,0.000,0.000,0.358\n4,0,15,25,0,0.000,0.000,0.358\n0,0,15,26,0,0.000,0.000,0.537\n0,0,15,30,0,0.000,1.423,0.000\n4,0,15,30,0,0.000,1.423,0.000\n0,0,15,37,0,0.000,3.000,0.000\n5,0,15,37,0,0.000,1.423,0.000\n0,1,15,37,37,0.000,2.177,0.000\n0,71,15,37,37,0.000,0.505,0.333\n0,0,15,40,0,0.000,0.000,0.424\n0,0,15,43,0,0.000,0.000,0.424\n0,0,15,57,0,0.000,1.423,0.000\n0,0,15,63,0,0.000,1.423,0.000\n0,0,15,64,0,0.000,1.423,0.000\n0,0,17,20,0,0.000,0.000,0.000\n4,0,17,20,0,0.000,0.000,0.000\n5,0,17,20,0,0.000,0.000,0.000\n0,0,17,22,0,0.000,0.000,0.000\n0,0,17,37,0,0.000,1.423,0.000\n0,0,17,43,0,0.000,3.795,0.000\n0,0,18,20,0,0.000,0.000,0.112\n4,0,18,20,0,0.000,0.000,0.112\n5,0,18,20,0,0.000,0.000,0.112\n0,0,18,22,0,0.000,0.000,0.112\n0,0,18,37,0,0.000,-1.200,-0.300\n0,32,18,37,37,-0.173,-0.965,-0.610\n0,39,18,37,37,0.000,-0.760,0.227\n0,43,18,37,37,0.228,-1.741,-0.371\n0,0,18,39,0,0.000,0.000,0.500\n0,32,18,39,63,0.000,0.687,0.680\n0,37,18,39,63,0.000,-0.513,0.357\n0,0,18,43,0,0.000,0.000,0.350\n4,0,18,43,0,0.000,0.000,0.141\n5,0,18,43,0,0.000,0.000,0.141\n0,1,18,43,1,-0.914,-0.482,0.179\n0,1,18,43,3,-0.392,-2.724,0.312\n0,1,18,43,28,-1.508,-1.816,-0.175\n0,1,18,43,37,0.823,-1.220,-0.770\n0,32,18,43,1,1.588,1.499,1.410\n0,32,18,43,3,0.653,0.254,0.000\n0,32,18,43,28,0.528,0.342,0.000\n0,32,18,43,37,0.812,1.513,1.266\n0,37,18,43,1,-1.139,-0.703,1.088\n0,37,18,43,28,-2.014,-1.646,-2.068\n0,37,18,43,37,-1.519,-0.328,1.437\n0,43,18,43,28,3.011,-1.405,2.038\n0,0,18,48,0,0.000,0.000,0.400\n0,1,18,48,28,1.767,1.606,0.408\n0,32,18,48,28,-1.463,-2.548,0.310\n0,0,18,55,0,0.000,0.000,0.000\n0,0,18,58,0,0.000,0.000,0.000\n0,0,18,62,0,0.000,0.000,0.500\n0,1,18,62,1,-0.403,-0.273,0.440\n0,32,18,62,1,0.291,0.385,0.582\n0,0,18,63,0,0.000,0.000,0.000\n0,0,18,64,0,0.000,0.000,0.000\n0,0,18,80,0,0.000,0.000,0.000\n0,0,19,20,0,0.000,0.000,0.179\n4,0,19,20,0,0.000,0.000,0.179\n0,0,19,37,0,0.000,0.000,0.000\n0,0,19,40,0,0.000,0.000,0.225\n0,0,19,63,0,0.000,0.000,0.000\n0,0,19,75,0,0.000,0.000,0.000\n0,0,20,20,0,0.000,0.000,0.200\n4,0,20,20,0,0.000,0.000,0.000\n5,0,20,20,0,0.000,0.000,0.236\n0,1,20,20,5,0.067,0.081,0.347\n0,1,20,20,20,-0.063,-0.064,0.140\n0,3,20,20,5,0.000,0.000,0.083\n0,3,20,20,20,0.000,0.000,0.000\n0,5,20,20,5,0.000,0.000,0.424\n0,5,20,20,6,0.000,0.000,-0.080\n0,5,20,20,8,0.000,0.127,0.450\n0,5,20,20,12,-0.072,-0.269,0.439\n0,5,20,20,20,-0.057,0.000,0.307\n4,6,20,20,20,0.000,0.000,0.000\n4,8,20,20,20,0.000,-0.091,0.192\n0,12,20,20,20,0.077,0.202,0.183\n4,20,20,20,20,0.000,0.000,0.000\n0,0,20,22,0,0.000,0.000,0.236\n4,0,20,22,0,0.000,0.000,0.236\n0,0,20,25,0,0.000,0.000,0.251\n4,0,20,25,0,0.000,0.000,0.251\n0,0,20,26,0,0.000,0.000,0.376\n4,0,20,26,0,0.000,0.000,0.376\n5,0,20,26,0,0.000,0.000,0.376\n0,0,20,30,0,0.000,0.000,0.000\n2,0,20,30,0,0.000,0.000,0.000\n4,0,20,30,0,0.000,0.000,0.000\n0,0,20,30,30,0.000,0.000,-0.500\n0,0,20,34,0,0.000,0.000,0.198\n4,0,20,34,0,0.000,0.000,0.198\n0,0,20,37,0,0.000,0.000,0.000\n4,0,20,37,0,0.000,0.000,0.000\n0,0,20,40,0,0.000,0.000,0.297\n0,0,20,41,0,0.000,0.000,0.000\n0,0,20,43,0,0.000,0.000,0.297\n4,0,20,43,0,0.000,0.000,0.297\n0,0,20,45,0,0.000,0.000,0.000\n0,0,22,22,0,0.000,0.000,0.236\n4,0,22,22,0,0.000,0.000,0.236\n5,0,22,22,0,0.000,0.000,0.236\n0,0,22,30,0,0.000,0.000,0.000\n4,0,22,30,0,0.000,0.000,0.000\n0,0,22,34,0,0.000,0.000,0.198\n0,0,22,37,0,0.000,0.500,-2.800\n0,0,22,40,0,0.000,0.000,0.297\n0,0,22,41,0,0.000,0.000,0.000\n0,0,22,43,0,0.000,0.000,0.297\n5,0,22,43,0,0.000,0.000,0.297\n0,0,22,45,0,0.000,0.000,0.000\n0,0,25,25,0,0.000,0.000,0.267\n0,0,25,37,0,0.000,0.000,0.000\n5,0,25,37,0,0.000,0.000,0.000\n0,0,25,39,0,0.000,0.000,0.000\n0,0,25,40,0,0.000,0.000,0.316\n5,0,25,40,0,0.000,0.000,0.316\n0,0,25,43,0,0.000,0.000,0.250\n0,1,25,43,1,-2.686,-1.512,0.591\n0,1,25,43,28,-3.730,-0.531,0.000\n0,32,25,43,1,2.108,1.896,0.965\n0,32,25,43,28,2.977,0.732,-0.502\n0,0,25,57,0,0.000,0.000,0.000\n0,0,25,63,0,0.000,0.000,0.000\n0,0,26,26,0,0.000,0.000,0.600\n5,0,26,26,0,0.000,0.000,0.600\n0,0,26,34,0,0.000,0.000,0.316\n5,0,26,34,0,0.000,0.000,0.316\n0,0,26,37,0,0.000,1.423,0.000\n0,0,26,40,0,0.000,0.000,0.474\n0,0,30,30,0,0.000,12.000,0.000\n1,0,30,30,0,0.000,1.800,0.000\n4,0,30,30,0,0.000,1.800,0.000\n0,0,30,40,0,0.000,3.600,0.000\n1,0,30,67,0,0.000,1.800,0.000\n0,0,34,37,0,0.000,0.000,0.000\n0,0,34,43,0,0.000,0.000,0.250\n0,0,37,37,0,0.000,7.000,0.000\n1,0,37,37,0,0.000,2.000,0.000\n4,0,37,37,0,0.000,6.000,0.000\n5,0,37,37,0,0.000,6.000,0.000\n0,1,37,37,5,0.000,7.000,0.000\n0,1,37,37,37,0.000,7.000,0.000\n0,2,37,37,5,0.000,7.000,0.000\n0,2,37,37,37,0.000,7.000,0.000\n0,3,37,37,5,0.000,7.000,0.000\n0,3,37,37,37,0.000,7.000,0.000\n0,5,37,37,5,0.000,7.000,0.000\n0,5,37,37,6,0.000,7.000,0.000\n0,5,37,37,15,0.000,7.000,0.000\n0,5,37,37,18,0.000,7.000,0.000\n0,5,37,37,37,0.000,7.000,0.000\n0,5,37,37,40,0.000,7.000,0.000\n0,5,37,37,43,0.000,7.000,0.000\n0,6,37,37,37,0.000,7.000,0.000\n0,15,37,37,37,0.000,7.000,0.000\n0,18,37,37,37,0.000,7.000,0.000\n0,37,37,37,37,0.000,7.000,0.000\n0,37,37,37,40,0.000,7.000,0.000\n0,37,37,37,43,0.000,7.000,0.000\n0,0,37,38,0,0.000,7.000,0.000\n0,0,37,39,0,0.000,3.600,0.000\n1,0,37,39,0,0.000,2.600,0.000\n0,0,37,40,0,0.000,4.000,0.000\n5,0,37,40,0,0.000,3.600,0.000\n0,37,37,40,1,0.000,4.095,0.382\n0,37,37,40,28,0.698,2.542,3.072\n0,0,37,41,0,0.000,1.800,0.000\n0,0,37,43,0,0.000,2.000,1.800\n5,0,37,43,0,0.000,3.600,0.000\n0,37,37,43,18,0.372,2.284,2.034\n0,37,37,43,28,0.000,1.694,1.508\n0,0,37,45,0,0.000,1.800,0.000\n0,0,37,46,0,0.000,1.800,0.000\n0,0,37,55,0,0.000,4.800,0.000\n0,0,37,56,0,0.000,4.800,0.000\n1,0,37,57,0,0.000,1.800,0.000\n0,0,37,58,0,0.000,6.000,0.000\n1,0,37,58,0,0.000,4.800,0.000\n0,0,37,62,0,0.000,3.600,0.000\n0,0,37,63,0,0.000,7.000,0.000\n1,0,37,63,0,0.000,1.800,0.000\n1,37,37,63,39,0.000,3.000,4.100\n1,37,37,63,44,0.000,3.000,2.100\n0,0,37,64,0,0.000,7.000,0.000\n1,0,37,64,0,0.000,1.800,0.000\n1,0,37,67,0,0.000,1.800,0.000\n0,0,37,69,0,0.000,7.000,0.000\n0,0,37,78,0,0.000,6.000,0.000\n0,0,37,81,0,0.000,6.000,0.000\n1,0,37,81,0,0.000,4.800,0.000\n0,0,38,38,0,0.000,7.000,0.000\n0,0,38,58,0,0.000,7.000,0.000\n0,0,38,63,0,0.000,7.000,0.000\n0,0,38,64,0,0.000,7.000,0.000\n0,0,38,69,0,0.000,6.000,0.000\n0,0,38,78,0,0.000,6.000,0.000\n0,0,39,40,0,0.000,0.000,0.000\n0,0,39,45,0,0.000,6.000,0.000\n0,0,39,63,0,0.000,4.000,0.000\n1,0,39,63,0,0.000,6.000,0.000\n5,0,39,63,0,0.000,3.600,0.000\n0,1,39,63,5,0.000,4.000,0.000\n0,1,39,63,64,0.000,4.000,0.000\n0,18,39,63,5,0.000,4.000,0.000\n0,18,39,63,64,0.000,4.000,0.000\n0,63,39,63,5,0.000,4.000,0.000\n0,63,39,63,64,0.000,4.000,0.000\n0,0,39,64,0,0.000,3.600,0.000\n1,0,39,64,0,0.000,6.000,0.000\n0,0,39,65,0,0.000,4.000,0.000\n0,0,39,78,0,0.000,3.600,0.000\n0,0,40,40,0,0.000,0.000,0.375\n0,0,40,45,0,0.000,3.600,0.000\n0,0,40,46,0,0.000,3.600,0.000\n0,0,40,54,0,0.000,3.600,0.000\n2,0,40,54,0,0.000,3.600,0.000\n0,0,40,63,0,0.000,3.600,0.000\n0,0,40,64,0,0.000,3.600,0.000\n0,0,40,78,0,0.000,3.600,0.000\n0,0,41,41,0,0.000,1.800,0.000\n0,0,41,55,0,0.000,4.800,0.000\n0,0,41,62,0,0.000,3.600,0.000\n0,0,41,80,0,0.000,1.800,0.000\n0,0,43,43,0,0.000,0.000,0.375\n0,0,43,45,0,0.000,3.600,0.000\n0,0,43,64,0,0.000,3.600,0.000\n0,0,44,57,0,0.000,7.000,0.000\n0,0,44,63,0,0.000,7.000,0.000\n0,0,44,65,0,0.000,7.000,0.000\n0,0,44,78,0,0.000,2.846,0.000\n0,0,44,80,0,0.000,2.846,0.000\n0,0,45,63,0,0.000,1.800,0.000\n0,0,45,64,0,0.000,1.800,0.000\n0,0,45,78,0,0.000,1.800,0.000\n0,0,55,57,0,0.000,10.000,0.000\n2,0,55,57,0,0.000,4.800,0.000\n5,0,55,57,0,0.000,4.800,0.000\n0,1,55,57,5,0.423,12.064,0.090\n0,1,55,57,55,-0.428,12.044,0.000\n0,36,55,57,5,-0.268,8.077,-0.806\n0,36,55,57,55,0.273,8.025,0.692\n0,0,55,62,0,0.000,3.600,0.000\n0,0,55,64,0,0.000,4.800,0.000\n0,0,55,80,0,0.000,4.800,0.000\n0,0,56,57,0,0.000,6.000,0.000\n0,1,56,57,56,0.000,6.886,-0.161\n0,36,56,57,56,0.000,4.688,0.107\n0,0,56,63,0,0.000,4.800,0.000\n0,0,56,80,0,0.000,4.800,0.000\n1,0,57,63,0,0.000,1.800,0.000\n1,0,57,64,0,0.000,1.800,0.000\n0,0,58,63,0,0.000,6.000,0.000\n0,0,58,64,0,0.000,6.000,0.000\n0,0,59,63,0,0.000,7.000,0.000\n0,0,59,65,0,0.000,7.000,0.000\n0,0,59,78,0,0.000,3.600,0.000\n0,0,59,80,0,0.000,3.600,0.000\n0,0,59,82,0,0.000,3.600,0.000\n0,0,62,63,0,0.000,3.600,0.000\n0,0,62,64,0,0.000,3.600,0.000\n1,0,63,63,0,0.000,1.800,0.000\n0,0,63,64,0,0.000,7.000,0.000\n0,5,63,64,5,0.000,7.000,0.000\n0,5,63,64,64,0.000,7.000,0.000\n0,39,63,64,5,0.000,7.000,0.000\n0,39,63,64,64,0.000,7.000,0.000\n0,0,63,66,0,0.000,7.000,0.000\n0,0,63,78,0,0.000,6.000,0.000\n0,0,63,81,0,0.000,6.000,0.000\n0,0,64,64,0,0.000,7.000,0.000\n1,0,64,64,0,0.000,1.800,0.000\n0,5,64,64,5,0.000,7.000,0.000\n0,5,64,64,63,0.000,7.000,0.000\n0,63,64,64,63,0.000,7.000,0.000\n0,0,64,65,0,0.000,7.000,0.000\n0,0,64,66,0,0.000,7.000,0.000\n0,0,64,78,0,0.000,6.000,0.000\n0,0,64,81,0,0.000,6.000,0.000\n5,0,64,81,0,0.000,6.000,0.000\n0,0,64,82,0,0.000,6.000,0.000\n0,0,65,66,0,0.000,7.000,0.000\n0,0,65,78,0,0.000,6.000,0.000\n0,0,65,81,0,0.000,6.000,0.000\n0,0,65,82,0,0.000,6.000,0.000\n0,0,66,66,0,0.000,7.000,0.000\n0,0,66,78,0,0.000,6.000,0.000\n0,0,66,81,0,0.000,6.000,0.000\n0,0,67,67,0,0.000,12.000,0.000\n5,0,67,67,0,0.000,12.000,0.000\n0,0,76,76,0,0.000,3.600,0.000\n0,0,76,78,0,0.000,3.600,0.000\n0,0,78,78,0,0.000,7.000,0.000\n0,0,78,79,0,0.000,6.000,0.000\n0,0,78,81,0,0.000,4.000,0.000\n0,0,79,79,0,0.000,6.000,0.000\n0,0,79,81,0,0.000,6.000,0.000\n0,0,80,81,0,0.000,4.000,0.000\n'));qlb.GG=true;}};U1(307,1,{},qlb.HG);_._minimise=function IG(a,b,c){return hlb.Oy(this.a,a,b);};_.getOCL=function JG(){return $wnd.OCL;};_.getTotalEnergy=function KG(){return ilb.Lz(this.a);};_.size=function MG(){return this.a.b.q;};qlb.BG=Hsb;qlb.CG=Isb;qlb.DG=qqb;qlb.EG=false;qlb.FG=false;qlb.GG=false;Ykb.XZ=w3(307);qlb.NG=function NG(a){clb._q.call(this,a.a);};U1(308,225,{},qlb.NG);V1(_,{acceptorCount:{'get':function OG(){return clb.Yq(this);}}});V1(_,{donorCount:{'get':function PG(){return clb.Zq(this);}}});V1(_,{logP:{'get':function QG(){return clb.$q(this);}}});V1(_,{logPString:{'get':function RG(){return qlb.zH(mlb.sD((new mlb.tD(),this.a)));}}});V1(_,{logS:{'get':function SG(){return mlb.VD((mlb.UD(),this.a));}}});V1(_,{logSString:{'get':function TG(){return qlb.zH(mlb.WD((mlb.UD(),this.a)));}}});V1(_,{polarSurfaceArea:{'get':function UG(){return mlb.ND((mlb.LD(),this.a));}}});V1(_,{polarSurfaceAreaString:{'get':function VG(){return qlb.zH(mlb.OD((mlb.LD(),this.a)));}}});V1(_,{rotatableBondCount:{'get':function WG(){return clb.Yn(this.a);}}});V1(_,{stereoCenterCount:{'get':function XG(){return clb.Qt(this.a);}}});Ykb.YZ=w3(308);qlb.YG=function YG(){};qlb.ZG=function ZG(a){return new rlb.vR(nlb.aF(a,null));};qlb.$G=function $G(a){return nlb.bF(a.a,false,0);};U1(309,1,{},qlb.YG);Ykb.ZZ=w3(309);qlb._G=function _G(a){this.a=new nlb.sF(a.a);};U1(310,1,{},qlb._G);_.getProducts=function aH(){var a,b,c,d;d=nlb.kF(this.a);if(d.length==0){return eW(Ykb.d$,[Llb,Ksb],[131,33],0,[0,0],2);}c=eW(Ykb.d$,[Llb,Ksb],[131,33],0,[d.length,d[0].length],2);for(a=0;a<d.length;a++){for(b=0;b<d[0].length;b++){kW(c[a],b,new rlb.fM(d[a][b]));}}return c;};_.setReactant=function bH(a,b){return nlb.qF(this.a,a,b.a);};Ykb.$Z=w3(310);qlb.mH=function mH(){qlb.mH=W1;qlb.lH=(!qlb.uH&&(qlb.uH=new qlb.xH()),qlb.uH);qlb.eH=(mlb.nE(),mlb.YD);};qlb.nH=function nH(){qlb.mH();new mlb.sE();};U1(311,1,{},qlb.nH);_.assessRisk=function oH(a,b){var c;return mlb.oE(a.a,(c=b,qlb.wH(qlb.lH),c));};_.getDetail=function pH(a,b){return qlb.zH(mlb.pE(a.a,b));};_.getOCL=function qH(){return $wnd.OCL;};qlb.cH=3;qlb.dH=2;qlb.fH=1;qlb.gH=0;qlb.hH=2;qlb.iH=0;qlb.jH=3;qlb.kH=1;Ykb._Z=w3(311);qlb.rH=function rH(a,b,c){this.a=new nlb.vF(a.a,b.a);};U1(312,1,{},qlb.rH);_.applyTransformation=function sH(a,b){nlb.tF(this.a,a.a,b);};_.setMolecule=function tH(a,b){return nlb.uF(this.a,a.a);};Ykb.a$=w3(312);qlb.vH=function vH(a){};qlb.wH=function wH(a){!a.a&&(a.a=new qlb.yH());return a.a;};qlb.xH=function xH(){qlb.vH(this);};U1(164,1,{},qlb.xH);_.a=null;qlb.uH=null;Ykb.c$=w3(164);qlb.yH=function yH(){};U1(220,1,{},qlb.yH);Ykb.b$=w3(220);qlb.zH=function zH(a){var b,c,d;d=a.a.a.length;b=qlb.BH(d);for(c=0;c<d;c++){$kb.BU(b,c,qlb.AH(dlb.Bi(a.a,c).a,dlb.Bi(a.a,c).b));}return b;};qlb.AH=function AH(a,b){return {type:b,value:a};};qlb.BH=function BH(a){return new Array(a);};rlb.bM=function bM(){rlb.bM=W1;rlb.aM=(!rlb.uT&&(rlb.uT=new rlb.xT()),rlb.uT);rlb._L=new plb.XF();rlb.hI=oW(aW(Ykb.l_,1),Xlb,2,6,['?','H','He','Li','Be','B','C','N','O','F','Ne','Na','Mg','Al','Si','P','S','Cl','Ar','K','Ca','Sc','Ti','V','Cr','Mn','Fe','Co','Ni','Cu','Zn','Ga','Ge','As','Se','Br','Kr','Rb','Sr','Y','Zr','Nb','Mo','Tc','Ru','Rh','Pd','Ag','Cd','In','Sn','Sb','Te','I','Xe','Cs','Ba','La','Ce','Pr','Nd','Pm','Sm','Eu','Gd','Tb','Dy','Ho','Er','Tm','Yb','Lu','Hf','Ta','W','Re','Os','Ir','Pt','Au','Hg','Tl','Pb','Bi','Po','At','Rn','Fr','Ra','Ac','Th','Pa','U','Np','Pu','Am','Cm','Bk','Cf','Es','Fm','Md','No','Lr','Rf','Db','Sg','Bh','Hs','Mt','Ds','Rg','Cn','Nh','Fl','Mc','Lv','Ts','Og',Qnb,Qnb,Qnb,Qnb,Qnb,Qnb,Qnb,Qnb,Qnb,Qnb,'R4','R5','R6','R7','R8','R9','R10','R11','R12','R13','R14','R15','R16','R1','R2','R3','A','A1','A2','A3',Qnb,Qnb,'D','T','X','R','H2','H+','Nnn','HYD','Pol',Qnb,Qnb,Qnb,Qnb,Qnb,Qnb,Qnb,Qnb,Qnb,Qnb,Qnb,'Ala','Arg','Asn','Asp','Cys','Gln','Glu','Gly','His','Ile','Leu','Lys','Met','Phe','Pro','Ser','Thr','Trp','Tyr','Val']);rlb.$L=oW(aW(Ykb.Y0,1),znb,6,15,[0,1,4,7,9,11,12,14,16,19,20,23,24,27,28,31,32,35,40,39,40,45,48,51,52,55,56,59,58,63,64,69,74,75,80,79,84,85,88,89,90,93,98,0,102,103,106,107,114,115,120,121,130,127,132,133,138,139,140,141,142,0,152,153,158,159,164,165,166,169,174,175,180,181,184,187,192,193,195,197,202,205,208,209,209,210,222,223,226,227,232,231,238,237,244,243,247,247,251,252,257,258,259,262,267,268,271,270,277,276,281,281,283,285,289,289,293,294,294,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,71,156,114,115,103,128,129,57,137,113,113,128,131,147,97,87,101,186,163,99]);rlb.VJ=oW(aW(Ykb.wX,2),Llb,9,0,[null,oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[0]),oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[4]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[0]),oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[4]),oW(aW(Ykb.wX,1),Fnb,6,15,[3,5]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,4,6]),oW(aW(Ykb.wX,1),Fnb,6,15,[1,3,5,7]),oW(aW(Ykb.wX,1),Fnb,6,15,[0]),oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),null,null,null,null,null,null,null,null,null,null,oW(aW(Ykb.wX,1),Fnb,6,15,[2,3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,4]),oW(aW(Ykb.wX,1),Fnb,6,15,[3,5]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,4,6]),oW(aW(Ykb.wX,1),Fnb,6,15,[1,3,5,7]),oW(aW(Ykb.wX,1),Fnb,6,15,[0,2]),oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),null,null,null,null,null,null,null,null,null,null,oW(aW(Ykb.wX,1),Fnb,6,15,[1,2,3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,4]),oW(aW(Ykb.wX,1),Fnb,6,15,[3,5]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,4,6]),oW(aW(Ykb.wX,1),Fnb,6,15,[1,3,5,7]),oW(aW(Ykb.wX,1),Fnb,6,15,[0,2,4,6]),oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2])]);rlb.mL=oW(aW(Ykb.wX,2),Llb,9,0,[null,oW(aW(Ykb.wX,1),Fnb,6,15,[1]),null,oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),null,null,oW(aW(Ykb.wX,1),Fnb,6,15,[-3]),oW(aW(Ykb.wX,1),Fnb,6,15,[-2]),oW(aW(Ykb.wX,1),Fnb,6,15,[-1]),null,oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),null,oW(aW(Ykb.wX,1),Fnb,6,15,[-3]),oW(aW(Ykb.wX,1),Fnb,6,15,[-2]),oW(aW(Ykb.wX,1),Fnb,6,15,[-1]),null,oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,3,4]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,3,4,5]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,3,6]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,3,4,7]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,3]),oW(aW(Ykb.wX,1),Fnb,6,15,[1,2]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,4]),oW(aW(Ykb.wX,1),Fnb,6,15,[-3,3,5]),oW(aW(Ykb.wX,1),Fnb,6,15,[-2]),oW(aW(Ykb.wX,1),Fnb,6,15,[-1]),null,oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[4]),oW(aW(Ykb.wX,1),Fnb,6,15,[3,5]),oW(aW(Ykb.wX,1),Fnb,6,15,[6]),oW(aW(Ykb.wX,1),Fnb,6,15,[4,6,7]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,4]),oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,4]),oW(aW(Ykb.wX,1),Fnb,6,15,[-3,3,5]),oW(aW(Ykb.wX,1),Fnb,6,15,[-2,4,6]),oW(aW(Ykb.wX,1),Fnb,6,15,[-1]),null,oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3,4]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[4]),oW(aW(Ykb.wX,1),Fnb,6,15,[5]),oW(aW(Ykb.wX,1),Fnb,6,15,[6]),oW(aW(Ykb.wX,1),Fnb,6,15,[4,6,7]),oW(aW(Ykb.wX,1),Fnb,6,15,[3,4]),oW(aW(Ykb.wX,1),Fnb,6,15,[3,4]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,4]),oW(aW(Ykb.wX,1),Fnb,6,15,[1,3]),oW(aW(Ykb.wX,1),Fnb,6,15,[1,2]),oW(aW(Ykb.wX,1),Fnb,6,15,[1,3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,4]),oW(aW(Ykb.wX,1),Fnb,6,15,[3,5]),oW(aW(Ykb.wX,1),Fnb,6,15,[-2,2,4]),oW(aW(Ykb.wX,1),Fnb,6,15,[-1,1]),null,oW(aW(Ykb.wX,1),Fnb,6,15,[1]),oW(aW(Ykb.wX,1),Fnb,6,15,[2]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[4]),oW(aW(Ykb.wX,1),Fnb,6,15,[4,5]),oW(aW(Ykb.wX,1),Fnb,6,15,[3,4,5,6]),oW(aW(Ykb.wX,1),Fnb,6,15,[3,4,5,6]),oW(aW(Ykb.wX,1),Fnb,6,15,[3,4,5,6]),oW(aW(Ykb.wX,1),Fnb,6,15,[3,4,5,6]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3,4]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,3]),oW(aW(Ykb.wX,1),Fnb,6,15,[2,3]),oW(aW(Ykb.wX,1),Fnb,6,15,[3])]);rlb.SH=oW(aW(Ykb.l_,1),Xlb,2,6,[Iob,Job,Kob]);};rlb.cM=function cM(a,b,c,d){return {x:a,y:b,width:c,height:d};};rlb.dM=function dM(){rlb.bM();rlb.eM.call(this,32,32,null);};rlb.eM=function eM(a,b,c){rlb.bM();c?this.a=c:this.a=new clb.Zt(a,b);};rlb.fM=function fM(a){rlb.bM();rlb.eM.call(this,0,0,a);};rlb.KM=function KM(a,b){return {molecule:a,map:b};};rlb.$M=function $M(a,b){rlb.bM();var c;typeof b===Lsb&&(b=true);typeof b===Nlb?c=rlb.aN(a,b):typeof b===Plb&&(c=rlb._M(a,b));return c;};rlb._M=function _M(a,b){return new rlb.fM(clb.cp(new clb.mp(false),a,b));};rlb.aN=function aN(a,b){return new rlb.fM(clb.bp(new clb.mp(b),a));};rlb.bN=function bN(a){rlb.bM();return new rlb.fM(clb.tq(new clb.Nq(),a));};rlb.cN=function cN(a){rlb.bM();var b,c,d;d=new clb.Oq();c=(d.j=null,clb.Lq(d,new Alb.q2(new Alb.u2(a)))?d.j:null);b=d.f==null?clb.In(d.j):d.f;return rlb.KM(new rlb.fM(c),b);};rlb.dN=function dN(a,b){rlb.bM();b=b||{};var c=!b.noCoordinates;var d=!b.noStereo;return rlb.eN(a,c,d);};rlb.eN=function eN(a,b,c){var d,e,f;f=new clb.ot();e=new rlb.dM();clb.gt(f,e.a,alb.qgb((d=a,alb.lgb(),d)),b,c);return e;};rlb.mN=function mN(a,b,c,d){rlb.bM();return clb.Lm(a,b,c,d);};rlb.nN=function nN(a,b){rlb.bM();return clb.Mm(a,b);};rlb.MN=function MN(a,b){rlb.bM();return clb.Nm(a,b);};rlb.oO=function oO(){rlb.bM();return clb.wj(),clb.wj(),clb.vj;};rlb.uP=function uP(a){rlb.bM();return clb.Om(a);};rlb.vP=function vP(a){rlb.bM();return clb.Pm(a);};rlb.SQ=function SQ(a){rlb.bM();clb.wj();clb.vj=a;};U1(33,1,{33:1},rlb.dM,rlb.eM,rlb.fM);_.addAtom=function gM(a){return clb.yj(this.a,a);};_.addBond=function hM(a,b){return clb.zj(this.a,a,b);};_.addFragment=function iM(a,b,c){clb.Um(this.a,a.a,b,c);};_.Lb=function jM(){flb.$w(this.a);};_.Mb=function kM(a){flb._w(this.a,a);};_.addImplicitHydrogens=function lM(a){a===undefined?this.Lb():this.Mb(a);};_.Nb=function mM(){flb.Hw();flb.Iw(this.a,1);};_.Ob=function nM(a){flb.Iw(this.a,a);};_.addMissingChirality=function oM(a){a===undefined?this.Nb():this.Ob(a);};_.addMolecule=function pM(a){return clb.Bj(this.a,a.a);};_.addOrChangeAtom=function qM(a,b,c,d,e,f,g){return clb.Dj(this.a,a,b,c,d,e,f,g);};_.addOrChangeBond=function rM(a,b,c){return clb.Ej(this.a,a,b,c);};_.addRing=function sM(a,b,c,d,e){return clb.Fj(this.a,a,b,c,d,e);};_.addRingToAtom=function uM(a,b,c,d){return clb.Gj(this.a,a,b,c,d);};_.addRingToBond=function vM(a,b,c,d){return clb.Hj(this.a,a,b,c,d);};_.addSubstituent=function wM(a,b){return clb.Ij(this.a,a.a,b);};_.calculateTorsion=function xM(a){return clb.Jj(this.a,a);};_.canonizeCharge=function yM(a){return clb.Wm(this.a,a,false);};_.changeAtom=function zM(a,b,c,d,e){return clb.Kj(this.a,a,b,c,d,e);};_.changeAtomCharge=function AM(a,b){return clb.Lj(this.a,a,b);};_.changeBond=function BM(a,b){return clb.Mj(this.a,a,b);};_.clear=function CM(){clb.Nj(this.a);};_.convertStereoBondsToSingleBonds=function DM(a){clb.Ym(this.a,a);};_.copyAtom=function EM(a,b,c,d){return clb.Pj(this.a,a.a,b,c,d);};_.copyBond=function FM(a,b,c,d,e,f){return clb.Rj(this.a,a.a,b,c,d,e,f);};_.copyMolecule=function GM(a){clb.Sj(this.a,a.a);};_.copyMoleculeByAtoms=function HM(a,b,c,d){clb.Zm(this.a,a.a,b,c,d);};_.copyMoleculeByBonds=function IM(a,b,c,d){return clb.$m(this.a,a.a,b,c,d);};_.copyMoleculeProperties=function JM(a){clb.Ft(this.a,a.a);};_.deleteAtom=function LM(a){clb.Uj(this.a,a);};_.deleteAtomOrBond=function MM(a,b){return clb.Vj(this.a,a,b);};_.deleteAtoms=function NM(a){return clb.Wj(this.a,a);};_.deleteBond=function OM(a){clb.Xj(this.a,a);};_.deleteBondAndSurrounding=function PM(a){clb.Yj(this.a,a);};_.deleteMarkedAtomsAndBonds=function QM(){return clb.Zj(this.a);};_.deleteMolecule=function RM(){clb.Nj(this.a);};_.deleteSelectedAtoms=function SM(){return clb.$j(this.a);};_.ensureHelperArrays=function TM(a){clb.Gt(this.a,a);};_.findAlleneCenterAtom=function UM(a){return clb.an(this.a,a);};_.findAlleneEndAtom=function VM(a,b){return clb.bn(this.a,a,b);};_.findAtom=function WM(a,b){return clb._j(this.a,a,b);};_.findBINAPChiralityBond=function XM(a){return clb.cn(this.a,a);};_.findBond=function YM(a,b){return clb.ak(this.a,a,b);};_.findRingSystem=function ZM(a,b,c,d){clb.dn(this.a,a,b,c,d);};_.getAbsoluteAtomParity=function fN(a){return clb.Ht(this.a,a);};_.getAbsoluteBondParity=function gN(a){return clb.It(this.a,a);};_.getAllAtoms=function hN(){return this.a.q;};_.getAllBonds=function iN(){return this.a.r;};_.getAllConnAtoms=function jN(a){return clb.gn(this.a,a);};_.getAllConnAtomsPlusMetalBonds=function kN(a){return clb.hn(this.a,a);};_.getAllHydrogens=function lN(a){return clb.jn(this.a,a);};_.getAromaticRingCount=function oN(){return clb.kn(this.a);};_.getAtomAbnormalValence=function pN(a){return clb.bk(this.a,a);};_.getAtomCIPParity=function qN(a){return clb.ck(this.a,a);};_.getAtomCharge=function rN(a){return clb.dk(this.a,a);};_.getAtomColor=function sN(a){return clb.ek(this.a,a);};_.getAtomCustomLabel=function tN(a){return clb.fk(this.a,a);};_.getAtomESRGroup=function uN(a){return clb.hk(this.a,a);};_.getAtomESRType=function vN(a){return clb.ik(this.a,a);};_.getAtomLabel=function wN(a){return clb.jk(this.a,a);};_.getAtomList=function xN(a){return clb.kk(this.a,a);};_.getAtomListString=function yN(a){return clb.lk(this.a,a);};_.getAtomMapNo=function zN(a){return clb.mk(this.a,a);};_.getAtomMass=function AN(a){return clb.nk(this.a,a);};_.getAtomParity=function BN(a){return clb.ok(this.a,a);};_.getAtomPi=function CN(a){return clb.mn(this.a,a);};_.getAtomPreferredStereoBond=function DN(a){return clb.nn(this.a,a);};_.getAtomRadical=function EN(a){return clb.qk(this.a,a);};_.getAtomRingBondCount=function FN(a){return clb.on(this.a,a);};_.getAtomRingCount=function GN(a,b){return clb.pn(this.a,a,b);};_.getAtomRingSize=function HN(a){return clb.qn(this.a,a);};_.getAtomX=function IN(a){return clb.rk(this.a,a);};_.getAtomY=function JN(a){return clb.sk(this.a,a);};_.getAtomZ=function KN(a){return clb.tk(this.a,a);};_.getAtomicNo=function LN(a){return clb.uk(this.a,a);};_.getAtoms=function NN(){return this.a.f;};_.getAverageBondLength=function ON(a){return clb.rn(this.a,a);};_.getAverageTopologicalAtomDistance=function PN(){return clb.sn(this.a);};_.getBond=function QN(a,b){return clb.tn(this.a,a,b);};_.getBondAngle=function RN(a,b){return clb.yk(this.a,a,b);};_.getBondAtom=function SN(a,b){return clb.zk(this.a,a,b);};_.getBondBridgeMaxSize=function TN(a){return clb.Ak(this.a,a);};_.getBondBridgeMinSize=function UN(a){return clb.Bk(this.a,a);};_.getBondCIPParity=function VN(a){return clb.Ck(this.a,a);};_.getBondESRGroup=function WN(a){return clb.Dk(this.a,a);};_.getBondESRType=function XN(a){return clb.Ek(this.a,a);};_.getBondLength=function YN(a){return clb.Fk(this.a,a);};_.getBondOrder=function ZN(a){return clb.Hk(this.a,a);};_.getBondParity=function $N(a){return clb.Ik(this.a,a);};_.getBondPreferredStereoBond=function _N(a){return clb.Ho(this.a,a);};_.getBondQueryFeatures=function aO(a){return clb.Jk(this.a,a);};_.getBondRingSize=function bO(a){return clb.un(this.a,a);};_.getBondType=function cO(a){return clb.Kk(this.a,a);};_.getBondTypeSimple=function dO(a){return clb.Lk(this.a,a);};_.getBonds=function eO(){return this.a.g;};_.getBounds=function fO(){var a;a=clb.Mk(this.a,rlb._L);if(!a)return null;return rlb.cM(a.c,a.d,a.b,a.a);};_.getCanonizedIDCode=function gO(a){var b;b=new clb.bg(this.a,a);return clb.Gf(b);};_.getChiralText=function hO(){return clb.Jt(this.a);};_.getChirality=function iO(){return this.a.I;};_.getCompactCopy=function jO(){return new rlb.fM(clb.Kt(this.a));};_.getConnAtom=function kO(a,b){return clb.vn(this.a,a,b);};_.getConnAtoms=function lO(a){return clb.wn(this.a,a);};_.getConnBond=function mO(a,b){return clb.xn(this.a,a,b);};_.getConnBondOrder=function nO(a,b){return clb.yn(this.a,a,b);};_.getDefaultMaxValenceUncharged=function pO(a){return clb.Nk(this.a,a);};_.getDiastereotopicAtomIDs=function qO(){return flb.Jw(this.a);};_.getElectronValenceCorrection=function rO(a,b){return clb.Ok(this.a,a,b);};_.getExcludedNeighbourCount=function sO(a){return clb.zn(this.a,a);};_.getExplicitHydrogens=function tO(a){return clb.An(this.a,a);};_.getFinalRanks=function uO(a){var b;b=new clb.bg(this.a,a);return b.d;};_.getFisherProjectionParity=function vO(a,b,c,d){return clb.Cn(this.a,a,b,c,d);};_.getFragmentAtoms=function wO(a,b){return clb.Dn(this.a,a,b);};_.getFragmentNumbers=function xO(a,b,c){return clb.En(this.a,a,b,c);};_.getFragments=function yO(){var a,b,c;a=clb.Mt(this.a);c=gW(Ykb.d$,Ksb,33,a.length,0,1);for(b=0;b<a.length;b++){c[b]=new rlb.fM(a[b]);}return c;};_.getFreeValence=function zO(a){return clb.Gn(this.a,a);};_.getHandleHydrogenMap=function AO(){return clb.In(this.a);};_.getHelperArrayStatus=function BO(){return this.a.T;};_.getHoseCodes=function CO(a){a=a||{};var b=(typeof a.maxSphereSize===Lsb?5:a.maxSphereSize)|0;var c=(typeof a.type===Lsb?0:a.type)|0;return flb.Lw(this.a,b,c);};_.getIDCode=function DO(){var a;a=clb.Ot(this.a);a==null&&(a=clb.Gf(new clb.ag(this.a)));return a;};_.getIDCodeAndCoordinates=function EO(){return {idCode:this.getIDCode(),coordinates:this.getIDCoordinates()};};_.getIDCoordinates=function FO(){var a;a=clb.Pt(this.a);a==null&&(a=clb.Df(new clb.ag(this.a)));return a;};_.getImplicitHigherValence=function GO(a,b){return clb.Jn(this.a,a,b);};_.getImplicitHydrogens=function HO(a){return clb.Kn(this.a,a);};_.getIndex=function IO(){return clb.rs(rlb.wT(rlb.aM),this.a);};_.getLowestFreeValence=function JO(a){return clb.Ln(this.a,a);};_.getMaxAtoms=function KO(){return this.a.M;};_.getMaxBonds=function LO(){return this.a.N;};_.getMaxValence=function MO(a){return clb.Pk(this.a,a);};_.getMaxValenceUncharged=function NO(a){return clb.Qk(this.a,a);};_.getMetalBondedConnAtoms=function OO(a){return clb.Mn(this.a,a);};_.getMolecularFormula=function PO(){return new rlb.qT(this.a);};_.getMoleculeColor=function QO(){return this.a.O;};_.getMolweight=function RO(){return clb.Nn(this.a);};_.getName=function SO(){return this.a.P;};_.getNonHydrogenNeighbourCount=function TO(a){return clb.On(this.a,a);};_.getNumberOfHydrogens=function UO(){return flb.ax(this.a);};_.getOCL=function VO(){return $wnd.OCL;};_.getOccupiedValence=function WO(a){return clb.Pn(this.a,a);};_.getPath=function XO(a,b,c,d,e){return clb.Rn(this.a,a,b,c,d,null,e);};_.getPathBonds=function YO(a,b,c){clb.Sn(this.a,a,b,c);};_.getPathLength=function ZO(a,b){return clb.Tn(this.a,a,b);};_.getRingSet=function $O(){return new rlb.kS(clb.Xn(this.a));};_.getRotatableBondCount=function _O(){return clb.Yn(this.a);};_.Pb=function aP(a,b,c,d,e,f,g){var h,i,j,k,l,m,n,o,p,q,r;j=true;for(k=0;k<this.a.q-1;k++){if(clb.rk(this.a,k)!=clb.rk(this.a,k+1)||clb.sk(this.a,k)!=clb.sk(this.a,k+1)){j=false;break;}}m=j?clb.Kt(this.a):this.a;j&&glb.yx(new glb.Rx(0),m);l=rlb.yT(g);i=new clb.Ss(m,l,f);i.H=c;clb.Pd(i,new plb.YF(0,0,a,b));h=i.u;clb.Id(i);r=clb.Qs(i);if(d){o=I1(p1($wnd.Math.round(h.b+e*2)));n=I1(p1($wnd.Math.round(h.a+e*2)));p=I1(p1($wnd.Math.round(h.c-e)));q=I1(p1($wnd.Math.round(h.d-e)));return Zkb.m5(r,'width="\\d+px" height="\\d+px" viewBox="0 0 \\d+ \\d+"','width="'+o+'px" height="'+n+'px" viewBox="'+p+' '+q+' '+o+' '+n+'"');}else {return r;}};_.getStereoBond=function bP(a){return clb._n(this.a,a);};_.getStereoCenterCount=function cP(){return clb.Qt(this.a);};_.getStereoProblem=function dP(a){return clb.Sk(this.a,a);};_.getSubstituent=function eP(a,b,c,d,e){return clb.bo(this.a,a,b,c,d.a,e);};_.getSubstituentSize=function fP(a,b){return clb.co(this.a,a,b);};_.getSymmetryRank=function gP(a){return clb.Rt(this.a,a);};_.getZNeighbour=function hP(a,b){return clb.eo(this.a,a,b);};_.invalidateHelperArrays=function iP(a){clb.Vk(this.a,a);};_.inventCoordinates=function jP(){var a;a=new glb.Qx();a.g=new dlb.Zdb(0);glb.yx(a,this.a);clb.Po(this.a);};_.is3D=function kP(){return clb.Wk(this.a);};_.isAlkaliMetal=function lP(a){return clb.io(this.a,a);};_.isAllylicAtom=function mP(a){return clb.jo(this.a,a);};_.isAmideTypeBond=function nP(a){return clb.ko(this.a,a);};_.isAromaticAtom=function oP(a){return clb.lo(this.a,a);};_.isAromaticBond=function pP(a){return clb.mo(this.a,a);};_.isAtomConfigurationUnknown=function qP(a){return clb.Xk(this.a,a);};_.isAtomMarkedForDeletion=function rP(a){return clb.Yk(this.a,a);};_.isAtomParityPseudo=function sP(a){return clb.Zk(this.a,a);};_.isAtomStereoCenter=function tP(a){return clb.$k(this.a,a);};_.isAutoMappedAtom=function wP(a){return clb._k(this.a,a);};_.isBINAPChiralityBond=function xP(a){return clb.no(this.a,a);};_.isBondBackgroundHilited=function yP(a){return clb.al(this.a,a);};_.isBondBridge=function zP(a){return clb.bl(this.a,a);};_.isBondForegroundHilited=function AP(a){return clb.cl(this.a,a);};_.isBondMarkedForDeletion=function BP(a){return clb.dl(this.a,a);};_.isBondParityPseudo=function CP(a){return clb.el(this.a,a);};_.isBondParityUnknownOrNone=function DP(a){return clb.fl(this.a,a);};_.isChalcogene=function EP(a){return clb.po(this.a,a);};_.isDelocalizedBond=function FP(a){return clb.qo(this.a,a);};_.isEarthAlkaliMetal=function GP(a){return clb.ro(this.a,a);};_.isElectronegative=function HP(a){return clb.gl(this.a,a);};_.isElectropositive=function IP(a){return clb.hl(this.a,a);};_.isFlatNitrogen=function JP(a){return clb.so(this.a,a,true);};_.isFragment=function KP(){return this.a.K;};_.isHalogene=function LP(a){return clb.to(this.a,a);};_.isMarkedAtom=function MP(a){return clb.il(this.a,a);};_.isMetalAtom=function NP(a){return clb.jl(this.a,a);};_.isNaturalAbundance=function OP(a){return clb.kl(this.a,a);};_.isNitrogenFamily=function PP(a){return clb.uo(this.a,a);};_.isOrganicAtom=function QP(a){return clb.ll(this.a,a);};_.isPseudoRotatableBond=function RP(a){return clb.vo(this.a,a);};_.isPurelyOrganic=function SP(){return clb.ml(this.a);};_.isRingAtom=function TP(a){return clb.yo(this.a,a);};_.isRingBond=function UP(a){return clb.zo(this.a,a);};_.isSelectedAtom=function VP(a){return clb.nl(this.a,a);};_.isSelectedBond=function WP(a){return clb.ol(this.a,a);};_.isSimpleHydrogen=function XP(a){return clb.Ao(this.a,a);};_.isSmallRingAtom=function YP(a){return clb.Bo(this.a,a);};_.isSmallRingBond=function ZP(a){return clb.Co(this.a,a);};_.isStabilizedAtom=function $P(a){return clb.Do(this.a,a);};_.isStereoBond=function _P(a){return clb.pl(this.a,a);};_.markAtomForDeletion=function aQ(a){clb.sl(this.a,a);};_.markBondForDeletion=function bQ(a){clb.tl(this.a,a);};_.normalizeAmbiguousBonds=function cQ(){return clb.Eo(this.a);};_.removeAtomColors=function dQ(){clb.wl(this.a);};_.removeAtomCustomLabels=function eQ(){this.a.t=null;};_.removeAtomMarkers=function fQ(){clb.xl(this.a);};_.removeAtomSelection=function gQ(){clb.yl(this.a);};_.removeBondHiliting=function hQ(){clb.zl(this.a);};_.removeExplicitHydrogens=function iQ(a){clb.Jo(this.a,true);};_.removeQueryFeatures=function jQ(){return clb.Bl(this.a);};_.renumberESRGroups=function kQ(a){return clb.Cl(this.a,a);};_.scaleCoords=function lQ(a){clb.Dl(this.a,a);};_.setAllAtoms=function mQ(a){clb.El(this.a,a);};_.setAllBonds=function nQ(a){clb.Fl(this.a,a);};_.setAssignParitiesToNitrogen=function oQ(a){clb.St(this.a,a);};_.setAtomAbnormalValence=function pQ(a,b){clb.Gl(this.a,a,b);};_.setAtomCIPParity=function qQ(a,b){clb.Hl(this.a,a,b);};_.setAtomCharge=function rQ(a,b){clb.Il(this.a,a,b);};_.setAtomColor=function sQ(a,b){clb.Jl(this.a,a,b);};_.setAtomConfigurationUnknown=function tQ(a,b){clb.Kl(this.a,a,b);};_.setAtomCustomLabel=function uQ(a,b){clb.Ll(this.a,a,b);};_.setAtomESR=function vQ(a,b,c){clb.Nl(this.a,a,b,c);};_.setAtomList=function wQ(a,b,c){clb.Pl(this.a,a,b,c);};_.setAtomMapNo=function xQ(a,b,c){clb.Ql(this.a,a,b,c);};_.setAtomMarker=function yQ(a,b){clb.Rl(this.a,a,b);};_.setAtomMass=function zQ(a,b){clb.Sl(this.a,a,b);};_.setAtomParity=function AQ(a,b,c){clb.Tl(this.a,a,b,c);};_.setAtomRadical=function BQ(a,b){clb.Vl(this.a,a,b);};_.setAtomSelection=function CQ(a,b){clb.Wl(this.a,a,b);};_.setAtomX=function DQ(a,b){clb.Yl(this.a,a,b);};_.setAtomY=function EQ(a,b){clb.Zl(this.a,a,b);};_.setAtomZ=function FQ(a,b){clb.$l(this.a,a,b);};_.setAtomicNo=function GQ(a,b){clb._l(this.a,a,b);};_.setBondAtom=function HQ(a,b,c){clb.am(this.a,a,b,c);};_.setBondBackgroundHiliting=function IQ(a,b){clb.bm(this.a,a,b);};_.setBondCIPParity=function JQ(a,b){clb.cm(this.a,a,b);};_.setBondESR=function KQ(a,b,c){clb.dm(this.a,a,b,c);};_.setBondForegroundHiliting=function LQ(a,b){clb.em(this.a,a,b);};_.setBondOrder=function MQ(a,b){clb.fm(this.a,a,b);};_.setBondParity=function NQ(a,b,c){clb.gm(this.a,a,b,c);};_.setBondParityUnknownOrNone=function OQ(a){clb.hm(this.a,a);};_.setBondQueryFeature=function PQ(a,b,c){clb.im(this.a,a,b,c);};_.setBondType=function QQ(a,b){clb.jm(this.a,a,b);};_.setChirality=function RQ(a){clb.km(this.a,a);};_.setFragment=function TQ(a){clb.lm(this.a,a);};_.setHelperValidity=function UQ(a){clb.mm(this.a,a);};_.setHydrogenProtection=function VQ(a){clb.nm(this.a,a);};_.setMaxAtoms=function WQ(a){clb.om(this.a,a);};_.setMaxBonds=function XQ(a){clb.pm(this.a,a);};_.setMoleculeColor=function YQ(a){clb.qm(this.a,a);};_.setName=function ZQ(a){clb.rm(this.a,a);};_.setParitiesValid=function $Q(a){clb.Mo(this.a,a);};_.setStereoBondFromAtomParity=function _Q(a){clb.No(this.a,a);};_.setStereoBondFromBondParity=function aR(a){clb.Oo(this.a,a);};_.setStereoBondsFromParity=function bR(){clb.Po(this.a);};_.setToRacemate=function cR(){this.a.L=true;};_.setUnknownParitiesToExplicitlyUnknown=function dR(){clb.Tt(this.a);};_.shareSameFragment=function eR(a,b){return clb.Tn(this.a,a,b)!=-1;};_.stripIsotopInfo=function fR(){return clb.um(this.a);};_.stripSmallFragments=function gR(a){return clb.Qo(this.a,a);};_.stripStereoInformation=function hR(){clb.Ut(this.a);};_.suggestBondType=function iR(a,b){return clb.vm(this.a,a,b);};_.supportsImplicitHydrogen=function jR(a){return clb.Ro(this.a,a);};_.swapAtoms=function kR(a,b){clb.wm(this.a,a,b);};_.swapBonds=function lR(a,b){clb.xm(this.a,a,b);};_.toIsomericSmiles=function mR(a){return clb.Dp(new clb.Mp(this.a,a));};_.toMolfile=function nR(){var a;a=new clb.nq(this.a);return a.a.a;};_.toMolfileV3=function oR(){var a;a=new clb.Sq(this.a);return a.a.a;};_.toSVG=function pR(a,b,c,d){if(!a||!b){throw new Error('Molecule#toSVG requires width and height to be specified');}d=d||{};var e=d.factorTextSize||1;var f=d.autoCrop===true;var g=typeof d.autoCropMargin===Lsb?5:d.autoCropMargin;var h=this.Pb(a,b,e,f,g,c,d);h=h.replace('<style>','<style> text {font-family: sans-serif;}');d.fontWeight&&(h=h.replace(/font-size=/g,'font-weight="'+d.fontWeight+'" font-size='));d.strokeWidth&&(h=h.replace(/stroke-width="[^"]+"/g,ymb+d.strokeWidth+'"'));return h;};_.toSmiles=function qR(){return clb.Ws(new clb.Zs(),this.a);};_.translateCoords=function rR(a,b){clb.ym(this.a,a,b);};_.validate=function sR(){clb.Wt(this.a);};_.zoomAndRotate=function tR(a,b,c){clb.Am(this.a,a,b,c);};_.zoomAndRotateInit=function uR(a,b){clb.Bm(this.a,a,b);};rlb.CH=32;rlb.DH=2;rlb.EH=4;rlb.FH=6;rlb.GH=64;rlb.HH=128;rlb.IH=1;rlb.JH=256;rlb.KH=8;rlb.LH=Nmb;rlb.MH=16;rlb.NH=lnb;rlb.OH=512;rlb.PH=Msb;rlb.QH=24;rlb.RH=Msb;rlb.TH=Kob;rlb.UH=Iob;rlb.VH=Job;rlb.WH=0;rlb.XH=3;rlb.YH=1;rlb.ZH=2;rlb._H=64;rlb.aI=384;rlb.bI=448;rlb.cI=192;rlb.dI=256;rlb.eI=0;rlb.fI=320;rlb.gI=128;rlb.iI=1;rlb.jI=2;rlb.kI=4;rlb.lI=0;rlb.mI=3;rlb.nI=1;rlb.oI=Hnb;rlb.pI=2;rlb.qI=1;rlb.rI=2;rlb.sI=Omb;rlb.tI=3;rlb.uI=25;rlb.vI=5;rlb.wI=39;rlb.xI=$mb;rlb.yI=Bmb;rlb.zI=jnb;rlb.AI=Lmb;rlb.BI=Mmb;rlb.CI=4;rlb.DI=7;rlb.EI=Kmb;rlb.FI=Jmb;rlb.GI=knb;rlb.HI=Imb;rlb.II=Aob;rlb.JI=5;rlb.KI=17;rlb.LI=Tmb;rlb.MI=kmb;rlb.NI=7;rlb.OI=32;rlb.QI=lnb;rlb.RI=46;rlb.SI=enb;rlb.TI=128;rlb.UI=Gnb;rlb.VI=Hmb;rlb.WI=Fob;rlb.XI=256;rlb.YI=tnb;rlb.ZI=Ynb;rlb.$I=Gob;rlb._I=512;rlb.aJ=snb;rlb.bJ=Ylb;rlb.cJ=16;rlb.dJ=Hob;rlb.eJ=Nmb;rlb.fJ=Inb;rlb.gJ=32;rlb.hJ=dnb;rlb.iJ=Wmb;rlb.jJ=64;rlb.kJ=4;rlb.lJ=8;rlb.mJ=Xnb;rlb.nJ=Wnb;rlb.oJ=134217728;rlb.pJ=3;rlb.qJ=14;rlb.rJ=Smb;rlb.sJ=lmb;rlb.tJ=mmb;rlb.uJ=nmb;rlb.vJ=omb;rlb.wJ=pmb;rlb.xJ=qmb;rlb.yJ=rmb;rlb.zJ=120;rlb.AJ=4;rlb.BJ=3;rlb.CJ=2;rlb.DJ=Jnb;rlb.EJ=Gsb;rlb.FJ=Jnb;rlb.GJ=fob;rlb.HJ=30;rlb.IJ=zob;rlb.JJ=inb;rlb.KJ=3;rlb.LJ=22;rlb.MJ=Knb;rlb.NJ=2;rlb.OJ=44;rlb.PJ=48;rlb.QJ=32;rlb.RJ=0;rlb.SJ=16;rlb.TJ=4;rlb.UJ=48;rlb.WJ=1;rlb.XJ=0;rlb.YJ=3;rlb.ZJ=2;rlb.$J=1;rlb._J=0;rlb.aK=3;rlb.bK=2;rlb.cK=hmb;rlb.dK=onb;rlb.eK=2;rlb.fK=21;rlb.gK=Wmb;rlb.hK=31;rlb.iK=5;rlb.jK=0;rlb.kK=nnb;rlb.lK=8;rlb.mK=7680;rlb.nK=4;rlb.oK=9;rlb.pK=9;rlb.qK=122880;rlb.rK=4;rlb.sK=13;rlb.tK=8;rlb.uK=2;rlb.vK=Lnb;rlb.wK=Inb;rlb.xK=16;rlb.yK=6291840;rlb.zK=23;rlb.AK=yob;rlb.BK=128;rlb.CK=32;rlb.DK=64;rlb.EK=96;rlb.FK=2;rlb.GK=5;rlb.HK=256;rlb.IK=Ymb;rlb.JK=3;rlb.KK=17;rlb.LK=384;rlb.MK=2;rlb.NK=7;rlb.OK=6291967;rlb.PK=1;rlb.QK=4;rlb.RK=386;rlb.SK=512;rlb.TK=64;rlb.UK=2;rlb.VK=129;rlb.WK=511;rlb.XK=127;rlb.YK=384;rlb.ZK=32;rlb.$K=8;rlb._K=16;rlb.aL=1;rlb.bL=4;rlb.cL=257;rlb.dL=458752;rlb.eL=Xmb;rlb.fL=Zlb;rlb.gL=tnb;rlb.hL=Gnb;rlb.iL=Ylb;rlb.jL=196608;rlb.kL=0;rlb.lL=327680;rlb.nL=24;rlb.oL=321;rlb.pL=6;rlb.qL=5;rlb.rL=32;rlb.sL=0;rlb.tL=1;rlb.uL=2;rlb.vL=16;rlb.wL=128;rlb.xL=1;rlb.yL=8;rlb.zL=4;rlb.AL=2;rlb.BL=32;rlb.CL=64;rlb.DL=248;rlb.EL=31;rlb.FL=1;rlb.GL=0;rlb.HL=15;rlb.IL=7;rlb.JL=3;rlb.KL=63;rlb.LL=95;rlb.ML=190;rlb.NL=16;rlb.OL=0;rlb.PL=1;rlb.QL=16;rlb.RL=256;rlb.SL=128;rlb.TL=8;rlb.UL=32;rlb.VL=4;rlb.WL=511;rlb.XL=64;rlb.YL=1;rlb.ZL=2;Ykb.d$=w3(33);rlb.vR=function vR(a){this.a=a;};rlb.ER=function ER(){return new rlb.vR(new nlb.TE());};rlb.FR=function FR(a,b){var c,d;d=gW(Ykb.uY,Bob,25,a.length,0,1);for(c=0;c<a.length;c++){d[c]=a[c].a;}return new rlb.vR(new nlb.VE(d,b));};rlb.GR=function GR(a){return new rlb.vR(llb.YC(a));};rlb.HR=function HR(a){var b,c;c=clb.it(new clb.ot(),alb.qgb((b=a,alb.lgb(),b)));return new rlb.vR(c);};U1(67,1,{},rlb.vR);_.addCatalyst=function wR(a){nlb.tE(this.a,a.a);};_.addCatalystAt=function xR(a,b){nlb.uE(this.a,a.a,b);};_.addProduct=function yR(a){nlb.vE(this.a,a.a);};_.addProductAt=function zR(a,b){nlb.wE(this.a,a.a,b);};_.addReactant=function AR(a){nlb.xE(this.a,a.a);};_.addReactantAt=function BR(a,b){nlb.yE(this.a,a.a,b);};_.clear=function CR(){nlb.zE(this.a);};_.clone=function DR(){return new rlb.vR(new nlb.UE(this.a));};_.getAverageBondLength=function IR(){return nlb.BE(this.a);};_.getCatalyst=function JR(a){return new rlb.fM(nlb.CE(this.a,a));};_.getCatalysts=function KR(){return this.a.a.a.length;};_.getHighestMapNo=function LR(){return nlb.DE(this.a);};_.getMergedCopy=function MR(){return new rlb.vR(nlb.EE(this.a));};_.getMolecule=function NR(a){return new rlb.fM(nlb.FE(this.a,a));};_.getMolecules=function OR(){return nlb.GE(this.a);};_.getName=function PR(){return nlb.HE(this.a);};_.getOCL=function QR(){return $wnd.OCL;};_.getProduct=function RR(a){return new rlb.fM(nlb.IE(this.a,a));};_.getProducts=function SR(){return this.a.f.a.length;};_.getReactant=function TR(a){return new rlb.fM(nlb.JE(this.a,a));};_.getReactants=function UR(){return this.a.g.a.length;};_.getReactionCenterMapNos=function VR(){return nlb.KE(this.a);};_.isEmpty=function WR(){return nlb.LE(this.a);};_.isFragment=function XR(){return nlb.ME(this.a);};_.isPerfectlyMapped=function YR(){return nlb.NE(this.a);};_.isReactionLayoutRequired=function ZR(){return nlb.OE(this.a);};_.removeCatalysts=function $R(){alb.igb(this.a.a.a,0);};_.setFragment=function _R(a){nlb.QE(this.a,a);};_.setName=function aS(a){nlb.RE(this.a,a);};_.toRxn=function bS(a){var b;b=new llb.XC(this.a,a);return b.a?b.a.a:null;};_.toRxnV3=function cS(a){var b;b=new llb.cD(this.a,a);return b.a?b.a.a:null;};_.toSmiles=function dS(){return clb.Np(this.a);};_.validateMapping=function eS(){nlb.SE(this.a);};Ykb.e$=w3(67);rlb.kS=function kS(a){this.a=a;};U1(214,1,{},rlb.kS);_.determineAromaticity=function lS(a,b,c,d){clb.dr(this.a,a,b,c,d);};_.getAtomIndex=function mS(a,b){return clb.fr(this.a,a,b);};_.getAtomRingSize=function nS(a){return clb.gr(this.a,a);};_.getBondIndex=function oS(a,b){return clb.hr(this.a,a,b);};_.getBondRingSize=function pS(a){return clb.ir(this.a,a);};_.getHeteroPosition=function qS(a){return clb.jr(this.a,a);};_.getOCL=function rS(){return $wnd.OCL;};_.getRingAtoms=function sS(a){return clb.kr(this.a,a);};_.getRingBonds=function tS(a){return clb.lr(this.a,a);};_.getRingSize=function uS(a){return clb.nr(this.a,a);};_.getSharedRing=function vS(a,b){return clb.or(this.a,a,b);};_.getSize=function wS(){return this.a.i.a.length;};_.isAromatic=function xS(a){return clb.qr(this.a,a);};_.isAtomMember=function yS(a,b){return clb.tr(this.a,a,b);};_.isBondMember=function zS(a,b){return clb.ur(this.a,a,b);};_.isDelocalized=function AS(a){return clb.vr(this.a,a);};_.qualifiesAsAmideTypeBond=function BS(a){return clb.yr(this.a,a);};_.validateMemberIndex=function CS(a,b){return clb.Er(this.a,a,b);};rlb.fS=7;rlb.gS=3;rlb.hS=7;rlb.iS=5;rlb.jS=1;Ykb.f$=w3(214);rlb.DS=function DS(a,b){this.a=new llb.mD(new Alb.u2(a),b);};U1(313,1,{},rlb.DS);_.getField=function ES(a){var b,c;c=llb.jD(this.a);for(b=0;b<c.length;b++){if(Zkb.c5(c[b],a)){return llb.iD(this.a,b);}}return null;};_.getFieldData=function FS(a){return llb.iD(this.a,a);};_.getFieldNames=function GS(a){return llb.kD(this.a,a);};_.getMolecule=function HS(){return new rlb.fM(llb.lD(this.a));};_.getNextFieldData=function IS(){var a;return a=this.a.a.a,a;};_.getNextMolFile=function JS(){var a;return a=this.a.f.a,a;};_.getOCL=function KS(){return $wnd.OCL;};_.next=function LS(){return llb.fD(this.a);};Ykb.g$=w3(313);rlb.MS=function MS(a){a.a=new clb.js();};rlb.NS=function NS(a,b){clb.bs(a.a,b.a);};rlb.OS=function OS(a,b){clb.ds(a.a,b.a);};rlb.PS=function PS(){rlb.MS(this);};U1(315,1,{},rlb.PS);_.getOCL=function QS(){return $wnd.OCL;};_.isFragmentInMolecule=function RS(){return clb.Yr(this.a);};_.setFragment=function SS(a){rlb.NS(this,a);};_.setMol=function TS(a,b){clb.ds(this.a,b.a);clb.bs(this.a,a.a);};_.setMolecule=function US(a){rlb.OS(this,a);};Ykb.i$=w3(315);rlb.VS=function VS(a){a.a=new clb.zs();};rlb.WS=function WS(){rlb.VS(this);};rlb.XS=function XS(a){return i4(a);};rlb.ZS=function ZS(a){return clb.As(a);};rlb.$S=function $S(a){return clb.Bs(a);};rlb._S=function _S(){return clb.qs(),clb.os;};rlb.bT=function bT(a,b){return clb.Cs(a,b);};rlb.cT=function cT(a,b){return clb.Ds(a,b);};U1(316,1,{},rlb.WS);_.createIndex=function YS(a){return clb.rs(this.a,a.a);};_.getOCL=function aT(){return $wnd.OCL;};_.isFragmentInMolecule=function dT(){return clb.us(this.a);};_.setFragment=function eT(a,b){clb.xs(this.a,a.a,b);};_.setMolecule=function fT(a,b){clb.ys(this.a,a.a,b);};Ykb.h$=w3(316);rlb.gT=function gT(g,a){a=a||{};var b=a.smartsMode||'smiles';var c=a.createSmartsWarnings||false;var d=a.skipCoordinateTemplates||false;var e=a.makeHydrogenExplicit||false;var f=a.noCactvs||false;g.Qb(b,c,d,e,f);};rlb.hT=function hT(a){rlb.gT(this,a);};U1(317,1,{},rlb.hT);_.getSmartsWarning=function iT(){return clb.dt(this.a);};_.Qb=function jT(a,b,c,d,e){var f;f=0;switch(a){case'smarts':f=2;break;case'guess':f=1;}d&&(f|=8);c&&(f|=4);e&&(f|=16);this.a=new clb.pt(f,b);};_.Rb=function kT(a,b,c,d){var e;clb.gt(this.a,a.a,alb.qgb((e=b,alb.lgb(),e)),c,d);return a;};_.parseMolecule=function lT(a,b){b=b||{};var c=b.molecule||new rlb.dM();var d=!b.noCoordinates;var e=!b.noStereo;return this.Rb(c,a,d,e);};_.parseReaction=function mT(a){return new rlb.vR(clb.ht(this.a,a));};_.setRandomSeed=function nT(a){clb.mt(this.a,Ykb.m1(a));};Ykb.j$=w3(317);rlb.oT=function oT(){};rlb.pT=function pT(a,b){b=b||{};var c=(typeof b.maxSphereSize===Lsb?5:b.maxSphereSize)|0;var d=(typeof b.type===Lsb?0:b.type)|0;return flb.Nw(a,c,d);};U1(318,1,{},rlb.oT);Ykb.k$=w3(318);rlb.qT=function qT(a){clb.$p();clb.cq.call(this,a);};U1(213,119,{119:1},rlb.qT);V1(_,{absoluteWeight:{'get':function rT(){return clb._p(this);}}});V1(_,{formula:{'get':function sT(){return clb.aq(this);}}});V1(_,{relativeWeight:{'get':function tT(){return clb.bq(this);}}});Ykb.l$=w3(213);rlb.vT=function vT(a){};rlb.wT=function wT(a){!a.a&&(a.a=new clb.zs());return a.a;};rlb.xT=function xT(){rlb.vT(this);};U1(210,1,{},rlb.xT);_.a=null;rlb.uT=null;Ykb.m$=w3(210);rlb.yT=function yT(a){if(!a)return 0;var b=0;a.inflateToMaxAVBL&&(b|=Ylb);a.inflateToHighResAVBL&&(b|=Gnb);a.chiralTextBelowMolecule&&(b|=0);a.chiralTextAboveMolecule&&(b|=tnb);a.chiralTextOnFrameTop&&(b|=snb);a.chiralTextOnFrameBottom&&(b|=rnb);a.noTabus&&(b|=1);a.showAtomNumber&&(b|=2);a.showBondNumber&&(b|=4);a.highlightQueryFeatures&&(b|=8);a.showMapping&&(b|=16);a.suppressChiralText&&(b|=32);a.suppressCIPParity&&(b|=64);a.suppressESR&&(b|=128);a.showSymmetryAny&&(b|=768);a.showSymmetrySimple&&(b|=256);a.showSymmetryStereoHeterotopicity&&(b|=512);a.noImplicitAtomLabelColors&&(b|=Nmb);a.noStereoProblem&&(b|=lnb);a.noColorOnESRAndCIP&&(b|=Imb);a.noImplicitHydrogen&&(b|=knb);a.drawBondsInGray&&(b|=Hmb);return b;};slb.zT=function zT(a,b){var c;c=a-b;c>=Fmb?c-=Emb:c<_nb&&(c+=Emb);return c;};slb.AT=function AT(a,b){var c;for(c=b;c<a.length;c++){if(a[c]==62)return c;}return -1;};slb.CT=function CT(){slb.CT=W1;slb.BT=oW(aW(Ykb.zX,1),cob,6,15,[0.29899999499320984,0.5870000123977661,0.11400000005960464]);};slb.DT=function DT(a,b){var c;c=gW(Ykb.zX,cob,6,4,15,1);c[0]=Nsb*((a&vnb)>>16);c[1]=Nsb*((a&imb)>>8);c[2]=Nsb*(a&255);slb.ET(c,b);return a&unb|vX($wnd.Math.round(c[0]*255))<<16|vX($wnd.Math.round(c[1]*255))<<8|vX($wnd.Math.round(c[2]*255));};slb.ET=function ET(a,b){var c,d,e,f,g,h,i,j;g=slb.BT[0]*a[0]+slb.BT[1]*a[1]+slb.BT[2]*a[2];if(g==0){a[0]=0;a[1]=0;a[2]=0;return;}c=b/g;j=0;i=0;for(e=0;e<3;e++){a[e]*=c;if(a[e]<1){i+=slb.BT[e];}else {j+=(a[e]-1)*slb.BT[e];a[e]=1;}}if(j!=0){h=0;for(f=0;f<3;f++){if(a[f]<1){a[f]+=j/i;if(a[f]>1){h+=(a[f]-1)*slb.BT[f];a[f]=1;}}}if(h!=0){for(d=0;d<3;d++){if(a[d]<1){a[d]+=h/slb.BT[d];a[d]>1&&(a[d]=1);}}}}};slb.FT=function FT(a,b){slb.CT();var c,d,e,f,g,h,i,j,k,l,m;c=(slb.BT[0]*((b&vnb)>>16)+slb.BT[1]*((b&imb)>>8)+slb.BT[2]*(b&255))/255;g=(slb.BT[0]*((a&vnb)>>16)+slb.BT[1]*((a&imb)>>8)+slb.BT[2]*(a&255))/255;e=$wnd.Math.abs(c-g);if(e>jmb)return a;h=ylb.d2(((b&vnb)>>16)/255,((b&imb)>>8)/255,(b&255)/255,null);i=ylb.d2(((a&vnb)>>16)/255,((a&imb)>>8)/255,(a&255)/255,null);j=$wnd.Math.abs(i[0]-h[0]);j>0.5&&(j=1-j);m=1-$wnd.Math.max(i[1],h[1]);d=$wnd.Math.abs(g+c-1);k=$wnd.Math.cos(Fmb*j*3);l=jmb*$wnd.Math.max(m,$wnd.Math.max(d,k));if(e>l)return a;f=g>c?g+l>1:g-l>0;return slb.DT(a,f?c-l:c+l);};slb.GT=function GT(a){slb.CT();var b,c,d;d=(a&vnb)>>16;c=(a&imb)>>8;b=a&255;return (d+vX($wnd.Math.round(jmb*(92-d)))<<16)+(c+vX($wnd.Math.round(jmb*(160-c)))<<8)+b+vX($wnd.Math.round(jmb*(255-b)));};slb.IT=function IT(){slb.IT=W1;slb.HT=oW(aW(Ykb.l_,1),Xlb,2,6,['','0','00','000','0000','00000','000000','0000000','00000000']);};slb.JT=function JT(a,b){slb.IT();var c,d,e,f;if(isNaN(a))return 'NaN';if(!isNaN(a)&&!isFinite(a))return 'Infinity';if(a==0)return '0';e=1;for(d=1;d<b;d++)e*=10;f=e*10;c=0;while($wnd.Math.abs(a)+0.5<e){a*=10;--c;}while($wnd.Math.abs(a)+0.5>=f){a/=10;++c;}return slb.KT(p1(a+(a<0?-0.5:0.5)),c,b,true);};slb.KT=function KT(a,b,c,d){var e,f,g,h,i,j;g=1;if(j1(a,0)==0)return d||c==1?'0':'0.'+slb.LT(c-1);if(j1(a,0)!=0){while(o1(w1(a,10),0)){a=n1(a,10);++b;}g=0;for(h=a;j1(h,0)!=0;h=n1(h,10))++g;}f=new Zkb.J5();j1(a,0)<0&&(f.a+='-',f);i=$wnd.Math.max(0,c-g);e=''+J1(j1(a,0)<0?y1(a):a);if(b==0){f.a+=e;if(!d&&i!=0){f.a+='.';Zkb.G5(f,slb.LT(i));}}else if(b>0){j=d?b>4:b-i>4;if(j){if(g==1){f.a+=e;if(c>1){f.a+='.';d?(f.a+='0',f):Zkb.G5(f,slb.LT(i));}}else {Zkb.G5(f,(alb.Jgb(0,1,alb.Pgb(e).length),alb.Pgb(e).substr(0,1)));f.a+='.';Zkb.G5(f,(alb.Kgb(1,alb.Pgb(e).length+1),alb.Pgb(e).substr(1)));!d&&i!=0&&Zkb.G5(f,slb.LT(i));}f.a+='e';f.a+=''+(b+g-1);}else {f.a+=e;Zkb.G5(f,slb.LT(b));if(!d&&i>b){f.a+='.';Zkb.G5(f,slb.LT(i-b));}}}else {if(-b<g){Zkb.G5(f,(alb.Jgb(0,g+b,alb.Pgb(e).length),alb.Pgb(e).substr(0,g+b)));f.a+='.';Zkb.G5(f,(alb.Kgb(g+b,alb.Pgb(e).length+1),alb.Pgb(e).substr(g+b)));!d&&i!=0&&Zkb.G5(f,slb.LT(i));}else if(-b==g){f.a+='0.';f.a+=e;!d&&i!=0&&Zkb.G5(f,slb.LT(i));}else {if(b+g<-2){if(g==1){f.a+=e;if(c>1){f.a+='.';d?(f.a+='0',f):Zkb.G5(f,slb.LT(i));}}else {Zkb.C5(f,(alb.Kgb(0,alb.Pgb(e).length),alb.Pgb(e).charCodeAt(0)));f.a+='.';Zkb.G5(f,(alb.Kgb(1,alb.Pgb(e).length+1),alb.Pgb(e).substr(1)));!d&&i!=0&&Zkb.G5(f,slb.LT(i));}f.a+='e-';f.a+=''+(1-b-g);}else {f.a+='0.';Zkb.G5(f,slb.LT(-b-g));f.a+=e;!d&&i!=0&&Zkb.G5(f,slb.LT(i));}}}return f.a;};slb.LT=function LT(a){var b;if(a<slb.HT.length)return slb.HT[a];b=new Zkb.J5();while(a>=slb.HT.length){Zkb.G5(b,slb.HT[slb.HT.length-1]);a-=slb.HT.length-1;}Zkb.G5(b,slb.HT[a]);return b.a;};slb.MT=function MT(a,b){var c;if(a==null)return b==null?0:1;if(b==null)return -1;for(c=0;c<a.length;c++){if(b.length==c)return 1;if(a[c]!=b[c])return a[c]<b[c]?-1:1;}return b.length>a.length?-1:0;};slb.NT=function NT(){};U1(120,1,fmb,slb.NT);_.pb=function OT(a,b){return slb.MT(a,b);};_.ib=function PT(a){return this===a;};Ykb.n$=w3(120);slb.QT=function QT(a){a.d=new dlb.Qi();};slb.RT=function RT(a,b){var c;c=slb.UT(a,b);if(c<0){c=-(c+1);dlb.vi(a.d,c,b);}return c;};slb.ST=function ST(a,b,c){return a.c?dlb.ycb(b,c):Zkb.U2(b,c);};slb.TT=function TT(a,b){return b<0?null:dlb.Bi(a.d,b);};slb.UT=function UT(a,b){var c,d,e,f;f=a.d.a.length;if(f==0){return -1;}e=1;while(2*e<=f)e<<=1;d=e;--e;while(d!=0){d>>=1;if(e>=f){e-=d;continue;}c=slb.ST(a,b,dlb.Bi(a.d,e));if(c==0)return e;if(d==0)break;c<0?e-=d:e+=d;}e<f&&slb.ST(a,b,dlb.Bi(a.d,e))>0&&++e;return -(e+1);};slb.VT=function VT(a,b){dlb.Ii(a.d,b);};slb.WT=function WT(){slb.XT.call(this,null);};slb.XT=function XT(a){slb.QT(this);this.c=a;};U1(78,1,{},slb.WT,slb.XT);Ykb.o$=w3(78);slb.YT=function YT(a){a.b=new dlb.Qi();};slb.ZT=function ZT(a,b){var c,d;d=a.d.a.length;c=slb.RT(a,b);if(a.d.a.length!=d){dlb.wi(a.b,b);a.a=null;return d;}a.a==null&&slb.$T(a);return a.a[c];};slb.$T=function $T(a){var b,c,d,e;a.a=gW(Ykb.AX,gmb,6,a.d.a.length,15,1);b=0;for(e=new dlb.Obb(a.b);e.a<e.c.a.length;){d=dlb.Nbb(e);a.a[(c=slb.UT(a,d),c<0?-1:c)]=b++;}};slb._T=function _T(){slb.WT.call(this);slb.YT(this);};U1(279,78,fmb,slb._T);Ykb.p$=w3(279);_kb.dU=function dU(a){Zkb.bU.call(this,a);};U1(248,100,Vlb);Ykb.t$=w3(248);$kb.fU=function fU(){$kb.fU=W1;$kb.eU=new Ec();};$kb.gU=function gU(a){a.a='';};$kb.hU=function hU(a){var b;if(a.c==null){b=uX(a.b)===uX($kb.eU)?null:a.b;a.d=b==null?Slb:pX(b)?$kb.mU(b):rX(b)?'String':Zkb.q3(Zkb.Ic(b));a.a=a.a+': '+(pX(b)?$kb.lU(b):b+'');a.c='('+a.d+') '+a.a;}};$kb.iU=function iU(a){return uX(a.b)===uX($kb.eU)?null:a.b;};$kb.jU=function jU(a){$kb.fU();$kb.kU.call(this,a);};$kb.kU=function kU(a){_kb.dU.call(this,a);$kb.gU(this);this.b=a;this.a='';};$kb.lU=function lU(a){return a==null?null:a.message;};$kb.mU=function mU(a){return a==null?null:a.name;};U1(125,248,{125:1,4:1,15:1,22:1},$kb.jU);_.Gb=function nU(){$kb.hU(this);return this.c;};_.Sb=function oU(){return $kb.iU(this);};Ykb.q$=w3(125);$kb.yU=function yU(b,a){return b[a];};$kb.zU=function zU(a){return a.length;};$kb.AU=function AU(b,a){b[b.length]=a;};$kb.BU=function BU(c,a,b){c[a]=b;};$kb.CU=function CU(b,a){return b[a];};$kb.DU=function DU(a){return a.length;};$kb.EU=function EU(){return Date.now();};U1(298,1,{});Ykb.s$=w3(298);_kb.IU=function IU(){_kb.IU=W1;!!(_kb.bV(),_kb.aV);};_kb.JU=function JU(a,b,c){return a.apply(b,c);};_kb.KU=function KU(){var a;if(FU!=0){a=$kb.EU();if(a-GU>2000){GU=a;HU=_kb.RU();}}if(FU++==0){_kb.UU((_kb.TU(),_kb.SU));return true;}return false;};function LU(b){_kb.IU();return function(){return _kb.MU(b,this,arguments);};}_kb.MU=function MU(a,b,c){var d;d=_kb.KU();try{return _kb.JU(a,b,c);}finally{_kb.NU(d);}};_kb.NU=function NU(a){a&&_kb.VU((_kb.TU(),_kb.SU));--FU;if(a){if(HU!=-1){_kb.PU(HU);HU=-1;}}};_kb.OU=function OU(a){_kb.IU();$wnd.setTimeout(function(){throw a;},0);};_kb.PU=function PU(a){$wnd.clearTimeout(a);};_kb.QU=function QU(){FU!=0&&(FU=0);HU=-1;};_kb.RU=function RU(){return $wnd.setTimeout(_kb.QU,10);};var FU=0;var GU=0;var HU=-1;_kb.TU=function TU(){_kb.TU=W1;_kb.SU=new _kb.WU();};_kb.UU=function UU(a){var b,c;if(a.a){c=null;do{b=a.a;a.a=null;c=_kb.YU(b,c);}while(a.a);a.a=c;}};_kb.VU=function VU(a){var b,c;if(a.b){c=null;do{b=a.b;a.b=null;c=_kb.YU(b,c);}while(a.b);a.b=c;}};_kb.WU=function WU(){};_kb.XU=function XU(a,b){!a&&(a=$kb.uU());$kb.AU(a,b);return a;};_kb.YU=function YU(b,c){var d,e,f,g;for(e=0,f=$kb.zU(b);e<f;e++){g=$kb.yU(b,e);try{_kb._U(g)?_kb.ZU(g).vc()&&(c=_kb.XU(c,g)):_kb.$U(g).vc();}catch(a){a=b1(a);if(mX(a,22)){d=a;_kb.IU();_kb.OU(mX(d,125)?d.Sb():d);}else throw c1(a);}}return c;};U1(292,298,{},_kb.WU);Ykb.u$=w3(292);_kb.ZU=function ZU(a){return a[0];};_kb.$U=function $U(a){return a[0];};_kb._U=function _U(a){return a[1];};tlb.vV=function vV(a){return a.compatMode;};tlb.wV=function wV(){return $doc;};ulb.xV=function xV(){return ['USD','US$',2,'US$','$'];};ulb.zV=function zV(){ulb.zV=W1;ulb.yV=new ulb.BV();};ulb.AV=function AV(a){!a.a&&(a.a=new vlb.WV());return a.a;};ulb.BV=function BV(){};U1(295,1,{},ulb.BV);Ykb.z$=w3(295);ulb.CV=function CV(){ulb.CV=W1;ulb.AV((ulb.zV(),ulb.zV(),ulb.yV));};ulb.DV=function DV(a){};ulb.EV=function EV(a,b){var c,d;b.a+='E';if(a.e<0){a.e=-a.e;b.a+='-';}c=''+a.e;for(d=alb.Pgb(c).length;d<a.k;++d){b.a+='0';}b.a+=c;};ulb.FV=function FV(a,b,c){if(a.d==0){Zkb.I5(b,0,String.fromCharCode(48));++a.b;++a.d;}if(a.b<a.d||a.c){Zkb.I5(b,a.b,String.fromCharCode(c));++a.d;}};ulb.GV=function GV(a,b){var c,d;c=a.b+a.n;if(a.d<c){while(a.d<c){b.a+='0';++a.d;}}else {d=a.b+a.i;d>a.d&&(d=a.d);while(d>c&&Zkb.X4(b.a,d-1)==48){--d;}if(d<a.d){Zkb.H5(b,d,a.d);a.d=d;}}};ulb.HV=function HV(a,b){var c,d;d=0;while(d<a.d-1&&Zkb.X4(b.a,d)==48){++d;}if(d>0){Zkb.z2(b,0,d,'');a.d-=d;a.e-=d;}if(a.j>a.o&&a.j>0){a.e+=a.b-1;c=a.e%a.j;c<0&&(c+=a.j);a.b=c+1;a.e-=c;}else {a.e+=a.b-a.o;a.b=a.o;}if(a.d==1&&Zkb.X4(b.a,0)==48){a.e=0;a.b=a.o;}};ulb.IV=function IV(a,b){var c,d,e,f;if(isNaN(b)){return 'NaN';}d=b<0||b==0&&1/b<0;d&&(b=-b);c=new Zkb.J5();if(!isNaN(b)&&!isFinite(b)){Zkb.G5(c,d?a.q:a.t);c.a+='\u221E';Zkb.G5(c,d?a.r:a.u);return c.a;}b*=a.p;f=ulb.VV(c,b);e=alb.Pgb(c.a).length+f+a.i+3;if(e>0&&e<alb.Pgb(c.a).length&&Zkb.X4(c.a,e)==57){ulb.QV(a,c,e-1);f+=alb.Pgb(c.a).length-e;Zkb.H5(c,e,alb.Pgb(c.a).length);}ulb.JV(a,d,c,f);return c.a;};ulb.JV=function JV(a,b,c,d){var e,f,g,h,i;if(a.g){f=(alb.Kgb(0,alb.Pgb('.').length),alb.Pgb('.').charCodeAt(0));g=(alb.Kgb(0,alb.Pgb(',').length),alb.Pgb(',').charCodeAt(0));}else {f=(alb.Kgb(0,alb.Pgb('.').length),alb.Pgb('.').charCodeAt(0));g=(alb.Kgb(0,alb.Pgb(',').length),alb.Pgb(',').charCodeAt(0));}a.e=0;a.d=alb.Pgb(c.a).length;a.b=a.d+d;h=a.v;e=a.f;a.b>Nmb&&(h=true);h&&ulb.HV(a,c);ulb.PV(a,c);ulb.RV(a,c);ulb.KV(a,c,g,e);ulb.GV(a,c);ulb.FV(a,c,f);h&&ulb.EV(a,c);i=(alb.Kgb(0,alb.Pgb('0').length),alb.Pgb('0').charCodeAt(0));i!=48&&ulb.LV(c,i);Zkb.I5(c,0,b?a.q:a.t);Zkb.G5(c,b?a.r:a.u);};ulb.KV=function KV(a,b,c,d){var e;if(d>0){for(e=d;e<a.b;e+=d+1){Zkb.I5(b,a.b-e,String.fromCharCode(c));++a.b;++a.d;}}};ulb.LV=function LV(a,b){var c,d,e;e=alb.Pgb(a.a).length;for(d=0;d<e;++d){c=Zkb.X4(a.a,d);c>=48&&c<=57&&Zkb.A2(a,d,c-48+b&Zlb);}};ulb.MV=function MV(a,b,c,d,e){var f,g,h,i;Zkb.H5(d,0,alb.Pgb(d.a).length);g=false;h=alb.Pgb(b).length;for(i=c;i<h;++i){f=(alb.Kgb(i,alb.Pgb(b).length),alb.Pgb(b).charCodeAt(i));if(f==39){if(i+1<h&&(alb.Kgb(i+1,alb.Pgb(b).length),alb.Pgb(b).charCodeAt(i+1)==39)){++i;d.a+="'";}else {g=!g;}continue;}if(g){d.a+=String.fromCharCode(f);}else {switch(f){case 35:case 48:case 44:case 46:case 59:return i-c;case 164:a.g=true;if(i+1<h&&(alb.Kgb(i+1,alb.Pgb(b).length),alb.Pgb(b).charCodeAt(i+1)==164)){++i;if(i<h-2&&(alb.Kgb(i+1,alb.Pgb(b).length),alb.Pgb(b).charCodeAt(i+1)==164)&&(alb.Kgb(i+2,alb.Pgb(b).length),alb.Pgb(b).charCodeAt(i+2)==164)){i+=2;Zkb.G5(d,wlb.$V(a.a));}else {Zkb.G5(d,wlb.XV(a.a));}}else {Zkb.G5(d,wlb.YV(a.a));}break;case 37:if(!e){if(a.p!=1){throw c1(new Zkb.c4(Osb+b+'"'));}a.p=100;}d.a+='%';break;case 8240:if(!e){if(a.p!=1){throw c1(new Zkb.c4(Osb+b+'"'));}a.p=1000;}d.a+='\u2030';break;case 45:d.a+='-';break;default:d.a+=String.fromCharCode(f);}}}return h-c;};ulb.NV=function NV(a,b){var c,d;d=0;c=new Zkb.J5();d+=ulb.MV(a,b,d,c,false);a.t=c.a;d+=ulb.OV(a,b,d,false);d+=ulb.MV(a,b,d,c,false);a.u=c.a;if(d<alb.Pgb(b).length&&(alb.Kgb(d,alb.Pgb(b).length),alb.Pgb(b).charCodeAt(d)==59)){++d;d+=ulb.MV(a,b,d,c,true);a.q=c.a;d+=ulb.OV(a,b,d,true);d+=ulb.MV(a,b,d,c,true);a.r=c.a;}else {a.q='-'+a.t;a.r=a.u;}};ulb.OV=function OV(a,b,c,d){var e,f,g,h,i,j,k,l,m,n,o,p;f=-1;g=0;p=0;h=0;j=-1;k=alb.Pgb(b).length;n=c;l=true;for(;n<k&&l;++n){e=(alb.Kgb(n,alb.Pgb(b).length),alb.Pgb(b).charCodeAt(n));switch(e){case 35:p>0?++h:++g;j>=0&&f<0&&++j;break;case 48:if(h>0){throw c1(new Zkb.c4("Unexpected '0' in pattern \""+b+'"'));}++p;j>=0&&f<0&&++j;break;case 44:j=0;break;case 46:if(f>=0){throw c1(new Zkb.c4('Multiple decimal separators in pattern "'+b+'"'));}f=g+p+h;break;case 69:if(!d){if(a.v){throw c1(new Zkb.c4('Multiple exponential symbols in pattern "'+b+'"'));}a.v=true;a.k=0;}while(n+1<k&&(alb.Kgb(n+1,alb.Pgb(b).length),alb.Pgb(b).charCodeAt(n+1)==48)){++n;d||++a.k;}if(!d&&g+p<1||a.k<1){throw c1(new Zkb.c4('Malformed exponential pattern "'+b+'"'));}l=false;break;default:--n;l=false;}}if(p==0&&g>0&&f>=0){m=f;m==0&&++m;h=g-m;g=m-1;p=1;}if(f<0&&h>0||f>=0&&(f<g||f>g+p)||j==0){throw c1(new Zkb.c4('Malformed pattern "'+b+'"'));}if(d){return n-c;}o=g+p+h;a.i=f>=0?o-f:0;if(f>=0){a.n=g+p-f;a.n<0&&(a.n=0);}i=f>=0?f:o;a.o=i-g;if(a.v){a.j=g+a.o;a.i==0&&a.o==0&&(a.o=1);}a.f=j>0?j:0;a.c=f==0||f==o;return n-c;};ulb.PV=function PV(a,b){var c,d,e;if(a.b>a.d){while(a.d<a.b){b.a+='0';++a.d;}}if(!a.v){if(a.b<a.o){d=new Zkb.J5();while(a.b<a.o){d.a+='0';++a.b;++a.d;}Zkb.I5(b,0,d.a);}else if(a.b>a.o){e=a.b-a.o;for(c=0;c<e;++c){if(Zkb.X4(b.a,c)!=48){e=c;break;}}if(e>0){Zkb.z2(b,0,e,'');a.d-=e;a.b-=e;}}}};ulb.QV=function QV(a,b,c){var d,e;d=true;while(d&&c>=0){e=Zkb.X4(b.a,c);if(e==57){Zkb.A2(b,c--,48);}else {Zkb.A2(b,c,e+1&Zlb);d=false;}}if(d){Zkb.I5(b,0,String.fromCharCode(49));++a.b;++a.d;}};ulb.RV=function RV(a,b){var c;if(a.d>a.b+a.i&&Zkb.y2(b,a.b+a.i)>=53){c=a.b+a.i-1;ulb.QV(a,b,c);}};ulb.SV=function SV(a,b,c){ulb.DV(this);if(!b){throw c1(new Zkb.c4('Unknown currency code'));}this.s=a;this.a=b;ulb.NV(this,this.s);if(!c&&this.g){this.n=wlb.ZV(this.a)&7;this.i=this.n;}};ulb.TV=function TV(a,b){ulb.CV();ulb.SV.call(this,a,b,true);};ulb.UV=function UV(a,b){return a.toPrecision(b);};ulb.VV=function VV(a,b){var c,d,e,f,g;g=alb.Pgb(a.a).length;Zkb.G5(a,ulb.UV(b,20));f=0;e=Zkb.h5(a.a,'e',g);e<0&&(e=Zkb.h5(a.a,'E',g));if(e>=0){d=e+1;d<alb.Pgb(a.a).length&&Zkb.X4(a.a,d)==43&&++d;d<alb.Pgb(a.a).length&&(f=Zkb.P3(Zkb.o5(a.a,d),oob,Qlb));Zkb.H5(a,e,alb.Pgb(a.a).length);}c=Zkb.h5(a.a,'.',g);if(c>=0){Zkb.z2(a,c,c+1,'');f-=alb.Pgb(a.a).length-c;}return f;};U1(199,1,{},ulb.TV);_.b=0;_.c=false;_.d=0;_.e=0;_.f=3;_.g=false;_.i=3;_.j=40;_.k=0;_.n=0;_.o=1;_.p=1;_.q='-';_.r='';_.t='';_.u='';_.v=false;Ykb.A$=w3(199);vlb.WV=function WV(){};U1(297,1,{},vlb.WV);Ykb.B$=w3(297);wlb.XV=function XV(a){return a[0];};wlb.YV=function YV(a){return a[1];};wlb.ZV=function ZV(a){return a[2];};wlb.$V=function $V(a){return a[4]||a[1];};Ykb.rW=function rW(a){var b,c,d;b=a&aob;c=a>>22&aob;d=a<0?Psb:0;return Ykb.tW(b,c,d);};Ykb.sW=function sW(a){return Ykb.tW(Ykb.zW(a),Ykb.AW(a),Ykb.yW(a));};Ykb.tW=function tW(a,b,c){return {l:a,m:b,h:c};};Ykb.uW=function uW(a,b,c){var d,e,f,g,h,i;if(Ykb.zW(b)==0&&Ykb.AW(b)==0&&Ykb.yW(b)==0){throw c1(new Zkb.F2('divide by zero'));}if(Ykb.zW(a)==0&&Ykb.AW(a)==0&&Ykb.yW(a)==0){c&&(Ykb.qW=Ykb.tW(0,0,0));return Ykb.tW(0,0,0);}if(Ykb.yW(b)==snb&&Ykb.AW(b)==0&&Ykb.zW(b)==0){return Ykb.vW(a,c);}i=false;if(Ykb.yW(b)>>19!=0){b=Ykb.TW(b);i=!i;}g=Ykb.EW(b);f=false;e=false;d=false;if(Ykb.yW(a)==snb&&Ykb.AW(a)==0&&Ykb.zW(a)==0){e=true;f=true;if(g==-1){a=Ykb.sW((Ykb.gX(),Ykb.cX));d=true;i=!i;}else {h=Ykb.XW(a,g);i&&Ykb.CW(h);c&&(Ykb.qW=Ykb.tW(0,0,0));return h;}}else if(Ykb.yW(a)>>19!=0){f=true;a=Ykb.TW(a);d=true;i=!i;}if(g!=-1){return Ykb.wW(a,g,i,f,c);}if(Ykb.QW(a,b)<0){c&&(f?Ykb.qW=Ykb.TW(a):Ykb.qW=Ykb.tW(Ykb.zW(a),Ykb.AW(a),Ykb.yW(a)));return Ykb.tW(0,0,0);}return Ykb.xW(d?a:Ykb.tW(Ykb.zW(a),Ykb.AW(a),Ykb.yW(a)),b,i,f,e,c);};Ykb.vW=function vW(a,b){if(Ykb.yW(a)==snb&&Ykb.AW(a)==0&&Ykb.zW(a)==0){b&&(Ykb.qW=Ykb.tW(0,0,0));return Ykb.sW((Ykb.gX(),Ykb.eX));}b&&(Ykb.qW=Ykb.tW(Ykb.zW(a),Ykb.AW(a),Ykb.yW(a)));return Ykb.tW(0,0,0);};Ykb.wW=function wW(a,b,c,d,e){var f;f=Ykb.XW(a,b);c&&Ykb.CW(f);if(e){a=Ykb.BW(a,b);d?Ykb.qW=Ykb.TW(a):Ykb.qW=Ykb.tW(Ykb.zW(a),Ykb.AW(a),Ykb.yW(a));}return f;};Ykb.xW=function xW(a,b,c,d,e,f){var g,h,i,j;j=Ykb.DW(b)-Ykb.DW(a);g=Ykb.WW(b,j);i=Ykb.tW(0,0,0);while(j>=0){h=Ykb.NW(a,g);if(h){j<22?Ykb.GW(i,j):j<44?Ykb.HW(i,j-22):Ykb.FW(i,j-44);if(Ykb.zW(a)==0&&Ykb.AW(a)==0&&Ykb.yW(a)==0){break;}}Ykb.MW(g);--j;}c&&Ykb.CW(i);if(f){if(d){Ykb.qW=Ykb.TW(a);e&&(Ykb.qW=Ykb.ZW(Ykb.qW,(Ykb.gX(),Ykb.eX)));}else {Ykb.qW=Ykb.tW(Ykb.zW(a),Ykb.AW(a),Ykb.yW(a));}}return i;};Ykb.yW=function yW(a){return a.h;};Ykb.zW=function zW(a){return a.l;};Ykb.AW=function AW(a){return a.m;};Ykb.BW=function BW(a,b){var c,d,e;if(b<=22){c=Ykb.zW(a)&(1<<b)-1;d=e=0;}else if(b<=44){c=Ykb.zW(a);d=Ykb.AW(a)&(1<<b-22)-1;e=0;}else {c=Ykb.zW(a);d=Ykb.AW(a);e=Ykb.yW(a)&(1<<b-44)-1;}return Ykb.tW(c,d,e);};Ykb.CW=function CW(a){var b,c,d;b=~Ykb.zW(a)+1&aob;c=~Ykb.AW(a)+(b==0?1:0)&aob;d=~Ykb.yW(a)+(b==0&&c==0?1:0)&Psb;Ykb.JW(a,b);Ykb.KW(a,c);Ykb.IW(a,d);};Ykb.DW=function DW(a){var b,c;c=q4(Ykb.yW(a));if(c==32){b=q4(Ykb.AW(a));return b==32?q4(Ykb.zW(a))+32:b+20-10;}else {return c-12;}};Ykb.EW=function EW(a){var b,c,d;c=Ykb.zW(a);if((c&c-1)!=0){return -1;}d=Ykb.AW(a);if((d&d-1)!=0){return -1;}b=Ykb.yW(a);if((b&b-1)!=0){return -1;}if(b==0&&d==0&&c==0){return -1;}if(b==0&&d==0&&c!=0){return r4(c);}if(b==0&&d!=0&&c==0){return r4(d)+22;}if(b!=0&&d==0&&c==0){return r4(b)+44;}return -1;};Ykb.FW=function FW(a,b){a.h|=1<<b;};Ykb.GW=function GW(a,b){a.l|=1<<b;};Ykb.HW=function HW(a,b){a.m|=1<<b;};Ykb.IW=function IW(a,b){a.h=b;};Ykb.JW=function JW(a,b){a.l=b;};Ykb.KW=function KW(a,b){a.m=b;};Ykb.LW=function LW(a){return Ykb.zW(a)+Ykb.AW(a)*yob+Ykb.yW(a)*Qsb;};Ykb.MW=function MW(a){var b,c,d;c=Ykb.AW(a);d=Ykb.yW(a);b=Ykb.zW(a);Ykb.IW(a,d>>>1);Ykb.KW(a,c>>>1|(d&1)<<21);Ykb.JW(a,b>>>1|(c&1)<<21);};Ykb.NW=function NW(a,b){var c,d,e;e=Ykb.yW(a)-Ykb.yW(b);if(e<0){return false;}c=Ykb.zW(a)-Ykb.zW(b);d=Ykb.AW(a)-Ykb.AW(b)+(c>>22);e+=d>>22;if(e<0){return false;}Ykb.JW(a,c&aob);Ykb.KW(a,d&aob);Ykb.IW(a,e&Psb);return true;};Ykb.OW=function OW(a,b){var c,d,e;c=Ykb.zW(a)+Ykb.zW(b);d=Ykb.AW(a)+Ykb.AW(b)+(c>>22);e=Ykb.yW(a)+Ykb.yW(b)+(d>>22);return Ykb.tW(c&aob,d&aob,e&Psb);};Ykb.PW=function PW(a,b){return Ykb.tW(Ykb.zW(a)&Ykb.zW(b),Ykb.AW(a)&Ykb.AW(b),Ykb.yW(a)&Ykb.yW(b));};Ykb.QW=function QW(a,b){var c,d,e,f,g,h,i,j;i=Ykb.yW(a)>>19;j=Ykb.yW(b)>>19;if(i!=j){return j-i;}e=Ykb.yW(a);h=Ykb.yW(b);if(e!=h){return e-h;}d=Ykb.AW(a);g=Ykb.AW(b);if(d!=g){return d-g;}c=Ykb.zW(a);f=Ykb.zW(b);return c-f;};Ykb.RW=function RW(a){var b,c,d,e,f;if(isNaN(a)){return Ykb.gX(),Ykb.fX;}if(a<-9223372036854775808){return Ykb.gX(),Ykb.dX;}if(a>=9223372036854775807){return Ykb.gX(),Ykb.cX;}e=false;if(a<0){e=true;a=-a;}d=0;if(a>=Qsb){d=vX(a/Qsb);a-=d*Qsb;}c=0;if(a>=yob){c=vX(a/yob);a-=c*yob;}b=vX(a);f=Ykb.tW(b,c,d);e&&Ykb.CW(f);return f;};Ykb.SW=function SW(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G;c=Ykb.zW(a)&8191;d=Ykb.zW(a)>>13|(Ykb.AW(a)&15)<<9;e=Ykb.AW(a)>>4&8191;f=Ykb.AW(a)>>17|(Ykb.yW(a)&255)<<5;g=(Ykb.yW(a)&1048320)>>8;h=Ykb.zW(b)&8191;i=Ykb.zW(b)>>13|(Ykb.AW(b)&15)<<9;j=Ykb.AW(b)>>4&8191;k=Ykb.AW(b)>>17|(Ykb.yW(b)&255)<<5;l=(Ykb.yW(b)&1048320)>>8;B=c*h;C=d*h;D=e*h;F=f*h;G=g*h;if(i!=0){C+=c*i;D+=d*i;F+=e*i;G+=f*i;}if(j!=0){D+=c*j;F+=d*j;G+=e*j;}if(k!=0){F+=c*k;G+=d*k;}l!=0&&(G+=c*l);n=B&aob;o=(C&511)<<13;m=n+o;q=B>>22;r=C>>9;s=(D&262143)<<4;t=(F&31)<<17;p=q+r+s+t;v=D>>18;w=F>>5;A=(G&4095)<<8;u=v+w+A;p+=m>>22;m&=aob;u+=p>>22;p&=aob;u&=Psb;return Ykb.tW(m,p,u);};Ykb.TW=function TW(a){var b,c,d;b=~Ykb.zW(a)+1&aob;c=~Ykb.AW(a)+(b==0?1:0)&aob;d=~Ykb.yW(a)+(b==0&&c==0?1:0)&Psb;return Ykb.tW(b,c,d);};Ykb.UW=function UW(a){return Ykb.tW(~Ykb.zW(a)&aob,~Ykb.AW(a)&aob,~Ykb.yW(a)&Psb);};Ykb.VW=function VW(a,b){return Ykb.tW(Ykb.zW(a)|Ykb.zW(b),Ykb.AW(a)|Ykb.AW(b),Ykb.yW(a)|Ykb.yW(b));};Ykb.WW=function WW(a,b){var c,d,e;b&=63;if(b<22){c=Ykb.zW(a)<<b;d=Ykb.AW(a)<<b|Ykb.zW(a)>>22-b;e=Ykb.yW(a)<<b|Ykb.AW(a)>>22-b;}else if(b<44){c=0;d=Ykb.zW(a)<<b-22;e=Ykb.AW(a)<<b-22|Ykb.zW(a)>>44-b;}else {c=0;d=0;e=Ykb.zW(a)<<b-44;}return Ykb.tW(c&aob,d&aob,e&Psb);};Ykb.XW=function XW(a,b){var c,d,e,f,g;b&=63;c=Ykb.yW(a);d=(c&snb)!=0;d&&(c|=-1048576);if(b<22){g=c>>b;f=Ykb.AW(a)>>b|c<<22-b;e=Ykb.zW(a)>>b|Ykb.AW(a)<<22-b;}else if(b<44){g=d?Psb:0;f=c>>b-22;e=Ykb.AW(a)>>b-22|c<<44-b;}else {g=d?Psb:0;f=d?aob:0;e=c>>b-44;}return Ykb.tW(e&aob,f&aob,g&Psb);};Ykb.YW=function YW(a,b){var c,d,e,f;b&=63;c=Ykb.yW(a)&Psb;if(b<22){f=c>>>b;e=Ykb.AW(a)>>b|c<<22-b;d=Ykb.zW(a)>>b|Ykb.AW(a)<<22-b;}else if(b<44){f=0;e=c>>>b-22;d=Ykb.AW(a)>>b-22|Ykb.yW(a)<<44-b;}else {f=0;e=0;d=c>>>b-44;}return Ykb.tW(d&aob,e&aob,f&Psb);};Ykb.ZW=function ZW(a,b){var c,d,e;c=Ykb.zW(a)-Ykb.zW(b);d=Ykb.AW(a)-Ykb.AW(b)+(c>>22);e=Ykb.yW(a)-Ykb.yW(b)+(d>>22);return Ykb.tW(c&aob,d&aob,e&Psb);};Ykb.$W=function $W(a){if(Ykb.QW(a,(Ykb.gX(),Ykb.fX))<0){return -Ykb.LW(Ykb.TW(a));}return Ykb.zW(a)+Ykb.AW(a)*yob+Ykb.yW(a)*Qsb;};Ykb._W=function _W(a){return Ykb.zW(a)|Ykb.AW(a)<<22;};Ykb.aX=function aX(a){var b,c,d,e,f;if(Ykb.zW(a)==0&&Ykb.AW(a)==0&&Ykb.yW(a)==0){return '0';}if(Ykb.yW(a)==snb&&Ykb.AW(a)==0&&Ykb.zW(a)==0){return '-9223372036854775808';}if(Ykb.yW(a)>>19!=0){return '-'+Ykb.aX(Ykb.TW(a));}c=a;d='';while(!(Ykb.zW(c)==0&&Ykb.AW(c)==0&&Ykb.yW(c)==0)){e=Ykb.rW(Rsb);c=Ykb.uW(c,e,true);b=''+Ykb._W(Ykb.qW);if(!(Ykb.zW(c)==0&&Ykb.AW(c)==0&&Ykb.yW(c)==0)){f=9-alb.Pgb(b).length;for(;f>0;f--){b='0'+b;}}d=b+d;}return d;};Ykb.bX=function bX(a,b){return Ykb.tW(Ykb.zW(a)^Ykb.zW(b),Ykb.AW(a)^Ykb.AW(b),Ykb.yW(a)^Ykb.yW(b));};Ykb.gX=function gX(){Ykb.gX=W1;Ykb.cX=Ykb.tW(aob,aob,524287);Ykb.dX=Ykb.tW(0,0,snb);Ykb.eX=Ykb.rW(1);Ykb.rW(2);Ykb.fX=Ykb.rW(0);};function d1(a,b){var c;if(Ykb.t1(a)&&Ykb.t1(b)){c=Ykb.g1(Ykb.h1(a))+Ykb.g1(Ykb.h1(b));if(Ssb<c&&c<Qsb){return Ykb.m1(c);}}return Ykb.l1(Ykb.OW(Ykb.t1(a)?Ykb.G1(Ykb.h1(a)):Ykb.f1(a),Ykb.t1(b)?Ykb.G1(Ykb.h1(b)):Ykb.f1(b)));}function e1(a,b){return Ykb.l1(Ykb.PW(Ykb.t1(a)?Ykb.G1(Ykb.h1(a)):Ykb.f1(a),Ykb.t1(b)?Ykb.G1(Ykb.h1(b)):Ykb.f1(b)));}Ykb.f1=function f1(a){return a;};Ykb.g1=function g1(a){return a;};Ykb.h1=function h1(a){return a;};Ykb.i1=function i1(a){return a|0;};function j1(a,b){var c;if(Ykb.t1(a)&&Ykb.t1(b)){c=Ykb.g1(Ykb.h1(a))-Ykb.g1(Ykb.h1(b));if(!isNaN(c)){return c;}}return Ykb.QW(Ykb.t1(a)?Ykb.G1(Ykb.h1(a)):Ykb.f1(a),Ykb.t1(b)?Ykb.G1(Ykb.h1(b)):Ykb.f1(b));}Ykb.k1=function k1(a){return a;};Ykb.l1=function l1(a){var b;b=Ykb.yW(a);if(b==0){return Ykb.m1(Ykb.zW(a)+Ykb.AW(a)*yob);}if(b==Psb){return Ykb.m1(Ykb.zW(a)+Ykb.AW(a)*yob-Qsb);}return Ykb.k1(a);};Ykb.m1=function m1(a){return a;};function n1(a,b){var c;if(Ykb.t1(a)&&Ykb.t1(b)){c=Ykb.g1(Ykb.h1(a))/Ykb.g1(Ykb.h1(b));if(Ssb<c&&c<Qsb){return Ykb.m1(c<0?$wnd.Math.ceil(c):$wnd.Math.floor(c));}}return Ykb.l1(Ykb.uW(Ykb.t1(a)?Ykb.G1(Ykb.h1(a)):Ykb.f1(a),Ykb.t1(b)?Ykb.G1(Ykb.h1(b)):Ykb.f1(b),false));}function o1(a,b){return j1(a,b)==0;}function p1(a){if(Ssb<a&&a<Qsb){return Ykb.m1(a<0?$wnd.Math.ceil(a):$wnd.Math.floor(a));}return Ykb.l1(Ykb.RW(a));}function q1(a){return Ykb.m1(a);}function r1(a,b){return j1(a,b)>0;}function s1(a,b){return j1(a,b)>=0;}Ykb.t1=function t1(a){return typeof a===Olb;};function u1(a,b){return j1(a,b)<0;}function v1(a,b){return j1(a,b)<=0;}function w1(a,b){var c;if(Ykb.t1(a)&&Ykb.t1(b)){c=Ykb.g1(Ykb.h1(a))%Ykb.g1(Ykb.h1(b));if(Ssb<c&&c<Qsb){return Ykb.m1(c);}}return Ykb.l1((Ykb.uW(Ykb.t1(a)?Ykb.G1(Ykb.h1(a)):Ykb.f1(a),Ykb.t1(b)?Ykb.G1(Ykb.h1(b)):Ykb.f1(b),true),Ykb.qW));}function x1(a,b){var c;if(Ykb.t1(a)&&Ykb.t1(b)){c=Ykb.g1(Ykb.h1(a))*Ykb.g1(Ykb.h1(b));if(Ssb<c&&c<Qsb){return Ykb.m1(c);}}return Ykb.l1(Ykb.SW(Ykb.t1(a)?Ykb.G1(Ykb.h1(a)):Ykb.f1(a),Ykb.t1(b)?Ykb.G1(Ykb.h1(b)):Ykb.f1(b)));}function y1(a){var b;if(Ykb.t1(a)){b=0-Ykb.g1(Ykb.h1(a));if(!isNaN(b)){return Ykb.m1(b);}}return Ykb.l1(Ykb.TW(Ykb.f1(a)));}function z1(a,b){return j1(a,b)!=0;}function A1(a){return Ykb.l1(Ykb.UW(Ykb.t1(a)?Ykb.G1(Ykb.h1(a)):Ykb.f1(a)));}function B1(a,b){return Ykb.l1(Ykb.VW(Ykb.t1(a)?Ykb.G1(Ykb.h1(a)):Ykb.f1(a),Ykb.t1(b)?Ykb.G1(Ykb.h1(b)):Ykb.f1(b)));}function C1(a,b){return Ykb.l1(Ykb.WW(Ykb.t1(a)?Ykb.G1(Ykb.h1(a)):Ykb.f1(a),b));}function D1(a,b){return Ykb.l1(Ykb.XW(Ykb.t1(a)?Ykb.G1(Ykb.h1(a)):Ykb.f1(a),b));}function E1(a,b){return Ykb.l1(Ykb.YW(Ykb.t1(a)?Ykb.G1(Ykb.h1(a)):Ykb.f1(a),b));}function F1(a,b){var c;if(Ykb.t1(a)&&Ykb.t1(b)){c=Ykb.g1(Ykb.h1(a))-Ykb.g1(Ykb.h1(b));if(Ssb<c&&c<Qsb){return Ykb.m1(c);}}return Ykb.l1(Ykb.ZW(Ykb.t1(a)?Ykb.G1(Ykb.h1(a)):Ykb.f1(a),Ykb.t1(b)?Ykb.G1(Ykb.h1(b)):Ykb.f1(b)));}Ykb.G1=function G1(a){var b,c,d,e;e=Ykb.g1(a);d=0;if(e<0){e+=Qsb;d=Psb;}c=vX(e/yob);b=vX(e-c*yob);return Ykb.tW(b,c,d);};function H1(a){var b;if(Ykb.t1(a)){b=Ykb.g1(Ykb.h1(a));return b==-0.?0:b;}return Ykb.$W(Ykb.f1(a));}function I1(a){if(Ykb.t1(a)){return Ykb.i1(Ykb.g1(Ykb.h1(a)));}return Ykb._W(Ykb.f1(a));}function J1(a){if(Ykb.t1(a)){return ''+Ykb.g1(Ykb.h1(a));}return Ykb.aX(Ykb.f1(a));}function K1(a,b){return Ykb.l1(Ykb.bX(Ykb.t1(a)?Ykb.G1(Ykb.h1(a)):Ykb.f1(a),Ykb.t1(b)?Ykb.G1(Ykb.h1(b)):Ykb.f1(b)));}function b2(){xlb.c2();}xlb.c2=function c2(){var a,b,c;b=tlb.vV(tlb.wV());a=oW(aW(Ykb.l_,1),Xlb,2,6,[Tsb]);for(c=0;c<a.length;c++){if(Zkb.c5(a[c],b)){return;}}a.length==1&&Zkb.c5(Tsb,a[0])&&Zkb.c5('BackCompat',b)?"GWT no longer supports Quirks Mode (document.compatMode=' BackCompat').<br>Make sure your application's host HTML page has a Standards Mode (document.compatMode=' CSS1Compat') doctype,<br>e.g. by using &lt;!doctype html&gt; at the start of your application's HTML page.<br><br>To continue using this unsupported rendering mode and risk layout problems, suppress this message by adding<br>the following line to your*.gwt.xml module file:<br>&nbsp;&nbsp;&lt;extend-configuration-property name=\"document.compatMode\" value=\""+b+'"/&gt;':"Your *.gwt.xml module configuration prohibits the use of the current document rendering mode (document.compatMode=' "+b+"').<br>Modify your application's host HTML page doctype, or update your custom "+"'document.compatMode' configuration property settings.";};ylb.d2=function d2(a,b,c,d){var e,f,g,h,i,j;g=0;j=0;e=0;d==null&&(d=gW(Ykb.zX,cob,6,3,15,1));i=$wnd.Math.min(a,$wnd.Math.min(b,c));h=$wnd.Math.max(a,$wnd.Math.max(b,c));e=h;f=h-i;if(f==0){e=i;g=0;d[0]=g;d[1]=j;d[2]=e;return d;}if(h!=0)j=f/h;else {j=0;g=0;d[0]=g;d[1]=j;d[2]=e;return d;}a==h?g=(b-c)/f:b==h?g=2+(c-a)/f:g=4+(a-b)/f;g*=60;g<0&&(g+=360);d[0]=g/360;d[1]=j;d[2]=e;return d;};ylb.g2=function g2(){ylb.g2=W1;ylb.f2=oW(aW(Ykb.yX,1),emb,6,15,[5.55,15,15,15,15,15,15,15,15,Usb,Usb,Usb,Usb,Usb,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,15,Usb,Usb,7.1,Vsb,Vsb,17.78,Wsb,3.82,6.66,6.66,7.78,11.68,Usb,6.66,Usb,Usb,Vsb,Vsb,Vsb,Vsb,Vsb,Vsb,Vsb,Vsb,Vsb,Vsb,Usb,Usb,11.68,11.68,11.68,Vsb,20.3,Wsb,Wsb,Xsb,Xsb,Wsb,12.22,15.56,Xsb,Usb,10,Wsb,Vsb,16.66,Xsb,15.56,Wsb,15.56,Xsb,Wsb,12.22,Xsb,Wsb,18.88,Wsb,Wsb,12.22,Usb,Usb,Usb,9.38,Vsb,6.66,Vsb,Vsb,10,Vsb,Vsb,Usb,Vsb,Vsb,4.44,4.44,10,4.44,16.66,Vsb,Vsb,Vsb,Vsb,6.66,10,Usb,Vsb,10,Xsb,10,10,10,6.68,5.2,6.68,11.68,10.5]);};ylb.h2=function h2(a,b){var c,d,e,f,g;if(Zkb.c5(a.a,'Helvetica')){f=0;for(d=0,e=alb.Pgb(b).length;d<e;d++){c=(alb.Kgb(d,alb.Pgb(b).length),alb.Pgb(b).charCodeAt(d));f+=(c<128?g=ylb.f2[c]:g=Usb,g*a.b/20);}return f;}else {return ylb.i2(a,b);}};ylb.i2=function i2(e,a){var b=ylb.e2;if(!b){b=$doc.createElement('canvas');ylb.e2=b;}var c=''+e.b+'px '+e.a;var d=b.getContext('2d');d.font=c;var a=d.measureText(a);return a.width;};ylb.j2=function j2(a){ylb.g2();this.a='Helvetica';this.b=a;};U1(187,1,{},ylb.j2);_.b=0;ylb.e2=null;Ykb.C$=w3(187);U1(339,1,{});Ykb.F$=w3(339);U1(195,339,{195:1});_.ib=function k2(a){var b;if(a===this){return true;}if(mX(a,51)){b=a;return this.c==b.c&&this.d==b.d&&this.b==b.b&&this.a==b.a;}return false;};_.kb=function l2(){var a;a=_3(this.c);a=d1(a,x1(_3(this.d),37));a=d1(a,x1(_3(this.b),43));a=d1(a,x1(_3(this.a),47));return I1(a)^I1(D1(a,32));};Ykb.E$=w3(195);zlb.m2=function m2(a,b){a.c=0;a.d=0;a.b=b;a.a=0;};zlb.n2=function n2(a){zlb.m2(this,a);};U1(51,195,{195:1,51:1},zlb.n2);_.a=0;_.b=0;_.c=0;_.d=0;Ykb.D$=w3(51);U1(334,1,{});Ykb.K$=w3(334);Alb.o2=function o2(a){var b;b=-1;if(a.a!=-2){b=a.a;a.a=-2;}else {b=Alb.t2(a.b);}return b;};Alb.p2=function p2(a){var b,c,d;c=Alb.o2(a);if(c==-1)return null;d=new Zkb.J5();b=false;while(!b){if(c==10){b=true;}else if(c==13){b=true;c=Alb.o2(a);c!=10&&(a.a=c);}if(!b){if(c==-1){break;}Zkb.C5(d,c&Zlb);c=Alb.o2(a);}}return d.a;};Alb.q2=function q2(a){this.b=a;this.a=-2;};U1(54,334,{},Alb.q2);_.a=0;Ykb.G$=w3(54);U1(300,1,{});Ykb.I$=w3(300);U1(299,300,{});Ykb.H$=w3(299);Alb.r2=function r2(){};U1(209,299,{},Alb.r2);Ykb.J$=w3(209);Alb.t2=function t2(a){return a.a==alb.Pgb(a.b).length?-1:Zkb.X4(a.b,a.a++);};Alb.u2=function u2(a){this.b=a;this.a=0;};U1(53,334,{},Alb.u2);_.a=0;Ykb.L$=w3(53);U1(336,1,{});Ykb.N$=w3(336);Alb.v2=function v2(a,b){Zkb.y5(a.a,b);};Alb.w2=function w2(){this.a=new Zkb.z5();};U1(185,336,{},Alb.w2);_.lb=function x2(){return this.a.a;};Ykb.M$=w3(185);Zkb.y2=function y2(a,b){return Zkb.X4(a.a,b);};Zkb.z2=function z2(a,b,c,d){var e;e=alb.Pgb(a.a).length;c>e?c=e:alb.Kgb(b,c+1);a.a=Zkb.p5(a.a,0,b)+(''+d)+Zkb.o5(a.a,c);};Zkb.A2=function A2(a,b,c){Zkb.z2(a,b,b+1,String.fromCharCode(c));};Zkb.B2=function B2(a,b){var c;c=alb.Pgb(a.a).length;b<c?a.a=Zkb.p5(a.a,0,b):b>c&&(a.a+=Zkb.u5(gW(Ykb.xX,Anb,6,b-c,15,1)));};Zkb.C2=function C2(a){return a.a;};Zkb.D2=function D2(a){this.a=a;};U1(89,1,{160:1});_.lb=function E2(){return Zkb.C2(this);};Ykb.O$=w3(89);Zkb.F2=function F2(a){Zkb.uz.call(this,a);};U1(85,41,Vlb,Zkb.F2);Ykb.P$=w3(85);Zkb.I2=function I2(){Zkb.G2.call(this);};Zkb.J2=function J2(a){Zkb.H2.call(this,a);};U1(203,69,Vlb,Zkb.I2,Zkb.J2);Ykb.Q$=w3(203);Zkb.W2=function W2(a,b){return a.a-b.a;};function X2(a){this.a=a;}function Y2(a){if(!a){throw c1(new Zkb.b4());}}function Z2(a,b,c){var d,e;d=Zkb.X4(a,b++);if(d>=55296&&d<=56319&&b<c&&f3(e=(alb.Kgb(b,alb.Pgb(a).length),alb.Pgb(a).charCodeAt(b)))){return Ylb+((d&1023)<<10)+(e&1023);}return d;}function _2(a){if(a>=48&&a<48+$wnd.Math.min(10,10)){return a-48;}if(a>=97&&a<97){return a-97+10;}if(a>=65&&a<65){return a-65+10;}return -1;}function b3(a){var b;b=a-10;return (b<0?48+a:97+b)&Zlb;}function d3(a){return null!=String.fromCharCode(a).match(/\d/);}function e3(a){return null!=String.fromCharCode(a).match(/[A-Z]/i);}function f3(a){return a>=56320&&a<=57343;}function g3(a,b,c){Y2(a>=0&&a<=1114111);if(a>=Ylb){b[c++]=55296+(a-Ylb>>10&1023)&Zlb;b[c]=56320+(a-Ylb&1023)&Zlb;return 2;}else {b[c]=a&Zlb;return 1;}}function h3(a){return String.fromCharCode(a).toLowerCase().charCodeAt(0);}function j3(a){return String.fromCharCode(a).toUpperCase().charCodeAt(0);}function k3(a){var b;if(a<128){b=(Zkb.m3(),Zkb.l3)[a];!b&&(b=Zkb.l3[a]=new X2(a));return b;}return new X2(a);}U1(109,1,{4:1,109:1,27:1},X2);_.qb=function $2(a){return Zkb.W2(this,a);};_.ib=function a3(a){return mX(a,109)&&a.a==this.a;};_.kb=function c3(){return this.a;};_.lb=function i3(){return String.fromCharCode(this.a);};_.a=0;Ykb.S$=w3(109);Zkb.m3=function m3(){Zkb.m3=W1;Zkb.l3=gW(Ykb.S$,Bqb,109,128,0,1);};function a4(a){var b;b=Zkb.O3(a);if(b>wob){return Infinity;}else if(b<-3.4028234663852886E38){return -Infinity;}return b;}Zkb.b4=function b4(){Zkb.sz.call(this);};Zkb.c4=function c4(a){Zkb.uz.call(this,a);};U1(37,41,Vlb,Zkb.b4,Zkb.c4);Ykb.X$=w3(37);Zkb.d4=function d4(){Zkb.sz.call(this);};U1(249,41,Vlb,Zkb.d4);Ykb.Y$=w3(249);Zkb.e4=function e4(a,b){return j4(a.a,b.a);};Zkb.f4=function f4(a){return a.a;};Zkb.g4=function g4(a){return a.a;};Zkb.h4=function h4(a){this.a=a;};function i4(a){a-=a>>1&1431655765;a=(a>>2&858993459)+(a&858993459);a=(a>>4)+a&252645135;a+=a>>8;a+=a>>16;return a&63;}function j4(a,b){return a<b?-1:a>b?1:0;}function o4(a){var b;if(a<0){return oob;}else if(a==0){return 0;}else {for(b=fob;(b&a)==0;b>>=1);return b;}}function q4(a){var b,c,d;if(a<0){return 0;}else if(a==0){return 32;}else {d=-(a>>16);b=d>>16&16;c=16-b;a=a>>b;d=a-256;b=d>>16&8;c+=b;a<<=b;d=a-Imb;b=d>>16&4;c+=b;a<<=b;d=a-Hmb;b=d>>16&2;c+=b;a<<=b;d=a>>14;b=d&~(d>>1);return c+2-b;}}function r4(a){var b,c;if(a==0){return 32;}else {c=0;for(b=1;(b&a)==0;b<<=1){++c;}return c;}}Zkb.t4=function t4(a){if(a>-129&&a<128){return Zkb.w4(a);}return new Zkb.h4(a);};U1(42,95,{4:1,27:1,42:1,95:1},Zkb.h4);_.qb=function k4(a){return Zkb.e4(this,a);};_.ac=function l4(){return this.a;};_.ib=function m4(a){return mX(a,42)&&a.a==this.a;};_.kb=function n4(){return Zkb.f4(this);};_.bc=function p4(){return Zkb.g4(this);};_.lb=function s4(){return ''+this.a;};_.a=0;Ykb.$$=w3(42);Zkb.v4=function v4(){Zkb.v4=W1;Zkb.u4=gW(Ykb.$$,Bqb,42,256,0,1);};Zkb.w4=function w4(a){Zkb.v4();var b,c;b=a+128;c=Zkb.u4[b];!c&&(c=Zkb.u4[b]=new Zkb.h4(a));return c;};Zkb.x4=function x4(a,b){return z4(a.a,b.a);};Zkb.y4=function y4(a){this.a=a;};function z4(a,b){return j1(a,b)<0?-1:j1(a,b)>0?1:0;}Zkb.E4=function E4(a){return I1(E1(a,32))^I1(a);};Zkb.G4=function G4(a){var b,c,d,e;c=I1(E1(a,32));if(c==0){return d=alb.Pgb(I1(a)),d.toString(16);}b=gW(Ykb.xX,Anb,6,17,15,1);e=17;do{b[--e]=b3(I1(a)&15);a=E1(a,4);}while(j1(a,0)!=0);return Zkb.v5(b,e,17-e);};Zkb.I4=function I4(a){if(j1(a,-129)>0&&j1(a,128)<0){return Zkb.L4(a);}return new Zkb.y4(a);};U1(68,95,{4:1,27:1,68:1,95:1},Zkb.y4);_.qb=function A4(a){return Zkb.x4(this,a);};_.ac=function B4(){return H1(this.a);};_.ib=function C4(a){return mX(a,68)&&o1(a.a,this.a);};_.kb=function D4(){return Zkb.E4(this.a);};_.bc=function F4(){return I1(this.a);};_.lb=function H4(){return ''+J1(this.a);};_.a=0;Ykb.a_=w3(68);Zkb.K4=function K4(){Zkb.K4=W1;Zkb.J4=gW(Ykb.a_,Bqb,68,256,0,1);};Zkb.L4=function L4(a){Zkb.K4();var b,c;b=I1(a)+128;c=Zkb.J4[b];!c&&(c=Zkb.J4[b]=new Zkb.y4(a));return c;};Zkb.M4=function M4(a){return a==0||isNaN(a)?a:a<0?-1:1;};U1(377,1,{});Zkb.N4=function N4(a){Zkb.uz.call(this,a);};U1(293,41,Vlb,Zkb.N4);Ykb.b_=w3(293);Zkb.S4=function S4(a){Zkb.c4.call(this,a);};U1(35,37,{4:1,15:1,35:1,22:1},Zkb.S4);Ykb.d_=w3(35);Zkb.T4=function T4(a,b,c){this.a=Mlb;this.d=a;this.b=b;this.c=c;};U1(66,1,{4:1,66:1},Zkb.T4);_.ib=function U4(a){var b;if(mX(a,66)){b=a;return this.c==b.c&&this.d==b.d&&this.a==b.a&&this.b==b.b;}return false;};_.kb=function V4(){return dlb.fcb(oW(aW(Ykb.f_,1),Ulb,1,5,[Zkb.t4(this.c),this.a,this.d,this.b]));};_.lb=function W4(){return this.a+'.'+this.d+'('+(this.b!=null?this.b:'Unknown Source')+(this.c>=0?':'+this.c:'')+')';};_.c=0;Ykb.h_=w3(66);Zkb.w5=function w5(a,b){a.a+=String.fromCharCode(b);return a;};Zkb.x5=function x5(a,b){a.a+=b;return a;};Zkb.y5=function y5(a,b){a.a+=''+b;return a;};Zkb.z5=function z5(){Zkb.D2.call(this,'');};Zkb.A5=function A5(){Zkb.D2.call(this,'');};Zkb.B5=function B5(a){Zkb.D2.call(this,(alb.Egb(a),a));};U1(56,89,{160:1},Zkb.z5,Zkb.A5,Zkb.B5);Ykb.i_=w3(56);Zkb.C5=function C5(a,b){a.a+=String.fromCharCode(b);return a;};Zkb.D5=function D5(a,b){a.a+=b;return a;};Zkb.E5=function E5(a,b){a.a+=J1(b);return a;};Zkb.F5=function F5(a,b){a.a+=''+b;return a;};Zkb.G5=function G5(a,b){a.a+=''+b;return a;};Zkb.H5=function H5(a,b,c){Zkb.z2(a,b,c,'');return a;};Zkb.I5=function I5(a,b,c){Zkb.z2(a,b,b,c);return a;};Zkb.J5=function J5(){Zkb.D2.call(this,'');};Zkb.K5=function K5(){Zkb.D2.call(this,'');};Zkb.L5=function L5(a){Zkb.D2.call(this,(alb.Egb(a),a));};U1(23,89,{160:1},Zkb.J5,Zkb.K5,Zkb.L5);Ykb.j_=w3(23);Zkb.O5=function O5(){Zkb.O5=W1;Zkb.N5=new Alb.r2();};Zkb.P5=function P5(a,b,c,d,e){Zkb.O5();alb.Fgb(a,'src');alb.Fgb(c,'dest');Zkb.Q5(a,b,c,d,e);alb.bgb(a,b,c,d,e,true);return;};Zkb.Q5=function Q5(a,b,c,d,e){var f,g;g=alb.Pgb(a).length;f=alb.Pgb(c).length;if(b<0||d<0||e<0||b+e>g||d+e>f){throw c1(new Zkb.G2());}};U1(379,1,{});Zkb.R5=function R5(){Zkb.sz.call(this);};Zkb.S5=function S5(a){Zkb.uz.call(this,a);};U1(87,41,Vlb,Zkb.R5,Zkb.S5);Ykb.n_=w3(87);Blb._5=function _5(){Blb._5=W1;var a,b,c;new Blb.j6(1,0);new Blb.j6(10,0);new Blb.j6(0,0);Blb.T5=gW(Ykb.o_,Bqb,16,11,0,1);Blb.U5=gW(Ykb.xX,Anb,6,100,15,1);Blb.V5=oW(aW(Ykb.yX,1),emb,6,15,[1,5,25,125,625,3125,15625,78125,390625,1953125,9765625,48828125,244140625,1220703125,6103515625,30517578125,152587890625,762939453125,3814697265625,19073486328125,95367431640625,476837158203125,2384185791015625]);Blb.W5=gW(Ykb.AX,gmb,6,Blb.V5.length,15,1);Blb.X5=oW(aW(Ykb.yX,1),emb,6,15,[1,10,100,1000,$lb,Mob,1000000,10000000,100000000,Rsb,10000000000,100000000000,1000000000000,10000000000000,100000000000000,1000000000000000,10000000000000000]);Blb.Y5=gW(Ykb.AX,gmb,6,Blb.X5.length,15,1);Blb.Z5=gW(Ykb.o_,Bqb,16,11,0,1);a=0;for(;a<Blb.Z5.length;a++){Blb.T5[a]=new Blb.j6(Ykb.m1(a),0);Blb.Z5[a]=new Blb.j6(0,a);Blb.U5[a]=48;}for(;a<Blb.U5.length;a++){Blb.U5[a]=48;}for(c=0;c<Blb.W5.length;c++){Blb.W5[c]=Blb.m6(Blb.V5[c]);}for(b=0;b<Blb.Y5.length;b++){Blb.Y5[b]=Blb.m6(Blb.X5[b]);}Blb.O7();};Blb.a6=function a6(a,b){var c,d,e,f,g,h;e=Blb.f6(a);h=Blb.f6(b);if(e==h){if(a.e==b.e&&a.a<54&&b.a<54){return a.f<b.f?-1:a.f>b.f?1:0;}d=a.e-b.e;c=(a.d>0?a.d:$wnd.Math.floor((a.a-1)*Ysb)+1)-(b.d>0?b.d:$wnd.Math.floor((b.a-1)*Ysb)+1);if(c>d+1){return e;}else if(c<d-1){return -e;}else {f=(!a.c&&(a.c=Blb.k7(p1(a.f))),a.c);g=(!b.c&&(b.c=Blb.k7(p1(b.f))),b.c);d<0?f=Blb.P6(f,Blb.X7(-d)):d>0&&(g=Blb.P6(g,Blb.X7(d)));return Blb.G6(f,g);}}else return e<h?-1:1;};Blb.b6=function b6(a){return Zkb.O3(Blb.g6(a));};Blb.c6=function c6(a,b){var c,d,e,f,g,h,i,j;c=0;g=0;f=alb.Pgb(b).length;h=null;j=(alb.Pgb(b),new Zkb.K5());if(g<f&&(alb.Kgb(g,alb.Pgb(b).length),alb.Pgb(b).charCodeAt(g)==43)){++g;++c;if(g<f&&(alb.Kgb(g,alb.Pgb(b).length),alb.Pgb(b).charCodeAt(g)==43||(alb.Kgb(g,alb.Pgb(b).length),alb.Pgb(b).charCodeAt(g)==45))){throw c1(new Zkb.S4(Rlb+b+'"'));}}while(g<f&&(alb.Kgb(g,alb.Pgb(b).length),alb.Pgb(b).charCodeAt(g)!=46)&&(alb.Kgb(g,alb.Pgb(b).length),alb.Pgb(b).charCodeAt(g)!=101)&&(alb.Kgb(g,alb.Pgb(b).length),alb.Pgb(b).charCodeAt(g)!=69)){++g;}j.a+=''+(alb.Jgb(c,g,alb.Pgb(b==null?Slb:b).length),alb.Pgb(b==null?Slb:b).substr(c,g-c));if(g<f&&(alb.Kgb(g,alb.Pgb(b).length),alb.Pgb(b).charCodeAt(g)==46)){++g;c=g;while(g<f&&(alb.Kgb(g,alb.Pgb(b).length),alb.Pgb(b).charCodeAt(g)!=101)&&(alb.Kgb(g,alb.Pgb(b).length),alb.Pgb(b).charCodeAt(g)!=69)){++g;}a.e=g-c;j.a+=''+(alb.Jgb(c,g,alb.Pgb(b==null?Slb:b).length),alb.Pgb(b==null?Slb:b).substr(c,g-c));}else {a.e=0;}if(g<f&&(alb.Kgb(g,alb.Pgb(b).length),alb.Pgb(b).charCodeAt(g)==101||(alb.Kgb(g,alb.Pgb(b).length),alb.Pgb(b).charCodeAt(g)==69))){++g;c=g;if(g<f&&(alb.Kgb(g,alb.Pgb(b).length),alb.Pgb(b).charCodeAt(g)==43)){++g;g<f&&(alb.Kgb(g,alb.Pgb(b).length),alb.Pgb(b).charCodeAt(g)!=45)&&++c;}h=(alb.Jgb(c,f,alb.Pgb(b).length),alb.Pgb(b).substr(c,f-c));a.e=a.e-Zkb.P3(h,oob,Qlb);if(a.e!=vX(a.e)){throw c1(new Zkb.S4('Scale out of range.'));}}i=j.a;if(alb.Pgb(i).length<16){a.f=(Blb.$5==null&&(Blb.$5=new RegExp('^[+-]?\\d*$','i')),Blb.$5.test(i)?parseInt(i,10):NaN);if(isNaN(a.f)){throw c1(new Zkb.S4(Rlb+b+'"'));}a.a=Blb.m6(a.f);}else {Blb.e6(a,new Blb._6(i));}a.d=alb.Pgb(j.a).length;for(e=0;e<alb.Pgb(j.a).length;++e){d=Zkb.X4(j.a,e);if(d!=45&&d!=48){break;}--a.d;}a.d==0&&(a.d=1);};Blb.d6=function d6(a,b){var c;alb.Egb(b);c=2-a.e;if(c==0){return a;}if(c>0){if(c<Blb.X5.length&&a.a+Blb.Y5[vX(c)]<54){return new Blb.i6(a.f*Blb.X5[vX(c)]);}return new Blb.l6(Blb.U7((!a.c&&(a.c=Blb.k7(p1(a.f))),a.c),vX(c)));}if(a.a<54&&-c<Blb.X5.length){return Blb.q6(a.f,Blb.X5[vX(-c)],b);}return Blb.p6((!a.c&&(a.c=Blb.k7(p1(a.f))),a.c),Blb.X7(-c),b);};Blb.e6=function e6(a,b){var c;a.c=b;a.a=Blb.l7(b);a.a<54&&(a.f=(c=b.d>1?alb.Sgb(b.a[0],b.a[1]):alb.Sgb(b.a[0],0),H1(b.e>0?c:y1(c))));};Blb.f6=function f6(a){if(a.a<54){return a.f<0?-1:a.f>0?1:0;}return (!a.c&&(a.c=Blb.k7(p1(a.f))),a.c).e;};Blb.g6=function g6(a){var b,c,d,e,f;if(a.g!=null){return a.g;}if(a.a<32){a.g=Blb.w7(p1(a.f),vX(a.e));return a.g;}e=Blb.x7((!a.c&&(a.c=Blb.k7(p1(a.f))),a.c),0);if(a.e==0){return e;}b=(!a.c&&(a.c=Blb.k7(p1(a.f))),a.c).e<0?2:1;c=alb.Pgb(e).length;d=-a.e+c-b;f=new Zkb.J5();f.a+=''+e;if(a.e>0&&d>=-6){if(d>=0){Zkb.I5(f,c-vX(a.e),String.fromCharCode(46));}else {Zkb.z2(f,b-1,b-1,'0.');Zkb.I5(f,b+1,Zkb.v5(Blb.U5,0,-vX(d)-1));}}else {if(c-b>=1){Zkb.I5(f,b,String.fromCharCode(46));++c;}Zkb.I5(f,c,String.fromCharCode(69));d>0&&Zkb.I5(f,++c,String.fromCharCode(43));Zkb.I5(f,++c,''+J1(p1(d)));}a.g=f.a;return a.g;};Blb.h6=function h6(a){Blb._5();var b;if(!isNaN(a)&&!isFinite(a)||isNaN(a)){throw c1(new Zkb.S4('Infinite or NaN'));}Blb.c6(this,(b=alb.Pgb(a),b.toPrecision(20)));};Blb.i6=function i6(a){this.f=a;this.e=2;this.a=Blb.m6(a);};Blb.j6=function j6(a,b){this.e=b;this.a=Blb.n6(a);this.a<54?this.f=H1(a):this.c=(Blb.E6(),j1(a,0)>=0?Blb.e7(a):Blb.Q6(Blb.e7(y1(a))));};Blb.k6=function k6(a){this.e=2;Blb.e6(this,(alb.Egb(a),a));};Blb.l6=function l6(a){Blb.k6.call(this,a);};Blb.m6=function m6(a){var b,c;if(a>-140737488355328&&a<140737488355328){if(a==0){return 0;}b=a<0;b&&(a=-a);c=vX($wnd.Math.floor($wnd.Math.log(a)/0.6931471805599453));(!b||a!=$wnd.Math.pow(2,c))&&++c;return c;}return Blb.n6(p1(a));};Blb.n6=function n6(a){var b;j1(a,0)<0&&(a=A1(a));return b=I1(E1(a,32)),64-(b!=0?q4(b):q4(I1(a))+32);};Blb.p6=function p6(a,b,c){var d,e,f,g,h,i,j,k,l;f=Blb.J6(a,b);g=f[0];i=f[1];if(i.e==0){return new Blb.l6(g);}j=a.e*b.e;if(Blb.l7(b)<54){h=(l=i.d>1?alb.Sgb(i.a[0],i.a[1]):alb.Sgb(i.a[0],0),i.e>0?l:y1(l));e=(k=b.d>1?alb.Sgb(b.a[0],b.a[1]):alb.Sgb(b.a[0],0),b.e>0?k:y1(k));d=u1(C1(j1(h,0)<0?y1(h):h,1),j1(e,0)<0?y1(e):e)?-1:r1(C1(j1(h,0)<0?y1(h):h,1),j1(e,0)<0?y1(e):e)?1:0;d=Blb.v6(Blb.V6(g,0)?1:0,j*(5+d),c);}else {d=Blb.G6(Blb.T6(i.e<0?i.e==0?i:new Blb.Z6(-i.e,i.d,i.a):i),b.e<0?b.e==0?b:new Blb.Z6(-b.e,b.d,b.a):b);d=Blb.v6(Blb.V6(g,0)?1:0,j*(5+d),c);}if(d!=0){if(Blb.l7(g)<54){return Blb.x6((k=g.d>1?alb.Sgb(g.a[0],g.a[1]):alb.Sgb(g.a[0],0),d1(g.e>0?k:y1(k),Ykb.m1(d))));}g=Blb.D7(g,(Blb.E6(),s1(Ykb.m1(d),0)?Blb.e7(Ykb.m1(d)):Blb.Q6(Blb.e7(y1(Ykb.m1(d))))));return new Blb.l6(g);}return new Blb.l6(g);};Blb.q6=function q6(a,b,c){var d,e,f,g,h;f=(e=a/b,e>0?$wnd.Math.floor(e):$wnd.Math.ceil(e));g=a%b;h=$3(a*b,0);if(g!=0){d=$3($wnd.Math.abs(g)*2,$wnd.Math.abs(b));f+=Blb.v6(vX(f)&1,h*(5+d),c);}return new Blb.i6(f);};Blb.v6=function v6(a,b,c){var d;d=0;switch(c.b){case 7:if(b!=0){throw c1(new Zkb.F2('Rounding necessary'));}break;case 0:d=b==0?0:b<0?-1:1;break;case 2:d=$wnd.Math.max(b==0?0:b<0?-1:1,0);break;case 3:d=$wnd.Math.min(b==0?0:b<0?-1:1,0);break;case 4:$wnd.Math.abs(b)>=5&&(d=b==0?0:b<0?-1:1);break;case 5:$wnd.Math.abs(b)>5&&(d=b==0?0:b<0?-1:1);break;case 6:$wnd.Math.abs(b)+a>5&&(d=b==0?0:b<0?-1:1);}return d;};Blb.x6=function x6(a){if(j1(a,0)==0&&2<Blb.Z5.length){return Blb.Z5[2];}return new Blb.j6(a,2);};U1(16,95,{4:1,27:1,95:1,16:1},Blb.h6,Blb.i6,Blb.j6,Blb.l6);_.qb=function o6(a){return Blb.a6(this,a);};_.ac=function r6(){return Blb.b6(this);};_.ib=function s6(a){var b;if(this===a){return true;}if(mX(a,16)){b=a;return this.e==b.e&&Blb.a6(this,b)==0;}return false;};_.kb=function t6(){var a;if(this.b!=0){return this.b;}if(this.a<54){a=p1(this.f);this.b=I1(e1(a,-1));this.b=33*this.b+I1(e1(D1(a,32),-1));this.b=17*this.b+vX(this.e);return this.b;}this.b=17*Blb.N6(this.c)+vX(this.e);return this.b;};_.bc=function u6(){return this.e<=-32||this.e>(this.d>0?this.d:$wnd.Math.floor((this.a-1)*Ysb)+1)?0:Blb.O6(this.e==0||this.a==0&&this.f!=-1?(!this.c&&(this.c=Blb.k7(p1(this.f))),this.c):this.e<0?Blb.P6((!this.c&&(this.c=Blb.k7(p1(this.f))),this.c),Blb.X7(-this.e)):Blb.I6((!this.c&&(this.c=Blb.k7(p1(this.f))),this.c),Blb.X7(this.e)));};_.lb=function w6(){return Blb.g6(this);};_.a=0;_.b=0;_.d=0;_.e=0;_.f=0;Ykb.o_=w3(16);Blb.E6=function E6(){Blb.E6=W1;var a;Blb.z6=new Blb.X6(1,1);Blb.B6=new Blb.X6(1,10);Blb.D6=new Blb.X6(0,0);Blb.y6=new Blb.X6(-1,1);Blb.A6=oW(aW(Ykb.p_,1),Bqb,21,0,[Blb.D6,Blb.z6,new Blb.X6(1,2),new Blb.X6(1,3),new Blb.X6(1,4),new Blb.X6(1,5),new Blb.X6(1,6),new Blb.X6(1,7),new Blb.X6(1,8),new Blb.X6(1,9),Blb.B6]);Blb.C6=gW(Ykb.p_,Bqb,21,32,0,1);for(a=0;a<Blb.C6.length;a++){Blb.C6[a]=s1(C1(1,a),0)?Blb.e7(C1(1,a)):Blb.Q6(Blb.e7(y1(C1(1,a))));}};Blb.F6=function F6(a){};Blb.G6=function G6(a,b){if(a.e>b.e){return 1;}if(a.e<b.e){return -1;}if(a.d>b.d){return a.e;}if(a.d<b.d){return -b.e;}return a.e*Blb.G7(a.a,b.a,a.d);};Blb.H6=function H6(a){while(a.d>0&&a.a[--a.d]==0);a.a[a.d++]==0&&(a.e=0);};Blb.I6=function I6(a,b){var c,d,e,f,g,h,i,j,k,l;if(b.e==0){throw c1(new Zkb.F2(Zsb));}e=b.e;if(b.d==1&&b.a[0]==1){return b.e>0?a:a.e==0?a:new Blb.Z6(-a.e,a.d,a.a);}k=a.e;j=a.d;d=b.d;if(j+d==2){l=n1(e1(q1(a.a[0]),$sb),e1(q1(b.a[0]),$sb));k!=e&&(l=y1(l));return j1(l,0)>=0?Blb.e7(l):Blb.Q6(Blb.e7(y1(l)));}c=j!=d?j>d?1:-1:Blb.G7(a.a,b.a,j);if(c==0){return k==e?Blb.z6:Blb.y6;}if(c==-1){return Blb.D6;}g=j-d+1;f=gW(Ykb.AX,gmb,6,g,15,1);h=k==e?1:-1;d==1?Blb.A7(f,a.a,j,b.a[0]):Blb.y7(f,g,a.a,j,b.a,d);i=new Blb.Z6(h,g,f);Blb.H6(i);return i;};Blb.J6=function J6(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p;f=b.e;if(f==0){throw c1(new Zkb.F2(Zsb));}e=b.d;d=b.a;if(e==1){return Blb.z7(a,d[0],f);}n=a.a;o=a.d;c=o!=e?o>e?1:-1:Blb.G7(n,d,o);if(c<0){return oW(aW(Ykb.p_,1),Bqb,21,0,[Blb.D6,a]);}p=a.e;h=o-e+1;k=e;i=p==f?1:-1;g=gW(Ykb.AX,gmb,6,h,15,1);j=Blb.y7(g,h,n,o,d,e);l=new Blb.Z6(i,h,g);m=new Blb.Z6(p,k,j);Blb.H6(l);Blb.H6(m);return oW(aW(Ykb.p_,1),Bqb,21,0,[l,m]);};Blb.K6=function K6(a,b){var c;if(uX(a)===uX(b)){return true;}if(mX(b,21)){c=b;return a.e==c.e&&a.d==c.d&&Blb.L6(a,c.a);}return false;};Blb.L6=function L6(a,b){var c;for(c=a.d-1;c>=0&&a.a[c]==b[c];c--);return c<0;};Blb.M6=function M6(a){var b;if(a.b==-2){if(a.e==0){b=-1;}else {for(b=0;a.a[b]==0;b++);}a.b=b;}return a.b;};Blb.N6=function N6(a){var b;if(a.c!=0){return a.c;}for(b=0;b<a.a.length;b++){a.c=a.c*33+(a.a[b]&-1);}a.c=a.c*a.e;return a.c;};Blb.O6=function O6(a){var b;b=a.a[0];return a.e>0?b:-b|0;};Blb.P6=function P6(a,b){if(b.e==0||a.e==0){return Blb.D6;}return Blb.O7(),Blb.P7(a,b);};Blb.Q6=function Q6(a){return a.e==0?a:new Blb.Z6(-a.e,a.d,a.a);};Blb.R6=function R6(a,b){var c;if(b<0){throw c1(new Zkb.F2('Negative exponent'));}if(b==0){return Blb.z6;}else if(b==1||Blb.K6(a,Blb.z6)||Blb.K6(a,Blb.D6)){return a;}if(!Blb.V6(a,0)){c=1;while(!Blb.V6(a,c)){++c;}return Blb.P6(Blb.f7(c*b),Blb.R6(Blb.U6(a,c),b));}return Blb.W7(a,b);};Blb.S6=function S6(a,b){if(b==0||a.e==0){return a;}return b>0?Blb.m7(a,b):Blb.q7(a,-b);};Blb.T6=function T6(a){return a.e==0?a:Blb.o7(a);};Blb.U6=function U6(a,b){if(b==0||a.e==0){return a;}return b>0?Blb.q7(a,b):Blb.m7(a,-b);};Blb.V6=function V6(a,b){var c,d,e;if(b==0){return (a.a[0]&1)!=0;}if(b<0){throw c1(new Zkb.F2('Negative bit address'));}e=b>>5;if(e>=a.d){return a.e<0;}c=a.a[e];b=1<<(b&31);if(a.e<0){d=Blb.M6(a);if(e<d){return false;}else d==e?c=-c:c=~c;}return (c&b)!=0;};Blb.W6=function W6(a){return Blb.x7(a,0);};Blb.X6=function X6(a,b){Blb.E6();Blb.Z6.call(this,a,1,oW(aW(Ykb.AX,1),gmb,6,15,[b]));};Blb.Y6=function Y6(a,b){Blb.Z6.call(this,1,2,oW(aW(Ykb.AX,1),gmb,6,15,[a,b]));};Blb.Z6=function Z6(a,b,c){Blb.E6();Blb.F6(this);this.e=a;this.d=b;this.a=c;};Blb.$6=function $6(a){Blb.E6();Blb.F6(this);if(a.length==0){this.e=0;this.d=1;this.a=oW(aW(Ykb.AX,1),gmb,6,15,[0]);}else {this.e=1;this.d=a.length;this.a=a;Blb.H6(this);}};Blb._6=function _6(a){Blb.E6();Blb.a7.call(this,a);};Blb.a7=function a7(a){Blb.F6(this);alb.Egb(a);if(alb.Pgb(a).length==0){throw c1(new Zkb.S4('Zero length BigInteger'));}Blb.i7(this,a);};Blb.e7=function e7(a){Blb.E6();var b,c;c=I1(a);b=I1(E1(a,32));if(b!=0){return new Blb.Y6(c,b);}if(c>10||c<0){return new Blb.X6(1,c);}return Blb.A6[c];};Blb.f7=function f7(a){var b,c,d;if(a<Blb.C6.length){return Blb.C6[a];}c=a>>5;b=a&31;d=gW(Ykb.AX,gmb,6,c+1,15,1);d[c]=1<<b;return new Blb.Z6(1,c+1,d);};Blb.i7=function i7(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q;n=alb.Pgb(b).length;i=n;alb.Kgb(0,alb.Pgb(b).length);if(alb.Pgb(b).charCodeAt(0)==45){l=-1;m=1;--n;}else {l=1;m=0;}f=(Blb.u7(),Blb.t7)[10];e=n/f|0;q=n%f;q!=0&&++e;h=gW(Ykb.AX,gmb,6,e,15,1);c=Blb.s7[8];g=0;o=m+(q==0?f:q);for(p=m;p<i;p=o,o=p+f){d=Zkb.P3((alb.Jgb(p,o,alb.Pgb(b).length),alb.Pgb(b).substr(p,o-p)),oob,Qlb);j=(Blb.O7(),Blb.S7(h,h,g,c));j+=Blb.H7(h,g,d);h[g++]=j;}k=g;a.e=l;a.d=k;a.a=h;Blb.H6(a);};Blb.k7=function k7(a){Blb.E6();return j1(a,0)>=0?Blb.e7(a):Blb.Q6(Blb.e7(y1(a)));};U1(21,95,{4:1,27:1,95:1,21:1},Blb.X6,Blb.Y6,Blb.Z6,Blb.$6,Blb._6);_.qb=function b7(a){return Blb.G6(this,a);};_.ac=function c7(){return Zkb.O3(Blb.x7(this,0));};_.ib=function d7(a){return Blb.K6(this,a);};_.kb=function g7(){return Blb.N6(this);};_.bc=function h7(){return Blb.O6(this);};_.lb=function j7(){return Blb.W6(this);};_.b=-2;_.c=0;_.d=0;_.e=0;Ykb.p_=w3(21);Blb.l7=function l7(a){var b,c,d;if(a.e==0){return 0;}b=a.d<<5;c=a.a[a.d-1];if(a.e<0){d=Blb.M6(a);if(d==a.d-1){--c;c=c|0;}}b-=q4(c);return b;};Blb.m7=function m7(a,b){var c,d,e,f;c=b>>5;b&=31;e=a.d+c+(b==0?0:1);d=gW(Ykb.AX,gmb,6,e,15,1);Blb.n7(d,a.a,c,b);f=new Blb.Z6(a.e,e,d);Blb.H6(f);return f;};Blb.n7=function n7(a,b,c,d){var e,f,g;if(d==0){Zkb.P5(b,0,a,c,a.length-c);}else {g=32-d;a[a.length-1]=0;for(f=a.length-1;f>c;f--){a[f]|=b[f-c-1]>>>g;a[f-1]=b[f-c-1]<<d;}}for(e=0;e<c;e++){a[e]=0;}};Blb.o7=function o7(a){var b,c,d,e;e=a.d;c=e+1;b=gW(Ykb.AX,gmb,6,c,15,1);Blb.p7(b,a.a,e);d=new Blb.Z6(a.e,c,b);Blb.H6(d);return d;};Blb.p7=function p7(a,b,c){var d,e,f;d=0;for(e=0;e<c;e++){f=b[e];a[e]=f<<1|d;d=f>>>31;}d!=0&&(a[c]=d);};Blb.q7=function q7(a,b){var c,d,e,f,g;d=b>>5;b&=31;if(d>=a.d){return a.e<0?(Blb.E6(),Blb.y6):(Blb.E6(),Blb.D6);}f=a.d-d;e=gW(Ykb.AX,gmb,6,f+1,15,1);Blb.r7(e,f,a.a,d,b);if(a.e<0){for(c=0;c<d&&a.a[c]==0;c++);if(c<d||b>0&&a.a[c]<<32-b!=0){for(c=0;c<f&&e[c]==-1;c++){e[c]=0;}c==f&&++f;++e[c];}}g=new Blb.Z6(a.e,f,e);Blb.H6(g);return g;};Blb.r7=function r7(a,b,c,d,e){var f,g,h;f=true;for(g=0;g<d;g++){f=f&c[g]==0;}if(e==0){Zkb.P5(c,d,a,0,b);g=b;}else {h=32-e;f=f&c[g]<<h==0;for(g=0;g<b-1;g++){a[g]=c[g+d]>>>e|c[g+d+1]<<h;}a[g]=c[g+d]>>>e;++g;}return f;};Blb.u7=function u7(){Blb.u7=W1;Blb.s7=oW(aW(Ykb.AX,1),gmb,6,15,[oob,1162261467,fob,1220703125,362797056,1977326743,fob,387420489,Rsb,214358881,429981696,815730721,1475789056,170859375,jnb,410338673,612220032,893871739,1280000000,1801088541,113379904,148035889,191102976,244140625,308915776,387420489,481890304,594823321,729000000,887503681,fob,1291467969,1544804416,1838265625,60466176]);Blb.t7=oW(aW(Ykb.AX,1),gmb,6,15,[-1,-1,31,19,15,13,11,11,10,9,9,8,8,8,8,7,7,7,7,7,7,7,6,6,6,6,6,6,6,6,6,6,6,6,6,6,5]);};Blb.v7=function v7(a){var b,c,d;if(j1(a,0)>=0){c=n1(a,Rsb);d=w1(a,Rsb);}else {b=E1(a,1);c=n1(b,500000000);d=w1(b,500000000);d=d1(C1(d,1),e1(a,1));}return B1(C1(d,32),e1(c,$sb));};Blb.w7=function w7(a,b){Blb.u7();var c,d,e,f,g,h,i,j,k,l,m,n,o,p;i=j1(a,0)<0;i&&(a=y1(a));if(j1(a,0)==0){switch(b){case 0:return '0';case 1:return '0.0';case 2:return '0.00';case 3:return '0.000';case 4:return lob;case 5:return '0.00000';case 6:return '0.000000';default:n=new Zkb.J5();b<0?(n.a+='0E+',n):(n.a+='0E',n);n.a+=b==oob?'2147483648':''+-b;return n.a;}}k=18;l=gW(Ykb.xX,Anb,6,k+1,15,1);c=k;p=a;do{j=p;p=n1(p,10);l[--c]=I1(d1(48,F1(j,x1(p,10))))&Zlb;}while(j1(p,0)!=0);e=F1(F1(F1(Ykb.m1(k),Ykb.m1(c)),Ykb.m1(b)),1);if(b==0){i&&(l[--c]=45);return Zkb.v5(l,c,k-c);}if(b>0&&j1(e,-6)>=0){if(j1(e,0)>=0){f=c+I1(e);for(h=k-1;h>=f;h--){l[h+1]=l[h];}l[++f]=46;i&&(l[--c]=45);return Zkb.v5(l,c,k-c+1);}for(g=2;u1(Ykb.m1(g),d1(y1(e),1));g++){l[--c]=48;}l[--c]=46;l[--c]=48;i&&(l[--c]=45);return Zkb.v5(l,c,k-c);}o=c+1;d=k;m=new Zkb.K5();i&&(m.a+='-',m);if(d-o>=1){Zkb.C5(m,l[c]);m.a+='.';m.a+=Zkb.v5(l,c+1,k-c-1);}else {m.a+=Zkb.v5(l,c,k-c);}m.a+='E';j1(e,0)>0&&(m.a+='+',m);m.a+=''+J1(e);return m.a;};Blb.x7=function x7(a,b){Blb.u7();var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G,H;B=a.e;o=a.d;e=a.a;if(B==0){switch(b){case 0:return '0';case 1:return '0.0';case 2:return '0.00';case 3:return '0.000';case 4:return lob;case 5:return '0.00000';case 6:return '0.000000';default:w=new Zkb.J5();b<0?(w.a+='0E+',w):(w.a+='0E',w);w.a+=-b;return w.a;}}t=o*10+1+7;u=gW(Ykb.xX,Anb,6,t+1,15,1);c=t;if(o==1){h=e[0];if(h<0){H=e1(Ykb.m1(h),$sb);do{p=H;H=n1(H,10);u[--c]=48+I1(F1(p,x1(H,10)))&Zlb;}while(j1(H,0)!=0);}else {H=h;do{p=H;H=H/10|0;u[--c]=48+(p-H*10)&Zlb;}while(H!=0);}}else {D=gW(Ykb.AX,gmb,6,o,15,1);G=o;Zkb.P5(e,0,D,0,G);I:while(true){A=0;for(j=G-1;j>=0;j--){F=d1(C1(A,32),e1(Ykb.m1(D[j]),$sb));r=Blb.v7(F);D[j]=I1(r);A=q1(I1(D1(r,32)));}s=I1(A);q=c;do{u[--c]=48+s%10&Zlb;}while((s=s/10|0)!=0&&c!=0);d=9-q+c;for(i=0;i<d&&c>0;i++){u[--c]=48;}l=G-1;for(;D[l]==0;l--){if(l==0){break I;}}G=l+1;}while(u[c]==48){++c;}}n=B<0;g=t-c-b-1;if(b==0){n&&(u[--c]=45);return Zkb.v5(u,c,t-c);}if(b>0&&g>=-6){if(g>=0){k=c+g;for(m=t-1;m>=k;m--){u[m+1]=u[m];}u[++k]=46;n&&(u[--c]=45);return Zkb.v5(u,c,t-c+1);}for(l=2;l<-g+1;l++){u[--c]=48;}u[--c]=46;u[--c]=48;n&&(u[--c]=45);return Zkb.v5(u,c,t-c);}C=c+1;f=t;v=new Zkb.K5();n&&(v.a+='-',v);if(f-C>=1){Zkb.C5(v,u[c]);v.a+='.';v.a+=Zkb.v5(u,c+1,t-c-1);}else {v.a+=Zkb.v5(u,c,t-c);}v.a+='E';g>0&&(v.a+='+',v);v.a+=''+g;return v.a;};Blb.y7=function y7(a,b,c,d,e,f){var g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A;q=gW(Ykb.AX,gmb,6,d+1,15,1);r=gW(Ykb.AX,gmb,6,f+1,15,1);s=f;i=q4(e[f-1]);if(i!=0){Blb.n7(r,e,0,i);Blb.n7(q,c,0,i);}else {Zkb.P5(c,0,q,0,d);Zkb.P5(e,0,r,0,f);}j=r[s-1];l=b-1;m=d;while(l>=0){k=0;if(q[m]==j){k=-1;}else {t=d1(C1(e1(Ykb.m1(q[m]),$sb),32),e1(Ykb.m1(q[m-1]),$sb));w=Blb.B7(t,j);k=I1(w);v=I1(D1(w,32));if(k!=0){o=0;A=0;u=false;++k;do{--k;if(u){break;}o=x1(e1(Ykb.m1(k),$sb),e1(Ykb.m1(r[s-2]),$sb));A=d1(C1(Ykb.m1(v),32),e1(Ykb.m1(q[m-2]),$sb));p=d1(e1(Ykb.m1(v),$sb),e1(Ykb.m1(j),$sb));q4(I1(E1(p,32)))<32?u=true:v=I1(p);}while(r1(K1(o,_sb),K1(A,_sb)));}}if(k!=0){g=Blb.C7(q,m-s,r,s,k);if(g!=0){--k;h=0;for(n=0;n<s;n++){h=d1(h,d1(e1(Ykb.m1(q[m-s+n]),$sb),e1(Ykb.m1(r[n]),$sb)));q[m-s+n]=I1(h);h=E1(h,32);}}}a[l]=k;--m;--l;}if(i!=0){Blb.r7(r,s,q,0,i);return r;}Zkb.P5(q,0,r,0,f);return q;};Blb.z7=function z7(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o,p;n=a.a;o=a.d;p=a.e;if(o==1){d=e1(Ykb.m1(n[0]),$sb);e=e1(Ykb.m1(b),$sb);f=n1(d,e);j=w1(d,e);p!=c&&(f=y1(f));p<0&&(j=y1(j));return oW(aW(Ykb.p_,1),Bqb,21,0,[(Blb.E6(),j1(f,0)>=0?Blb.e7(f):Blb.Q6(Blb.e7(y1(f)))),j1(j,0)>=0?Blb.e7(j):Blb.Q6(Blb.e7(y1(j)))]);}h=o;i=p==c?1:-1;g=gW(Ykb.AX,gmb,6,h,15,1);k=oW(aW(Ykb.AX,1),gmb,6,15,[Blb.A7(g,n,o,b)]);l=new Blb.Z6(i,h,g);m=new Blb.Z6(p,1,k);Blb.H6(l);Blb.H6(m);return oW(aW(Ykb.p_,1),Bqb,21,0,[l,m]);};Blb.A7=function A7(a,b,c,d){var e,f,g,h,i,j,k;j=0;f=e1(Ykb.m1(d),$sb);for(h=c-1;h>=0;h--){k=B1(C1(j,32),e1(Ykb.m1(b[h]),$sb));if(j1(k,0)>=0){i=n1(k,f);j=w1(k,f);}else {e=E1(k,1);g=Ykb.m1(d>>>1);i=n1(e,g);j=w1(e,g);j=d1(C1(j,1),e1(k,1));if((d&1)!=0){if(j1(i,j)<=0){j=F1(j,i);}else {if(v1(F1(i,j),f)){j=d1(j,F1(f,i));i=F1(i,1);}else {j=d1(j,F1(C1(f,1),i));i=F1(i,2);}}}}a[h]=I1(e1(i,$sb));}return I1(j);};Blb.B7=function B7(a,b){var c,d,e,f,g;d=e1(Ykb.m1(b),$sb);if(j1(a,0)>=0){f=n1(a,d);g=w1(a,d);}else {c=E1(a,1);e=Ykb.m1(b>>>1);f=n1(c,e);g=w1(c,e);g=d1(C1(g,1),e1(a,1));if((b&1)!=0){if(j1(f,g)<=0){g=F1(g,f);}else {if(v1(F1(f,g),d)){g=d1(g,F1(d,f));f=F1(f,1);}else {g=d1(g,F1(C1(d,1),f));f=F1(f,2);}}}}return B1(C1(g,32),e1(f,$sb));};Blb.C7=function C7(a,b,c,d,e){var f,g,h;f=0;g=0;for(h=0;h<d;h++){f=(Blb.O7(),d1(x1(e1(Ykb.m1(c[h]),$sb),e1(Ykb.m1(e),$sb)),e1(q1(I1(f)),$sb)));g=d1(F1(e1(Ykb.m1(a[b+h]),$sb),e1(f,$sb)),g);a[b+h]=I1(g);g=D1(g,32);f=E1(f,32);}g=d1(F1(e1(Ykb.m1(a[b+d]),$sb),f),g);a[b+d]=I1(g);return I1(D1(g,32));};Blb.D7=function D7(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o;g=a.e;i=b.e;if(g==0){return b;}if(i==0){return a;}f=a.d;h=b.d;if(f+h==2){c=e1(q1(a.a[0]),$sb);d=e1(q1(b.a[0]),$sb);if(g==i){k=d1(c,d);o=I1(k);n=I1(E1(k,32));return n==0?new Blb.X6(g,o):new Blb.Z6(g,2,oW(aW(Ykb.AX,1),gmb,6,15,[o,n]));}return Blb.E6(),s1(g<0?F1(d,c):F1(c,d),0)?Blb.e7(g<0?F1(d,c):F1(c,d)):Blb.Q6(Blb.e7(y1(g<0?F1(d,c):F1(c,d))));}else if(g==i){m=g;l=f>=h?Blb.E7(a.a,f,b.a,h):Blb.E7(b.a,h,a.a,f);}else {e=f!=h?f>h?1:-1:Blb.G7(a.a,b.a,f);if(e==0){return Blb.E6(),Blb.D6;}if(e==1){m=g;l=Blb.J7(a.a,f,b.a,h);}else {m=i;l=Blb.J7(b.a,h,a.a,f);}}j=new Blb.Z6(m,l.length,l);Blb.H6(j);return j;};Blb.E7=function E7(a,b,c,d){var e;e=gW(Ykb.AX,gmb,6,b+1,15,1);Blb.F7(e,a,b,c,d);return e;};Blb.F7=function F7(a,b,c,d,e){var f,g;f=d1(e1(Ykb.m1(b[0]),$sb),e1(Ykb.m1(d[0]),$sb));a[0]=I1(f);f=D1(f,32);if(c>=e){for(g=1;g<e;g++){f=d1(f,d1(e1(Ykb.m1(b[g]),$sb),e1(Ykb.m1(d[g]),$sb)));a[g]=I1(f);f=D1(f,32);}for(;g<c;g++){f=d1(f,e1(Ykb.m1(b[g]),$sb));a[g]=I1(f);f=D1(f,32);}}else {for(g=1;g<c;g++){f=d1(f,d1(e1(Ykb.m1(b[g]),$sb),e1(Ykb.m1(d[g]),$sb)));a[g]=I1(f);f=D1(f,32);}for(;g<e;g++){f=d1(f,e1(Ykb.m1(d[g]),$sb));a[g]=I1(f);f=D1(f,32);}}j1(f,0)!=0&&(a[g]=I1(f));};Blb.G7=function G7(a,b,c){var d;for(d=c-1;d>=0&&a[d]==b[d];d--);return d<0?0:u1(e1(Ykb.m1(a[d]),$sb),e1(Ykb.m1(b[d]),$sb))?-1:1;};Blb.H7=function H7(a,b,c){var d,e;d=e1(Ykb.m1(c),$sb);for(e=0;j1(d,0)!=0&&e<b;e++){d=d1(d,e1(Ykb.m1(a[e]),$sb));a[e]=I1(d);d=D1(d,32);}return I1(d);};Blb.I7=function I7(a,b){var c,d,e,f,g,h,i,j,k,l;g=a.e;i=b.e;if(i==0){return a;}if(g==0){return b.e==0?b:new Blb.Z6(-b.e,b.d,b.a);}f=a.d;h=b.d;if(f+h==2){c=e1(q1(a.a[0]),$sb);d=e1(q1(b.a[0]),$sb);g<0&&(c=y1(c));i<0&&(d=y1(d));return Blb.E6(),s1(F1(c,d),0)?Blb.e7(F1(c,d)):Blb.Q6(Blb.e7(y1(F1(c,d))));}e=f!=h?f>h?1:-1:Blb.G7(a.a,b.a,f);if(e==-1){l=-i;k=g==i?Blb.J7(b.a,h,a.a,f):Blb.E7(b.a,h,a.a,f);}else {l=g;if(g==i){if(e==0){return Blb.E6(),Blb.D6;}k=Blb.J7(a.a,f,b.a,h);}else {k=Blb.E7(a.a,f,b.a,h);}}j=new Blb.Z6(l,k.length,k);Blb.H6(j);return j;};Blb.J7=function J7(a,b,c,d){var e;e=gW(Ykb.AX,gmb,6,b,15,1);Blb.K7(e,a,b,c,d);return e;};Blb.K7=function K7(a,b,c,d,e){var f,g;f=0;for(g=0;g<e;g++){f=d1(f,F1(e1(Ykb.m1(b[g]),$sb),e1(Ykb.m1(d[g]),$sb)));a[g]=I1(f);f=D1(f,32);}for(;g<c;g++){f=d1(f,e1(Ykb.m1(b[g]),$sb));a[g]=I1(f);f=D1(f,32);}};Blb.O7=function O7(){Blb.O7=W1;var a,b;Blb.L7=gW(Ykb.p_,Bqb,21,32,0,1);Blb.M7=gW(Ykb.p_,Bqb,21,32,0,1);Blb.N7=oW(aW(Ykb.AX,1),gmb,6,15,[1,10,100,1000,$lb,Mob,1000000,10000000,100000000,Rsb]);a=1;for(b=0;b<=18;b++){Blb.L7[b]=(Blb.E6(),j1(a,0)>=0?Blb.e7(a):Blb.Q6(Blb.e7(y1(a))));Blb.M7[b]=s1(C1(a,b),0)?Blb.e7(C1(a,b)):Blb.Q6(Blb.e7(y1(C1(a,b))));a=x1(a,5);}for(;b<Blb.M7.length;b++){Blb.L7[b]=Blb.P6(Blb.L7[b-1],Blb.L7[1]);Blb.M7[b]=Blb.P6(Blb.M7[b-1],(Blb.E6(),Blb.B6));}};Blb.P7=function P7(a,b){Blb.O7();var c,d,e,f,g,h,i,j,k;if(b.d>a.d){h=a;a=b;b=h;}if(b.d<63){return Blb.V7(a,b);}g=(a.d&-2)<<4;j=Blb.U6(a,g);k=Blb.U6(b,g);d=Blb.I7(a,Blb.S6(j,g));e=Blb.I7(b,Blb.S6(k,g));i=Blb.P7(j,k);c=Blb.P7(d,e);f=Blb.P7(Blb.I7(j,d),Blb.I7(e,k));f=Blb.D7(Blb.D7(f,i),c);f=Blb.S6(f,g);i=Blb.S6(i,g<<1);return Blb.D7(Blb.D7(i,f),c);};Blb.Q7=function Q7(a,b,c,d,e){if(b==0||d==0){return;}b==1?e[d]=Blb.S7(e,c,d,a[0]):d==1?e[b]=Blb.S7(e,a,b,c[0]):Blb.R7(a,c,e,b,d);};Blb.R7=function R7(a,b,c,d,e){var f,g,h,i;if(uX(a)===uX(b)&&d==e){Blb.Y7(a,d,c);return;}for(h=0;h<d;h++){g=0;f=a[h];for(i=0;i<e;i++){g=d1(d1(x1(e1(Ykb.m1(f),$sb),e1(Ykb.m1(b[i]),$sb)),e1(Ykb.m1(c[h+i]),$sb)),e1(q1(I1(g)),$sb));c[h+i]=I1(g);g=E1(g,32);}c[h+e]=I1(g);}};Blb.S7=function S7(a,b,c,d){Blb.O7();var e,f;e=0;for(f=0;f<c;f++){e=d1(x1(e1(Ykb.m1(b[f]),$sb),e1(Ykb.m1(d),$sb)),e1(q1(I1(e)),$sb));a[f]=I1(e);e=E1(e,32);}return I1(e);};Blb.T7=function T7(a,b){var c,d,e,f,g,h,i,j,k;j=a.e;if(j==0){return Blb.E6(),Blb.D6;}d=a.d;c=a.a;if(d==1){e=x1(e1(Ykb.m1(c[0]),$sb),e1(Ykb.m1(b),$sb));i=I1(e);g=I1(E1(e,32));return g==0?new Blb.X6(j,i):new Blb.Z6(j,2,oW(aW(Ykb.AX,1),gmb,6,15,[i,g]));}h=d+1;f=gW(Ykb.AX,gmb,6,h,15,1);f[d]=Blb.S7(f,c,d,b);k=new Blb.Z6(j,h,f);Blb.H6(k);return k;};Blb.U7=function U7(a,b){Blb.O7();return b<Blb.N7.length?Blb.T7(a,Blb.N7[b]):Blb.P6(a,Blb.X7(b));};Blb.V7=function V7(a,b){var c,d,e,f,g,h,i,j,k,l,m;d=a.d;f=b.d;h=d+f;i=a.e!=b.e?-1:1;if(h==2){k=x1(e1(q1(a.a[0]),$sb),e1(q1(b.a[0]),$sb));m=I1(k);l=I1(E1(k,32));return l==0?new Blb.X6(i,m):new Blb.Z6(i,2,oW(aW(Ykb.AX,1),gmb,6,15,[m,l]));}c=a.a;e=b.a;g=gW(Ykb.AX,gmb,6,h,15,1);Blb.Q7(c,d,e,f,g);j=new Blb.Z6(i,h,g);Blb.H6(j);return j;};Blb.W7=function W7(a,b){Blb.O7();var c,d;d=(Blb.E6(),Blb.z6);c=a;for(;b>1;b>>=1){(b&1)!=0&&(d=Blb.P6(d,c));c.d==1?c=Blb.P6(c,c):c=new Blb.$6(Blb.Y7(c.a,c.d,gW(Ykb.AX,gmb,6,c.d<<1,15,1)));}d=Blb.P6(d,c);return d;};Blb.X7=function X7(a){Blb.O7();var b,c,d,e;b=vX(a);if(a<Blb.M7.length){return Blb.M7[b];}else if(a<=50){return Blb.R6((Blb.E6(),Blb.B6),b);}else if(a<=1000){return Blb.S6(Blb.R6(Blb.L7[1],b),b);}if(a>1000000){throw c1(new Zkb.F2('power of ten too big'));}if(a<=Qlb){return Blb.S6(Blb.R6(Blb.L7[1],b),b);}d=Blb.R6(Blb.L7[1],Qlb);e=d;c=p1(a-Qlb);b=vX(a%Qlb);while(j1(c,Qlb)>0){e=Blb.P6(e,d);c=F1(c,Qlb);}e=Blb.P6(e,Blb.R6(Blb.L7[1],b));e=Blb.S6(e,Qlb);c=p1(a-Qlb);while(j1(c,Qlb)>0){e=Blb.S6(e,Qlb);c=F1(c,Qlb);}e=Blb.S6(e,b);return e;};Blb.Y7=function Y7(a,b,c){var d,e,f,g,h;for(f=0;f<b;f++){d=0;for(h=f+1;h<b;h++){d=d1(d1(x1(e1(Ykb.m1(a[f]),$sb),e1(Ykb.m1(a[h]),$sb)),e1(Ykb.m1(c[f+h]),$sb)),e1(q1(I1(d)),$sb));c[f+h]=I1(d);d=E1(d,32);}c[f+b]=I1(d);}Blb.p7(c,c,b<<1);d=0;for(e=0,g=0;e<b;++e,g++){d=d1(d1(x1(e1(Ykb.m1(a[e]),$sb),e1(Ykb.m1(a[e]),$sb)),e1(Ykb.m1(c[g]),$sb)),e1(q1(I1(d)),$sb));c[g]=I1(d);d=E1(d,32);++g;d=d1(d,e1(Ykb.m1(c[g]),$sb));c[g]=I1(d);d=E1(d,32);}return c;};Blb.f8=function f8(){Blb.f8=W1;Blb.e8=new Blb.g8('UP',0);Blb.$7=new Blb.g8('DOWN',1);Blb.Z7=new Blb.g8('CEILING',2);Blb._7=new Blb.g8('FLOOR',3);Blb.c8=new Blb.g8('HALF_UP',4);Blb.a8=new Blb.g8('HALF_DOWN',5);Blb.b8=new Blb.g8('HALF_EVEN',6);Blb.d8=new Blb.g8('UNNECESSARY',7);};Blb.g8=function g8(a,b){_z.call(this,a,b);};Blb.h8=function h8(){Blb.f8();return oW(aW(Ykb.q_,1),Bqb,61,0,[Blb.e8,Blb.$7,Blb.Z7,Blb._7,Blb.c8,Blb.a8,Blb.b8,Blb.d8]);};U1(61,52,{4:1,27:1,52:1,61:1},Blb.g8);Ykb.q_=x3(61,Blb.h8);Clb.i8=function i8(a,b){return Zkb.$4(a.a,b.a);};Clb.j8=function j8(a){this.a=a;};U1(88,1,atb);_.qb=function k8(a){return Clb.i8(this,a);};_.ib=function l8(a){var b;if(a===this){return true;}if(!mX(a,88)){return false;}b=a;return Zkb.c5(this.a,b.a);};_.kb=function m8(){return Zkb.f5(this.a);};_.lb=function n8(){return this.a;};Ykb.r_=w3(88);U1(338,1,{});Ykb.t_=w3(338);Dlb.o8=function o8(a,b){return ulb.IV(a.a,b);};Dlb.p8=function p8(a,b){return ulb.IV(a.a,b);};Dlb.q8=function q8(a){this.a=(ulb.CV(),new ulb.TV(a,ulb.xV()));};Dlb.r8=function r8(a){Dlb.q8.call(this,a);};U1(113,338,{},Dlb.q8,Dlb.r8);Ykb.s_=w3(113);dlb.Kdb=function Kdb(a,b,c){var d;d=a.get(b);return d==null&&!a.containsKey(b)?c:d;};dlb.Ldb=function Ldb(a,b,c){var d;d=a.get(b);return d!=null?d:a.put(b,c);};dlb.Mdb=function Mdb(a,b,c){return a.containsKey(b)?a.put(b,c):null;};dlb.s8=function s8(a){a.dc().clear();};dlb.t8=function t8(a,b){var c,d,e;c=b.hc();e=b.ic();d=a.get(c);if(!(uX(e)===uX(d)||e!=null&&Zkb.Gc(e,d))){return false;}if(d==null&&!a.containsKey(c)){return false;}return true;};dlb.u8=function u8(a,b,c){var d,e,f;for(e=a.dc().rb();e.ec();){d=e.fc();f=d.hc();if(uX(b)===uX(f)||b!=null&&Zkb.Gc(b,f)){if(c){d=new dlb.Cab(d.hc(),d.ic());e.gc();}return d;}}return null;};dlb.v8=function v8(a){return a.size()==0;};dlb.w8=function w8(a){return new dlb.Y9(a);};dlb.x8=function x8(a,b){return b===a?'(this Map)':b==null?Slb:_1(b);};dlb.y8=function y8(a){return new dlb.hab(a);};dlb.F8=function F8(a){return !a?null:a.ic();};U1(332,1,btb);_.getOrDefault=function G8(a,b){var c;return c=this.get(a),c==null&&!this.containsKey(a)?b:c;};_.putIfAbsent=function M8(a,b){var c;return c=this.get(a),c!=null?c:this.put(a,b);};_.replace=function O8(a,b){return this.containsKey(a)?this.put(a,b):null;};_.clear=function z8(){dlb.s8(this);};_.cc=function A8(a){return dlb.t8(this,a);};_.containsKey=function B8(a){return !!dlb.u8(this,a,false);};_.containsValue=function C8(a){var b,c,d;for(c=this.dc().rb();c.ec();){b=c.fc();d=b.ic();if(uX(a)===uX(d)||a!=null&&Zkb.Gc(a,d)){return true;}}return false;};_.ib=function D8(a){var b,c,d;if(a===this){return true;}if(!mX(a,99)){return false;}d=a;if(this.size()!=d.size()){return false;}for(c=d.dc().rb();c.ec();){b=c.fc();if(!this.cc(b)){return false;}}return true;};_.get=function E8(a){return dlb.F8(dlb.u8(this,a,false));};_.kb=function H8(){return dlb.wcb(this.dc());};_.isEmpty=function I8(){return dlb.v8(this);};_.keySet=function J8(){return dlb.w8(this);};_.put=function K8(a,b){throw c1(new Zkb.S5('Put not supported on this map'));};_.putAll=function L8(a){var b,c;alb.Egb(a);for(c=a.dc().rb();c.ec();){b=c.fc();this.put(b.hc(),b.ic());}};_.remove=function N8(a){return dlb.F8(dlb.u8(this,a,true));};_.size=function P8(){return this.dc().size();};_.lb=function Q8(){var a,b,c;c=new dlb.aeb('{','}');for(b=this.dc().rb();b.ec();){a=b.fc();dlb.$db(c,dlb.x8(this,a.hc())+'='+dlb.x8(this,a.ic()));}return !c.a?c.c:alb.Pgb(c.e).length==0?c.a.a:c.a.a+(''+c.e);};_.values=function R8(){return dlb.y8(this);};Ykb.J_=w3(332);dlb.S8=function S8(a){dlb.c9(a);};dlb.T8=function T8(a,b){return rX(b)?dlb.Z8(a,alb.Pgb(b)):!!dlb.Ycb(a.a,b);};dlb.U8=function U8(a,b){return dlb.V8(b,a.c)||dlb.V8(b,a.a);};dlb.V8=function V8(a,b){var c,d;for(d=b.rb();d.ec();){c=d.fc();if(dlb.Jcb(a,c.ic())){return true;}}return false;};dlb.W8=function W8(a){return new dlb.s9(a);};dlb.X8=function X8(a,b){return rX(b)?dlb.Y8(a,alb.Pgb(b)):dlb.F8(dlb.Ycb(a.a,b));};dlb.Y8=function Y8(a,b){return b==null?dlb.F8(dlb.Ycb(a.a,null)):dlb.rdb(a.c,b);};dlb.Z8=function Z8(a,b){return b==null?!!dlb.Ycb(a.a,null):dlb.qdb(a.c,b);};dlb.$8=function $8(a,b,c){return rX(b)?dlb._8(a,alb.Pgb(b),c):dlb.$cb(a.a,b,c);};dlb._8=function _8(a,b,c){return b==null?dlb.$cb(a.a,null,c):dlb.tdb(a.c,b,c);};dlb.a9=function a9(a,b){return rX(b)?dlb.b9(a,alb.Pgb(b)):dlb._cb(a.a,b);};dlb.b9=function b9(a,b){return b==null?dlb._cb(a.a,null):dlb.udb(a.c,b);};dlb.c9=function c9(a){a.a=new dlb.adb(a);a.c=new dlb.vdb(a);++a.b;};dlb.d9=function d9(a){return a.a.c+a.c.c;};dlb.e9=function e9(){dlb.c9(this);};U1(246,332,btb);_.clear=function f9(){dlb.S8(this);};_.containsKey=function g9(a){return dlb.T8(this,a);};_.containsValue=function h9(a){return dlb.U8(this,a);};_.dc=function i9(){return dlb.W8(this);};_.get=function j9(a){return dlb.X8(this,a);};_.put=function k9(a,b){return dlb.$8(this,a,b);};_.remove=function l9(a){return dlb.a9(this,a);};_.size=function m9(){return dlb.d9(this);};_.b=0;Ykb.x_=w3(246);U1(333,39,ctb);_.ib=function n9(a){var b;if(a===this){return true;}if(!mX(a,86)){return false;}b=a;if(b.size()!=this.size()){return false;}return dlb.Th(this,b);};_.kb=function o9(){return dlb.wcb(this);};_.removeAll=function p9(a){var b,c,d,e;alb.Egb(a);e=this.size();if(e<a.size()){for(b=this.rb();b.ec();){c=b.fc();a.contains(c)&&b.gc();}}else {for(d=a.rb();d.ec();){c=d.fc();this.remove(c);}}return e!=this.size();};Ykb.O_=w3(333);dlb.q9=function q9(a){dlb.c9(a.a);};dlb.r9=function r9(a,b){if(mX(b,72)){return dlb.t8(a.a,b);}return false;};dlb.s9=function s9(a){this.a=a;};U1(145,333,ctb,dlb.s9);_.clear=function t9(){dlb.q9(this);};_.contains=function u9(a){return dlb.r9(this,a);};_.rb=function v9(){return new dlb.C9(this.a);};_.remove=function w9(a){var b;if(dlb.r9(this,a)){b=a.hc();dlb.a9(this.a,b);return true;}return false;};_.size=function x9(){return dlb.d9(this.a);};Ykb.w_=w3(145);dlb.Jdb=function Jdb(){throw c1(new Zkb.R5());};dlb.y9=function y9(a){a.e=new dlb.zdb(a.f.c);a.a=a.e;a.b=dlb.z9(a);a.d=a.f.b;};dlb.z9=function z9(a){if(a.a.ec()){return true;}if(a.a!=a.e){return false;}a.a=new dlb.ddb(a.f.a);return a.a.ec();};dlb.A9=function A9(a){return a.b;};dlb.B9=function B9(a){var b;alb.Bgb(a.f.b,a.d);alb.Cgb(a.b);a.c=a.a;b=a.a.fc();a.b=dlb.z9(a);return b;};dlb.C9=function C9(a){this.f=a;dlb.y9(this);};U1(247,1,{},dlb.C9);_.fc=function E9(){return dlb.B9(this);};_.ec=function D9(){return dlb.A9(this);};_.gc=function F9(){alb.Igb(!!this.c);alb.Bgb(this.f.b,this.d);this.c.gc();this.c=null;this.b=dlb.z9(this);this.d=this.f.b;};_.b=false;_.d=0;Ykb.v_=w3(247);dlb.G9=function G9(a){};dlb.H9=function H9(a){return a.a<a.c.size();};dlb.I9=function I9(a){alb.Cgb(a.a<a.c.size());return a.c.getAtIndex(a.b=a.a++);};dlb.J9=function J9(a){alb.Igb(a.b!=-1);a.c.removeAtIndex(a.b);a.a=a.b;a.b=-1;};dlb.K9=function K9(a){this.c=a;dlb.G9(this);};U1(174,1,{},dlb.K9);_.ec=function L9(){return dlb.H9(this);};_.fc=function M9(){return dlb.I9(this);};_.gc=function N9(){dlb.J9(this);};_.a=0;_.b=-1;Ykb.y_=w3(174);dlb.O9=function O9(a){dlb.J9(a);};dlb.P9=function P9(a,b){dlb.K9.call(this,a);alb.Ggb(b,a.size());this.a=b;};U1(175,174,{},dlb.P9);_.gc=function Q9(){dlb.O9(this);};Ykb.z_=w3(175);dlb.R9=function R9(a,b,c){alb.Hgb(b,c,a.size());this.c=a;this.a=b;this.b=c-b;};U1(176,80,Onb,dlb.R9);_.addAtIndex=function S9(a,b){alb.Ggb(a,this.b);this.c.addAtIndex(this.a+a,b);++this.b;};_.getAtIndex=function T9(a){alb.Dgb(a,this.b);return this.c.getAtIndex(this.a+a);};_.removeAtIndex=function U9(a){var b;alb.Dgb(a,this.b);b=this.c.removeAtIndex(this.a+a);--this.b;return b;};_.setAtIndex=function V9(a,b){alb.Dgb(a,this.b);return this.c.setAtIndex(this.a+a,b);};_.size=function W9(){return this.b;};_.a=0;_.b=0;Ykb.A_=w3(176);dlb.X9=function X9(a){var b;b=a.a.dc().rb();return new dlb.cab(b);};dlb.Y9=function Y9(a){this.a=a;};U1(177,333,ctb,dlb.Y9);_.clear=function Z9(){this.a.clear();};_.contains=function $9(a){return this.a.containsKey(a);};_.rb=function _9(){return dlb.X9(this);};_.remove=function aab(a){if(this.a.containsKey(a)){this.a.remove(a);return true;}return false;};_.size=function bab(){return this.a.size();};Ykb.D_=w3(177);dlb.cab=function cab(a){this.a=a;};U1(178,1,{},dlb.cab);_.ec=function dab(){return this.a.ec();};_.fc=function eab(){var a;a=this.a.fc();return a.hc();};_.gc=function fab(){this.a.gc();};Ykb.C_=w3(178);dlb.gab=function gab(a){var b;b=a.a.dc().rb();return new dlb.oab(b);};dlb.hab=function hab(a){this.a=a;};U1(137,39,Nnb,dlb.hab);_.clear=function iab(){this.a.clear();};_.contains=function jab(a){return this.a.containsValue(a);};_.rb=function kab(){return dlb.gab(this);};_.size=function lab(){return this.a.size();};Ykb.F_=w3(137);dlb.mab=function mab(a){return a.a.ec();};dlb.nab=function nab(a){var b;b=a.a.fc();return b.ic();};dlb.oab=function oab(a){this.a=a;};U1(138,1,{},dlb.oab);_.ec=function pab(){return dlb.mab(this);};_.fc=function qab(){return dlb.nab(this);};_.gc=function rab(){this.a.gc();};Ykb.E_=w3(138);dlb.sab=function sab(a){return a.c;};dlb.tab=function tab(a){return a.d;};dlb.uab=function uab(a,b){var c;c=a.d;a.d=b;return c;};dlb.vab=function vab(a,b){this.c=a;this.d=b;};U1(124,1,{124:1,72:1});_.ib=function wab(a){var b;if(!mX(a,72)){return false;}b=a;return dlb.Odb(this.c,b.hc())&&dlb.Odb(this.d,b.ic());};_.hc=function xab(){return dlb.sab(this);};_.ic=function yab(){return dlb.tab(this);};_.kb=function zab(){return dlb.Pdb(this.c)^dlb.Pdb(this.d);};_.jc=function Aab(a){return dlb.uab(this,a);};_.lb=function Bab(){return this.c+'='+this.d;};Ykb.G_=w3(124);dlb.Cab=function Cab(a,b){dlb.vab.call(this,a,b);};U1(112,124,{124:1,112:1,72:1},dlb.Cab);Ykb.H_=w3(112);U1(337,1,{72:1});_.ib=function Dab(a){var b;if(!mX(a,72)){return false;}b=a;return dlb.Odb(alb.Pgb(this.b.value[0]),b.hc())&&dlb.Odb(dlb.Edb(this),b.ic());};_.kb=function Eab(){return dlb.Pdb(alb.Pgb(this.b.value[0]))^dlb.Pdb(dlb.Edb(this));};_.lb=function Fab(){return alb.Pgb(this.b.value[0])+'='+dlb.Edb(this);};Ykb.I_=w3(337);dlb.Gab=function Gab(a,b){var c,d;c=b.hc();d=dlb.feb(a,c);return !!d&&dlb.Odb(d.d,b.ic());};dlb.Hab=function Hab(a,b){var c;c=b;return !!dlb.feb(a,c);};dlb.Iab=function Iab(a,b){var c;c=b;return dlb.F8(dlb.feb(a,c));};dlb.Jab=function Jab(a){return new dlb.Wab(a);};U1(335,332,btb);_.cc=function Kab(a){return dlb.Gab(this,a);};_.containsKey=function Lab(a){return dlb.Hab(this,a);};_.dc=function Mab(){return new dlb.Qab(this);};_.get=function Nab(a){return dlb.Iab(this,a);};_.keySet=function Oab(){return dlb.Jab(this);};Ykb.N_=w3(335);dlb.Pab=function Pab(a){return new dlb.Ceb(a.b);};dlb.Qab=function Qab(a){this.b=a;};U1(181,333,ctb,dlb.Qab);_.contains=function Rab(a){return mX(a,72)&&dlb.Gab(this.b,a);};_.rb=function Sab(){return dlb.Pab(this);};_.remove=function Tab(a){var b;if(mX(a,72)){b=a;return dlb.meb(this.b,b);}return false;};_.size=function Uab(){return this.b.c;};Ykb.K_=w3(181);dlb.Vab=function Vab(a){var b;b=new dlb.Ceb(new dlb.Heb(a.a).b);return new dlb.cbb(b);};dlb.Wab=function Wab(a){this.a=a;};U1(107,333,ctb,dlb.Wab);_.clear=function Xab(){dlb.deb(this.a);};_.contains=function Yab(a){return dlb.Hab(this.a,a);};_.rb=function Zab(){return dlb.Vab(this);};_.remove=function $ab(a){if(dlb.Hab(this.a,a)){dlb.leb(this.a,a);return true;}return false;};_.size=function _ab(){return this.a.c;};Ykb.M_=w3(107);dlb.abb=function abb(a){return dlb.H9(a.a.a);};dlb.bbb=function bbb(a){var b;b=dlb.Aeb(a.a);return b.hc();};dlb.cbb=function cbb(a){this.a=a;};U1(108,1,{},dlb.cbb);_.ec=function dbb(){return dlb.abb(this);};_.fc=function ebb(){return dlb.bbb(this);};_.gc=function fbb(){dlb.Beb(this.a);};Ykb.L_=w3(108);dlb.gbb=function gbb(a,b){dlb.hbb(a,b);return true;};dlb.hbb=function hbb(a,b){alb.Egb(b);kW(a.a,a.c,b);a.c=a.c+1&a.a.length-1;dlb.kbb(a);};dlb.ibb=function ibb(a,b){if(b==null){return false;}while(a.a!=a.b){if(Zkb.Gc(b,dlb.Fbb(a))){return true;}}return false;};dlb.jbb=function jbb(a,b,c){var d,e,f;f=a.a.length-1;for(e=a.b,d=0;d<c;e=e+1&f,++d){kW(b,d,a.a[e]);}};dlb.kbb=function kbb(a){var b,c,d;if(a.b!=a.c){return;}d=a.a.length;c=o4($wnd.Math.max(8,d))<<1;if(a.b!=0){b=alb.cgb(a.a,c);dlb.jbb(a,b,d);a.a=b;a.b=0;}else {alb.igb(a.a,c);}a.c=d;};dlb.lbb=function lbb(a){return a.b==a.c;};dlb.mbb=function mbb(a){return new dlb.Hbb(a);};dlb.nbb=function nbb(a){var b;b=a.a[a.b];if(b==null){return null;}kW(a.a,a.b,null);a.b=a.b+1&a.a.length-1;return b;};dlb.obb=function obb(a,b){if(dlb.ibb(a,b)){dlb.Gbb(a);return true;}return false;};dlb.pbb=function pbb(a,b){var c,d,e,f;d=a.a.length-1;c=b-a.b&d;f=a.c-b&d;e=a.c-a.b&d;dlb.vbb(c<e);if(c>=f){dlb.qbb(a,b);return -1;}else {dlb.rbb(a,b);return 1;}};dlb.qbb=function qbb(a,b){var c,d;c=a.a.length-1;a.c=a.c-1&c;while(b!=a.c){d=b+1&c;kW(a.a,b,a.a[d]);b=d;}kW(a.a,a.c,null);};dlb.rbb=function rbb(a,b){var c,d;c=a.a.length-1;while(b!=a.b){d=b-1&c;kW(a.a,b,a.a[d]);b=d;}kW(a.a,a.b,null);a.b=a.b+1&c;};dlb.sbb=function sbb(a){return a.c-a.b&a.a.length-1;};dlb.tbb=function tbb(){this.a=gW(Ykb.f_,Ulb,1,8,5,1);};dlb.vbb=function vbb(a){if(!a){throw c1(new dlb.Icb());}};U1(294,39,{5:1,38:1,39:1,45:1},dlb.tbb);_.add=function ubb(a){return dlb.gbb(this,a);};_.clear=function wbb(){if(this.b==this.c){return;}this.a=gW(Ykb.f_,Ulb,1,8,5,1);this.b=0;this.c=0;};_.contains=function xbb(a){return dlb.ibb(new dlb.Hbb(this),a);};_.isEmpty=function ybb(){return dlb.lbb(this);};_.rb=function zbb(){return dlb.mbb(this);};_.remove=function Abb(a){return dlb.obb(new dlb.Hbb(this),a);};_.size=function Bbb(){return dlb.sbb(this);};_.sb=function Cbb(a){var b;b=this.c-this.b&this.a.length-1;a.length<b&&(a=alb.kgb(new Array(b),a));dlb.jbb(this,a,b);a.length>b&&Ykb.jW(a,b,null);return a;};_.b=0;_.c=0;Ykb.Q_=w3(294);dlb.Dbb=function Dbb(a){a.a=a.d.b;a.b=a.d.c;};dlb.Ebb=function Ebb(a){return a.a!=a.b;};dlb.Fbb=function Fbb(a){var b;alb.Cgb(a.a!=a.b);b=a.d.a[a.a];dlb.vbb(a.b==a.d.c&&b!=null);a.c=a.a;a.a=a.a+1&a.d.a.length-1;return b;};dlb.Gbb=function Gbb(a){alb.Igb(a.c>=0);if(dlb.pbb(a.d,a.c)<0){a.a=a.a-1&a.d.a.length-1;a.b=a.d.c;}a.c=-1;};dlb.Hbb=function Hbb(a){this.d=a;dlb.Dbb(this);};U1(153,1,{},dlb.Hbb);_.ec=function Ibb(){return dlb.Ebb(this);};_.fc=function Jbb(){return dlb.Fbb(this);};_.gc=function Kbb(){dlb.Gbb(this);};_.a=0;_.b=0;_.c=-1;Ykb.P_=w3(153);dlb.Lbb=function Lbb(a){};dlb.Mbb=function Mbb(a){return a.a<a.c.a.length;};dlb.Nbb=function Nbb(a){alb.Cgb(a.a<a.c.a.length);a.b=a.a++;return a.c.a[a.b];};dlb.Obb=function Obb(a){this.c=a;dlb.Lbb(this);};U1(20,1,{},dlb.Obb);_.ec=function Pbb(){return dlb.Mbb(this);};_.fc=function Qbb(){return dlb.Nbb(this);};_.gc=function Rbb(){alb.Igb(this.b!=-1);dlb.Ii(this.c,this.a=this.b);this.b=-1;};_.a=0;_.b=-1;Ykb.R_=w3(20);dlb.Sbb=function Sbb(a,b){alb.Agb(b);return dlb.Wbb(a,gW(Ykb.wX,Fnb,6,b,15,1),b);};dlb.Tbb=function Tbb(a,b){alb.Agb(b);return dlb.Wbb(a,gW(Ykb.yX,emb,6,b,15,1),b);};dlb.Ubb=function Ubb(a,b){alb.Agb(b);return dlb.Wbb(a,gW(Ykb.AX,gmb,6,b,15,1),b);};dlb.Vbb=function Vbb(a,b){alb.Agb(b);return dlb.Wbb(a,gW(Ykb.Y0,znb,6,b,15,1),b);};dlb.Wbb=function Wbb(a,b,c){var d,e;e=alb.Pgb(a).length;d=$wnd.Math.min(c,e);alb.bgb(a,0,b,0,d,true);return b;};dlb.Xbb=function Xbb(a){dlb.acb(a,a.length);};dlb.Ybb=function Ybb(a){dlb.bcb(a,a.length,-1);};dlb.Zbb=function Zbb(a){dlb.ccb(a,a.length);};dlb.$bb=function $bb(a){dlb.dcb(a,a.length);};dlb._bb=function _bb(a){dlb.ecb(a,a.length);};dlb.acb=function acb(a,b){var c;for(c=0;c<b;++c){a[c]=-1;}};dlb.bcb=function bcb(a,b,c){var d;for(d=0;d<b;++d){a[d]=c;}};dlb.ccb=function ccb(a,b){var c;for(c=0;c<b;++c){a[c]=0;}};dlb.dcb=function dcb(a,b){var c;for(c=0;c<b;++c){a[c]=-1;}};dlb.ecb=function ecb(a,b){var c;for(c=0;c<b;++c){a[c]=false;}};dlb.fcb=function fcb(a){var b,c,d,e,f;f=1;for(c=a,d=0,e=c.length;d<e;++d){b=c[d];f=31*f+(b!=null?Zkb.Kc(b):0);f=f|0;}return f;};dlb.gcb=function gcb(a,b,c,d){var e,f,g;for(e=b+1;e<c;++e){for(f=e;f>b&&d.pb(a[f-1],a[f])>0;--f){g=a[f];Ykb.jW(a,f,a[f-1]);Ykb.jW(a,f-1,g);}}};dlb.hcb=function hcb(a,b,c,d,e,f,g,h){var i;i=c;while(f<g){i>=d||b<c&&h.pb(a[b],a[i])<=0?kW(e,f++,a[b++]):kW(e,f++,a[i++]);}};dlb.icb=function icb(a,b,c,d){var e;d=(dlb.Dcb(),!d?dlb.Ccb:d);e=alb.Pgb(a).slice(b,c);dlb.jcb(e,a,b,c,-b,d);};dlb.jcb=function jcb(a,b,c,d,e,f){var g,h,i,j;g=d-c;if(g<7){dlb.gcb(b,c,d,f);return;}i=c+e;h=d+e;j=i+(h-i>>1);dlb.jcb(b,a,i,j,-e,f);dlb.jcb(b,a,j,h,-e,f);if(f.pb(a[j-1],a[j])<=0){while(c<d){kW(b,c++,a[i++]);}return;}dlb.hcb(a,i,j,h,b,c,d,f);};dlb.kcb=function kcb(a){dlb.icb(a,0,a.length,null);};dlb.lcb=function lcb(a,b,c){alb.zgb(b,a.length);dlb.icb(a,0,b,c);};dlb.mcb=function mcb(a,b){dlb.icb(a,0,a.length,b);};dlb.ncb=function ncb(){return Ykb.r$;};dlb.ocb=function ocb(){};U1(304,$wnd.Function,{},dlb.ocb);_.kc=function pcb(a,b){return $3(a,b);};dlb.qcb=function qcb(){return Ykb.r$;};dlb.rcb=function rcb(){};U1(349,$wnd.Function,{},dlb.rcb);_.lc=function scb(a,b){return j1(a,b)<0?-1:j1(a,b)>0?1:0;};dlb.tcb=function tcb(){return Ykb.r$;};dlb.ucb=function ucb(){};U1(49,$wnd.Function,{},dlb.ucb);_.kc=function vcb(a,b){return a-b;};dlb.wcb=function wcb(a){var b,c,d;d=0;for(c=a.rb();c.ec();){b=c.fc();d=d+(b!=null?Zkb.Kc(b):0);d=d|0;}return d;};dlb.xcb=function xcb(a){var b,c,d;d=1;for(c=a.rb();c.ec();){b=c.fc();d=31*d+(b!=null?Zkb.Kc(b):0);d=d|0;}return d;};dlb.ycb=function ycb(a,b){return $3(a.b,b.b);};dlb.zcb=function zcb(){};U1(208,1,fmb,dlb.zcb);_.pb=function Acb(a,b){return dlb.ycb(a,b);};_.ib=function Bcb(a){return this===a;};Ykb.T_=w3(208);dlb.Dcb=function Dcb(){dlb.Dcb=W1;dlb.Ccb=new dlb.Fcb();};dlb.Ecb=function Ecb(a,b){return alb.Egb(a),Zkb.U2(a,(alb.Egb(b),b));};dlb.Fcb=function Fcb(){};U1(271,1,fmb,dlb.Fcb);_.pb=function Gcb(a,b){return dlb.Ecb(a,b);};_.ib=function Hcb(a){return this===a;};Ykb.U_=w3(271);dlb.Icb=function Icb(){Zkb.sz.call(this);};U1(206,41,Vlb,dlb.Icb);Ykb.V_=w3(206);dlb.Jcb=function Jcb(a,b){return uX(a)===uX(b)||a!=null&&Zkb.Gc(a,b);};dlb.Kcb=function Kcb(a){var b;if(a==null){return 0;}b=Zkb.Kc(a);return b|0;};dlb.Lcb=function Lcb(){dlb.e9.call(this);};U1(93,246,{4:1,5:1,99:1},dlb.Lcb);Ykb.W_=w3(93);dlb.Mcb=function Mcb(a,b){var c;c=dlb.$8(a.a,b,a);return c==null;};dlb.Ncb=function Ncb(){this.a=new dlb.Lcb();};U1(128,333,{4:1,5:1,38:1,39:1,45:1,86:1},dlb.Ncb);_.add=function Ocb(a){return dlb.Mcb(this,a);};_.clear=function Pcb(){dlb.c9(this.a);};_.contains=function Qcb(a){return dlb.T8(this.a,a);};_.isEmpty=function Rcb(){return dlb.d9(this.a)==0;};_.rb=function Scb(){var a;return a=new dlb.Y9(this.a).a.dc().rb(),new dlb.cab(a);};_.remove=function Tcb(a){return dlb.a9(this.a,a)!=null;};_.size=function Ucb(){return dlb.d9(this.a);};Ykb.X_=w3(128);dlb.Vcb=function Vcb(a){a.a=dlb.odb();};dlb.Wcb=function Wcb(a,b){var c,d,e,f;for(d=b,e=0,f=d.length;e<f;++e){c=d[e];if(dlb.Jcb(a,c.hc())){return c;}}return null;};dlb.Xcb=function Xcb(a,b){var c;c=alb.Pgb(a.a.get(b));return c==null?alb.Pgb(gW(Ykb.f_,Ulb,1,0,5,1)):c;};dlb.Ycb=function Ycb(a,b){return dlb.Wcb(b,dlb.Xcb(a,dlb.Kcb(b)));};dlb.Zcb=function Zcb(a){return new dlb.ddb(a);};dlb.$cb=function $cb(a,b,c){var d,e,f,g;g=dlb.Kcb(b);e=(d=alb.Pgb(a.a.get(g)),d==null?alb.Pgb(gW(Ykb.f_,Ulb,1,0,5,1)):d);if(e.length==0){a.a.set(g,e);}else {f=dlb.Wcb(b,e);if(f){return f.jc(c);}}kW(e,e.length,new dlb.Cab(b,c));++a.c;++a.b.b;return null;};dlb._cb=function _cb(a,b){var c,d,e,f,g;f=dlb.Kcb(b);d=(c=alb.Pgb(a.a.get(f)),c==null?alb.Pgb(gW(Ykb.f_,Ulb,1,0,5,1)):c);for(g=0;g<d.length;g++){e=d[g];if(dlb.Jcb(b,e.hc())){if(d.length==1){alb.Pgb(d).length=0;dlb.hdb(a.a,f);}else {alb.Pgb(d).splice(g,1);}--a.c;++a.b.b;return e.ic();}}return null;};dlb.adb=function adb(a){dlb.Vcb(this);this.b=a;};U1(274,1,{38:1},dlb.adb);_.rb=function bdb(){return dlb.Zcb(this);};_.c=0;Ykb.Z_=w3(274);dlb.cdb=function cdb(a){a.b=a.e.a.entries();a.a=alb.Pgb(gW(Ykb.f_,Ulb,1,0,5,1));};dlb.ddb=function ddb(a){this.e=a;dlb.cdb(this);};U1(192,1,{},dlb.ddb);_.fc=function fdb(){return this.d=this.a[this.c++],this.d;};_.ec=function edb(){var a;if(this.c<this.a.length){return true;}a=this.b.next();if(!a.done){this.a=alb.Pgb(alb.Pgb(a.value[1]));this.c=0;return true;}return false;};_.gc=function gdb(){dlb._cb(this.e,this.d.hc());this.c!=0&&--this.c;};_.c=0;_.d=null;Ykb.Y_=w3(192);dlb.hdb=function hdb(a,b){var c;c=alb.Mgb(a,dtb);c.call(a,b);};dlb.idb=function idb(a,b){var c;c=alb.Mgb(a,dtb);c.call(a,b);};dlb.kdb=function kdb(){dlb.kdb=W1;dlb.jdb=dlb.mdb();};dlb.ldb=function ldb(){if(!Object.create||!Object.getOwnPropertyNames){return false;}var a='__proto__';var b=Object.create(null);if(b[a]!==undefined){return false;}var c=Object.getOwnPropertyNames(b);if(c.length!=0){return false;}b[a]=42;if(b[a]!==42){return false;}if(Object.getOwnPropertyNames(b).length==0){return false;}return true;};dlb.mdb=function mdb(){function b(){try{return new Map().entries().next().done;}catch(a){return false;}}if(typeof Map==='function'&&Map.prototype.entries&&b()){return Map;}else {return dlb.ndb();}};dlb.ndb=function ndb(){function e(){this.obj=this.createObject();}e.prototype.createObject=function(a){return Object.create(null);};e.prototype.get=function(a){return this.obj[a];};e.prototype.set=function(a,b){this.obj[a]=b;};e.prototype[dtb]=function(a){delete this.obj[a];};e.prototype.keys=function(){return Object.getOwnPropertyNames(this.obj);};e.prototype.entries=function(){var b=this.keys();var c=this;var d=0;return {next:function(){if(d>=b.length)return {done:true};var a=b[d++];return {value:[a,c.get(a)],done:false};}};};if(!dlb.ldb()){e.prototype.createObject=function(){return {};};e.prototype.get=function(a){return this.obj[':'+a];};e.prototype.set=function(a,b){this.obj[':'+a]=b;};e.prototype[dtb]=function(a){delete this.obj[':'+a];};e.prototype.keys=function(){var a=[];for(var b in this.obj){b.charCodeAt(0)==58&&a.push(b.substring(1));}return a;};}return e;};dlb.odb=function odb(){dlb.kdb();return new dlb.jdb();};dlb.pdb=function pdb(a){a.a=dlb.odb();};dlb.qdb=function qdb(a,b){return !alb.Ngb(a.a.get(b));};dlb.rdb=function rdb(a,b){return a.a.get(b);};dlb.sdb=function sdb(a){return new dlb.zdb(a);};dlb.tdb=function tdb(a,b,c){var d;d=a.a.get(b);a.a.set(b,alb.Ngb(c)?null:c);if(alb.Ngb(d)){++a.c;++a.b.b;}else {++a.d;}return d;};dlb.udb=function udb(a,b){var c;c=a.a.get(b);if(alb.Ngb(c)){++a.d;}else {dlb.idb(a.a,b);--a.c;++a.b.b;}return c;};dlb.vdb=function vdb(a){dlb.pdb(this);this.b=a;};U1(272,1,{38:1},dlb.vdb);_.rb=function wdb(){return dlb.sdb(this);};_.c=0;_.d=0;Ykb.a0=w3(272);dlb.xdb=function xdb(a){a.b=a.d.a.entries();a.a=a.b.next();};dlb.ydb=function ydb(a){a.c=a.a;a.a=a.b.next();return new dlb.Fdb(a.d,a.c,a.d.d);};dlb.zdb=function zdb(a){this.d=a;dlb.xdb(this);};U1(191,1,{},dlb.zdb);_.fc=function Bdb(){return dlb.ydb(this);};_.ec=function Adb(){return !this.a.done;};_.gc=function Cdb(){dlb.udb(this.d,alb.Pgb(this.c.value[0]));};Ykb.$_=w3(191);dlb.Ddb=function Ddb(a){return alb.Pgb(a.b.value[0]);};dlb.Edb=function Edb(a){if(a.a.d!=a.c){return dlb.rdb(a.a,alb.Pgb(a.b.value[0]));}return alb.Pgb(a.b.value[1]);};dlb.Fdb=function Fdb(a,b,c){this.a=a;this.b=b;this.c=c;};U1(273,337,{72:1},dlb.Fdb);_.hc=function Gdb(){return dlb.Ddb(this);};_.ic=function Hdb(){return dlb.Edb(this);};_.jc=function Idb(a){return dlb.tdb(this.a,alb.Pgb(this.b.value[0]),a);};_.c=0;Ykb.__=w3(273);dlb.Ndb=function Ndb(){Zkb.sz.call(this);};U1(296,41,Vlb,dlb.Ndb);Ykb.b0=w3(296);dlb.Odb=function Odb(a,b){return uX(a)===uX(b)||a!=null&&Zkb.Gc(a,b);};dlb.Pdb=function Pdb(a){return a!=null?Zkb.Kc(a):0;};dlb.Tdb=function Tdb(){dlb.Tdb=W1;var a,b,c,d;dlb.Qdb=gW(Ykb.yX,emb,6,25,15,1);dlb.Rdb=gW(Ykb.yX,emb,6,33,15,1);d=1.52587890625E-5;for(b=32;b>=0;b--){dlb.Rdb[b]=d;d*=0.5;}c=1;for(a=24;a>=0;a--){dlb.Qdb[a]=c;c*=0.5;}};dlb.Udb=function Udb(a){return dlb.Wdb(a,26)*1.4901161193847656E-8+dlb.Wdb(a,27)*1.1102230246251565E-16;};dlb.Vdb=function Vdb(a,b){var c,d;alb.xgb(b>0);if((b&-b)==b){return vX(b*dlb.Wdb(a,31)*4.6566128730773926E-10);}do{c=dlb.Wdb(a,31);d=c%b;}while(c-d+(b-1)<0);return vX(d);};dlb.Wdb=function Wdb(a,b){var c,d,e,f,g,h;f=a.a*etb+a.b*1502;h=a.b*etb+11;c=$wnd.Math.floor(h*ftb);f+=c;h-=c*gtb;f%=gtb;a.a=f;a.b=h;if(b<=24){return $wnd.Math.floor(a.a*dlb.Qdb[b]);}else {e=a.a*(1<<b-24);g=$wnd.Math.floor(a.b*dlb.Rdb[b]);d=e+g;d>=Gsb&&(d-=lmb);return d;}};dlb.Xdb=function Xdb(a,b,c){a.a=b^1502;a.b=c^etb;};dlb.Ydb=function Ydb(){dlb.Tdb();var a,b,c;c=dlb.Sdb++ +Date.now();a=vX($wnd.Math.floor(c*ftb))&hmb;b=vX(c-a*gtb);this.a=a^1502;this.b=b^etb;};dlb.Zdb=function Zdb(a){dlb.Tdb();dlb.Xdb(this,I1(e1(D1(a,24),hmb)),I1(e1(a,hmb)));};U1(55,1,{},dlb.Ydb,dlb.Zdb);_.a=0;_.b=0;dlb.Sdb=0;Ykb.c0=w3(55);dlb.$db=function $db(a,b){!a.a?a.a=new Zkb.L5(a.d):Zkb.G5(a.a,a.b);Zkb.F5(a.a,b);return a;};dlb._db=function _db(a){return !a.a?a.c:alb.Pgb(a.e).length==0?a.a.a:a.a.a+(''+a.e);};dlb.aeb=function aeb(a,b){this.b=', ';this.d=a;this.e=b;this.c=this.d+(''+this.e);};U1(170,1,{},dlb.aeb);_.lb=function beb(){return dlb._db(this);};Ykb.d0=w3(170);dlb.ceb=function ceb(a){};dlb.deb=function deb(a){a.b=null;a.c=0;};dlb.eeb=function eeb(a){return new dlb.Heb(a);};dlb.feb=function feb(a,b){var c,d,e;e=a.b;while(e){c=a.a.pb(b,e.c);if(c==0){return e;}d=c<0?0:1;e=e.a[d];}return null;};dlb.geb=function geb(a,b,c,d,e,f,g,h){var i,j;if(!d){return;}i=d.a[0];!!i&&dlb.geb(a,b,c,i,e,f,g,h);dlb.heb(a,c,d.c,e,f,g,h)&&b.add(d);j=d.a[1];!!j&&dlb.geb(a,b,c,j,e,f,g,h);};dlb.heb=function heb(a,b,c,d,e,f,g){var h,i;if(b.mc()&&(i=a.a.pb(c,d),i<0||!e&&i==0)){return false;}if(b.nc()&&(h=a.a.pb(c,f),h>0||!g&&h==0)){return false;}return true;};dlb.ieb=function ieb(a,b,c,d){var e,f;if(!b){return c;}else {e=a.a.pb(c.c,b.c);if(e==0){d.d=dlb.uab(b,c.d);d.b=true;return b;}f=e<0?0:1;b.a[f]=dlb.ieb(a,b.a[f],c,d);if(dlb.jeb(b.a[f])){if(dlb.jeb(b.a[1-f])){b.b=true;b.a[0].b=false;b.a[1].b=false;}else {dlb.jeb(b.a[f].a[f])?b=dlb.qeb(b,1-f):dlb.jeb(b.a[f].a[1-f])&&(b=dlb.peb(b,1-f));}}}return b;};dlb.jeb=function jeb(a){return !!a&&a.b;};dlb.keb=function keb(a,b,c){var d,e;d=new dlb.Keb(b,c);e=new dlb.Meb();a.b=dlb.ieb(a,a.b,d,e);e.b||++a.c;a.b.b=false;return e.d;};dlb.leb=function leb(a,b){var c,d;c=b;d=new dlb.Meb();dlb.neb(a,c,d);return d.d;};dlb.meb=function meb(a,b){var c;c=new dlb.Meb();c.c=true;c.d=b.ic();return dlb.neb(a,b.hc(),c);};dlb.neb=function neb(a,b,c){var d,e,f,g,h,i,j,k,l,m,n;if(!a.b){return false;}g=null;m=null;i=new dlb.Keb(null,null);e=1;i.a[1]=a.b;l=i;while(l.a[e]){j=e;h=m;m=l;l=l.a[e];d=a.a.pb(b,l.c);e=d<0?0:1;d==0&&(!c.c||dlb.Odb(l.d,c.d))&&(g=l);if(!(!!l&&l.b)&&!dlb.jeb(l.a[e])){if(dlb.jeb(l.a[1-e])){m=m.a[j]=dlb.qeb(l,e);}else if(!dlb.jeb(l.a[1-e])){n=m.a[1-j];if(n){if(!dlb.jeb(n.a[1-j])&&!dlb.jeb(n.a[j])){m.b=false;n.b=true;l.b=true;}else {f=h.a[1]==m?1:0;dlb.jeb(n.a[j])?h.a[f]=dlb.peb(m,j):dlb.jeb(n.a[1-j])&&(h.a[f]=dlb.qeb(m,j));l.b=h.a[f].b=true;h.a[f].a[0].b=false;h.a[f].a[1].b=false;}}}}}if(g){c.b=true;c.d=g.d;if(l!=g){k=new dlb.Keb(l.c,l.d);dlb.oeb(a,i,g,k);m==g&&(m=k);}m.a[m.a[1]==l?1:0]=l.a[!l.a[0]?1:0];--a.c;}a.b=i.a[1];!!a.b&&(a.b.b=false);return c.b;};dlb.oeb=function oeb(a,b,c,d){var e,f;f=b;e=f.c==null||a.a.pb(c.c,f.c)>0?1:0;while(f.a[e]!=c){f=f.a[e];e=a.a.pb(c.c,f.c)>0?1:0;}f.a[e]=d;d.b=c.b;d.a[0]=c.a[0];d.a[1]=c.a[1];c.a[0]=null;c.a[1]=null;};dlb.peb=function peb(a,b){var c;c=1-b;a.a[c]=dlb.qeb(a.a[c],c);return dlb.qeb(a,b);};dlb.qeb=function qeb(a,b){var c,d;c=1-b;d=a.a[c];a.a[c]=d.a[b];d.a[b]=a;a.b=true;d.b=false;return d;};dlb.reb=function reb(a){return a.c;};dlb.seb=function seb(){dlb.teb.call(this,null);};dlb.teb=function teb(a){dlb.ceb(this);this.b=null;this.a=(dlb.Dcb(),!a?dlb.Ccb:a);};U1(57,335,{4:1,99:1},dlb.seb,dlb.teb);_.clear=function ueb(){dlb.deb(this);};_.dc=function veb(){return dlb.eeb(this);};_.put=function web(a,b){return dlb.keb(this,a,b);};_.remove=function xeb(a){return dlb.leb(this,a);};_.size=function yeb(){return dlb.reb(this);};_.c=0;Ykb.m0=w3(57);dlb.zeb=function zeb(a){return dlb.H9(a.a);};dlb.Aeb=function Aeb(a){return a.b=dlb.I9(a.a);};dlb.Beb=function Beb(a){dlb.J9(a.a);dlb.meb(a.c,a.b);a.b=null;};dlb.Ceb=function Ceb(a){dlb.Deb.call(this,a,(dlb.Seb(),dlb.Oeb));};dlb.Deb=function Deb(a,b){var c;this.c=a;c=new dlb.Qi();dlb.geb(a,c,b,a.b,null,false,null,false);this.a=new dlb.P9(c,0);};U1(79,1,{},dlb.Ceb);_.fc=function Feb(){return dlb.Aeb(this);};_.ec=function Eeb(){return dlb.zeb(this);};_.gc=function Geb(){dlb.Beb(this);};Ykb.e0=w3(79);dlb.Heb=function Heb(a){this.a=a;dlb.Qab.call(this,a);};U1(94,181,ctb,dlb.Heb);_.clear=function Ieb(){dlb.deb(this.a);};Ykb.f0=w3(94);dlb.Jeb=function Jeb(a){a.a=gW(Ykb.g0,Ulb,97,2,0,1);};dlb.Keb=function Keb(a,b){dlb.Leb.call(this,a,b);};dlb.Leb=function Leb(a,b){dlb.Cab.call(this,a,b);dlb.Jeb(this);this.b=true;};U1(97,112,{124:1,112:1,72:1,97:1},dlb.Keb);_.b=false;Ykb.g0=w3(97);dlb.Meb=function Meb(){};U1(146,1,{},dlb.Meb);_.lb=function Neb(){return 'State: mv='+this.c+' value='+this.d+' done='+this.a+' found='+this.b;};_.a=false;_.b=false;_.c=false;Ykb.h0=w3(146);dlb.Seb=function Seb(){dlb.Seb=W1;dlb.Oeb=new dlb.Teb('All',0);dlb.Peb=new dlb.Xeb();dlb.Qeb=new dlb.Zeb();dlb.Reb=new dlb.afb();};dlb.Teb=function Teb(a,b){_z.call(this,a,b);};dlb.Web=function Web(){dlb.Seb();return oW(aW(Ykb.l0,1),Bqb,64,0,[dlb.Oeb,dlb.Peb,dlb.Qeb,dlb.Reb]);};U1(64,52,htb,dlb.Teb);_.mc=function Ueb(){return false;};_.nc=function Veb(){return false;};Ykb.l0=x3(64,dlb.Web);dlb.Xeb=function Xeb(){dlb.Teb.call(this,'Head',1);};U1(253,64,htb,dlb.Xeb);_.nc=function Yeb(){return true;};Ykb.i0=x3(253,null);dlb.Zeb=function Zeb(){dlb.Teb.call(this,'Range',2);};U1(254,64,htb,dlb.Zeb);_.mc=function $eb(){return true;};_.nc=function _eb(){return true;};Ykb.j0=x3(254,null);dlb.afb=function afb(){dlb.Teb.call(this,'Tail',3);};U1(255,64,htb,dlb.afb);_.mc=function bfb(){return true;};Ykb.k0=x3(255,null);dlb.cfb=function cfb(a,b){return dlb.keb(a.a,b,(Zkb.L2(),K2))==null;};dlb.dfb=function dfb(a){dlb.deb(a.a);};dlb.efb=function efb(a,b){return dlb.Hab(a.a,b);};dlb.ffb=function ffb(a){var b;return b=new dlb.Ceb(new dlb.Heb(new dlb.Wab(a.a).a).b),new dlb.cbb(b);};dlb.gfb=function gfb(a){return a.a.c;};dlb.hfb=function hfb(){this.a=new dlb.seb();};dlb.ifb=function ifb(a){this.a=new dlb.teb(a);};U1(123,333,{4:1,38:1,39:1,45:1,86:1},dlb.hfb,dlb.ifb);_.add=function jfb(a){return dlb.cfb(this,a);};_.clear=function kfb(){dlb.dfb(this);};_.contains=function lfb(a){return dlb.efb(this,a);};_.rb=function mfb(){return dlb.ffb(this);};_.remove=function nfb(a){return dlb.leb(this.a,a)!=null;};_.size=function ofb(){return dlb.gfb(this);};Ykb.n0=w3(123);dlb.pfb=function pfb(a,b){return dlb.wi(a.a,b);};dlb.qfb=function qfb(a){return a.a.a.length;};dlb.rfb=function rfb(a,b){return dlb.Pi(a.a,b);};dlb.sfb=function sfb(){this.a=new dlb.Qi();};dlb.xfb=function xfb(a,b){if(a<0||a>=b){throw c1(new Zkb.I2());}};U1(266,80,{4:1,5:1,38:1,39:1,80:1,45:1,98:1,157:1},dlb.sfb);_.addAtIndex=function tfb(a,b){dlb.xfb(a,this.a.a.length+1);dlb.vi(this.a,a,b);};_.add=function ufb(a){return dlb.pfb(this,a);};_.addAllAtIndex=function vfb(a,b){dlb.xfb(a,this.a.a.length+1);return dlb.xi(this.a,a,b);};_.addAll=function wfb(a){return dlb.yi(this.a,a);};_.clear=function yfb(){alb.igb(this.a.a,0);};_.contains=function zfb(a){return dlb.Di(this.a,a,0)!=-1;};_.containsAll=function Afb(a){return dlb.Th(this.a,a);};_.getAtIndex=function Bfb(a){dlb.xfb(a,this.a.a.length);return dlb.Bi(this.a,a);};_.indexOf=function Cfb(a){return dlb.Di(this.a,a,0);};_.isEmpty=function Dfb(){return this.a.a.length==0;};_.rb=function Efb(){return new dlb.Obb(this.a);};_.lastIndexOf=function Ffb(a){return dlb.Gi(this.a,a);};_.removeAtIndex=function Gfb(a){dlb.xfb(a,this.a.a.length);return dlb.Ii(this.a,a);};_.removeAll=function Hfb(a){return dlb.Uh(this.a,a);};_.tb=function Ifb(a,b){dlb.Ki(this.a,a,b);};_.setAtIndex=function Jfb(a,b){dlb.xfb(a,this.a.a.length);return dlb.Li(this.a,a,b);};_.size=function Kfb(){return dlb.qfb(this);};_.subList=function Lfb(a,b){return new dlb.R9(this.a,a,b);};_.toArray=function Mfb(){return alb.agb(this.a.a);};_.sb=function Nfb(a){return dlb.rfb(this,a);};_.lb=function Ofb(){return dlb.Vh(this.a);};Ykb.o0=w3(266);Elb.Pfb=function Pfb(a,b){if(b==null){throw c1(new Zkb.O4());}return dlb.T8(a.d,b);};Elb.Qfb=function Qfb(a){return new dlb.s9(a.d);};Elb.Rfb=function Rfb(a,b){if(b==null){throw c1(new Zkb.O4());}return dlb.X8(a.d,b);};Elb.Sfb=function Sfb(a,b,c){if(b==null||c==null){throw c1(new Zkb.O4());}return dlb.$8(a.d,b,c);};Elb.Tfb=function Tfb(){this.d=new dlb.Lcb();};U1(250,332,btb);_.containsKey=function Ufb(a){return Elb.Pfb(this,a);};_.containsValue=function Vfb(a){if(a==null){throw c1(new Zkb.O4());}return dlb.U8(this.d,a);};_.dc=function Wfb(){return Elb.Qfb(this);};_.get=function Xfb(a){return Elb.Rfb(this,a);};_.put=function Yfb(a,b){return Elb.Sfb(this,a,b);};_.putIfAbsent=function Zfb(a,b){return Elb.Pfb(this,a)?this.get(a):Elb.Sfb(this,a,b);};_.remove=function $fb(a){if(a==null){throw c1(new Zkb.O4());}return dlb.a9(this.d,a);};_.replace=function _fb(a,b){if(b==null){throw c1(new Zkb.O4());}else return Elb.Pfb(this,a)?Elb.Sfb(this,a,b):null;};Ykb.p0=w3(250);alb.kgb=function kgb(a,b){return Ykb.pW(a,b);};alb.lgb=function lgb(){alb.lgb=W1;new alb.rgb();new alb.ngb('ISO-LATIN-1');new alb.ngb('ISO-8859-1');};alb.mgb=function mgb(a){Clb.j8.call(this,a);};U1(171,88,atb);Ykb.s0=w3(171);alb.ngb=function ngb(a){alb.mgb.call(this,a);};U1(172,171,atb,alb.ngb);Ykb.q0=w3(172);alb.ogb=function ogb(a,b,c){var d,e,f,g,h,i,j,k,l;f=0;for(j=0;j<c;){++f;e=a[b+j];if((e&192)==128){throw c1(new Zkb.c4(itb));}else if((e&128)==0){++j;}else if((e&224)==192){j+=2;}else if((e&240)==224){j+=3;}else if((e&248)==240){j+=4;}else {throw c1(new Zkb.c4(itb));}if(j>c){throw c1(new Zkb.H2(itb));}}g=gW(Ykb.xX,Anb,6,f,15,1);l=0;h=0;for(i=0;i<c;){e=a[b+i++];if((e&128)==0){h=1;e&=127;}else if((e&224)==192){h=2;e&=31;}else if((e&240)==224){h=3;e&=15;}else if((e&248)==240){h=4;e&=7;}else if((e&252)==248){h=5;e&=3;}while(--h>0){d=a[b+i++];if((d&192)!=128){throw c1(new Zkb.c4('Invalid UTF8 sequence at '+(b+i-1)+', byte='+(k=alb.Pgb(alb.Ogb(d)),k.toString(16))));}e=e<<6|d&63;}l+=g3(e,g,l);}return g;};alb.pgb=function pgb(a,b){if(b<128){alb.fgb(a,(b&127)<<24>>24);}else if(b<lnb){alb.fgb(a,(b>>6&31|192)<<24>>24);alb.fgb(a,(b&63|128)<<24>>24);}else if(b<Ylb){alb.fgb(a,(b>>12&15|224)<<24>>24);alb.fgb(a,(b>>6&63|128)<<24>>24);alb.fgb(a,(b&63|128)<<24>>24);}else if(b<Wmb){alb.fgb(a,(b>>18&7|240)<<24>>24);alb.fgb(a,(b>>12&63|128)<<24>>24);alb.fgb(a,(b>>6&63|128)<<24>>24);alb.fgb(a,(b&63|128)<<24>>24);}else if(b<Xnb){alb.fgb(a,(b>>24&3|248)<<24>>24);alb.fgb(a,(b>>18&63|128)<<24>>24);alb.fgb(a,(b>>12&63|128)<<24>>24);alb.fgb(a,(b>>6&63|128)<<24>>24);alb.fgb(a,(b&63|128)<<24>>24);}else {throw c1(new Zkb.c4('Character out of range: '+b));}};alb.qgb=function qgb(a){var b,c,d,e;e=alb.Pgb(a).length;b=gW(Ykb.wX,Fnb,6,0,15,1);for(d=0;d<e;){c=Z2(a,d,alb.Pgb(a).length);d+=c>=Ylb?2:1;alb.pgb(b,c);}return b;};alb.rgb=function rgb(){alb.mgb.call(this,'UTF-8');};U1(235,171,atb,alb.rgb);Ykb.r0=w3(235);alb.Sgb=function Sgb(a,b){var c,d;d=e1(Ykb.m1(a),$sb);c=C1(Ykb.m1(b),32);return B1(c,d);};Flb.Tgb=function Tgb(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s;l=b.f;m=b.g;e=b.a;r=0;f=clb.zk(a.o,0,e);g=clb.zk(a.o,1,e);for(n=0;n<l.c.length;n++){c=l.e[l.c[n]];if(c!=f&&c!=g){s=Flb.zhb(clb.uk(a.o,c));for(o=0;o<m.c.length;o++){d=m.e[m.c[o]];if(d!=f&&d!=g){p=s+Flb.zhb(clb.uk(a.o,d));i=$wnd.Math.abs(a.k[c].a-a.k[d].a);if(i<p){j=$wnd.Math.abs(a.k[c].b-a.k[d].b);if(j<p){k=$wnd.Math.abs(a.k[c].c-a.k[d].c);if(k<p){h=$wnd.Math.sqrt(i*i+j*j+k*k);if(h<p){q=(p-h)/p;r+=q*q;}}}}}}}}return r;};Flb.Ugb=function Ugb(a,b,c,d,e,f){var g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z,$,ab,bb,cb,db,eb,fb;G=b.i;H=b.j;A=b.f;B=b.g;if(!d[G]&&!d[H]){N=A.c.length>B.c.length?A:B;O=A.c.length>B.c.length?G:H;d[O]=true;D=e==null?0:e[O];for(L=0;L<N.d.length;L++){i=N.e[N.d[L]];elb.uv(a,i,elb.ov(N.b[D],N.d[L]));}}if(d[G]){F=H;w=B;m=b.b?1:0;}else {F=G;w=A;m=b.b?0:1;}l=b.a;V=clb.zk(a.o,m,l);S=clb.zk(a.o,1-m,l);C=e==null?0:e[F];u=w.f[V];t=w.f[S];I=elb.ov(w.b[C],w.d[u]);U=a.k[V];J=clb.Bh(clb.Ah(I,elb.ov(w.b[C],w.d[t])));fb=clb.Bh(clb.Ah(U,a.k[S]));g=clb.uh(J,fb);v=gW(Ykb.TX,Vnb,24,w.d.length,0,1);if(g<0.0010000000474974513){for(L=0;L<w.d.length;L++){i=w.e[w.d[L]];i!=V&&i!=S&&(v[L]=g>Gmb?clb.Ah(I,elb.ov(w.b[C],w.d[L])):clb.Ah(elb.ov(w.b[C],w.d[L]),I));}}else {g<3.1405926535422957?W=new clb.Dh(fb.b*J.c-fb.c*J.b,-(fb.a*J.c-fb.c*J.a),fb.a*J.b-fb.b*J.a):$wnd.Math.abs(fb.a)>=$wnd.Math.abs(fb.b)&&$wnd.Math.abs(fb.a)>=$wnd.Math.abs(fb.c)?W=new clb.Dh(-(fb.b+fb.c)/fb.a,1,1):$wnd.Math.abs(fb.b)>=$wnd.Math.abs(fb.a)&&$wnd.Math.abs(fb.b)>=$wnd.Math.abs(fb.c)?W=new clb.Dh(1,-(fb.a+fb.c)/fb.b,1):W=new clb.Dh(1,1,-(fb.a+fb.b)/fb.c);P=Flb.bhb(clb.Bh(W),g);for(L=0;L<w.d.length;L++){i=w.e[w.d[L]];i!=V&&i!=S&&(v[L]=clb.vh(clb.Ah(elb.ov(w.b[C],w.d[L]),I),P));}}d[F]=true;for(M=0;M<clb.wn(a.o,V);M++){p=clb.vn(a.o,V,M);if(p!=S){s=w.f[p];elb.vv(a,p,clb.oh(v[s],U));}}X=elb.Lv(a,b.p);q=-1;j=0;k=0;for($=0;$<a.i[c].length;$++){q=a.i[c][$];P=Flb.bhb(fb,Fmb*q/180-X);for(L=0;L<w.d.length;L++){i=w.e[w.d[L]];if(i!=V&&i!=S){elb.uv(a,i,v[L]);clb.nh(clb.vh(a.k[i],P),U);}}n=Flb.Tgb(a,b);eb=n;bb=0;if(n<_ob){T=n/jtb;a.e[c][$]=a.d[c][$]*(1-T*T);}else {o=a.i[c][$];db=Unb;for(Q=0;Q<2;Q++){q=f[$][Q];if(q!=o){P=Flb.bhb(fb,Fmb*q/180-X);for(K=0;K<w.d.length;K++){i=w.e[w.d[K]];if(i!=V&&i!=S){elb.uv(a,i,v[K]);clb.nh(clb.vh(a.k[i],P),U);}}R=Flb.Tgb(a,b);if(R<n*0.800000011920929&&R<db){a.i[c][$]=f[$][Q];T=R/0.16000000476837162;a.e[c][$]=a.d[c][$]*(1-T*T);eb=R;bb=Q+1;db=R;}}}if(db==Unb&&n<jtb){T=n/jtb;a.e[c][$]=a.d[c][$]*(1-T*T);}}if(a.e[c][a.a[c]]<a.e[c][$]){a.a[c]=$;j=bb;k=eb;}}cb=0;for(ab=0;ab<a.i[c].length;ab++)a.e[c][ab]>0&&(cb+=a.e[c][ab]);if(a.e[c][a.a[c]]<=0){a.e[c][a.a[c]]=1;h=j==1?-8:j==2?8:dlb.Udb(a.f)<0.5?-8:8;for(Y=1;Y<=4;Y++){q=a.i[c][a.a[c]]+h*Y<<16>>16;P=Flb.bhb(fb,Fmb*q/180-X);for(K=0;K<w.d.length;K++){i=w.e[w.d[K]];if(i!=V&&i!=S){elb.uv(a,i,v[K]);clb.nh(clb.vh(a.k[i],P),U);}}r=Flb.Tgb(a,b);if(k-r<0.05)break;a.i[c][a.a[c]]=q;}}else {for(Z=0;Z<a.i[c].length;Z++)a.e[c][Z]/=cb;}if(q!=a.i[c][a.a[c]]){P=Flb.bhb(fb,Fmb*a.i[c][a.a[c]]/180-X);for(K=0;K<w.d.length;K++){i=w.e[w.d[K]];if(i!=V&&i!=S){elb.uv(a,i,v[K]);clb.nh(clb.vh(a.k[i],P),U);}}}elb.tv(a,l,a.i[c][a.a[c]]);};Flb.Vgb=function Vgb(a,b,c){var d,e;++a.b;d=new elb.Cv(a);d.p=c;for(e=a.g.length-1;e>=0;e--)Flb._gb(a,d,a.g[e],e,b[e]);return d;};Flb.Wgb=function Wgb(a,b,c,d){var e,f,g;f=0;for(g=0;g<a.i[b].length;g++){e=(1-d)*a.e[b][g]+d/a.i[b].length;f+=e;if(c<=f)return g;}return a.i[b].length-1;};Flb.Xgb=function Xgb(a,b,c){return a.i[b][c];};Flb.Ygb=function Ygb(a,b,c){return a.e[b][c];};Flb.Zgb=function Zgb(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o;k=b.p;i=b.n;j=elb.ov(a,k[2]);l=clb.Bh(clb.Ah(j,elb.ov(a,k[1])));h=Flb.bhb(l,i==k[1]?c:-c);for(e=b.o,f=0,g=e.length;f<g;++f){d=e[f];if(d!=i){m=a.k[d].a-j.a;n=a.k[d].b-j.b;o=a.k[d].c-j.c;elb.xv(a,d,m*h[0][0]+n*h[0][1]+o*h[0][2]+j.a);elb.yv(a,d,m*h[1][0]+n*h[1][1]+o*h[1][2]+j.b);elb.zv(a,d,m*h[2][0]+n*h[2][1]+o*h[2][2]+j.c);}}};Flb.$gb=function $gb(a,b,c){var d,e;while(c<0)c=c+360<<16>>16;while(c>=360)c=c-360<<16>>16;d=b.a;if(c!=(a.j==null?-1:a.j[d])){e=c-(a.j==null?-1:a.j[d]);Flb.Zgb(a,b,Fmb*e/180);elb.tv(a,d,c);}};Flb._gb=function _gb(a,b,c,d,e){Flb.$gb(b,c,a.i[d][e]);};Flb.ahb=function ahb(a,b,c,d,e){var f,g,h,i,j,k,l,m;elb.Bv.call(this,a);this.f=e;this.g=c;this.i=gW(Ykb.Y0,apb,13,c.length,0,2);this.d=gW(Ykb.Y0,apb,13,c.length,0,2);this.e=gW(Ykb.yX,Llb,12,c.length,0,2);h=gW(Ykb.Y0,Llb,30,c.length,0,3);for(g=0;g<c.length;g++){m=c[g].d;this.i[g]=dlb.Vbb(m,m.length);i=c[g].c;this.d[g]=dlb.Vbb(i,i.length);this.e[g]=gW(Ykb.yX,emb,6,this.i[g].length,15,1);h[g]=c[g].e;}this.a=gW(Ykb.AX,gmb,6,c.length,15,1);k=gW(Ykb.Z0,Amb,6,b.length,16,1);for(f=0;f<c.length;f++)Flb.Ugb(this,c[f],f,k,d,h[f]);for(j=0;j<b.length;j++)if(!k[j])for(l=0;l<b[j].c.length;l++)elb.uv(this,Flb.Ihb(b[j],l),Flb.Lhb(b[j],d[j],l));this.c=new dlb.Qi();};Flb.bhb=function bhb(a,b){var c,d,e,f;f=$wnd.Math.sin(b);c=$wnd.Math.cos(b);d=1-c;e=eW(Ykb.yX,[Llb,emb],[12,6],15,[3,3],2);e[0][0]=a.a*a.a*d+c;e[1][1]=a.b*a.b*d+c;e[2][2]=a.c*a.c*d+c;e[0][1]=a.a*a.b*d-a.c*f;e[1][2]=a.b*a.c*d-a.a*f;e[2][0]=a.c*a.a*d-a.b*f;e[0][2]=a.a*a.c*d+a.b*f;e[1][0]=a.b*a.a*d+a.c*f;e[2][1]=a.c*a.b*d+a.a*f;return e;};U1(163,58,{58:1,27:1,163:1},Flb.ahb);_.b=0;Ykb.v0=w3(163);Flb.chb=function chb(a,b){dlb.wi(a.c,b);};Flb.dhb=function dhb(a,b){a.a=b;};Flb.ehb=function ehb(a,b,c){var d,e;d=new clb.ag(elb.Av(c,null));clb.Gf(d);clb.Ef(d,d.hb);a.d=gW(Ykb.AX,gmb,6,b.g.length,15,1);for(e=0;e<a.d.length;e++)a.d[e]=elb.nv(c,b.g[e].a);};Flb.fhb=function fhb(a,b){alb.Pgb(a.b.a).length!=0&&Zkb.G5(a.b,'<NL>');Zkb.G5(a.b,b);};Flb.ghb=function ghb(){this.b=new Zkb.J5();this.c=new dlb.Qi();};U1(196,1,{196:1},Flb.ghb);Ykb.w0=w3(196);Flb.hhb=function hhb(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s;a.i&&Flb.dhb(Flb.Ghb(a.c,b),null);i=0;h=null;q=c.o;for(d=1;d<q.q;d++){s=Flb.zhb(q.C[d]);for(e=0;e<d;e++){if(!a.u[d][e]){p=s+Flb.zhb(q.C[e]);k=$wnd.Math.abs(c.k[d].a-c.k[e].a);if(k<p){l=$wnd.Math.abs(c.k[d].b-c.k[e].b);if(l<p){m=$wnd.Math.abs(c.k[d].c-c.k[e].c);if(m<p){j=$wnd.Math.sqrt(k*k+l*l+m*m);if(j<p){r=(p-j)/p;g=20*r*r;i+=g;if(a.i){Flb.fhb(Flb.Ghb(a.c,b),'a1:'+d+' f1:'+a.g[d]+' a2:'+e+' f2:'+a.g[e]+ktb+(slb.IT(),slb.JT(j,5))+' min:'+slb.JT(p,5));if(Flb.Ghb(a.c,b).a==null){f=gW(Ykb.AX,gmb,6,2,15,1);f[0]=d;f[1]=e;Flb.dhb(Flb.Ghb(a.c,b),f);}}h==null&&(h=gW(Ykb.yX,Llb,12,a.q.length,0,2));n=a.g[d];o=a.g[e];if(n<o){h[o]==null&&(h[o]=gW(Ykb.yX,emb,6,o,15,1));h[o][n]+=g;}else {h[n]==null&&(h[n]=gW(Ykb.yX,emb,6,n,15,1));h[n][o]+=g;}}}}}}}}Flb.nib(b,i,h);return i!=0;};Flb.ihb=function ihb(a,b,c,d){var e,f,g,h,i,j,k,l,m,n,o,p,q;h=0;for(m=0;m<c.c.length;m++){e=c.e[c.c[m]];q=Flb.zhb(clb.uk(a.k,e));for(n=0;n<d.c.length;n++){f=d.e[d.c[n]];o=q+Flb.zhb(clb.uk(a.k,f));j=$wnd.Math.abs(b.k[e].a-b.k[f].a);if(j<o){k=$wnd.Math.abs(b.k[e].b-b.k[f].b);if(k<o){l=$wnd.Math.abs(b.k[e].c-b.k[f].c);if(l<o){i=$wnd.Math.sqrt(j*j+k*k+l*l);if(i<o){p=(o-i)/o;g=p*p;h+=g;}}}}}}return 20*h;};Flb.jhb=function jhb(a,b){var c;c=dlb.Iab(a.b,b);if(c)return c;c=new Flb.ahb(a.k,a.q,a.s,b,a.n);dlb.keb(a.b,dlb.Ubb(b,b.length),c);return c;};Flb.khb=function khb(a){var b,c;if(a.s==null&&!a.t)return null;if(a.t){c=Glb.Djb(a.t);if(c){Flb.thb(a,c);++a.p;elb.wv(c,'SO#'+ ++a.a);return c;}return null;}if(a.j)return null;a.b.c==0&&Flb.jhb(a,gW(Ykb.AX,gmb,6,a.q.length,15,1));a.v=Flb.Mib(a.w,a.v,a.c);while(a.v){b=Flb.jhb(a,a.v.d);if(!a.v.c){Flb.oib(a.v,Flb.Vgb(b,a.v.i,'#'+ ++a.a));a.i&&Flb.Fhb(a.c,a.v);}if(a.v.b==0){Flb.hhb(a,a.v,a.v.c);a.v.b!=0&&Flb.vhb(a,a.v);if(a.i){Flb.ehb(Flb.Ghb(a.c,a.v),b,a.v.c);Flb.Ghb(a.c,a.v);}}if(a.v.b>a.w.s+3){a.v=Flb.Mib(a.w,a.v,a.c);if(!!a.v||a.p!=0)continue;if(!a.v&&a.A){a.t=new Glb.Mjb(a.k);Glb.Fjb(a.t,a.o,-1);c=Glb.Djb(a.t);if(c){Flb.thb(a,c);++a.p;elb.wv(c,'SO#'+ ++a.a);return c;}}a.v=a.w.e;a.j=true;}if(a.v){Flb.thb(a,a.v.c);a.v.g=true;++a.p;a.i&&Flb.Ghb(a.c,a.v);return a.v.c;}}return null;};Flb.lhb=function lhb(a,b){var c;c=Flb.khb(a);return !c?null:elb.Av(c,b);};Flb.mhb=function mhb(a,b){var c,d;if(!Flb.phb(a,b,false))return null;if(a.s!=null){a.w=new Flb.Wib(a,a.o);Flb.Qib(a.w,400);a.b=new dlb.teb(new slb.NT());return Flb.khb(a);}else {d=new Glb.Mjb(b);c=Glb.Cjb(d,a.o);Flb.thb(a,c);c.p='SO#1';return c;}};Flb.nhb=function nhb(a,b){var c;c=Flb.mhb(a,b);return !c?null:elb.Av(c,b);};Flb.ohb=function ohb(a){return !a.w?1:a.w.u;};Flb.phb=function phb(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o,p;a.t=null;clb.Gt(b,1);for(e=0;e<b.f;e++)if(clb.Pn(b,e)>(p=clb.Qk(b,e),p+clb.Ok(b,e,p)))return false;Flb.yhb(b);b.S=true;g=null;k=null;h=null;l=null;if((b.T&8)!=0){g=gW(Ykb.AX,gmb,6,b.f,15,1);h=gW(Ykb.Z0,Amb,6,b.f,16,1);for(f=0;f<b.f;f++){g[f]=b.u[f]&3;h[f]=(b.u[f]&4)!=0;}k=gW(Ykb.AX,gmb,6,b.g,15,1);l=gW(Ykb.Z0,Amb,6,b.g,16,1);for(j=0;j<b.g;j++){k[j]=b.F[j]&3;l[j]=(b.F[j]&4)!=0;}}clb.Gt(b,63);if(g!=null){for(f=0;f<b.f;f++)clb.Tl(b,f,g[f],h[f]);for(j=0;j<b.g;j++)clb.gm(b,j,k[j],l[j]);}a.k=b;a.a=0;a.p=0;a.v=null;a.s=null;a.e=gW(Ykb.AX,gmb,6,b.q,15,1);a.d=clb.En(b,a.e,false,true);a.f=gW(Ykb.AX,gmb,6,a.d,15,1);for(d=0;d<b.q;d++)++a.f[a.e[d]];n=gW(Ykb.Z0,Amb,6,b.r,16,1);m=elb.Ov(b,n);if(m==0)return true;if(!Flb.shb(a,n))return false;a.s=gW(Ykb.E0,Ulb,133,m,0,1);o=0;for(i=0;i<b.g;i++)n[i]&&(a.s[o++]=new Flb.kib(b,i,a.g,a.e,a.f[a.e[b.D[0][i]]],a.q,c));dlb.mcb(a.s,new Flb.Chb());a.i&&(a.c=new Flb.Hhb());Flb.qhb(a);return true;};Flb.qhb=function qhb(a){var b,c,d,e,f,g,h,i,j,k,l,m;a.u=gW(Ykb.Z0,Llb,11,a.k.q,0,2);for(c=1;c<a.k.q;c++)a.u[c]=gW(Ykb.Z0,Amb,6,c,16,1);for(k=a.q,l=0,m=k.length;l<m;++l){j=k[l];for(g=1;g<j.d.length;g++)for(i=0;i<g;i++)Flb.uhb(a,j.e[j.d[g]],j.e[j.d[i]]);}for(b=0;b<a.k.f;b++)for(f=1;f<clb.gn(a.k,b);f++)for(h=0;h<f;h++)Flb.uhb(a,clb.vn(a.k,b,f),clb.vn(a.k,b,h));if(a.e!=null)for(d=1;d<a.k.q;d++)for(e=0;e<d;e++)a.e[d]!=a.e[e]&&(a.u[d][e]=true);};Flb.rhb=function rhb(a,b,c,d,e){if(!Flb.phb(a,b,e))return false;if(a.s==null){a.t=new Glb.Mjb(b);Glb.Fjb(a.t,a.o,-1);}else {a.b=new dlb.teb(new slb.NT());switch(c){case 2:a.w=new Flb.Uib(a,false,a.o);break;case 3:a.w=new Flb.Uib(a,true,a.o);break;case 4:a.w=new Flb.Wib(a,a.o);break;case 1:a.w=new Flb.Zib(a);}Flb.Qib(a.w,d);}return true;};Flb.shb=function shb(a,b){var c,d,e;a.g=gW(Ykb.AX,gmb,6,a.k.q,15,1);c=clb.Fn(a.k,a.g,b,true);a.q=gW(Ykb.D0,Ulb,134,c,0,1);e=true;for(d=0;d<c;d++)e=e&!!(a.q[d]=Flb.Zhb(a.r,a.k,a.g,d));return e;};Flb.thb=function thb(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o;if(a.d>1){j=gW(Ykb.yX,emb,6,a.d,15,1);k=gW(Ykb.yX,emb,6,a.d,15,1);l=gW(Ykb.yX,emb,6,a.d,15,1);i=gW(Ykb.yX,emb,6,a.d,15,1);for(g=0;g<a.d;g++){l[g]=Rsb;i[g]=-1000000000;}for(d=0;d<b.k.length;d++){j[a.e[d]]+=b.k[d].a;k[a.e[d]]+=b.k[d].b;l[a.e[d]]>b.k[d].c&&(l[a.e[d]]=b.k[d].c);i[a.e[d]]<b.k[d].c&&(i[a.e[d]]=b.k[d].c);}for(h=0;h<a.d;h++){j[h]/=a.f[h];k[h]/=a.f[h];}m=gW(Ykb.yX,emb,6,a.d,15,1);n=gW(Ykb.yX,emb,6,a.d,15,1);o=gW(Ykb.yX,emb,6,a.d,15,1);for(f=1;f<a.d;f++){m[f]=j[0]-j[f];n[f]=k[0]-k[f];o[f]=o[f-1]+i[f-1]-l[f]+3;}for(c=0;c<b.k.length;c++){if(a.e[c]!=0){e=b.k[c];e.a+=m[a.e[c]];e.b+=n[a.e[c]];e.c+=o[a.e[c]];}}}};Flb.uhb=function uhb(a,b,c){b<c?a.u[c][b]=true:a.u[b][c]=true;};Flb.vhb=function vhb(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A;n=b.a;s=0;for(g=1;g<n.length;g++)if(n[g]!=null)for(i=0;i<g;i++)n[g][i]!=0&&Flb.Kib(a.w,g,i).length!=2&&(s+=n[g][i]);if(s>6)return false;e=null;m=null;j=null;c=Unb;o=b.b;for(f=1;f<n.length;f++){if(n[f]!=null){for(h=0;h<f;h++){if(n[f][h]>1&&Flb.Kib(a.w,f,h).length==2){r=Flb.Kib(a.w,f,h);u=gW(Ykb.AX,gmb,6,2,15,1);for(l=0;l<2;l++){t=a.s[r[l]];u[l]=elb.nv(b.c,t.a);}A=gW(Ykb.AX,gmb,6,2,15,1);for(p=-1;p<=1;p+=2){A[0]=p*8;for(q=-1;q<=1;q+=2){A[1]=q*8;d=n[f][h];for(v=1;v<=3;v++){!e?e=new elb.Cv(b.c):elb.lv(e,b.c);for(k=0;k<2;k++)Flb.$gb(e,a.s[r[k]],u[k]+v*A[k]<<16>>16);w=Flb.ihb(a,e,a.q[f],a.q[h]);if(w<d-1){d=w;!m?m=new elb.Cv(e):elb.lv(m,e);if(d<1)break;}else {break;}}if(d<n[f][h]&&d<c){c=d;!j?j=new elb.Cv(m):elb.lv(j,m);}}}}}}}if(!j)return false;Flb.hhb(a,b,j);if(b.b>=o){Flb.nib(b,o,n);return false;}elb.lv(b.c,j);return true;};Flb.whb=function whb(a,b){elb.Tv();this.o=a;this.n=j1(a,0)==0?new dlb.Ydb():new dlb.Zdb(a);this.r=new Flb._hb(a,b);};Flb.xhb=function xhb(a){Flb.whb.call(this,a,Flb.Thb());};Flb.yhb=function yhb(a){var b,c,d,e,f,g,h;h=a.T&248;clb.Gt(a,1);g=gW(Ykb.AX,gmb,6,a.f,15,1);for(c=0;c<a.f;c++)g[c]=clb.Kn(a,c);e=0.8*clb.wk(a,a.q,a.r,(clb.wj(),clb.vj));for(d=0;d<g.length;d++)if(g[d]!=0)for(f=0;f<g[d];f++)clb.Aj(a,d,clb.yj(a,1),1);clb.Gt(a,1);for(b=0;b<g.length;b++)g[b]!=0&&Flb.Bhb(a,b,g[b],e);(h&8)!=0&&(a.T|=248&(8|h));};Flb.zhb=function zhb(a){var b;b=(elb.Fw(),elb.Ew)[a<elb.Ew.length?a:6];return b*(a==1?0.9:0.9);};Flb.Ahb=function Ahb(a,b){return j4(b.o.length,a.o.length);};Flb.Bhb=function Bhb(a,b,c,d){var e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u;l=a.e[b]-c;u=-1;s=NaN;for(o=0;o<l;o++){if(clb.ql(a,a.k[b][o],b)){u=o;s=clb.yk(a,b,a.i[b][o]);break;}}t=u==-1?0:1;g=null;if(t<l){g=gW(Ykb.yX,emb,6,l-t,15,1);j=0;for(p=0;p<l;p++)p!=u&&(g[j++]=clb.yk(a,b,a.i[b][p]));alb.jgb(g,alb.Pgb(X1(dlb.ocb.prototype.kc,dlb.ocb,[])));}h=Emb/$wnd.Math.max(c,3);r=0;if(g!=null){if(g.length==1&&c==1){r=g[0];}else {i=0;for(p=0;p<g.length;p++){e=p==0?g[g.length-1]-Emb:g[p-1];f=g[p];if(i<f-e){i=f-e;r=e;}}h=i/(c+1);}}for(n=0;n<c;n++){r+=h;m=r;if(t!=0){k=clb.Mm(m,s);$wnd.Math.abs(k)<h/2&&(k<0?m=s-h/2:m=s+h/2);}q=a.i[b][l+n];clb.Yl(a,q,a.J[b].a+d*$wnd.Math.sin(m));clb.Zl(a,q,a.J[b].b+d*$wnd.Math.cos(m));}};U1(161,1,{},Flb.xhb);_.a=0;_.d=0;_.i=false;_.j=false;_.o=0;_.p=0;_.A=false;Ykb.y0=w3(161);Flb.Chb=function Chb(){};U1(216,1,{},Flb.Chb);_.pb=function Dhb(a,b){return Flb.Ahb(a,b);};_.ib=function Ehb(a){return this===a;};Ykb.x0=w3(216);Flb.Fhb=function Fhb(a,b){dlb.keb(a.a,elb.pv(b.c),new Flb.ghb());};Flb.Ghb=function Ghb(a,b){return dlb.Iab(a.a,elb.pv(b.c));};Flb.Hhb=function Hhb(){this.a=new dlb.seb();};U1(217,1,{},Flb.Hhb);Ykb.z0=w3(217);Flb.Ihb=function Ihb(a,b){return a.e[a.c[b]];};Flb.Jhb=function Jhb(a,b){return a.a[b];};Flb.Khb=function Khb(a){return a.d.length-a.c.length;};Flb.Lhb=function Lhb(a,b,c){return elb.ov(a.b[b],a.c[c]);};Flb.Mhb=function Mhb(a,b,c){var d,e,f;e=0;for(f=0;f<a.a.length;f++){d=(1-c)*a.a[f]+c/a.a.length;e+=d;if(b<=e)return f;}return a.a.length-1;};Flb.Nhb=function Nhb(a,b,c,d,e,f){this.c=a;this.e=b;this.d=c;this.f=d;this.b=e;this.a=f;};U1(134,1,{134:1},Flb.Nhb);Ykb.D0=w3(134);Flb.Phb=function Phb(a,b){var c;c=Elb.Rfb(a,b);++a.a;if(c){++c.b;++a.b;}return c;};Flb.Qhb=function Qhb(){Elb.Tfb.call(this);};Flb.Thb=function Thb(){if(Flb.Ohb)return Flb.Ohb;!Flb.Ohb&&(Flb.Ohb=new Flb.Qhb());return Flb.Ohb;};U1(251,250,{4:1,99:1},Flb.Qhb);_.get=function Shb(a){return Flb.Phb(this,a);};_.clear=function Rhb(){dlb.c9(new dlb.s9(this.d).a);};_.a=0;_.b=0;_.c=0;Ykb.B0=w3(251);Flb.Uhb=function Uhb(a,b){if(a.b!=b.b)return a.b<b.b?-1:1;return 0;};Flb.Vhb=function Vhb(a,b){this.a=a;this.c=b;};U1(180,1,{27:1,180:1},Flb.Vhb);_.qb=function Whb(a){return Flb.Uhb(this,a);};_.b=0;Ykb.A0=w3(180);Flb.Zhb=function Zhb(a,b,c,d){var e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z,$,ab,bb,cb,db,eb,fb,gb,hb,ib,jb,kb,lb,mb,nb,ob;H=0;j=0;M=0;X=gW(Ykb.Z0,Amb,6,b.q,16,1);ab=gW(Ykb.Z0,Amb,6,b.q,16,1);$=gW(Ykb.Z0,Amb,6,b.q,16,1);for(f=0;f<b.q;f++){if(c[f]==d){$[f]=true;X[f]=true;++j;++H;}}for(g=0;g<b.q;g++){if($[g]){for(S=0;S<b.j[g];S++){A=b.i[g][S];if(!X[A]){X[A]=true;++j;++M;}}}}for(h=0;h<b.q;h++){if(X[h]&&!$[h]&&!ab[h]){for(S=0;S<b.e[h];S++){A=b.i[h][S];if(!X[A]){ab[A]=true;X[A]=true;++j;}}}}n=0;for(m=0;m<b.r;m++)X[b.D[0][m]]&&X[b.D[1][m]]&&++n;O=new clb.Zt(j,n);clb.Zm(b,O,X,false,null);clb.lm(O,true);I=gW(Ykb.AX,gmb,6,H,15,1);Q=gW(Ykb.AX,gmb,6,j,15,1);N=gW(Ykb.AX,gmb,6,H+M,15,1);hb=gW(Ykb.AX,gmb,6,b.q,15,1);G=0;P=0;L=0;for(i=0;i<b.q;i++){if(X[i]){clb.so(b,i,true)&&clb.Ul(O,P,jnb,true);$[i]||(O.u[P]|=Gnb);if($[i]||!ab[i]){N[L]=P;hb[i]=L;++L;}if($[i]){I[G]=P;++G;}Q[P]=i;O.C[P]==1&&(O.A[P]=2,O.T&=7);++P;}}w=null;db=null;q=null;cb=null;Z=false;mb=!!a.a&&j<=Flb.Xhb;if(mb){q=new clb.bg(O,512);for(e=0;e<O.f;e++){if(q.bb[e]==3){mb=false;break;}}for(l=0;l<O.g;l++){if(q.k[l]==3){mb=false;break;}}mb&&clb.Yf(q);}!!a.a&&!mb&&++a.a.c;O.T|=8;if(mb){Z=clb.Uf(q);cb=clb.Gf(q);p=Flb.Phb(a.a,cb);if(p){R=(clb.Af(q),q.F);w=new dlb.Qi();for(C=p.a,D=0,F=C.length;D<F;++D){B=C[D];for(bb=0;bb<O.q;bb++){o=B[R[bb]];clb.Yl(O,bb,o.a);clb.Zl(O,bb,o.b);clb.$l(O,bb,Z?-o.c:o.c);}dlb.wi(w,new Glb.skb(O));}db=p.c;}}if(!w){kb=new Glb.Mjb(O);Glb.Fjb(kb,a.c,Flb.Yhb);w=new dlb.Qi();k=Glb.Djb(kb);alb.ggb(w.a,k);v=Glb.Djb(kb);while(v){alb.ggb(w.a,v);v=Glb.Djb(kb);}gb=Unb;for(t=new dlb.Obb(w);t.a<t.c.a.length;){r=dlb.Nbb(t);gb=$wnd.Math.min(gb,r.e);}lb=gb+4.08;for(T=w.a.length-1;T>=0;T--)(alb.Dgb(T,w.a.length),w.a[T]).e>lb&&dlb.Ii(w,T);db=gW(Ykb.yX,emb,6,w.a.length,15,1);eb=0;Y=0;for(U=0;U<w.a.length;U++){r=(alb.Dgb(U,w.a.length),w.a[U]);db[U]=$wnd.Math.pow(10,(gb-r.e)/1.36);eb+=db[U];}for(V=0;V<w.a.length;V++)db[V]/=eb;if(a.b){nb=0;fb=Unb;for(u=new dlb.Obb(w);u.a<u.c.a.length;){r=dlb.Nbb(u);J=Flb.$hb(elb.Av(r,r.o));r.n=J;if(!isNaN(J)){fb=$wnd.Math.min(fb,J);++nb;}elb.kv(r,O);}K=fb+2.72;for(s=new dlb.Obb(w);s.a<s.c.a.length;){r=dlb.Nbb(s);if(!isNaN(r.n)&&r.n>K){r.n=NaN;--nb;}}if(nb!=0){ib=gW(Ykb.yX,emb,6,nb,15,1);jb=0;Y=0;for(W=w.a.length-1;W>=0;W--){r=(alb.Dgb(W,w.a.length),w.a[W]);if(isNaN(r.n))dlb.Ii(w,W);else {ib[Y]=$wnd.Math.pow(10,(fb-r.n)/1.36);jb+=ib[Y];++Y;}}db=gW(Ykb.yX,emb,6,nb,15,1);for(S=0;S<nb;S++)db[S]=ib[S]/jb;}}if(mb){R=(clb.Af(q),q.F);B=eW(Ykb.TX,[Llb,Vnb],[105,24],0,[w.a.length,R.length],2);for(S=0;S<B.length;S++){for(bb=0;bb<R.length;bb++){ob=elb.ov((alb.Dgb(S,w.a.length),w.a[S]),bb);B[S][R[bb]]=new clb.Dh(ob.a,ob.b,Z?-ob.c:ob.c);}}Elb.Sfb(a.a,cb,new Flb.Vhb(B,db));}}return new Flb.Nhb(I,Q,N,hb,dlb.Pi(w,gW(Ykb.U0,{4:1,5:1,17:1,8:1,350:1},84,0,0,1)),db);};Flb.$hb=function $hb(b){var c,d;try{d=new ilb.Oz(b);hlb.Oy(d,4000,jqb);return ilb.Mz(d,d.i);}catch(a){a=b1(a);if(mX(a,147)){return NaN;}else if(mX(a,15)){c=a;Zkb._y(c,(Zkb.O5(),Zkb.N5),'');return NaN;}else throw c1(a);}};Flb._hb=function _hb(a,b){this.c=a;this.a=b;this.b=false;};U1(215,1,{},Flb._hb);_.b=false;_.c=0;Flb.Xhb=32;Flb.Yhb=16;Ykb.C0=w3(215);Flb.dib=function dib(){Flb.dib=W1;Flb.cib=oW(aW(Ykb.Y0,1),znb,6,15,[0,60,120,180,240,300]);Flb.aib=oW(aW(Ykb.Y0,1),znb,6,15,[17,17,17,17,17,17]);Flb.bib=oW(aW(Ykb.Y0,2),apb,13,0,[oW(aW(Ykb.Y0,1),znb,6,15,[-20,20]),oW(aW(Ykb.Y0,1),znb,6,15,[40,80]),oW(aW(Ykb.Y0,1),znb,6,15,[100,140]),oW(aW(Ykb.Y0,1),znb,6,15,[160,200]),oW(aW(Ykb.Y0,1),znb,6,15,[220,260]),oW(aW(Ykb.Y0,1),znb,6,15,[280,320])]);};Flb.eib=function eib(a,b,c){var d,e,f;if(a.o[b]==2)return 1;if((a.o[b]==1||clb.so(a,b,true))&&a.j[b]!=3)return 1;if(a.o[b]==0&&a.j[b]!=4)return 1;f=-2;for(e=0;e<a.j[b];e++){d=a.i[b][e];if(d!=c){if(f==-2)f=clb.Kf(a.d,d);else if(f!=clb.Kf(a.d,d))return 1;}}return a.j[b]-1;};Flb.fib=function fib(a,b,c,d){var e,f,g,h,i,j,k,l,m,n,o;k=gW(Ykb.Z0,Amb,6,b.q,16,1);m=clb.bo(b,a.k[0],a.p[1],k,null,null);e=0;a.k[0]!=a.p[2]&&(e=clb.Tn(b,a.k[0],a.p[2]));j=false;if(m>d-e-m){m=d-e-m;j=true;}if(j&&e!=0){o=a.k[0];g=a.p[1];while(b.o[o]==2&&b.j[o]==2&&b.C[o]<10){k[o]=true;for(l=0;l<2;l++){h=b.i[o][l];if(h!=g){g=o;o=h;break;}}}}n=0;i=c[a.p[1]];a.o=gW(Ykb.AX,gmb,6,m,15,1);for(f=0;f<b.q;f++)c[f]==i&&k[f]^j&&(a.o[n++]=f);a.n=a.p[j?2:1];};Flb.gib=function gib(a,b){return b==0?a.i:a.j;};Flb.hib=function hib(a,b){var c,d,e,f,g,h;for(f=0;f<2;f++){c=clb.zk(b,f,a.a);h=clb.zk(b,1-f,a.a);while(b.o[c]==2&&b.j[c]==2&&b.C[c]<10){for(g=0;g<2;g++){d=b.i[c][g];if(d!=h){h=c;c=d;break;}}}a.p[f+1]=c;a.k[f]=h;}if(clb.mn(b,a.p[1])==0&&clb.wn(b,a.p[1])==3){a.p[0]=-1;}else {for(e=0;e<clb.wn(b,a.p[1]);e++){d=clb.vn(b,a.p[1],e);if(d!=a.p[2]){a.p[0]=d;break;}}}if(clb.mn(b,a.p[2])==0&&clb.wn(b,a.p[2])==3){a.p[3]=-1;}else {for(e=0;e<clb.wn(b,a.p[2]);e++){d=clb.vn(b,a.p[2],e);if(d!=a.p[1]){a.p[3]=d;break;}}}};Flb.iib=function iib(a,b){var c,d,e,f,g,h,i,j,k,l;k=Flb.Khb(a.f)!=1?1:Flb.eib(b,a.p[1],a.k[0]);l=Flb.Khb(a.g)!=1?1:Flb.eib(b,a.p[2],a.k[1]);if(k==1&&l==1)return;g=360/$wnd.Math.max(k,l)|0;c=0;d=0;for(f=0;f<a.d.length&&a.d[f]<g;f++){d+=a.c[f];++c;}if(c==0)return;j=gW(Ykb.Y0,znb,6,c,15,1);h=gW(Ykb.Y0,znb,6,c,15,1);i=gW(Ykb.Y0,apb,13,c,0,2);for(e=0;e<c;e++){j[e]=a.d[e];h[e]=(a.c[e]*100/d|0)<<16>>16;i[e]=a.e[e];}a.d=j;a.c=h;a.e=i;};Flb.jib=function jib(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p;if(clb.Hk(b,a.a)==1&&(clb.Ik(b,a.a)==1||clb.Ik(b,a.a)==2)){j=false;for(h=0;h<2;h++){d=a.p[3*h];c=a.p[1+h];p=a.p[2-h];for(k=0;k<b.j[c];k++){o=b.i[c][k];if(o!=p&&o!=d){o<d&&(j=!j);break;}}}clb.Ik(b,a.a)==1&&(j=!j);e=0;f=0;for(i=0;i<a.d.length;i++){if(a.d[i]<180^j){f+=a.c[i];++e;}}if(e<a.d.length){n=gW(Ykb.Y0,znb,6,e,15,1);l=gW(Ykb.Y0,znb,6,e,15,1);m=gW(Ykb.Y0,apb,13,e,0,2);e=0;for(g=0;g<a.d.length;g++){if(a.d[g]<180^j){n[e]=a.d[g];l[e]=(a.c[g]*100/f|0)<<16>>16;m[e]=a.e[g];++e;}}a.d=n;a.c=l;a.e=m;}}};Flb.kib=function kib(a,b,c,d,e,f,g){Flb.dib();var h,i,j,k;(k=elb.Gv(elb.Fv,ltb),!k?null:elb.vw(k))[0]==-1&&(Zkb.O5(),String.fromCharCode(10));this.a=b;this.p=gW(Ykb.AX,gmb,6,4,15,1);this.k=gW(Ykb.AX,gmb,6,2,15,1);h=new elb.tw();if(elb.Qv(a,b,this.p,h)!=null){this.k[0]=h.e[0];this.k[1]=h.e[1];}else {Flb.hib(this,a);}this.i=c[this.p[1]];this.j=c[this.p[2]];this.f=f[this.i];this.g=f[this.j];this.b=c[a.D[0][b]]==this.i;(j=elb.Gv(elb.Fv,ltb),!j?null:elb.vw(j))[0]==-1&&(Zkb.O5(),String.fromCharCode(10));if(g){this.d=Flb.cib;this.c=Flb.aib;this.e=Flb.bib;}else {this.d=elb.Sv(h.d);if(this.d==null){i=new elb.Cw(a,this.p);this.d=i.b;this.c=i.a;this.e=i.c;}else {this.c=elb.Pv(h.d);this.e=elb.Rv(h.d);}}Flb.jib(this,a);Flb.iib(this,a);Flb.fib(this,a,d,e);};U1(133,1,{133:1},Flb.kib);_.a=0;_.b=false;_.i=0;_.j=0;_.n=0;Ykb.E0=w3(133);Flb.lib=function lib(a,b){var c;for(c=0;c<a.f.length;c++)if(z1(a.f[c],b.f[c]))return u1(a.f[c],b.f[c])?-1:1;return 0;};Flb.mib=function mib(a,b,c){var d;for(d=0;d<b.length;d++)if(z1(e1(a.f[d],b[d]),e1(c[d],b[d])))return false;return true;};Flb.nib=function nib(a,b,c){a.b=b;a.a=c;!!a.c&&a.e*$wnd.Math.pow(10,-b/1.36);};Flb.oib=function oib(a,b){a.c=b;a.e*$wnd.Math.pow(10,-a.b/1.36);};Flb.pib=function pib(a,b){a.e=b;};Flb.qib=function qib(a,b,c){this.i=a;this.d=b;this.f=Flb.Bib(c,a,b);};U1(126,1,{27:1,126:1},Flb.qib);_.qb=function rib(a){return Flb.lib(this,a);};_.ib=function sib(a){return Flb.lib(this,a)==0;};_.lb=function tib(){var a,b,c,d,e,f,g,h;h=new Zkb.J5();for(c=this.i,e=0,g=c.length;e<g;++e){a=c[e];h.a+=a;h.a+=',';}this.i.length!=0&&Zkb.B2(h,alb.Pgb(h.a).length-1);h.a+=';';for(b=this.d,d=0,f=b.length;d<f;++d){a=b[d];h.a+=a;h.a+=',';}this.d.length!=0&&Zkb.B2(h,alb.Pgb(h.a).length-1);return h.a;};_.b=0;_.e=0;_.g=false;Ykb.O0=w3(126);Flb.uib=function uib(a,b){var c,d;d=true;for(c=0;c<a.c.length;c++)(z1(e1(A1(b.c[c]),a.c[c]),0)||z1(e1(b.b[c],a.c[c]),a.b[c]))&&(d=false);return d;};Flb.vib=function vib(a,b){var c,d;d=true;for(c=0;c<a.c.length;c++)(z1(e1(A1(a.c[c]),b.c[c]),0)||z1(e1(a.b[c],b.c[c]),b.b[c]))&&(d=false);return d;};Flb.wib=function wib(a,b,c,d){this.c=gW(Ykb.BX,Anb,6,d.c,14,1);this.b=gW(Ykb.BX,Anb,6,d.c,14,1);Flb.Cib(d,a,b,this.c,this.b);this.a=c;};U1(200,1,{200:1},Flb.wib);_.a=0;Ykb.F0=w3(200);Flb.yib=function yib(){Flb.yib=W1;Flb.xib=oW(aW(Ykb.BX,1),Anb,6,14,[0,1,3,7,15,31,63,127]);};Flb.zib=function zib(a,b,c){var d,e,f,g,h,i;h=new Zkb.J5();d=Flb.Aib(a,b);h.a+=' rb:';i=alb.Pgb(h.a).length;for(f=0;f<d.length;f++){if(d[f]!=-1){alb.Pgb(h.a).length!=i&&(h.a+=',',h);h.a+=f;}}h.a+=' ti:';i=alb.Pgb(h.a).length;for(g=0;g<d.length;g++){if(d[g]!=-1){alb.Pgb(h.a).length!=i&&(h.a+=',',h);Zkb.D5(h,d[g]);}}h.a+=' (';i=alb.Pgb(h.a).length;for(e=0;e<d.length;e++){if(d[e]!=-1){alb.Pgb(h.a).length!=i&&(h.a+=',',h);Zkb.D5(h,Flb.Xgb(c,e,d[e]));}}Zkb.G5(h,(slb.IT(),') '+slb.JT(b.a,3)));return h.a;};Flb.Aib=function Aib(a,b){var c,d,e;c=gW(Ykb.AX,gmb,6,a.e.length,15,1);for(e=0;e<a.e.length;e++){d=C1(Flb.xib[a.a[e]],a.b[e]);z1(e1(b.c[a.d[e]],d),0)?c[e]=I1(D1(e1(b.b[a.d[e]],d),a.b[e])):c[e]=-1;}return c;};Flb.Bib=function Bib(a,b,c){var d,e,f,g,h,i,j,k,l;l=gW(Ykb.BX,Anb,6,1+a.d[a.d.length-1],14,1);d=0;for(g=b,i=0,k=g.length;i<k;++i){e=g[i];l[a.d[d]]=d1(l[a.d[d]],q1(e<<a.b[d]));++d;}for(f=c,h=0,j=f.length;h<j;++h){e=f[h];l[a.d[d]]=d1(l[a.d[d]],q1(e<<a.b[d]));++d;}return l;};Flb.Cib=function Cib(a,b,c,d,e){var f,g,h,i;for(g=c,h=0,i=g.length;h<i;++h){f=g[h];e[a.d[f]]=d1(e[a.d[f]],q1(b[f]<<a.b[f]));d[a.d[f]]=d1(d[a.d[f]],C1(Flb.xib[a.a[f]],a.b[f]));}};Flb.Dib=function Dib(a,b,c){return z1(e1(b.c[a.d[c]],C1(1,a.b[c])),0);};Flb.Eib=function Eib(a){var b,c;b=0;c=a-1;while(c>0){c>>=1;++b;}return b;};Flb.Fib=function Fib(a,b){Flb.yib();var c,d,e,f,g,h,i,j,k,l,m,n;this.e=b;this.a=gW(Ykb.AX,gmb,6,b.length+a.length,15,1);this.b=gW(Ykb.AX,gmb,6,b.length+a.length,15,1);this.d=gW(Ykb.AX,gmb,6,b.length+a.length,15,1);c=0;f=0;e=0;for(h=b,i=0,j=h.length;i<j;++i){g=h[i];d=Flb.Eib(g.d.length);if(c+d<=64){this.b[e]=c;c+=d;}else {++f;this.b[e]=0;c=0;}this.a[e]=d;this.d[e]=f;++e;}for(l=a,m=0,n=l.length;m<n;++m){k=l[m];d=Flb.Eib(k.b.length);if(c+d<=64){this.b[e]=c;c+=d;}else {++f;this.b[e]=0;c=0;}this.a[e]=d;this.d[e]=f;++e;}this.c=f+1;};U1(278,1,{},Flb.Fib);_.c=0;Ykb.G0=w3(278);Flb.Gib=function Gib(a,b){var c,d,e;e=0;for(d=new dlb.Obb(b);d.a<d.c.a.length;){c=dlb.Nbb(d);e+=Flb.mib(a,c.c,c.b)?a.b:0;}return e;};Flb.Hib=function Hib(a,b,c){var d;d=new Flb.qib(b,c,a.D);Flb.pib(d,Flb.Lib(a,d));return d;};Flb.Iib=function Iib(a){var b,c;if(a.A.d.a.length==0)return null;b=mX(a,92)?dlb.Vdb(a.c,a.A.d.a.length):0;c=slb.TT(a.A,b);slb.VT(a.A,b);return c;};Flb.Jib=function Jib(a,b){var c,d,e,f,g;c=gW(Ykb.yX,emb,6,a.w.length+a.v.length,15,1);d=Flb.jhb(a.i,b.d).c;for(f=new dlb.Obb(d);f.a<f.c.a.length;){e=dlb.Nbb(f);if((Flb.mib(b,e.c,e.b)?b.b:0)!=0)for(g=0;g<c.length;g++)Flb.Dib(a.D,e,g)&&(c[g]+=e.a);}return c;};Flb.Kib=function Kib(a,b,c){return a.f[b][c];};Flb.Lib=function Lib(a,b){var c,d,e,f;d=1;for(f=0;f<a.v.length;f++)d*=Flb.Jhb(a.v[f],b.d[f]);c=Flb.jhb(a.i,b.d);for(e=0;e<a.w.length;e++)d*=Flb.Ygb(c,e,b.i[e]);return d;};Flb.Mib=function Mib(a,b,c){var d,e,f,g,h,i,j;!!b&&b.g&&++a.C;!!b&&a.s>b.b&&(a.s=b.b);if(a.G)return Flb.Iib(a);if(a.F.d.a.length==a.t){return null;}if(!!b&&b.b>3){d=c?Flb.jhb(a.i,b.d):null;g=c?d.c:null;f=!c?0:g.a.length;Flb.Pib(a,b);if(c)for(h=f;h<g.a.length;h++)Flb.chb(dlb.Iab(c.a,elb.pv(b.c)),Flb.zib(a.D,(alb.Dgb(h,g.a.length),g.a[h]),d));b.g||(b.b<6?slb.RT(a.A,b):(!a.e||a.e.b>b.b)&&(a.e=b));++a.g;}i=a.s+3;j=Flb.Oib(a,i,b);while(j){e=Flb.Gib(j,Flb.jhb(a.i,j.d).c);if(e<i)break;e<6&&slb.RT(a.B,new Flb.ejb(j,e));++a.g;slb.ZT(a.F,j);if(a.F.d.a.length==a.t){return null;}i=a.s+3;j=Flb.Oib(a,i,j);}if(!j){if(a.A.d.a.length!=0){a.G=true;while(a.A.d.a.length!=0&&slb.TT(a.A,a.A.d.a.length-1).b>a.s+3)slb.VT(a.A,a.A.d.a.length-1);j=Flb.Iib(a);}return j;}slb.ZT(a.F,j);return j;};Flb.Nib=function Nib(a,b,c){var d,e,f,g,h,i,j;dlb._bb(a.q);a.p[0]=b;a.q[b]=true;f=0;g=0;while(f<=g){for(h=0;h<a.j[a.p[f]].length;h++){e=a.j[a.p[f]][h];if(e==c){d=1;i=f;while(i!=0){++d;i=a.r[i];}j=gW(Ykb.AX,gmb,6,d,15,1);j[0]=a.k[a.p[f]][h];d=1;while(f!=0){j[d++]=a.o[f];f=a.r[f];}return j;}if(!a.q[e]){a.q[e]=true;++g;a.p[g]=e;a.o[g]=a.k[a.p[f]][h];a.r[g]=f;}}++f;}return null;};Flb.Oib=function Oib(a,b,c){var d;if(a.B.d.a.length!=0){d=slb.TT(a.B,0);if(d.a<b){slb.VT(a.B,0);return d.b;}}return a.oc(c);};Flb.Pib=function Pib(a,b){var c,d,e,f,g,h,i,j,k,l,m;c=b.a;m=b.i;for(g=1;g<c.length;g++){if(c[g]!=null){for(h=0;h<g;h++){if(c[g][h]!=0){k=a.f[g][h];l=new Flb.wib(m,k,c[g][h],a.D);i=false;j=null;d=Flb.jhb(a.i,b.d).c;for(f=new dlb.Obb(d);f.a<f.c.a.length;){e=dlb.Nbb(f);if(Flb.uib(e,l)){i=true;break;}if(Flb.vib(e,l)){!j&&(j=new dlb.Qi());alb.ggb(j.a,e);}}if(!i){!!j&&dlb.Uh(d,j);alb.ggb(d.a,l);}}}}}};Flb.Qib=function Qib(a,b){a.t=$wnd.Math.min(b,a.u);};Flb.Rib=function Rib(a){var b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u;this.i=a;this.w=a.s;this.v=a.q;this.D=new Flb.Fib(this.v,this.w);this.n=0;for(j=this.w,m=0,p=j.length;m<p;++m){h=j[m];this.n=$wnd.Math.max(this.n,$wnd.Math.max(1+h.i,1+h.j));}b=gW(Ykb.AX,gmb,6,this.n,15,1);for(k=this.w,n=0,q=k.length;n<q;++n){h=k[n];++b[h.i];++b[h.j];}this.j=gW(Ykb.AX,Dnb,7,b.length,0,2);this.k=gW(Ykb.AX,Dnb,7,b.length,0,2);for(g=0;g<b.length;g++){this.j[g]=gW(Ykb.AX,gmb,6,b[g],15,1);this.k[g]=gW(Ykb.AX,gmb,6,b[g],15,1);}dlb.bcb(b,b.length,0);for(f=0;f<this.w.length;f++){d=Flb.gib(this.w[f],0);e=Flb.gib(this.w[f],1);this.j[d][b[d]]=e;this.j[e][b[e]]=d;this.k[d][b[d]]=f;this.k[e][b[e]]=f;++b[d];++b[e];}this.p=gW(Ykb.AX,gmb,6,this.n,15,1);this.o=gW(Ykb.AX,gmb,6,this.n,15,1);this.r=gW(Ykb.AX,gmb,6,this.n,15,1);this.q=gW(Ykb.Z0,Amb,6,this.n,16,1);this.f=gW(Ykb.AX,Llb,26,this.n,0,3);for(c=1;c<this.n;c++){this.f[c]=gW(Ykb.AX,Dnb,7,c,0,2);for(e=0;e<c;e++)this.f[c][e]=Flb.Nib(this,c,e);}this.u=1;for(i=this.w,l=0,o=i.length;l<o;++l){h=i[l];this.u*=h.d.length;}for(s=this.v,t=0,u=s.length;t<u;++t){r=s[t];this.u*=r.b.length;}this.u<=0&&(this.u=Qlb);this.F=new slb._T();this.A=new slb.XT((alb.Egb(new Flb.Sib()),new dlb.zcb()));this.B=new slb.WT();this.g=0;this.C=0;this.s=3;this.G=false;this.t=$wnd.Math.min($lb,this.u);};U1(182,1,{});_.g=0;_.n=0;_.s=0;_.t=0;_.u=0;_.C=0;_.G=false;Ykb.M0=w3(182);Flb.Sib=function Sib(){};U1(252,1,{},Flb.Sib);Ykb.H0=w3(252);Flb.Tib=function Tib(a){var b,c,d,e,f,g,h,i,j,k,l;if(a.F.d.a.length==a.u)return null;k=gW(Ykb.AX,gmb,6,a.w.length,15,1);c=gW(Ykb.AX,gmb,6,a.v.length,15,1);d=0;do{if(d++==64)return null;if(a.b){h=d/64;for(j=0;j<a.v.length;j++)c[j]=Flb.Mhb(a.v[j],dlb.Udb(a.c),h);b=Flb.jhb(a.i,c);for(i=0;i<a.w.length;i++)k[i]=Flb.Wgb(b,i,dlb.Udb(a.c),h);}else {for(g=0;g<a.v.length;g++)c[g]=dlb.Vdb(a.c,a.v[g].b.length);for(f=0;f<a.w.length;f++)k[f]=dlb.Vdb(a.c,a.w[f].d.length);}l=Flb.Hib(a,k,c);}while((e=slb.UT(a.F,l),(e<0?-1:e)!=-1));return l;};Flb.Uib=function Uib(a,b,c){Flb.Rib.call(this,a);this.b=b;this.c=j1(c,0)==0?new dlb.Ydb():new dlb.Zdb(c);};U1(92,182,{92:1},Flb.Uib);_.oc=function Vib(a){return Flb.Tib(this);};_.b=false;Ykb.L0=w3(92);Flb.Wib=function Wib(a,b){Flb.Uib.call(this,a,true,b);this.a=true;};U1(162,92,{92:1},Flb.Wib);_.oc=function Xib(a){var b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s;if(!a){return this.a?Flb.Hib(this,gW(Ykb.AX,gmb,6,this.w.length,15,1),gW(Ykb.AX,gmb,6,this.v.length,15,1)):Flb.Tib(this);}if(a.b==0)return Flb.Tib(this);d=Flb.Jib(this,a);c=a.i;b=a.d;k=gW(Ykb.Z0,Amb,6,d.length,16,1);for(f=0;f<64;f++){(k[0]||this.w[0].d.length==1)&&(d[0]=0);j=1;for(h=1;h<this.w.length;h++){k[j]||this.w[h].d.length==1?d[j]=d[j-1]:d[j]+=d[j-1];++j;}for(o=this.v,p=0,q=o.length;p<q;++p){n=o[p];k[j]||n.b.length==1?d[j]=d[j-1]:d[j]+=d[j-1];++j;}if(d[d.length-1]==0)return Flb.Tib(this);m=dlb.Udb(this.c)*d[d.length-1];for(g=0;g<d.length;g++){if(m<d[g]){r=dlb.Ubb(c,c.length);e=dlb.Ubb(b,b.length);if(g<this.w.length){for(l=1;l<this.w[g].d.length;l++){++r[g];r[g]==this.w[g].d.length&&(r[g]=0);s=Flb.Hib(this,r,e);i=slb.UT(this.F,s);if((i<0?-1:i)==-1)return s;}}else {g-=this.w.length;for(l=1;l<this.v[g].b.length;l++){++e[g];e[g]==this.v[g].b.length&&(e[g]=0);s=Flb.Hib(this,r,e);i=slb.UT(this.F,s);if((i<0?-1:i)==-1)return s;}}k[g]=true;break;}}}return Flb.Tib(this);};_.a=false;Ykb.I0=w3(162);Flb.Yib=function Yib(a){var b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s;c=-1;j=false;n=Unb;b=Flb.jhb(a.i,a.c);for(p=0;p<a.d.length;p++){if(a.d[p]<a.w[p].d.length-1){m=Flb.Ygb(b,p,a.d[p])/Flb.Ygb(b,p,a.d[p]+1);if(n>m){n=m;c=p;}}}for(q=0;q<a.c.length;q++){if(a.c[q]<a.v[q].b.length-1){m=Flb.Jhb(a.v[q],a.c[q])/Flb.Jhb(a.v[q],a.c[q]+1);if(n>m){n=m;c=q;j=true;}}}if(c==-1){a.a=null;return;}f=1;for(h=0;h<a.d.length;h++)(j||h!=c)&&(f*=a.d[h]+1);for(i=0;i<a.c.length;i++)(!j||i!=c)&&(f*=a.c[i]+1);a.a=gW(Ykb.O0,Enb,126,f,0,1);j?++a.c[c]:++a.d[c];for(g=0;g<f;g++){o=g;s=gW(Ykb.AX,gmb,6,a.d.length,15,1);for(l=0;l<a.d.length;l++){if(j||l!=c){r=a.d[l]+1;if(r!=1){s[l]=o%r;o=o/r|0;}}}e=gW(Ykb.AX,gmb,6,a.c.length,15,1);for(k=0;k<a.c.length;k++){if(!j||k!=c){d=a.c[k]+1;if(d!=1){e[k]=o%d;o=o/d|0;}}}j?e[c]=a.c[c]:s[c]=a.d[c];a.a[g]=Flb.Hib(a,s,e);}dlb.mcb(a.a,new Flb.ajb());a.b=-1;};Flb.Zib=function Zib(a){Flb.Rib.call(this,a);this.d=gW(Ykb.AX,gmb,6,this.w.length,15,1);this.c=gW(Ykb.AX,gmb,6,this.v.length,15,1);this.a=gW(Ykb.O0,Enb,126,1,0,1);this.a[0]=Flb.Hib(this,gW(Ykb.AX,gmb,6,this.w.length,15,1),gW(Ykb.AX,gmb,6,this.v.length,15,1));this.b=-1;};Flb._ib=function _ib(a,b){return $3(b.e,a.e);};U1(218,182,{},Flb.Zib);_.oc=function $ib(a){if(this.a==null)return null;this.b+1==this.a.length&&Flb.Yib(this);if(this.a==null)return null;++this.b;return this.a[this.b];};_.b=0;Ykb.K0=w3(218);Flb.ajb=function ajb(){};U1(256,1,{},Flb.ajb);_.pb=function bjb(a,b){return Flb._ib(a,b);};_.ib=function cjb(a){return this===a;};Ykb.J0=w3(256);Flb.djb=function djb(a,b){return a.a<b.a?-1:a.a>b.a?1:0;};Flb.ejb=function ejb(a,b){this.b=a;this.a=b;};U1(201,1,{27:1,201:1},Flb.ejb);_.qb=function fjb(a){return Flb.djb(this,a);};_.a=0;Ykb.N0=w3(201);Glb.hjb=function hjb(){Glb.hjb=W1;Glb.gjb=oW(aW(Ykb.l_,1),Xlb,2,6,['distance','plane','line','torsion','stereo','binap']);};Glb.ijb=function ijb(a,b){var c;if(a.f==null){b.a+=' atoms:<null>';}else {Zkb.G5(b,' atoms:'+a.f[0]);for(c=1;c<a.f.length;c++)Zkb.G5(b,','+a.f[c]);}};Glb.jjb=function jjb(a,b,c,d,e,f){var g,h,i,j,k;clb.mh(a.k[b],d,e,f);k=a.o;for(i=0;i<k.e[b];i++){g=k.i[b][i];h=false;if(c!=null){for(j=0;j<c.length;j++){if(g==c[j]){h=true;break;}}}h||(k.e[g]==1?clb.mh(a.k[g],d,e,f):clb.zo(k,k.k[b][i])?clb.mh(a.k[g],d/3,e/3,f/3):Glb.kjb(a,b,g,d,e,f));}};Glb.kjb=function kjb(a,b,c,d,e,f){var g,h,i,j,k,l,m;clb.mh(a.k[c],d,e,f);m=a.o;l=gW(Ykb.Z0,Amb,6,m.q,16,1);i=gW(Ykb.AX,gmb,6,m.q,15,1);i[0]=c;l[b]=true;l[c]=true;h=0;j=0;while(h<=j){for(k=0;k<clb.gn(m,i[h]);k++){g=clb.vn(m,i[h],k);if(!l[g]){l[g]=true;i[++j]=g;clb.mh(a.k[g],d,e,f);}}++h;}};Glb.ljb=function ljb(a){this.f=a;this.g=true;};Glb.mjb=function mjb(a,b,c,d,e){Glb.hjb();var f,g,h,i,j,k,l,m,n,o,p;for(i=0;i<b.length;i++)clb.nh(c,elb.ov(a,b[i]));clb.wh(c,1/b.length);for(j=0;j<b.length;j++){e[j][0]=elb.qv(a,b[j])-c.a;e[j][1]=elb.rv(a,b[j])-c.b;e[j][2]=elb.sv(a,b[j])-c.c;}o=eW(Ykb.yX,[Llb,emb],[12,6],15,[3,3],2);for(k=0;k<b.length;k++)for(l=0;l<3;l++)for(m=0;m<3;m++)o[l][m]+=e[k][l]*e[k][m];p=new blb.Nc(o);f=p.e;n=0;for(h=1;h<3;h++)f[h]<f[n]&&(n=h);g=p.a;d.a=g[0][n];d.b=g[1][n];d.c=g[2][n];};Glb.njb=function njb(a,b,c,d,e){var f,g,h,i,j,k,l,m,n;l=d.a;m=d.b;n=d.c;f=$wnd.Math.cos(e);j=$wnd.Math.sin(e);k=1-f;g=a.k[b].a-c.a;h=a.k[b].b-c.b;i=a.k[b].c-c.c;elb.xv(a,b,c.a+(k*l*l+f)*g+(k*l*m+j*n)*h+(k*l*n-j*m)*i);elb.yv(a,b,c.b+(k*l*m-j*n)*g+(k*m*m+f)*h+(k*m*n+j*l)*i);elb.zv(a,b,c.c+(k*l*n+j*m)*g+(k*n*m-j*l)*h+(k*n*n+f)*i);};Glb.ojb=function ojb(a,b,c,d,e,f){Glb.hjb();var g,h,i,j,k,l,m,n,o,p,q;m=a.o;g=gW(Ykb.Z0,Amb,6,m.q,16,1);j=gW(Ykb.AX,gmb,6,m.q,15,1);j[0]=b;g[b]=true;for(o=c,p=0,q=o.length;p<q;++p){n=o[p];g[n]=true;}Glb.njb(a,b,d,e,f);i=0;k=0;while(i<=k){for(l=0;l<clb.gn(m,j[i]);l++){h=clb.vn(m,j[i],l);if(!g[h]){g[h]=true;j[++k]=h;Glb.njb(a,h,d,e,f);}}++i;}};U1(43,1,mtb);_.g=false;Ykb.Q0=w3(43);Glb.pjb=function pjb(a,b,c){var d,e,f,g,h,i,j,k,l,m;d=gW(Ykb.AX,gmb,6,a.f,15,1);l=gW(Ykb.Z0,Amb,6,a.f,16,1);l[c]=true;l[b]=true;d[0]=b;g=0;h=1;while(g<=h){for(j=0;j<clb.wn(a,d[g]);j++){if(clb.mo(a,clb.xn(a,d[g],j))){f=clb.vn(a,d[g],j);if(!l[f]){d[++h]=f;l[f]=true;}}}++g;}for(k=0;k<=h;k++){for(m=0;m<clb.wn(a,d[k]);m++){f=clb.vn(a,d[k],m);!l[f]&&!clb.zo(a,clb.xn(a,d[k],m))&&clb.bo(a,d[k],f,l,null,null);}}l[c]=false;for(i=0;i<=h;i++)l[d[i]]=false;for(e=0;e<l.length;e++)l[e]&&(d[++h]=e);return alb.Agb(h+1),dlb.Wbb(d,gW(Ykb.AX,gmb,6,h+1,15,1),h+1);};Glb.qjb=function qjb(a,b,c,d,e){var f,g,h,i,j,k,l;if(c)return Glb.pjb(b,d[1],d[2]);j=eW(Ykb.Z0,[Llb,Amb],[11,6],16,[2,b.q],2);g=gW(Ykb.AX,gmb,6,2,15,1);for(h=0;h<2;h++)g[h]=clb.bo(b,d[1+h],e[h],j[h],null,null);l=g[0]<g[1]?0:1;k=gW(Ykb.AX,gmb,6,g[l],15,1);i=0;for(f=0;f<b.q;f++)j[l][f]&&(k[i++]=f);a.a=l==1;return k;};Glb.rjb=function rjb(a,b,c,d,e){Glb.ljb.call(this,b);this.c=Glb.qjb(this,a,d,b,c);this.b=e;};Glb.ujb=function ujb(a,b){Glb.hjb();var c,d,e,f,g,h,i,j,k,l,m;for(f=0;f<b.f;f++){if(b.o[f]==2&&b.j[f]==2&&b.n[f][0]==2&&b.n[f][1]==2&&b.C[f]<=7){k=b.u[f]&3;if(k==1||k==2){d=gW(Ykb.AX,gmb,6,4,15,1);m=gW(Ykb.AX,gmb,6,2,15,1);for(h=0;h<b.j[f];h++){c=b.i[f][h];j=Qlb;for(i=0;i<b.j[c];i++){g=b.i[c][i];g!=f&&j>g&&(j=g);}d[3*h]=j;d[1+h]=c;m[h]=f;}if(d[0]==Qlb||d[3]==Qlb){Zkb.O5();'Unexpected MAX_VALUE idcode:'+clb.Gf(new clb.ag(b));break;}dlb.wi(a,new Glb.rjb(b,d,m,(b.u[f]&bob)!=0,k==1));}}}for(e=0;e<b.g;e++){k=b.F[e]&3;if((k==1||k==2)&&clb.Hk(b,e)!=2){d=gW(Ykb.AX,gmb,6,4,15,1);m=gW(Ykb.AX,gmb,6,2,15,1);for(h=0;h<2;h++){c=b.D[h][e];l=b.D[1-h][e];j=Qlb;for(i=0;i<b.j[c];i++){g=b.i[c][i];g!=l&&j>g&&(j=g);}d[3*h]=j;d[1+h]=c;m[h]=b.D[1-h][e];}dlb.wi(a,new Glb.rjb(b,d,m,(b.F[e]&64)!=0,k==2));}}};U1(190,43,mtb,Glb.rjb);_.pc=function sjb(a,b){var c,d,e,f,g;g=elb.iv(a,this.f)<0?1:0;if(b!=null)for(d=this.f,e=0,f=d.length;e<f;++e){c=d[e];b[c]+=g/4;}return g;};_.qc=function tjb(a,b){var c,d,e,f,g,h,i;h=elb.iv(a,this.f);if(h==0||this.b==h>0)return false;i=clb.Ah(elb.ov(a,this.f[2]),elb.ov(a,this.f[1]));clb.Bh(i);g=$wnd.Math.abs(h)<Gmb?-2*h:2*(Fmb-h);this.a&&(g=-g);for(d=this.c,e=0,f=d.length;e<f;++e){c=d[e];Glb.njb(a,c,elb.ov(a,this.f[1]),i,g);}return true;};_.rc=function vjb(){return 5;};_.lb=function wjb(){var a;a=new Zkb.L5('binap rule ('+(this.b?'positive':'negative')+' torsion):');Glb.ijb(this,a);return a.a;};_.a=false;_.b=false;Ykb.P0=w3(190);Glb.yjb=function yjb(){Glb.yjb=W1;Glb.xjb=oW(aW(Ykb.AX,1),gmb,6,15,[40,20,20,100,20]);};Glb.zjb=function zjb(a,b){var c,d,e;a.g==null&&(a.g=elb.iw(a.d));if(b.e>a.c+2.72)return false;elb.hv(b,a.g);for(d=a.a.a.length-1;d>=0;d--){e=dlb.Bi(a.a,d);elb.mv(b,e);if(elb.Vv(b.q,e.q)){if(e.e>b.e){dlb.Ii(a.a,d);dlb.wi(a.a,b);a.c>b.e&&(a.c=b.e);return true;}return false;}}dlb.wi(a.a,b);if(a.c>b.e){a.c=b.e;for(c=a.a.a.length-1;c>=0;c--){e=dlb.Bi(a.a,c);e.e>a.c+2.72&&dlb.Ii(a.a,c);}}return true;};Glb.Ajb=function Ajb(a){var b;for(b=0;b<a.o.q;b++)if((a.a==null?NaN:a.a[b])>1000||(a.a==null?NaN:a.a[b])>2000)return true;return false;};Glb.Bjb=function Bjb(a,b){var c,d,e,f;Glb.pkb(b,a.j);d=0;for(c=0;c<a.d.q;c++){e=b.a==null?NaN:b.a[c];if(e>1000){if(Glb.Jjb(a,b,c)){++d;continue;}}if(e>2000){f=b.k[c];clb.mh(f,8*dlb.Udb(a.f)-4,8*dlb.Udb(a.f)-4,8*dlb.Udb(a.f)-4);++d;}}d!=0&&Glb.rkb(b);return d;};Glb.Cjb=function Cjb(a,b){var c,d,e,f;a.f=j1(b,0)==0?new dlb.Ydb():new dlb.Zdb(b);d=new Glb.skb(a.d);c=null;for(e=0;e<12;e++){if(Glb.Ljb(a,d)||j1(b,0)!=0)return d;if(!c){c=d;d=new Glb.skb(a.d);}else if(c.e>d.e){f=c;c=d;d=f;}}return c;};Glb.Djb=function Djb(a){var b,c,d;if(!a.a)return null;a.e||Glb.Ejb(a,1);b=null;for(d=new dlb.Obb(a.a);d.a<d.c.a.length;){c=dlb.Nbb(d);!c.b&&(!b||b.e>c.e)&&(b=c);}b?b.b=true:a.a=null;return b;};Glb.Ejb=function Ejb(a,b){var c,d,e,f,g,h;c=null;d=null;e=a.a.a.length+b;h=b*12;for(f=0;f<h&&a.a.a.length<e;f++){!d&&(d=new Glb.skb(a.d));if(Glb.Ljb(a,d)){Glb.zjb(a,d)&&(d=null);}else {if(!c){c=d;d=null;}else if(c.e>d.e){g=c;c=d;d=g;}}}a.a.a.length==0&&!!c&&dlb.wi(a.a,c);(a.a.a.length<e||a.a.a.length==a.b)&&(a.e=true);};Glb.Fjb=function Fjb(a,b,c){var d,e,f;a.f=j1(b,0)==0?new dlb.Ydb():new dlb.Zdb(b);a.a=new dlb.Qi();a.c=Unb;a.e=false;e=0;f=0;for(d=0;d<a.d.g;d++){!clb.mo(a.d,d)&&clb.Hk(a.d,d)==1&&clb.gn(a.d,clb.zk(a.d,0,d))>1&&clb.gn(a.d,clb.zk(a.d,1,d))>1&&(clb.zo(a.d,d)?clb.un(a.d,d)>4&&++f:++e);}a.b=c==-1?1<<1+e+(f/2|0):c;Glb.Ejb(a,$wnd.Math.min(8,a.b));};Glb.Gjb=function Gjb(a){var b;for(b=0;b<a.o.q;b++)if((a.a==null?NaN:a.a[b])>2.72)return false;return true;};Glb.Hjb=function Hjb(a,b){var c,d,e,f;e=1+3*$wnd.Math.sqrt(a.d.q);for(d=0;d<a.d.q;d++){if(clb.gn(a.d,d)!=1){elb.xv(b,d,e*dlb.Udb(a.f)-e/2);elb.yv(b,d,e*dlb.Udb(a.f)-e/2);elb.zv(b,d,e*dlb.Udb(a.f)-e/2);}}for(c=0;c<a.d.q;c++){if(clb.gn(a.d,c)==1){f=clb.vn(a.d,c,0);elb.xv(b,c,b.k[f].a+2*dlb.Udb(a.f)-1);elb.yv(b,c,b.k[f].b+2*dlb.Udb(a.f)-1);elb.zv(b,c,b.k[f].c+2*dlb.Udb(a.f)-1);}}Glb.rkb(b);};Glb.Ijb=function Ijb(a,b,c,d){var e,f,g,h,i,j,k,l,m,n,o,p,q,r,s;i=Glb.xjb[d];h=1;n=d==4?$wnd.Math.exp($wnd.Math.log(0.01)/i):1;e=a.d.q*a.d.q;m=gW(Ykb.yX,emb,6,10,15,1);l=0;for(k=0;k<i;k++){d!=0&&k%10==0&&Glb.Kjb(a,b);for(j=0;j<e;j++){o=null;o=dlb.Bi(a.j,vX(dlb.Udb(a.f)*a.j.a.length));if(o.g&&!a.k[o.rc()]){g=o.qc(b,h);g&&Glb.rkb(b);}}Glb.pkb(b,a.j);m[l++]=b.e;l==10&&(l=0);if(k>10){f=0;for(q=m,r=0,s=q.length;r<s;++r){p=q[r];f+=p;}f/=10;if(b.e>f)break;}c.e>b.e&&(elb.lv(c,b),Glb.qkb(c,b));h*=n;}b.e>c.e&&(elb.lv(b,c),Glb.qkb(b,c));};Glb.Jjb=function Jjb(a,b,c){var d,e,f,g,h,i,j;if(clb.gn(a.d,c)==1){f=clb.vn(a.d,c,0);if(clb.Bo(a.d,f)){d=b.k[c];e=b.k[f];i=new clb.Dh(e.a-d.a,e.b-d.b,e.c-d.c);for(g=0;g<clb.wn(a.d,f);g++){h=clb.vn(a.d,f,g);if(clb.yo(a.d,h)){j=clb.Ah(e,b.k[h]);if(clb.uh(i,j)>Gmb)return false;}}clb.nh(clb.nh(d,i),i);return true;}}return false;};Glb.Kjb=function Kjb(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D;f=false;B=clb.Xn(a.d);for(s=0;s<B.i.a.length;s++){A=dlb.Bi(B.i,s);if(A.length==6&&!B.e[s]){n=true;for(u=dlb.Bi(B.j,s),v=0,w=u.length;v<w;++v){t=u[v];if(clb.Hk(a.d,t)!=1||clb.qo(a.d,t)){n=false;break;}}if(n){g=new clb.Ch();p=new clb.Ch();i=eW(Ykb.yX,[Llb,emb],[12,6],15,[6,3],2);Glb.mjb(b,A,g,p,i);j=gW(Ykb.yX,emb,6,A.length,15,1);C=0;for(l=0;l<A.length;l++){j[l]=-(p.a*i[l][0]+p.b*i[l][1]+p.c*i[l][2]);j[l]<0^(l&1)==1&&++C;}if(C!=0&&C!=6){for(k=0;k<A.length;k++){if(j[k]<0^(k&1)==1^C>=3){q=gW(Ykb.AX,gmb,6,2,15,1);q[0]=A[k==0?5:k-1];q[1]=A[k==5?0:k+1];r=elb.ov(b,A[k]);d=clb.Bh(clb.rh(clb.Ah(elb.ov(b,A[k]),g),p));c=0.6+$wnd.Math.asin($wnd.Math.abs(j[k])/$wnd.Math.sqrt((g.a-r.a)*(g.a-r.a)+(g.b-r.b)*(g.b-r.b)+(g.c-r.c)*(g.c-r.c)));D=j[k]<0?c:-c;e=clb.ph(new clb.Eh(r),g);m=false;if(clb.wn(a.d,A[k])>2){for(o=0;o<clb.wn(a.d,A[k]);o++){h=clb.vn(a.d,A[k],o);if(h!=q[0]&&h!=q[1]&&clb.zo(a.d,clb.xn(a.d,A[k],o))){m=true;break;}}}m||Glb.ojb(b,A[k],q,e,d,D);}}f=true;}}}}if(f){Glb.rkb(b);Glb.pkb(b,a.j);}return f;};Glb.Ljb=function Ljb(a,b){var c,d,e,f,g;if(a.d.q<2)return true;for(g=new dlb.Obb(a.j);g.a<g.c.a.length;){f=dlb.Nbb(g);f.g=true;}for(e=0;e<a.k.length;e++)a.k[e]=false;Glb.Hjb(a,b);c=new Glb.tkb(b);Glb.Ijb(a,b,c,0);for(d=0;Glb.Ajb(b)&&d<3;d++){if(Glb.Bjb(a,b)==0)break;Glb.Ijb(a,b,c,2);}Glb.Ijb(a,b,c,3);Glb.Ijb(a,b,c,4);return Glb.Gjb(b);};Glb.Mjb=function Mjb(a){Glb.yjb();this.d=a;clb.Gt(this.d,15);this.j=new dlb.Qi();this.k=gW(Ykb.Z0,Amb,6,(Glb.hjb(),Glb.gjb).length,16,1);this.i=gW(Ykb.AX,gmb,6,Glb.gjb.length,15,1);Glb.$jb(this.j,a);this.i[0]=this.j.a.length;this.i[1]=-this.j.a.length;Glb.lkb(this.j,a);this.i[1]+=this.j.a.length;this.i[2]=-this.j.a.length;Glb.xkb(this.j,a);this.i[2]+=this.j.a.length;this.i[4]=-this.j.a.length;Glb.Ikb(this.j,a);this.i[4]+=this.j.a.length;this.i[5]=-this.j.a.length;Glb.ujb(this.j,a);this.i[5]+=this.j.a.length;this.i[3]=-this.j.a.length;Glb.Tkb(this.j,a);this.i[3]+=this.j.a.length;};U1(121,1,{},Glb.Mjb);_.b=0;_.c=0;_.e=false;Ykb.R0=w3(121);Glb.Njb=function Njb(a){return $lb*a*a;};Glb.Ojb=function Ojb(a){return 4000*a*a;};Glb.Pjb=function Pjb(a){return 8000*a*a;};Glb.Qjb=function Qjb(a,b,c){var d,e,f;f=1.02*Glb.bkb(a.f[1],b)+Glb.bkb(a.f[0],b);d=c/f;e=$wnd.Math.pow(d,-6);return d>=1?0:2*(e*e-e);};Glb.Rjb=function Rjb(a,b){var c,d;c=clb.sh(elb.ov(b,a.f[1]),elb.ov(b,a.f[0]));if(a.a.length==2){if(c<1.02*a.a[0]){return Glb.Qjb(a,b.o,c);}else if(c>a.a[1]){return Glb.Ojb((c-a.a[1])/c);}}else {d=a.c==10?Glb.Njb($wnd.Math.abs(a.a[0]-c)/$wnd.Math.max(a.a[0],c)):a.c==5?Glb.Pjb($wnd.Math.abs(a.a[0]-c)/$wnd.Math.max(a.a[0],c)):Glb.Ojb($wnd.Math.abs(a.a[0]-c)/$wnd.Math.max(a.a[0],c));if($wnd.Math.abs(d)>0.009999999776482582)return d;}return 0;};Glb.Sjb=function Sjb(){Glb.ljb.call(this,null);};Glb.Tjb=function Tjb(a,b){Glb.ljb.call(this,a);this.a=gW(Ykb.yX,emb,6,2,15,1);this.a[0]=b;this.a[1]=Unb;this.c=-1;};Glb.Ujb=function Ujb(a,b,c,d,e){Glb.ljb.call(this,a);this.a=gW(Ykb.yX,emb,6,2,15,1);this.a[0]=c;this.a[1]=d;this.b=b;this.c=e;};Glb.Vjb=function Vjb(a,b,c,d){Glb.ljb.call(this,a);this.a=gW(Ykb.yX,emb,6,1,15,1);this.a[0]=c;this.b=b;this.c=d;};Glb.Yjb=function Yjb(a,b){var c,d,e,f;for(c=1;c<b.q;c++){for(d=0;d<c;d++){!a[c][d]&&kW(a[c],d,new Glb.Tjb(Glb._jb(c,d),(f=b.C[c],(f<(elb.Fw(),elb.Ew).length?elb.Ew[f]:2)+(e=b.C[d],e<elb.Ew.length?elb.Ew[e]:2))));}}};Glb.Zjb=function Zjb(a,b,c,d){var e,f,g,h,i,j,k,l,m,n,o;g=gW(Ykb.AX,gmb,6,c.q,15,1);k=gW(Ykb.AX,gmb,6,c.q,15,1);j=gW(Ykb.yX,emb,6,c.q,15,1);k[0]=b;i=0;l=0;while(i<=l){o=k[i];for(m=0;m<c.e[o];m++){h=c.i[o][m];if(g[h]==0&&h!=b){k[++l]=h;g[h]=g[o]+1;if(g[h]==2)j[h]=h<b?a[b][h].a[0]:a[h][b].a[0];else if(g[h]>2){j[h]=j[o]+elb.$u(d,c.k[o][m]);if(h<b&&!a[b][h]){if(g[h]==3){kW(a[b],h,new Glb.Sjb());}else {n=gW(Ykb.AX,gmb,6,2,15,1);n[0]=k[1];n[1]=o;kW(a[b],h,new Glb.Ujb(Glb._jb(b,h),n,(f=c.C[b],(f<(elb.Fw(),elb.Ew).length?elb.Ew[f]:2)+(e=c.C[h],e<elb.Ew.length?elb.Ew[e]:2)),j[h],0));}}}}}++i;}};Glb.$jb=function $jb(a,b){Glb.hjb();var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W;q=new elb._u(b);n=new elb.Su(b,q);W=gW(Ykb.S0,Llb,341,b.q,0,2);for(L=1;L<b.q;L++)W[L]=gW(Ykb.S0,{4:1,5:1,8:1,342:1,341:1},65,L,0,1);for(m=0;m<b.r;m++){g=Glb._jb(b.D[0][m],b.D[1][m]);Glb.fkb(W,g,g,q.a[m],10);}for(j=0;j<b.f;j++){for(M=1;M<b.e[j];M++){v=b.i[j][M];B=b.k[j][M];o=q.a[B];for(R=0;R<M;R++){w=b.i[j][R];C=b.k[j][R];c=M<R?n.a[j][R][M]:n.a[j][M][R];p=q.a[C];F=$wnd.Math.sqrt(o*o+p*p-2*o*p*$wnd.Math.cos(c));T=gW(Ykb.AX,gmb,6,1,15,1);T[0]=j;Glb.fkb(W,Glb._jb(v,w),T,F,5);}}}for(l=0;l<b.r;l++){if(l<b.g&&clb.sr(b.p,l)||(b.F[l]&64)!=0&&(!!b.p&&l<b.g?clb.ir(b.p,l):0)<=5)continue;g=gW(Ykb.AX,gmb,6,2,15,1);for(M=0;M<2;M++)g[M]=b.D[M][l];if(clb.gn(b,g[0])>1&&clb.gn(b,g[1])>1){if(clb.Hk(b,l)==3){F=q.a[l];V=gW(Ykb.AX,gmb,6,2,15,1);for(N=0;N<2;N++){for(R=0;R<clb.gn(b,g[N]);R++){A=clb.xn(b,g[N],R);if(A!=l){F+=q.a[A];V[N]=clb.vn(b,g[N],R);break;}}}T=gW(Ykb.AX,gmb,6,2,15,1);T[0]=g[0];T[1]=g[1];Glb.fkb(W,Glb._jb(V[0],V[1]),T,F,3);}else if(clb.Hk(b,l)==2&&clb.mn(b,g[0])==1&&clb.mn(b,g[1])==1&&(b.F[l]&3)!=3){u=gW(Ykb.AX,Dnb,7,2,0,2);A=gW(Ykb.AX,Dnb,7,2,0,2);t=gW(Ykb.yX,Llb,12,2,0,2);for(N=0;N<2;N++){u[N]=gW(Ykb.AX,gmb,6,clb.gn(b,g[N])-1,15,1);A[N]=gW(Ykb.AX,gmb,6,clb.gn(b,g[N])-1,15,1);t[N]=gW(Ykb.yX,emb,6,clb.gn(b,g[N])-1,15,1);G=-1;for(R=0;R<clb.gn(b,g[N]);R++){if(clb.vn(b,g[N],R)==g[1-N]){G=R;break;}}D=0;for(S=0;S<clb.gn(b,g[N]);S++){if(S!=G){u[N][D]=clb.vn(b,g[N],S);A[N][D]=clb.xn(b,g[N],S);t[N][D]=elb.Ou(n,g[N],G,S);++D;}}}for(O=0;O<u[0].length;O++){for(R=0;R<u[1].length;R++){P=(b.F[l]&3)==1;u[0].length==2&&u[0][O]>u[0][1-O]&&(P=!P);u[1].length==2&&u[1][R]>u[1][1-R]&&(P=!P);Glb.ekb(u[0][O],u[1][R],A[0][O],A[1][R],t[0][O],t[1][R],l,P,q,W,b);}}}else if(clb.Hk(b,l)!=0){U=gW(Ykb.AX,gmb,6,2,15,1);for(N=0;N<2;N++){for(R=0;R<clb.gn(b,g[N]);R++){if(clb.vn(b,g[N],R)==g[1-N]){U[N]=R;break;}}}for(O=0;O<clb.gn(b,g[0]);O++){if(O!=U[0]){for(R=0;R<clb.gn(b,g[1]);R++){R!=U[1]&&(clb.mn(b,g[0])==0&&clb.mn(b,g[1])==0?Glb.gkb(clb.vn(b,g[0],O),clb.vn(b,g[1],R),clb.xn(b,g[0],O),clb.xn(b,g[1],R),elb.Ou(n,g[0],U[0],O),elb.Ou(n,g[1],U[1],R),l,q,W,b):Glb.dkb(clb.vn(b,g[0],O),clb.vn(b,g[1],R),clb.xn(b,g[0],O),clb.xn(b,g[1],R),elb.Ou(n,g[0],U[0],O),elb.Ou(n,g[1],U[1],R),l,q,W,b));}}}}}}for(k=0;k<b.f;k++){if(b.o[k]==2&&b.j[k]==2&&b.n[k][0]==2&&b.n[k][1]==2){h=b.i[k][0];i=b.i[k][1];for(M=0;M<b.e[h];M++){r=b.i[h][M];if(r!=k){for(R=0;R<b.e[i];R++){s=b.i[i][R];if(s!=k){d=elb.Nu(n,h,k,r);e=elb.Nu(n,i,k,s);o=elb.$u(q,b.k[h][M]);p=elb.$u(q,b.k[i][R]);H=elb.$u(q,b.k[k][0])+elb.$u(q,b.k[k][1])-o*$wnd.Math.cos(d)-p*$wnd.Math.cos(e);I=o*$wnd.Math.sin(d);J=p*$wnd.Math.sin(e);T=gW(Ykb.AX,gmb,6,2,15,1);T[0]=h;T[1]=i;Glb.fkb(W,Glb._jb(r,s),T,$wnd.Math.sqrt(H*H+I*I+J*J),3);}}}}}}for(f=0;f<b.q;f++)Glb.Zjb(W,f,b,q);Glb.Yjb(W,b);for(K=1;K<b.q;K++)for(Q=0;Q<K;Q++)W[K][Q].a!=null&&dlb.wi(a,W[K][Q]);};Glb._jb=function _jb(a,b){var c;c=gW(Ykb.AX,gmb,6,2,15,1);if(a>b){c[0]=a;c[1]=b;}else {c[0]=b;c[1]=a;}return c;};Glb.bkb=function bkb(a,b){var c;c=b.C[a];return c<(elb.Fw(),elb.Ew).length?elb.Ew[c]:2;};Glb.ckb=function ckb(a,b){var c,d,e,f,g,h,i,j,k;if(a==null)return b;k=gW(Ykb.AX,gmb,6,a.length+b.length,15,1);j=0;for(e=a,g=0,i=e.length;g<i;++g){c=e[g];k[j++]=c;}for(d=b,f=0,h=d.length;f<h;++f){c=d[f];k[j++]=c;}return k;};Glb.dkb=function dkb(a,b,c,d,e,f,g,h,i,j){var k,l,m,n,o,p,q,r,s,t;if(a==b)return;k=Glb._jb(a,b);if(!!i[k[0]][k[1]]&&i[k[0]][k[1]].a.length==1)return;m=h.a[g]-h.a[c]*$wnd.Math.cos(e)-h.a[d]*$wnd.Math.cos(f);s=h.a[c]*$wnd.Math.sin(e);t=h.a[d]*$wnd.Math.sin(f);n=s+t;o=s-t;q=$wnd.Math.sqrt(m*m+o*o);p=$wnd.Math.sqrt(m*m+n*n);r=gW(Ykb.AX,gmb,6,2,15,1);r[0]=j.D[0][g];r[1]=j.D[1][g];l=i[k[0]][k[1]];if(!l){kW(i[k[0]],k[1],new Glb.Ujb(k,r,q,p,3));}else {l.a[0]=$wnd.Math.min(l.a[0],q);l.a[1]=$wnd.Math.min(l.a[1],p);}};Glb.ekb=function ekb(a,b,c,d,e,f,g,h,i,j,k){var l,m,n;m=i.a[g]-i.a[c]*$wnd.Math.cos(e)-i.a[d]*$wnd.Math.cos(f);n=i.a[c]*$wnd.Math.sin(e);h?n+=i.a[d]*$wnd.Math.sin(f):n-=i.a[d]*$wnd.Math.sin(f);l=gW(Ykb.AX,gmb,6,2,15,1);l[0]=k.D[0][g];l[1]=k.D[1][g];Glb.fkb(j,Glb._jb(a,b),l,$wnd.Math.sqrt(m*m+n*n),3);};Glb.fkb=function fkb(a,b,c,d,e){if(!a[b[0]][b[1]]){kW(a[b[0]],b[1],new Glb.Vjb(b,c,d,e));}else if(a[b[0]][b[1]].a.length==2||a[b[0]][b[1]].c<e){kW(a[b[0]],b[1],new Glb.Vjb(b,c,d,e));}else if(a[b[0]][b[1]].c==e){a[b[0]][b[1]].a[0]=(a[b[0]][b[1]].a[0]+d)/2;a[b[0]][b[1]].b=Glb.ckb(a[b[0]][b[1]].b,c);}};Glb.gkb=function gkb(a,b,c,d,e,f,g,h,i,j){var k,l,m,n,o,p,q,r,s,t,u,v,w,A;if(a==b)return;k=Glb._jb(a,b);if(!!i[k[0]][k[1]]&&i[k[0]][k[1]].a.length==1)return;A=0.866;l=0.5;if((j.F[g]&64)!=0){u=!!j.p&&g<j.g?clb.ir(j.p,g):0;if(u<6){A=0;l=1;}}n=h.a[g]-h.a[c]*$wnd.Math.cos(e)-h.a[d]*$wnd.Math.cos(f);v=h.a[c]*$wnd.Math.sin(e);w=h.a[d]*$wnd.Math.sin(f);o=v+w;p=v-w*l;q=w*A;s=$wnd.Math.sqrt(n*n+p*p+q*q);r=$wnd.Math.sqrt(n*n+o*o);t=gW(Ykb.AX,gmb,6,2,15,1);t[0]=j.D[0][g];t[1]=j.D[1][g];m=i[k[0]][k[1]];if(!m){kW(i[k[0]],k[1],new Glb.Ujb(k,t,s,r,3));}else {m.a[0]=$wnd.Math.min(m.a[0],s);m.a[1]=$wnd.Math.min(m.a[1],r);}};U1(65,43,{43:1,65:1},Glb.Sjb,Glb.Tjb,Glb.Ujb,Glb.Vjb);_.pc=function Wjb(a,b){var c;c=Glb.Rjb(this,a);if(b!=null&&c>0){b[this.f[0]]+=c/2;b[this.f[1]]+=c/2;}return c;};_.qc=function Xjb(a,b){var c,d,e,f,g,h,i;e=elb.qv(a,this.f[1])-elb.qv(a,this.f[0]);f=elb.rv(a,this.f[1])-elb.rv(a,this.f[0]);g=elb.sv(a,this.f[1])-elb.sv(a,this.f[0]);c=$wnd.Math.sqrt(e*e+f*f+g*g);d=0;this.a.length==2?c<this.a[0]?d=(c-this.a[0])/c:c>this.a[1]&&(d=(c-this.a[1])/c):c<this.a[0]?d=(c-this.a[0])/c:c>this.a[0]&&(d=(c-this.a[0])/c);if($wnd.Math.abs(d)<0.001)return false;h=b*d;i=a.o;if(this.c==10){if(clb.gn(i,this.f[0])==1&&clb.gn(i,this.f[1])!=1){clb.mh(elb.ov(a,this.f[0]),e*h,f*h,g*h);return true;}if(clb.gn(i,this.f[0])!=1&&clb.gn(i,this.f[1])==1){clb.mh(elb.ov(a,this.f[1]),-e*h,-f*h,-g*h);return true;}}h/=2;Glb.jjb(a,this.f[0],this.b,e*h,f*h,g*h);Glb.jjb(a,this.f[1],this.b,-e*h,-f*h,-g*h);return true;};_.rc=function akb(){return 0;};_.lb=function hkb(){var a,b;b=new Zkb.L5('distance rule:');Glb.ijb(this,b);this.a.length==1?Zkb.G5(b,(slb.IT(),ktb+slb.JT(this.a[0],5))):Zkb.G5(b,(slb.IT(),' min:'+slb.JT(this.a[0],5)+' max:'+slb.JT(this.a[1],5)));if(this.b!=null){Zkb.G5(b,' not:'+this.b[0]);for(a=1;a<this.b.length;a++)Zkb.G5(b,','+this.b[a]);}return b.a;};_.c=0;Ykb.S0=w3(65);Glb.ikb=function ikb(a,b){var c,d,e;Glb.ljb.call(this,a);c=0;for(e=0;e<a.length;e++)clb.wn(b,a[e])!=1&&++c;if(c>2){this.a=gW(Ykb.AX,gmb,6,c,15,1);c=0;for(d=0;d<a.length;d++)clb.wn(b,a[d])!=1&&(this.a[c++]=a[d]);}else {this.a=a;}};Glb.lkb=function lkb(a,b){Glb.hjb();var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v;r=gW(Ykb.Z0,Amb,6,b.g,16,1);v=(clb.Gt(b,7),b.p);q=gW(Ykb.Z0,Amb,6,v.i.a.length,16,1);clb.dr(v,q,gW(Ykb.Z0,Amb,6,v.i.a.length,16,1),gW(Ykb.AX,gmb,6,v.i.a.length,15,1),true);for(u=0;u<v.i.a.length;u++)if(q[u])for(p=0;p<dlb.Bi(v.j,u).length;p++)r[dlb.Bi(v.j,u)[p]]=true;e=gW(Ykb.AX,gmb,6,2,15,1);for(g=0;g<b.g;g++){i=b.D[0][g];j=b.D[1][g];e[0]=b.C[i];e[1]=b.C[j];r[g]=r[g]|(g<b.g&&clb.sr(b.p,g)||clb.Hk(b,g)==2&&e[0]<=8&&e[1]<=8&&b.o[i]==1&&b.o[j]==1&&b.e[i]>1&&b.e[j]>1);if(!r[g]){if(clb.Hk(b,g)==1){for(o=0;o<2;o++){if((e[o]==7||e[o]==8)&&e[1-o]==6){k=b.D[1-o][g];for(t=0;t<b.j[k];t++){if(b.n[k][t]==2){l=b.i[k][t];if(b.C[l]==7||b.C[l]==8||b.C[l]==16){r[g]=true;break;}}}}}}}}s=gW(Ykb.Z0,Amb,6,b.f,16,1);for(h=0;h<b.g;h++){if(r[h]){s[b.D[0][h]]=true;s[b.D[1][h]]=true;}}n=gW(Ykb.AX,gmb,6,b.q,15,1);for(f=0;f<b.g;f++){if(r[f]){n[0]=b.D[0][f];m=Glb.mkb(n,r,b);d=gW(Ykb.AX,gmb,6,m,15,1);for(o=0;o<m;o++)d[o]=n[o];dlb.wi(a,new Glb.ikb(d,b));}}for(c=0;c<b.f;c++){if(!s[c]){if(b.C[c]==5&&b.s[c]==0&&b.e[c]<=3||b.C[c]<=8&&b.o[c]==1&&b.e[c]>1||clb.so(b,c,true)&&b.o[c]!=2&&b.e[c]>1){d=gW(Ykb.AX,gmb,6,1+b.e[c],15,1);for(o=0;o<b.e[c];o++)d[o]=b.i[c][o];d[b.e[c]]=c;dlb.wi(a,new Glb.ikb(d,b));}}}};Glb.mkb=function mkb(a,b,c){var d,e,f,g,h,i,j,k,l;k=gW(Ykb.Z0,Amb,6,c.q,16,1);k[a[0]]=true;g=0;h=0;while(g<=h&&clb.mn(c,a[g])<2){for(j=0;j<clb.wn(c,a[g]);j++){d=clb.vn(c,a[g],j);e=clb.xn(c,a[g],j);if(b[e]){if(!k[d]){a[++h]=d;k[d]=true;}b[e]=false;}}++g;}for(i=h;i>=0;i--){if(clb.uk(c,a[i])<=8){for(l=0;l<clb.gn(c,a[i]);l++){f=clb.vn(c,a[i],l);if(!k[f]&&clb.yn(c,a[i],l)!=0){a[++h]=f;k[f]=true;}}}}return h+1;};U1(189,43,mtb,Glb.ikb);_.pc=function jkb(a,b){var c,d,e,f,g,h,i;c=new clb.Ch();g=new clb.Ch();d=eW(Ykb.yX,[Llb,emb],[12,6],15,[this.f.length,3],2);Glb.mjb(a,this.f,c,g,d);i=0;for(f=0;f<this.f.length;f++){e=-(g.a*d[f][0]+g.b*d[f][1]+g.c*d[f][2]);h=20*e*e;b!=null&&(b[this.f[f]]+=h);i+=h;}return i;};_.qc=function kkb(a,b){var c,d,e,f,g;c=new clb.Ch();g=new clb.Ch();d=eW(Ykb.yX,[Llb,emb],[12,6],15,[this.a.length,3],2);Glb.mjb(a,this.a,c,g,d);for(f=0;f<this.f.length;f++){e=-(g.a*(elb.qv(a,this.f[f])-c.a)+g.b*(elb.rv(a,this.f[f])-c.b)+g.c*(elb.sv(a,this.f[f])-c.c));Glb.jjb(a,this.f[f],this.f,0.5*e*b*g.a,0.5*e*b*g.b,0.5*e*b*g.c);}return true;};_.rc=function nkb(){return 1;};_.lb=function okb(){var a;a=new Zkb.L5('plane rule:');Glb.ijb(this,a);return a.a;};Ykb.T0=w3(189);Glb.pkb=function pkb(a,b){var c,d,e;if(a.a!=null)return;a.a=gW(Ykb.yX,emb,6,a.o.q,15,1);a.d=gW(Ykb.yX,emb,6,(Glb.hjb(),Glb.gjb).length,15,1);for(e=new dlb.Obb(b);e.a<e.c.a.length;){d=dlb.Nbb(e);d.g&&(a.d[d.rc()]+=d.pc(a,a.a));}a.e=0;for(c=0;c<a.o.q;c++)a.e+=a.a[c];a.c=-1;};Glb.qkb=function qkb(a,b){a.e=b.e;a.c=b.c;a.b=b.b;a.a=b.a==null?null:dlb.Tbb(b.a,b.a.length);a.d=b.d==null?null:dlb.Tbb(b.d,b.d.length);};Glb.rkb=function rkb(a){a.e=Unb;a.a=null;a.d=null;};Glb.skb=function skb(a){elb.Bv.call(this,a);this.e=NaN;};Glb.tkb=function tkb(a){elb.Cv.call(this,a);Glb.qkb(this,a);};U1(84,58,{58:1,27:1,84:1},Glb.skb,Glb.tkb);_.b=false;_.c=0;_.e=0;Ykb.U0=w3(84);Glb.ukb=function ukb(a){Glb.ljb.call(this,a);};Glb.xkb=function xkb(a,b){Glb.hjb();var c,d,e,f;d=gW(Ykb.Z0,Amb,6,b.q,16,1);for(c=0;c<b.f;c++){if(!d[c]&&b.o[c]==2&&b.C[c]<=8){e=Glb.ykb(c,b);for(f=0;f<e.length;f++)d[e[f]]=true;e[0]!=e[e.length-1]&&dlb.wi(a,new Glb.ukb(e));}}};Glb.ykb=function ykb(a,b){var c,d,e,f,g,h,i,j;f=a;d=b.i[f][0];while(b.e[f]!=1&&b.o[f]==2){j=d;d=f;f=b.i[f][0]==j?b.i[f][1]:b.i[f][0];if(f==a)break;}i=f;g=d;e=2;while(b.e[g]!=1&&b.o[g]==2){j=i;i=g;g=b.i[g][0]==j?b.i[g][1]:b.i[g][0];++e;if(g==f)break;}c=gW(Ykb.AX,gmb,6,e,15,1);c[0]=f;c[1]=d;for(h=2;h<e;h++)c[h]=clb.vn(b,c[h-1],0)==c[h-2]?clb.vn(b,c[h-1],1):clb.vn(b,c[h-1],0);return c;};U1(269,43,mtb,Glb.ukb);_.pc=function vkb(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B;f=gW(Ykb.yX,emb,6,3,15,1);for(k=0;k<this.f.length;k++){f[0]+=elb.qv(a,this.f[k]);f[1]+=elb.rv(a,this.f[k]);f[2]+=elb.sv(a,this.f[k]);}for(q=0;q<3;q++)f[q]/=this.f.length;c=eW(Ykb.yX,[Llb,emb],[12,6],15,[this.f.length,3],2);for(l=0;l<this.f.length;l++){c[l][0]=elb.qv(a,this.f[l])-f[0];c[l][1]=elb.rv(a,this.f[l])-f[1];c[l][2]=elb.sv(a,this.f[l])-f[2];}v=eW(Ykb.yX,[Llb,emb],[12,6],15,[3,3],2);for(m=0;m<this.f.length;m++)for(p=0;p<3;p++)for(r=0;r<3;r++)v[p][r]+=c[m][p]*c[m][r];A=new blb.Nc(v);d=A.e;t=0;for(n=1;n<3;n++)d[n]>d[t]&&(t=n);e=A.a;u=gW(Ykb.yX,emb,6,3,15,1);for(o=0;o<3;o++)u[o]=e[o][t];B=0;for(j=0;j<this.f.length;j++){s=u[0]*c[j][0]+u[1]*c[j][1]+u[2]*c[j][2];g=s*u[0]-c[j][0];h=s*u[1]-c[j][1];i=s*u[2]-c[j][2];w=10*g*g+h*h+i*i;b!=null&&(b[this.f[j]]+=w);B+=w;}return B;};_.qc=function wkb(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A;f=gW(Ykb.yX,emb,6,3,15,1);for(h=0;h<this.f.length;h++){f[0]+=elb.qv(a,this.f[h]);f[1]+=elb.rv(a,this.f[h]);f[2]+=elb.sv(a,this.f[h]);}for(r=0;r<3;r++)f[r]/=this.f.length;c=eW(Ykb.yX,[Llb,emb],[12,6],15,[this.f.length,3],2);for(i=0;i<this.f.length;i++){c[i][0]=elb.qv(a,this.f[i])-f[0];c[i][1]=elb.rv(a,this.f[i])-f[1];c[i][2]=elb.sv(a,this.f[i])-f[2];}w=eW(Ykb.yX,[Llb,emb],[12,6],15,[3,3],2);for(j=0;j<this.f.length;j++)for(q=0;q<3;q++)for(s=0;s<3;s++)w[q][s]+=c[j][q]*c[j][s];A=new blb.Nc(w);d=A.e;u=0;for(k=1;k<3;k++)d[k]>d[u]&&(u=k);e=A.a;v=gW(Ykb.yX,emb,6,3,15,1);for(l=0;l<3;l++)v[l]=e[l][u];t=gW(Ykb.yX,emb,6,this.f.length,15,1);for(m=0;m<this.f.length;m++)t[m]=v[0]*c[m][0]+v[1]*c[m][1]+v[2]*c[m][2];if(b==1){o=false;p=t[0]<t[1];for(n=2;n<this.f.length;n++){if(p!=t[n-1]<t[n]){o=true;break;}}if(o)return false;}for(g=0;g<this.f.length;g++){clb.mh(elb.ov(a,this.f[g]),b*(t[g]*v[0]-c[g][0]),b*(t[g]*v[1]-c[g][1]),b*(t[g]*v[2]-c[g][2]));}return true;};_.rc=function zkb(){return 2;};_.lb=function Akb(){var a;a=new Zkb.L5('line rule:');Glb.ijb(this,a);return a.a;};Ykb.V0=w3(269);Glb.Bkb=function Bkb(a,b,c,d){var e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D,F,G,H,I,J,K,L,M,N,O,P;P=c[4];I=c[3]==-1?3:4;l=gW(Ykb.AX,gmb,6,b.q,15,1);C=gW(Ykb.Z0,Amb,6,b.r,16,1);for(o=0;o<I;o++)C[d[o]]=true;k=clb.Fn(b,l,C,false);m=gW(Ykb.AX,gmb,6,k,15,1);for(g=l,h=0,i=g.length;h<i;++h){j=g[h];++m[j];}F=0;u=gW(Ykb.Z0,Amb,6,k,16,1);for(p=0;p<I;p++){j=l[c[p]];if(!u[j]){u[j]=true;++F;}}G=gW(Ykb.AX,gmb,6,F,15,1);H=gW(Ykb.AX,gmb,6,F,15,1);D=gW(Ykb.AX,gmb,6,F,15,1);t=0;for(f=0;f<k;f++){if(u[f]){G[t]=f;H[t]=m[f];for(q=0;q<I;q++)f==l[c[q]]&&++D[t];++t;}}v=gW(Ykb.Z0,Amb,6,b.q,16,1);K=0;if(F==I){B=-1;for(q=0;q<I-2;q++){M=-1;N=Qlb;for(A=0;A<F;A++){if(A!=B&&H[A]<N){M=A;N=H[A];}}for(e=0;e<b.q;e++){if(l[e]==G[M]){v[e]=true;++K;}}B=M;}}else {for(q=0;q<G.length;q++){if(D[q]==1&&I==3){w=2*H[q]<b.q;for(e=0;e<b.q;e++){if(e!=P){if(l[e]==G[q]==w){v[e]=true;++K;}}}break;}if(D[q]==2&&I==4){w=2*H[q]<b.q;for(e=0;e<b.q;e++){if(e!=P){if(l[e]==G[q]==w){v[e]=true;++K;}}}break;}}}if(K==0){for(q=0;q<G.length;q++){if(D[q]==1){for(e=0;e<b.q;e++){if(l[e]==G[q]){v[e]=true;++K;}}break;}}J=I-2-(K==0?0:1);for(r=0;r<J;r++){for(A=0;A<I;A++){if(!v[c[A]]){v[c[A]]=true;++K;break;}}}}t=0;a.a=gW(Ykb.AX,gmb,6,K,15,1);for(s=0;s<v.length;s++)v[s]&&(a.a[t++]=s);O=0;L=0;a.c=gW(Ykb.AX,gmb,6,2,15,1);a.b=gW(Ykb.AX,gmb,6,c[3]==-1?1:2,15,1);for(n=0;n<I;n++)v[c[n]]?a.b[L++]=c[n]:a.c[O++]=c[n];};Glb.Ckb=function Ckb(a,b){var c,d,e,f,g;g=new clb.Ch();for(d=a.c,e=0,f=d.length;e<f;++e){c=d[e];clb.nh(g,b.k[c]);}clb.wh(g,0.5);clb.Bh(clb.zh(g,elb.ov(b,a.f[4])));return g;};Glb.Dkb=function Dkb(a,b){var c,d,e;c=eW(Ykb.yX,[Llb,emb],[12,6],15,[2,3],2);for(d=0;d<2;d++){c[d][0]=elb.qv(b,a.f[d])-elb.qv(b,a.f[4]);c[d][1]=elb.rv(b,a.f[d])-elb.rv(b,a.f[4]);c[d][2]=elb.sv(b,a.f[d])-elb.sv(b,a.f[4]);}e=gW(Ykb.yX,emb,6,3,15,1);e[0]=c[0][1]*c[1][2]-c[0][2]*c[1][1];e[1]=c[0][2]*c[1][0]-c[0][0]*c[1][2];e[2]=c[0][0]*c[1][1]-c[0][1]*c[1][0];return e;};Glb.Ekb=function Ekb(a,b,c,d){var e;e=gW(Ykb.yX,emb,6,3,15,1);e[0]=a.k[d].a-a.k[c].a;e[1]=a.k[d].b-a.k[c].b;e[2]=a.k[d].c-a.k[c].c;return e[0]*b[0]+e[1]*b[1]+e[2]*b[2]>0;};Glb.Fkb=function Fkb(a,b,c){Glb.ljb.call(this,b);Glb.Bkb(this,a,b,c);};Glb.Ikb=function Ikb(a,b){Glb.hjb();var c,d,e,f,g,h,i,j,k,l;for(c=0;c<b.f;c++){if(b.e[c]>=3){k=b.u[c]&3;if((k==1||k==2)&&!(b.o[c]==2&&b.j[c]==2&&b.n[c][0]==2&&b.n[c][1]==2&&b.C[c]<=7)){d=gW(Ykb.AX,gmb,6,5,15,1);e=gW(Ykb.AX,gmb,6,4,15,1);for(h=0;h<b.e[c];h++){f=b.i[c][h];g=b.k[c][h];i=0;while(i<h&&f>d[i])++i;for(j=h-1;j>=i;j--){d[j+1]=d[j];e[j+1]=e[j];}d[i]=f;e[i]=g;}if(b.e[c]==3){d[3]=-1;e[3]=-1;}d[4]=c;if(k==1){l=d[1];d[1]=d[0];d[0]=l;l=e[1];e[1]=e[0];e[0]=l;}dlb.wi(a,new Glb.Fkb(b,d,e));}}}};U1(270,43,mtb,Glb.Fkb);_.pc=function Gkb(a,b){var c,d,e,f,g;f=0;d=Glb.Dkb(this,a);g=0;if(this.f[3]==-1){Glb.Ekb(a,d,this.f[4],this.f[2])||++g;}else {Glb.Ekb(a,d,this.f[4],this.f[2])||++g;Glb.Ekb(a,d,this.f[4],this.f[3])&&++g;}if(g!=0){for(c=0;c<this.f.length;c++){if(this.f[c]!=-1){e=0.68*g;b!=null&&(b[this.f[c]]+=e);f+=e;}}}return f;};_.qc=function Hkb(a,b){var c,d,e,f,g,h,i;h=Glb.Dkb(this,a);g=this.f[3]==-1&&!Glb.Ekb(a,h,this.f[4],this.f[2])||this.f[3]!=-1&&!Glb.Ekb(a,h,this.f[4],this.f[2])&&Glb.Ekb(a,h,this.f[4],this.f[3]);if(!g)return false;i=Glb.Ckb(this,a);for(d=this.a,e=0,f=d.length;e<f;++e){c=d[e];Glb.njb(a,c,elb.ov(a,this.f[4]),i,Fmb);}return true;};_.rc=function Jkb(){return 4;};_.lb=function Kkb(){var a,b,c,d,e;e=new Zkb.L5('stereo rule:');Glb.ijb(this,e);e.a+=' rotatable:';for(b=this.b,c=0,d=b.length;c<d;++c){a=b[c];e.a+=a+' ';}return e.a;};Ykb.W0=w3(270);Glb.Lkb=function Lkb(a,b){var c,d,e,f,g;e=-1;f=Unb;for(d=0;d<a.e.length;d++){g=Fmb*a.e[d]/180;c=$wnd.Math.abs(b-g);c>Fmb&&(c=Emb-c);c/=10+$wnd.Math.sqrt(a.b[d]);if(f>c){f=c;e=d;}}return e;};Glb.Mkb=function Mkb(a,b,c){var d,e,f,g;e=a.c[c][0]*Fmb/180;f=a.c[c][1]*Fmb/180;g=a.e[c]*Fmb/180;b<g-Fmb?b+=Emb:b>g+Fmb&&(b-=Emb);d=(g-b)/(g-(b<g?e:f));if(d<1)return 0;if(d<2){d-=1;return d*d;}return 1;};Glb.Nkb=function Nkb(a,b,c,d,e){var f,g,h;Glb.njb(a,b,a.k[c],d,e);h=a.o;for(g=0;g<h.e[b];g++){f=h.i[b][g];h.e[f]==1&&Glb.njb(a,f,a.k[c],d,e);}};Glb.Okb=function Okb(a,b,c,d,e,f){Glb.ljb.call(this,d);this.e=a;this.b=b;this.c=c;this.a=e;this.d=f;};Glb.Pkb=function Pkb(a,b,c,d,e){var f,g,h,i,j,k,l,m;f=gW(Ykb.AX,gmb,6,d,15,1);m=gW(Ykb.AX,gmb,6,4,15,1);m[0]=clb.vn(a,c,a.i[c][0]==b?1:0);m[1]=c;m[2]=b;m[3]=clb.vn(a,b,a.i[b][0]==c?1:0);i=0;for(j=0;j<a.e[b];j++){g=a.i[b][j];g!=c&&(f[i++]=g);}l=gW(Ykb.Y0,znb,6,3,15,1);h=gW(Ykb.Y0,znb,6,3,15,1);k=eW(Ykb.Y0,[apb,znb],[13,6],15,[3,2],2);l[0]=60;l[1]=180;l[2]=300;h[0]=33;h[1]=33;h[2]=33;k[0][0]=45;k[0][1]=75;k[1][0]=165;k[1][1]=195;k[2][0]=285;k[2][1]=315;dlb.wi(e,new Glb.Okb(l,h,k,m,f,1));};Glb.Qkb=function Qkb(a,b,c,d,e){var f,g,h,i,j,k,l,m,n,o,p;l=-1;for(k=0;k<a.j[c];k++)a.n[c][k]==2&&(l=a.i[c][k]);f=gW(Ykb.AX,gmb,6,d,15,1);p=gW(Ykb.AX,gmb,6,4,15,1);p[0]=l;p[1]=c;p[2]=b;i=0;for(j=0;j<a.e[b];j++){g=a.i[b][j];if(a.C[g]==1){i==0&&(p[3]=g);f[i++]=g;}}n=!(c<a.f&&clb.rr(a.p,c))&&d==1?1:2;o=gW(Ykb.Y0,znb,6,n,15,1);h=gW(Ykb.Y0,znb,6,n,15,1);m=eW(Ykb.Y0,[apb,znb],[13,6],15,[n,2],2);if(!(c<a.f&&clb.rr(a.p,c))&&d==1){o[0]=0;h[0]=100;m[0][0]=-15;m[0][1]=15;}else {o[0]=0;o[1]=180;h[0]=50;h[1]=50;m[0][0]=-15;m[0][1]=15;m[1][0]=165;m[1][1]=195;}dlb.wi(e,new Glb.Okb(o,h,m,p,f,1));};Glb.Tkb=function Tkb(a,b){Glb.hjb();var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,A,B,C,D;elb.Tv();o=gW(Ykb.Z0,Amb,6,b.r,16,1);elb.Ov(b,o);for(g=0;g<b.g;g++){if(o[g]){B=gW(Ykb.AX,gmb,6,4,15,1);C=new elb.tw();D=elb.Qv(b,g,B,C);if(D!=null&&!Glb.Ukb(B,a)){A=(v=elb.Gv(elb.Fv,D),!v?null:elb.uw(v));j=(w=elb.Gv(elb.Fv,D),!w?null:elb.vw(w));r=(u=elb.Gv(elb.Fv,D),!u?null:elb.ww(u));if(A==null){q=new elb.Cw(b,B);A=q.b;j=q.a;r=q.c;}if(A!=null){d=null;t=0;if((b.F[g]&64)==0){n=eW(Ykb.Z0,[Llb,Amb],[11,6],16,[2,b.q],2);i=gW(Ykb.AX,gmb,6,2,15,1);for(l=0;l<2;l++)i[l]=clb.bo(b,C.e[l],C.b[l],n[l],null,null);t=i[0]<i[1]?0:1;d=gW(Ykb.AX,gmb,6,i[t],15,1);m=0;for(c=0;c<b.q;c++)n[t][c]&&(d[m++]=c);}dlb.wi(a,new Glb.Okb(A,j,r,B,d,t));}}}}for(f=0;f<b.g;f++){if(b.H[f]==1&&(b.F[f]&64)==0){for(l=0;l<2;l++){h=b.D[l][f];p=clb.On(b,h);k=b.e[h]-p;if(p==1&&k!=0){s=b.D[1-l][f];e=b.C[h];e>6&&b.o[s]==1?Glb.Qkb(b,h,s,k,a):b.o[s]!=2&&b.e[s]>1&&Glb.Pkb(b,h,s,k,a);break;}}}}};Glb.Ukb=function Ukb(a,b){var c,d,e,f,g,h,i,j,k,l,m,n;for(j=new dlb.Obb(b);j.a<j.c.a.length;){i=dlb.Nbb(j);if(i.rc()==1){h=i.f;for(l=a,m=0,n=l.length;m<n;++m){k=l[m];if(k==-1)return false;c=false;for(e=h,f=0,g=e.length;f<g;++f){d=e[f];if(k==d){c=true;break;}}if(!c)return false;}return true;}}return false;};U1(150,43,mtb,Glb.Okb);_.pc=function Rkb(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o;c=elb.Lv(a,this.f);if(isNaN(c))return 0;c<0&&(c+=Emb);n=180*c/Fmb;g=Glb.Lkb(this,c);if(g==-1){Zkb.O5();for(k=this.e,l=0,m=k.length;l<m;++l){}}i=Glb.Mkb(this,c,g);if(i==0)return 0;d=$wnd.Math.abs(n-this.e[g]);d>180&&(d=360-d);d>60&&(d=60);h=a.o;j=3*i*d*d/3600;o=0;for(f=0;f<clb.gn(h,this.f[1]);f++){if(clb.vn(h,this.f[1],f)!=this.f[2]){b!=null&&(b[clb.vn(h,this.f[1],f)]+=j);o+=j;}}for(e=0;e<clb.gn(h,this.f[2]);e++){if(clb.vn(h,this.f[2],e)!=this.f[1]){b!=null&&(b[clb.vn(h,this.f[2],e)]+=j);o+=j;}}return o;};_.qc=function Skb(a,b){var c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u;i=elb.Lv(a,this.f);if(isNaN(i))return false;i<0&&(i+=Emb);m=Glb.Lkb(this,i);t=Glb.Mkb(this,i,m);if(t==0)return false;g=Fmb*this.e[m]/180-i;$wnd.Math.abs(g)>Fmb&&(g=g<0?Emb+g:g-Emb);if($wnd.Math.abs(g)<0.0031415926535897933)return false;u=clb.Ah(elb.ov(a,this.f[2]),elb.ov(a,this.f[1]));clb.Bh(u);g*=b*t;q=a.o;if(this.a!=null){r=this.d==0?-g:g;for(d=this.a,e=0,f=d.length;e<f;++e){c=d[e];Glb.njb(a,c,elb.ov(a,this.f[1]),u,r);}}else {h=clb.tn(q,this.f[1],this.f[2]);n=h!=-1&&(!!q.p&&h<q.g?clb.ir(q.p,h):0)<=5;for(l=1;l<=2;l++){j=(l==1?-2:2)*clb.on(q,this.f[l]);for(o=0;o<clb.gn(q,this.f[l]);o++){k=clb.vn(q,this.f[l],o);if(k!=this.f[3-l]){Glb.Nkb(a,k,this.f[l],u,g/j);if(!n){for(p=0;p<q.j[k];p++){s=q.i[k][p];s!=k&&q.e[s]!=1&&Glb.Nkb(a,s,this.f[l],u,g/(4*j));}}}}}}return true;};_.rc=function Vkb(){return 3;};_.lb=function Wkb(){var a,b;b=new Zkb.L5('torsion rule:');Glb.ijb(this,b);b.a+=' torsions:';for(a=0;a<this.e.length;a++){a!=0&&(b.a+=',',b);Zkb.G5(b,this.e[a]+'('+this.b[a]+')');}return b.a;};_.d=0;Ykb.X0=w3(150);Ykb.xX=y3('C');Ykb.Y0=y3('S');Ykb.wX=y3('B');Ykb.AX=y3('I');Ykb.Z0=y3('Z');Ykb.yX=y3('D');Ykb.zX=y3('F');Ykb.BX=y3('J');_=$1('OCL.CanonizerUtil',qlb.dG);_.BACKBONE=qlb.$F;_.NORMAL=qlb._F;_.NOSTEREO=qlb.aG;_.NOSTEREO_TAUTOMER=qlb.bG;_.TAUTOMER=qlb.cG;_.getIDCode=qlb.eG;_=$1('OCL.ConformerGenerator',qlb.jG);_.STRATEGY_ADAPTIVE_RANDOM=qlb.fG;_.STRATEGY_LIKELY_RANDOM=qlb.gG;_.STRATEGY_LIKELY_SYSTEMATIC=qlb.hG;_.STRATEGY_PURE_RANDOM=qlb.iG;_=$1('OCL.DrugScoreCalculator',qlb.rG);_.calculate=qlb.sG;qlb.vG();_=$1('OCL.DruglikenessPredictor',qlb.wG);_.DRUGLIKENESS_UNKNOWN=qlb.tG;_=$1('OCL.ForceFieldMMFF94',qlb.HG);_.MMFF94=qlb.BG;_.MMFF94S=qlb.CG;_.MMFF94SPLUS=qlb.DG;rlb.bM();_=$1('OCL.Molecule',rlb.eM);_.CANONIZER_ASSIGN_PARITIES_TO_TETRAHEDRAL_N=rlb.CH;_.CANONIZER_CONSIDER_DIASTEREOTOPICITY=rlb.DH;_.CANONIZER_CONSIDER_ENANTIOTOPICITY=rlb.EH;_.CANONIZER_CONSIDER_STEREOHETEROTOPICITY=rlb.FH;_.CANONIZER_COORDS_ARE_3D=rlb.GH;_.CANONIZER_CREATE_PSEUDO_STEREO_GROUPS=rlb.HH;_.CANONIZER_CREATE_SYMMETRY_RANK=rlb.IH;_.CANONIZER_DISTINGUISH_RACEMIC_OR_GROUPS=rlb.JH;_.CANONIZER_ENCODE_ATOM_CUSTOM_LABELS=rlb.KH;_.CANONIZER_ENCODE_ATOM_CUSTOM_LABELS_WITHOUT_RANKING=rlb.LH;_.CANONIZER_ENCODE_ATOM_SELECTION=rlb.MH;_.CANONIZER_NEGLECT_ANY_STEREO_INFORMATION=rlb.NH;_.CANONIZER_TIE_BREAK_FREE_VALENCE_ATOMS=rlb.OH;_.FISCHER_PROJECTION_LIMIT=rlb.PH;_.FISCHER_PROJECTION_RING_LIMIT=rlb.QH;_.STEREO_ANGLE_LIMIT=rlb.RH;_.VALIDATION_ERRORS_STEREO=rlb.SH;_.VALIDATION_ERROR_AMBIGUOUS_CONFIGURATION=rlb.TH;_.VALIDATION_ERROR_ESR_CENTER_UNKNOWN=rlb.UH;_.VALIDATION_ERROR_OVER_UNDER_SPECIFIED=rlb.VH;_.cAtomCIPParityNone=rlb.WH;_.cAtomCIPParityProblem=rlb.XH;_.cAtomCIPParityRorM=rlb.YH;_.cAtomCIPParitySorP=rlb.ZH;_.cAtomColorBlue=rlb._H;_.cAtomColorDarkGreen=rlb.aI;_.cAtomColorDarkRed=rlb.bI;_.cAtomColorGreen=rlb.cI;_.cAtomColorMagenta=rlb.dI;_.cAtomColorNone=rlb.eI;_.cAtomColorOrange=rlb.fI;_.cAtomColorRed=rlb.gI;_.cAtomLabel=rlb.hI;_.cAtomParity1=rlb.iI;_.cAtomParity2=rlb.jI;_.cAtomParityIsPseudo=rlb.kI;_.cAtomParityNone=rlb.lI;_.cAtomParityUnknown=rlb.mI;_.cAtomQFAny=rlb.nI;_.cAtomQFAromState=rlb.oI;_.cAtomQFAromStateBits=rlb.pI;_.cAtomQFAromStateShift=rlb.qI;_.cAtomQFAromatic=rlb.rI;_.cAtomQFCharge=rlb.sI;_.cAtomQFChargeBits=rlb.tI;_.cAtomQFChargeShift=rlb.uI;_.cAtomQFENeighbourBits=rlb.vI;_.cAtomQFENeighbourShift=rlb.wI;_.cAtomQFENeighbours=rlb.xI;_.cAtomQFExcludeGroup=rlb.yI;_.cAtomQFFlatNitrogen=rlb.zI;_.cAtomQFHeteroAromatic=rlb.AI;_.cAtomQFHydrogen=rlb.BI;_.cAtomQFHydrogenBits=rlb.CI;_.cAtomQFHydrogenShift=rlb.DI;_.cAtomQFIsNotStereo=rlb.EI;_.cAtomQFIsStereo=rlb.FI;_.cAtomQFMatchStereo=rlb.GI;_.cAtomQFMoreNeighbours=rlb.HI;_.cAtomQFNarrowing=rlb.II;_.cAtomQFNeighbourBits=rlb.JI;_.cAtomQFNeighbourShift=rlb.KI;_.cAtomQFNeighbours=rlb.LI;_.cAtomQFNewRingSize=rlb.MI;_.cAtomQFNewRingSizeBits=rlb.NI;_.cAtomQFNewRingSizeShift=rlb.OI;_.cAtomQFNoMoreNeighbours=rlb.QI;_.cAtomQFNoOfBits=rlb.RI;_.cAtomQFNot0ENeighbours=rlb.SI;_.cAtomQFNot0Hydrogen=rlb.TI;_.cAtomQFNot0Neighbours=rlb.UI;_.cAtomQFNot0PiElectrons=rlb.VI;_.cAtomQFNot1ENeighbour=rlb.WI;_.cAtomQFNot1Hydrogen=rlb.XI;_.cAtomQFNot1Neighbour=rlb.YI;_.cAtomQFNot1PiElectron=rlb.ZI;_.cAtomQFNot2ENeighbours=rlb.$I;_.cAtomQFNot2Hydrogen=rlb._I;_.cAtomQFNot2Neighbours=rlb.aJ;_.cAtomQFNot2PiElectrons=rlb.bJ;_.cAtomQFNot2RingBonds=rlb.cJ;_.cAtomQFNot3ENeighbours=rlb.dJ;_.cAtomQFNot3Hydrogen=rlb.eJ;_.cAtomQFNot3Neighbours=rlb.fJ;_.cAtomQFNot3RingBonds=rlb.gJ;_.cAtomQFNot4ENeighbours=rlb.hJ;_.cAtomQFNot4Neighbours=rlb.iJ;_.cAtomQFNot4RingBonds=rlb.jJ;_.cAtomQFNotAromatic=rlb.kJ;_.cAtomQFNotChain=rlb.lJ;_.cAtomQFNotCharge0=rlb.mJ;_.cAtomQFNotChargeNeg=rlb.nJ;_.cAtomQFNotChargePos=rlb.oJ;_.cAtomQFPiElectronBits=rlb.pJ;_.cAtomQFPiElectronShift=rlb.qJ;_.cAtomQFPiElectrons=rlb.rJ;_.cAtomQFRingSize0=rlb.sJ;_.cAtomQFRingSize3=rlb.tJ;_.cAtomQFRingSize4=rlb.uJ;_.cAtomQFRingSize5=rlb.vJ;_.cAtomQFRingSize6=rlb.wJ;_.cAtomQFRingSize7=rlb.xJ;_.cAtomQFRingSizeLarge=rlb.yJ;_.cAtomQFRingState=rlb.zJ;_.cAtomQFRingStateBits=rlb.AJ;_.cAtomQFRingStateShift=rlb.BJ;_.cAtomQFRxnParityBits=rlb.CJ;_.cAtomQFRxnParityHint=rlb.DJ;_.cAtomQFRxnParityInvert=rlb.EJ;_.cAtomQFRxnParityRacemize=rlb.FJ;_.cAtomQFRxnParityRetain=rlb.GJ;_.cAtomQFRxnParityShift=rlb.HJ;_.cAtomQFSimpleFeatures=rlb.IJ;_.cAtomQFSmallRingSize=rlb.JJ;_.cAtomQFSmallRingSizeBits=rlb.KJ;_.cAtomQFSmallRingSizeShift=rlb.LJ;_.cAtomQFStereoState=rlb.MJ;_.cAtomQFStereoStateBits=rlb.NJ;_.cAtomQFStereoStateShift=rlb.OJ;_.cAtomRadicalState=rlb.PJ;_.cAtomRadicalStateD=rlb.QJ;_.cAtomRadicalStateNone=rlb.RJ;_.cAtomRadicalStateS=rlb.SJ;_.cAtomRadicalStateShift=rlb.TJ;_.cAtomRadicalStateT=rlb.UJ;_.cAtomValence=rlb.VJ;_.cBondCIPParityEorP=rlb.WJ;_.cBondCIPParityNone=rlb.XJ;_.cBondCIPParityProblem=rlb.YJ;_.cBondCIPParityZorM=rlb.ZJ;_.cBondParityEor1=rlb.$J;_.cBondParityNone=rlb._J;_.cBondParityUnknown=rlb.aK;_.cBondParityZor2=rlb.bK;_.cBondQFAllFeatures=rlb.cK;_.cBondQFAromState=rlb.dK;_.cBondQFAromStateBits=rlb.eK;_.cBondQFAromStateShift=rlb.fK;_.cBondQFAromatic=rlb.gK;_.cBondQFBondTypes=rlb.hK;_.cBondQFBondTypesBits=rlb.iK;_.cBondQFBondTypesShift=rlb.jK;_.cBondQFBridge=rlb.kK;_.cBondQFBridgeBits=rlb.lK;_.cBondQFBridgeMin=rlb.mK;_.cBondQFBridgeMinBits=rlb.nK;_.cBondQFBridgeMinShift=rlb.oK;_.cBondQFBridgeShift=rlb.pK;_.cBondQFBridgeSpan=rlb.qK;_.cBondQFBridgeSpanBits=rlb.rK;_.cBondQFBridgeSpanShift=rlb.sK;_.cBondQFDelocalized=rlb.tK;_.cBondQFDouble=rlb.uK;_.cBondQFMatchFormalOrder=rlb.vK;_.cBondQFMatchStereo=rlb.wK;_.cBondQFMetalLigand=rlb.xK;_.cBondQFNarrowing=rlb.yK;_.cBondQFNoOfBits=rlb.zK;_.cBondQFNotAromatic=rlb.AK;_.cBondQFNotRing=rlb.BK;_.cBondQFQuadruple=rlb.CK;_.cBondQFQuintuple=rlb.DK;_.cBondQFRareBondTypes=rlb.EK;_.cBondQFRareBondTypesBits=rlb.FK;_.cBondQFRareBondTypesShift=rlb.GK;_.cBondQFRing=rlb.HK;_.cBondQFRingSize=rlb.IK;_.cBondQFRingSizeBits=rlb.JK;_.cBondQFRingSizeShift=rlb.KK;_.cBondQFRingState=rlb.LK;_.cBondQFRingStateBits=rlb.MK;_.cBondQFRingStateShift=rlb.NK;_.cBondQFSimpleFeatures=rlb.OK;_.cBondQFSingle=rlb.PK;_.cBondQFTriple=rlb.QK;_.cBondTypeCross=rlb.RK;_.cBondTypeDeleted=rlb.SK;_.cBondTypeDelocalized=rlb.TK;_.cBondTypeDouble=rlb.UK;_.cBondTypeDown=rlb.VK;_.cBondTypeIncreaseOrder=rlb.WK;_.cBondTypeMaskSimple=rlb.XK;_.cBondTypeMaskStereo=rlb.YK;_.cBondTypeMetalLigand=rlb.ZK;_.cBondTypeQuadruple=rlb.$K;_.cBondTypeQuintuple=rlb._K;_.cBondTypeSingle=rlb.aL;_.cBondTypeTriple=rlb.bL;_.cBondTypeUp=rlb.cL;_.cChiralityDiastereomers=rlb.dL;_.cChiralityEpimers=rlb.eL;_.cChiralityIsomerCountMask=rlb.fL;_.cChiralityKnownEnantiomer=rlb.gL;_.cChiralityMeso=rlb.hL;_.cChiralityNotChiral=rlb.iL;_.cChiralityRacemic=rlb.jL;_.cChiralityUnknown=rlb.kL;_.cChiralityUnknownEnantiomer=rlb.lL;_.cCommonOxidationState=rlb.mL;_.cDefaultAVBL=rlb.nL;_.cDefaultAllowedPseudoAtoms=rlb.oL;_.cDefaultAtomValence=rlb.pL;_.cESRGroupBits=rlb.qL;_.cESRMaxGroups=rlb.rL;_.cESRTypeAbs=rlb.sL;_.cESRTypeAnd=rlb.tL;_.cESRTypeOr=rlb.uL;_.cHelperBitCIP=rlb.vL;_.cHelperBitIncludeNitrogenParities=rlb.wL;_.cHelperBitNeighbours=rlb.xL;_.cHelperBitParities=rlb.yL;_.cHelperBitRings=rlb.zL;_.cHelperBitRingsSimple=rlb.AL;_.cHelperBitSymmetrySimple=rlb.BL;_.cHelperBitSymmetryStereoHeterotopicity=rlb.CL;_.cHelperBitsStereo=rlb.DL;_.cHelperCIP=rlb.EL;_.cHelperNeighbours=rlb.FL;_.cHelperNone=rlb.GL;_.cHelperParities=rlb.HL;_.cHelperRings=rlb.IL;_.cHelperRingsSimple=rlb.JL;_.cHelperSymmetrySimple=rlb.KL;_.cHelperSymmetryStereoHeterotopicity=rlb.LL;_.cMaxAtomicNo=rlb.ML;_.cMaxConnAtoms=rlb.NL;_.cMoleculeColorDefault=rlb.OL;_.cMoleculeColorNeutral=rlb.PL;_.cPseudoAtomA=rlb.QL;_.cPseudoAtomAttachmentPoint=rlb.RL;_.cPseudoAtomPolymer=rlb.SL;_.cPseudoAtomR=rlb.TL;_.cPseudoAtomX=rlb.UL;_.cPseudoAtomsAGroups=rlb.VL;_.cPseudoAtomsAll=rlb.WL;_.cPseudoAtomsAminoAcids=rlb.XL;_.cPseudoAtomsHydrogenIsotops=rlb.YL;_.cPseudoAtomsRGroups=rlb.ZL;_.cRoundedMass=rlb.$L;_.fromIDCode=rlb.$M;_.fromMolfile=rlb.bN;_.fromMolfileWithAtomMap=rlb.cN;_.fromSmiles=rlb.dN;_.getAngle=rlb.mN;_.getAngleDif=rlb.nN;_.getAtomicNoFromLabel=rlb.MN;_.getDefaultAverageBondLength=rlb.oO;_.isAtomicNoElectronegative=rlb.uP;_.isAtomicNoElectropositive=rlb.vP;_.setDefaultAverageBondLength=rlb.SQ;_=$1('OCL.MoleculeProperties',qlb.NG);_=$1('OCL.Reaction');_.create=rlb.ER;_.fromMolecules=rlb.FR;_.fromRxn=rlb.GR;_.fromSmiles=rlb.HR;_=$1('OCL.ReactionEncoder',qlb.YG);_.decode=qlb.ZG;_.encode=qlb.$G;_=$1('OCL.Reactor',qlb._G);_=$1('OCL.RingCollection');_.MAX_SMALL_RING_SIZE=rlb.fS;_.MODE_SMALL_AND_LARGE_RINGS=rlb.gS;_.MODE_SMALL_AND_LARGE_RINGS_AND_AROMATICITY=rlb.hS;_.MODE_SMALL_RINGS_AND_AROMATICITY=rlb.iS;_.MODE_SMALL_RINGS_ONLY=rlb.jS;_=$1('OCL.SDFileParser',rlb.DS);_=$1('OCL.SSSearcher',rlb.PS);_=$1('OCL.SSSearcherWithIndex',rlb.WS);_.bitCount=rlb.XS;_.getHexStringFromIndex=rlb.ZS;_.getIndexFromHexString=rlb.$S;_.getKeyIDCode=rlb._S;_.getSimilarityAngleCosine=rlb.bT;_.getSimilarityTanimoto=rlb.cT;_=$1('OCL.SmilesParser',rlb.hT);qlb.mH();_=$1('OCL.ToxicityPredictor',qlb.nH);_.RISK_HIGH=qlb.cH;_.RISK_LOW=qlb.dH;_.RISK_NAMES=qlb.eH;_.RISK_NO=qlb.fH;_.RISK_UNKNOWN=qlb.gH;_.TYPE_IRRITANT=qlb.hH;_.TYPE_MUTAGENIC=qlb.iH;_.TYPE_REPRODUCTIVE_EFFECTIVE=qlb.jH;_.TYPE_TUMORIGENIC=qlb.kH;_=$1('OCL.Transformer',qlb.rH);_=$1('OCL.Util',rlb.oT);_.getHoseCodesFromDiastereotopicID=rlb.pT;_=$1('java.io.Serializable');_.$isInstance=s2;Zkb.L2();_=$1('java.lang.Boolean');_.$isInstance=S2;_=$1('java.lang.CharSequence');_.$isInstance=V2;_=$1('java.lang.Cloneable');_.$isInstance=K3;_=$1('java.lang.Comparable');_.$isInstance=L3;_=$1('java.lang.Double');_.$isInstance=Z3;_=$1('java.lang.Number');_.$isInstance=Zkb.N3;_=$1('java.lang.String');_.$isInstance=i5;_=$1('java.lang.Throwable');_.of=nz;_=$1('javaemul.internal.HashCodes',alb.tgb);_.getIdentityHashCode=alb.ugb;_.getNextHash=alb.vgb;_.getObjectIdentityHashCode=alb.wgb;_=$1('javaemul.internal.JsUtils');_.toDoubleFromUnsignedInt=alb.Ogb;var Xkb=(_kb.IU(),LU);var gwtOnLoad=gwtOnLoad=P1;N1(b2);Q1('permProps',[[['locale','default'],['user.agent','safari']]]);gwtOnLoad(__gwtModuleFunction.__errFn,__gwtModuleFunction.__moduleName,__gwtModuleFunction.__moduleBase,__gwtModuleFunction.__softPermutationId,__gwtModuleFunction.__computePropValue);$gwt&&$gwt.permProps&&__gwtModuleFunction.__moduleStartupDone($gwt.permProps);// End GWT code
  var toReturn=$wnd["OCL"];toReturn.version='8.7.2';return toReturn;}var isBrowser,globalEnv;if(typeof self!=='undefined'){// Usual Browser Window or Web Worker
  isBrowser=true;globalEnv=self;}else if(typeof commonjsGlobal!=='undefined'){// Node.js
  isBrowser=false;globalEnv=commonjsGlobal;}else {// Other environment (example: CouchDB)
  isBrowser=false;globalEnv=root;}var document=globalEnv.document||{};if(!document.compatMode){document.compatMode='CSS1Compat';}var fakeWindow;if(isBrowser&&!true){fakeWindow=globalEnv;}else {fakeWindow={};fakeWindow.setTimeout=globalEnv.setTimeout?globalEnv.setTimeout.bind(globalEnv):noop;fakeWindow.clearTimeout=globalEnv.clearTimeout?globalEnv.clearTimeout.bind(globalEnv):noop;fakeWindow.setInterval=globalEnv.setInterval?globalEnv.setInterval.bind(globalEnv):noop;fakeWindow.clearInterval=globalEnv.clearInterval?globalEnv.clearInterval.bind(globalEnv):noop;// required since GWT 2.8.0
  fakeWindow.Error=globalEnv.Error;fakeWindow.Math=globalEnv.Math;fakeWindow.RegExp=globalEnv.RegExp;fakeWindow.TypeError=globalEnv.TypeError;}if(!fakeWindow.document){fakeWindow.document=document;}var exportedApi=getExports(fakeWindow);var extendApi=function extendApi(exports){function extendCore(exports){let ConformerGenerator=exports.ConformerGenerator;ConformerGenerator.prototype.molecules=function*molecules(){let nextConformer;while((nextConformer=this.getNextConformerAsMolecule())!==null){yield nextConformer;}};let ForceFieldMMFF94=exports.ForceFieldMMFF94;let defaultMinimiseOptions={maxIts:4000,gradTol:1e-4,funcTol:1e-6};ForceFieldMMFF94.prototype.minimise=function minimise(options){options={...defaultMinimiseOptions,...options};return this._minimise(options.maxIts,options.gradTol,options.funcTol);};}extendCore(exports);};{// NodeJS
  fillExports(exportedApi,exports);}function fillExports(obj,exports){var keys=Object.keys(obj);for(var i=0;i<keys.length;i++){exports[keys[i]]=obj[keys[i]];}extendApi(exports);}function noop(){}})(commonjsGlobal);})(openchemlibCore);

  const OCL = openchemlibCore;
  core.default = OCL;
  core.CanonizerUtil = OCL.CanonizerUtil;
  core.ConformerGenerator = OCL.ConformerGenerator;
  core.DrugScoreCalculator = OCL.DrugScoreCalculator;
  core.DruglikenessPredictor = OCL.DruglikenessPredictor;
  core.ForceFieldMMFF94 = OCL.ForceFieldMMFF94;
  var Molecule = core.Molecule = OCL.Molecule;
  core.MoleculeProperties = OCL.MoleculeProperties;
  core.Reaction = OCL.Reaction;
  core.ReactionEncoder = OCL.ReactionEncoder;
  core.Reactor = OCL.Reactor;
  core.RingCollection = OCL.RingCollection;
  core.SDFileParser = OCL.SDFileParser;
  core.SSSearcher = OCL.SSSearcher;
  core.SSSearcherWithIndex = OCL.SSSearcherWithIndex;
  core.SmilesParser = OCL.SmilesParser;
  core.ToxicityPredictor = OCL.ToxicityPredictor;
  core.Transformer = OCL.Transformer;
  core.Util = OCL.Util;
  core.version = OCL.version;

  function ensureSmiles(reagent) {
    if (reagent.smiles) return;
    if (reagent.molfile) {
      reagent.smiles = Molecule.fromMolfile(reagent.molfile).toSmiles();
    }
    if (reagent.ocl?.value) {
      reagent.smiles = Molecule.fromIDCode(reagent.ocl.value).toSmiles();
    }
    if (reagent.ocl?.idCode) {
      reagent.smiles = Molecule.fromIDCode(reagent.ocl.idCode).toSmiles();
    }
  }

  /**
   * Returns a very important number
   * @return {number}
   */
  function normalizeQuantities(reagent, options = {}) {
    const {
      logger
    } = options;
    if (reagent.ml !== undefined) {
      reagent.volume = {
        value: reagent.ml,
        units: 'ml'
      };
    } else if (!reagent.volume) {
      reagent.volume = {
        value: 0,
        units: 'l'
      };
    }
    if (reagent.g !== undefined) {
      reagent.mass = {
        value: reagent.g,
        units: 'g'
      };
    } else if (!reagent.mass) {
      reagent.mass = {
        value: 0,
        units: 'kg'
      };
    }
    if (reagent.volume) {
      const targetUnits = 'l';
      let convert = Qty.swiftConverter(reagent.volume.units, targetUnits);
      reagent.volume = {
        value: convert(reagent.volume.value),
        units: targetUnits
      };
    }
    if (reagent.mass) {
      const targetUnits = 'kg';
      let convert = Qty.swiftConverter(reagent.mass.units, targetUnits);
      reagent.mass = {
        value: convert(reagent.mass.value),
        units: targetUnits
      };
    }
    if (!reagent.volume && !reagent.mass) {
      logger?.error('reagent has no volume or mass');
    } else {
      if (reagent.volume && !reagent.mass) {
        logger?.info('reagent has volume but no mass, assuming density of 1kg/l');
        reagent.mass = {
          value: reagent.volume.value,
          units: 'kg'
        };
      }
      if (reagent.mass && !reagent.volume) {
        logger?.info('reagent has mass but no volume, assuming density of 1kg/l');
        reagent.volume = {
          value: reagent.mass.value,
          units: 'l'
        };
      }
    }
  }

  async function prepareReagents(reagents, options = {}) {
    reagents = JSON.parse(JSON.stringify(reagents));
    for (const reagent of reagents) {
      normalizeQuantities(reagent, options);
      ensureSmiles(reagent);
      await ensureHHazardAndPhysical(reagent, options);
      reagent.safety = {};
    }
    return reagents;
  }

  async function calculateSafety(originalReagents, options = {}) {
    const reagents = await prepareReagents(originalReagents, options);
    const report = {
      scores: {}
    };
    appendAcuteToxicity(reagents, report, options);
    appendReactivityAndInstability(reagents, report, options);
    appendVolumeAndFlammability(reagents, report, options);
    appendLongTermToxicity(reagents, report, options);
    appendMiscellaneous(reagents, report, options);
    report.finalScore = Object.values(report.scores).reduce((sum, score) => sum + score, 0) + report.miscellaneous.reduce((sum, misc) => sum + misc.score, 0);
    const hasRed = report.redAcuteToxicity.length > 0 || report.redReactivityAndInstabilities.length > 0;
    if (report.finalScore <= 12 && !hasRed) {
      report.class = 1;
    } else if (report.finalScore > 18) {
      report.class = 3;
    } else {
      report.class = 2;
    }
    return {
      reagents,
      report
    };
  }

  exports.calculateSafety = calculateSafety;

  Object.defineProperty(exports, '__esModule', { value: true });

}));
//# sourceMappingURL=epfl-safety.js.map
